(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  23830982,     963984]*)
(*NotebookOutlinePosition[  23873443,     965346]*)
(*  CellTagsIndexPosition[  23873399,     965342]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Wuschel Activator Model", "Subtitle"],

Cell[TextData[StyleBox["This model is based on the \"Activator Model\" in \
figure 4 and equations (5) through (8) of the following reference:\n\nH \
Jonsson, M Heisler, GV Reddy, V Agrawal, V Gor, BE Shapiro, E Mjolsness & EM \
Meyerowitz (2005) \"Modeling the organization of the WUSCHEL expression \
domain in the shoot apical meristem,\" Bioinformatics, Vol. 21 Suppl. 1, \
2005, pages i232-i240.\n\nPlease not that the Cellerator and MathSBML \
simulations generate slightly different results because the two programs \
handle diffusion differently: in Cellerator, each compartment has the same \
size, and in MathSBML the actual cell size is used. ",
  FontFamily->"Lucida Grande",
  FontSize->13]], "Text"],

Cell["\<\
File generated by: Bruce Shapiro bshapiro at caltech dot edu 
\trevised 2/23/06 to generate SBML
\t
Support was provided by the US National Science Foundation Grant EF-0330786\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["Licensing: LGPL", "Subsection"],

Cell[TextData[StyleBox["Copyright 2005 California Institute of Technology \n\n\
This notebook is free software; you can redistribute it and/or modify it \
under the terms of the GNU Lesser General Public License as published by the \
Free Software Foundation; either version 2.1 of the License, or any later \
version.\n\nThis notebook is distributed in the hope that it will be useful, \
but WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF \
MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The notebook and  \
documentation provided hereunder is on an \"as is\" basis, and the  \
California Institute of Technology has no obligations to provide maintenance, \
support, updates, enhancements or modifications.  In no event shall the \
California Institute of Technology  be liable to any party for direct, \
indirect, special, incidental or consequential damages, including lost \
profits, arising  out of the use of this notebook and its documentation, even \
if the California Institute of Technology has been advised of the possibility \
of such damage.  See the GNU Lesser General Public License for more details.\n\
\nYou should have received a copy of the GNU Lesser General Public License \
along with this library; if not, write to the Free Software Foundation, Inc., \
59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.",
  FontSize->12]], "Text"],

Cell["\<\


                  GNU LESSER GENERAL PUBLIC LICENSE
                       Version 2.1, February 1999

 Copyright (C) 1991, 1999 Free Software Foundation, Inc.
     59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

[This is the first released version of the Lesser GPL.  It also counts
 as the successor of the GNU Library Public License, version 2, hence
 the version number 2.1.]

                            Preamble

  The licenses for most software are designed to take away your
freedom to share and change it.  By contrast, the GNU General Public
Licenses are intended to guarantee your freedom to share and change
free software--to make sure the software is free for all its users.

  This license, the Lesser General Public License, applies to some
specially designated software packages--typically libraries--of the
Free Software Foundation and other authors who decide to use it.  You
can use it too, but we suggest you first think carefully about whether
this license or the ordinary General Public License is the better
strategy to use in any particular case, based on the explanations
below.

  When we speak of free software, we are referring to freedom of use,
not price.  Our General Public Licenses are designed to make sure that
you have the freedom to distribute copies of free software (and charge
for this service if you wish); that you receive source code or can get
it if you want it; that you can change the software and use pieces of
it in new free programs; and that you are informed that you can do
these things.

  To protect your rights, we need to make restrictions that forbid
distributors to deny you these rights or to ask you to surrender these
rights.  These restrictions translate to certain responsibilities for
you if you distribute copies of the library or if you modify it.

  For example, if you distribute copies of the library, whether gratis
or for a fee, you must give the recipients all the rights that we gave
you.  You must make sure that they, too, receive or can get the source
code.  If you link other code with the library, you must provide
complete object files to the recipients, so that they can relink them
with the library after making changes to the library and recompiling
it.  And you must show them these terms so they know their rights.

  We protect your rights with a two-step method: (1) we copyright the
library, and (2) we offer you this license, which gives you legal
permission to copy, distribute and/or modify the library.

  To protect each distributor, we want to make it very clear that
there is no warranty for the free library.  Also, if the library is
modified by someone else and passed on, the recipients should know
that what they have is not the original version, so that the original
author's reputation will not be affected by problems that might be
introduced by others.
^L
  Finally, software patents pose a constant threat to the existence of
any free program.  We wish to make sure that a company cannot
effectively restrict the users of a free program by obtaining a
restrictive license from a patent holder.  Therefore, we insist that
any patent license obtained for a version of the library must be
consistent with the full freedom of use specified in this license.

  Most GNU software, including some libraries, is covered by the
ordinary GNU General Public License.  This license, the GNU Lesser
General Public License, applies to certain designated libraries, and
is quite different from the ordinary General Public License.  We use
this license for certain libraries in order to permit linking those
libraries into non-free programs.

  When a program is linked with a library, whether statically or using
a shared library, the combination of the two is legally speaking a
combined work, a derivative of the original library.  The ordinary
General Public License therefore permits such linking only if the
entire combination fits its criteria of freedom.  The Lesser General
Public License permits more lax criteria for linking other code with
the library.

  We call this license the \"Lesser\" General Public License because it
does Less to protect the user's freedom than the ordinary General
Public License.  It also provides other free software developers Less
of an advantage over competing non-free programs.  These disadvantages
are the reason we use the ordinary General Public License for many
libraries.  However, the Lesser license provides advantages in certain
special circumstances.

  For example, on rare occasions, there may be a special need to
encourage the widest possible use of a certain library, so that it
becomes
a de-facto standard.  To achieve this, non-free programs must be
allowed to use the library.  A more frequent case is that a free
library does the same job as widely used non-free libraries.  In this
case, there is little to gain by limiting the free library to free
software only, so we use the Lesser General Public License.

  In other cases, permission to use a particular library in non-free
programs enables a greater number of people to use a large body of
free software.  For example, permission to use the GNU C Library in
non-free programs enables many more people to use the whole GNU
operating system, as well as its variant, the GNU/Linux operating
system.

  Although the Lesser General Public License is Less protective of the
users' freedom, it does ensure that the user of a program that is
linked with the Library has the freedom and the wherewithal to run
that program using a modified version of the Library.

  The precise terms and conditions for copying, distribution and
modification follow.  Pay close attention to the difference between a
\"work based on the library\" and a \"work that uses the library\".  The
former contains code derived from the library, whereas the latter must
be combined with the library in order to run.
^L
                  GNU LESSER GENERAL PUBLIC LICENSE
   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION

  0. This License Agreement applies to any software library or other
program which contains a notice placed by the copyright holder or
other authorized party saying it may be distributed under the terms of
this Lesser General Public License (also called \"this License\").
Each licensee is addressed as \"you\".

  A \"library\" means a collection of software functions and/or data
prepared so as to be conveniently linked with application programs
(which use some of those functions and data) to form executables.

  The \"Library\", below, refers to any such software library or work
which has been distributed under these terms.  A \"work based on the
Library\" means either the Library or any derivative work under
copyright law: that is to say, a work containing the Library or a
portion of it, either verbatim or with modifications and/or translated
straightforwardly into another language.  (Hereinafter, translation is
included without limitation in the term \"modification\".)

  \"Source code\" for a work means the preferred form of the work for
making modifications to it.  For a library, complete source code means
all the source code for all modules it contains, plus any associated
interface definition files, plus the scripts used to control
compilation
and installation of the library.

  Activities other than copying, distribution and modification are not
covered by this License; they are outside its scope.  The act of
running a program using the Library is not restricted, and output from
such a program is covered only if its contents constitute a work based
on the Library (independent of the use of the Library in a tool for
writing it).  Whether that is true depends on what the Library does
and what the program that uses the Library does.

  1. You may copy and distribute verbatim copies of the Library's
complete source code as you receive it, in any medium, provided that
you conspicuously and appropriately publish on each copy an
appropriate copyright notice and disclaimer of warranty; keep intact
all the notices that refer to this License and to the absence of any
warranty; and distribute a copy of this License along with the
Library.

  You may charge a fee for the physical act of transferring a copy,
and you may at your option offer warranty protection in exchange for a
fee.
\.0c
  2. You may modify your copy or copies of the Library or any portion
of it, thus forming a work based on the Library, and copy and
distribute such modifications or work under the terms of Section 1
above, provided that you also meet all of these conditions:

    a) The modified work must itself be a software library.

    b) You must cause the files modified to carry prominent notices
    stating that you changed the files and the date of any change.

    c) You must cause the whole of the work to be licensed at no
    charge to all third parties under the terms of this License.

    d) If a facility in the modified Library refers to a function or a
    table of data to be supplied by an application program that uses
    the facility, other than as an argument passed when the facility
    is invoked, then you must make a good faith effort to ensure that,
    in the event an application does not supply such function or
    table, the facility still operates, and performs whatever part of
    its purpose remains meaningful.

    (For example, a function in a library to compute square roots has
    a purpose that is entirely well-defined independent of the
    application.  Therefore, Subsection 2d requires that any
    application-supplied function or table used by this function must
    be optional: if the application does not supply it, the square
    root function must still compute square roots.)

These requirements apply to the modified work as a whole.  If
identifiable sections of that work are not derived from the Library,
and can be reasonably considered independent and separate works in
themselves, then this License, and its terms, do not apply to those
sections when you distribute them as separate works.  But when you
distribute the same sections as part of a whole which is a work based
on the Library, the distribution of the whole must be on the terms of
this License, whose permissions for other licensees extend to the
entire whole, and thus to each and every part regardless of who wrote
it.

Thus, it is not the intent of this section to claim rights or contest
your rights to work written entirely by you; rather, the intent is to
exercise the right to control the distribution of derivative or
collective works based on the Library.

In addition, mere aggregation of another work not based on the Library
with the Library (or with a work based on the Library) on a volume of
a storage or distribution medium does not bring the other work under
the scope of this License.

  3. You may opt to apply the terms of the ordinary GNU General Public
License instead of this License to a given copy of the Library.  To do
this, you must alter all the notices that refer to this License, so
that they refer to the ordinary GNU General Public License, version 2,
instead of to this License.  (If a newer version than version 2 of the
ordinary GNU General Public License has appeared, then you can specify
that version instead if you wish.)  Do not make any other change in
these notices.
^L
  Once this change is made in a given copy, it is irreversible for
that copy, so the ordinary GNU General Public License applies to all
subsequent copies and derivative works made from that copy.

  This option is useful when you wish to copy part of the code of
the Library into a program that is not a library.

  4. You may copy and distribute the Library (or a portion or
derivative of it, under Section 2) in object code or executable form
under the terms of Sections 1 and 2 above provided that you accompany
it with the complete corresponding machine-readable source code, which
must be distributed under the terms of Sections 1 and 2 above on a
medium customarily used for software interchange.

  If distribution of object code is made by offering access to copy
from a designated place, then offering equivalent access to copy the
source code from the same place satisfies the requirement to
distribute the source code, even though third parties are not
compelled to copy the source along with the object code.

  5. A program that contains no derivative of any portion of the
Library, but is designed to work with the Library by being compiled or
linked with it, is called a \"work that uses the Library\".  Such a
work, in isolation, is not a derivative work of the Library, and
therefore falls outside the scope of this License.

  However, linking a \"work that uses the Library\" with the Library
creates an executable that is a derivative of the Library (because it
contains portions of the Library), rather than a \"work that uses the
library\".  The executable is therefore covered by this License.
Section 6 states terms for distribution of such executables.

  When a \"work that uses the Library\" uses material from a header file
that is part of the Library, the object code for the work may be a
derivative work of the Library even though the source code is not.
Whether this is true is especially significant if the work can be
linked without the Library, or if the work is itself a library.  The
threshold for this to be true is not precisely defined by law.

  If such an object file uses only numerical parameters, data
structure layouts and accessors, and small macros and small inline
functions (ten lines or less in length), then the use of the object
file is unrestricted, regardless of whether it is legally a derivative
work.  (Executables containing this object code plus portions of the
Library will still fall under Section 6.)

  Otherwise, if the work is a derivative of the Library, you may
distribute the object code for the work under the terms of Section 6.
Any executables containing that work also fall under Section 6,
whether or not they are linked directly with the Library itself.
^L
  6. As an exception to the Sections above, you may also combine or
link a \"work that uses the Library\" with the Library to produce a
work containing portions of the Library, and distribute that work
under terms of your choice, provided that the terms permit
modification of the work for the customer's own use and reverse
engineering for debugging such modifications.

  You must give prominent notice with each copy of the work that the
Library is used in it and that the Library and its use are covered by
this License.  You must supply a copy of this License.  If the work
during execution displays copyright notices, you must include the
copyright notice for the Library among them, as well as a reference
directing the user to the copy of this License.  Also, you must do one
of these things:

    a) Accompany the work with the complete corresponding
    machine-readable source code for the Library including whatever
    changes were used in the work (which must be distributed under
    Sections 1 and 2 above); and, if the work is an executable linked
    with the Library, with the complete machine-readable \"work that
    uses the Library\", as object code and/or source code, so that the
    user can modify the Library and then relink to produce a modified
    executable containing the modified Library.  (It is understood
    that the user who changes the contents of definitions files in the
    Library will not necessarily be able to recompile the application
    to use the modified definitions.)

    b) Use a suitable shared library mechanism for linking with the
    Library.  A suitable mechanism is one that (1) uses at run time a
    copy of the library already present on the user's computer system,
    rather than copying library functions into the executable, and (2)
    will operate properly with a modified version of the library, if
    the user installs one, as long as the modified version is
    interface-compatible with the version that the work was made with.

    c) Accompany the work with a written offer, valid for at
    least three years, to give the same user the materials
    specified in Subsection 6a, above, for a charge no more
    than the cost of performing this distribution.

    d) If distribution of the work is made by offering access to copy
    from a designated place, offer equivalent access to copy the above
    specified materials from the same place.

    e) Verify that the user has already received a copy of these
    materials or that you have already sent this user a copy.

  For an executable, the required form of the \"work that uses the
Library\" must include any data and utility programs needed for
reproducing the executable from it.  However, as a special exception,
the materials to be distributed need not include anything that is
normally distributed (in either source or binary form) with the major
components (compiler, kernel, and so on) of the operating system on
which the executable runs, unless that component itself accompanies
the executable.

  It may happen that this requirement contradicts the license
restrictions of other proprietary libraries that do not normally
accompany the operating system.  Such a contradiction means you cannot
use both them and the Library together in an executable that you
distribute.
^L
  7. You may place library facilities that are a work based on the
Library side-by-side in a single library together with other library
facilities not covered by this License, and distribute such a combined
library, provided that the separate distribution of the work based on
the Library and of the other library facilities is otherwise
permitted, and provided that you do these two things:

    a) Accompany the combined library with a copy of the same work
    based on the Library, uncombined with any other library
    facilities.  This must be distributed under the terms of the
    Sections above.

    b) Give prominent notice with the combined library of the fact
    that part of it is a work based on the Library, and explaining
    where to find the accompanying uncombined form of the same work.

  8. You may not copy, modify, sublicense, link with, or distribute
the Library except as expressly provided under this License.  Any
attempt otherwise to copy, modify, sublicense, link with, or
distribute the Library is void, and will automatically terminate your
rights under this License.  However, parties who have received copies,
or rights, from you under this License will not have their licenses
terminated so long as such parties remain in full compliance.

  9. You are not required to accept this License, since you have not
signed it.  However, nothing else grants you permission to modify or
distribute the Library or its derivative works.  These actions are
prohibited by law if you do not accept this License.  Therefore, by
modifying or distributing the Library (or any work based on the
Library), you indicate your acceptance of this License to do so, and
all its terms and conditions for copying, distributing or modifying
the Library or works based on it.

  10. Each time you redistribute the Library (or any work based on the
Library), the recipient automatically receives a license from the
original licensor to copy, distribute, link with or modify the Library
subject to these terms and conditions.  You may not impose any further
restrictions on the recipients' exercise of the rights granted herein.
You are not responsible for enforcing compliance by third parties with
this License.
^L
  11. If, as a consequence of a court judgment or allegation of patent
infringement or for any other reason (not limited to patent issues),
conditions are imposed on you (whether by court order, agreement or
otherwise) that contradict the conditions of this License, they do not
excuse you from the conditions of this License.  If you cannot
distribute so as to satisfy simultaneously your obligations under this
License and any other pertinent obligations, then as a consequence you
may not distribute the Library at all.  For example, if a patent
license would not permit royalty-free redistribution of the Library by
all those who receive copies directly or indirectly through you, then
the only way you could satisfy both it and this License would be to
refrain entirely from distribution of the Library.

If any portion of this section is held invalid or unenforceable under
any particular circumstance, the balance of the section is intended to
apply, and the section as a whole is intended to apply in other
circumstances.

It is not the purpose of this section to induce you to infringe any
patents or other property right claims or to contest validity of any
such claims; this section has the sole purpose of protecting the
integrity of the free software distribution system which is
implemented by public license practices.  Many people have made
generous contributions to the wide range of software distributed
through that system in reliance on consistent application of that
system; it is up to the author/donor to decide if he or she is willing
to distribute software through any other system and a licensee cannot
impose that choice.

This section is intended to make thoroughly clear what is believed to
be a consequence of the rest of this License.

  12. If the distribution and/or use of the Library is restricted in
certain countries either by patents or by copyrighted interfaces, the
original copyright holder who places the Library under this License
may add an explicit geographical distribution limitation excluding those
countries, so that distribution is permitted only in or among
countries not thus excluded.  In such case, this License incorporates
the limitation as if written in the body of this License.

  13. The Free Software Foundation may publish revised and/or new
versions of the Lesser General Public License from time to time.
Such new versions will be similar in spirit to the present version,
but may differ in detail to address new problems or concerns.

Each version is given a distinguishing version number.  If the Library
specifies a version number of this License which applies to it and
\"any later version\", you have the option of following the terms and
conditions either of that version or of any later version published by
the Free Software Foundation.  If the Library does not specify a
license version number, you may choose any version ever published by
the Free Software Foundation.
^L
  14. If you wish to incorporate parts of the Library into other free
programs whose distribution conditions are incompatible with these,
write to the author to ask for permission.  For software which is
copyrighted by the Free Software Foundation, write to the Free
Software Foundation; we sometimes make exceptions for this.  Our
decision will be guided by the two goals of preserving the free status
of all derivatives of our free software and of promoting the sharing
and reuse of software generally.

                            NO WARRANTY

  15. BECAUSE THE LIBRARY IS LICENSED FREE OF CHARGE, THERE IS NO
WARRANTY FOR THE LIBRARY, TO THE EXTENT PERMITTED BY APPLICABLE LAW.
EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR
OTHER PARTIES PROVIDE THE LIBRARY \"AS IS\" WITHOUT WARRANTY OF ANY
KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
LIBRARY IS WITH YOU.  SHOULD THE LIBRARY PROVE DEFECTIVE, YOU ASSUME
THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

  16. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN
WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY
AND/OR REDISTRIBUTE THE LIBRARY AS PERMITTED ABOVE, BE LIABLE TO YOU
FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
LIBRARY (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE LIBRARY TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
DAMAGES.

                     END OF TERMS AND CONDITIONS
^L
           How to Apply These Terms to Your New Libraries

  If you develop a new library, and you want it to be of the greatest
possible use to the public, we recommend making it free software that
everyone can redistribute and change.  You can do so by permitting
redistribution under these terms (or, alternatively, under the terms
of the ordinary General Public License).

  To apply these terms, attach the following notices to the library.
It is safest to attach them to the start of each source file to most
effectively convey the exclusion of warranty; and each file should
have at least the \"copyright\" line and a pointer to where the full
notice is found.


    <one line to give the library's name and a brief idea of what it
does.>
    Copyright (C) <year>  <name of author>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA

Also add information on how to contact you by electronic and paper
mail.

You should also get your employer (if you work as a programmer) or
your school, if any, to sign a \"copyright disclaimer\" for the library,
if necessary.  Here is a sample; alter the names:

  Yoyodyne, Inc., hereby disclaims all copyright interest in the
  library `Frob' (a library for tweaking knobs) written by James
  Random Hacker.

  <signature of Ty Coon>, 1 April 1990
  Ty Coon, President of Vice

That's all there is to it!
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load the Necessary Packages", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< mathsbml.m;\)\), "\[IndentingNewLine]", 
    \(<< xlr8r.m\)}], "Input"],

Cell[BoxData[
    \("MathSBML 2.5.13 (4 May 2006) loaded 18-May-2006 09:44:40.028694 using \
Mathematica 5.2 for Mac OS X (June 20, 2005)"\)], "Print"],

Cell[BoxData[
    \("xlr8r 0.22 (10-September-2005) loaded 18-May-2006 09:44:40.327163 \
using Mathematica 5.2 for Mac OS X (June 20, 2005)"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< mpower.m\)], "Input"],

Cell[BoxData[
    \("mPower Version alpha 0.7 (1 March 2006) using Mathematica Version 5.2 \
for Mac OS X (June 20, 2005) loaded 18-May-2006 09:44:40.516129"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< cellzilla.m\)], "Input"],

Cell[BoxData[
    \("MathSBML 2.5.13 (4 May 2006) loaded 18-May-2006 09:44:40.968763 using \
Mathematica 5.2 for Mac OS X (June 20, 2005)"\)], "Print"],

Cell[BoxData[
    \("mPower Version alpha 0.7 (1 March 2006) using Mathematica Version 5.2 \
for Mac OS X (June 20, 2005) loaded 18-May-2006 09:44:41.068135"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("cellzilla version "\[InvisibleSpace]"1.0.8 \
Experimental (15 Feb 2006)"\[InvisibleSpace]" loaded."\),
      SequenceForm[ 
      "cellzilla version ", "1.0.8 Experimental (15 Feb 2006)", " loaded."],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Read the data file, extract the Meristem Coordinates, and remove \
the floral meristems\
\>", "Section"],

Cell[BoxData[{
    \(\(t014 = 
        Import["\<Desktop/WusActivator/t014.txt\>", "\<Table\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(xyz = \(Drop[#, \(-1\)] &\) /@ t014;\)\), "\[IndentingNewLine]", 
    \(\(slice[data_, \ bottom_, \ top_] := \ 
        Select[data, \ \[IndentingNewLine]\((\((bottom \[LessEqual] \ 
                    Last[#]\ )\) \[And] \ \((Last[#] \[LessEqual] 
                    top)\))\) &\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(\(xy = Most /@ slice[xyz, 62, 72];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[xy]\)], "Input"],

Cell[BoxData[
    \(344\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = 
        ListPlot[xy, PlotRange \[Rule] \ {{0, 150}, {0, 120}}, 
          AspectRatio \[Rule] \ 0.8, ImageSize \[Rule] \ 500, \ 
          DisplayFunction \[Rule] \ Identity];\)\), "\[IndentingNewLine]", 
    \(\(mypoly = {{60, 120}, {40, 110}, {40, 75}, {20, 35}, {80, 20}, {120, 
            35}, {80, 120}, {60, 120}};\)\), "\[IndentingNewLine]", 
    \(Show[p1, Graphics[Line[mypoly]], \ 
      DisplayFunction \[Rule] \ $DisplayFunction]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
%%ImageSize: 500 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.20924e-17 0.00666667 0 0.00666667 [
[.13333 -0.0125 -6 -9 ]
[.13333 -0.0125 6 0 ]
[.26667 -0.0125 -6 -9 ]
[.26667 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.53333 -0.0125 -6 -9 ]
[.53333 -0.0125 6 0 ]
[.66667 -0.0125 -9 -9 ]
[.66667 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[.93333 -0.0125 -9 -9 ]
[.93333 -0.0125 9 0 ]
[-0.0125 .13333 -12 -4.5 ]
[-0.0125 .13333 0 4.5 ]
[-0.0125 .26667 -12 -4.5 ]
[-0.0125 .26667 0 4.5 ]
[-0.0125 .4 -12 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .53333 -12 -4.5 ]
[-0.0125 .53333 0 4.5 ]
[-0.0125 .66667 -18 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13333 0 m
.13333 .00625 L
s
[(20)] .13333 -0.0125 0 1 Mshowa
.26667 0 m
.26667 .00625 L
s
[(40)] .26667 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.53333 0 m
.53333 .00625 L
s
[(80)] .53333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(100)] .66667 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(120)] .8 -0.0125 0 1 Mshowa
.93333 0 m
.93333 .00625 L
s
[(140)] .93333 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.3 0 m
.3 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.5 0 m
.5 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13333 m
.00625 .13333 L
s
[(20)] -0.0125 .13333 1 0 Mshowa
0 .26667 m
.00625 .26667 L
s
[(40)] -0.0125 .26667 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(60)] -0.0125 .4 1 0 Mshowa
0 .53333 m
.00625 .53333 L
s
[(80)] -0.0125 .53333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(100)] -0.0125 .66667 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(120)] -0.0125 .8 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .16667 m
.00375 .16667 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .3 m
.00375 .3 L
s
0 .33333 m
.00375 .33333 L
s
0 .36667 m
.00375 .36667 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .5 m
.00375 .5 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
.25 Mabswid
0 0 m
0 .8 L
s
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
.008 w
.18173 .6496 Mdot
.08507 .36347 Mdot
.52587 .17787 Mdot
.24747 .43307 Mdot
.37507 .43307 Mdot
.54133 .59547 Mdot
.116 .3828 Mdot
.2436 .34027 Mdot
.27067 .4756 Mdot
.34413 .2204 Mdot
.40987 .29773 Mdot
.4524 .27067 Mdot
.65347 .33253 Mdot
.754 .40213 Mdot
.7656 .53747 Mdot
.11213 .59933 Mdot
.23973 .39827 Mdot
.348 .3596 Mdot
.4408 .35187 Mdot
.46787 .39053 Mdot
.45627 .7192 Mdot
.49493 .38667 Mdot
.4872 .69987 Mdot
.50267 .67667 Mdot
.53747 .32867 Mdot
.5916 .1856 Mdot
.64187 .21267 Mdot
.63413 .52973 Mdot
.696 .35187 Mdot
.25907 .30547 Mdot
.30547 .43693 Mdot
.36347 .25133 Mdot
.37507 .76173 Mdot
.37507 .38667 Mdot
.3944 .21267 Mdot
.3944 .71147 Mdot
.49107 .55293 Mdot
.51813 .4292 Mdot
.522 .6148 Mdot
.5568 .19333 Mdot
.64573 .32093 Mdot
.6844 .3712 Mdot
.7772 .36733 Mdot
.80813 .3828 Mdot
.232 .51427 Mdot
.3248 .59547 Mdot
.36347 .51427 Mdot
.3596 .5336 Mdot
.35573 .22813 Mdot
.34027 .6728 Mdot
.3596 .696 Mdot
.38667 .4872 Mdot
.3828 .1972 Mdot
.40213 .34027 Mdot
.4292 .1972 Mdot
.42533 .62253 Mdot
.46787 .41373 Mdot
.47173 .754 Mdot
.4872 .35187 Mdot
.4988 .26293 Mdot
.5336 .21267 Mdot
.52587 .5684 Mdot
.52587 .6496 Mdot
.54907 .3596 Mdot
.57227 .4176 Mdot
.6032 .4756 Mdot
.59933 .46013 Mdot
.6844 .27067 Mdot
.7772 .56067 Mdot
.12373 .65733 Mdot
.12373 .35187 Mdot
.11213 .7076 Mdot
.15853 .7192 Mdot
.1508 .42147 Mdot
.19333 .41373 Mdot
.21267 .65733 Mdot
.22427 .6032 Mdot
.2552 .41373 Mdot
.3132 .23973 Mdot
.348 .74627 Mdot
.33253 .2552 Mdot
.35187 .6148 Mdot
.348 .64573 Mdot
.39827 .37893 Mdot
.4176 .43307 Mdot
.4292 .29773 Mdot
.4524 .5916 Mdot
.45627 .20493 Mdot
.48333 .18173 Mdot
.58387 .5684 Mdot
.64573 .24747 Mdot
.63027 .37893 Mdot
.638 .35573 Mdot
.6264 .38667 Mdot
.79267 .47173 Mdot
.06187 .5452 Mdot
.1276 .46013 Mdot
.17013 .5452 Mdot
.20107 .58773 Mdot
.25907 .3364 Mdot
.27067 .4408 Mdot
.29387 .57613 Mdot
.29773 .39827 Mdot
.3132 .51427 Mdot
.31707 .696 Mdot
.36733 .45627 Mdot
.3712 .5452 Mdot
.40987 .58773 Mdot
.40213 .51813 Mdot
.41373 .75013 Mdot
.4176 .69987 Mdot
.40213 .22427 Mdot
.41373 .48333 Mdot
.5104 .5336 Mdot
.50653 .50653 Mdot
.50653 .1972 Mdot
.50267 .58773 Mdot
.5684 .59547 Mdot
.57613 .21653 Mdot
.61093 .22427 Mdot
.60707 .52587 Mdot
.66507 .45627 Mdot
.72307 .49493 Mdot
.7308 .51813 Mdot
.07733 .406 Mdot
.0696 .4292 Mdot
.21267 .45627 Mdot
.3828 .5568 Mdot
.39827 .45627 Mdot
.3828 .26293 Mdot
.4292 .3828 Mdot
.43693 .6612 Mdot
.49493 .47173 Mdot
.57613 .2552 Mdot
.54907 .69987 Mdot
.55293 .28227 Mdot
.57613 .6728 Mdot
.61867 .28613 Mdot
.6148 .25133 Mdot
.65347 .28613 Mdot
.66893 .3248 Mdot
.8236 .38667 Mdot
.058 .63413 Mdot
.08507 .3364 Mdot
.15853 .65733 Mdot
.27453 .3248 Mdot
.32093 .52973 Mdot
.3132 .45627 Mdot
.40987 .54133 Mdot
.41373 .35187 Mdot
.43693 .32867 Mdot
.44467 .54907 Mdot
.4292 .68827 Mdot
.4292 .44467 Mdot
.45627 .51813 Mdot
.47173 .52587 Mdot
.49493 .6496 Mdot
.52973 .46013 Mdot
.54907 .2436 Mdot
.54133 .39053 Mdot
.53747 .51813 Mdot
.5336 .53747 Mdot
.54907 .43693 Mdot
.59547 .28227 Mdot
.76947 .40213 Mdot
.80427 .4176 Mdot
.09667 .4524 Mdot
.16627 .69987 Mdot
.18947 .4176 Mdot
.2668 .37893 Mdot
.29773 .29 Mdot
.30933 .6496 Mdot
.3016 .32867 Mdot
.3248 .55293 Mdot
.3248 .3364 Mdot
.33253 .49107 Mdot
.3364 .71147 Mdot
.3364 .42533 Mdot
.35187 .29773 Mdot
.3712 .58773 Mdot
.3828 .63413 Mdot
.39827 .6612 Mdot
.3944 .41373 Mdot
.41373 .39053 Mdot
.43693 .23587 Mdot
.45627 .7308 Mdot
.48333 .2088 Mdot
.47173 .638 Mdot
.47173 .57613 Mdot
.522 .23973 Mdot
.5568 .63027 Mdot
.57613 .5104 Mdot
.58773 .30933 Mdot
.1392 .52973 Mdot
.18947 .56067 Mdot
.22427 .5336 Mdot
.348 .3596 Mdot
.32093 .29 Mdot
.3712 .35187 Mdot
.4292 .65347 Mdot
.4408 .21267 Mdot
.46787 .61093 Mdot
.48333 .50267 Mdot
.50267 .43693 Mdot
.49107 .7076 Mdot
.5452 .66507 Mdot
.5336 .36733 Mdot
.54133 .56453 Mdot
.54133 .58773 Mdot
.6148 .3248 Mdot
.73853 .54133 Mdot
.7424 .44853 Mdot
.8352 .35573 Mdot
.0696 .52587 Mdot
.18173 .50267 Mdot
.18173 .66507 Mdot
.20493 .63027 Mdot
.21267 .49107 Mdot
.28227 .3596 Mdot
.31707 .4292 Mdot
.36347 .50267 Mdot
.37893 .522 Mdot
.4176 .60707 Mdot
.4292 .52973 Mdot
.4408 .5916 Mdot
.44467 .3596 Mdot
.46787 .24747 Mdot
.49493 .35187 Mdot
.58 .48333 Mdot
.75787 .57613 Mdot
.14307 .63027 Mdot
.31707 .63027 Mdot
.3364 .4524 Mdot
.3712 .70373 Mdot
.3944 .49493 Mdot
.39053 .6264 Mdot
.4292 .50267 Mdot
.43693 .47947 Mdot
.47173 .38667 Mdot
.50267 .53747 Mdot
.74627 .5104 Mdot
.34413 .57227 Mdot
.36733 .46013 Mdot
.40213 .46787 Mdot
.50267 .57613 Mdot
.06187 .4872 Mdot
.21653 .56453 Mdot
.6032 .4524 Mdot
.75787 .47173 Mdot
.7888 .42533 Mdot
.80427 .38667 Mdot
.79267 .5104 Mdot
.11213 .34027 Mdot
.1624 .50653 Mdot
.23587 .63413 Mdot
.32867 .72693 Mdot
.7888 .42147 Mdot
.1856 .70373 Mdot
.29387 .53747 Mdot
.34413 .58 Mdot
.37893 .64573 Mdot
.48333 .44467 Mdot
.64187 .44467 Mdot
.65347 .48333 Mdot
.6728 .4292 Mdot
.14693 .57613 Mdot
.232 .3712 Mdot
.23973 .54907 Mdot
.3016 .32093 Mdot
.29 .2436 Mdot
.37507 .66893 Mdot
.58 .64573 Mdot
.58387 .37893 Mdot
.59547 .59933 Mdot
.67667 .23973 Mdot
.696 .3132 Mdot
.76947 .44853 Mdot
.08893 .47173 Mdot
.28227 .27067 Mdot
.348 .48333 Mdot
.55293 .50267 Mdot
.58387 .61867 Mdot
.75787 .49107 Mdot
.11213 .51427 Mdot
.13147 .68827 Mdot
.1972 .50653 Mdot
.29387 .66507 Mdot
.29387 .464 Mdot
.46013 .696 Mdot
.5452 .464 Mdot
.8352 .33253 Mdot
.17787 .46013 Mdot
.18173 .61867 Mdot
.1972 .68053 Mdot
.30547 .49107 Mdot
.4988 .61867 Mdot
.5684 .54133 Mdot
.62253 .41373 Mdot
.73853 .57613 Mdot
.77333 .61093 Mdot
.37507 .7308 Mdot
.39053 .28613 Mdot
.46013 .66893 Mdot
.6612 .40213 Mdot
.10053 .696 Mdot
.464 .3364 Mdot
.58 .42533 Mdot
.79653 .36347 Mdot
.07347 .67667 Mdot
.1276 .40213 Mdot
.14307 .47947 Mdot
.15467 .3828 Mdot
.16627 .44467 Mdot
.28227 .41373 Mdot
.348 .3944 Mdot
.36347 .3132 Mdot
.37893 .59933 Mdot
.52587 .68053 Mdot
.62253 .4756 Mdot
.6496 .3596 Mdot
.78493 .4524 Mdot
.0928 .42533 Mdot
.10827 .49107 Mdot
.12373 .66507 Mdot
.29387 .3828 Mdot
.31707 .5916 Mdot
.40987 .7192 Mdot
.4176 .5684 Mdot
.4292 .42147 Mdot
.638 .4292 Mdot
.08507 .37507 Mdot
.54133 .61867 Mdot
.174 .61093 Mdot
.348 .53747 Mdot
.52973 .4872 Mdot
.7656 .42533 Mdot
.3364 .68053 Mdot
.4756 .41373 Mdot
.4292 .76947 Mdot
.28613 .61867 Mdot
.3016 .29387 Mdot
.50267 .73467 Mdot
.47173 .30547 Mdot
.52587 .7192 Mdot
.5 Mabswid
.4 .8 m
.26667 .73333 L
.26667 .5 L
.13333 .23333 L
.53333 .13333 L
.8 .23333 L
.53333 .8 L
.4 .8 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001T2000`400?l00000o`00003ooooooooe
ooooo`00DOooool5o`0000?ooooo0_l0000gooooo`?o00000oooool2o`0003Oooooo0ol00004oooo
o`;o0000=_ooool3o`0000Cooooo0_l0000cooooo`?o00001?ooool2o`0000Cooooo0_l0000`oooo
o`?o00000_ooool5o`0000?ooooo0_l0000aooooo`?o00001?ooool3o`0000?ooooo0_l0000Joooo
o`00D_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003Oooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0003Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05oooool005?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000dooooo`Go00000_ooool01?l0003oooooooooool0
000eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000dooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000cooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000`ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000aooooo`04
o`000?ooooooooooooooo`Go00000_ooool01?l0003oooooooooool0000Iooooo`00E?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0003Gooooo1?l00003ooooo`04o`000?ooooooooooo`0003Go
oooo0ol00003ooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0;oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
01Oooooo001Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000e
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000=Oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0003Cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00033ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000?ooooo00Co0000oooooooooooo00006Oooool0057ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0003Kooooo0_l00003ooooo`04o`000?oooooo
ooooo`0003Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000dooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000booooo`;o00001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0002oooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0000`ooooo`;o00001Oooool2o`0000?o
oooo00Co0000oooooooooooo00006Oooool005;ooooo0ol00004ooooo`;o0000>?ooool00ol0003o
ooooooooo`02ooooo`;o0000>?ooool2o`0000Cooooo0_l0000fooooo`?o00001?ooool2o`0003Co
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0000aooooo`03o`000?oooooooooo00;o
oooo0ol00004ooooo`;o0000<_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo0_l0000Jooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`00oooooooeoooo
o`00oooooooeooooo`00oooooooeooooo`00oooooooeooooo`006?ooooooo`000=co00000Oooool0
01Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00oooooo000Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0?ooooo`006?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01kooooo
000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJ
ooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oo
oooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003ooooooooo
o`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000oooo
ooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`00
0?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool0
0ol0003oooooooooo`3oooooom[ooooo000Hooooo`?o0000oooooooJooooo`006?ooool00ol0003o
ooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o
0000ooooooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hoooo
o`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`00
6?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_oo
ool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3ooooo
om[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0
oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooo
oooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool3o`000?oo
oooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003ooooooooo
o`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000oooo
ooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`00
0?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool0
0ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001So
oooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo
000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJ
ooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oo
oooof_ooool001Sooooo0ol0003oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_oo
ool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3ooooo
om[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0
oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooo
oooo0?oooooof_ooool001Sooooo00?o0000ooooooooool0oooooooJooooo`006?ooool00ol0003o
ooooooooo`3oooooom[ooooo000Hooooo`03o`000?oooooooooo0?oooooof_ooool001Sooooo00?o
0000ooooooooool0oooooooJooooo`006?ooool00ol0003oooooooooo`3oooooom[ooooo0006oooo
o`Go00000oooool2o`0000Sooooo00?o0000ooooooooool0oooooooJooooo`001oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0oooooooJ
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0oooooooJooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool01Oooool4o`000?Oooooo1?l0003Mooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3dooooo`Co00001?oo
ool3o`000=[ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo0?3ooooo1?l0000;ooooo`?o0000eoooool000Oooooo0ol0
0004ooooo`;o00002?ooool00ol0003oooooooooo`3/ooooo`Co00004_ooool2o`000=Gooooo000H
ooooo`03o`000?oooooooooo0>Sooooo1?l0000Hooooo`?o0000d_ooool001Sooooo00?o0000oooo
ooooool0i?ooool4o`0001oooooo0ol0003?ooooo`006?ooool00ol0003oooooooooo`3Pooooo`Co
00009_ooool2o`000<gooooo000Hooooo`03o`000?oooooooooo0=cooooo1?l0000/ooooo`?o0000
b_ooool001Sooooo00?o0000ooooooooool0f?ooool4o`0003?ooooo0ol00037ooooo`006?ooool0
0ol0003oooooooooo`3Dooooo`Co0000>_ooool2o`000<Gooooo000Hooooo`03o`000?oooooooooo
0=3ooooo1?l00010ooooo`?o0000`_ooool001Sooooo00?o0000ooooooooool0c?ooool4o`0004Oo
oooo0ol0002oooooo`006?ooool00ol0003oooooooooo`37ooooo`Go0000C_ooool3o`000;cooooo
000Hooooo`03o`000?oooooooooo0<?ooooo1?l0001Fooooo`;o0000^_ooool001Sooooo00?o0000
ooooooooool0_oooool4o`0005cooooo0ol0002gooooo`006?ooool00ol0003oooooooooo`2koooo
o`Co0000Hoooool3o`000;Cooooo000Hooooo`?o0000]oooool4o`0006[ooooo0_l0002booooo`00
6?ooool00ol0003oooooooooo`2cooooo`Co0000L?ooool3o`000:oooooo000Hooooo`03o`000?oo
oooooooo0:oooooo1?l0001gooooo`?o0000[?ooool001Sooooo00?o0000ooooooooool0Zoooool4
o`0007kooooo0_l0002Zooooo`006?ooool00ol0003oooooooooo`2Wooooo`Co0000B_ooool3o`00
03Oooooo0ol0002Wooooo`006?ooool00ol0003oooooooooo`2Sooooo`Co0000C_ooool3o`0003[o
oooo0ol0002Tooooo`006?ooool00ol0003oooooooooo`2Oooooo`Co0000?_ooool3o`00017ooooo
0ol0000mooooo`;o0000X_ooool001Sooooo00?o0000ooooooooool0Voooool4o`0004;ooooo0ol0
001Cooooo`?o0000Woooool001Sooooo00?o0000ooooooooool0Uoooool4o`0004Kooooo0ol0000`
ooooo`?o00008oooool3o`0009cooooo000Hooooo`03o`000?oooooooooo09?ooooo1?l0001moooo
o`?o00009_ooool2o`0009[ooooo000Hooooo`03o`000?oooooooooo08oooooo1?l00021ooooo`?o
0000:?ooool3o`0009Oooooo000Hooooo`03o`000?oooooooooo08_ooooo1?l0002cooooo`?o0000
U?ooool001Sooooo00?o0000ooooooooool0Qoooool4o`0007Wooooo0ol0000nooooo`;o0000T_oo
ool001Sooooo00?o0000ooooooooool0Poooool4o`0002[ooooo0ol0000Cooooo`?o00008_ooool3
o`0001Gooooo0ol00010ooooo`?o0000Soooool001Sooooo00?o0000ooooooooool0Ooooool4o`00
02kooooo0ol0000Cooooo`?o00008_ooool3o`0001Gooooo0ol00013ooooo`?o0000S?ooool001So
oooo0ol0001kooooo`Co0000<_ooool3o`0001?ooooo0ol0000Rooooo`?o0000G_ooool2o`0008[o
oooo000Hooooo`03o`000?oooooooooo07Oooooo1?l0003Dooooo`?o0000Qoooool001Sooooo00?o
0000ooooooooool0Loooool4o`0005gooooo0ol0001kooooo`?o0000Q?ooool001Sooooo00?o0000
ooooooooool0Koooool4o`00067ooooo0ol0001nooooo`;o0000P_ooool001Sooooo00?o0000oooo
ooooool0J_ooool5o`0006Gooooo0ol0000:ooooo`?o0000Loooool3o`0007oooooo000Hooooo`03
o`000?oooooooooo06Kooooo1?l0001gooooo`?o0000M_ooool3o`0007cooooo000Hooooo`03o`00
0?oooooooooo06;ooooo1?l0001@ooooo`?o00005?ooool3o`00017ooooo0ol0000Eooooo`?o0000
<?ooool3o`0002kooooo0ol0001iooooo`006?ooool00ol0003oooooooooo`1Nooooo`Co0000E?oo
ool3o`0001Cooooo0ol0000Yooooo`?o0000<?ooool3o`00037ooooo0_l0001gooooo`006?ooool0
0ol0003oooooooooo`1Jooooo`Co0000F?ooool3o`0001Cooooo0ol0000Yooooo`?o00004Oooool3
o`0001cooooo0ol0000cooooo`?o0000M?ooool001Sooooo00?o0000ooooooooool0E_ooool4o`00
04Gooooo0ol0001[ooooo`?o0000EOooool3o`00077ooooo000Hooooo`03o`000?oooooooooo05;o
oooo1?l00019ooooo`?o0000Joooool3o`0005Sooooo0_l0001_ooooo`006?ooool00ol0003ooooo
ooooo`1>ooooo`Co0000COooool3o`0001Sooooo0ol0001Pooooo`?o0000B_ooool3o`0006cooooo
000Hooooo`03o`000?oooooooooo04[ooooo1?l0001/ooooo`?o0000H?ooool3o`0004gooooo0ol0
001Yooooo`006?ooool00ol0003oooooooooo`16ooooo`Co0000F_ooool3o`0001?ooooo0ol0001P
ooooo`?o0000D?ooool2o`0006Oooooo000Hooooo`03o`000?oooooooooo04;ooooo1?l0001Noooo
o`?o0000boooool3o`0006Cooooo000Hooooo`03o`000?oooooooooo03kooooo1?l0001Rooooo`?o
0000c_ooool3o`00067ooooo000Hooooo`?o0000??ooool2o`000?oooooo>oooool00ol0003ooooo
ooooo`1Nooooo`006?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08cooooo0ol0
002Zooooo`03o`000?oooooooooo05kooooo000Hooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0Roooool3o`000:Wooooo00?o0000ooooooooool0Goooool001Sooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`1@ooooo`?o0000>?ooool3o`0002Gooooo0ol00016oooo
o`?o0000>?ooool00ol0003oooooooooo`1Oooooo`006?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo04Cooooo0ol00008ooooo`?o0000H?ooool3o`0000[ooooo0ol0000iooooo`?o
0000=oooool00ol0003oooooooooo`1Pooooo`006?ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo04Cooooo0ol00008ooooo`?o0000H?ooool3o`0000[ooooo0ol0000iooooo`?o0000
=oooool00ol0003oooooooooo`1Pooooo`006?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo04?ooooo0ol0001Aooooo`?o00009?ooool3o`0002_ooooo0ol00014ooooo`03o`000?oo
oooooooo067ooooo000Hooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Uoooool3
o`0005;ooooo0ol00014ooooo`03o`000?oooooooooo067ooooo000Hooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool0IOooool3o`0002kooooo0ol00013ooooo`?o00003?ooool3o`00
04?ooooo00?o0000ooooooooool0H_ooool001Sooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`1Uooooo`?o0000M?ooool3o`0005;ooooo00?o0000ooooooooool0H_ooool001Sooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Eooooo`?o00003?ooool3o`0006;ooooo
0ol0000?ooooo`?o0000D_ooool00ol0003oooooooooo`1Rooooo`006?ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo05Gooooo0ol0001aooooo`?o0000Hoooool00ol0003ooooooooo
o`1Sooooo`006?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05Cooooo0ol0001a
ooooo`?o0000Hoooool00ol0003oooooooooo`1Sooooo`002?ooool3o`0000?ooooo0_l00008oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo
06Cooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Joooool3o`0003Cooooo0ol00027oooo
o`03o`000?oooooooooo06Cooooo0006ooooo`Go00000_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Joooool3o`0003Cooooo0ol00026oooo
o`03o`000?oooooooooo06Gooooo0006ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooo00001oooool4o`0004?ooooo00?o0000ooooooooool0J_ooool3o`0003Cooooo0ol00026
ooooo`03o`000?oooooooooo06Gooooo0007ooooo`03o`000?oooooo000000?ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03[ooooo0ol0001>
ooooo`?o0000Joooool3o`0002gooooo00?o0000ooooooooool0I_ooool000Sooooo0_l00003oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0i
ooooo`?o0000C_ooool3o`0006_ooooo0ol0000]ooooo`03o`000?oooooooooo06Kooooo0009oooo
o`03o`000?oooooooooo00;ooooo0_l00008ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0>Oooool3o`0004kooooo0ol0001[ooooo`?o0000;?ooool00ol0003oooooooooo`1Woooo
o`006?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`1Wooooo`006?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0?oooooo
9_ooool00ol0003oooooooooo`1Xooooo`006?ooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo0?oooooo9Oooool00ol0003oooooooooo`1Xooooo`006?ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo0;Sooooo0ol0000Aooooo`?o0000E?ooool00ol0003oooooooooo`1Y
ooooo`006?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0;Oooooo0ol0000Aoooo
o`?o0000E?ooool00ol0003oooooooooo`1Yooooo`006?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo06[ooooo0ol0001:ooooo`?o00004Oooool3o`0000Sooooo0ol0000=ooooo`?o
0000>Oooool00ol0003oooooooooo`1Yooooo`006?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo03gooooo0ol00008ooooo`?o00007_ooool3o`0006Wooooo0ol0000=ooooo`?o0000
>?ooool00ol0003oooooooooo`1Zooooo`006?ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo03gooooo0ol00008ooooo`?o00007_ooool3o`0006Wooooo0ol0000=ooooo`?o0000>?oo
ool00ol0003oooooooooo`1Zooooo`006?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo03cooooo1?l00007ooooo`?o0000e?ooool00ol0003oooooooooo`1[ooooo`006?ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo03gooooo0ol0003Nooooo`03o`000?oooooooooo
06_ooooo000Hooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0??ooool3o`0001Go
oooo0ol0000Iooooo`?o00001_ooool3o`000:3ooooo00?o0000ooooooooool0K?ooool001Sooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`1Dooooo`?o00006Oooool3o`0000Kooooo
0ol0002Pooooo`03o`000?oooooooooo06cooooo000Hooooo`?o0000C?ooool00ol0003ooooooooo
o`1Cooooo`?o00006Oooool3o`0000Kooooo0ol0002Oooooo`03o`000?oooooooooo06gooooo000H
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0oooooolKooooo`03o`000?oooooo
oooo06gooooo000Hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool09_ooool3o`00
06;ooooo0ol0002:ooooo`03o`000?oooooooooo06kooooo000Hooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool09_ooool3o`0006;ooooo0ol0002:ooooo`03o`000?oooooooooo06ko
oooo000Hooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09Oooool3o`0006;ooooo
0ol0000dooooo`?o0000D_ooool00ol0003oooooooooo`1_ooooo`006?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo05Oooooo0ol0001Wooooo`?o0000<Oooool3o`0001kooooo00?o
0000ooooooooool0Koooool001Sooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`1F
ooooo`?o0000Ioooool3o`00037ooooo0ol0000Mooooo`03o`000?oooooooooo073ooooo000Hoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0E_ooool3o`0009_ooooo0ol0000Moooo
o`03o`000?oooooooooo073ooooo000Hooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0oooooolCooooo`03o`000?oooooooooo077ooooo000Hooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0=oooool3o`000:7ooooo0ol0000dooooo`03o`000?oooooooooo077ooooo
000Hooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0=_ooool3o`000:7ooooo0ol0
000dooooo`03o`000?oooooooooo077ooooo000Hooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool0:_ooool3o`0000Wooooo0ol0002Booooo`?o00003?ooool3o`0000Sooooo0ol0000X
ooooo`03o`000?oooooooooo07;ooooo000Hooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0:Oooool3o`0009kooooo0ol0000Gooooo`?o0000:?ooool00ol0003oooooooooo`1boooo
o`006?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo02Wooooo0ol00009ooooo`?o
0000?_ooool3o`0002cooooo0ol0000Rooooo`?o00005oooool3o`0002Oooooo00?o0000oooooooo
ool0Loooool001Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0dooooo`?o0000
?_ooool3o`0002cooooo0ol0001Vooooo`03o`000?oooooooooo07?ooooo000Hooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool0=?ooool3o`0003kooooo0ol0000/ooooo`?o0000=?oo
ool3o`0002kooooo00?o0000ooooooooool08oooool3o`0004kooooo000Hooooo`?o00009?ooool3
o`0002gooooo00?o0000ooooooooool07oooool3o`0001cooooo0ol00010ooooo`?o0000E_ooool3
o`0002kooooo00?o0000ooooooooool08oooool3o`0004kooooo000Hooooo`03o`000?oooooooooo
02Cooooo0ol0000]ooooo`03o`000?oooooooooo01oooooo0ol0000Looooo`?o0000@?ooool3o`00
05Kooooo0ol0000]ooooo`03o`000?oooooooooo02Cooooo0ol0001>ooooo`006?ooool00ol0003o
ooooooooo`0Tooooo`?o00002_ooool3o`00027ooooo00?o0000ooooooooool05oooool3o`0000Co
oooo0ol0000Looooo`?o00008_ooool3o`0001_ooooo0ol00026ooooo`03o`000?oooooooooo07Go
oooo000Hooooo`03o`000?oooooooooo037ooooo0ol0000Qooooo`03o`000?oooooooooo01Oooooo
0ol00018ooooo`?o0000Xoooool00ol0003oooooooooo`1fooooo`006?ooool00ol0003ooooooooo
o`0aooooo`?o00008_ooool00ol0003oooooooooo`0Fooooo`?o0000B?ooool3o`000:?ooooo00?o
0000ooooooooool0M_ooool001Sooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool0Moooool001Sooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0Moooool001Sooooo00?o0000oooooooo
ool0Eoooool00ol0003oooooooooo`3oooooo`Gooooo00?o0000ooooooooool0N?ooool001Sooooo
00?o0000ooooooooool0=_ooool3o`0001oooooo00?o0000ooooooooool0D?ooool3o`0001;ooooo
0ol0000:ooooo`?o00004oooool6o`0005gooooo0ol0000Eooooo`03o`000?oooooooooo07Sooooo
000Hooooo`03o`000?oooooooooo03Kooooo0ol0000Oooooo`03o`000?oooooooooo053ooooo0ol0
000Booooo`?o00002_ooool3o`0001?ooooo1_l0001Mooooo`?o00005Oooool00ol0003ooooooooo
o`1hooooo`006?ooool00ol0003oooooooooo`0fooooo`?o00008?ooool00ol0003oooooooooo`1?
ooooo`?o00004_ooool3o`0000[ooooo0ol0000Cooooo`Ko0000@Oooool3o`0001Wooooo0ol0000D
ooooo`03o`000?oooooooooo02Sooooo0ol0001>ooooo`006?ooool00ol0003oooooooooo`1Ioooo
o`03o`000?oooooooooo02Gooooo0ol0000Looooo`?o0000:oooool3o`0002oooooo0ol0000Woooo
o`?o00000oooool3o`0002[ooooo00?o0000ooooooooool0:?ooool3o`0004kooooo000Hooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool09?ooool3o`0001cooooo0ol0000[ooooo`?o
0000;oooool3o`0002Oooooo0ol00003ooooo`?o0000:Oooool00ol0003oooooooooo`0Yooooo`?o
0000C_ooool001Sooooo00?o0000ooooooooool09?ooool3o`0003?ooooo00?o0000ooooooooool0
9?ooool3o`0001cooooo0ol0000[ooooo`?o0000;oooool3o`0002gooooo0ol0000Yooooo`03o`00
0?oooooooooo01Kooooo0ol0001Qooooo`006?ooool00ol0003oooooooooo`0Tooooo`?o0000=?oo
ool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo01Oooooo0ol0001Qooooo`006?ooool3
o`0002Cooooo0ol0000dooooo`03o`000?oooooooooo09_ooooo0ol0001Oooooo`03o`000?oooooo
oooo00kooooo0ol00006ooooo`?o0000HOooool001Sooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`2Jooooo`?o0000G_ooool00ol0003oooooooooo`0?ooooo`?o0000J_ooool001So
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0:ooooo`?o0000SOooool3o`0004Co
oooo0ol0000Gooooo`03o`000?oooooooooo00oooooo0ol0001Zooooo`006?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo00[ooooo0ol0003Dooooo`?o00005_ooool00ol0003ooooo
ooooo`1mooooo`006?ooool00ol0003oooooooooo`0Tooooo`?o0000=_ooool00ol0003ooooooooo
o`09ooooo`?o0000e?ooool3o`0001Kooooo00?o0000ooooooooool0OOooool001Sooooo00?o0000
ooooooooool09?ooool3o`0003Kooooo00?o0000ooooooooool0n?ooool00ol0003oooooooooo`1n
ooooo`006?ooool00ol0003oooooooooo`0Tooooo`?o0000=oooool00ol0003oooooooooo`0Ioooo
o`?o0000>oooool3o`0005Gooooo0ol0000Cooooo`?o0000;oooool00ol0003oooooooooo`1noooo
o`006?ooool00ol0003oooooooooo`0booooo`?o00004?ooool3o`0001Kooooo00?o0000oooooooo
ool06Oooool3o`0000[ooooo0ol0000^ooooo`?o00003?ooool3o`0004Kooooo0ol0000Cooooo`?o
0000;_ooool00ol0003oooooooooo`0Qooooo`?o0000Foooool001Sooooo00?o0000ooooooooool0
<_ooool3o`00013ooooo0ol0000Gooooo`03o`000?oooooooooo01Sooooo0ol0000:ooooo`?o0000
;_ooool3o`0000cooooo0ol00016ooooo`?o00004oooool3o`0002kooooo00?o0000ooooooooool0
8Oooool3o`0005_ooooo000Hooooo`03o`000?oooooooooo03;ooooo0ol0000@ooooo`?o00005ooo
ool00ol0003oooooooooo`0Uooooo`?o00008oooool3o`0001Oooooo0ol0000Aooooo`?o00002?oo
ool3o`0003cooooo0ol0000_ooooo`03o`000?oooooooooo01oooooo1Ol00004ooooo`?o0000E?oo
ool001Sooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1:ooooo`?o0000:oooool3
o`0000Sooooo0ol0000looooo`?o0000;_ooool00ol0003oooooooooo`0Pooooo`?o00001_ooool3
o`0005Cooooo000Hooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0B_ooool3o`00
013ooooo0ol0000Fooooo`Go00002?ooool3o`0001?ooooo0ol0000Vooooo`?o0000;_ooool00ol0
003oooooooooo`0Pooooo`?o00001_ooool3o`0005Cooooo000Hooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0G?ooool3o`0001Kooooo0ol0000Pooooo`?o0000E_ooool00ol0003o
ooooooooo`21ooooo`006?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo03cooooo
0ol0000Mooooo`?o00005_ooool3o`00023ooooo0ol0001Fooooo`03o`000?oooooooooo087ooooo
0007ooooo`?o00001?ooool2o`0000Sooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0kooooo`?o0000/Oooool00ol0003oooooooooo`22ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo00Sooooo0ol0000Iooooo`?o00005?ooool3o`000;7ooooo00?o0000ooooooooool0
P_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Oo
oooo1?l0001Rooooo`03o`000?oooooooooo00Oooooo0ol0000Iooooo`?o0000aoooool00ol0003o
ooooooooo`23ooooo`001_ooool4o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`0hooooo`?o0000:?ooool00ol0003oooooooooo`07ooooo`?o00006Oooool3o`000:Wo
oooo0ol0000Kooooo`03o`000?oooooooooo00_ooooo0ol00004ooooo`?o0000K_ooool000Kooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo023o
oooo0ol0000Eooooo`?o0000:Oooool00ol0003oooooooooo`3>ooooo`?o00006_ooool00ol0003o
ooooooooo`0<ooooo`?o00001?ooool3o`0006kooooo0007ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Pooooo`?o00005Oooool3o`0002Wo
oooo00?o0000ooooooooool0c_ooool3o`0001[ooooo00?o0000ooooooooool03?ooool3o`0000Co
oooo0ol0001^ooooo`002?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo023ooooo
0ol00012ooooo`03o`000?oooooooooo0>Wooooo00?o0000ooooooooool0QOooool001Sooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`3Yooooo`03o`000?oooooooooo08Gooooo000H
ooooo`03o`000?oooooooooo05Oooooo0ol0000<ooooo`03o`000?oooooooooo00_ooooo0ol0000:
ooooo`?o0000<_ooool3o`00023ooooo0ol000001?oooooo0000o`000?l00013ooooo`?o0000:_oo
ool00ol0003oooooooooo`26ooooo`006?ooool00ol0003oooooooooo`1Gooooo`?o00003?ooool0
0ol0003oooooooooo`0;ooooo`?o00002_ooool3o`0003;ooooo0ol0000Pooooo`?o000000Cooooo
o`000?l0003o0000@oooool3o`0002[ooooo00?o0000ooooooooool0Q_ooool001Sooooo00?o0000
ooooooooool0EOooool5o`0000gooooo00?o0000ooooooooool02_ooool3o`0000[ooooo0ol0000b
ooooo`?o00008?ooool3o`000004ooooool0003o0000o`0002_ooooo0ol0000Eooooo`?o0000:Ooo
ool00ol0003oooooooooo`0Wooooo`?o0000GOooool001Sooooo00?o0000ooooooooool0EOooool3
o`0000oooooo00?o0000ooooooooool0XOooool3o`00047ooooo00?o0000ooooooooool09oooool3
o`0005gooooo000Hooooo`03o`000?oooooooooo04?ooooo0ol0000?ooooo`?o00004?ooool00ol0
003oooooooooo`1Looooo`?o0000@Oooool3o`00047ooooo00?o0000ooooooooool08?ooool3o`00
00Cooooo0ol0001Mooooo`006?ooool00ol0003oooooooooo`13ooooo`?o00008_ooool00ol0003o
ooooooooo`1Looooo`?o0000Q?ooool00ol0003oooooooooo`0Qooooo`?o0000I?ooool001Sooooo
00?o0000ooooooooool09oooool3o`0001Wooooo0ol0000Sooooo`03o`000?oooooooooo02oooooo
0ol0000Yooooo`?o0000AOooool3o`0003cooooo00?o0000ooooooooool05_ooool3o`0000Sooooo
0ol0001Tooooo`006?ooool00ol0003oooooooooo`0Looooo`?o00002?ooool3o`0003oooooo00?o
0000ooooooooool09_ooool3o`0000Kooooo0ol0001Cooooo`?o00006oooool3o`0001Sooooo0ol0
000>ooooo`?o00003oooool00ol0003oooooooooo`0Gooooo`?o00002?ooool3o`0006Cooooo000H
ooooo`03o`000?oooooooooo01cooooo0ol00008ooooo`?o0000@?ooool00ol0003oooooooooo`0U
ooooo`?o00001_ooool3o`0005?ooooo0ol0000Kooooo`?o00006?ooool3o`0000kooooo0ol0000?
ooooo`03o`000?oooooooooo01Oooooo0ol00008ooooo`?o0000I?ooool001Sooooo00?o0000oooo
ooooool07?ooool3o`0004_ooooo00?o0000ooooooooool01?ooool3o`0001kooooo0ol0000Hoooo
o`?o00004Oooool3o`0002gooooo0ol0000fooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool0R_ooool001Sooooo0ol0001[ooooo`03o`000?oooooooooo00?ooooo0ol0000iooooo`?o
00004Oooool3o`0008Sooooo00?o0000ooooooooool0R_ooool001Sooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`03ooooo`?o00006?ooool3o`0001kooooo0ol0000Aooooo`?o0000
9_ooool3o`0001?ooooo0ol00018ooooo`03o`000?oooooooooo08_ooooo000Hooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool07Oooool3o`0005_ooooo0ol0000Cooooo`?o0000B?oo
ool00ol0003oooooooooo`2;ooooo`006?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00gooooo0ol0000=ooooo`?o0000Foooool3o`0001?ooooo0ol00017ooooo`03o`000?oooooo
oooo08cooooo000Hooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool03?ooool3o`00
0<_ooooo00?o0000ooooooooool0S?ooool001Sooooo00?o0000ooooooooool0B_ooool3o`00023o
oooo00?o0000ooooooooool03?ooool3o`0004Sooooo0ol0000Gooooo`?o0000B?ooool3o`0001[o
oooo00?o0000ooooooooool0SOooool001Sooooo00?o0000ooooooooool0B_ooool3o`00027ooooo
00?o0000ooooooooool0E_ooool3o`0001Oooooo0ol00018ooooo`?o00006_ooool00ol0003ooooo
ooooo`2=ooooo`006?ooool00ol0003oooooooooo`1:ooooo`?o00008Oooool00ol0003ooooooooo
o`1Fooooo`?o00005oooool3o`0004Sooooo0ol0000Iooooo`03o`000?oooooooooo017ooooo0ol0
0009ooooo`?o0000K_ooool001Sooooo00?o0000ooooooooool0:Oooool3o`0004?ooooo00?o0000
ooooooooool0:Oooool3o`0007cooooo0ol0000[ooooo`03o`000?oooooooooo017ooooo0ol00009
ooooo`?o00001Oooool3o`0006Kooooo000Hooooo`03o`000?oooooooooo02Wooooo0ol00013oooo
o`03o`000?oooooooooo02Wooooo0ol0001looooo`?o0000:oooool00ol0003oooooooooo`0Aoooo
o`?o00002Oooool3o`0000Gooooo0ol0001Vooooo`006?ooool00ol0003oooooooooo`0Yooooo`?o
0000=?ooool3o`0000gooooo00?o0000ooooooooool07Oooool3o`0000Sooooo0ol0000<ooooo`?o
00002oooool3o`0005oooooo0ol0000Jooooo`?o00003Oooool00ol0003oooooooooo`0Vooooo`?o
0000I_ooool001Sooooo00?o0000ooooooooool0H?ooool3o`0000gooooo00?o0000ooooooooool0
7Oooool3o`0001Oooooo0ol0000;ooooo`?o0000O?ooool3o`0000gooooo00?o0000ooooooooool0
Soooool001Sooooo00?o0000ooooooooool0>?ooool3o`0001Gooooo0ol0000=ooooo`?o00003_oo
ool00ol0003oooooooooo`0Looooo`?o00005oooool3o`0000_ooooo0ol0000looooo`?o00007_oo
ool3o`0001cooooo0ol0000<ooooo`03o`000?oooooooooo093ooooo000Hooooo`03o`000?oooooo
oooo03Sooooo0ol0000Eooooo`?o00007_ooool00ol0003oooooooooo`0fooooo`?o0000B_ooool3
o`0001kooooo0ol0000[ooooo`03o`000?oooooooooo093ooooo000Hooooo`03o`000?oooooooooo
03Sooooo0ol0000Eooooo`?o00007oooool00ol0003oooooooooo`0Booooo`?o00008?ooool3o`00
04[ooooo0ol00004ooooo`?o00005oooool3o`0002[ooooo00?o0000ooooooooool0TOooool001So
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Booooo`?o0000M?ooool3o`0004Co
oooo00?o0000ooooooooool0TOooool001Sooooo0ol0001cooooo`03o`000?oooooooooo017ooooo
0ol0000`ooooo`?o0000@Oooool3o`0004?ooooo00?o0000ooooooooool0T_ooool001Sooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`14ooooo`?o0000Qoooool00ol0003ooooooooo
o`2Booooo`006?ooool00ol0003oooooooooo`0Vooooo`?o0000Boooool00ol0003oooooooooo`13
ooooo`?o0000:Oooool3o`0005[ooooo00?o0000ooooooooool07Oooool3o`0000gooooo0ol0001S
ooooo`006?ooool00ol0003oooooooooo`0Vooooo`?o0000Boooool00ol0003oooooooooo`05oooo
o`?o0000Ioooool3o`00037ooooo0ol00006ooooo`?o00007Oooool00ol0003oooooooooo`0Moooo
o`?o00003Oooool3o`0006?ooooo000Hooooo`03o`000?oooooooooo02Kooooo0ol0001<ooooo`03
o`000?oooooooooo00Cooooo0ol0001Wooooo`?o0000<Oooool3o`0000Kooooo0ol0000Looooo`03
o`000?oooooooooo01kooooo0ol0000=ooooo`?o0000Hoooool001Sooooo00?o0000ooooooooool0
?oooool3o`0003?ooooo00?o0000ooooooooool01?ooool3o`0004cooooo0ol0001<ooooo`?o0000
1_ooool3o`0001cooooo00?o0000ooooooooool0U?ooool001Sooooo00?o0000ooooooooool0?ooo
ool3o`0003Cooooo00?o0000ooooooooool0D_ooool3o`0007?ooooo00?o0000ooooooooool0UOoo
ool001Sooooo00?o0000ooooooooool0?oooool3o`0003Cooooo00?o0000ooooooooool09oooool3
o`0001gooooo0ol00008ooooo`?o0000@Oooool3o`0001oooooo0ol0000=ooooo`03o`000?oooooo
oooo09Gooooo000Hooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool09_ooool3o`00
01gooooo0ol0001<ooooo`?o00007oooool3o`0000cooooo00?o0000ooooooooool0U_ooool001So
oooo00?o0000ooooooooool06Oooool3o`0005_ooooo00?o0000ooooooooool09_ooool3o`00013o
oooo0ol0000:ooooo`?o0000=?ooool3o`0001Gooooo0ol0000Oooooo`?o00003?ooool00ol0003o
ooooooooo`2Fooooo`006?ooool00ol0003oooooooooo`0Iooooo`?o0000G?ooool00ol0003ooooo
ooooo`0hooooo`?o0000@Oooool3o`0004Kooooo00?o0000ooooooooool0U_ooool001Sooooo00?o
0000ooooooooool06Oooool3o`0001?ooooo0ol0000^ooooo`?o00005Oooool00ol0003ooooooooo
o`0Aooooo`?o00002_ooool3o`0001Oooooo0ol00011ooooo`?o0000AOooool00ol0003ooooooooo
o`0Qooooo`?o0000Loooool001Sooooo00?o0000ooooooooool0;oooool3o`0002kooooo0ol0000F
ooooo`03o`000?oooooooooo013ooooo0ol0000:ooooo`?o0000Xoooool00ol0003oooooooooo`0Q
ooooo`?o0000Loooool001Sooooo00?o0000ooooooooool0;oooool3o`0002kooooo0ol0000Foooo
o`03o`000?oooooooooo013ooooo0ol0000:ooooo`?o00006_ooool3o`0008Gooooo00?o0000oooo
ooooool04Oooool3o`0000kooooo0ol0001cooooo`006?ooool00ol0003oooooooooo`1jooooo`03
o`000?oooooooooo03Wooooo0ol00025ooooo`03o`000?oooooooooo017ooooo0ol00024ooooo`00
6?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo03Wooooo0ol00024ooooo`03o`00
0?oooooooooo01;ooooo0ol00024ooooo`006?ooool3o`0005;ooooo0ol0000Vooooo`03o`000?oo
oooooooo02[ooooo0ol0000Looooo`?o00005oooool3o`0001kooooo0ol0000hooooo`03o`000?oo
oooooooo09Wooooo000Hooooo`03o`000?oooooooooo05;ooooo0ol0000Vooooo`03o`000?oooooo
oooo02[ooooo0ol0000Looooo`?o00005oooool3o`0001kooooo0ol0000gooooo`03o`000?oooooo
oooo09[ooooo000Hooooo`03o`000?oooooooooo04Sooooo0ol00007ooooo`?o00001?ooool3o`00
01oooooo00?o0000ooooooooool0:_ooool3o`0001cooooo0ol0000Gooooo`?o00002?ooool3o`00
01?ooooo0ol0000gooooo`03o`000?oooooooooo09[ooooo000Hooooo`03o`000?oooooooooo04So
oooo0ol0000>ooooo`?o00007oooool00ol0003oooooooooo`1^ooooo`?o0000C?ooool00ol0003o
ooooooooo`2Kooooo`006?ooool00ol0003oooooooooo`18ooooo`?o00003_ooool3o`0001oooooo
00?o0000ooooooooool0K_ooool3o`0001kooooo0ol0000[ooooo`03o`000?oooooooooo01oooooo
0ol0000Cooooo`?o0000Hoooool001Sooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`2?ooooo`?o0000:_ooool00ol0003oooooooooo`0Pooooo`?o00004oooool3o`0006?ooooo000H
ooooo`03o`000?oooooooooo037ooooo0ol0000eooooo`?o00003oooool00ol0003oooooooooo`0B
ooooo`?o00005Oooool3o`0006;ooooo0ol0000Zooooo`03o`000?oooooooooo023ooooo0ol0000C
ooooo`?o0000Hoooool001Sooooo00?o0000ooooooooool0<Oooool3o`0003Gooooo0ol0000?oooo
o`03o`000?oooooooooo01;ooooo0ol0000Eooooo`?o0000S_ooool00ol0003oooooooooo`2Moooo
o`006?ooool00ol0003oooooooooo`0aooooo`?o0000=Oooool3o`0000oooooo00?o0000oooooooo
ool04_ooool3o`0001Gooooo0ol0000?ooooo`?o00005oooool3o`0002?ooooo0ol0000looooo`03
o`000?oooooooooo01[ooooo0ol00020ooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo037ooooo0ol00008ooooo`?o00005oooool3o`0002?ooooo0ol0000looooo`03o`00
0?oooooooooo01[ooooo0ol00020ooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo037ooooo0ol00008ooooo`?o00005oooool3o`0002?ooooo0ol0000kooooo`03o`000?oo
oooooooo01_ooooo0ol00020ooooo`006?ooool00ol0003oooooooooo`0Looooo`?o0000G?ooool0
0ol0003oooooooooo`0aooooo`?o0000:Oooool3o`0003gooooo0ol0000Jooooo`03o`000?oooooo
oooo09kooooo000Hooooo`03o`000?oooooooooo01cooooo0ol0001Looooo`03o`000?oooooooooo
05gooooo0ol0000mooooo`?o00006Oooool00ol0003oooooooooo`2Oooooo`001oooool3o`0000Co
oooo0_l00008ooooo`03o`000?oooooooooo01cooooo0ol0000Nooooo`?o0000>oooool00ol0003o
ooooooooo`0Fooooo`?o0000<?ooool3o`00017ooooo0ol0000mooooo`?o00002_ooool3o`0000co
oooo00?o0000ooooooooool0Woooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0?Oooool3o`0003_ooooo00?o0000oooo
ooooool05_ooool3o`00033ooooo0ol0001Nooooo`?o00002oooool00ol0003oooooooooo`2Poooo
o`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001oooool4
o`0003cooooo0ol0000Vooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`?o00003oooool3
o`0001kooooo0ol0000Tooooo`?o0000=oooool3o`0000_ooooo00?o0000ooooooooool0X?ooool0
00Oooooo0ol00003ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0I_ooool3
o`0001;ooooo00?o0000ooooooooool0:?ooool3o`0004Gooooo0ol00014ooooo`03o`000?oooooo
oooo0:7ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo06Kooooo0ol0000Booooo`03o`000?oooooooooo00Wooooo0ol0
000Fooooo`?o00000oooool3o`00047ooooo0ol000001?oooooo0000o`000?l00008ooooo`?o0000
>Oooool00ol0003oooooooooo`0_ooooo`?o0000Koooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`09ooooo`?o00005_ooool3o`0004Oooooo0ol0000<ooooo`?o0000>?ooool00ol0003o
ooooooooo`0`ooooo`?o0000Koooool000Oooooo0ol00004ooooo`;o00002?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Wooooo0ol0000Fooooo`?o00006oooool3o`0002Wooooo
0ol0000<ooooo`?o00003Oooool3o`0002Sooooo00?o0000ooooooooool08oooool3o`0000[ooooo
0ol0001_ooooo`006?ooool00ol0003oooooooooo`0Iooooo`?o0000<?ooool3o`0002cooooo00?o
0000ooooooooool0;Oooool3o`00013ooooo0ol00018ooooo`?o00009oooool00ol0003ooooooooo
o`0Tooooo`?o0000O?ooool001Sooooo00?o0000ooooooooool06Oooool3o`00033ooooo0ol0000/
ooooo`03o`000?oooooooooo02gooooo0ol0000@ooooo`?o0000B?ooool3o`0002Oooooo00?o0000
ooooooooool09?ooool3o`0007cooooo000Hooooo`03o`000?oooooooooo01Wooooo0ol0000`oooo
o`?o00007_ooool3o`0000_ooooo00?o0000ooooooooool0;Oooool3o`00023ooooo0ol0001Qoooo
o`03o`000?oooooooooo0:Cooooo000Hooooo`03o`000?oooooooooo06gooooo0ol0000;ooooo`03
o`000?oooooooooo053ooooo0ol0001Qooooo`03o`000?oooooooooo0:Cooooo000Hooooo`03o`00
0?oooooooooo06gooooo0ol0000;ooooo`03o`000?oooooooooo01Oooooo0ol0000fooooo`?o0000
4oooool3o`0004_ooooo00?o0000ooooooooool0Y?ooool001Sooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Gooooo`?o0000C?ooool3o`0004[ooooo00?o0000ooooooooool0YOoo
ool001Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Gooooo`?o00006Oooool3
o`00033ooooo0ol0001:ooooo`03o`000?oooooooooo0:Gooooo000Hooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool0<oooool3o`0007cooooo00?o0000ooooooooool0Y_ooool001So
oooo00?o0000ooooooooool0EOooool3o`0002?ooooo00?o0000ooooooooool0<oooool3o`0007co
oooo00?o0000ooooooooool0>Oooool3o`0006[ooooo000Hooooo`03o`000?oooooooooo05Gooooo
0ol0000Sooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0>_ooool3o`0006[ooooo
000Hooooo`03o`000?oooooooooo05Gooooo0ol0000:ooooo`?o00005_ooool00ol0003ooooooooo
o`1nooooo`?o0000<?ooool00ol0003oooooooooo`0jooooo`?o0000J_ooool001Sooooo0ol0001R
ooooo`?o00005_ooool00ol0003oooooooooo`13ooooo`?o0000<Oooool3o`0000Cooooo0ol0000A
ooooo`?o00006oooool00ol0003oooooooooo`2Xooooo`006?ooool00ol0003oooooooooo`1Roooo
o`?o00005_ooool00ol0003oooooooooo`13ooooo`?o0000<Oooool3o`0000Cooooo0ol0000Aoooo
o`?o00006oooool00ol0003oooooooooo`2Xooooo`006?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo027ooooo0ol0000Oooooo`?o0000<Oooool3o`0001Sooooo0ol0000Jooooo`03
o`000?oooooooooo0:Wooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0
8Oooool3o`0008_ooooo00?o0000ooooooooool0ZOooool001Sooooo00?o0000ooooooooool0@Ooo
ool3o`0003Oooooo00?o0000ooooooooool02Oooool3o`0001Gooooo0ol0000iooooo`?o00003?oo
ool3o`0003oooooo00?o0000ooooooooool0:oooool3o`0000Kooooo0ol0001cooooo`006?ooool0
0ol0003oooooooooo`11ooooo`?o0000=oooool00ol0003oooooooooo`09ooooo`?o0000DOooool3
o`0000cooooo0ol0000oooooo`03o`000?oooooooooo02_ooooo0ol00006ooooo`?o0000Loooool0
01Sooooo00?o0000ooooooooool0@Oooool3o`0003Oooooo00?o0000ooooooooool02Oooool3o`00
01Gooooo0ol0000iooooo`?o00003?ooool3o`0003kooooo00?o0000ooooooooool0;?ooool3o`00
00Kooooo0ol0001cooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo027o
oooo0ol00029ooooo`03o`000?oooooooooo0:_ooooo000Hooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool08Oooool3o`0008Sooooo00?o0000ooooooooool0[?ooool001Sooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo0:cooooo000H
ooooo`03o`000?oooooooooo05_ooooo0ol0000Mooooo`03o`000?oooooooooo02gooooo0ol0000@
ooooo`?o0000:Oooool3o`0000oooooo0ol0000[ooooo`03o`000?oooooooooo0:cooooo000Hoooo
o`03o`000?oooooooooo05_ooooo0ol0000Mooooo`03o`000?oooooooooo01Cooooo0ol0000Foooo
o`?o00004?ooool3o`0000cooooo0ol00002ooooo`?o00005Oooool3o`0000oooooo0ol0000Zoooo
o`03o`000?oooooooooo0:gooooo000Hooooo`03o`000?oooooooooo05_ooooo0ol0000Mooooo`03
o`000?oooooooooo01Cooooo0ol0000Fooooo`?o00004?ooool3o`0000cooooo0ol00002ooooo`?o
00005Oooool3o`0000oooooo0ol0000Zooooo`03o`000?oooooooooo0:gooooo000Hooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooooooool05?ooool6o`0003Gooooo0ol00002ooooo`?o0000
9oooool3o`0000[ooooo0ol0000Looooo`03o`000?oooooooooo0:kooooo000Hooooo`03o`000?oo
oooooooo07_ooooo00?o0000ooooooooool05oooool3o`0006Cooooo0ol0000:ooooo`?o00007?oo
ool00ol0003oooooooooo`2^ooooo`006?ooool00ol0003oooooooooo`0aooooo`?o0000Aoooool0
0ol0003oooooooooo`0Gooooo`?o00005oooool3o`0004[ooooo0ol0000:ooooo`?o00002_ooool3
o`0000kooooo00?o0000ooooooooool0[oooool001Sooooo0ol0000aooooo`?o0000Aoooool00ol0
003oooooooooo`0aooooo`?o0000I?ooool3o`0000kooooo00?o0000ooooooooool0[oooool001So
oooo00?o0000ooooooooool0<Oooool3o`0003;ooooo0ol0000Booooo`03o`000?oooooooooo037o
oooo0ol0001Tooooo`?o00003Oooool00ol0003oooooooooo`2`ooooo`006?ooool00ol0003ooooo
ooooo`1Vooooo`?o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo0;3ooooo
000Hooooo`03o`000?oooooooooo06Kooooo0ol0000Booooo`03o`000?oooooooooo04?ooooo0ol0
001Qooooo`03o`000?oooooooooo0;7ooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool0@oooool3o`00067ooooo00?o0000ooooooooool0/Oooool001Sooooo00?o0000oooo
ooooool0C_ooool3o`0002[ooooo00?o0000ooooooooool0@oooool3o`0001Gooooo0ol00018oooo
o`03o`000?oooooooooo04?ooooo0ol0001/ooooo`006?ooool00ol0003oooooooooo`1>ooooo`?o
0000:_ooool00ol0003oooooooooo`1Kooooo`?o0000B?ooool00ol0003oooooooooo`13ooooo`?o
0000K?ooool001Sooooo00?o0000ooooooooool0C_ooool3o`0002[ooooo00?o0000ooooooooool0
9?ooool3o`0003Cooooo0ol0000Gooooo`?o0000;Oooool00ol0003oooooooooo`14ooooo`?o0000
K?ooool001Sooooo00?o0000ooooooooool0D_ooool3o`0002Kooooo00?o0000ooooooooool01Ooo
ool3o`0001cooooo0ol00013ooooo`?o00002?ooool3o`0000Kooooo0ol0000Aooooo`?o00004?oo
ool00ol0003oooooooooo`2cooooo`006?ooool00ol0003oooooooooo`1Booooo`?o00009_ooool0
0ol0003oooooooooo`05ooooo`?o00007?ooool3o`0004?ooooo0ol00008ooooo`?o00001_ooool3
o`00017ooooo0ol0000@ooooo`03o`000?oooooooooo0;?ooooo000Hooooo`03o`000?oooooooooo
05;ooooo0ol0000Vooooo`03o`000?oooooooooo00Gooooo0ol0000oooooo`?o00008?ooool3o`00
017ooooo0ol0000Aooooo`?o00003oooool00ol0003oooooooooo`2dooooo`006?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo04Oooooo0ol0001Jooooo`03o`000?oooooooooo0;Co
oooo000Hooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0=oooool3o`0000gooooo
0ol0001Iooooo`03o`000?oooooooooo0;Gooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool0=oooool3o`0006Wooooo00?o0000ooooooooool0]Oooool001Sooooo00?o0000
ooooooooool0?oooool3o`0001_ooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo0ol0000P
ooooo`?o0000C?ooool3o`0001Wooooo00?o0000ooooooooool0]_ooool001Sooooo00?o0000oooo
ooooool0?oooool3o`0001_ooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo0ol0001_oooo
o`?o00006Oooool00ol0003oooooooooo`2fooooo`006?ooool3o`0001Oooooo0ol0000Uooooo`?o
00006oooool3o`0000_ooooo0ol0000=ooooo`03o`000?oooooooooo01Cooooo0ol0000Looooo`?o
0000D?ooool3o`0001Sooooo00?o0000ooooooooool0]oooool001Sooooo00?o0000ooooooooool0
5oooool3o`00057ooooo0ol0000=ooooo`03o`000?oooooooooo03?ooooo0ol0001[ooooo`03o`00
0?oooooooooo0;Oooooo000Hooooo`03o`000?oooooooooo01Oooooo0ol0001Aooooo`?o00003Ooo
ool00ol0003oooooooooo`0cooooo`?o00009oooool3o`00043ooooo00?o0000ooooooooool0^?oo
ool001Sooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`1Mooooo`?o0000@?ooool0
0ol0003oooooooooo`2hooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
05gooooo0ol0000oooooo`03o`000?oooooooooo0;Wooooo000Hooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool08_ooool3o`0000cooooo0ol0001Mooooo`?o00002oooool00ol0003o
ooooooooo`2iooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo02;ooooo
0ol0000<ooooo`?o0000GOooool3o`0000[ooooo00?o0000ooooooooool0^_ooool001Sooooo00?o
0000ooooooooool0D_ooool3o`0002Kooooo00?o0000ooooooooool04?ooool3o`0000oooooo0ol0
000<ooooo`?o0000=?ooool3o`0000cooooo0ol0000Gooooo`?o00002_ooool00ol0003ooooooooo
o`2jooooo`006?ooool00ol0003oooooooooo`1Booooo`?o00009_ooool00ol0003oooooooooo`0@
ooooo`?o0000EOooool3o`0000cooooo0ol0000Sooooo`03o`000?oooooooooo0;_ooooo000Hoooo
o`03o`000?oooooooooo05;ooooo0ol0000Vooooo`03o`000?oooooooooo013ooooo0ol0000foooo
o`?o00007?ooool3o`0000cooooo0ol0000Sooooo`03o`000?oooooooooo0;_ooooo000Hooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool0BOooool3o`00057ooooo00?o0000oooooooo
ool0^oooool001Sooooo00?o0000ooooooooool0=_ooool3o`0000kooooo0ol0000Fooooo`?o0000
6?ooool00ol0003oooooooooo`19ooooo`?o0000D?ooool00ol0003oooooooooo`2looooo`006?oo
ool00ol0003oooooooooo`0fooooo`?o00003_ooool3o`0001Kooooo0ol0000Hooooo`03o`000?oo
oooooooo09cooooo00?o0000ooooooooool0_?ooool00004ooooool0003o0000o`0000Cooooo0_l0
0004ooooo`;o00002?ooool00ol0003oooooooooo`0fooooo`?o00003_ooool3o`0001Kooooo0ol0
000Hooooo`03o`000?oooooooooo03[ooooo0ol0000@ooooo`?o0000Boooool00ol0003ooooooooo
o`2mooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`0fooooo`?o00006Oooool3o`0002Kooooo
00?o0000ooooooooool02Oooool3o`0002kooooo0ol0000@ooooo`?o0000<?ooool3o`0001Sooooo
00?o0000ooooooooool0_Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0=_ooool3o`0001Wo
oooo0ol0000Vooooo`03o`000?oooooooooo00Wooooo0ol0000^ooooo`?o00004?ooool3o`00033o
oooo0ol0000Gooooo`03o`000?oooooooooo0;kooooo0002ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`Co0000=Oooool3o`00
01Wooooo0ol0000Vooooo`03o`000?oooooooooo00Wooooo0ol0000Sooooo`?o00009_ooool3o`00
02Gooooo0ol0000Gooooo`03o`000?oooooooooo0;kooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo07_ooooo00?o0000ooooooooool0;oooool3o`0002Kooooo0ol0000nooooo`03o`000?oooooo
oooo0;oooooo00000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01oooooo0ol0
000=ooooo`?o00009_ooool3o`0003Cooooo0ol00007ooooo`03o`000?oooooooooo0;oooooo0002
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00002?ooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo01oooooo0ol0001]ooooo`?o00001_ooool00ol0003oooooooooo`30
ooooo`006?ooool00ol0003oooooooooo`0Nooooo`?o0000F_ooool00ol0003oooooooooo`0Ooooo
o`?o0000B_ooool3o`00023ooooo0ol00006ooooo`03o`000?oooooooooo0<3ooooo000Hooooo`03
o`000?oooooooooo01kooooo0ol0001Jooooo`03o`000?oooooooooo06cooooo0ol0000Xooooo`03
o`000?oooooooooo0<7ooooo000Hooooo`03o`000?oooooooooo01kooooo0ol0000hooooo`?o0000
7oooool00ol0003oooooooooo`0Mooooo`?o0000C?ooool3o`0000Sooooo0ol0000Mooooo`03o`00
0?oooooooooo0<7ooooo000Hooooo`03o`000?oooooooooo05Wooooo0ol0000Oooooo`03o`000?oo
oooooooo01gooooo0ol0001Gooooo`?o00007?ooool00ol0003oooooooooo`32ooooo`006?ooool0
0ol0003oooooooooo`1Iooooo`?o00007oooool00ol0003oooooooooo`0Mooooo`?o0000Eoooool3
o`0001cooooo00?o0000ooooooooool0`_ooool001Sooooo00?o0000ooooooooool0>_ooool3o`00
03kooooo00?o0000ooooooooool0BOooool3o`0004[ooooo00?o0000ooooooooool0`_ooool001So
oooo00?o0000ooooooooool0>_ooool3o`0003kooooo00?o0000ooooooooool0BOooool3o`0004Wo
oooo00?o0000ooooooooool0`oooool001Sooooo00?o0000ooooooooool0>_ooool3o`0003kooooo
00?o0000ooooooooool0BOooool3o`0004Wooooo00?o0000ooooooooool0`oooool001Sooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo0<Cooooo000H
ooooo`03o`000?oooooooooo02_ooooo0ol0001=ooooo`03o`000?oooooooooo01Cooooo0ol0000A
ooooo`?o0000;Oooool3o`0003Wooooo00?o0000ooooooooool0a?ooool001Sooooo00?o0000oooo
ooooool0:oooool3o`0004gooooo00?o0000ooooooooool05?ooool3o`00017ooooo0ol0000]oooo
o`?o0000>?ooool00ol0003oooooooooo`35ooooo`006?ooool00ol0003oooooooooo`0[ooooo`?o
00007?ooool3o`0002kooooo00?o0000ooooooooool05?ooool3o`00017ooooo0ol0000Hooooo`?o
00004_ooool3o`0000[ooooo0ol0000Jooooo`?o00003_ooool00ol0003oooooooooo`35ooooo`00
6?ooool3o`0004[ooooo0ol0000^ooooo`03o`000?oooooooooo04?ooooo0ol0000Oooooo`?o0000
6_ooool3o`0000gooooo00?o0000ooooooooool0a_ooool001Sooooo00?o0000ooooooooool0B_oo
ool3o`0000Kooooo0ol0000Uooooo`03o`000?oooooooooo02gooooo0ol0000Cooooo`?o00007ooo
ool3o`0001[ooooo0ol0000=ooooo`03o`000?oooooooooo0<Kooooo000Hooooo`03o`000?oooooo
oooo05?ooooo0ol0000Uooooo`03o`000?oooooooooo02gooooo0ol0001Qooooo`03o`000?oooooo
oooo0<Oooooo000Hooooo`03o`000?oooooooooo037ooooo0ol0000Oooooo`?o00009Oooool00ol0
003oooooooooo`0]ooooo`?o0000=_ooool3o`0002Sooooo00?o0000ooooooooool0aoooool001So
oooo00?o0000ooooooooool0<Oooool3o`0004Oooooo00?o0000ooooooooool07Oooool3o`0001So
oooo0ol0000[ooooo`?o00009oooool00ol0003oooooooooo`38ooooo`006?ooool00ol0003ooooo
ooooo`0aooooo`?o0000Aoooool00ol0003oooooooooo`0Mooooo`?o00006?ooool3o`0002_ooooo
0ol0000Wooooo`03o`000?oooooooooo0<Sooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool07Oooool3o`0001Sooooo0ol0001Dooooo`03o`000?oooooooooo0<Wooooo000H
ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`39
ooooo`006?ooool00ol0003oooooooooo`17ooooo`?o0000<Oooool00ol0003oooooooooo`10oooo
o`?o00004oooool3o`0001kooooo0ol0000Eooooo`03o`000?oooooooooo0<Wooooo000Hooooo`03
o`000?oooooooooo04Oooooo0ol0000aooooo`03o`000?oooooooooo043ooooo0ol0000Cooooo`?o
00007_ooool3o`0001Cooooo00?o0000ooooooooool0b_ooool001Sooooo00?o0000ooooooooool0
Aoooool3o`00037ooooo00?o0000ooooooooool0@?ooool3o`0001?ooooo0ol0000Nooooo`?o0000
5?ooool00ol0003oooooooooo`3:ooooo`006?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo08gooooo00?o0000ooooooooool0boooool001Sooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`0Iooooo`?o0000LOooool00ol0003oooooooooo`3;ooooo`006?ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo01Wooooo0ol0001`ooooo`03o`000?oooooooooo
0<cooooo000Hooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06Oooool3o`0001?o
oooo0ol0000Tooooo`?o0000<oooool00ol0003oooooooooo`3<ooooo`006?ooool3o`0007_ooooo
0_l0000`ooooo`?o00009?ooool3o`0001?ooooo0ol0000Looooo`03o`000?oooooooooo0<gooooo
000Hooooo`03o`000?oooooooooo07gooooo0_l0000^ooooo`?o00009?ooool3o`0001?ooooo0ol0
000Looooo`03o`000?oooooooooo0<gooooo000Hooooo`03o`000?oooooooooo07oooooo0_l0001Y
ooooo`?o00006oooool00ol0003oooooooooo`3>ooooo`006?ooool00ol0003oooooooooo`21oooo
o`;o0000QOooool00ol0003oooooooooo`3>ooooo`006?ooool00ol0003oooooooooo`23ooooo`;o
0000P_ooool00ol0003oooooooooo`3?ooooo`006?ooool00ol0003oooooooooo`25ooooo`;o0000
P?ooool00ol0003oooooooooo`3?ooooo`006?ooool00ol0003oooooooooo`27ooooo`;o00005ooo
ool3o`0006?ooooo00?o0000ooooooooool0d?ooool001Sooooo00?o0000ooooooooool0ROooool2
o`0001Gooooo0ol0001Sooooo`03o`000?oooooooooo0=3ooooo000Hooooo`03o`000?oooooooooo
08_ooooo0_l0000Cooooo`?o00007Oooool3o`0004;ooooo00?o0000ooooooooool0dOooool001So
oooo00?o0000ooooooooool0SOooool2o`00037ooooo0ol00012ooooo`03o`000?oooooooooo0=7o
oooo000Hooooo`03o`000?oooooooooo08oooooo0_l0000_ooooo`?o00006?ooool3o`0002Oooooo
00?o0000ooooooooool0dOooool001Sooooo00?o0000ooooooooool0TOooool2o`0004Sooooo0ol0
000Vooooo`03o`000?oooooooooo0=;ooooo000Hooooo`03o`000?oooooooooo09?ooooo0_l00016
ooooo`?o00009_ooool00ol0003oooooooooo`3Booooo`006?ooool00ol0003oooooooooo`2Eoooo
o`;o00005_ooool3o`0005?ooooo00?o0000ooooooooool0doooool001Sooooo00?o0000oooooooo
ool0Uoooool2o`0001Cooooo0ol0001Cooooo`03o`000?oooooooooo0=?ooooo000Hooooo`03o`00
0?oooooooooo09Wooooo0_l0000Booooo`?o0000D_ooool00ol0003oooooooooo`3Dooooo`006?oo
ool3o`0009_ooooo0_l0001Uooooo`03o`000?oooooooooo0=Cooooo000Hooooo`03o`000?oooooo
oooo09gooooo0_l0000Xooooo`?o0000=oooool00ol0003oooooooooo`3Eooooo`006?ooool00ol0
003oooooooooo`2Oooooo`;o00009_ooool3o`0003Oooooo00?o0000ooooooooool0eOooool001So
oooo00?o0000ooooooooool0XOooool2o`0002Cooooo0ol0000fooooo`03o`000?oooooooooo0=Ko
oooo000Hooooo`03o`000?oooooooooo0:?ooooo0_l0001Kooooo`03o`000?oooooooooo0=Kooooo
000Hooooo`03o`000?oooooooooo0:Gooooo0_l0001Hooooo`03o`000?oooooooooo0=Oooooo000H
ooooo`03o`000?oooooooooo0:Oooooo0_l0001Fooooo`03o`000?oooooooooo0=Oooooo000Hoooo
o`03o`000?oooooooooo0:Wooooo0_l0001Cooooo`03o`000?oooooooooo0=Sooooo000Hooooo`03
o`000?oooooooooo0:_ooooo0_l0001Aooooo`03o`000?oooooooooo0=Sooooo000Hooooo`03o`00
0?oooooooooo0:gooooo0_l0001?ooooo`03o`000?oooooooooo0=Sooooo000Hooooo`03o`000?oo
oooooooo0:oooooo0_l0001<ooooo`03o`000?oooooooooo0=Wooooo000Hooooo`03o`000?oooooo
oooo0;7ooooo0_l0001:ooooo`03o`000?oooooooooo0=Wooooo000Hooooo`03o`000?oooooooooo
0;?ooooo0_l00017ooooo`03o`000?oooooooooo0=[ooooo00001?oooooo0000o`000?l00002oooo
o`Go00000oooool2o`0000Sooooo00?o0000ooooooooool0]Oooool2o`0004Gooooo00?o0000oooo
ooooool0f_ooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0]oooool2o`0004;ooooo00?o0000
ooooooooool0foooool000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0^Oooool2o`00043ooooo00?o0000
ooooooooool0foooool000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01Oooool4o`000;[ooooo@?l0003Nooooo`000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`3oooooon;ooooo00000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0003oooooonCooooo0002ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o0000oooooooUooooo`00oooooooeooooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {399, 0}} -> {-7.66254, -4.72097, 0.316151, \
0.316151}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(inside[{x_, y_}, polygon_] := \ 
      Module[{n, i, j, inside = False}, \[IndentingNewLine]n = 
          Length[polygon]; \[IndentingNewLine]For[i = 1; \ j = n, \ 
          i \[LessEqual] n, \ 
          j = \(i++\), \
\[IndentingNewLine]\[IndentingNewLine]\(If[\((\((\((\((polygon[\([i, 
                                  2]\)] \[LessEqual] y)\) && \((y < 
                              polygon[\([j, 
                                  2]\)])\))\) || \((\((polygon[\([j, 
                                  2]\)] \[LessEqual] y)\) && \((y < 
                              polygon[\([i, 
                                  2]\)])\))\))\) && \((x < \((polygon[\([j, 
                                  1]\)] - 
                              polygon[\([i, 1]\)])\)*\((y - 
                                polygon[\([i, 2]\)])\)/\((polygon[\([j, 
                                    2]\)] - polygon[\([i, 2]\)])\) + 
                        polygon[\([i, 
                            1]\)])\))\), \[IndentingNewLine]inside = \(! \
inside\)];\)\[IndentingNewLine]\[IndentingNewLine]]; \
\[IndentingNewLine]Return[
          inside]\[IndentingNewLine]\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xymeristem = Union[Select[xy, inside[#, mypoly] &]]\)], "Input"],

Cell[BoxData[
    \({{34.8`, 55.67999999999999`}, {35.96`, 59.74`}, {36.54`, 
        51.04`}, {37.120000000000005`, 64.96000000000001`}, {38.28`, 
        62.06`}, {38.86`, 45.82`}, {38.86`, 50.46`}, {40.019999999999996`, 
        56.84`}, {40.599999999999994`, 66.12`}, {40.599999999999994`, 
        71.34`}, {41.18000000000001`, 48.72`}, {42.34`, 
        40.599999999999994`}, {42.34`, 53.94`}, {42.34`, 62.06`}, {42.92`, 
        92.8`}, {43.5`, 36.54`}, {44.080000000000005`, 
        57.42`}, {44.080000000000005`, 69.6`}, {44.080000000000005`, 
        80.61999999999999`}, {44.080000000000005`, 
        86.41999999999999`}, {44.080000000000005`, 
        99.76`}, {44.660000000000004`, 43.5`}, {44.660000000000004`, 
        59.74`}, {45.24`, 44.080000000000005`}, {45.24`, 48.14`}, {45.24`, 
        49.3`}, {45.82`, 65.54`}, {45.82`, 73.66`}, {46.4`, 
        97.44`}, {46.980000000000004`, 35.96`}, {46.980000000000004`, 
        68.44`}, {46.980000000000004`, 77.14`}, {47.56`, 64.38`}, {47.56`, 
        88.74000000000001`}, {47.56`, 94.54`}, {47.56`, 104.4`}, {48.14`, 
        43.5`}, {48.14`, 79.46`}, {48.72`, 50.46`}, {48.72`, 
        82.94`}, {48.72`, 89.32000000000001`}, {49.3`, 109.04`}, {49.88`, 
        38.28`}, {49.88`, 73.66`}, {50.46`, 63.8`}, {50.46`, 
        67.86`}, {50.46`, 102.08`}, {50.46`, 106.72`}, {51.04`, 
        100.92000000000002`}, {51.62`, 33.06`}, {51.62`, 85.84`}, {51.62`, 
        87.`}, {52.199999999999996`, 53.94`}, {52.199999999999996`, 
        59.160000000000004`}, {52.199999999999996`, 
        72.5`}, {52.199999999999996`, 
        80.61999999999999`}, {52.199999999999996`, 
        96.86`}, {52.199999999999996`, 111.94`}, {52.779999999999994`, 
        44.660000000000004`}, {52.779999999999994`, 92.22`}, {53.36`, 
        34.22`}, {53.94`, 80.03999999999999`}, {53.94`, 
        104.4`}, {54.519999999999996`, 37.7`}, {54.519999999999996`, 
        46.980000000000004`}, {54.519999999999996`, 
        75.4`}, {54.519999999999996`, 77.14`}, {55.099999999999994`, 
        68.44`}, {55.099999999999994`, 69.02`}, {55.67999999999999`, 
        52.779999999999994`}, {55.67999999999999`, 
        81.78`}, {55.67999999999999`, 
        88.16000000000001`}, {55.67999999999999`, 
        105.56`}, {56.260000000000005`, 58.`}, {56.260000000000005`, 
        64.96000000000001`}, {56.260000000000005`, 
        100.34`}, {56.260000000000005`, 109.62`}, {56.260000000000005`, 
        114.26`}, {56.84`, 78.3`}, {56.84`, 89.9`}, {56.84`, 
        96.86`}, {57.42`, 29.580000000000002`}, {57.42`, 39.44`}, {57.42`, 
        83.52000000000001`}, {57.42`, 95.12`}, {58.`, 73.08`}, {58.58`, 
        42.92`}, {58.58`, 93.96000000000001`}, {59.160000000000004`, 
        31.9`}, {59.160000000000004`, 62.06`}, {59.160000000000004`, 
        74.24000000000001`}, {59.160000000000004`, 106.72`}, {59.74`, 
        56.84`}, {59.74`, 68.44`}, {59.74`, 99.17999999999999`}, {60.32`, 
        33.64`}, {60.32`, 51.04`}, {60.32`, 70.17999999999999`}, {60.32`, 
        77.72`}, {61.48`, 44.660000000000004`}, {61.48`, 
        81.19999999999999`}, {61.48`, 88.16000000000001`}, {61.48`, 
        107.88`}, {62.06`, 52.779999999999994`}, {62.06`, 58.58`}, {62.06`, 
        72.5`}, {62.06`, 112.52`}, {62.64`, 64.96000000000001`}, {62.64`, 
        85.25999999999999`}, {62.64`, 91.06`}, {62.64`, 104.98`}, {63.8`, 
        93.38`}, {64.38`, 29.580000000000002`}, {64.38`, 
        44.660000000000004`}, {64.38`, 57.42`}, {64.38`, 63.22`}, {64.38`, 
        66.7`}, {64.38`, 75.4`}, {64.38`, 79.46`}, {64.38`, 98.02`}, {64.38`, 
        103.24`}, {64.38`, 115.41999999999999`}, {65.54`, 
        35.379999999999995`}, {65.54`, 49.3`}, {65.54`, 71.92`}, {65.54`, 
        99.17999999999999`}, {66.12`, 31.9`}, {66.12`, 
        52.779999999999994`}, {66.12`, 88.74000000000001`}, {66.7`, 
        53.94`}, {66.7`, 82.36000000000001`}, {67.86`, 
        40.599999999999994`}, {67.86`, 88.74000000000001`}, {68.44`, 
        30.74`}, {68.44`, 77.72`}, {68.44`, 107.88`}, {68.44`, 
        109.62`}, {69.02`, 100.34`}, {69.02`, 104.4`}, {69.6`, 
        50.46`}, {70.17999999999999`, 
        37.120000000000005`}, {70.17999999999999`, 
        58.58`}, {70.17999999999999`, 62.06`}, {70.17999999999999`, 
        91.64`}, {70.75999999999999`, 45.82`}, {70.75999999999999`, 
        58.`}, {70.75999999999999`, 78.88`}, {70.75999999999999`, 
        86.41999999999999`}, {70.75999999999999`, 
        95.7`}, {70.75999999999999`, 113.1`}, {71.34`, 62.06`}, {72.5`, 
        27.259999999999998`}, {72.5`, 31.32`}, {72.5`, 66.7`}, {72.5`, 
        75.4`}, {73.08`, 52.779999999999994`}, {73.08`, 104.98`}, {73.66`, 
        82.94`}, {73.66`, 106.13999999999999`}, {74.24000000000001`, 
        52.779999999999994`}, {74.24000000000001`, 
        58.`}, {74.24000000000001`, 70.75999999999999`}, {74.24000000000001`, 
        97.44`}, {74.82000000000001`, 39.44`}, {74.82000000000001`, 
        92.8`}, {75.4`, 65.54`}, {75.4`, 80.61999999999999`}, {75.4`, 
        86.41999999999999`}, {75.4`, 88.16000000000001`}, {75.4`, 
        101.49999999999999`}, {75.4`, 110.2`}, {75.98`, 
        29.580000000000002`}, {75.98`, 75.98`}, {76.56`, 
        80.03999999999999`}, {77.72`, 64.38`}, {78.3`, 35.96`}, {78.3`, 
        92.22`}, {78.88`, 26.68`}, {78.88`, 85.25999999999999`}, {78.88`, 
        97.44`}, {78.88`, 102.08`}, {78.88`, 107.88`}, {79.46`, 
        69.02`}, {79.46`, 73.08`}, {80.03999999999999`, 
        31.9`}, {80.03999999999999`, 
        55.099999999999994`}, {80.03999999999999`, 
        80.61999999999999`}, {80.61999999999999`, 
        49.3`}, {80.61999999999999`, 77.72`}, {81.19999999999999`, 
        58.58`}, {81.19999999999999`, 84.68`}, {81.19999999999999`, 
        88.16000000000001`}, {81.19999999999999`, 
        89.32000000000001`}, {81.19999999999999`, 92.8`}, {81.78`, 
        69.6`}, {81.78`, 99.76`}, {82.36000000000001`, 
        36.54`}, {82.36000000000001`, 53.94`}, {82.36000000000001`, 
        65.54`}, {82.36000000000001`, 104.98`}, {82.94`, 42.34`}, {82.94`, 
        75.4`}, {83.52000000000001`, 29.`}, {83.52000000000001`, 
        94.54`}, {85.25999999999999`, 
        81.19999999999999`}, {85.25999999999999`, 
        89.32000000000001`}, {85.84`, 62.64`}, {86.41999999999999`, 
        32.480000000000004`}, {86.41999999999999`, 
        38.28`}, {86.41999999999999`, 76.56`}, {86.41999999999999`, 
        100.92000000000002`}, {87.`, 63.8`}, {87.`, 72.5`}, {87.`, 
        96.86`}, {87.57999999999998`, 56.84`}, {87.57999999999998`, 
        85.25999999999999`}, {87.57999999999998`, 
        92.8`}, {88.16000000000001`, 46.4`}, {88.74000000000001`, 
        27.839999999999996`}, {89.32000000000001`, 
        42.34`}, {89.32000000000001`, 89.9`}, {89.9`, 69.02`}, {90.48`, 
        67.86`}, {90.48`, 71.34`}, {91.06`, 78.88`}, {91.64`, 
        33.64`}, {92.22`, 37.7`}, {92.22`, 48.72`}, {92.8`, 42.92`}, {93.38`, 
        62.06`}, {93.38`, 71.34`}, {93.96000000000001`, 58.`}, {94.54`, 
        56.84`}, {95.12`, 79.46`}, {95.7`, 53.36`}, {95.7`, 64.38`}, {96.28`, 
        31.9`}, {96.28`, 66.7`}, {96.86`, 37.120000000000005`}, {96.86`, 
        48.14`}, {97.44`, 53.94`}, {98.02`, 42.92`}, {98.02`, 
        49.88`}, {98.02`, 72.5`}, {99.17999999999999`, 60.32`}, {99.76`, 
        68.44`}, {100.34`, 48.72`}, {100.92000000000002`, 
        64.38`}, {101.49999999999999`, 35.96`}, {102.66`, 
        40.599999999999994`}, {102.66`, 55.67999999999999`}, {104.4`, 
        46.980000000000004`}, {104.4`, 52.779999999999994`}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize the meristem", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = Length[xymeristem]\)], "Input"],

Cell[BoxData[
    \(253\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(rn := Random[Real, {0,  .3}];\)\), "\[IndentingNewLine]", 
    \(\(rc := CMYKColor[rn, rn, rn, rn];\)\), "\[IndentingNewLine]", 
    \(\(rcs = Table[rc, {n}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = 
      visualization[cellCoordinates \[Rule] \ xymeristem, 
        cellNumbers \[Rule] \ False, cellColors \[Rule] \ rcs, \ 
        ImageSize \[Rule] \ 700, Frame \[Rule] \ True, 
        cellDots \[Rule] \ Blue, PlotRange \[Rule] \ {{20, 120}, {20, 120}}, 
        AspetcRatio \[Rule] \ 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 700 700 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.2 0.01 -0.2 0.01 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .2 -12 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -12 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -12 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(40)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(80)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(100)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(120)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(40)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(60)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(80)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(100)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(120)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .2 m
1 .2 L
s
.99375 .4 m
1 .4 L
s
.99375 .6 m
1 .6 L
s
.99375 .8 m
1 .8 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .25 m
1 .25 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .45 m
1 .45 L
s
.99625 .5 m
1 .5 L
s
.99625 .55 m
1 .55 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .75 m
1 .75 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 .125 .182 .123 k
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
F
0 g
.004 w
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
s
.045 .194 .202 .25 k
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
F
0 g
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
s
.28 .187 .189 .044 k
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
F
0 g
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
s
.192 .297 .074 .029 k
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
F
0 g
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
s
.104 .089 .187 .229 k
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
F
0 g
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
s
.256 .272 .248 .05 k
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
F
0 g
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
s
.156 .148 .066 .227 k
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
F
0 g
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
s
.111 .254 .164 .277 k
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
F
0 g
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
s
.131 .067 .275 .233 k
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
F
0 g
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
s
.238 .07 .201 .204 k
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
F
0 g
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
s
.134 .281 .013 .275 k
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
F
0 g
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
s
.179 .009 .065 .225 k
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
s
.023 .161 .299 .298 k
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
F
0 g
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
s
.212 .207 .135 .021 k
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
F
0 g
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
s
.081 .139 .161 .088 k
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
s
.143 .07 .26 .184 k
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
s
.008 .089 .247 .209 k
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
s
.13 .08 .181 .284 k
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
F
0 g
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
s
.107 .219 .182 .286 k
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
F
0 g
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
s
.196 .013 .047 .265 k
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
F
0 g
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
s
.115 .173 .186 .177 k
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
s
.272 .104 .226 .294 k
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
F
0 g
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
s
.264 .015 .28 .085 k
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
F
0 g
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
s
.134 .235 .098 .101 k
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
s
.027 .016 .216 .114 k
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
s
.132 .003 .17 .149 k
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
F
0 g
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
s
.017 .13 .284 .272 k
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
F
0 g
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
s
.045 .026 .057 .278 k
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
F
0 g
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
s
.081 .011 .078 .193 k
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
s
.247 .076 .28 .093 k
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
F
0 g
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
s
.22 .06 .063 .278 k
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
F
0 g
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
s
.088 .057 .194 .129 k
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
F
0 g
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
s
.071 .227 .21 .157 k
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
s
.026 .201 .153 .179 k
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
F
0 g
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
s
.245 .19 .075 .286 k
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
F
0 g
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
s
.298 .113 .095 .193 k
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
s
.078 .053 .032 .215 k
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
s
.29 .296 .138 .085 k
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
F
0 g
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
s
.219 .069 .228 .228 k
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
s
.193 .168 .075 .049 k
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
s
.249 .278 .3 .063 k
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
F
0 g
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
s
.251 .165 .204 .17 k
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
s
.173 .112 .172 .255 k
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
s
.183 .116 .034 .17 k
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
F
0 g
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
s
.263 .047 .107 .242 k
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
s
.07 .18 .032 .193 k
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
s
.121 .201 .032 .13 k
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
F
0 g
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
s
.17 .036 .127 .26 k
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
s
.298 .224 .255 .005 k
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
F
0 g
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
s
.115 .108 .221 .135 k
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
s
.151 .06 .114 .194 k
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
s
.081 .181 .082 .001 k
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
F
0 g
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
s
.26 .28 .05 .17 k
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
s
.09 .244 .223 .21 k
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
s
.092 .02 .268 .205 k
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
F
0 g
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
s
.277 .212 .047 .069 k
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
s
.126 .152 .233 .176 k
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
F
0 g
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
s
.044 .271 .151 .175 k
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
F
0 g
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
s
.084 .292 .101 .005 k
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
s
.295 .048 .178 .095 k
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
F
0 g
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
s
.202 .028 .21 .19 k
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
s
.225 .116 .163 .121 k
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
s
.099 .264 .23 .245 k
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
F
0 g
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
s
.055 .293 .079 .07 k
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
F
0 g
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
s
.27 .001 .278 .065 k
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
F
0 g
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
s
.276 .253 .099 .27 k
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
s
.073 .225 .189 .08 k
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
s
.148 .109 .026 .259 k
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
s
.049 .144 .096 .015 k
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
F
0 g
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
s
.294 .151 .017 .245 k
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
F
0 g
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
s
.024 .15 .04 .18 k
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
F
0 g
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
s
.048 .197 .241 .21 k
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
F
0 g
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
s
.275 .272 .052 .13 k
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
F
0 g
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
s
.127 .164 .026 .17 k
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
F
0 g
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
s
.078 .019 .23 .156 k
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
F
0 g
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
s
.083 .168 .213 .211 k
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
F
0 g
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
s
.059 .018 .173 .031 k
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
s
.011 .121 .232 .121 k
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
s
.036 .149 .18 .291 k
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
s
.209 .285 .155 .12 k
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
F
0 g
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
s
.132 .266 .225 .265 k
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
F
0 g
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
s
.048 .098 .012 .054 k
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
F
0 g
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
s
.289 .08 .139 .023 k
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
s
.279 .26 .207 .202 k
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
F
0 g
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
s
.243 .111 .027 .212 k
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
F
0 g
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
s
.034 .126 .172 .091 k
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
F
0 g
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
s
.202 .16 .248 .127 k
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
s
.154 .061 .235 .073 k
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
s
.165 .281 .096 .05 k
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
F
0 g
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
s
.186 .021 .189 .148 k
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
F
0 g
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
s
.243 .211 .162 .236 k
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
F
0 g
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
s
.209 .085 .29 .145 k
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
s
.007 .225 .042 .018 k
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
s
.153 .164 .107 .245 k
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
F
0 g
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
s
.289 .183 .011 .195 k
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
F
0 g
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
s
.103 .161 .122 .047 k
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
F
0 g
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
s
.16 .251 .26 .111 k
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
s
.25 .166 .27 .267 k
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
s
.243 .241 .228 .249 k
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
s
.09 .077 .121 .004 k
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
F
0 g
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
s
.102 .194 .11 .11 k
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
F
0 g
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
s
.299 .032 .288 .063 k
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
F
0 g
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
s
.139 .081 .028 .251 k
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
s
.189 .215 .058 .285 k
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
s
.246 .275 .13 .036 k
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
s
.156 .198 .01 .031 k
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
F
0 g
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
s
.054 .004 .2 .221 k
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
s
.055 .272 .212 .159 k
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
F
0 g
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
s
.216 .191 .185 .208 k
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
F
0 g
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
s
.026 .275 .127 .223 k
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
F
0 g
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
s
.08 .001 .297 .187 k
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
s
.225 .103 .287 .156 k
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
s
.17 .098 .087 .235 k
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
F
0 g
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
s
.115 .126 .175 .076 k
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
F
0 g
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
s
.2 .235 .29 .168 k
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
s
.173 .26 .163 .245 k
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
F
0 g
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
s
.093 .259 .166 .058 k
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
s
.168 .156 .179 .202 k
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
s
.298 .058 .091 .267 k
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
F
0 g
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
s
.182 .232 .217 .192 k
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
s
.283 .297 .227 .024 k
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
F
0 g
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
s
.11 .037 .064 .078 k
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
F
0 g
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
s
.017 .078 .198 .02 k
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
s
.149 .222 .02 .118 k
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
F
0 g
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
s
.151 .163 .228 .151 k
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
s
.269 .231 .012 .259 k
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
F
0 g
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
s
.286 .234 .085 .236 k
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
s
.177 .197 .02 .157 k
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
F
0 g
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
s
.16 .118 .122 .137 k
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
F
0 g
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
s
.01 .197 .102 .019 k
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
s
.159 .033 .174 .168 k
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
s
.19 .102 .162 .208 k
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
F
0 g
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
s
.204 .168 .077 .273 k
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
s
.027 .271 .057 .115 k
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
F
0 g
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
s
.167 .153 .235 .278 k
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
F
0 g
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
s
.157 .256 .134 .26 k
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
s
.298 .223 .26 .092 k
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
F
0 g
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
s
.108 .121 .098 .184 k
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
s
.204 .253 .021 .211 k
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
F
0 g
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
s
.177 .282 .263 .096 k
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
s
.01 .129 .028 .117 k
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
s
.153 .173 .194 .158 k
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
s
.155 .251 .234 .066 k
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
F
0 g
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
s
.047 .13 .136 .182 k
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
s
.143 .177 .116 .272 k
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
F
0 g
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
s
.265 .195 .153 .176 k
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
F
0 g
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
s
.255 .066 .125 .059 k
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
F
0 g
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
s
.102 .193 .23 .201 k
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
F
0 g
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
s
.247 .242 .296 .135 k
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
F
0 g
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
s
.2 .112 .159 .252 k
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
F
0 g
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
s
.057 .236 .043 .281 k
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
s
.092 .04 .191 .105 k
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
s
.136 .275 .066 .046 k
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
F
0 g
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
s
.034 .082 .136 .145 k
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
F
0 g
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
s
.087 .14 .14 .011 k
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
s
.187 .028 .281 .058 k
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
s
.13 .092 .238 .078 k
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
s
.038 .052 .047 .273 k
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
s
.202 .077 .281 .227 k
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
s
.168 .295 .145 .081 k
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
F
0 g
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
s
.081 .155 .005 .07 k
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
s
.194 .127 .024 .012 k
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
s
.064 .035 .086 .234 k
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
F
0 g
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
s
.025 .284 .04 .262 k
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
F
0 g
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
s
.124 .207 .059 .035 k
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
F
0 g
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
s
.256 .212 .214 .254 k
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
F
0 g
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
s
.175 .057 .209 .183 k
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
F
0 g
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
s
.281 .23 .185 .171 k
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
F
0 g
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
s
.217 .194 .099 .237 k
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
F
0 g
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
s
.192 .21 .059 .275 k
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
F
0 g
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
s
.068 .003 0 .24 k
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
F
0 g
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
s
.113 .091 .087 .287 k
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
F
0 g
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
s
.238 .034 .178 .104 k
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
F
0 g
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
s
.257 .104 .292 .232 k
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
F
0 g
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
s
.039 .21 .194 .296 k
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
s
.147 .299 .135 .021 k
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
F
0 g
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
s
.079 .296 .134 .08 k
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
F
0 g
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
s
.266 .205 .048 .094 k
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
s
.029 .171 .17 .29 k
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
F
0 g
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
s
.072 .067 .177 .058 k
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
F
0 g
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
s
.033 .157 .284 .062 k
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
s
.186 .158 .149 .041 k
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
s
.107 .162 .015 .261 k
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
F
0 g
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
s
.14 .257 .267 .167 k
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
F
0 g
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
s
.112 .086 .097 .177 k
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
F
0 g
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
s
.04 .019 .22 .119 k
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
s
.007 .161 .236 .057 k
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
F
0 g
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
s
.121 .003 .087 .016 k
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
F
0 g
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
s
.015 .141 .072 .055 k
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
F
0 g
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
s
.174 .184 .105 .188 k
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
F
0 g
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
s
.063 .098 .007 .011 k
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
F
0 g
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
s
.023 .08 .087 .192 k
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
F
0 g
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
s
.016 .219 .151 .136 k
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
F
0 g
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
s
.195 .216 .064 .12 k
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
F
0 g
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
s
.18 .075 .292 .065 k
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
F
0 g
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
s
.006 .191 .187 .178 k
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
s
.244 .093 .18 .166 k
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
F
0 g
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
s
.221 .013 .093 .274 k
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
s
.204 .094 .242 .138 k
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
s
.009 .179 .178 .018 k
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
F
0 g
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
s
.129 .104 .186 .253 k
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
F
0 g
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
s
.123 .213 .299 .075 k
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
F
0 g
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
s
.179 .121 .119 .209 k
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
F
0 g
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
s
.258 .108 .026 .235 k
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
F
0 g
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
s
.054 .013 .085 .096 k
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
F
0 g
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
s
.045 .135 .207 .078 k
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
F
0 g
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
s
.216 .031 .021 .126 k
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
s
.093 .118 .022 .05 k
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
F
0 g
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
s
.214 .297 .203 .142 k
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
F
0 g
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
s
.255 .189 .176 .207 k
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
F
0 g
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
s
.201 .176 .092 .111 k
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
F
0 g
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
s
.157 .041 .185 .033 k
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
s
.241 .01 .164 .207 k
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
s
.148 .192 .143 .156 k
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
s
.234 .195 .24 .015 k
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
F
0 g
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
s
.279 .006 .064 .107 k
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
F
0 g
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
s
.078 .13 .272 .297 k
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
s
.221 .089 .087 .264 k
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
F
0 g
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
s
.28 .079 .222 .057 k
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
F
0 g
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
s
.131 .187 .08 .201 k
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
F
0 g
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
s
.197 .291 .14 .186 k
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
F
0 g
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
s
.218 .286 .076 .079 k
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
s
.14 .156 .104 .082 k
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
s
.22 .067 .017 .118 k
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
s
.24 .288 .095 .061 k
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
F
0 g
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
s
.109 .101 .015 .16 k
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
s
.212 .11 .176 .274 k
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
s
.294 .124 .1 .195 k
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
F
0 g
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
s
.153 .268 .296 .113 k
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
F
0 g
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
s
.234 .202 .278 .296 k
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
s
.293 .214 .184 .235 k
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
F
0 g
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
s
.185 .113 .168 .075 k
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
s
.273 .003 .293 .101 k
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
F
0 g
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
s
.279 .179 .193 .205 k
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
F
0 g
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
s
.126 .211 .197 .092 k
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
F
0 g
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
s
.192 .01 .219 .096 k
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
s
.199 .096 .035 .161 k
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
F
0 g
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
s
.014 .283 .167 .087 k
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
s
.041 .28 .174 .286 k
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
s
.062 .1 .282 .08 k
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
s
.236 .189 .084 .288 k
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
F
0 g
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
s
.044 .179 .166 .192 k
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
F
0 g
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
s
.145 .084 .131 .03 k
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
s
.131 .101 .264 .244 k
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
s
.09 .121 .089 .258 k
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
s
.028 .021 .108 .178 k
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
s
.092 .132 .023 .19 k
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
s
.048 .253 .157 .298 k
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
F
0 g
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
s
.203 .169 .027 .267 k
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
F
0 g
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
s
.072 .068 .063 .024 k
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
F
0 g
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
s
.283 .247 .274 .066 k
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
F
0 g
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
s
.255 .226 .167 .188 k
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
F
0 g
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
s
.163 .094 .144 .298 k
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
F
0 g
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
s
0 0 1 r
.008 w
.148 .3568 Mdot
.1596 .3974 Mdot
.1654 .3104 Mdot
.1712 .4496 Mdot
.1828 .4206 Mdot
.1886 .2582 Mdot
.1886 .3046 Mdot
.2002 .3684 Mdot
.206 .4612 Mdot
.206 .5134 Mdot
.2118 .2872 Mdot
.2234 .206 Mdot
.2234 .3394 Mdot
.2234 .4206 Mdot
.2292 .728 Mdot
.235 .1654 Mdot
.2408 .3742 Mdot
.2408 .496 Mdot
.2408 .6062 Mdot
.2408 .6642 Mdot
.2408 .7976 Mdot
.2466 .235 Mdot
.2466 .3974 Mdot
.2524 .2408 Mdot
.2524 .2814 Mdot
.2524 .293 Mdot
.2582 .4554 Mdot
.2582 .5366 Mdot
.264 .7744 Mdot
.2698 .1596 Mdot
.2698 .4844 Mdot
.2698 .5714 Mdot
.2756 .4438 Mdot
.2756 .6874 Mdot
.2756 .7454 Mdot
.2756 .844 Mdot
.2814 .235 Mdot
.2814 .5946 Mdot
.2872 .3046 Mdot
.2872 .6294 Mdot
.2872 .6932 Mdot
.293 .8904 Mdot
.2988 .1828 Mdot
.2988 .5366 Mdot
.3046 .438 Mdot
.3046 .4786 Mdot
.3046 .8208 Mdot
.3046 .8672 Mdot
.3104 .8092 Mdot
.3162 .1306 Mdot
.3162 .6584 Mdot
.3162 .67 Mdot
.322 .3394 Mdot
.322 .3916 Mdot
.322 .525 Mdot
.322 .6062 Mdot
.322 .7686 Mdot
.322 .9194 Mdot
.3278 .2466 Mdot
.3278 .7222 Mdot
.3336 .1422 Mdot
.3394 .6004 Mdot
.3394 .844 Mdot
.3452 .177 Mdot
.3452 .2698 Mdot
.3452 .554 Mdot
.3452 .5714 Mdot
.351 .4844 Mdot
.351 .4902 Mdot
.3568 .3278 Mdot
.3568 .6178 Mdot
.3568 .6816 Mdot
.3568 .8556 Mdot
.3626 .38 Mdot
.3626 .4496 Mdot
.3626 .8034 Mdot
.3626 .8962 Mdot
.3626 .9426 Mdot
.3684 .583 Mdot
.3684 .699 Mdot
.3684 .7686 Mdot
.3742 .0958 Mdot
.3742 .1944 Mdot
.3742 .6352 Mdot
.3742 .7512 Mdot
.38 .5308 Mdot
.3858 .2292 Mdot
.3858 .7396 Mdot
.3916 .119 Mdot
.3916 .4206 Mdot
.3916 .5424 Mdot
.3916 .8672 Mdot
.3974 .3684 Mdot
.3974 .4844 Mdot
.3974 .7918 Mdot
.4032 .1364 Mdot
.4032 .3104 Mdot
.4032 .5018 Mdot
.4032 .5772 Mdot
.4148 .2466 Mdot
.4148 .612 Mdot
.4148 .6816 Mdot
.4148 .8788 Mdot
.4206 .3278 Mdot
.4206 .3858 Mdot
.4206 .525 Mdot
.4206 .9252 Mdot
.4264 .4496 Mdot
.4264 .6526 Mdot
.4264 .7106 Mdot
.4264 .8498 Mdot
.438 .7338 Mdot
.4438 .0958 Mdot
.4438 .2466 Mdot
.4438 .3742 Mdot
.4438 .4322 Mdot
.4438 .467 Mdot
.4438 .554 Mdot
.4438 .5946 Mdot
.4438 .7802 Mdot
.4438 .8324 Mdot
.4438 .9542 Mdot
.4554 .1538 Mdot
.4554 .293 Mdot
.4554 .5192 Mdot
.4554 .7918 Mdot
.4612 .119 Mdot
.4612 .3278 Mdot
.4612 .6874 Mdot
.467 .3394 Mdot
.467 .6236 Mdot
.4786 .206 Mdot
.4786 .6874 Mdot
.4844 .1074 Mdot
.4844 .5772 Mdot
.4844 .8788 Mdot
.4844 .8962 Mdot
.4902 .8034 Mdot
.4902 .844 Mdot
.496 .3046 Mdot
.5018 .1712 Mdot
.5018 .3858 Mdot
.5018 .4206 Mdot
.5018 .7164 Mdot
.5076 .2582 Mdot
.5076 .38 Mdot
.5076 .5888 Mdot
.5076 .6642 Mdot
.5076 .757 Mdot
.5076 .931 Mdot
.5134 .4206 Mdot
.525 .0726 Mdot
.525 .1132 Mdot
.525 .467 Mdot
.525 .554 Mdot
.5308 .3278 Mdot
.5308 .8498 Mdot
.5366 .6294 Mdot
.5366 .8614 Mdot
.5424 .3278 Mdot
.5424 .38 Mdot
.5424 .5076 Mdot
.5424 .7744 Mdot
.5482 .1944 Mdot
.5482 .728 Mdot
.554 .4554 Mdot
.554 .6062 Mdot
.554 .6642 Mdot
.554 .6816 Mdot
.554 .815 Mdot
.554 .902 Mdot
.5598 .0958 Mdot
.5598 .5598 Mdot
.5656 .6004 Mdot
.5772 .4438 Mdot
.583 .1596 Mdot
.583 .7222 Mdot
.5888 .0668 Mdot
.5888 .6526 Mdot
.5888 .7744 Mdot
.5888 .8208 Mdot
.5888 .8788 Mdot
.5946 .4902 Mdot
.5946 .5308 Mdot
.6004 .119 Mdot
.6004 .351 Mdot
.6004 .6062 Mdot
.6062 .293 Mdot
.6062 .5772 Mdot
.612 .3858 Mdot
.612 .6468 Mdot
.612 .6816 Mdot
.612 .6932 Mdot
.612 .728 Mdot
.6178 .496 Mdot
.6178 .7976 Mdot
.6236 .1654 Mdot
.6236 .3394 Mdot
.6236 .4554 Mdot
.6236 .8498 Mdot
.6294 .2234 Mdot
.6294 .554 Mdot
.6352 .09 Mdot
.6352 .7454 Mdot
.6526 .612 Mdot
.6526 .6932 Mdot
.6584 .4264 Mdot
.6642 .1248 Mdot
.6642 .1828 Mdot
.6642 .5656 Mdot
.6642 .8092 Mdot
.67 .438 Mdot
.67 .525 Mdot
.67 .7686 Mdot
.6758 .3684 Mdot
.6758 .6526 Mdot
.6758 .728 Mdot
.6816 .264 Mdot
.6874 .0784 Mdot
.6932 .2234 Mdot
.6932 .699 Mdot
.699 .4902 Mdot
.7048 .4786 Mdot
.7048 .5134 Mdot
.7106 .5888 Mdot
.7164 .1364 Mdot
.7222 .177 Mdot
.7222 .2872 Mdot
.728 .2292 Mdot
.7338 .4206 Mdot
.7338 .5134 Mdot
.7396 .38 Mdot
.7454 .3684 Mdot
.7512 .5946 Mdot
.757 .3336 Mdot
.757 .4438 Mdot
.7628 .119 Mdot
.7628 .467 Mdot
.7686 .1712 Mdot
.7686 .2814 Mdot
.7744 .3394 Mdot
.7802 .2292 Mdot
.7802 .2988 Mdot
.7802 .525 Mdot
.7918 .4032 Mdot
.7976 .4844 Mdot
.8034 .2872 Mdot
.8092 .4438 Mdot
.815 .1596 Mdot
.8266 .206 Mdot
.8266 .3568 Mdot
.844 .2698 Mdot
.844 .3278 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 700},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0002_2000`400?l00000o`00003ooooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo
003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool009_ooooo0ol00003ooooo`;o0000Noooool3o`0000Cooooo0_l0001looooo`?o0000
1?ooool2o`0007Wooooo0ol00004ooooo`;o00001?ooool2o`0007Gooooo0ol00002ooooo`Go0000
0oooool2o`0000Cooooo002Looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`1gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001joooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`00VOooool5o`0000;ooooo00Co0000oooooooooooo0000NOooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo0000N_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000MOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool009Wooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool0001iooooo`Co00000oooool01?l0003oooooooooool0001koooo
o`?o00000oooool01?l0003oooooooooool0001iooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo007ooooo002Jooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0007[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0007Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0007Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00Oooool009_ooooo0_l00003ooooo`04o`000?oooooooooo
o`0007[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001jooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0001hooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0007Cooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`00W?ooool00ol0003ooooooooo
o`02ooooo`;o0000O?ooool2o`0000Cooooo0_l0001looooo`?o00001?ooool2o`0007[ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l0001fooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o00001?ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool0
0?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooo
oonnooooo`006_ooooooo`000?oo0000V_l0000:ooooo`006_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooo
oooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooo
oooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooo
oiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooomioooooaWo0000ooooool4ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooN?oooolKo`000?oooooo0oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooogKooooo1?l0000Goj>cf`?o0000
ooooool2ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooG_oo
ool7o`0000oooooo1Ol0000Ioj>cf`?o0000ooooool1ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0?ooooooE_oooolAo`0000cooooo1?l0000Loj>cf`?o0000ooooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodkooooo4Ol00005olgJ
]0Ko00001oooool4o`0001ooXk?K1?l0003mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0?ooooooB_ooool=o`0000oocMZd1_l00003ooooo`Go00008OnS/m/4o`0002Oo
oooo1Ol0003@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000oooooom9ooooo`Ko0000
6_o=f[@9o`0002GoXk?K0ol0000Sooooo`_o0000boooool3o`0000[ooooo000Jooooo`03o`000?oo
oooooooo0?ooooooB?ooool3o`00023ocMZd1Ol0000Xoj>cf`?o00007oooool7o`0000?oZMfh2?l0
0039ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooAoooool3
o`0002?ocMZd0_l0000Zoj>cf`?o00001Oooool:o`0000cooooo1ol00009ojWM^0So0000a_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodKooooo0ol0000TolgJ
]0;o0000:onS/m/Do`0000Kooooo1ol0000@ojWM^0Oo0000`oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3oooooodGooooo0ol0000UolgJ]0;o0000;?nS/m/7o`0000So
W:^/3_l0000FojWM^0Ko0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodCooooo0ol0000VolgJ]0;o0000:onS/m/3o`00013oW:^/2?l0000LojWM^0?o0000
`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3ooooood?ooooo0ol0
000WolgJ]0?o0000:_nS/m/2o`0001CoW:^/0_l0000PojWM^0?o0000`?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`3ooooood;ooooo0ol0000YolgJ]0;o0000:OnS/m/3
o`0001CoW:^/0_l0000QojWM^0?o0000_oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`3oooooob[ooooo2Ol0000>ooooo`?o0000:_o=f[@2o`0002WoXk?K0_l0000Eoib[
[0?o00008OnYgKP3o`000;kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0oooooolMoooooaWo00002_ooool3o`0002_ocMZd0ol0000Boj>cf`?o003o4_nS/m/3o`0001Ko
W:^/0_l0000RojWM^0?o0000_Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`3gooooo`Go00006?oooolFo`0000OoV:Z]1_l00007ooooo`?o0000;?o=f[@4o`00013oXk?K
1Ol00?lAoj>cf`;o00005onLZj`2o`0002?oZMfh0_l0002mooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0?Cooooo2ol0000Dooooo`[o00005onHZZd<o`0002cocMZd1_l0
000?oj>cf`Go003o4?nS/m/3o`0001OoW:^/0_l0000SojWM^0?o0000_?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`3aooooo`Oo00000ooUfNl6o`00013ooooo1?l0000Q
oiRZ[@Wo0000;?o=f[@3o`0000;oVInP0ol0000>oj>cf`Go003o4?nS/m/2o`0001SoW:^/0_l0000T
ojWM^0?o0000^oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3^oooo
o`Oo00002OoUfNl6o`0000cooooo1?l0000RoiRZ[@;o00001OoKWM<3o`0001SocMZd0ol00?l@olgJ
]0;o00001?nIWj03o`0000koXk?K0ol00?l@oj>cf`?o00006?nLZj`3o`0002CoZMfh0ol0002joooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>_ooooo1ol0000>onGIk`Oo
00002?ooool3o`0002?oV:Z]0ol00006om^Md`?o00005_o=f[@5o`00o`kocMZd0ol00005oiVOX0?o
00008?nS/m/2o`0001[oW:^/0_l0000UojWM^0?o0000^Oooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`3Xooooo`Oo00005?oUfNl6o`0000Cooooo1?l0000ToiRZ[@;o0000
2?oKWM<3o`0001GocMZd1Ol00?l=olgJ]0?o00001onIWj03o`0001koXk?K0ol0000Joib[[0;o0000
9_nYgKP2o`000;Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0iOoo
ool7o`0001[oiMW_2_l0000UoiRZ[@;o00002OoKWM<3o`0001CocMZd1Ol00?l=olgJ]0;o00002OnI
Wj03o`0001goXk?K0_l0000Koib[[0;o00009_nYgKP3o`000;Sooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0hoooool6o`0001ooiMW_1_l0000WoiRZ[@;o00002_oKWM<3
o`0001CocMZd0ol00?l=olgJ]0?o00002_nIWj03o`0001_oXk?K0ol0000Koib[[0;o00004OnYgKP3
o`00oa?oZMfh0ol0002gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0>?ooooo0ol0000UonGIk`;o00009onHZZd3o`0000_ofigC0ol0000RolgJ]0?o00003?nIWj03o`00
01[oXk?K0_l0000Loib[[0?o00003onYgKP5o`00oa?oZMfh0ol0002fooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0>;ooooo0ol0000VonGIk`;o00009onHZZd2o`0000go
figC0ol0000PolgJ]0?o00003_nIWj03o`0001SoXk?K0ol0000Moib[[0;o00003onYgKP5o`00oaCo
ZMfh0_l0002fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>;ooooo
0_l0000WonGIk`;o00009onHZZd2o`0000kofigC0ol0000OolgJ]0;o00004?nIWj03o`0001OoXk?K
0_l0000Noib[[0;o00003onYgKP5o`00oaCoZMfh0ol0002eooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0>7ooooo0ol0000WonGIk`;o00009onHZZd2o`0000oofigC0_l0
000NolgJ]0?o00004OnIWj03o`0001GoXk?K0ol0000Noib[[0;o00004?nYgKP3o`00oaKoZMfh0ol0
002dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>7ooooo0_l0000X
onGIk`;o00009_nHZZd3o`0000oofigC0ol0000LolgJ]0?o00004onIWj03o`0001CoXk?K0_l0000O
oib[[0;o0000:_nYgKP3o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0h?ooool3o`0002SoiMW_0_l0000VoiRZ[@;o00004OoKWM<3o`0001_ocMZd0_l0000EoiVO
X0?o00004_nS/m/3o`0001ooW:^/0ol0000ZojWM^0?o0000/_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3Pooooo`;o0000:OoUfNl2o`0002KoV:Z]0_l0000Bom^Md`?o
00006Oo=f[@3o`0001KoVInP0ol0000Aoj>cf`;o00003onLZj`3o`00o`ooW:^/0_l0000[ojWM^0;o
0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Oooooo`?o0000
:?oUfNl3o`0002KoV:Z]0_l0000Com^Md`?o00005oo=f[@3o`0001SoVInP0ol0000?oj>cf`?o0000
3_nLZj`5o`00o`koW:^/0_l0000[ojWM^0?o00002_ooool>o`0009Wooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0g_ooool3o`0002SoiMW_1?l0000VoiRZ[@;o00005?oK
WM<3o`0001KocMZd0_l0000JoiVOX0?o00003_nS/m/2o`0000ooW:^/1Ol00?l>oib[[0;o0000;?nY
gKPKo`0009Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0g_ooool2
o`0002SoiMW_1_l0000ToiRZ[@?o00005OoKWM<3o`0001CocMZd0ol0000KoiVOX0?o00002OnS/m/6
o`0000ooW:^/1Ol00?l>oib[[0;o0000:onYgKP>o`0000coXkk=1?l0002Fooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0=gooooo0ol0000DonGIk`?o003o3ooUfNl4o`00
00;ob:_J0_l0000DoiRZ[@?o003o3OnHZZd2o`0001OofigC6?l0000<oiVOX0?o003o3_nIWj03o`00
00;oXk?K2ol0000Aoib[[0?o003o3onLZj`3o`0002WoZMfh0ol0000Ioj>nc@Co0000UOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Mooooo`;o00005?oUfNl5o`00o`go
iMW_1?l00003olR[fP?o00004_nHZZd5o`00o`coV:Z]0_l0000Hom^MdaKo00003?nIWj05o`00o`ko
VInP2ol00002okJl^@?o00008onLZj`2o`0002OoZMfh1?l0000Loj>nc@?o0000U?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Looooo`?o00005?oUfNl5o`00o`coiMW_
0ol00006olR[fP;o00004_nHZZd5o`00o`coV:Z]0_l0000Hom^Md`;o00004_oA[N<3o`0000_oVInP
1Ol00?l?oiVOX0Co00002Onf_;T3o`00027oW:^/1?l0000TojWM^0Go00007_nS_/d4o`0009;ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0b?ooool<o`0000Sooooo0_l0
000EonGIk`Go003o2_oUfNl4o`0000Oob:_J0ol0000AoiRZ[@Go003o2onHZZd3o`0001SofigC0_l0
000Com6]h`;o00002onIWj05o`00o`koVInP0ol0000<okJl^@?o00007onLZj`7o`00023oZMfh2?l0
000Noj>nc@Co0000TOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`37
oooooaOo00005_oUfNl3o`00o`[oiMW_1?l00009olR[fP;o00004_nHZZd3o`00o`_oV:Z]0ol0000I
om^Md`;o00004ooA[N<3o`0000_oVInP0ol00?l?oiVOX0;o00003_nf_;T3o`0001goW:^/0ol00002
om_Dk@Go00007?nYgKP5o`0000?o^kgC0_l0000Poj>nc@Co0000Soooool00ol0003oooooooooo`08
ooooo`006_ooool3o`000<Kooooo0ol0000:oko1Y0[o00008ooUfNl3o`0000_ob:_J0ol0000NoiRZ
[@Co00006?oKWM<3o`0001CodJgS0_l0000LoiVOX0?o00003onf_;T3o`0001_oW:^/0ol00005om_D
k@Go00006?nYgKP5o`0000Go^kgC0_l0000Qoj>nc@Co0000S?ooool3o`0000[ooooo000Jooooo`03
o`000?oooooooooo0<Gooooo0ol0000Coko1Y0?o00008?oUfNl4o`0000gob:_J0_l0000MoiRZ[@Ko
00005ooKWM<2o`0001GodJgS0ol0000JoiVOX0?o00004Onf_;T3o`0001SoW:^/1?l00008om_Dk@Go
00005?nYgKP5o`0000Oo^kgC0ol0000Roj>nc@?o0000SOooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`34ooooo`?o00005Ono`J@2o`0001ooiMW_1?l0000>olR[fP?o0000
6_nHZZd4o`0000;oNXN]0_l0000Gom^Md`;o00005_oA[N<2o`0001[oVInP0_l0000CokJl^@;o0000
5onLZj`4o`0000_ofmC]1_l0000@ojWM^0Co00002_nk_M<2o`0002?oXkk=0ol0002<ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<?ooooo0ol0000Foko1Y0?o00007OoU
fNl3o`00017ob:_J0_l0000IoiRZ[@Co00000omjQjd3o`0000SofigC0ol00?l;om^Md`;o00005_oA
[N<3o`0001SoVInP0ol0000CokJl^@?o00005OnLZj`3o`0000oofmC]1_l0000<ojWM^0Co00003?nk
_M<3o`0002?oXkk=0_l0002<ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0<;ooooo0ol0000Hoko1Y0?o00006_oUfNl4o`0001;ob:_J0ol0000GoiRZ[@?o00001_mjQjd2
o`0000OofigC1Ol00?l:om^Md`;o00005ooA[N<2o`0001SoVInP0_l0000EokJl^@?o00004onLZj`3
o`0001?ofmC]1Ol00008ojWM^0Go00003_nk_M<2o`0002?oXkk=0ol0002;ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0<7ooooo0ol0000Joko1Y0;o00006OoUfNl4o`00
01Cob:_J0_l0000EoiRZ[@Co00001omjQjd3o`0000KofigC1Ol00?l:om^Md`;o00005ooA[N<3o`00
01KoVInP0ol0000FokJl^@?o00004?nLZj`4o`0001KofmC]1Ol00004ojWM^0Go00004?nk_M<2o`00
02CoXkk=0_l0002;ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<3o
oooo0ol0000Koko1Y0Co00005_oUfNl3o`0001Kob:_J0ol0000CoiRZ[@Co00002OmjQjd2o`0000Ko
figC1Ol00?l:om^Md`;o00006?oA[N<2o`0001KoVInP0_l0000HokJl^@?o00003_nLZj`4o`0001Wo
fmC]2_l0000Bok^md`?o00008onS_/d3o`0008[ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0__ooool4o`0001go_l6T1?l0000ConGIk`Co00006?o8ZmX2o`00017oV:Z]
1?l0000;ogZ7[@?o00001_oKWM<3o`00o`[ofigC0ol0000;om6]h`?o003o2_oA[N<3o`0001CoVInP
0ol0000IokJl^@?o00003?nLZj`3o`0001gofmC]1_l0000Eok^md`;o00009?nS_/d2o`0008[ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0_Oooool4o`0001go_l6T1_l0
000AonGIk`Co00006Oo8ZmX3o`0000ooV:Z]1?l0000=ogZ7[@;o00004ooKWM<2o`0000_odJgS1Ol0
0?l:om6]h`;o00004onIWj03o`0001_o][bi0_l0000;oib[[0?o00008?oKe>d2o`0001Oo^kgC0ol0
000Soj>nc@?o0000ROooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2l
ooooo`?o00007_no`J@3o`0000;oVlRI0ol0000?onGIk`?o00006_o8ZmX4o`0000koV:Z]0ol0000?
ogZ7[@?o00004_oKWM<2o`0000_odJgS1Ol00?l:om6]h`?o00004_nIWj02o`0001co][bi0ol00009
oib[[0?o00008OoKe>d2o`0001So^kgC0_l0000Toj>nc@;o0000ROooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2kooooo`?o00007ono`J@2o`0000CoVlRI0ol0000<onGI
k`Co00006Oo8ZmX7o`0000_oV:Z]1?l0000AogZ7[@;o00004_oKWM<2o`0000_odJgS1Ol00?l;om6]
h`;o00004OnIWj03o`0001go][bi0ol00006oib[[0Co00008OoKe>d3o`0001So^kgC0_l0000Toj>n
c@?o0000R?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2jooooo`?o
00007ono`J@3o`0000GoVlRI1?l00009onGIk`Co00002oo8ZmX3o`00o`_ob:_J1?l00002omW:e0?o
00002OnHZZd4o`0000[oNXN]0ol00?l5ogZ7[@?o00004OoKWM<2o`0000codJgS0ol00?l<om6]h`;o
00004OnIWj02o`0000ko][bi0ol00?l>okJl^@?o00001?nLZj`4o`0002;ofmC]0_l0000Iok^md`?o
00004?nS_/d3o`00oa7oXkk=0ol00027ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0;Wooooo0ol0000Ooko1Y0?o00001onKb9T4o`0000OoiMW_0ol0000<olR[fPGo003o
2?o8ZmX4o`0000GofL[D0ol00007oiRZ[@?o00002omjQjd5o`00o`GoNXN]0_l0000Aom^Md`;o0000
6ooA[N<3o`0000ooVInP0ol0000=okJl^@Go003o3_nf_;T3o`0000;oW:^/0ol0000Tom_Dk@;o0000
6_nk_M<2o`0000ooXkk=1Ol00?lAoj>nc@;o0000Qoooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2hooooo`?o00008?no`J@2o`0000[oVlRI0ol00004onGIk`Co00003Oo8
ZmX5o`00o`Oob:_J1?l00007omW:e0?o00001?nHZZd4o`0000coNXN]1Ol00?l5ogZ7[@?o00004?oK
WM<2o`0001codJgS0_l0000?oiVOX0;o00003_nf_;T5o`00o`oo][bi1_l0000Uom_Dk@;o00006_nk
_M<3o`0000koXkk=1Ol00?lAoj>nc@?o0000Q_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2gooooo`?o00008?no`J@3o`0000_oVlRI0ol00002onGIk`Co00003_o8ZmX5
o`00o`Gob:_J1?l0000:omW:e0?o00000_nHZZd4o`0000goNXN]1Ol00?l6ogZ7[@;o00004?oKWM<2
o`0001codJgS0ol0000=oiVOX0?o00003_nf_;T5o`00oa3o][bi1?l0000Vom_Dk@;o00006onk_M<2
o`0000koXkk=1Ol00?lBoj>nc@;o0000Q_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2_ooooo`Ko000000Coooooo`000?l0003o00008?no`J@3o`0000goVlRI1_l0000A
olR[fP?o003o1Oo8ZmX4o`0000cofL[D1_l0000@ogZ7[@?o003o1omjQjd3o`0000kofigC0ol0000M
om6]h`;o00003OnIWj02o`00013o][bi0ol00?lBokJl^@;o00005?oKe>d3o`00o`oofmC]0ol0000K
ok^md`;o00003onS_/d3o`00oa?oXkk=0ol00025ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0:gooooo2ol0000Qoko1Y0;o00003onKb9T4o`0001Sob:_J1?l0000?omW:
e0Co00007?mjQjd2o`0000kofigC0_l0000Nom6]h`?o00002onIWj03o`0002Go][bi0_l0000Com_D
k@Go003o3_oKe>d2o`0001co^kgC0ol0000Uoj>nc@;o0000QOooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`2/ooooo`Co00001?nXe:03o`00027o_l6T0ol0000@oi_8V@;o
00006?o8ZmX4o`00017ofL[D0_l0000MogZ7[@?o00003OoKWM<2o`0001oodJgS0_l0000:oiVOX0?o
00009_nf_;T2o`0001?ofmC]1Ol00?l>om_Dk@;o00007Onk_M<2o`0002GoXkk=2Ol0001nooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:[ooooo1?l00007ojSDX0?o0000
5_no`J@3o`00o`Ko_l6T0ol0000Aoi_8V@?o00005Oo8ZmX4o`0001?ofL[D0ol0000MogZ7[@;o0000
3OoKWM<2o`0001oodJgS0ol00009oiVOX0;o00009onf_;T2o`0001?ofmC]1Ol00?l>om_Dk@;o0000
7Onk_M<3o`0002GoXkk=2_l0001looooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo0:Sooooo1Ol00009ojSDX0?o00005?no`J@5o`00o`Go_l6T0_l0000Coi_8V@;o00005?o8
ZmX4o`0001GofL[D0_l0000MogZ7[@?o00003?oKWM<2o`00023odJgS0_l00007oiVOX0Co00009onf
_;T2o`0001CofmC]0ol00?l?om_Dk@;o00007_nk_M<2o`0002CoXkk=0ol00005ohN@]0Go0000N_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Vooooo`Go00003?nXe:02
o`0001Co_l6T1Ol00?l4oko1Y0?o00004onKb9T2o`0001?ob:_J0ol0000GomW:e0;o00007_mjQjd2
o`0000cofigC0_l0000Pom6]h`?o00000onIWj09o`0002Go][bi0_l0000Uom_Dk@?o00007_nk_M<2
o`0002?oXkk=0ol00008ohN@]0Go0000N?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2Tooooo`Go00003_nXe:03o`0001?o_l6T1Ol00?l3oko1Y0?o00005?nKb9T3o`00
013ob:_J1?l0000HomW:e0Ko00006_mjQjd3o`0000_ofigC0_l0000Qom6]h`Wo00000_oD[]P6o`00
02;o][bi0_l0000Uom_Dk@;o00007onk_M<3o`00027oXkk=0ol0000;ohN@]0Go0000M_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Sooooo`Co00004OnXe:03o`0001?o
_l6T0ol00?l4oko1Y0;o00005_nKb9T2o`0000oob:_J1?l00005omW:e0?o003o4_oIb]@;o`0001Go
NXN]0_l0000:om^Md`?o00008OoA[N<6o`0000Ooe:kH1_l0000OokJl^@?o00009OoKe>d2o`0000oo
^kgC0ol00?l>ok^md`;o00008OnS_/d2o`0000koQi2d1Ol0001dooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo0:7ooooo1?l0000DojSDX0;o00006Ono`J@3o`0001KoVlRI
0ol0000<olR[fPCo00001_oIb]@5o`00oa3ofL[D0ol00002ooKVb0go00003omjQjd3o`0000WofigC
0_l0000Som6]h`;o00003OoD[]P5o`0001_o][bi1_l0000Tom_Dk@;o00003_nk_M<5o`00o`go^kgC
0ol0000Ooj>nc@?o00004?n7T;@5o`0007;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0T_oooolBo`0001GoZ=BP0ol0000Hoko1Y0;o00006?nKb9T2o`0000_ob:_J1?l0
0007omW:e0Go003o4?oIb]@2o`0000Wom^K83?l0000;ogZ7[@;o00002OoKWM<2o`0002;odJgS0ol0
000?omB^f0Ko00005_nf_;T5o`000004oiNmYol0003o0000o`0002?ofmC]0_l0000>ok^md`Go003o
3_nk_M<2o`0001koXkk=0ol0000CohN@]0Go0000L?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2Aoooooa7o00006?nXe:03o`0001Ko_l6T0ol0000Hoi_8V@;o00002Oo8
ZmX4o`0000WofL[D1Ol00?l@omW:e0;o00003oofi/P<o`0000GoNXN]0ol00006om^Md`Go00008?oA
[N<3o`0001;oe:kH1_l0000BokJl^@Go00001?nG_JL3o`00027ofmC]0ol0000>ok^md`Go003o3_nk
_M<2o`0001koXkk=0_l0000FohN@]0Go0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2@ooooo`?o00003On/_Xh2o`0001WoZ=BP0_l0000Eoko1Y0?o00001?nKb9T3
o`00oa;oVlRI0ol00007olR[fPCo00002ooIb]@3o`00oa3ofL[D0ol0000DooKVb0oo000000?ofigC
o`000?l000002ol0000Lom6]h`?o00005_oD[]P5o`0000go][bi1_l00007oiNmY`?o00008?oKe>d2
o`00013o^kgC0ol00?l?ok^md`?o00007?nS_/d3o`0001SoQi2d1?l0001]ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08oooooo0ol0000>ojbnSP;o00006OnXe:03o`00
01Co_l6T0_l00004oi_8V@Go003o4_nKb9T2o`0000Gob:_J1?l0000PomW:e0;o00006oofi/P@o`00
00?ogl7J1ol0000Iom6]h`;o00006OoD[]P5o`0000Wo][bi1_l0000:oiNmY`?o00007ooKe>d2o`00
02?o^kgC0_l0000Koj>nc@?o00006on7T;@2o`0006gooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0S_ooool3o`0000oo[;j>0ol0000IojSDX0;o00004ono`J@3o`0000Co
VlRI1Ol00?lBoi_8V@?o00000oo8ZmX4o`00027ofL[D0_l0000QooKVb0Go00002ooO`MX6o`0001Ko
dJgS0ol0000KomB^f0Ko00001?nf_;T5o`0000koUkfW0ol0000Nom_Dk@;o00008onk_M<3o`0001Go
Xkk=1ol0000LohN@]0?o0000K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2=ooooo`?o00004On/_Xh2o`0001WoZ=BP0ol0000Aoko1Y0?o00001OnKb9T5o`00oa?oVlRI
0_l000000oo8Zm[o0000o`000002o`0002;ofL[D0ol0000RooKVb0?o00003ooO`MX6o`0001;odJgS
0ol0000NomB^f0_o00004OnG_JL3o`0001gofmC]0_l0000Tok^md`;o00003?nS_/d?o`0001koQi2d
0ol0001[ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0ol0
000BojbnSP;o00006_nXe:03o`00013o_l6T0_l00007oi_8V@?o003o5?nKb9T6o`0002?ofL[D0_l0
000SooKVb0;o00004_oO`MX6o`0000oodJgS0ol0000RomB^f0Ko00005?nG_JL3o`0001_ofmC]0ol0
000Tok^md`;o00000onS_/dCo`0000?o[6n:0_l0000OohN@]0;o0000Joooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`?o00004on/_Xh2o`0001_oZ=BP0_l0000?
oko1Y0?o00007_nKb9T4o`0002GofL[D0_l0000SooKVb0;o00005OoO`MX6o`0000_odJgS0ol0000U
omB^f0;o00005onG_JL3o`0001[ofmC]0_l0000Uok^md`oo00003?n/KhX3o`0001koQi2d0ol0001Z
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08[ooooo0ol0000Dojbn
SP;o00006onXe:03o`0000go_l6T0ol0000Poi_8V@;o00009OoIb]@3o`0002;om^K80ol0000Gomo1
fPOo00002?oA[N<2o`0002Koe:kH0_l0000HoiNmY`?o00006OoKe>d2o`0002Ko^kgC1Ol0000Foja_
RP;o00007on7T;@3o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo0ol00029ooooo`?o
00005On/_Xh3o`0001_oZ=BP0ol0000<oko1Y0;o00008?nKb9T3o`0002GofL[D0_l0000SooKVb0;o
00006ooO`MX6o`0000GodJgS0ol0000VomB^f0;o00006OnG_JL3o`0001SofmC]0_l0000Uok^md`?o
00006On/KhX2o`00023oQi2d0_l0001Wooooo`?o00002_ooool001[ooooo00?o0000ooooooooool0
R?ooool3o`0001Oo[;j>0_l0000LojSDX0;o00002ono`J@3o`0001goVlRI1_l0000UomW:e0;o0000
4?ofi/P3o`00oa3om^K80_l0000Nomo1fPKo000000CodJgSo`000?l0003o00009_oD[]P3o`0001[o
UkfW0ol0000Gom_Dk@;o00009?nk_M<3o`0001[o[6n:0_l0000PohN@]0?o0000J?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`27ooooo`?o00006?n/_Xh2o`0001coZ=BP
0ol00009oko1Y0?o00006onKb9T:o`0002?ofL[D0ol0000?ooKVb0Go003o3_ofi/P3o`00023ogl7J
1ol0000WomB^f0;o00007?nG_JL3o`0001GofmC]0ol0000Pok^md`Ko00006on/KhX2o`00027oQi2d
0ol0001Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Kooooo0ol0
000IojbnSP;o00007OnXe:05o`0000Ko_l6T0_l0000Ioi_8V@Oo00001?oOXmT3o`0002;ofL[D0_l0
000@ooKVb0Go003o3_ofi/P2o`0002Cogl7J1?l0000WomB^f0;o00007OnG_JLIo`0001[o^kgC3?l0
000Loja_RP?o00008On7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0QOooool3o`0001[o[;j>0_l0000NojSDX0So000000Co_l6To`000?l0003o00005_nK
b9T7o`0000Sogj?I0_l0000RomW:e0;o00004?ofi/P5o`00o`gom^K80ol0000Somo1fPKo00009_oD
[]P2o`0001koUkfW6Ol0000Bok^md`oo00000_n3WH`2o`0001go[6n:0_l0000QohN@]0;o0000Iooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00006on/_Xh2
o`0000_oZ=BP0ol00?l?ojSDX0?o000000?oTZ:Bo`000?l000001_l0000Doi_8V@Oo00002ooOXmT3
o`00023ofL[D0ol0000AooKVb0?o003o3_ofi/P2o`0002Cogl7J0_l00002okId/P?o00005ooD[]P3
o`00o`_oe:kH0_l0000MoiNmY`?o00005OnTSjL3o`0000[o^kgC3ol00009oh>MS0;o00007On/KhX2
o`0000ooQi2d0ol00?l?ohN@]0;o0000Ioooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`25ooooo`;o00006on/_Xh3o`0000WoZ=BP1Ol00?l=ojSDX0?o00001_nBXY84o`00
017oVlRI1ol0000?omnSf@Co00007_oIb]@2o`0002?om^K80_l0000Somo1fP?o00000onfM;83o`00
01Goe:kH1Ol00?l:omB^f0;o00007OnG_JL2o`0001OoY8nW0ol00002ok^md`oo00004?n3WH`2o`00
01go[6n:0_l0000>ohN@]0Go003o3_n7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0QOooool2o`0001co[;j>0_l00009ojSDX0Go003o3?nXe:03o`0000Wo
TZ:B0ol0000=oi_8V@Oo00004ooOXmT5o`0001cofL[D0_l0000RooKVb0?o00008ooO`MX2o`0000Go
]WBb0ol0000DomB^f0Go003o2_oD[]P2o`0001goUkfW0_l0000HojB?Y`co00005on3WH`3o`0001co
[6n:0ol0000=ohN@]0Go003o3_n7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0QOooool2o`00017o[;j>0ol00?l8ojbnSP;o00002OnXe:05o`00o`_oZ=BP
0ol0000;oi:RTP?o00002OnKb9T7o`0001Gogj?I2?l0000IomW:e0?o00008_ofi/P2o`0002?ogl7J
0ol00006okId/P?o00004ooD[]P5o`00o`Woe:kH0ol0000;oiNmY`?o003o3_nG_JL3o`0001WoY8nW
1?l0000Ooh>MS0;o00007On/KhX2o`0000goQi2d1Ol00?l>ohN@]0;o0000Ioooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00004?n/_Xh5o`00o`Oo[;j>0_l0
000:ojSDX0?o003o2onXe:03o`0000goTZ:B0ol00005oi_8V@Oo00005ooOXmT3o`0000?o/>GF1Ol0
000GomW:e0;o00008oofi/P2o`0002?ogl7J0_l00008okId/P?o00004ooD[]P3o`00o`[oe:kH0_l0
000;oiNmY`Go003o3OnG_JL2o`0001[oY8nW0_l0000Qoh>MS0;o00007On/KhX2o`0000koQi2d0ol0
0?l?ohN@]0;o0000Ioooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25
ooooo`;o00004?n/_Xh5o`00o`Oo[;j>0_l0000HojSDX0;o00003onBXY83o`000003oi_8VOl0003o
000000Go00006_oOXmT2o`0000Ko/>GF1Ol0000EomW:e0;o00008_ofi/P3o`0002;ogl7J0ol00009
okId/P?o00007ooD[]P2o`0000_oUkfW1Ol00?l<oiNmY`?o00006_nTSjL2o`00027oPif<0_l0000M
oja_RP;o00008?n7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0QOooool2o`00013o[;j>1Ol00?l7ojbnSP?o00005_nXe:03o`00013oTZ:B1ol0000LomnS
f@?o00002?n`iMH5o`0001;ofL[D0ol0000RooKVb0;o00008ooO`MX2o`0000_o]WBb0ol0000NomB^
f0;o00002onG_JL5o`00o`coUkfW0_l0000KojB?Y`;o00008On3WH`2o`0001go[6n:0ol0000NohN@
]0?o0000Ioooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o
00004On/_Xh3o`00o`Wo[;j>0_l0000EojSDX0?o00004_nBXY83o`0001oogj?I0_l0000;ok3UePGo
00004?oIb]@2o`0002;om^K80ol0000>omo1fP?o003o4OoO`MX3o`0000co]WBb0ol0000MomB^f0;o
00003?nG_JL3o`00o`coUkfW0ol0000KojB?Y`;o00008On3WH`2o`0000ko[6n:0ol00?l=oja_RP;o
00007_n7T;@2o`0006Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
QOooool2o`0001go[;j>0_l0000DojSDX0?o00004onBXY82o`0001oogj?I0ol0000=ok3UePGo0000
3_oIb]@2o`0002;om^K80_l0000>omo1fPGo003o4?oO`MX2o`0000ko]WBb0ol0000LomB^f0;o0000
6onG_JL2o`0001coY8nW0ol0000Poh>MS0;o00003On/KhX5o`00o`co[6n:0_l0000NohN@]0;o0000
J?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00007On/
_Xh2o`0001?oZ=BP0ol0000Doi:RTP;o00007_oOXmT3o`00013o/>GF1Ol0000;omW:e0?o00008_of
i/P2o`0000kogl7J1Ol00?l?omo1fP?o00003onfM;83o`0001_oe:kH0_l0000KoiNmY`;o00007OnT
SjL2o`00023oPif<0_l0000=oja_RPGo003o3?n/KhX2o`0001koQi2d0_l0001Xooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000MojbnSP;o00004_nXe:03
o`0001GoTZ:B0ol0000MomnSf@;o00004on`iMH5o`0000WofL[D0_l0000RooKVb0?o00003_oO`MX5
o`00o`oogl7J0_l0000AokId/P?o00006OoD[]P3o`0001[oUkfW0ol0000MojB?Y`;o00008?n3WH`3
o`0000co[6n:1Ol00?l<oja_RP;o00007_n7T;@2o`0006Sooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0QOooool2o`0001go[;j>0ol0000AojSDX0;o00005onBXY82o`00
00kogj?I0ol00?l;omnSf@?o00005On`iMH5o`0000OofL[D0_l0000RooKVb0;o00004?oO`MX3o`00
o`oogl7J0ol0000BokId/P?o00006?oD[]P2o`0001_oUkfW0_l0000NojB?Y`;o00004On3WH`3o`00
o`goPif<0_l0000=oja_RP?o003o3On/KhX3o`0001goQi2d0_l0001Xooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000NojbnSP;o00004?nXe:03o`0001Oo
TZ:B0_l0000=omnSf@Go003o2_oOXmT2o`0001So/>GF1Ol00004omW:e0?o00008_ofi/P2o`0002;o
gl7J0_l0000DokId/P?o00005ooD[]P2o`0001[oUkfW0ol0000NojB?Y`;o00004?n3WH`5o`00o`co
Pif<0_l0000Noja_RP;o00007On7T;@2o`0006Sooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0QOooool2o`0001ko[;j>0_l0000?ojSDX0?o00006?nBXY82o`0000gogj?I
1Ol00?l9omnSf@?o00006_n`iMH5o`0000;ofL[D0_l0000QooKVb0Co00008OoO`MX3o`0001Go]WBb
0ol0000FomB^f0;o00006_nG_JL2o`0001ooY8nW0_l0000@oh>MS0Go003o3?n3WH`2o`0001ko[6n:
0_l0000MohN@]0;o0000J?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`25ooooo`Co00007?n/_Xh2o`0000koZ=BP0ol0000Ioi:RTP;o00003OoOXmT5o`00o`Sogj?I0ol0
000Mok3UePOo00007oofi/P7o`00023ogl7J0_l0000GokId/P?o00005OoD[]P2o`0001WoUkfW0ol0
000OojB?Y`;o00004?n3WH`5o`00o`coPif<0_l0000Noja_RP;o00006on7T;@5o`0006Oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Q?ooool8o`0001Wo[;j>0_l0000=
ojSDX0?o00002onBXY83o`00o`coTZ:B0_l0000>omnSf@?o003o2OoOXmT2o`00023o/>GF1Ol0000L
ooKVb0Ko00000_nJ/:44o`0001gogl7J0ol0000HokId/P?o00005?oD[]P2o`0001WoUkfW0_l0000=
ojB?Y`?o003o4?nTSjL2o`00017oPif<0ol00?l=oh>MS0;o00007_n/KhX3o`0001KoQi2d2_l0001V
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08?ooooo0ol00002oiS4
]@So00005On/_Xh2o`0000goZ=BP0_l0000;oi:RTPGo003o2onBXY82o`0001Wogj?I0ol0000Rok3U
eP;o00006oofi/P6o`0000GoV[2Q1?l0000Lomo1fP;o00006_nfM;83o`0001?oe:kH0_l0000IoiNm
Y`;o00003?nTSjL5o`00o`ooY8nW0_l0000Qoh>MS0;o00007on/KhX2o`0001;oQi2d2Ol00003onOX
j@?o0000IOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`?o
00001_nHa;D8o`0001;o[;j>0ol0000;ojSDX0?o00002onBXY85o`00o`_oTZ:B0ol0000HomnSf@;o
00008on`iMH3o`0001Som^K81Ol0000:oiZ`X@Co00006OoO`MX3o`0001_o]WBb0ol0000AomB^f0?o
00006?nG_JL3o`0000coY8nW1Ol00?l?ojB?Y`;o00008On3WH`2o`0001oo[6n:0_l0000=ohN@]0[o
00002?oWj>T3o`0006Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
POooool3o`0000_oV<Be1ol0000@ojbnSP;o00002_nXe:03o`0000coTZ:B1Ol00?l<oi:RTP;o0000
5ooOXmT3o`0002Co/>GF0_l0000EooKVb0Ko00003OnJ/:44o`0001Sogl7J0_l0000MokId/P?o0000
4?oD[]P2o`0001WoUkfW0_l0000=ojB?Y`Go003o3onTSjL2o`00027oPif<0ol0000Noja_RP;o0000
2On7T;@:o`0000goinSY0ol0001Sooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo083ooooo0ol0000?oiS4]@So00003?n/_Xh2o`0000WoZ=BP0ol0000>oi:RTP?o003o3OnB
XY82o`0001Kogj?I0ol0000Uok3UeP?o00004_ofi/P6o`00017oV[2Q1?l0000Eomo1fP?o00007_nf
M;83o`0000ooe:kH0_l0000HoiNmY`?o00003_nTSjL3o`00oa3oY8nW0ol0000Qoh>MS0;o00007_n/
KhX2o`0000GoQi2d2Ol0000ConOXj@?o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1oooooo`?o00004onHa;D8o`0000Wo[;j>0_l00008ojSDX0?o00007onBXY82
o`0001Kogj?I0_l0000Wok3UeP;o00004?ofi/P5o`0001GoV[2Q1?l0000Domo1fP;o00008?nfM;83
o`0000koe:kH0_l0000HoiNmY`;o00008onTSjL2o`00027oPif<0_l0000Noja_RPco00006?oWj>T2
o`0006;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool3o`00
01SoV<Be2?l00005ojbnSP;o00001onXe:03o`00023oTZ:B0_l0000EomnSf@?o00009on`iMH3o`00
00com^K81_l0000IoiZ`X@Co00004OoO`MX3o`00027o]WBb0ol0000=omB^f0;o00005onG_JL3o`00
02?oY8nW0_l0000Qoh>MS0;o00007on/KhX7o`0001coinSY0_l0001Rooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0ol0000LoiS4]@So00000_n/_Xh3o`0000Ko
Z=BP0_l0000Qoi:RTP;o00005?oOXmT3o`0002Wo/>GF0_l0000:ooKVb0Ko00007?nJ/:44o`00013o
gl7J0_l0000SokId/P?o00003?oD[]P2o`0001OoUkfW0_l0000TojB?Y`;o00008On3WH`2o`0001oo
[6n:0ol0000PonOXj@;o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1looooo`?o00008OnHa;D9o`0000GoZ=BP0ol0000Qoi:RTP;o00005?oOXmT2o`0000[o/>GF
0ol00?lMok3UeP;o00002?ofi/P5o`00027oV[2Q1?l0000=omo1fP?o00004?nfM;83o`00oa7o]WBb
0ol0000;omB^f0;o00005onG_JL2o`0002?oY8nW1?l0000Poh>MS0;o00007_n/KhX3o`00027oinSY
0ol0001Qooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07_ooooo0ol0
000UoiS4]@Ko00001?nXe:03o`0002;oTZ:B0ol0000BomnSf@?o00002On`iMH5o`00oaco/>GF0ol0
0004ooKVb0Ko00009?nJ/:44o`0000cogl7J0_l0000@okId/PGo003o4OnfM;83o`0000Woe:kH0ol0
000@oiNmY`Wo00008_nTSjL6o`0001ooPif<0_l0000Moja_RP?o00008ooWj>T2o`00067ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Noooool2o`0002WoV<Be1?l00002
ojSDX0?o00009?nBXY82o`0001;ogj?I0_l0000:ok3UePGo003o7On`iMH2o`0000;om^K81_l0000X
oiZ`X@Co00002OoO`MX3o`00013o]WBb1Ol00?lBokId/P?o00002?oD[]P2o`0000CoUkfW5ol0000P
ojB?Y`?o00000_n[W;P4o`0001goPif<0_l0000Moja_RP;o00009?oWj>T2o`00067ooooo00?o0000
ooooooooool02?ooool000Sooooo0ol00003ooooo`;o00002_ooool00ol0003oooooooooo`1koooo
o`;o0000:onHa;D6o`0002GoTZ:B0_l0000AomnSf@?o00002_n`iMH5o`00oaco/>GF2?l0000/oiZ`
X@Co00002?oO`MX2o`00017o]WBb1Ol00?lCokId/P?o00001_oD[]PEo`0000OoWZB?0ol0000MojB?
Y`Co00001?n[W;P5o`0001_oPif<0ol0000Hoja_RPKo00009?oWj>T2o`00067ooooo00?o0000oooo
ooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Noooool2o`0002coV<Be1?l0000Voi:RTP;o00004?oOXmT3o`00
00co/>GF0ol00?lJok3UePWo0000<?nJ/:44o`0000Gogl7J0ol0000BokId/P?o003o5OnfM;83o`00
00Coe:kH2Ol0000EoijTS`?o00006onTSjL4o`0000OoZibh1?l0000Koh>MS0;o00004on/KhX:o`00
02GoinSY0_l0001Qooooo`03o`000?oooooooooo00Sooooo0006ooooo`Go00000_ooool01?l0003o
ooooooooool00009ooooo`Go0000NOooool2o`0002_oV<Be1_l0000Uoi:RTP;o00004?oOXmT2o`00
02Oo/>GF3_l0000_oiZ`X@Co00001?oO`MX2o`0002co]WBb0ol00002omB^f0?o00007OnNY8l3o`00
01SoY8nW1?l0000;oj^L^0Co00006On3WH`2o`0000ko[6n:2ol00002ol>QY0?o00009?oWj>T2o`00
05gooooo1Ol0000:ooooo`001_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0Noooool2o`0002[oV<Be0ol000000om_VW[o0000o`000004
o`0002;oTZ:B0_l0000?omnSf@?o00009?n`iMH7o`0000?oZkJO0_l00002onO[g`Co0000<?nJ/:44
o`000004omo1f_l0003o0000o`0002go]WBb1_l0000OoijTS`?o00005_nTSjL4o`0000goZibh1Ol0
000Aoh>MS0Wo00002?n/KhX;o`0000So`j6T0_l0000TonOXj@?o0000H?ooool00ol0003ooooooooo
o`08ooooo`001oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0Noooool2o`0001?oV<Be0ol00?lCoiS4]@?o00000_m_VWX9o`0001ooTZ:B0_l0
000?omnSf@;o00008_n`iMH7o`0000GoZkJO0ol00002onO[g`Go00006onJ/:43o`00oa;oV[2Q1_l0
000_okId/PCo00008OnNY8l3o`0001CoY8nW0ol0000Aoj^L^0Co00001On3WH`Eo`0000;o[6n:2ol0
000=ol>QY0?o00004_oWj>T3o`00o`ooinSY0_l0001Pooooo`03o`000?oooooooooo00Sooooo0008
ooooo`;o00000oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo07_ooooo0_l0
000BoiS4]@Go003o4?nHa;D4o`0000?oKiYj0_l00003okBk`0Oo00007?nBXY83o`0000gogj?I0ol0
000Ook3UePOo00001on[]Yl3o`0000?oin_O0_l000001?o?c;oo0000o`000?l0000IoiZ`X@Go003o
4onJ/:44o`00033o]WBb0_l0000SoijTS`Co00004?nTSjL4o`0001CoZibh4ol00007ok^NU`[o0000
4oo3XJ@2o`00017oinSY1Ol00?l>onOXj@;o0000H?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`02ooooo`;o00002_ooool00ol0003oooooooooo`1kooooo`;o00004_nH
a;D5o`00o`ooV<Be1?l00004ofnJNP;o00001_nd^l07o`0001[oTZ:B0_l0000<omnSf@?o00007On`
iMH7o`0000[oZkJO0_l00004onO[g`;o00000_o?c;l3o`0001SoV[2Q1Ol00?lDoiZ`X@;o0000<?nf
M;83o`0002CoWZB?1?l0000>ojB?Y`Co00005_n[W;P7o`0001?o^ijG1?l0000Hol>QY0?o00004?oW
j>T5o`00o`koinSY0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo07_ooooo0_l0000BoiS4]@Go003o3_nHa;D3o`0000KoKiYj0_l00009okBk`0Oo00005onBXY82
o`0000cogj?I0_l0000Kok3UePOo00003?n[]Yl3o`0000Coin_O0_l00003olo<_`Co00005_nJ/:45
o`00oaCoV[2Q0_l0000`okId/P;o00009onNY8l3o`0000coY8nW0ol0000Hoj^L^0;o00006?nkWYL2
o`0001_o`j6T0_l0000@onOXj@Go003o3_oWj>T2o`00063ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0N_ooool3o`0001?oV<Be0ol00?l>oiS4]@?o00001om_VWX2o`00
00co];_01_l0000Doi:RTPGo00002OoOXmT3o`0001So/>GF1ol0000?oj^fW`;o00001OoWjml2o`00
00Coclbo1?l0000FoiZ`X@?o003o5OnJ/:43o`0002oo]WBb0_l0000XoijTS`?o00002OnTSjL4o`00
01WoZibh0_l0000Hok^NU`;o00006oo3XJ@3o`00013oinSY0ol00?l?onOXj@?o0000Goooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1jooooo`;o00009?nHa;D3o`0000So
KiYj0_l0000?okBk`0Ko00003onBXY8;o`0000Gogj?I0_l0000Fok3UePOo00004On[]Yl3o`0000Go
in_O0_l00006olo<_`?o0000;_nJ/:42o`0002ko]WBb0ol0000YoijTS`?o00001onTSjL4o`0001Wo
Zibh0ol0000Hok^NU`;o00007?o3XJ@2o`0002?oinSY0_l0001Oooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo07[ooooo0_l0000RoiS4]@Co00002Om_VWX2o`00017o];_0
1ol0000:oi:RTPGo00000ooY/n@8o`000004omnSfOl0003o0000o`0001?o/>GF1ol0000Coj^fW`?o
00001_oWjml2o`0000Ooclbo0ol0000]oiZ`X@;o0000;_nfM;82o`0002_oWZB?0ol00004ojB?Y`Co
00006on[W;P2o`0001Wo^ijG0_l0000Lol>QY0?o00008_oWj>T2o`0005oooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0N_ooool2o`00027oV<Be1?l0000:ofnJNP;o0000
5?nd^l07o`0000GoTZ:B1Ol00009onVci0Oo00004On`iMH7o`0001KoZkJO0_l00007onO[g`;o0000
2?o?c;l3o`0002coV[2Q0_l0000^okId/P;o0000;?nNY8l3o`0000;oY8nW1?l0000Loj^L^0;o0000
6OnkWYL2o`0001go`j6T0_l0000RonOXj@;o0000Goooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1jooooo`;o00008?nHa;D3o`0000coKiYj0_l0000GokBk`0co00003_oY
/n@5o`0000go/>GF1ol0000Hoj^fW`?o00001ooWjml2o`0000Woclbo0ol0000[oiZ`X@;o0000;Onf
M;83o`0002goWZB?1_l0000Noj^L^0;o00006OnkWYL2o`0001go`j6T0ol0000QonOXj@;o0000Gooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1jooooo`;o00007onHa;D3
o`0000goKiYj0_l0000JokBk`0Oo00004ooY/n@3o`0000Wo/>GF1ol0000Koj^fW`;o00002?oWjml2
o`0000[oclbo1?l0000YoiZ`X@?o0000;?nfM;82o`0002ooWZB?1?l0000Ooj^L^0;o00006OnkWYL2
o`0001ko`j6T0_l0000QonOXj@;o0000Goooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1jooooo`;o00007OnHa;D4o`0000koKiYj0_l0000MokBk`0;o00005_oY/n@3o`00
00Go/>GF1ol0000Moj^fW`?o00002?oWjml2o`0000_oclbo1?l0000YoiZ`X@;o0000;?nfM;82o`00
033oWZB?0_l0000Poj^L^0;o00006OnkWYL2o`0001ko`j6T0ol0000PonOXj@?o0000G_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1jooooo`;o00007?nHa;D4o`0000oo
KiYj0_l0000MokBk`0;o00005ooY/n@3o`000003ok3Ue_l0003o000000Go00007on[]Yl3o`0000Wo
in_O0_l0000=olo<_`?o00009onJ/:44o`0002[o]WBb0ol0000`oijTS`;o00007on[W;P3o`0001Wo
^ijG0_l0000Ool>QY0;o00008OoWj>T2o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0NOooool4o`0001[oV<Be0ol0000AofnJNP;o00007?nd^l03o`0001SojK?T
1ol0000Roj^fW`;o00002_oWjml2o`0000koclbo0ol0000ToiZ`X@Oo0000:OnfM;82o`0001_oWZB?
0ol00?lCoijTS`;o00004on[W;P3o`00o`WoZibh0_l0000Jok^NU`;o00007oo3XJ@3o`00023oinSY
0_l0001Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07Oooooo1ol0
000HoiS4]@?o00004_m_VWX2o`0001co];_00_l0000JonVci0?o00009?n[]Yl3o`0000[oin_O0_l0
000?olo<_`?o00008OnJ/:45o`0000;oUHfL1?l0000WokId/P;o00006_nNY8l5o`00oa;oWZB?0_l0
000Boj^L^0Go003o2?n[W;P2o`0001[o^ijG0_l0000Pol>QY0;o00008?oWj>T2o`0005kooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0MOooool5o`0000;o/Jfc1?l0000D
oiS4]@Co00004om_VWX2o`0001co];_00_l0000JonVci0;o00009On[]Yl2o`0000_oin_O0_l0000@
olo<_`Co00007OnJ/:45o`0000GoUHfL1?l0000UokId/P?o00006_nNY8l5o`00oa;oWZB?0_l0000B
oj^L^0Go003o2?n[W;P2o`0001[o^ijG0_l0000Pol>QY0;o00007ooWj>T3o`0005kooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Loooool5o`0000Go/Jfc1?l0000BoiS4
]@Co00004om_VWX3o`0001co];_00_l0000JonVci0?o00008on[]Yl3o`0000_oin_O0_l0000Aolo<
_`Co00006onJ/:44o`0000WoUHfL1?l0000SokId/P;o00006onNY8l5o`00oa;oWZB?0_l0000Boj^L
^0Go003o2?n[W;P2o`0001[o^ijG0_l0000Pol>QY0?o00007_oWj>T2o`0005oooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0LOooool5o`0000Wo/Jfc1?l0000?oiS4]@?o
00005?m_VWX4o`0001_o];_00ol0000KonVci0;o00005?n[]Yl3o`00o`_oZkJO0ol0000<onO[g`;o
00004oo?c;l3o`0001SoV[2Q1?l0000<oiF=W0Co00008OnfM;83o`0001coWZB?0ol00?lCoijTS`;o
00004on[W;P3o`00o`WoZibh0_l00009ok^NU`?o003o3_nkWYL2o`0000oo`j6T0ol00?l?ol>QY0;o
00007_oWj>T2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
Koooool5o`0000co/Jfc1?l0000=oiS4]@?o00005?m_VWX6o`0001[o];_00_l0000LonVci0;o0000
4on[]Yl5o`00o`[oZkJO0_l0000=onO[g`;o00005?o?c;l3o`0001GoV[2Q1Ol0000?oiF=W0Co0000
7onfM;82o`0003?oWZB?0_l0000Noj^L^0?o00002?nkWYL5o`00o`go^ijG0_l0000>ol>QY0Go003o
3_o3XJ@3o`0001coinSY0ol0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo06kooooo1?l0000@ok6]/`?o00002onHa;D3o`0001CoKiYj0ol00002ol>Yc@;o00006_nd
^l02o`0001cojK?T0ol0000Boj^fW`Go003o2On[]Yl3o`0000goin_O0_l0000Eolo<_`?o00004_nJ
/:45o`0001;oUHfL1?l0000NokId/P;o0000<onNY8l2o`0001koZibh0_l00009ok^NU`Go003o3Onk
WYL2o`0000ko`j6T1Ol00?l?ol>QY0;o00007?oWj>T2o`00063ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0K_ooool2o`0001?o/Jfc1?l00007oiS4]@Co00005?m_VWX3
o`0000?o`jW=0_l0000JokBk`0;o00007OoY/n@2o`0001;oZkJO1Ol00?l9oj^fW`;o00003_oWjml2
o`0001Koclbo0ol0000?oiZ`X@Go00005_nESI`4o`0001_o]WBb0ol0000coijTS`;o00007_n[W;P2
o`0000Wo^ijG1Ol00?l=ok^NU`;o00003_o3XJ@5o`00o`oo`j6T0ol0000KonOXj@;o0000H?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1]ooooo`?o00005?na[K<4o`00
00GoV<Be1?l0000>ofnJNP?o003o0om_VWX3o`0000Co`jW=0_l00008okBk`0?o003o3_nd^l03o`00
01gojK?T0_l0000Coj^fW`?o003o2On[]Yl3o`0000koin_O0_l0000Golo<_`Co00002onJ/:45o`00
01WoUHfL1?l0000JokId/P;o0000=?nNY8l2o`0001koZibh0_l0000:ok^NU`?o003o3_nkWYL2o`00
00oo`j6T0ol00?lAol>QY0;o00006_oWj>T3o`00063ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0KOooool2o`0001Oo/Jfc1?l00002oiS4]@?o00003om_VWX5o`00o`04
ofnJN_l0003o0000o`0000Go`jW=0_l00007okBk`0Go003o3Ond^l02o`0001kojK?T0_l0000Noj^f
W`?o00003ooWjml2o`0001Soclbo1?l00008oiZ`X@Go00007OnESI`4o`0001So]WBb0_l0000doijT
S`;o00007_n[W;P2o`0001_o^ijG0_l0000Sol>QY0?o00005ooWj>T4o`00067ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0K?ooool3o`0001So/Jfc1ol0000@ofnJNPGo
003o0ol00006ol>Yc@?o00001_nd^l05o`00o`go];_00_l0000NonVci0?o00007On[]Yl2o`00013o
in_O0_l0000Jolo<_`?o00001_nJ/:44o`00023oUHfL1Ol0000EokId/P?o0000=?nNY8l4o`0001co
Zibh0_l0000Kok^NU`;o00009?o3XJ@2o`0001?oinSY2?l0001Qooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06cooooo0_l0000Kok6]/`Co00004Om_VWX8o`00o`Oo`jW=
0_l00006okBk`0Go003o3Ond^l02o`0001oojK?T0_l0000Loj^fW`?o00004?oWjml2o`0001_oclbo
0ol00003oiZ`X@Co00009?nESI`4o`0001Co]WBb0_l0000eoijTS`Oo00006?n[W;P3o`0001_o^ijG
0_l0000Tol>QY0?o00003_oWj>T9o`000004ohjFYOl0003o0000o`00063ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0K?ooool2o`0001co/Jfc0_l0000CofnJNPSo003o
1_o3ZLd2o`0000Oo];_00ol00?l=okBk`0?o00007ooY/n@2o`0001coZkJO0_l0000AonO[g`;o0000
7?o?c;l8o`0002OoUHfL1?l0000BokId/P;o0000=?nNY8l3o`000003oh>UY_l0003o000000Go0000
5On[W;P2o`0001co^ijG0_l0000Uol>QY0;o00002_oWj>T9o`0000KoSYJU0ol0001Oooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06_ooooo0ol0000Lok6]/`?o00004om_
VWX2o`0000Go003o1_o3ZLd2o`0001Oo];_00_l0000PonVci0?o00006_n[]Yl3o`00017oin_O0_l0
000Molo<_`Go0000:_nESI`4o`00013o]WBb0ol0000coijTS`?o00001On3YJH8o`00017oZibh0_l0
000Lok^NU`;o00009Oo3XJ@3o`0000GoinSY2Ol0000;ohjFY@?o0000G_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o00007_na[K<2o`0001;oKiYj0ol00005
o`00o`Ko`jW=0_l0000GokBk`0;o00008?oY/n@3o`0001WoZkJO0ol0000BonO[g`;o00007_o?c;l2
o`0002koUHfL1?l0000>okId/P;o0000<onNY8l3o`0000WoPjFV2?l0000>oj^L^0;o00007?nkWYL2
o`0002Ko`j6T0_l000000ooWj>Wo0000o`000007o`00013oSYJU0ol0001Mooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo06[ooooo0ol0000Nok6]/`;o00004Om_VWX3o`00
00;o`jW=0ol00?l7ol>Yc@?o00005Ond^l03o`0000gojK?T0ol00?l?onVci0Go00006?n[]Yl2o`00
00Woin_O0ol00?l7onO[g`;o00001oo?c;l3o`00oaCoclbo0_l0000_oiF=W0Co00003OnfM;82o`00
03?oWZB?0_l0000>oh>UYPOo00002on[W;P2o`0001co^ijG0_l0000Vol>QY0So00005On>UZD3o`00
05cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0J_ooool2o`0001oo
/Jfc0ol0000?ofnJNP?o00003_o3ZLd2o`0001Go];_00_l0000=onVci0Go003o3OoY/n@3o`000004
oj[_Z?l0003o0000o`0001KoZkJO0ol00008onO[g`Go003o1_oWjml2o`0000Koclbo1Ol00?lColo<
_`;o0000<OnESI`4o`0000Wo]WBb1Ol0000aoijTS`?o00004On3YJH8o`0000OoZibh0_l0000Lok^N
U`;o00009oo3XJ@3o`0001[oSYJU0ol0001Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06Wooooo0ol0000Pok6]/`;o00003_m_VWX3o`0000oo`jW=0_l0000EokBk`0;o
00003OoY/n@5o`00o`_ojK?T1?l00003oj[_Z0?o00005On[]Yl2o`0000Woin_O1Ol00?l6onO[g`;o
00001_o?c;l5o`00oa;oclbo0ol0000boiF=W0Co00001_nfM;8:o`0002goWZB?0ol0000Eoh>UYPSo
00000on[W;P3o`0001co^ijG0_l0000Vol>QY0?o00007?n>UZD3o`0005[ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0JOooool2o`00027o/Jfc0ol0000<ofnJNP?o0000
4?o3ZLd2o`0001Go];_00_l0000=onVci0Go003o2_oY/n@4o`0000GoZ^nX0ol0000Coj^fW`?o0000
2OoWjml5o`00o`Koin_O0_l00006olo<_`Go003o4_o?c;l2o`0003GoUHfL1?l00003okId/PCo0000
0ooLnnD7o`0002WoWZB?0ol0000Joh>UYPWo00007OnkWYL2o`0002Go`j6T0ol0000NohjFY@?o0000
FOooool00ol0003oooooooooo`08ooooo`006_ooool3o`0006Sooooo0ol0000Rok6]/`;o00002om_
VWX3o`00017o`jW=0_l0000DokBk`0?o00003_oY/n@3o`00o`[ojK?T0ol00008oj[_Z0?o00004On[
]Yl3o`0000_oin_O0ol00?l7onO[g`;o00001oo?c;l3o`00oa?oclbo0_l0000foiF=W0So00002?oL
nnD7o`0002KoWZB?0_l0000Noh>UYPKo00007OnkWYL2o`0002Go`j6T0_l0000PohjFY@?o0000E_oo
ool3o`0000[ooooo000Jooooo`03o`000?oooooooooo06Sooooo0_l0000Sok6]/`?o00002Om_VWX3
o`0001;o`jW=0ol0000CokBk`0;o00006ooY/n@3o`0000[oZ^nX0ol0000@oj^fW`;o00005_oWjml2
o`0001goclbo0_l0000hoiF=W0Go00003?oLnnD7o`0002;oWZB?0ol0000Qoh>UYP?o00007?nkWYL5
o`00027o`j6T1?l0000QohjFY@?o0000Eoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1Wooooo`?o00009?na[K<2o`0000SoKiYj0ol0000Dol>Yc@;o00004ond^l02o`00
01WojK?T1?l0000<oj[_Z0?o00003_n[]Yl3o`0001Koin_O0_l0000Molo<_`;o0000>OnESI`2o`00
017og?_U1ol0000NoijTS`?o00008on3YJH3o`0001[o^ijG2ol0000Iol>QY0Ko00008on>UZD3o`00
05Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ioooool2o`0002Go
/Jfc0_l00007ofnJNP?o00005Oo3ZLd2o`0001?o];_00_l0000HonVci0Co00003_nZkjP3o`0000go
ZkJO0_l0000GonO[g`;o00007?o?c;l3o`0003SoUHfL0ol0000Domcki@Oo00006_nNY8l3o`0002Go
PjFV0ol0000Hok^NU`?o00000ooKdJ<;o`00017o`j6T2_l0000SohjFY@;o0000E_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Wooooo`;o00004?na[K<3o`00oa;o/Jfc
1?l00004ofnJNP?o00005_o3ZLd2o`0001;o];_00ol0000GonVci0?o00004OnZkjP3o`0000_oZkJO
0ol0000GonO[g`;o00007?o?c;l2o`0001CoUHfL0ol00?lRoiF=W0;o00006?oLnnD7o`0001OoWZB?
0_l0000Woh>UYP?o00005OnkWYL4o`0000Wofm6S2ol00009ol>QY0Oo00001?ng[LT2o`0002?oSYJU
0_l0001Fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Kooooo0ol0
000?ok6]/`Go003o4?na[K<6o`0000;oKiYj0ol0000Gol>Yc@;o00004_nd^l02o`0001KojK?T1?l0
000Coj[_Z0?o00002On[]Yl3o`0001Soin_O0_l0000Lolo<_`;o00004onESI`5o`00ob7oUHfL0_l0
000Komcki@Oo00004onNY8l3o`0002SoPjFV2?l0000>ok^NU`Co00003ooKdJ<;o`000003ol>QY?l0
003o000000Go00001ong[LT3o`0002;oSYJU0_l0001Fooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo06Kooooo0_l0000@ok6]/`Go003o3ona[K<3o`0000;oUg6f1_l0000H
ol>Yc@?o00004Ond^l02o`0001GojK?T1?l0000Eoj[_Z0?o00002?n[]Yl2o`0001Woin_O0_l0000L
olo<_`;o00004onESI`5o`00ob3oUHfL0ol0000Nomcki@Oo00003onNY8l3o`0002[oPjFV4?l00004
ok^NU`?o00005_oKdJ<;o`0000_o]jg90_l0000RohjFY@?o0000EOooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1Uooooo`?o00004?na[K<5o`00o`go/Jfc1?l00004oiMa
]PCo00006_o3ZLd2o`00017o];_00_l0000DonVci0?o00006?nZkjP3o`0000KoZkJO0ol0000IonO[
g`;o00007?o?c;l2o`0001?oUHfL1Ol00?lPoiF=W0;o00008_oLnnD7o`0000_oWZB?0ol0000Zoh>U
YP?o00001?n2[[@@o`0001cofm6S0ol0000>okN]b@;o00008on>UZD2o`0005Gooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool2o`0001;o/Jfc0ol00?l=ok6]/`Co
00001_nGLKHPo`0000oo];_00ol0000ConVci0?o00006_nZkjP3o`0000GoZkJO0_l0000JonO[g`;o
00006oo?c;l3o`0001CoUHfL0ol00?lQoiF=W0;o00009OoLnnD7o`0000SoWZB?0_l0000Goh>UYP?o
003o4On3YJH2o`0000koPZjd1_l0000Nom_AX`;o00003_ng[LT3o`0002;oSYJU0_l0001Eooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Gooooo0_l0000Qok6]/`?o0000
2OnGLKHPo`0000ko];_00_l0000BonVci0Co00007?nZkjP3o`0000?oZkJO0ol0000JonO[g`;o0000
6oo?c;l2o`0003SoUHfL0ol0000Xomcki@Oo00001?nNY8l3o`0001KoPjFV1Ol00?l?oh>UYP?o0000
4_n2[[@2o`0001kofm6S0_l0000?okN]b@;o00008_n>UZD2o`0005Gooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0IOooool2o`00023o/Jfc0ol0000:oiMa]P;o00007?oK
gZ/4o`0000co];_00_l0000AonVci0Co00007_nZkjP3o`000004oj^fWol0003o0000o`0001_oin_O
0_l0000Iolo<_`Co0000>?nESI`2o`0002cog?_U2_l0000Goh>UYPGo003o3_n3YJH3o`0001?oPZjd
0_l0000Nom_AX`;o00003ong[LT3o`00027oSYJU0_l0001Eooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo06Gooooo0_l0000Nok6]/`Co00002onGLKH2o`0001gofmj[1?l0
000;okBk`0;o00004?oY/n@3o`00027oZ^nX1Ol0000LonO[g`;o00005Oo?c;l8o`0003SoUHfL0_l0
000_omcki@Ko00006?n3YJH5o`00o`koPjFV0_l0000Doh:^]0;o00007OoKdJ<3o`00013o]jg90_l0
000QohjFY@;o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1U
ooooo`;o00007Ona[K<4o`0000coUg6f0_l0000Oom_NZ`Co00002?nd^l03o`0000kojK?T1?l0000;
oj[_Z0?o003o5OnZkjP4o`0001coin_O0_l0000Aolo<_`Wo000000Co^jSLo`000?l0003o0000=_nE
SI`3o`0003;og?_U0_l0000Joh>UYP?o003o3_n3YJH3o`0001CoPZjd0ol0000Lom_AX`;o00004Ong
[LT3o`0000ooSYJU0ol00?l>ohjFY@?o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Uooooo`?o00006ona[K<3o`0000koUg6f0ol0000Oom_NZ`Co00000ond^l07
o`0000gojK?T1?l0000;oj[_Z0Go003o5OnZkjP2o`0001goin_O0_l0000<olo<_`[o00001_nkZ=`3
o`0003GoUHfL0_l0000comcki@?o0000:_n3YJH2o`0001KoPZjd0_l0000Lom_AX`;o00004_ng[LT2
o`0000koSYJU1Ol00?l>ohjFY@;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1Vooooo`;o00006Ona[K<4o`00013oUg6f0_l0000Qom_NZ`go00002ooY/n@3o`00
00goZ^nX1Ol00?lEoj[_Z0?o00007?oWjml2o`0000Soclbo2_l0000;ok^Xg0?o0000=?nESI`2o`00
03Cog?_U0_l0000Yoh>UYP?o00005_n2[[@2o`0001cofm6S0_l0000BokN]b@;o00003_n>UZD5o`00
o`koSYJU0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Ko
oooo0_l0000Hok6]/`Co00004OnGLKH2o`0002;ofmj[1Ol00005ohfcR`Co00002?oY/n@3o`0000ko
Z^nX1Ol00?lFoj[_Z0;o00007?oWjml2o`0000Coclbo2Ol0000Aok^Xg0;o0000<onESI`3o`0003Co
g?_U0_l0000Xoh>UYP?o00005on2[[@2o`0001cofm6S0_l0000BokN]b@?o00003On>UZD5o`00o`ko
SYJU0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Kooooo
0_l0000Gok6]/`?o00004onGLKH2o`00027ofmj[0ol00009ohfcR`Co00001OoY/n@4o`00013oZ^nX
0ol00?lGoj[_Z0;o00007?oWjml;o`0001Go^jSL0ol0000boiF=W0;o0000=OoLnnD3o`0002OoPjFV
0_l0000Hoh:^]0;o00007?oKdJ<2o`0001?o]jg90_l0000>ohjFY@?o003o3on>UZD2o`0005Cooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0I_ooool2o`0001Ko/Jfc0ol0
000DoiMa]P;o00008?oKgZ/3o`0000coSK>;1?l00002onVci0Co0000:onZkjP6o`0001Ooin_O2?l0
000Jok^Xg0?o0000<OnESI`2o`0003Kog?_U0_l0000Voh>UYP?o00006?n2[[@2o`0001cofm6S0_l0
000CokN]b@?o00007on>UZD2o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0IOooool4o`0001?o/Jfc1?l0000EoiMa]P;o00007ooKgZ/3o`0000koSK>;1ol0000^
oj[_Z0_o00004?oWjml5o`0001oo^jSL1Ol0000]oiF=W0?o0000=_oLnnD2o`0002KoPjFV0_l0000I
oh:^]0;o00007?oKdJ<2o`0001Co]jg90_l0000OohjFY@;o0000E?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1Tooooo`So00003ona[K<4o`0001KoUg6f0_l0000<om_N
Z`?o003o4?oKgZ/2o`00017oSK>;1?l0000^oj[_Z0?o00000_njXj4=o`0000Woin_O0ol0000Sok^X
g0So0000:?nESI`3o`0003Oog?_U0ol0000Toh>UYP?o00006On2[[@3o`0000kofm6S0ol00?l9om_A
X`?o00005?ng[LT3o`0001koSYJU0ol0001Cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06?ooooo0ol00002ojg4a0Ko00003?na[K<3o`0001SoUg6f0_l0000;om_NZ`Go
003o3_oKgZ/3o`0001;oSK>;0_l0000^oj[_Z0?o00002OnjXj4=o`0000;oin_O0ol0000Tok^Xg0;o
000000?o^YnTo`000?l000001ol0000RoiF=W0Go0000>?oLnnD2o`0002?oPjFV0ol0000Koh:^]0;o
00003OoKdJ<5o`00o`Sofm6S0_l0000FokN]b@;o00007on>UZD2o`0005?ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0HOooool4o`0000Ko[LC44Ol0000IoiMa]P;o0000
2ooKgZ/5o`00o`gofmj[0ol0000CohfcR`?o0000;?nZkjP3o`00013o^Z>Q2ol0000Tok^Xg0?o0000
1OnjWj@9o`0001coUHfL2?l0000gomcki@?o00008_n3YJH2o`0001coPZjd0_l0000=om_AX`Go003o
2?oKdJ<2o`0001Ko]jg90ol0000NohjFY@;o0000Doooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Pooooo`Co00002On]a<@>o`0001[oUg6f0ol0000:om_NZ`Go003o3OoK
gZ/2o`0001GoSK>;0_l0000/oj[_Z0;o00005onjXj44o`0002Go^jSL0_l0000:okZOY0[o00005?nE
SI`6o`0000?o`9o60_l0000homcki@;o00008On3YJH3o`0001coPZjd0_l0000=om_AX`Go003o1ooK
dJ<3o`0001Oo]jg90_l0000NohjFY@;o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Oooooo`?o00002on]a<@2o`0000[oWInd0ol0000<oiMa]P?o003o2onGLKH2
o`0000_ofmj[0ol00?l=om_NZ`?o00005On=/h/3o`0002[oZ^nX0ol0000IokZSX@?o00009?nkZ=`2
o`0000ko^YnT2_l0000>oiF=W0Ko00001Oo0WlH3o`0003Oog?_U0_l0000Qoh>UYP;o00003_n2[[@3
o`00o`coPZjd0_l0000>om_AX`?o003o1ooKdJ<4o`0000Wo]jg90ol00?l;okN]b@;o00007On>UZD3
o`0005?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0G_ooool3o`00
00co[LC40ol0000:oifO]0?o00002_nGLKH5o`00o`[oUg6f0_l0000Jom_NZ`?o00005on=/h/3o`00
02SoZ^nX0ol0000KokZSX@;o00008onkZ=`3o`0001?o^YnT2Ol00008oiF=W0Go00002Oo0WlH2o`00
03Oog?_U0ol0000Ooh>UYP?o00003On2[[@5o`00o`_oPZjd0_l0000Fom_AX`Oo00001ong[LT5o`00
o`[o]jg90ol0000LohjFY@;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Mooooo`?o00003_n]a<@2o`0000_oWInd0ol00009oiMa]PGo003o2_nGLKHNo`0001Wo
SK>;0_l0000Woj[_Z0?o00007?njXj42o`0002?o^jSL0_l0000HokZOY0Wo00000_nESI`5o`0000_o
`9o60ol0000gomcki@;o00007_n3YJH3o`0000koPZjd1Ol00?l;oh:^]0;o00005OoKdJ<4o`0000;o
dn;F0_l00007okN]b@Go003o2ong[LT2o`0001_oSYJU0ol0001Dooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo05gooooo0_l0000?ojg4a0;o00003?nMWk@2o`0000WoUg6f
1Ol00?l:oiMa]Qgo00006_n=/h/3o`0002GoZ^nX0ol0000MokZSX@?o00008_nkZ=`2o`0001co^YnT
2_l0000>ol2OaP;o0000=ooLnnD2o`0001koPjFV0_l0000?oh:^]0Go003o2on2[[@3o`0001;ofm6S
1?l00004om?ReP?o00001_ng[LT5o`00o`_o]jg90ol0000IohjFY@?o0000EOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Looooo`?o00003on]a<@2o`0000coWInd0ol0
0009oiMa]P?o003o2onGLKH2o`0000_o^=V^0ol00?l;okSI[P;o00006on=/h/2o`0002GoZ^nX0_l0
000OokZSX@;o00004_nkZ=`3o`00o`go^jSL0_l0000PokZOY0Ko00003_o0WlH3o`0001_og?_U0ol0
0?lHomcki@?o00007?n3YJH3o`00013oPZjd0ol00?l=oh:^]0;o00004OoKdJ<4o`0000Kodn;F0_l0
0007okN]b@?o003o3Ong[LT2o`0001WoSYJU0_l0001Fooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo05cooooo0_l0000@ojg4a0?o00003?nMWk@3o`0001KoUg6f0_l0000:
okSI[PGo003o2OnhfJh3o`0001_oSK>;0ol0000Soj[_Z0?o00007onjXj42o`00017o^jSL1Ol00?l;
ok^Xg0?o00008?njWj@3o`000003ol7YZOl0003o000000oo`9o60ol0000Iomcki@Go003o6?oLnnD2
o`0001coPjFV0_l0000Qoh:^]0;o00003ooKdJ<4o`0000Sodn;F0ol0000FokN]b@?o00005on>UZD3
o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Foooool3o`00
017o[LC40_l0000=oifO]0?o00005OnGLKH2o`0000[o^=V^1Ol00?l9okSI[P;o00007On=/h/2o`00
02;oZ^nX0ol0000PokZSX@?o00004?nkZ=`5o`00o`_o^jSL0_l0000PokZOY0?o00000_o1jJT2o`00
013o`9o60_l0000Iomcki@Go003o6?oLnnD3o`0001[oPjFV0ol0000Qoh:^]0;o00003OoKdJ<5o`00
00[odn;F0_l0000GokN]b@;o00005on>UZD2o`0005Oooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Foooool2o`0001;o[LC40_l0000>oifO]0?o00004onGLKH3o`0000[o
^=V^1Ol00?l9okSI[P;o00007On=/h/3o`0001koZ^nX1Ol0000RokZSX@;o00004?nkZ=`5o`00o`_o
^jSL0_l0000PokZOY0;o00000oo1jJT2o`00013o`9o60ol0000Homcki@Go003o6OoLnnD2o`0001[o
PjFV0_l0000Roh:^]0;o00003?oKdJ<4o`0000codn;F0ol0000FokN]b@;o00005_n>UZD3o`0005Oo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Foooool2o`0001;o[LC4
0_l0000?oifO]0;o00004onGLKH2o`0000co^=V^0ol00?l9okSI[P?o00007_n=/h/2o`0001WoZ^nX
2Ol0000SokZSX@;o00004OnkZ=`3o`00o`_o^jSL0ol0000OokZOY0?o00000oo1jJT2o`00017o`9o6
0_l0000Iomcki@?o003o6_oLnnD2o`0001WoPjFV0ol0000Roh:^]0;o00002_oKdJ<4o`0000Kodn;F
0ol00?l6om?ReP;o00005_ng[LT3o`0001CoSYJU0ol0001Hooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05[ooooo0ol0000Bojg4a0;o00003onMWk@3o`0001;oUg6f0_l0
000HokSI[P;o00007on=/h/3o`0001?oZ^nX2ol000001?mfV[co0000o`000?l0000RokZSX@?o0000
7_nkZ=`2o`0001oo^YnT0ol00004ol7YZ@;o00004Oo0WlH3o`0003Gog?_U0ol0000Goh>UYP?o0000
8on2[[@2o`0000Wofm6S1?l00006om?RePGo003o1OoCh]H3o`0001Ko]jg90_l0000DohjFY@;o0000
FOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00004on]
a<@3o`0000ooWInd0ol0000AoiMa]P;o00006?nhfJh2o`00023oSK>;0ol0000>oj[_Z0[o00001omf
V[`2o`0002?o^Z>Q0_l0000Nok^Xg0;o00007onjWj@2o`0000Go`NVY0_l0000Bol2OaP;o0000=_oL
nnD2o`0001OoPjFV0_l0000Toh:^]0?o00001_oKdJ<4o`0000Sodn;F1Ol00?l6om?ReP;o00005_ng
[LTHo`0005Wooooo00?o0000ooooooooool02?ooool001[ooooo0ol0001Iooooo`?o00005?n]a<@2
o`00013oWInd0ol0000@oiMa]P;o00005onhfJh3o`00027oSK>;0_l00009oj[_Z0[o00003?mfV[`2
o`0002?o^Z>Q0_l0000Nok^Xg0;o00007_njWj@3o`0000Go`NVY0_l0000Bol2OaP?o0000=OoLnnD2
o`0001KoPjFV0ol0000Uoh:^]0;o00001OoKdJ<4o`0000Wodn;F1Ol00?l6om?ReP?o00005Ong[LTG
o`0005Sooooo0ol0000:ooooo`006_ooool00ol0003oooooooooo`1Iooooo`;o00005On]a<@2o`00
00OoWInd0ol00?l7oifO]0;o00004?nGLKH2o`0001Oo^=V^0_l0000:ohfcR`?o003o5On=/h/5o`00
0003oj[_Z?l0003o000000Wo00004?mfV[`3o`0002;o^Z>Q0ol0000Lok^Xg0?o00002onjWj@3o`00
o`oo^YnT0ol00006ol7YZ@;o00004oo0WlH2o`0003Gog?_U1?l0000Doh>UYP;o00009_n2[[@2o`00
00?ofm6S1?l0000<om?ReP?o003o2?oCh]H2o`0001Co]jg90ol0000CohVKSP?o0000FOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Hooooo`?o00005On]a<@2o`0000Ko
WInd1Ol00?l6oifO]0?o00003onGLKH2o`0001Oo^=V^0_l00009ohfcR`Go003o5?n=/h/<o`0001Ko
MYZl0_l0000QokZSX@Go00006onkZ=`2o`0000_o^YnT1Ol00?l=okZOY0?o00001oo1jJT2o`0001?o
`9o60ol0000aomcki@So00004_n3YJH3o`0002GoPZjd2Ol0000Hom?ReP?o00004_ng[LT3o`0001Go
RI^>0_l0001Iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Sooooo
0_l0000Fojg4a0?o00001OnMWk@5o`00o`OoWInd0ol0000>oiMa]P;o00005_nhfJh3o`0000WoSK>;
1Ol00?lCohfcR`?o00000_nAS<L3o`0001_oMYZl0_l0000PokZSX@?o000000CoQWnXo`000?l0003o
00006_nkZ=`2o`0000_o^YnT1Ol00?l=okZOY0;o00002?o1jJT2o`0001Co`9o60_l0000^omcki@Oo
00000_n1]Z83o`00013oPjFV0ol0000Uoh:^]0So00006ooCh]H2o`00017o]jg90ol0000FohVKSP?o
0000F?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Gooooo`?o0000
5on]a<@2o`0000GoWInd1Ol00?l8oifO]0?o00003?nGLKH3o`0001Ko^=V^0_l0000:ohfcR`Go003o
4_n=/h/3o`0000?oTHc70ol0000KogJJ_0?o00007_njXj43o`0000?oQWnX0ol0000Hok^Xg0?o0000
2onjWj@5o`00o`co^YnT0ol00008ol7YZ@;o00005?o0WlH3o`0002_og?_U1_l00006oh6fXPCo0000
3_n3YJH2o`0002GoPZjd0ol00003olRb]PCo00006_oCh]H2o`00013o]jg90ol0000HohVKSP?o0000
Eoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Gooooo`;o00004?n]
a<@3o`00o`Go[LC40_l00006oifO]0?o003o2_nMWk@3o`0000_oUg6f0_l0000GokSI[P;o00002on=
/h/3o`00oa;oSK>;0ol00005oi6<a`;o00007?mfV[`2o`00013o^Z>Q0ol00?l:okZSX@?o00001On6
OjP3o`0001?o^jSL1_l0000=okZOY0?o003o3?njWj@3o`0000Wo`NVY0_l0000Eol2OaP;o0000:?oL
nnD6o`0000[oPKJR1?l0000<oh>UYP?o00008on2[[@4o`0000Kob;:f1?l0000Hom?ReP?o00003_ng
[LT3o`0001[oRI^>0_l0001Gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo05Oooooo0_l0000?ojg4a0Go003o1?n]a<@2o`0001CoWInd0_l0000;oiMa]P;o00005_nhfJh3
o`0001ooSK>;0ol00006oi6<a`;o00007?mfV[`3o`0000ko^Z>Q1Ol00?l8okZSX@?o00001on6OjP3
o`0000_o^jSL3Ol0000LokZOY0;o00002_o1jJT2o`0001Go`9o60ol0000Tomcki@Oo00003_n1]Z83
o`0000_oPjFV0_l0000Soh:^]0Co00002?o8/[H4o`0001Sodn;F0_l0000=okN]b@?o00006on9Vhh3
o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E_ooool3o`00
00oo[LC41Ol00?l4ojg4a0?o00004onMWk@3o`0000SoUg6f1Ol0000EokSI[P;o00007on=/h/3o`00
00OoTHc70ol0000LogJJ_0;o00003_njXj45o`00o`Oo^Z>Q0ol00009ohIoZ0?o00000onkZ=`?o`00
00?oZZGB0ol0000JokZOY0?o00002_o1jJT2o`0001Ko`9o60ol0000Pomcki@Oo00004_n1]Z84o`00
00SoPjFV0ol0000Roh:^]0?o00003?o8/[H4o`0001Kodn;F0ol0000;okN]b@?o00007On9Vhh2o`00
05Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E_ooool2o`00013o
[LC41Ol00?l5ojg4a0;o00005?nMWk@3o`0000;oUg6f3?l0000CokSI[P;o00007_n=/h/3o`0000Wo
THc70_l0000LogJJ_0;o00003_njXj45o`00o`Ko^Z>Q0ol0000;ohIoZ0go00002onZYM83o`0001So
^YnT0ol0000;ol7YZ@;o00005oo0WlH2o`0001kog?_U1_l0000Foh6fXPCo00001_n3YJH3o`0002;o
PZjd0ol0000>olRb]PCo00005_oCh]H2o`0000[o]jg90ol0000NohVKSP?o0000EOooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Eooooo`?o00004On]a<@3o`00o`Ko[LC4
0_l0000EoifO]0[o00000on]RVL4o`00017o^=V^0ol0000MohfcR`?o00002_nAS<L2o`0001coMYZl
0ol0000>okZSX@?o003o1_njXj43o`0000goQWnX1Ol0000CojZUdP;o00006?njWj@2o`0000co`NVY
0_l0000Gol2OaP?o00006_oLnnD6o`0001_oPKJR0ol00005oh>UYP;o00008On2[[@4o`00017ob;:f
0ol0000Eom?ReP?o00002?ng[LT3o`00023oRI^>0ol0001Dooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05Gooooo0_l0000Kojg4a0;o00005?nMWk@6o`0000[o[HYW1?l0
000?okSI[P;o00007On=/h/3o`0000_oTHc70ol0000LogJJ_0;o00005_njXj43o`0000koQWnX0_l0
000FojZUdP?o00005_njWj@3o`0000co`NVY0_l0000Hol2OaP;o00005ooLnnD7o`0001koPKJR2Ol0
000Poh:^]0Co00004oo8/[H4o`0001Codn;F0_l00007okN]b@?o00008_n9Vhh2o`0005Cooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0EOooool2o`0001_o[LC40ol0000B
oifO]0?o00003on]RVL5o`0000go^=V^0_l0000LohfcR`?o00003OnAS<L2o`0001coMYZl0ol0000D
okZSX@?o00003on6OjP2o`0001OoZZGB0ol0000DokZOY0?o00003Oo1jJT2o`0001So`9o60ol0000D
omcki@Ko00008_n1]Z8:o`0001goPZjd0ol0000FolRb]PCo00004ooCh]H3o`0000Go]jg90ol0000S
ohVKSP?o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Eoooo
o`?o00006on]a<@2o`00017oWInd0ol0000Bojf:I`Co00002onhfJh3o`0001_oSK>;0ol0000>oi6<
a`;o00007OmfV[`2o`0001?o^Z>Q0ol0000@ohIoZ0;o00006?nZYM83o`0001?o^YnT0_l0000>ol7Y
Z@;o00006Oo0WlH2o`00017og?_U1_l0000Toh6fXP?o00001Oo0b[h4o`0001[oPZjd1?l0000IolRb
]POo00003ooCh]H2o`0000Co]jg90ol0000UohVKSP;o0000Doooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Fooooo`;o00006on]a<@2o`00013oWInd0ol0000Eojf:I`Co
00002OnhfJh2o`0001_oSK>;0ol0000?oi6<a`?o00007?mfV[`2o`0001;o^Z>Q0ol0000AohIoZ0;o
00006OnZYM82o`0001;o^YnT0ol0000>ol7YZ@;o00006Oo0WlH:o`0000Kog?_U1ol0000Voh6fXP;o
00002?o0b[h4o`0001OoPZjd1?l0000KolRb]Pko00001ooCh]H3o`0000;o]jg90ol0000VohVKSP;o
0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Fooooo`;o0000
6on]a<@2o`0000ooWInd0ol0000Gojf:I`Go00001onhfJh2o`0001[oSK>;0ol0000Aoi6<a`;o0000
7?mfV[`3o`00013o^Z>Q0ol0000BohIoZ0;o00006OnZYM83o`00013o^YnT0ol0000?ol7YZ@;o0000
6_o0WlHCo`0002SoPKJR0ol00009ol3:_PGo00005?n2[[@3o`0001cob;:f0ol00003ogV5X13o0000
00Codn;Fo`000?l0003o]jg90ol0000WohVKSP;o0000Doooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1Fooooo`;o00006on]a<@3o`0000goWInd0ol0000Jojf:I`Co0000
1OnhfJh3o`0001WoSK>;0ol0000Boi6<a`;o00007OmfV[`2o`0000oo^Z>Q0ol0000CohIoZ0;o0000
6_nZYM84o`0000ko^YnT0_l0000@ol7YZ@;o00006Oo0WlH3o`0000KoembY2?l0000[oh6fXP;o0000
3?o0b[h4o`00017oPZjd1?l0000MolRb]P;o00003?miQJ0>o`0002SoRI^>0_l0001Cooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Kooooo0ol0000Kojg4a0;o00003?nM
Wk@3o`0001go[HYW1?l00003okSI[P;o00006On=/h/3o`0001?oTHc70ol0000;ogJJ_0?o003o3_mf
V[`2o`0000ko^Z>Q0ol00007ohIoZ0?o003o2_n6OjP2o`0000coZZGB0ol00?l9ojZUdPOo00003?nj
Wj@3o`0000co`NVY0ol00?l00oo1jJWo0000o`000002ol2OaP?o003o5?o0WlH2o`0000goembY0ol0
000Yoh6fXP?o00003_o0b[h4o`0000koPZjd1?l0000NolRb]P;o00004omiQJ06o`0001KoRI^>0ol0
0?l?ohVKSP?o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1G
ooooo`?o00006_n]a<@2o`0000_oWInd0ol0000Oojf:I`Go000000?o^=V^o`000?l000006?n=/h/3
o`0001GoTHc70_l0000:ogJJ_0Go003o3OmfV[`3o`0000co^Z>Q0ol00007ohIoZ0Go003o2On6OjP2
o`0000_oZZGB1Ol00?l6ojZUdPGo00000_ohb>43o`0000[o^YnT0ol0000<ol7YZ@Go003o0_l00000
0oo0WlKo003oo`00o`03o`00oa?o`9o60_l0000>omOLZ@;o0000:?n1]Z83o`00013o`<Zn1Ol0000;
oh:^]0?o00007oo8/[H3o`0001OoNHFP0ol0000DohVKSPGo003o3_n9Vhh2o`0005Cooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Eoooool6o`0001Oo[LC40_l0000:oifO
]0?o00008_n]RVL6o`0001OoSK>;0ol0000Foi6<a`;o00002_mfV[`5o`00o`koMYZl0_l0000;okZS
X@?o00002?n6OjP5o`00o`WoQWnX0_l0000;ojZUdPGo003o1?nZYM85o`0000Gon<SQ0ol00008okZO
Y0?o00003Oo1jJT5o`00o`;o000000?o`9o6o`00ool00?l00ol00?lBol2OaP?o00003_oGg:T3o`00
02OoPKJR0_l0000Col3:_PCo00002On2[[@3o`00023ob;:f0_l0000HogV5X0Go00004_n9Vhh5o`00
o`koRI^>0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Ko
oooo2_l0000Dojg4a0;o00002OnMWk@3o`0002Go[HYW0ol0000GohfcR`?o00005onAS<L3o`0000Wo
MYZl1Ol00?l>ogJJ_0?o00002OnjXj43o`0000WoQWnX1Ol00?l9ohIoZ0;o00002onZYM85o`00o`;o
ZZGB1Ol00008ooS8h@?o00001onjWj@2o`0000ko`NVY1Ol00?l2o`000003ol2Oa_l00?oo003o00?o
003o4_o0WlH2o`00013oembY0_l0000Voh6fXP?o00005Oo0b[h4o`0000GoPZjd1?l0000QolRb]P;o
00006?miQJ06o`00017oRI^>1Ol00?l>ohVKSP;o0000E?ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1Eooooo`?o00001?o6`;46o`0001;o[LC40ol00007oifO]0?o0000
9on]RVL2o`0001KoSK>;0ol0000Ioi6<a`;o00002_mfV[`3o`00oa3oMYZl0_l00008okZSX@?o0000
2on6OjP3o`00o`[oQWnX0_l0000<ojZUdP?o003o00?oZZGBo`000?l000000ol0000;ooS8h@?o0000
1OnjWj@3o`0000oo`NVY0ol00?l00oo1jJWo0000o`000002ol2OaP?o003o4_o0WlH3o`00013oembY
0ol0000Uoh6fXP;o00005oo0b[h5o`0000;oPZjd1?l0000JolRb]P?o003o1?o8/[H3o`0001OoNHFP
0ol00002ojJ_Z0Co00004?n9Vhh3o`00o`ooRI^>0_l0001Dooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05Cooooo0ol00008olK0/@Ko00004?n]a<@2o`0000KoWInd0ol0
000Xojf:I`?o00005?n=/h/3o`0001[oTHc70ol0000LogJJ_0;o00001onjXj43o`0001WoQWnX0_l0
000>ojZUdPGo00003_ohb>43o`0000?o^YnT0ol0000Dol7YZ@;o00005oo0WlH2o`0001;oembY0_l0
000Toh6fXP?o00006Oo0b[h7o`0001_ob;:f1Ol00?l3olRb]P;o00006?miQJ02o`0000CoYZnX1Ol0
000PohVKSP;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1C
ooooo`?o00002oo6`;47o`0000go[LC40_l00005oifO]0?o0000:_n]RVL2o`0001?oSK>;0ol0000L
oi6<a`;o00007?mfV[`3o`0000Go^Z>Q0ol0000JohIoZ0;o00003?nZYM85o`00017on<SQ0ol00002
okZOY0;o00005Oo1jJT2o`0001Oo`9o60_l0000BomOLZ@?o00008on1]Z82o`0001co`<Zn1?l0000L
olRb]PGo003o0oo8/[H2o`0001SoNHFP0_l00006ojJ_Z0Co00007on9Vhh2o`0005Cooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0D_ooool3o`0000ooa/2a1ol0000:ojg4
a0;o00001?nMWk@3o`0002_o[HYW0ol0000AohfcR`?o00007OnAS<L2o`0001goMYZl0_l00004okZS
X@?o00006on6OjP2o`0000_oZZGB1?l0000DooS8h@Ko00005Oo1jJT2o`0001Ko`9o60ol0000ComOL
Z@;o00008_n1]Z83o`0001go`<Zn0_l0000MolRb]PGo003o0_o8/[H3o`0001OoNHFP0ol00008ojJ_
Z0Co00007?n9Vhh3o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0D_ooool2o`0001?oa/2a1_l00008ojg4a0So00004on]RVL3o`00oaOo[HYW0ol0000?ohfcR`?o
00004_nAS<L3o`00o`WoTHc70ol0000LogJJ_0;o00000onjXj43o`0001coQWnX0_l00009ojZUdPCo
00000oohb>43o`00oa7on<SQ1?l0000Fol7YZ@;o00005_o0WlH2o`0001CoembY0ol00009oh6fXP?o
003o5On1]Z82o`0001ko`<Zn0ol0000MolRb]P?o003o0oo8/[H2o`0000CoNHFP0ol00?lAogV5X0;o
00002_nV[jP5o`0001[oRI^>0_l0001Eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo057ooooo0ol0000FolK0/@Ko00001On]a<@9o`00017o[HYW1Ol00?lGojf:I`;o0000
3_n=/h/3o`0001;oTHc71Ol00?l9oi6<a`;o00007?mfV[`7o`0001goQWnX0_l00007ojZUdPGo0000
0oohb>45o`00oa7on<SQ0_l0000Gol7YZ@;o00005Oo0WlH3o`0001GoembY0_l00008oh6fXPGo003o
4on1]Z83o`0001oo`<Zn1?l0000QolRb]P;o00000omiQJ05o`00oa3oNHFP0_l0000<ojJ_Z0Co0000
6On9Vhh2o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0D?oo
ool3o`0001Woa/2a3Ol00003oiahS`?o00004?n]RVL5o`00oaOo[HYW1?l0000;ohfcR`?o00004onA
S<L5o`00o`WoTHc70_l0000KogJJ_0[o00006on6OjP2o`0000GoZZGB1Ol00005ooS8h@Go003o4Ooh
b>42o`0001Oo`NVY0_l0000Eol2OaP;o00005_oGg:T3o`0000OoPKJR1Ol00?lCoh6fXP;o00008?o0
b[h7o`0001gob;:f0ol00003ogV5X0Go003o3omiQJ03o`0000koYZnX1?l0000GohVKSP;o0000EOoo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1?ooooo`?o00007Oo6`;47
o`0000OoW7R?0ol0000?ojf:I`Go003o5On]RVL7o`0000WoSK>;0ol0000Doi6<a`Go003o2OnAS<L3
o`0001WoMYZl0ol00005ooW1l0Co00006_n6OjP2o`0000?oZZGB1Ol00007ooS8h@Go003o4Oohb>42
o`0001Oo`NVY0_l0000Dol2OaP?o00005ooGg:T2o`0000OoPKJR1Ol00?lBoh6fXP?o00008?o0b[h2
o`000003oj3UVol0003o000000Go00006_o8/[H2o`0000CoNHFP1Ol00?l?ogV5X0;o00004?nV[jP5
o`0001GoRI^>0_l0001Eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
04kooooo0ol0000QolK0/@;o00002_nLN8l4o`0000ko[HYW0ol00?lDojf:I`Go00000_o8/h/3o`00
00OoSK>;0ol0000Foi6<a`?o003o2onAS<L2o`0001SoMYZl0ol00008ooW1l0Co00006?n6OjP2o`00
0003ojZUd_l0003o000000?o00002_ohb>43o`00oa;on<SQ0ol0000Fol7YZ@;o00005?o0WlH2o`00
01SoembY0ol00007oh6fXP?o003o4_n1]Z83o`00027o`<Zn0_l00004oj3UV`So00005_o8/[H2o`00
00GoNHFP0ol00?l@ogV5X0;o00004_nV[jP5o`0001?oRI^>0_l0001Eooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo04gooooo0ol0000RolK0/@;o00002onLN8l4o`0002;o
[HYW1Ol00005olRcR`Co00001?n=/h/3o`0002GoTHc70_l0000GogJJ_0?o00002_oi`O05o`0001Ko
QWnX1_l0000RooS8h@;o00005_o1jJT2o`0001Co`9o60_l0000IomOLZ@;o00007?n1]Z82o`0002;o
`<Zn0_l00007oj3UV`So00004_o8/[H3o`0001OoNHFP0ol0000DojJ_Z0Co00004_n9Vhh2o`0005Go
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0COooool2o`0002;oa/2a
0ol0000=oiahS`?o00007on]RVL5o`0000Sob;>;1?l00002ohfcR`?o00009_nAS<L3o`0001GoMYZl
0ol0000=ooW1l0Co00005On6OjP4o`0002Con<SQ0ol0000Eol7YZ@;o00004oo0WlH3o`0001WoembY
0ol0000Joh6fXP?o00008_o0b[h2o`0000_oX>FK1ol0000?olRb]P;o00006?miQJ02o`0001OoYZnX
1?l0000?ohVKSP?o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1=ooooo`;o00008_o6`;42o`0000ooW7R?0ol0000Lojf:I`Go00003?o8/h/6o`0002SoTHc70_l0
000DogJJ_0?o00004?oi`O04o`0001;oQWnX1?l0000TooS8h@Ko00004oo1jJT2o`0001?o`9o60_l0
000KomOLZ@;o00006_n1]Z82o`0002?o`<Zn0_l0000>oj3UV`Oo00003?o8/[H2o`0001SoNHFP0_l0
000HojJ_Z0Go00003On9Vhh2o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0COooool2o`0002;oa/2a0_l0000@oiahS`Co00006?n]RVL5o`0000oob;>;1?l0000Y
oi6<a`;o00004omfV[`3o`0001;onL7`1Ol0000>ohIoZ0Oo00008_ohb>43o`000003ohnQZol0003o
000000Co00004?o1jJT2o`0001;o`9o60ol0000ComOLZ@?o003o1OoGg:T3o`0001SoPKJR0ol0000S
ol3:_P;o00004OnPiI/8o`0000Oob;:f0ol0000GogV5X0?o00006_nV[jP4o`0000coRI^>0_l0001F
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000COooool2o`0002;oa/2a0_l0000Aoiah
S`Co00005On]RVL5o`0001;ob;>;0_l0000Zoi6<a`?o00004OmfV[`3o`0001GonL7`1?l0000;ohIo
Z0Go00000_nQV8X4o`0001oon<SQ0ol00004ohnQZ`Ko00003_o1jJT2o`0001;o`9o60_l0000ComOL
Z@Go003o1OoGg:T2o`0001SoPKJR0_l0000Tol3:_P;o00005?nPiI/8o`0000Cob;:f0_l0000HogV5
X0;o00007OnV[jP4o`0000WoRI^>0ol0001Dooooo`?o00002_ooool001[ooooo00?o0000oooooooo
ool0C?ooool3o`0002;oa/2a0_l0000CoiahS`?o00004on]RVL4o`0001Cob;>;0ol0000Zoi6<a`;o
00003?mfV[`7o`0001SonL7`1?l00007ohIoZ0Go00001OnQV8X4o`0001gon<SQ0ol00008ohnQZ`Go
00003?o1jJT2o`0001;o`9o60_l0000ComOLZ@Go003o1OoGg:T3o`0001KoPKJR0ol0000Tol3:_P;o
00006?nPiI/7o`000003olRb]_l0003o000001SoNHFP0_l0000NojJ_Z0Go00001_n9Vhh4o`0005Ko
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0C?ooool2o`00013oa/2a
0ol00?l?olK0/@?o00005?nLN8l3o`00013o[HYW1?l0000GolRcR`;o0000:_nAS<L2o`0000?oMYZl
3ol0000JooW1l0Go00000on6OjP5o`0000WoXIR:1?l0000JooS8h@?o00002on?XJ/6o`0000Oo`NVY
6?l0000ComOLZ@Go003o1_oGg:T2o`0001KoPKJR0_l0000Uol3:_P;o00006onPiI/7o`0001OoNHFP
0ol0000?ojJ_Z0?o003o3_nV[jP4o`0000?oRI^>1?l0001Hooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo04cooooo0_l0000?olK0/@Go003o3_o6`;42o`0001KoW7R?0ol0
000=ojf:I`Go00006?o8/h/3o`0002WoTHc73ol00003ok>Zc@;o00007?oi`O09o`0000coXIR:1?l0
000HooS8h@?o00003_n?XJ/6o`000003ol7YZOl0003o000001Wo00005OoGg:T3o`00o`OoembY0ol0
000Doh6fXP?o00009Oo0b[h2o`0001koX>FK1?l0000GogV5X0;o00003onV[jP5o`00o`ooYZnX2?l0
001Iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04cooooo0_l0000?
olK0/@Go003o3_o6`;42o`0001OoW7R?1?l00009ojf:I`Go00006oo8/h/2o`0002WoTHc71_l0000<
ok>Zc@?o00007Ooi`O05o`00013oXIR:1?l0000EooS8h@?o00004_n?XJ/9o`0001CofLK/0ol0000O
omOLZ@;o00005?n1]Z82o`0002Ko`<Zn0_l0000Poj3UV`?o00005_miQJ02o`0000ooYZnX1Ol00?l@
ojJ_Z0Go0000Foooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1<oooo
o`;o00003oo6`;45o`00o`koa/2a0_l0000HoiahS`Co00001_n]RVL5o`0001gob;>;0ol0000Woi6<
a`?o00004OncZ/d2o`0001konL7`0_l0000Coj6HRPGo00004_ohb>43o`0001GoSj6[0ol0000IomW6
k0;o00007ooGg:T3o`0001;oPKJR0ol0000Vol3:_P?o00008?nPiI/3o`0001CoNHFP0ol0000?ojJ_
Z0Go003o4_nV[jP2o`0005cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0C?ooool2o`00013oa/2a0ol00?l?olK0/@;o00006_nLN8l3o`0000?o[HYW1Ol0000PolRcR`;o
00009_nAS<L3o`0001;o/j[=0_l0000NooW1l0;o00005OnQV8X4o`00013on<SQ0ol0000FohnQZ`;o
00006_oIa^`3o`0001ooembY0_l0000Boh6fXP;o00009oo0b[h5o`0001ooX>FK0ol0000CogV5X0;o
00004OnV[jP3o`00oa?oYZnX0_l0001Looooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo04cooooo0_l0000QolK0/@?o00006onLN8l8o`0002;ob;>;0_l0000Uoi6<a`?o0000
4oncZ/d3o`0001gonL7`0_l0000Goj6HRPCo00003Oohb>43o`0001OoSj6[0_l0000KomW6k0;o0000
7ooGg:T3o`00013oPKJR0ol0000Wol3:_POo00007_nPiI/3o`0001;oNHFP0_l0000VojJ_Z0?o0000
G?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1<ooooo`;o00008Oo6
`;42o`0001goW7R?1Ol0000TolRcR`?o00008onAS<L3o`0001Go/j[=0_l0000LooW1l0Co00005onQ
V8X4o`0000[on<SQ1?l0000HohnQZ`;o00006ooIa^`3o`0001ooembY0_l0000?oh6fXP?o0000:?o0
b[h2o`0000;o_Lo11Ol0000Moj3UV`?o00004?miQJ03o`0002KoYZnX0_l0001Mooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo04cooooo0_l0000QolK0/@;o00007_nLN8l2
o`0002Oob;>;0_l0000Roi6<a`?o00005_ncZ/d2o`0001_onL7`1Ol0000Ioj6HRPCo00001oohb>45
o`0001SoSj6[0_l0000LomW6k0;o00007_oGg:T6o`0000coPKJR0_l0000Xol3:_P?o00001?nmcl45
o`0001coX>FK0ol0000?ogV5X0;o00009onV[jP2o`0005gooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Boooool3o`00027oa/2a0_l0000@oiahS`?o003o2onLN8l2o`00
02Oob;>;9_l0000Gok>Zc@?o00002ooi`O03o`00o`_onL7`0ol000001?ng/=Go0000o`000?l0000I
oj6HRPCo00001Oohb>43o`000004ok2[YOl0003o0000o`0001OoSj6[0_l0000LomW6k0?o00006_oG
g:T>o`0000KoPKJR0ol0000Bol3:_P?o003o4oo0b[h2o`0000Oo_Lo11Ol0000:oj3UV`?o003o3_nP
iI/3o`0000koNHFP0_l0000VojJ_Z0?o0000GOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1;ooooo`;o00008_o6`;42o`0000ooW7R?1Ol00?l:oiahS`;o0000:?o8/h/T
o`0001Wo/j[=0_l0000:ooW1l0Go003o2_oi`O02o`0000?o]k3E0_l0000Koj6HRPCo00000_ohb>43
o`0000?o/:^U0ol0000FohnQZ`;o00007OoIa^`2o`0001OoembY1ol00004oj>P]0_o000000?oPKJR
o`000?l000004_o0b[h5o`00oa;o`<Zn0_l00009okg?`@Go00001onPiI/5o`00o`koX>FK0ol0000<
ogV5X0?o00009_nV[jP2o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Boooool2o`00027oa/2a0ol0000?oiahS`Go003o2OnLN8l3o`0002Sob;>;0_l0000Pok>;
T@;o00006OncZ/d2o`0000[onL7`1Ol00?l9ooW1l0?o00000ong/=D3o`0001_oXIR:1ol00005ok2[
Y@?o00005On?XJ/2o`0001gofLK/0ol0000ComOLZ@Oo00003?nSX;@9o`0001;o`<Zn1Ol00?lBol3:
_P;o00002onmcl45o`0000GoX>FK1Ol00?l?oj3UV`?o00002OmiQJ05o`0002KoYZnX0_l0001Noooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04_ooooo0_l0000QolK0/@;o
00004?nLN8l5o`00o`WoW7R?0_l0000YolRcR`;o00008?ncRi43o`0001So/j[=0ol00009ooW1l0Go
003o2?oi`O03o`0000Go]k3E0_l0000Moj6HRPCo00001on`ZjD3o`0001CoSj6[0_l0000NomW6k0;o
00003ooGg:T8o`0001CoXj2d0ol0000Col3:_PGo003o4_o0b[h2o`0000go_Lo11Ol00003oj3UV`Go
003o4?nPiI/3o`0000GoNHFP2Ol0000TojJ_Z0?o0000G_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1;ooooo`;o00007oo6`;44o`00017oW7R?0ol00?l:oiahS`;o0000
2oo8/h/3o`00oa[ob;>;0ol0000Qok>;T@;o00006OncZ/d2o`0000[onL7`0ol00?l8ooW1l0?o0000
1_ng/=D3o`0000SoXIR:0ol00?lBoj6HRP;o00002On`ZjD3o`0001?oSj6[0_l0000NomW6k0?o0000
2ooGg:T8o`0001SoXj2d0_l0000Dol3:_P?o003o4oo0b[h2o`0000oo_Lo11Ol00002oj3UV`?o003o
4_nPiI/3o`000003ogV5X?l0003o000000Go00000onVWZL3o`0002?oYZnX0_l0001Oooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04_ooooo0ol0000KolK0/@Oo00007_nL
N8l2o`0000[ob;>;1Ol00?lIolRcR`;o00008_ncRi42o`0001Wo/j[=0_l0000EooW1l0;o00002?ng
/=D2o`0000OoXIR:1Ol00?lAoj6HRP;o00002_n`ZjD3o`0001;oSj6[0_l0000OomW6k0;o00002?oG
g:T7o`0001coXj2d0ol0000Xol3:_P?o00004Onmcl45o`0001KoX>FK1ol00007ojJNY`Co00008OnV
[jP2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0C?ooool3
o`0001Ooa/2a1ol000001?ndSXco0000o`000?l0000MoiahS`;o00002_o8/h/5o`00oaWob;>;0_l0
000Rok>;T@?o00006?ncZ/d3o`0001?onL7`0ol00008okN`e@?o00001_nQV8X5o`00oa7oXIR:0_l0
000;ok2[Y@?o00004On?XJ/2o`0001oofLK/0ol00004omOLZ@Oo00008?nSX;@2o`0002So`<Zn0_l0
000Dokg?`@Go00005OnPiI/3o`0000_oYYjW1?l0000OojJ_Z0?o0000Goooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1=ooooo`?o00004_o6`;48o`0000Go]8j<0ol0000L
oiahS`;o00002_o8/h/5o`00oaOob;>;1?l0000Sok>;T@;o00006OncZ/d2o`0001;onL7`0ol0000:
okN`e@;o00001_nQV8X5o`00oa3oXIR:0ol0000<ok2[Y@?o00004?n?XJ/2o`00023ofLK/0_l00000
0ooGg:Wo0000o`000005o`0002?oXj2d0_l0000Xol3:_P;o00005_nmcl45o`0001;oX>FK0ol0000>
ojJNY`?o00007_nV[jP2o`00063ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0C_ooool3o`0000koa/2a2?l00009okB>S0?o00006onLN8l2o`0000_ob;>;0ol00?lDolRc
R`So00008oncRi42o`0000go/j[=0ol00?l9ok>Zc@;o00004Ooi`O03o`0000_o]k3E0ol00006oj6H
RP?o003o4OnQV8X2o`0000ko/:^U0ol00004ohnQZ`?o003o2?n?XJ/2o`0000[ofLK/0ol00?lComW6
k0Oo00009_nSX;@2o`0002So`<Zn0_l0000Dokg?`@?o003o00?o_Lo1o`000?l000000ol0000?oj3U
V`?o00004?nVWZL4o`0001coYZnX0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo04oooooo0ol00009olK0/@So00003_ndSX`2o`0001[oW7R?0ol0000NolRcR`Wo
000000?oY^JRo`000?l000008oncRi42o`0000co/j[=1Ol00?l8ok>Zc@?o00004?oi`O02o`0000go
]k3E0_l0000Joj6HRP;o00003on`ZjD3o`0000;oSj6[1Ol00?l7ohnQZ`;o00002OoIa^`5o`00oa?o
fLK/0ol0000Yoj>P]0?o00009oo0b[h2o`0001?o_Lo11Ol00?l2okg?`@Go00003?nPiI/3o`0001;o
YYjW1?l0000JojJ_Z0?o0000H?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1@ooooo`?o00001Oo6`;48o`00017o]8j<0ol0000IoiahS`;o00006oo8/h/9o`0000GoY^JR
0_l0000Sok>;T@?o00002oncZ/d5o`00o`Wo/j[=0_l0000?ooW1l0?o00003Ong/=D3o`0001WoXIR:
0_l0000@ok2[Y@?o000000?oSj6[o`00ool00?l00ol00?l7ohnQZ`;o00002OoIa^`5o`00oa?ofLK/
0_l0000[oj>P]0;o00009oo0b[h2o`0001?o_Lo11Ol00?l4okg?`@Go00002OnPiI/3o`0001GoYYjW
0ol0000IojJ_Z0;o0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Aooooo`?o000000?oa/2ao`000?l000001Ol0000FokB>S0?o00006?nLN8l2o`0001Oob;>;2Ol0
0009ojKVXP;o00009?ncRi42o`0000_o/j[=1Ol00?l9ok>Zc@;o00003_oi`O03o`0000oo]k3E0_l0
000Ioj6HRP;o00004On`ZjD3o`0000Go003o1on?XJ/2o`0000WofLK/1Ol00?lComW6k0;o0000:onS
X;@2o`0002Oo`<Zn0_l0000Cokg?`@Go003o1_nmcl45o`0000KoX>FK0ol0000GojJNY`Co00005onV
[jP2o`00067ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0D_ooool7
o`0001[o]8j<0_l0000HoiahS`;o00004oo8/h/9o`0000goY^JR0_l0000Tok>;T@;o00003?ncZ/d3
o`00o`[o/j[=0ol0000=ooW1l0;o00002?ng/=D3o`00o`Go]k3E0_l0000Hoj6HRP?o00004On`ZjD3
o`00o`04o`000?l00?oo003oo`00o`SoSj6[0_l0000:omW6k0?o003o5?oIa^`2o`0001GoXj2d0ol0
0?lCoj>P]0?o00009Oo0b[h3o`0001Co_Lo10ol00?l9okg?`@Go00000onPiI/3o`0001WoYYjW1?l0
000EojJ_Z0?o0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1C
ooooo`?o00007OndSX`3o`0001OoW7R?0_l0000@olRcR`So00004OnViZ82o`0002Co/h^A0_l0000J
ok>Zc@;o00003?oi`O03o`0000Oo]k3E1Ol00?l4okN`e@?o00005onQV8X2o`00017o/:^U1Ol00?l0
0ol0003oSj6[ohnQZ`08ohnQZ`;o00008OoIa^`2o`0001CoXj2d1Ol00?lCoj>P]0;o00009Oo0b[h2
o`0002?o_Lo12?l0000LojJNY`Co00004onV[jP2o`0006;ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Doooool2o`0001oo]8j<0ol0000FoiahS`;o00003?o8/h/8o`00
01GoY^JR0_l0000Tok>;T@?o00006OncZ/d2o`0000_onL7`0ol00008okN`e@Go003o1Ong/=D2o`00
01OoXIR:0_l0000Aok2[Y@Go003o0_l00009ohnQZ`;o00008OoIa^`2o`0001CoXj2d1Ol00?lCoj>P
]0;o00009Oo0b[h2o`0002Go_Lo11Ol0000NojJNY`Co00004_nV[jP2o`0006;ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Doooool2o`00023o]8j<0ol0000EoiahS`;o
00002?o8/h/9o`0001SoY^JR0_l0000Uok>;T@;o00006OncZ/d3o`0000WonL7`0ol00009okN`e@Go
003o1Ong/=D3o`0001KoXIR:0_l0000Aok2[Y@Go003o0ol00008ohnQZ`;o00008OoIa^`2o`0001Co
Xj2d1Ol00?lCoj>P]0;o00009Oo0b[h2o`0002Oo_Lo10_l0000QojJNY`?o00004?nV[jP3o`0006;o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Doooool2o`00027o]8j<
0_l0000DoiahS`?o00001?o8/h/9o`0001coY^JR0_l0000Gok>;T@?o003o2oncRi42o`0001[o/j[=
0_l00009ooW1l0;o00002ong/=D3o`00o`Oo]k3E0_l0000Foj6HRP;o00004_n`ZjD3o`00o`;o/:^U
0ol00007ohnQZ`;o00008OoIa^`2o`0001GoXj2d0ol00?lDoj>P]0?o00009?o0b[h2o`0002Ko_Lo1
0ol0000RojJNY`Co00003OnV[jP3o`0006?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Doooool2o`00027o]8j<0ol0000CoiahS`;o000000?ob;>;o`000?l000001ol0
000PojKVXP?o00005OncRi45o`00o`[o/h^A0ol0000Iok>Zc@;o00002?oi`O03o`0001Go]k3E0ol0
000Eoj6HRP;o00006?n`ZjD3o`0000KoSj6[0_l0000PomW6k0?o0000;OnSX;@4o`0002;o`<Zn0_l0
000Vokg?`@;o00009?nVWZL4o`0000_oYZnX1?l0001Sooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo05?ooooo0_l0000RokB>S0Co00004?nLN8l9o`0002GoY^JR0_l0000E
ok>;T@Go003o2oncRi42o`0001Wo/j[=0ol00006ooW1l0?o00005ong/=D2o`0001CoXIR:0ol0000I
ok2[Y@?o00001On?XJ/2o`00023ofLK/0_l0000^oj>P]0Oo00007_o0b[h3o`0002Go_Lo10ol0000V
ojJNY`?o00002?nV[jP4o`0006Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Doooool2o`00017o]8j<0ol00?l>okB>S0Oo00002onLN8l7o`0000ooY^JR0ol00?lGojKV
XP;o00005OncRi45o`00o`_o/h^A0_l0000Iok>Zc@_o00006?ng/=D3o`0001?oXIR:0_l0000Kok2[
Y@?o00001?n?XJ/2o`00023ofLK/0_l0000]oj>P]0?o000000?oZ=OJo`000?l000001Ol0000Kol3:
_P;o00009_nmcl42o`0002SoYYjW1?l00005ojJ_Z0Co0000I_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Cooooo`;o00004?ndSX`5o`00o`co]8j<0ol000000onZ[YGo
0000o`000005o`0000GoW7R?1_l00002olC5f0?o00003OnViZ85o`00oaKoY^JR0_l0000Fok>;T@?o
003o3?ncRi42o`0001So/j[=3Ol0000HokN`e@;o00004onQV8X2o`0001co/:^U0ol00003ohnQZ`;o
00008?oIa^`2o`0002coXj2d0ol00005ojSGfPOo00006?o0b[h6o`00027o_Lo10ol0000YojJNY`Co
00000_nV[jP4o`0006Sooooo00?o0000ooooooooool02?ooool000Oooooo0ol00004ooooo`;o0000
2_ooool00ol0003oooooooooo`1Cooooo`;o00004?ndSX`5o`00o`_o]8j<0ol00005ojZ^U@go0000
1Oo4aMP3o`0000coY^JR1Ol00?lFojKVXP;o00009OncRi43o`0001Ko/j[=0ol00009oj[DZ@?o0000
5ong/=D3o`0001;oXIR:0_l0000Mok2[Y@?o00000_n?XJ/2o`00023ofLK/0_l0000[oj>P]0?o0000
2OnXemX8o`0001?o`<Zn3_l0000Jokg?`@;o0000;?nVWZL7o`0006Wooooo00?o0000ooooooooool0
2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool0Doooool2o`00013o]8j<1Ol00?l:okB>S0?o00002OnZ[YD7o`0000Wo
a<GH0ol0000;ojKVXPGo003o5_nViZ82o`0002Ko/h^A0_l0000Dok>Zc@Co00002onZe:T3o`0001Oo
]k3E0_l0000Boj6HRP;o00007_n`ZjD7o`0001oofLK/0_l0000Zoj>P]0?o00003OnXemX8o`0000oo
`<Zn0ol00004ogR0KA3o00004_nmcl42o`0002goYYjW1?l0001[ooooo`03o`000?oooooooooo00So
oooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00009oooo
o`Go0000DOooool2o`00017o]8j<0ol00?l:okB>S0?o00003OnZ[YD2o`0000coa<GH0ol0000;ojKV
XP?o003o5onViZ82o`0002Ko/h^A0_l0000Cok>Zc@Co00003OnZe:T3o`0001Ko]k3E0ol0000@oj6H
RP?o00006on`ZjD;o`0001kofLK/0_l0000Yoj>P]0?o00004_nXemX7o`0000_o`<Zn0ol0000<ogR0
KA3o00002_nmcl43o`00017oYYjW0ol00?lJojJNY`;o0000J?ooool5o`0000[ooooo0006ooooo`Co
00000oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo05?ooooo0ol0000LokB>
S0?o00003_nZ[YD2o`0000goa<GH0ol0000TojKVXP;o00009_ncRi42o`0001;o/j[=0ol0000@oj[D
Z@?o00005_ng/=D2o`00013oXIR:0_l0000Iok2[Y@Oo00001OnYNjd4o`0001cofLK/0_l0000Xoj>P
]0?o00005_nXemX7o`0000Oo`<Zn0ol0000EogR0K@oo00000onmcl42o`00017oYYjW1Ol00?lIojJN
Y`;o0000K?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0E?ooool2o`0001_o]8j<0ol0000?ojZ^
U@;o00003_o4aMP3o`0002?oY^JR0_l0000Vok>;T@?o00003oncZ/d4o`0001;oZ]BY0ol0000EokN`
eC7o00002OnYNjd4o`0001[ofLK/1?l0000Voj>P]0?o00006_nXemX7o`0000?o`<Zn0ol0000MogR0
K@go00004OnVWZL5o`00oaSoYYjW0ol0001/ooooo`03o`000?oooooooooo00Sooooo0007ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1Doooo
o`;o00006_ndSX`3o`00013oZZjE0_l0000?olC5f0?o00008_nViZ83o`0002Ko/h^A0_l0000>ok>Z
c@Co00005?nZe:T4o`00017o]k3E<?l0000>ojUk[@?o00005ooIa^`7o`0002CoXj2d0ol0000NojSG
fPWo00009OmhP6d5o`0001;oYYjW1Ol00?lHojJNY`;o0000KOooool00ol0003oooooooooo`08oooo
o`002?ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo05Cooooo0_l0000IokB>S0?o
00004OnZ[YD2o`00013oa<GH0ol0000OojKVXPSo00008oncRi42o`0000co/j[=1?l0000Goj[DZ@Co
00003_ng/=D5o`00017oU7jG0_l0000HolN^/`;o00003onYNjd4o`0001?ofLK/1Ol00002ojYnPPCo
00008OnSX;@3o`0002;oZ=OJ1Ol0000YogR0K@?o00004_nVWZL3o`00oaWoYYjW0_l0001]ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Cooooo0_l0000HokB>S0?o0000
4_nZ[YD2o`00017oa<GH0ol0000MojKVXPCo000000?oO[JVo`000?l000001Ol0000Pok>;T@?o0000
2_ncZ/d4o`0001[oZ]BY0ol0000;okN`e@Go00004onDOYL2o`0001Soajjc0_l0000@ojUk[@Co0000
4?oIa^`5o`0000GoZWj21Ol0000Ooj>P]0;o00008_nXemX3o`000003olo]b?l0003o000002[oN81]
0_l0000^ojJNY`;o0000KOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Dooooo`;o00005ondSX`3o`0001?oZZjE0_l0000BolC5f0?o00006_nViZ86o`0000CoO[JV1_l0
000Ook>;T@;o00002OncZ/d3o`0001goZ]BY0ol00009okN`e@Co00005OnDOYL3o`0001Ooajjc0_l0
000BojUk[@Co00003?oIa^`5o`0000WoZWj21?l0000Moj>P]0?o00008OnXemX3o`0000;ocng80ol0
000YogR0K@?o0000;?nVWZL3o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0E?ooool2o`0001Ko]8j<0ol0000DojZ^U@;o00004oo4aMP3o`0001OoY^JR1Ol00000
1?o5WJ;o0000o`000?l00006ogjfYPKo00007?ncRi42o`0000Oo/j[=1?l0000Ooj[DZ@?o00001_ng
/=D4o`0001SoU7jG0_l0000GolN^/`;o00004onYNjd4o`0000[ofLK/1?l0000=ojYnPPCo00006_nS
X;@3o`00027oZ=OJ0ol00004olo]b0;o0000:_mhP6d2o`0002_oYYjW0ol0001^ooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Cooooo0_l0000EokB>S0?o00005OnZ[YD2
o`0001Coa<GH0ol0000EojKVXPCo00001?o5WJ82o`0000SoO[JV1ol0000Iok>;T@;o00001_ncZ/d4
o`00027oZ]BY0ol00003okN`e@Go00006OnDOYL2o`0001Ooajjc0_l0000EojUk[@?o00001ooIa^`4
o`00013oZWj21Ol0000Goj>P]0?o00008OnXemX3o`0000Gocng80_l0000ZogR0K@;o0000:OnVWZL5
o`0006kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E?ooool2o`00
01Co]8j<0ol0000FojZ^U@;o00005Oo4aMP3o`0001;oY^JR1?l00006olFMXP;o00002omn]ZH7o`00
01Ko/h^A0ol00004ok>Zc@?o00009?nZe:T8o`0001_oU7jG0_l0000GolN^/`;o00005_nYNjd4o`00
00?ofLK/1Ol0000CojYnPPCo00005OnSX;@3o`00027oZ=OJ0ol00006olo]b0?o0000:OmhP6d4o`00
02CoYYjW2Ol0001]ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Co
oooo0_l0000CokB>S0?o00005onZ[YD2o`0001Koa<GH0ol0000?ojKVXPGo00001oo5WJ82o`0000ko
O[JV1_l0000Dok>;T@Wo00009_nZe:T5o`0001goU7jG0_l0000GolN^/`;o00005onYNjd9o`0001Oo
ZWj21?l0000Boj>P]0?o00008OnXemX3o`0000Socng80_l0000YogR0K@Go00008OnVWZL6o`0000?o
Yg:;0_l0001]ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Cooooo
0_l0000BokB>S0?o00006?nZ[YD2o`0001Ooa<GH0ol0000=ojKVXPCo00002Oo5WJ82o`00017oO[JV
1_l0000@ok>;T@[o00009onZe:T2o`0001ooU7jG0ol0000FolN^/`;o00006OnYNjd5o`0001[oZWj2
1?l0000@oj>P]0?o00008OnXemX3o`0000Wocng80_l0000XogR0K@?o000000Co]^B_o`000?l0003o
00007_nVWZL5o`0000KoYg:;0ol0001/ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo05Cooooo0_l0000AokB>S0?o00002onZ[YD3o`00o`_oZZjE0_l0000;olC5f0?o003o
2_o4aMP3o`0000[oY^JR1?l0000;olFMXP?o00004_mn]ZH7o`0000co/h^A0ol00006olCCW@?o0000
4onZe:T3o`00o`ooZ]BY0ol0000PoiAnU`;o00004_o7[[<3o`00o`04olN^/ol0003o0000ojUk[@?o
003o5_nYNjd2o`0001koZWj21?l0000=oj>P]0?o00008OnXemX3o`0000[ocng80_l0000FogR0K@?o
003o3_mhP6d3o`0000?o]^B_0ol0000JojJNY`Ko00002OnWLX/2o`0006cooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0E?ooool3o`0000oo]8j<0ol0000;ojZ^U@Go003o
2_nZ[YD2o`0000[oa<GH1Ol00?l:olC5f0?o00002?nViZ84o`0000goaIfR0_l0000EogjfYPKo0000
2?ncRi44o`0000Soa=>M0ol0000Aoj[DZ@Go003o3_nZe:T2o`00027oU7jG0_l0000AolN^/`Go003o
0_l00005o`00oaGoZG^]0_l0000OojYnPPGo00002?nSX;@5o`00027oZ=OJ0ol0000;olo]b0?o0000
5?mhP6d5o`00o`coN81]0ol00005okKT[`?o00005onVWZL6o`0000_oYg:;0_l0001/ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Gooooo0ol0000=okB>S0?o00003?nZ
[YD5o`00o`[oZZjE0_l0000:olC5f0Go003o2oo4aMP3o`0000GoY^JR1?l0000?olFMXP;o00006?mn
]ZH6o`0000Co/h^A1?l0000:olCCW@?o00004?nZe:T5o`00o`koZ]BY0_l0000QoiAnU`;o00004Oo7
[[<5o`00o`;o00001Ol00?lDojUk[@Co00008?nZOX84o`0000;oXj2d2Ol0000QojSGfP?o00003Oo?
kLP2o`0001CoN81]1Ol00?l;ogR0K@?o00001onfi:l3o`0001CoYYjW1Ol0000>ojMbR`?o0000Jooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Fooooo`?o00002ondSX`3
o`0000goZZjE1Ol00?l:ojZ^U@;o00002_o4aMP5o`00o`coa<GH0ol00002ojKVXPGo00004?o5WJ82
o`0001[oO[JV2_l0000=olCCW@?o00003onZe:T5o`00o`goZ]BY0ol0000QoiAnU`;o00004Oo7[[<5
o`00o`;o00001Ol00?lCojUk[@Go00008_nZOX8:o`000004ojS4W_l0003o0000o`0001ooZ=OJ0ol0
000>olo]b0;o00005?mhP6d5o`00o`[oN81]0ol00009okKT[`?o00004OnVWZL5o`00017oYg:;0_l0
001[ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Oooooo0ol00009
okB>S0?o00003onZ[YD3o`00o`_oZZjE0_l0000;olC5f0?o003o3_o4aMP7o`0001;oaIfR0_l0000M
ogjfYPKo00003oo4did3o`0000ooZ]BY0ol00?l>oj[DZ@;o00008_nDOYL3o`00017oajjc0ol00?l0
1?o7[[?o0000o`000?nYNjd3o`00oa?oZG^]0ol000001?mmR8So0000o`000?l0000RojYnPPCo0000
1onXa9h3o`0001CoZ=OJ0ol00?l6ojSGfP?o00003oo?kLP3o`0001CoN81]0ol00?l:ogR0K@?o0000
2onfi:l3o`0000goYYjW1_l0000CojMbR`?o0000J_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Hooooo`?o00001OndSX`5o`0001koZZjE0_l0000MolC5f0Co00005?o5
WJ83o`0001ooO[JV0_l0000AolCCW@?o00007onZe:T3o`0002;oU7jG0_l0000EolN^/`;o00005_nY
Njd3o`0000?oOHR80_l0000RojYnPP;o00002_nXa9h3o`0001;oZ=OJ1Ol00?l4ojSGfP?o00004Oo?
kLP2o`00023oN81]0ol0000=okKT[`?o00002_nVWZL6o`0001KoYg:;0_l0001Zooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Wooooo0ol000000ondSXco0000o`000009
o`0001_oZZjE0_l0000NolC5f0;o00005_o5WJ82o`0001ooO[JV0_l0000BolCCW@?o00007OnZe:T5
o`00027oU7jG0_l0000EolN^/`;o00005OnYNjd3o`0000CoOHR80ol0000PojYnPP?o00002onXa9h3
o`00017oZ=OJ1Ol00?l3ojSGfP?o00004_o?kLP2o`0001ooN81]0ol0000?okKT[`?o00001onVWZL5
o`0001WoYg:;0ol0001Yooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
05[ooooo1ol00003olN/i@Ko00006OnZ[YD2o`0001goa<GH0ol0000FolFMXP;o00007_mn]ZH3o`00
01?oa=>M0ol0000Koj[DZ@?o000000CobI6Qo`000?l0003o00008?nDOYL2o`0001Goajjc0_l0000D
ojUk[@?o00001_mmR8P2o`00023oZWj20_l0000=ojS4WP?o00004?nXemX5o`00o`;oZ=OJ0ol0000C
olo]b0;o00007_mhP6d3o`00017o]^B_0ol00003ojJNY`Ko00007?nWLX/2o`0006Wooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Foooool3o`0000WoajcU1Ol0000GojZ^
U@;o00007?o4aMP5o`0001GoaIfR0_l0000NogjfYP;o00005Oo4did3o`0001WoZ]BY0ol00003olVA
X@?o00002onDOYL3o`00oa7oU7jG0_l0000EolN^/`;o00004onYNjd3o`0000OoOHR80ol0000OojYn
PP;o00003_nXa9h3o`00013oZ=OJ0ol00?l2ojSGfP?o00005?o?kLP3o`0001coN81]0ol0000CokKT
[`Wo00007_nWLX/2o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Foooool2o`0000coajcU1_l0000DojZ^U@;o00006oo4aMP3o`000004okJILOl0003o0000o`00
01CoaIfR0_l0000NogjfYP;o00005_o4did3o`0001OoZ]BY0ol00005olVAX@?o00002OnDOYL5o`00
oa3oU7jG0ol0000DolN^/`;o00004onYNjd2o`0000WoOHR80_l0000OojYnPP;o00003onXa9h3o`00
01?oZ=OJ0ol0000Folo]b0;o00006omhP6d3o`0001Go]^B_1Ol0000QojMbR`?o0000J?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Kooooo`;o00003_o7[>D6o`0001;o
ZZjE0_l0000JolC5f0?o00000onfVG42o`0001CoaIfR0ol0000MogjfYP;o00005oo4did3o`0001Ko
Z]BY0_l00007olVAX@?o00002?nDOYL5o`00oa7oU7jG0_l0000DolN^/`;o00004_nYNjd3o`0000Wo
OHR80ol0000MojYnPP?o00004?nXa9h3o`00017oZ=OJ0ol0000Golo]b0;o00006_mhP6d3o`0001Oo
]^B_0_l0000TojMbR`;o0000J?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1Kooooo`;o00004Oo7[>D5o`00013oZZjE0_l0000IolC5f0?o00001?nfVG43o`0001CoaIfR
0_l00008ogjfYP?o003o4_mn]ZH2o`0001Soa=>M0ol0000Doj[DZ@?o00002?o9TJ43o`0000OoU7jG
1Ol00?lAoiAnU`;o00005?o7[[<2o`00017oZG^]0ol0000;ogf8R0;o00007OnZOX82o`0001;oZ<BN
0ol0000?ojSGfP?o00000_o?kLP3o`00oa?ocng80_l0000IogR0K@?o00006?nfi:l2o`0002CoYg:;
0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0
000ColN/i@Ko00003?nZ[YD4o`0001Ooa<GH0ol00006okJIL@?o00004oo5WJ82o`0000OoO[JV1Ol0
0?l@ogjfYP?o00006Oo4did3o`0001;oZ]BY0ol0000:olVAX@?o00001onDOYL3o`00oa;oU7jG0_l0
000DolN^/`;o00004?nYNjd3o`0000coOHR80ol0000LojYnPP;o00004onXa9h2o`0000koZ=OJ0ol0
0002olo]b0Go003o4_o?kLP3o`0001OoN81]0ol0000IokKT[`;o00008onWLX/3o`0006Sooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Foooool2o`0001GoajcU1_l00008
ojZ^U@So00005?o4aMP3o`0000So]YUa0_l0000ColFMXP;o00001omn]ZH5o`00oa3oO[JV0_l0000K
olCCW@?o00004?nZe:T3o`0000cobI6Q0ol0000KoiAnU`;o00005?o7[[<2o`0000ooZG^]0ol0000>
ogf8R0;o00007?nZOX82o`0001?oZ<BN0ol0000<ojSGfP?o00000oo?kLP5o`00oa?ocng80_l0000F
ogR0K@?o00006_nfi:l2o`0002?oYg:;0_l0001Yooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo05_ooooo0_l0000HolN/i@Go00001OnZ[YD4o`0000;oX[=m1_l0000@olC5
f0?o00002OnfVG43o`0001;oaIfR0_l00007ogjfYPGo003o4?mn]ZH2o`0001coa=>M0ol0000>oj[D
Z@?o00003_o9TJ43o`0001[oU7jG0ol0000ColN^/`;o00003_nYNjd3o`0000ooOHR80ol0000JojYn
PP?o00005?nXa9h3o`0000[oZ=OJ0ol00004olo]b0Go003o4oo?kLP2o`0001GoN81]0ol0000KokKT
[`;o00008onWLX/2o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Foooool2o`0001[oajcU2_l00006oj:cO@Ko00003Oo4aMP3o`0000_o]YUa0ol00008olFMXP?o
003o1_o5WJ83o`0000OoO[JV0ol00?lAogjfYP;o00007Oo4did3o`0000goZ]BY0_l0000@olVAX@?o
00006_nDOYL2o`0001?oajjc0_l0000;ojUk[@Go00004OmmR8P2o`0000WoZWj20ol00?l>ojYnPP;o
00005_nXa9h3o`0000SoZ=OJ0ol00006olo]b0?o003o5?o?kLP3o`0001?oN81]0ol0000:okKT[`?o
003o3onfi:l2o`0000ooYg:;0ol00?l@ojMbR`?o0000JOooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1Kooooo`;o00007?o7[>D7o`0000[oX[=m1Ol0000:olC5f0?o0000
3OnfVG42o`0000OoaIfR1Ol00?l6olFMXP;o00006_mn]ZH3o`0001koa=>M0ol0000;oj[DZ@?o0000
4Oo9TJ43o`0001WoU7jG0_l0000ColN^/`;o00001onYNjd8o`0001;oOHR80ol00007ojYnPPGo003o
3OnZOX82o`0001OoZ<BN0ol00006ojSGfP?o00007_o?kLP4o`00017oN81]0ol0000:okKT[`Go003o
3_nfi:l2o`0000koYg:;1Ol00?l?ojMbR`;o0000J_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Kooooo`;o00007oo7[>D2o`0000koX[=m1Ol00007olC5f0?o00003_nf
VG43o`0000KoaIfR1Ol00?l6olFMXP;o00006_mn]ZH2o`00023oa=>M0ol00009oj[DZ@?o00004oo9
TJ43o`0001SoU7jG0_l0000ColN^/`;o00001?nYNjd8o`000004om;5^?l0003o0000o`0001;oOHR8
0_l00007ojYnPPGo003o3?nZOX83o`0001SoZ<BN0ol00004ojSGfP?o00007_o?kLP7o`0000koN81]
0ol0000;okKT[`Go003o3_nfi:l2o`0000koYg:;1Ol00?l?ojMbR`;o0000J_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Kooooo`;o00007_o7[>D3o`00013oX[=m1_l0
0003olC5f0?o00004?nfVG43o`0000GoaIfR1Ol00?l6olFMXP;o00006_mn]ZH2o`00027oa=>M0ol0
0007oj[DZ@?o00005Oo9TJ43o`0001OoU7jG0_l0000ColN^/`[o00001_oBaKP2o`0001;oOHR80ol0
0006ojYnPPGo003o3?nZOX82o`0001[oZ<BN0ol00002ojSGfP?o00007_o?kLP3o`0000;oal?@1Ol0
000;ogR0K@?o00003?nfi:l5o`00o`ko]^B_0_l0000>ojMbR`Go003o3_nWLX/3o`0006[ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool3o`00013oajcU0ol00?l;
olN/i@;o00004onR/gd9o`0001;o]YUa0ol00005olFMXP?o003o1oo5WJ82o`0001[oO[JV0_l0000A
olCCW@?o003o3_o4did3o`0000KoZ]BY0_l0000?olVAX@?o003o1Oo9TJ43o`0001KoU7jG0ol0000A
olN^/`So00002OoBaKP2o`0001?oOHR80_l00007ojYnPP?o003o3OnZOX82o`0001_oZ<BN1_l0000N
olo]b0?o00001Oo7`m05o`0000SoN81]0ol0000>okKT[`?o003o3onfi:l2o`0000ooYg:;0ol00?l?
ojMbR`;o0000Joooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Joooo
o`;o00004?o7[>D5o`00o`[oajcU0_l0000Foj:cO@Go00005?nfVG42o`0000ooaIfR0ol0000Iogjf
YP;o00004?o4did5o`00o`koa=>M0ol00004oj[DZ@?o00003_o9TJ45o`00o`GobI6Q0ol0000FoiAn
U`;o00003oo7[[<6o`0000god/Fh0ol0000Bogf8R0;o00005onZOX82o`0001coZ<BN1?l0000Nolo]
b0?o00002?o7`m04o`0000KoN81]0ol0000QokKT[`;o00008OnWLX/2o`0006_ooooo00?o0000oooo
ooooool02?ooool001[ooooo0ol0001Jooooo`;o00004?o7[>D5o`00o`WoajcU0ol0000Hoj:cO@;o
00005OnfVG43o`0000ooaIfR0_l0000HogjfYP?o00004?o4did5o`00o`ooa=>M0ol00002oj[DZ@?o
00003oo9TJ45o`00o`KobI6Q6_l0000=olN^/`Go00004OoBaKP2o`0001;oOHR80ol0000EojYnPP?o
00007OnXa9h2o`0001kocng80ol0000;olO3d0Co00000omhP6d3o`00023o]^B_1?l0000PojMbR`?o
0000JOooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo05[ooooo0_l0000@olN/i@Go003o
2Oo7[>D2o`0001WoX[=m0_l0000FokJIL@?o00003_o5WJ82o`0001SoO[JV0_l0000AolCCW@Go003o
4?o4did6o`00013obI6Q1Ol00?l6olVAXA[o00002oo7[[<5o`0001?od/Fh0ol0000Bogf8R0;o0000
5OnZOX82o`0001koZ<BN0ol0000Lolo]b0?o00003Oo7`m08o`0001co]^B_2Ol0000PojMbR`;o0000
K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00004Oo7
[>D3o`00o`[oajcU0_l0000Ioj:cO@;o00004?nfVG43o`00o`Co]YUa0_l0000>olFMXP;o00006?mn
]ZH2o`0001;oa=>M0ol00?lBolCCW@Co00004_o9TJ43o`00o`KobI6Q0ol0000FomV^aP?o00002?o7
[[<5o`0001Kod/Fh0_l0000:ogf8R0?o003o1OmmR8P3o`0001CoZWj20_l0000>ojS4WP?o003o3_nX
a9h2o`0001_ocng80ol0000@olO3d0Go00006Onfi:l:o`000004onJQ__l0003o0000o`0001ooYg:;
0_l0001/ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05[ooooo0_l0
000MolN/i@?o00006OnR/gd3o`0000ko]YUa1Ol00?l3okJIL@?o00003Oo5WJ82o`0001SoO[JV0_l0
000VolCCW@Ko00006Oo9TJ43o`0001SofJk60ol00005olN^/`Go00006?oBaKP2o`0000WoOHR81Ol0
0?l5ogf8R0;o00005?nZOX82o`0000goZ<BN1Ol00?l=ojS4WP;o00006_o?kLP3o`0001?oal?@0_l0
000FokKT[`Wo00001ooVXKh2o`0001ooYg:;0_l0001/ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo05[ooooo0_l0000MolN/i@;o00006onR/gd2o`0000ko]YUa1Ol00?l4
okJIL@?o00003?o5WJ83o`0001OoO[JV0_l0000UolCCW@?o00000_nJUjD3o`0001OobI6Q0ol0000J
omV^aP;o00000oo7[[<5o`0001[od/Fh0ol00008ogf8R0Go003o1OmmR8P3o`0001;oZWj20ol0000=
ojS4WPGo003o3OnXa9h3o`0001Oocng81?l0000DolO3d0?o00004?nfi:l:o`0000_oiZ6n0ol0000M
ojMbR`?o0000K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Joooo
o`;o00007Oo7[>D2o`0001_oX[=m0_l0000>okJIL@Go003o1OnfVG42o`0000goaIfR0_l0000Fogjf
YP?o00009?o4did3o`0000CoVYNU0ol0000EolVAX@?o00006ooI[/H8o`0001god/Fh0_l00008ogf8
R0Go003o1_mmR8P2o`0001;oZWj20_l0000>ojS4WPGo003o3_nXa9h2o`0001Kocng81?l0000FolO3
d0?o00002onfi:l:o`00013oiZ6n0_l0000MojMbR`;o0000KOooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Jooooo`;o00007?o7[>D3o`0000WoX[=m0ol00?l?oj:cO@;o
00003onfVG43o`00o`Ko]YUa0ol0000;olFMXQgo00008_o4did3o`0000KoVYNU0ol0000ColVAX@?o
00007OoI[/H5o`0001ood/Fh0ol00008ogf8R0?o003o1ommR8P3o`00017oZWj20_l0000?ojS4WP?o
003o3onXa9h2o`0001Gocng80ol0000IolO3d0;o00001onfi:l9o`0001GoiZ6n0_l0000MojMbR`;o
0000KOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o0000
7?o7[>D2o`0000WoX[=m1Ol00?l>oj:cO@;o00006OnfVG43o`0000WoaIfR8Ol0000NolCCW@?o0000
2?nJUjD3o`00017obI6Q0ol0000OomV^aP;o00008_oBaKP2o`0001?oOHR80_l0000AojYnPP;o0000
8OnXa9h3o`0001?ocng80ol0000JolO3d0?o000000?o]^B_o`000?l000002?l0000IonJQ_PGo0000
6OnWLX/3o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_oo
ool2o`0001coajcU0_l00009oj:cO@Go003o3_nR/gd2o`0001[o]YUa0_l00008olFMXP?o00006?nl
X<H2o`000003oiNQ]ol0003o000000Go00006_o4did3o`0000[oVYNU0ol0000?olVAX@?o00008?oI
[/H2o`0002;od/Fh0ol0000Bogf8R0?o00003onZOX83o`0002;oZ<BN0_l0000Bolo]b0?o00007?o7
`m09o`0001koiZ6n2?l0000EojMbR`;o0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Jooooo`;o00006oo7[>D3o`0000WoX[=m1Ol00?l>oj:cO@;o00006_nfVG43
o`0000KoaIfR0ol0000IokbPaP;o00001?nGXKL7o`0001Koa=>M0ol0000<oiZGY@Co00003?o9TJ43
o`00027ofJk60_l0000Som;5^0;o00004ommR8P2o`0000koZWj21?l0000RojS4WP;o00004Oo?kLP3
o`0001koal?@0ol0000RonJQ_P?o000000?oblffo`000?l000001ol0000AojMbR`;o0000K_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00006oo7[>D2o`00
00_oX[=m0ol00?l?oj:cO@?o00006_nfVG46o`000004olFMX_l0003o0000o`0001[o_:360_l00007
oiNQ]`So00004Oo4did3o`0000koVYNU1?l0000:olVAX@?o00001ooI[/H3o`00oaSofJk60_l0000I
om;5^0?o003o1ooBaKP2o`0001?oOHR80ol0000:ojYnPPSo00008OnXa9h3o`0000oocng80ol0000O
olO3d0;o00004ooVXKh3o`00o`goiZ6n0_l00006ol_=]PWo00003?nWLX/3o`0006kooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool3o`0001[oajcU0_l0000Noj:c
O@;o00005onfVG4<o`0001_o_:360_l0000:oiNQ]`So00003Oo4did3o`00017oVYNU0ol00008olVA
X@?o00001ooI[/H5o`00oaOofJk60_l0000Hom;5^0Go003o1_oBaKP3o`0001?oOHR80_l00007ojYn
PPOo00000_nQTkT3o`00027oZ<BN0_l0000>olo]b0?o00008?o7`m03o`00017oiZ6n1Ol00?l;onJQ
_P?o00002_o;cKH8o`0000WoYg:;0_l0001_ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo05_ooooo0ol0000HolN/i@?o00007_nR/gd2o`0001Co]YUa1ol00004oh2YZ0?o
00006onlX<H3o`0000koUj6g1ol00009olCCW@?o00004onJUjD3o`0000KobI6Q0ol00008omV^aPGo
003o5ooI[/H2o`0001Sod/Fh1Ol00?l7om;5^0;o00004ommR8P3o`0000?oZWj21ol00006oj6C^@Co
00007onXa9h2o`0000gocng80ol0000RolO3d0;o00004OoVXKh5o`00o`_oiZ6n0_l0000?ol_=]PSo
00001OnWLX/2o`0006oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
G?ooool3o`0001OoajcU0_l0000Noj:cO@Co00004?nfVG47o`0000SoP:VX0_l0000KokbPaP;o0000
4_nGXKL7o`0000Goa=>M0ol0000EoiZGY@?o00001?o9TJ43o`0000WofJk61Ol00?lGomV^aP;o0000
6?oBaKP5o`00o`Ood/Fh0ol0000Cogf8R0Wo00002_nQTkT4o`0001koZ<BN0ol0000;olo]b0?o0000
8oo7`m02o`00017oiZ6n1Ol00?l:onJQ_P?o00004_o;cKH<o`0006oooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0GOooool3o`0001KoajcU0_l0000Moj:cO@So00002onf
VG46o`0000_oP:VX0_l0000KokbPaP;o00005OnGXKL7o`000004olCCWOl0003o0000o`0001OoVYNU
0ol00002olVAX@?o00002ooI[/H3o`00oaSofJk60_l0000Iom;5^0?o003o2OoBaKP2o`0001?oOHR8
1_l0000?oj6C^@?o00007_nXa9h2o`0000Wocng81?l0000TolO3d0;o00004_oVXKh3o`00o`_oiZ6n
0_l0000Gol_=]POo0000L?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Nooooo`?o00005?o7[>D3o`0001coX[=m0ol00002oiJRR0Ko00001_nfVG46o`0000koP:VX0ol0
000JokbPaP;o00006?nGXKL7o`0001WoVYNU1_l0000WomV^aP;o00009OoBaKP2o`0001CoOHR80_l0
000Coj6C^@?o00007OnXa9h2o`0000Oocng82?l0000RolO3d0;o00007ooVXKh3o`0001_oblff0ol0
001`ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05oooooo0ol0000C
olN/i@;o00007?nR/gd3o`0000KoUZ:83Ol0000Aoh2YZ0;o00006_nlX<H2o`0001_oUj6g0ol0000K
oiZGY@Co0000:?oI[/H2o`0002God/Fh0ol0000Bogf8R0?o00005?nQTkT6o`0001WoZ<BN0ol00004
olo]b0Go00000_ncX]P5o`00023oal?@0ol0000NonJQ_P;o00007Oo;cKH2o`00073ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0H?ooool2o`0001?oajcU0_l0000Koj:c
O@?o00002OnFXXP8o`0001CoP:VX0_l0000:okbPaP?o003o3OnlX<H2o`0001coUj6g0_l0000LoiZG
Y@;o0000:OoI[/H2o`0002Kod/Fh0_l0000Aogf8R0?o00005_nQTkT;o`0001CoZ<BN0_l00002olo]
b0Go00001_ncX]P5o`0000_oal?@0ol00?lAolO3d0;o00007OoVXKh3o`0001goblff0_l0001`oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo063ooooo0ol0000AolN/i@?o
00006_nR/gd3o`0000goUZ:80_l0000Goh2YZ0;o00002OnlX<H5o`00o`co_:360_l0000LoiNQ]`;o
00007?nJUjD3o`0002SofJk60_l0000Vom;5^0?o00003ommR8P3o`0001OoXI>i0_l00002ol7LY0ko
00003OnXa9h7o`0000[o/j;H1Ol00008olO3d0Go003o4?o7`m02o`0001goiZ6n0_l0000Mol_=]P?o
0000L?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Qooooo`?o0000
4?o7[>D2o`0001[oX[=m0ol0000>oiJRR0?o00005_n0ZJP2o`0000Wo_:361Ol00?l<okbPaP;o0000
7?nGXKL2o`0001goVYNU0_l0000XomV^aP;o00009ooBaKP2o`0000koOHR80ol0000Goj6C^@?o0000
2?o1g:@>o`0000OoZ<BN1Ol0000>ok>Rf0Go00001_o7`m05o`00oa3oal?@0_l0000LonJQ_P?o0000
7Oo;cKH2o`00077ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0H_oo
ool3o`0000ooajcU0_l0000Ioj:cO@?o00004?nFXXP2o`0001KoP:VX0_l00009okbPaPGo003o3?nl
X<H2o`0001coUj6g0_l0000MoiZGY@;o0000:?oI[/H2o`0002Ood/Fh0_l0000=ogf8R0?o00006?nQ
TkT2o`00013o`MbT3Ol00002ojS4WP;o00004_ncX]P5o`0000Coal?@1Ol00?l@olO3d0;o00007?oV
XKh2o`0001koblff0_l0001aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo06?ooooo0ol0000=olN/i@?o00006?nR/gd3o`00017oUZ:80ol0000:oh2YZ0?o003o2?n0ZJP2
o`0000[o_:360ol00?l<okbPaP?o00003OnGXKL3o`00o`coUj6g0_l0000=oiZGY@?o003o3OnJUjD3
o`0002OofJk60_l0000Wom;5^0Ko00002?mmR8P3o`0001WoXI>i0_l0000Fol7LY0_o00005?ncX]P5
o`0000?oal?@0ol00?lAolO3d0?o00006_oVXKh3o`0000[oblff0ol00?l@ol_=]P?o0000LOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Tooooo`?o00003?o7[>D2o`00
01SoX[=m0ol0000CoiJRR0;o00002On0ZJP5o`00o`OoP:VX0ol0000HokbPaP;o00003OnGXKL5o`00
o`_oUj6g0_l0000<oiZGY@Go003o3OnJUjD2o`0002OofJk60_l0000Tom;5^0ko00000_mmR8P3o`00
01[oXI>i0_l0000Lol7LY0Co00005oncX]P5o`0001Goal?@1?l0000IonJQ_P;o00002_o;cKH5o`00
o`ooblff0_l0001booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Go
oooo0_l0000<olN/i@;o00005onR/gd3o`0001CoUZ:80_l00009oh2YZ0Go003o2?n0ZJP2o`0001So
_:360_l0000=oiNQ]`Go003o2onGXKL2o`0000coVYNU1Ol00?l=oiZGY@;o00009ooI[/H2o`0002;o
d/Fh1_l00004ol_LmP[o00006_nQTkT3o`0001ko`MbT0_l0000Iok>Rf0Go00004_o7`m06o`0001Oo
iZ6n0ol0000:ol_=]PGo003o3oo;cKH2o`0007;ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0IOooool3o`0000[oajcU0ol0000Foj:cO@?o00005OnFXXP3o`0000SoP:VX
1Ol00?l8oh2YZ0;o00006?nlX<H2o`0000goUj6g1Ol00?l;oiNQ]`;o00003?nJUjD5o`00o`coVYNU
1?l0000TomV^aPCo00008?oBaKP5o`0000cobmcf1?l0000Koj6C^@;o00007oo1g:@3o`0001[o/j;H
1Ol0000?olO3d0?o00000_mhSI@4o`0001GoiZ6n0_l0000;ol_=]PGo003o3_o;cKH3o`0007;ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0I_ooool3o`0000SoajcU7?l0
000GoiJRR0;o00002On0ZJP3o`00o`WoP:VX0_l0000HokbPaQ3o00000ol00?l>o`0000goVYNU0ol0
0?l:oiZGY@So00007_oI[/H9o`0001god/Fh1_l0000@ol_LmP?o00004OnQTkT3o`00o`KoXI>i0_l0
000Ool7LY0Co00006?ncX]P3o`00o`Go00003?o7`m03o`0000CoN8fD1Ol0000BonJQ_P?o00003?o;
cKH3o`00o`ooblff0_l0001cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo06Oooooo0ol00005olN/iAgo00006?nFXXP3o`0001CoP:VX0_l0000HokbPaPoo00001Ol00?l=
o`0001OoVYNU1ol00002og^AMP?o00006?oI[/H;o`000004ok:_W_l0003o0000o`0001[od/Fh1_l0
000Col_LmP;o00004?nQTkT5o`00o`GoXI>i0_l0000Nol7LY0Ko00005_ncX]P5o`00o`03ok>Rf?l0
003o000000?o00002Oo7`m03o`0000OoN8fD1?l0000AonJQ_P;o00007oo;cKH2o`0007?ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0J?ooool3o`0000?oajcU1?l0000H
ohjiV0?o00006?nFXXP2o`0001CoP:VX0_l0000HokbPaP;o00003Oo_en<5o`00o`_okmOS0_l0000D
oiZGY@Oo00001_mkTGH3o`0001;ofJk62ol00007ok:_WP?o00005ooBaKP5o`0001Kobmcf0_l0000@
oj6C^@Go003o1?nQTkT3o`0001ko`MbT0_l00002ohg8X@?o00005OncX]P5o`00o`?o/j;H1Ol00006
olO3d0?o00002_mhSI@4o`0000koiZ6n0ol0000Nol_=]P?o0000Loooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1Yooooo`Oo00006on>^IP2o`0001SoUZ:80ol0000Coh2Y
Z0;o00005onlX<H3o`0000gokmOS1Ol00?l;onoGh`;o00004OnJUjD7o`0000[oNi5f0ol0000=omV^
aP[o00003Onb[ih3o`0001?od/Fh1_l0000Hol_LmP?o00003onQTkT5o`00o`CoXI>i0_l0000Nol7L
Y0?o00000on=b:43o`0001Co/j;H1Ol00?l5ok>Rf0Go00000oo7`m03o`0000coN8fD1Ol0000<onJQ
_P;o00007oo;cKH2o`0007Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0J_ooool5o`0001coS[VH0ol0000=oiJRR0?o003o2?nFXXP2o`0001?oP:VX0ol0000FokbPaP;o
00003oo_en<3o`00o`cokmOS0_l0000=oiZGY@So00003_mkTGH3o`0000OofJk62_l0000Cok:_WP?o
00004?oBaKP6o`0001_obmcf0_l0000@oj6C^@?o003o1OnQTkT2o`0000Ko`MbT0ol00?lEol7LY0;o
00001On=b:44o`0001?o/j;H0ol00?l8ok>Rf0So00003omhSI@4o`0000[oiZ6n0ol0000Ool_=]P;o
0000M?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o0000
7on>^IP2o`0000coUZ:81Ol00?l7oiJRR0;o00005?n0ZJP2o`0001Ko_:360_l0000NonoGh`?o0000
2OnJUjD8o`0001;oNi5f0ol000000ooI[/Ko0000o`000009o`0001So/ZnN0ol0000=om;5^0Go0000
7_o;g?H2o`0001SoXI>i0_l00005ol7LY0Go003o4oo1g:@3o`0000KoSLRQ1?l0000Ook>Rf0Go0000
4_mhSI@4o`0000SoiZ6n0_l0000Ool_=]P?o0000M?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1[ooooo`;o00007on>^IP3o`0000_oUZ:81Ol00?l7oiJRR0?o00004on0
ZJP2o`0001Go_:360ol0000OonoGh`;o00001_nJUjD7o`0001OoNi5f2Ol0000Nok:_WP;o00002_oB
aKP6o`00023obmcf0ol0000Foj6C^@?o00001Oo1g:@5o`00oa;o`MbT0ol00009ohg8X@?o00007onc
X]P3o`0001CoN8fD1Ol00004onJQ_PCo00007oo;cKH2o`0007Gooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0J_ooool3o`00023oS[VH0_l0000;oiJRR0Go003o2?nFXXP2
o`0001?oP:VX0_l0000DokbPaPCo00007oo_en<2o`0000?oVYNU1ol0000Iog^AMPGo00008onb[ih3
o`0000Ood/Fh1_l0000Sol_LmP;o00005_nQTkT2o`0000Ko`MbT1Ol00?lBol7LY0;o00002on=b:43
o`0001_o/j;H1Ol0000GogR=U0ko00007?o;cKH2o`0007Gooooo00?o0000ooooooooool02?ooool0
01[ooooo0ol0001Zooooo`;o00008On>^IP3o`0000_oUZ:80ol00?l9oiJRR0?o00004_n0ZJP2o`00
017o_:362?l0000NonoGh`Wo00002OmkTGH3o`00o`ooNi5f1Ol0000Uok:_WP?o00001?oBaKP5o`00
02Kobmcf0_l0000Foj6C^@;o00001oo1g:@3o`00oa;o`MbT0ol0000<ohg8X@Co00005OncX]P8o`00
01[oN8fD1_l00002oinWO@Ko00006Oo;cKH3o`0007?ooooo0ol0000:ooooo`006_ooool00ol0003o
ooooooooo`1Zooooo`;o00008_n>^IP2o`0001SoUZ:80_l0000Boh2YZ0;o00003_nlX<H7o`0000;o
/lJ60ol0000MonoGh`Ko00002omkTGH5o`00o`coNi5f1?l000000oo@aOGo0000o`00000Vok:_WPWo
0000:?o;g?H3o`0001GoXI>i0_l0000Lol7LY0;o00003_n=b:44o`00013o/j;H2Ol000000onYd=go
0000o`00000KogR=U0;o00002?nOYgd5o`0001Ooblff0_l0001fooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06Wooooo0ol0000RohjiV0?o00005onFXXP3o`00017oP:VX
0_l0000;okbPaPOo00001_ncaXH3o`0001cokmOS0ol0000>og^AMPGo003o2omkTGH4o`0000;od<Ge
0ol0000Vok:_WPKo0000:oo;g?H2o`0001CoXI>i0ol0000Kol7LY0?o00004?n=b:43o`0000_o/j;H
2Ol00005ojW@g@;o00006omhSI@2o`0000[oWjMm1_l0000Dol_=]P;o0000M_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`;o00009?n>^IP2o`0001SoUZ:80_l0
000Aoh2YZ0?o00001onlX<H7o`0000[o/lJ60ol0000JonoGh`Co00003_mkTGH5o`00o`[oNi5f0ol0
0005om35m@;o00009onb[ih2o`0002kobmcf0_l0000Doj6C^@;o00007?o1g:@2o`0001;oSLRQ0ol0
0006ok>Rf0Wo00002OnYd=d2o`0001[oN8fD0ol0000<oinWO@Ko00004Oo;cKH3o`0007Kooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool2o`0002CoS[VH0ol0000G
oiJRR0;o00004_n0ZJP2o`0000Co_:361ol0000>ok?6QPCo00005oo_en<6o`0000koNi5f0ol00?l9
og^AMPCo00001_o@aOD2o`0002Oo/ZnN0_l0000Lol_LmP?o003o3oo;g?H3o`0001?oXI>i0_l0000K
ol7LY0?o00004on=b:43o`000003ok>Rf?l0003o000000Oo00003OnYd=d2o`0001[oN8fD0_l0000@
oinWO@Go00003oo;cKH2o`0007Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0J?ooool3o`0002GoS[VH0_l0000GoiJRR0?o00004?n0ZJP;o`0001;o/lJ61?l0000DonoG
h`Co00000_oOb;`3o`0001SoNi5f1?l00007om35m@;o00009onb[ih2o`0001_obmcf1Ol00?l?ol_L
mP;o00004onQTkT2o`0001_o`MbT0_l0000Eohg8X@So00004OnYd=d2o`0001[oN8fD0_l0000BoinW
O@Ko00003?o;cKH2o`0007Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0J?ooool2o`0002KoS[VH0ol0000GoiJRR0;o00003on0ZJP9o`0001Oo/lJ60ol0000BonoGh`Co
00001?oOb;`4o`0001CoNi5f1?l00009om35m@;o00009onb[ih2o`0001_obmcf1Ol00?l?ol_LmP;o
00004_nQTkT3o`0001[o`MbT0ol0000Fohg8X@?o00005OnYd=d2o`0001[oN8fD0_l0000DoinWO@Ko
00002Oo;cKH3o`0007Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
J?ooool2o`0001[oS[VH0ol00?l:ohjiV0;o00005onFXXP5o`0000[oP:VX1?l00005ojFfb`?o0000
5oncaXH3o`0000ookmOS1?l00007omo8_0Co00004_mkTGH4o`0000[od<Ge0_l0000Wok:_WP;o0000
6oo;g?H5o`00o`oobmcf5ol0000Jol7LY0;o00005on=b:43o`0000_oZM3M0ol00?l7ojW@g@;o0000
2?mhSI@3o`00o`koN8fD0ol0000GoinWO@Go00001oo;cKH2o`0007Sooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0J?ooool3o`0001SoS[VH1Ol00?l9ohjiV0?o00004onF
XXP;o`0000GoP:VX1Ol00007ojFfb`;o00006?ncaXH3o`0000gokmOS1?l0000:omo8_0?o00004?mk
TGH3o`0000cod<Ge0ol0000Vok:_WP?o00006oo;g?H3o`00oa7obmcf5ol0000Hol7LY0?o00006?n=
b:42o`0000[oZM3M1Ol00?l6ojW@g@;o00001omhSI@5o`00o`goN8fD0_l0000JoinWO@Ko00001?o;
cKH2o`0007Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool2
o`0001SoS[VH1Ol00?l:ohjiV0;o00004OnFXXP6o`0000?o[K:Z1ol000000on0ZJSo0000o`000002
o`0000WoYKK;0ol0000Hok?6QPCo00002_o_en<3o`0000goglRl1?l0000<og^AMPCo00003_o@aOD2
o`0002Oo/ZnN0_l0000^ol_LmP?o00004onaTi04o`0001Ko`MbT0_l0000Iohg8X@;o00002_nYd=d5
o`00o`KoZM3M0_l00007ogR=U0Go003o3OmhSI@2o`0001coWjMm2_l0001hooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo06Wooooo0_l0000HohjiV0Go003o2_n>^IP3o`00
00koUZ:81Ol00009ojfbZPOo00003?nU]//2o`0001Wo/lJ61?l00007onoGh`Co00003ooOb;`4o`00
00[oNi5f1?l0000?om35m@;o00009onb[ih2o`0002kobmcf0_l0000Eok6CT0Co00005?o1g:@3o`00
01WoSLRQ0ol00009ojW@g@Go003o1_nYd=d2o`0000OoN8fD1Ol00?l=ogR=U0;o00007onOYgd6o`00
07Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool3o`0001So
S[VH0ol00?l<ohjiV0;o00002onFXXP6o`0000ko[K:Z0ol0000=ojFfb`?o00006_ncaXH3o`0000Go
kmOS1?l0000Bomo8_0?o00002?mkTGH3o`00017od<Ge0_l0000:ok:_WP?o003o6_nb[ih2o`0002go
bmcf0ol0000Gok6CT0Co00004Oo1g:@3o`0001_oSLRQ0_l0000:ojW@g@?o003o1onYd=d2o`0000So
N8fD0ol00?l=ogR=U0?o00008OnOYgd2o`0007_ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0J_ooool2o`0002OoS[VH0ol00008oiJRR0Ko00004On]/ZX2o`0000koYKK;
0_l0000Kok?6QP?o00000_o_en<4o`0001GoglRl1?l00004og^AMPCo00004_o@aOD2o`0000Wo/ZnN
1Ol00?lIok:_WP?o0000;?o;g?H2o`0001Wo/I>@1?l0000@ol7LY0;o00007?n=b:42o`0001CoZM3M
0_l0000HogR=U0;o00008OnOYgd3o`0007_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0J_ooool2o`0002SoS[VH0_l00006oiJRR0Go00005?n]/ZX2o`0000koYKK;0ol0
000Kok?6QPOo00005ooOb;`4o`0000;oNi5f1?l0000Com35m@;o00002Onb[ih5o`00oaWo/ZnN1_l0
000Xol_LmP?o00006onaTi04o`0000go`MbT0ol0000Lohg8X@?o00004onYd=d2o`0001SoN8fD0_l0
000QoinWO@;o0000O?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Z
ooooo`?o00009on>^IP3o`0000;oUZ:81_l0000FojfbZP;o00003onU]//2o`0001co/lJ61?l0000K
omo8_0Ko00005Oo@aOD2o`0000Wo/ZnN1Ol00?lHok:_WPWo00009_o;g?H2o`0001go/I>@1?l0000<
ol7LY0;o00007_n=b:42o`0001?oZM3M0_l0000HogR=U0;o00008OnOYgd2o`0007cooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Joooool2o`0002SoS[VH2?l0000Hojfb
ZP;o00003onU]//3o`0000So/lJ60ol00?lAok?6QP;o00007OoOb;`4o`0000_od<Ge0ol00?l8om35
m@?o00002Onb[ih3o`00oaWo/ZnN0_l00004onKIf@Ko00008oo;g?H2o`0001oo/I>@1?l00007ol7L
Y0Go00004_n=b:43o`00o`WoSLRQ0_l0000CojW@g@;o00005omhSI@3o`0000coWjMm0ol00?lAoinW
O@?o0000O?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o
0000:?n>^IP5o`0001_o[K:Z0_l0000@ojFfb`;o00001oncaXH5o`00oa3o/lJ60_l0000Momo8_0?o
00002oo@aOD5o`00o`Sod<Ge0_l0000Tok:_WP?o00001_oVfMT7o`0001oobmcf0ol0000Pok6CT0Co
000000?o`MbTo`000?l000001ol0000Bohg8X@Go003o2?n=b:43o`0001;oZM3M0_l0000GogR=U0;o
00003?nOYgd5o`00oa3oWjMm0_l0001mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo06_ooooo0ol0000XohjiV0;o00007On]/ZX2o`00013oYKK;0ol00006ok?6QPGo003o
3oncaXH3o`0001coglRl1?l0000;om35m@Go003o2?o@aOD2o`0002Co/ZnN0_l0000:onKIf@Ko0000
7Oo;g?H2o`0002?o/I>@2Ol000001?o=]Z3o0000o`000?l0000Aohg8X@Go003o2On=b:42o`0001;o
ZM3M0_l0000GogR=U0;o00003?nOYgd5o`00oa3oWjMm0_l0001mooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06cooooo0_l0000WohjiV0?o00007On]/ZX2o`00017oYKK;
0_l00006ok?6QPGo003o3_ncaXH4o`0001_oglRl1_l0000:om35m@Go003o2?o@aOD2o`0002Co/ZnN
0_l0000=onKIf@Ko00006Oo;g?H3o`0002Co/I>@0ol00007olffX0?o00004?n=b:45o`00o`WoSLRQ
0_l0000BojW@g@;o00005_mhSI@3o`0000coWjMm1Ol00?l?oinWO@?o0000OOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1/ooooo`;o00009on>^IP2o`0001ko[K:Z0_l0
000AojFfb`?o00001_ncaXH3o`00o`ko/lJ61_l0000@omo8_0?o003o1_oOb;`3o`0000;oQHfJ0ol0
000:om35m@?o003o2Oo@aOD2o`0002?o/ZnN0ol0000?onKIf@Ko00005oo;g?H2o`00017o/I>@0ol0
0?l@ok6CT0?o00002Oo=]Z03o`00013oSLRQ0ol00?l:ohg8X@?o00004OnYd=d2o`0001KoN8fD0_l0
000>oinWO@?o003o4?nOYgd2o`0007kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0K?ooool3o`0002KoS[VH0_l0000NojfbZP;o00004_nU]//2o`0001Ko/lJ60ol00002
ogAjX@?o00003_oOb;`5o`00o`CoglRl0ol00004ohF=VP;o00005_o@aOD2o`0002?o/ZnN0_l0000C
onKIf@Ko00004_o;g?H4o`00013o/I>@1Ol00?l>ok6CT0?o00002oo=]Z02o`0001koSLRQ0_l0000A
ojW@g@;o00005_mhSI@2o`00023oWjMm0ol0001nooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo06gooooo0_l0000UohjiV0?o00007_n]/ZX2o`0001;oYKK;0_l0000Dok?6
QPCo00001?mdNZ42o`0000koglRl1Ol00?l3omo8_0?o00001On5SIX3o`0001God<Ge0ol0000Qok:_
WP?o00005OoVfMT7o`0000cobmcf1_l0000Aok6CT0Go003o3OnaTi03o`0000cocKJP0ol0000Mohg8
X@?o00004?nYd=d2o`0001KoN8fD0_l0000PoinWO@;o0000Ooooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1]ooooo`;o00009On>^IP2o`0001oo[K:Z0_l0000BojFfb`?o
00004_ncaXH4o`0000GoM7ZQ0ol0000=omo8_0Go003o0_oOb;`3o`0000OoQHfJ0_l0000Fom35m@;o
00008Onb[ih2o`0001Woi]WI1_l00007ol_LmP[o00004?naTi05o`00o`go/I>@0_l0000>olffX0?o
00007On=b:42o`00013oZM3M0_l0000EogR=U0?o00008?nOYgd2o`0007oooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0KOooool3o`0002?oS[VH0ol0000AojfbZP?o003o
2on]/ZX2o`0000_oYKK;0ol00?l5ojFfb`;o00004OncaXH3o`0000SoM7ZQ0ol0000=omo8_0?o003o
0_oOb;`3o`0000SoQHfJ0ol0000Dom35m@Go00007_nb[ih3o`0001coi]WI1_l000000oo;g?Ko0000
o`000005o`0000CoZ=bg0ol0000@ok6CT0?o003o3OnaTi03o`0000oocKJP0_l0000Mohg8X@;o0000
4?nYd=d2o`0001GoN8fD0_l0000PoinWO@?o0000Ooooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1^ooooo`;o00008on>^IP2o`00017o[K:Z1Ol00?l:ojfbZP;o00002_nU
]//5o`00o`CoYKK;0ol0000?ok?6QP?o00002_mdNZ42o`00017oglRl0ol0000:ohF=VP?o00004_o@
aOD9o`0001_o/ZnN0_l0000OonKIf@Wo00002?nXg;L3o`0001ko/I>@0ol0000@olffX0?o00007?n=
b:43o`0000ooZM3M0_l0000EogR=U0;o00008?nOYgd2o`00083ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0K_ooool2o`0002;oS[VH0ol0000AojfbZPGo003o2_n]/ZX2
o`0000[oYKK;1Ol00?l5ojFfb`;o00003OncaXH4o`0000_oM7ZQ0ol0000?omo8_0?o00003?n5SIX2
o`00017od<Ge0ol00003oj6TWPSo00005onb[ih2o`0002;oi]WI0ol0000<ojSL]`?o00007OnaTi02
o`0001;ocKJP0ol0000Lohg8X@;o00003onYd=d2o`0001GoN8fD0_l0000PoinWO@;o0000P?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1^ooooo`?o00008On>^IP2o`00
01;o[K:Z1Ol00?l:ojfbZP;o00002_nU]//5o`00o`GoYKK;0ol0000;ok?6QPCo00003OmdNZ43o`00
00goglRl0ol0000=ohF=VP?o00003oo@aOD3o`0000OoXJBN2?l0000Bok:_WPCo00008_oVfMT2o`00
00koZ=bg0ol0000Kok6CT0?o00004oo=]Z03o`0001_oSLRQ0_l0000?ojW@g@;o00005?mhSI@3o`00
01ooWjMm0ol00020ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06oo
oooo0_l0000QohjiV0;o00004on]/ZX3o`00o`_o[K:Z0_l0000;ojFfb`?o003o1onU]//2o`0000[o
/lJ60ol0000@ogAjX@;o00003?oOb;`3o`0000CoQHfJ0ol00?l8ohF=VP?o00003?o@aOD4o`0000co
XJBN1ol0000=ok:_WPGo00008ooVfMT2o`0000ooZ=bg0ol0000Iok6CT0?o00005Oo=]Z02o`0001_o
SLRQ0ol0000>ojW@g@;o00005?mhSI@2o`00023oWjMm0_l00021ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06oooooo0_l0000PohjiV0?o00008On]/ZX2o`0001GoYKK;
0ol00008ok?6QP?o00004OmdNZ43o`0000[oglRl0ol00004ohF=VPGo003o2?n5SIX2o`0000_od<Ge
1?l0000@oj6TWPSo00001_nb[ih9o`00027oi]WI0ol0000@ojSL]`?o00005onaTi03o`0001KocKJP
0ol0000Kohg8X@;o00003_nYd=d2o`0001CoN8fD0_l0000PoinWO@;o0000POooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1_ooooo`?o00007on>^IP2o`0002;o[K:Z0_l0
000FojFfb`;o00001oncaXH3o`0001?oM7ZQ0ol00008omo8_0?o00001On5SIX5o`00o`SoQHfJ0ol0
0009om35m@?o00005OnQY9h8o`000003ok:_W_l0003o000000Co00000on>TG`2o`00027oi]WI0_l0
000BojSL]`?o00005_naTi02o`0001SocKJP1ol0000Fohg8X@;o00003_nYd=d2o`0001CoN8fD0_l0
000OoinWO@?o0000POooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1`
ooooo`;o00007_n>^IP3o`0002;o[K:Z0_l0000FojFfb`?o00001?ncaXH4o`0001GoM7ZQ0_l00007
omo8_0?o00001_n5SIX5o`00o`WoQHfJ0ol00007om35m@?o00006_nQY9h8o`0000KoSY5l0ol0000P
onKIf@;o00004onXg;L2o`0001Go/I>@0ol0000IolffX0go00003on=b:43o`0000goZM3M0_l0000C
ogR=U0?o00007onOYgd2o`0008;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0L?ooool2o`0001koS[VH0_l0000SojfbZP;o00005onU]//2o`0000?o/lJ61?l0000FogAj
X@?o00001OoOb;`3o`0000SoQHfJ0ol00?l;ohF=VP;o00001Oo@aOD4o`0001koXJBN0ol00009ohjA
O0?o00007ooVfMT2o`0001?oZ=bg0ol0000Cok6CT0?o00006Oo=]Z03o`0000?oRIZM4?l00008ohg8
X@;o00003OnYd=d2o`0001?oN8fD0_l0000OoinWO@?o0000P_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1`ooooo`?o00007?n>^IP3o`0002?o[K:Z0_l0000GojFfb`?o
000000Co/lJ6o`000?l0003o00006OmdNZ43o`0000?oglRl0ol0000GohF=VP?o00000oo@aOD4o`00
01ooXJBN0ol0000:ohjAO0;o00007ooVfMT2o`0001CoZ=bg0ol0000Bok6CT0;o00006_o=]Z02o`00
00_oRIZM4?l000000on=b:7o0000o`00000=ojW@g@;o00004omhSI@2o`0001ooWjMm0_l00023oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo077ooooo0_l0000LohjiV0;o
00008_n]/ZX5o`0001OoYKK;1Ol0000KogAjX@;o00000_oOb;`3o`0001WoQHfJ0_l00002om35m@?o
00008OnQY9h2o`0000_oSY5l0ol0000NonKIf@;o00005OnXg;L3o`00013o/I>@0ol0000JolffX0;o
00004on9VYd<o`0000coZM3M0_l0000CogR=U0;o00007onOYgd2o`0008?ooooo00?o0000oooooooo
ool02?ooool001[ooooo0ol0001aooooo`;o00007?n>^IP2o`0001oo[K:Z2Ol0000FojFfb`Co0000
3_mdNZ43o`00o`_oM7ZQ1_l0000JohF=VPKo00003OnQY9h3o`00oa7oXJBN0ol0000<ohjAO0;o0000
4OoVfMT3o`00o`Woi]WI0ol0000FojSL]`?o00003_naTi03o`0000cocKJP0ol00?l;olffX0?o0000
6_n9VYd5o`0000KoZM3M2_l0000@ogR=U0?o00007_nOYgd3o`00087ooooo0ol0000:ooooo`006_oo
ool00ol0003oooooooooo`1aooooo`?o00006_n>^IP3o`0001co[K:Z1ol00003olS@[@?o00005_nU
]//2o`0000koM7ZQ1Ol00?l;ogAjX@Co00007?n5SIX4o`0000goXJBN1Ol00?l@oj6TWP;o00003On>
TG`3o`0000ooi]WI1Ol00?l8onKIf@;o00006?nXg;L3o`0000[o/I>@1Ol0000<olffX0Go003o2_o=
]Z02o`0001koRIZM5_l0000:ogR=U0Go00007_nOYgd2o`0008Cooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0L_ooool3o`0001WoS[VH0_l0000JojfbZPOo00001oo8d:d3
o`0001CoYKK;0ol0000>ogAjX@Go003o3?mdNZ42o`0001_oQHfJ1Ol0000>oj6TWPGo003o3onQY9h3
o`0000koSY5l0_l0000?onKIf@Go003o2?oVfMT2o`0001WoZ=bg0ol00005ok6CT0So00003Oo=]Z05
o`00o`[ocKJP0_l0000OohVJW@So00002?nbY]P8o`0000;oN8fD3?l0000LoinWO@;o0000Q?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1booooo`Co00005on>^IP3o`00
01Oo[K:Z1ol0000;olS@[@Co00004_nU]//2o`0000ooM7ZQ1Ol00?l<ogAjX@?o00005on5SIX7o`00
00ooXJBN1Ol00?l>oj6TWP?o00003on>TG`3o`0000koi]WI1Ol00?l8onKIf@;o00006_nXg;L3o`00
0003ok6CT?l0003o000000Ko000000Cok/gOo`000?l0003o00003?o=]Z05o`00o`WocKJP0ol0000N
ohVJW@?o00004_nbY]P<o`0000?oQ9fJ1_l0000GoinWO@Co0000Q?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1dooooo`?o00005_n>^IP2o`0001Go[K:Z1ol0000?olS@
[@Co00004OnU]//2o`00013oM7ZQ0ol00?l=ogAjX@Co00004on5SIX7o`000004oh:2QOl0003o0000
o`0000ooXJBN0ol00?l?oj6TWP;o00004On>TG`2o`0000ooi]WI0ol00?l9onKIf@;o00002OnXg;L3
o`00o`ooZ=bg1ol00006onk=g`?o00003?o=]Z03o`00o`[ocKJP0_l0000OohVJW@;o00005_nbY]P4
o`0000[oQ9fJ1_l0000CoinWO@Go0000QOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1eooooo`?o00005?n>^IP3o`0001;o[K:Z1ol0000DolS@[@?o00003onU]//3o`00
01ooM7ZQ1_l0000?ohF=VPOo00001On2PXD2o`00023oXJBN0ol0000AohjAO0?o00006_oVfMT2o`00
00SoZ=bg1Ol00?l?ojSL]`?o00002_o^cMl3o`0001SocKJP0_l0000NohVJW@?o00005onbY]P2o`00
00koQ9fJ1Ol0000@oinWO@Co0000Qoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1fooooo`?o00004on>^IP2o`00013o[K:Z1ol0000HolS@[@?o00003_nU]//2o`0001oo
M7ZQ0ol00002ojb?Q`Co00002_n5SIX7o`0000SoPX:50ol0000Ooj6TWP;o00004on>TG`3o`0001So
i]WI0ol00008ojSL]`Go003o3_nXg;L3o`0000cok/gO0ol0000FolffX0?o00007_n9VYd2o`0001So
/ZKH0_l0000@ohBMVPGo00003?nOYgd4o`0008Wooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Moooool4o`00017oS[VH0_l0000=ojfbZPOo00007?o8d:d3o`0000goYKK;
0_l0000NogAjX@?o00001?n/ShL5o`0000GoQHfJ1ol0000<oh:2Q@?o00007OnQY9h3o`0001CoSY5l
0_l0000HonKIf@;o00002OnXg;L5o`00o`koZ=bg0_l0000>onk=g`?o00005Oo=]Z02o`0001koRIZM
0ol0000Hok:Vf0;o00004_n4WIX5o`0000SoWjMm1Ol0002:ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo07Sooooo1?l0000>ohjiV0Go00002On]/ZX7o`00023ob=2]1?l0
000:ojFfbb?o00001on/ShL4o`000003ohF=V_l0003o000000Go00004?n2PXD2o`0001goXJBN0_l0
000EohjAO0?o00005ooVfMT2o`0000[oZ=bg0ol00?l>ojSL]`?o00003oo^cMl3o`0001CocKJP0_l0
000:ohVJW@?o003o4On9VYd2o`0001So/ZKH0ol0000DohBMVPKo00001?nOYgd4o`0008cooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0N_ooool3o`0000[oS[VH3?l00002
ojfbZPOo00009?o8d:d4o`0000WoYKK;8_l0000:ojb?Q`Oo00004on2PXD3o`0001_oXJBN0ol0000F
ohjAO0;o00005ooVfMT2o`0001_oZ=bg0_l0000Aonk=g`?o00004_o=]Z03o`0000WoRIZM1Ol00?l?
ohVJW@?o00006?nbY]P2o`0001OoQ9fJ2_l0002>ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo07_ooooo0ol00007ohjiV0Ko00000onKOXP;o`0002Wob=2]0ol00007ojFf
b`?o00007OoH/K/3o`0000_o[8n70ol0000Goh:2Q@;o00006onQY9h2o`0001OoSY5l1?l0000EonKI
f@;o00006onXg;L2o`0001;ok/gO0ol0000AolffX0;o00002_n9VYd5o`00o`ooRIZM0_l0000Iok:V
f0;o00006_n4WIX6o`0008oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0O?ooool3o`0000CoS[VH1Ol0000:oi]nR0Go0000;?o8d:d3o`0000GoYKK;0ol0000NomRa^`;o
00003?n/ShL2o`0001SoPX:50ol0000Ioj6TWP?o00006?n>TG`5o`0001?oi]WI0_l0000JojSL]`?o
00004oo^cMl3o`00013ocKJP0_l0000:ohVJW@Go003o3_n9VYd3o`0001Wo/ZKH0_l0000LohBMVP;o
0000TOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1mooooo`Wo0000
3onKOXP3o`0001Oob=2]0ol00?lBolS@[@Co00000onU]//2o`0001Cof;6k0ol00?l7omRa^`?o0000
3?n/ShL2o`0001WoPX:50_l0000Hoj6TWP?o00006?n>TG`8o`00013oi]WI0ol0000JojSL]`;o0000
5Oo^cMl3o`0000kocKJP0ol0000;ohVJW@?o003o3on9VYd2o`0001[o/ZKH0_l0000LohBMVP;o0000
TOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1nooooo`Ko00004_nK
OXP3o`0001Gob=2]1Ol00?l?olS@[@_o00004ooH/K/5o`00o`Kof;6k0_l0000=ojb?Q`?o00006?n2
PXD3o`0001OoXJBN0_l0000IohjAO0;o00000on_gm05o`0000koi]WI0_l0000JojSL]`?o00005_o^
cMl3o`0000gocKJP0_l0000MohVJW@?o00006_nbY]P2o`0001coQ9fJ0_l0002Aooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000Foi]nR0?o00005?o8d:d5
o`00o`gob=2]1Ol00002oinNaPGo00005?oH/K/5o`00o`Gof;6k0ol0000>ojb?Q`;o00006On2PXD3
o`0001GoXJBN0ol0000HohjAO0?o00001On_gm05o`0000coi]WI0_l0000JojSL]`;o00006?o^cMl3
o`0000cocKJP0_l0000MohVJW@;o00006onbY]P2o`0001coQ9fJ0_l0002Aooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000Goi]nR0?o00004oo8d:d5o`00
o`_ob=2]1Ol00006oinNaP?o00005?oH/K/5o`00o`Gof;6k0_l0000?ojb?Q`;o00006_n2PXD2o`00
01GoXJBN0_l0000IohjAO0;o00002?n_gm05o`0000[oi]WI0_l0000IojSL]`?o00006Oo^cMl3o`00
00[ocKJP0ol0000LohVJW@?o00006onbY]P2o`0001coQ9fJ0ol0002@ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07kooooo0ol0000Hoi]nR0Co00004_o8d:d3o`00o`[o
b=2]1Ol00008oinNaPGo00004ooH/K/3o`00o`Gof;6k0ol0000?ojb?Q`;o00002_n2PXD3o`00o`go
PX:56Ol0000=ohjAO0?o003o2?n>TG`3o`0000[o[mo@1?l00009onKIf@;o00006OnXg;L2o`0000oo
k/gO0ol00?l9onk=g`?o00002Oo=]Z02o`0001goRIZM0_l0000Kok:Vf0?o00007On4WIX2o`00093o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2o`0001[oVgj8
1?l0000LolS@[@Go00002_nOW/H6o`0001[of;6k0_l0000@ojb?Q`;o00002On2PXD5o`00o`goPX:5
5ol0000=ohjAO0Go003o1on>TG`2o`0000go[mo@1?l00007onKIf@;o00006OnXg;L2o`0000kok/gO
1Ol00?l9onk=g`?o00002?o=]Z02o`0001coRIZM0ol0000Kok:Vf0;o00007_n4WIX2o`00093ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2o`0001coVgj80ol0
000IolS@[@Go00002onOW/H3o`0000;oYkSR1?l0000HomRa^`;o00004?n/ShL2o`0000WoPX:51Ol0
0?l<oh:2Q@?o00004om_[:@3o`0000coSY5l1Ol00?l6ohjAO0?o00003_n_gm05o`0000Coi]WI0ol0
000EojSL]`Ko00003_o^cMl5o`00o`[ok/gO0ol00006olffX0?o00007?n9VYd2o`0001co/ZKH0_l0
000NohBMVP;o0000T?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1n
ooooo`;o00007OnKOXP3o`0001Kob=2]1Ol0000=oinNaP;o00001?nW^>85o`0001Gof;6k0ol0000@
ojb?Q`?o00002?n2PXD5o`00o`coPX:50_l0000Eofn/Y0;o00003?n>TG`5o`00o`KoSY5l0_l0000A
ojoOd0Go00000_oVfMT2o`0000ooZ=bg3?l0000?onk=g`Go003o2oo^cMl3o`0000GocKJP0_l0000L
ohVJW@?o00007?nbY]P2o`0001koQ9fJ0_l0002@ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo07kooooo0_l0000Noi]nR0?o00004oo8d:d5o`0000ooWik60_l00006ojNh
hPCo00005?oH/K/2o`0000Ko[8n70ol00?l9ojb?Q`;o00002On2PXD3o`00o`goPX:50_l0000Eofn/
Y0;o00003On>TG`3o`00o`KoSY5l0ol0000CojoOd0_o00001?nXg;L?o`0000;oPZUi0ol0000?onk=
g`?o003o3Oo^cMl3o`0000CocKJP0_l0000LohVJW@;o00007OnbY]P2o`0001koQ9fJ0_l0002@oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0ol0000Ooi]nR0Co
00003oo8d:d5o`00013oWik60ol00008ojNhhPGo00004?oH/K/3o`0000Go[8n71Ol00?l8ojb?Q`;o
00006?n2PXD3o`0001GoKjbT0ol0000EohjAO0;o00005_n_gm0Eo`0000[oPZUi0_l0000Ponk=g`?o
00000_o=]Z03o`0001_oRIZM0ol0000Mok:Vf0;o00007_n4WIX2o`00093ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0OOooool2o`00027oVgj81?l0000<olS@[@Go0000
4_nOW/H2o`0000[oYkSR2Ol0000;omRa^`;o00001_n/ShL5o`00o`So[8n70_l0000Hoh:2Q@;o0000
5om_[:@2o`0001CoSY5l0ol0000HojoOd0;o00001?nT`Y/6o`00017oPZUi0ol0000Ponk=g`So0000
6_n9VYd2o`0001ko/ZKH0_l0000NohBMVP?o0000Soooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1mooooo`;o00008onKOXP3o`0000Wob=2]1Ol0000DoinNaP;o00002_nW
^>82o`000003ojO3]ol0003o000000So00001_oH/K/3o`0000Ko[8n71Ol00?l8ojb?Q`;o00005on2
PXD3o`0001OoKjbT0ol0000BohjAO0?o00001_n_gm03o`00o`oo[mo@0ol00006ojC2V`?o00004on2
ZGT3o`00023ok/gO2ol0000EohVJW@?o00003onbY]P3o`00o`co/ZKH0_l0000OohBMVP;o0000Sooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1mooooo`;o00009?nKOXP3
o`0000Kob=2]1Ol0000FoinNaP;o00002_nW^>83o`0000GoYl>g2_l000000ooH/K_o0000o`000008
ojb?Q`?o003o2On/ShL2o`0001OoPX:50_l0000Iofn/Y0;o00004_n>TG`2o`0000Ko[mo@1Ol00?l>
ojoOd0;o00002?nT`Y/2o`0001CoPZUi0_l0000Qonk=g`;o00000ooIi=48o`0001;oRIZM0_l0000?
ok:Vf0Go003o2_nbY]P3o`0001ooQ9fJ0_l0002?ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo07gooooo0_l0000Uoi]nR0?o00000oo8d:d5o`0001OoWik60ol0000;ojNh
hP;o00002OnW`kL9o`0001Co[8n70_l0000Goh:2Q@;o00006Om_[:@2o`00017oSY5l0ol00006ojoO
d0Go003o3_n_gm02o`0000SoY<:K0ol0000Coh:YN@Go00007Oo^cMl3o`0000OofNCA2?l0000=ohVJ
W@?o00003onbY]P5o`00o`[o/ZKH0_l0000PohBMVP;o0000Soooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1looooo`?o00009_nKOXP8o`0001WoWik60_l0000<ojNhhP;o
00003_nW`kL3o`0001Go[8n70ol0000Doh:2Q@Co00006Om_[:@3o`00013oSY5l0_l00007ojoOd0Go
003o3On_gm03o`0000WoY<:K0_l0000Doh:YN@Wo00005oo^cMl3o`0000_ofNCA2Ol00009ohVJW@;o
00004?nbY]P5o`00o`[o/ZKH0_l0000PohBMVP;o0000Soooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1looooo`;o0000:?nKOXP5o`0000_oWik60ol00?l=oinNaP;o0000
3?nW^>83o`0000koYl>g0ol0000Eojb?Q`;o00004On2PXD6o`0000coKjbT0ol00?l<ofn/Y0;o0000
3on>TG`3o`0000So[mo@0ol00?l>ojoOd0;o00002_nT`Y/3o`0001?oPZUi0_l000000oo_b;Co0000
o`000009o`0001;ok/gO0_l0000@omWTd@So00001On9VYd3o`00017o/ZKH0ol00?l;ok:Vf0;o0000
2on4WIX3o`00oa;oQ9fJ0_l0002?ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07cooooo0_l0000Yoi]nR0;o00003?nOW/H5o`00o`_oWik60ol0000=ojNhhP;o00003onW
`kL3o`0001Co[8n70_l0000>oh:2Q@[o00002_m_[:@5o`00o`_oKjbT0ol0000>ohjAO0;o00006On_
gm03o`0000_oY<:K0_l0000Coh:YN@;o00001_o_b;@;o`0000cok/gO0ol0000DomWTd@So000000?o
RIZMo`000?l000008?nbY]P2o`0000[oQ9fJ1Ol00?lAohBMVP;o0000Soooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1looooo`;o0000:OnKOXP2o`0000coWik61Ol00?l;
oinNaP;o00003_nW^>82o`00013oYl>g0ol0000Cojb?Q`;o00002on2PXD7o`0000CobK;70_l0000:
ofn/Y0Go003o3?m_[:@2o`0000goSY5l0ol0000IojoOd0;o00003?nT`Y/3o`00017oPZUi0ol0000;
ono8]0_o00001oo^cMl2o`0001SofNCA2?l0000Pok:Vf0;o00002_n4WIX5o`00oa7oQ9fJ0ol0002>
ooooo`03o`000?oooooooooo00Sooooo0007ooooo`?o00001?ooool2o`0000[ooooo00?o0000oooo
ooooool0O?ooool2o`0002WoVgj80ol0000;oinNaPGo003o2onOW/H2o`0000koYkSR0ol0000@ojO3
]`;o00004on/ShL2o`0000WoPX:51_l00007olVba`?o00002Om_[:@5o`00o`coKjbT0_l0000=ohjA
O0;o00006_n_gm02o`0000goY<:K0_l0000Aoh:YN@;o00004Oo_b;@;o`000004onk=gol0003o0000
o`0001cofNCA0ol0000Qok:Vf0;o00002_n4WIX5o`00oa;oQ9fJ0_l0002>ooooo`03o`000?oooooo
oooo00Sooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo07_ooooo0ol0000Zoi]nR0;o00003?nOW/H3o`00o`_oWik60ol0
000?ojNhhP;o00001OnW`kL3o`00o`SoYl>g0ol0000Bojb?Q`;o00001_n2PXD6o`0000_obK;70ol0
0009ofn/Y0?o003o3Om_[:@4o`0000[oSY5l0ol0000IojoOd0?o00003OnT`Y/3o`0000CoPZUi0ol0
0?l9oh:YN@;o00005_o_b;@9o`0001kofNCA0ol0000Ook:Vf0?o00002on4WIX3o`00oa?oQ9fJ0_l0
002>ooooo`03o`000?oooooooooo00Sooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo07_ooooo0_l0000[oi]nR0;o0000
6_nOW/H2o`00013oYkSR0_l00004ojO3]`Go003o2?nW`kL4o`00013o[8n70ol00002oh:2Q@Oo0000
3_o9//L2o`0001SoKjbT2?l00007ohjAO0;o00006_n_gm02o`0000ooY<:K0_l00003oh:YN@Go003o
2?n2ZGT2o`0001_oklRd0ol0000PomWTd@;o00007onbY]P2o`0002;oQ9fJ0_l0002>ooooo`03o`00
0?oooooooooo00Sooooo0007ooooo`?o00000oooool01?l0003oooooooooool00009ooooo`Go0000
NOooool2o`0002_oVgj80ol0000IoinNaP;o00004?nW^>83o`0000?oYl>g1Ol00?l8ojO3]`Oo0000
3_n/ShL8o`00017obK;70ol0000Fofn/Y0?o00000_n/c:P7o`0000?oSY5l0ol0000IojoOd0?o0000
3onT`Y/3o`0000;oPZUi1Ol00?l8oh:YN@;o00007?o_b;@2o`00023ofNCA0ol0000Nok:Vf0;o0000
8_n4WIX2o`0008[ooooo1Ol0000:ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1kooooo`;o0000;?nKOXP2o`0001Wo
Wik60_l0000AojNhhP;o00000onW`kL5o`00o`OoYl>g0ol000000oo;ZlOo0000o`000005o`0000_o
[8n71Ol0000EolVba`;o00005Om_[:@3o`0000Ko[<bX2Ol0000JojoOd0;o00004OnT`Y/2o`0000;o
PZUi1Ol00?l8oh:YN@;o00007?o_b;@2o`00027ofNCA0_l0000Nok:Vf0;o00008On4WIX3o`0008ko
oooo00?o0000ooooooooool02?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0Noooool3o`0001goVgj80ol00?l;oi]n
R0;o00006?nOW/H3o`0000_oYkSR0ol00?l3ojNhhP;o00001?nW`kL3o`00o`OoYl>g0ol00005ol^[
a`Oo00002?n/ShL2o`0001SobK;70ol0000Cofn/Y0?o00002_n/c:P6o`0001[o[mo@0_l0000>ojC2
V`?o003o0ol00002oh:YN@?o003o2?n2ZGT3o`0000WoklRd0ol00?l@ono8]0;o00008OoIi=42o`00
01ko/ZKH0_l0000PohBMVP?o0000Soooool00ol0003oooooooooo`08ooooo`001oooool3o`0000Co
oooo0_l0000:ooooo`03o`000?oooooooooo07cooooo0_l0000Loi]nR0Go003o2_nKOXP3o`0001Oo
Wik60_l0000;ojNhhPGo003o0_nW^>82o`0000goYl>g0ol00009ol^[a`Oo00001?n/ShL3o`0001Wo
bK;70_l0000Aofn/Y0Co00003_n/c:P2o`0001Wo[mo@1?l0000=ojC2V`Go003o0_l0000=oh:YN@;o
00002Oo_b;@5o`00o`koklRd0ol0000QomWTd@?o00007OnbY]P2o`0001ooQ9fJ0ol0002@ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07cooooo0_l0000Loi]nR0Go003o
2onKOXP2o`0001OoWik60_l0000;ojNhhPGo003o0_nW^>83o`0000_oYl>g0ol0000=ol^[a`Oo0000
00?o[8n7o`000?l000006_o9//L3o`0000ooKjbT1?l0000?ojc<Z0?o00005on_gm06o`0000coY<:K
1Ol00?l3o`0000coPZUi0_l00009ono8]0Go003o3_o_b;@2o`0002?ofNCA0_l0000Mok:Vf0;o0000
7on4WIX2o`00097ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O?oo
ool2o`0001coVgj81Ol00?l;oi]nR0;o00005_nOW/H3o`0000_oYkSR1Ol00?l3ojNhhP;o00002_nW
`kL3o`00017obj_71ol0000KolVba`?o00003Om_[:@3o`0001;o[<bX0ol0000DojoOd0Co00000_n`
[:h3o`0000_oY<:K1Ol00?l01?nT`Y_o0000o`000?l0000;oh:YN@;o00002Oo_b;@5o`00o`koklRd
0_l0000SomWTd@?o00007?nbY]P2o`0001koQ9fJ0ol0002Aooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo07cooooo0ol0000Loi]nR0?o003o3?nKOXP3o`0001;oWik61Ol0
000=ojNhhP?o003o1?nW^>82o`0000WoYl>g0ol0000Dol^[a`Co00004Oo9//L3o`00o`WobK;70_l0
000<ofn/Y0?o00005?n/c:P3o`0001;o[mo@1?l00004ok2/[PCo00002_nT`Y/3o`00o`?oY<:K0_l0
000;oh:YN@;o00002_o_b;@3o`00o`ooklRd0_l0000?omWTd@?o003o4_oIi=42o`0001_o/ZKH0ol0
000MohBMVP?o0000T_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1m
ooooo`;o0000;?nKOXP2o`0000goWik62_l0000DojNhhP?o00001onW`kL3o`0001Cobj_71_l0000?
olVba`Go003o2?o9//L3o`0000[oKjbT0ol0000Fojc<Z0?o00004?n_gm03o`0000Oo/:b^1?l0000?
ojC2V`?o00002_n2ZGT2o`0001coklRd0_l0000>omWTd@Go003o4OoIi=43o`0001[o/ZKH0_l0000M
ohBMVP?o0000Toooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1moooo
o`;o0000;?nKOXP2o`0000OoWik63?l00002ol;8h0?o00005?nW^>82o`0000KoYl>g0ol0000Dol^[
a`?o00000_n4RIL2o`0000oobK;71Ol00?l9olVba`;o00002Om_[:@3o`0001So[<bX0ol0000=ojoO
d0Co00002_n`[:h4o`0000koY<:K0_l0000:oh:YN@;o00007?o_b;@2o`0000kofNCA1Ol00?lBomWT
d@;o00006_nbY]P2o`0001goQ9fJ0_l0002Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo07gooooo0_l0000/oi]nR0?o000000?oWik6o`000?l000002_l00008ol;8h0?o
00004onW^>82o`0000GoYl>g0ol0000Dol^[a`?o00000on4RIL3o`0000kobK;71Ol00?l9olVba`?o
00001_m_[:@4o`0001[o[<bX0ol0000;ojoOd0Co00003?n`[:h4o`0000goY<:K0ol00008oh:YN@?o
00007?o_b;@2o`0000kofNCA1Ol00?lBomWTd@;o00006_nbY]P2o`0001coQ9fJ0ol0002Dooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0ol0000/oi]nR0Wo0000
3oo2b>02o`0001?oYkSR0ol00003ojO3]`?o00001_o;ZlL3o`00o`_obj_70ol00005ohB9U`;o0000
3oo9//L3o`00o`_obK;70_l00005ofn/Y0Co00007?n/c:P2o`0000Wo[mo@1?l0000@ok2/[P?o0000
3OnT`Y/2o`0000SoPZUi0_l0000Mono8]0;o00003ooIi=43o`00oa?ofNCA0ol0000Iok:Vf0;o0000
6on4WIX3o`0009Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_oo
ool2o`0002coVgj81?l0000Dol;8h0?o00004onW^>82o`0000;oYl>g0ol00006ol^[a`Go003o2Oo;
ZlL3o`0000KoQ8VG0ol0000LolVba`?o00000om_[:@3o`0001ko[<bX0ol00007ojoOd0Co00004_n`
[:h4o`0000_oY<:K0ol00007oh:YN@;o00007?o_b;@3o`0002KofNCA0_l0000Iok:Vf0;o00006_n4
WIX3o`0009Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2
o`0002_oVgj80ol0000Gol;8h0?o00004_nW^>82o`000004ojO3]ol0003o0000o`0000Oobj_71Ol0
0?l8ol^[a`?o00002?n4RIL3o`0001cobK;70ol000001?m_[:Co0000o`000?l0000Pojc<Z0?o0000
1On_gm03o`0001Go/:b^1?l0000;ojC2V`;o00001on2ZGT2o`0001coklRd0_l0000WomWTd@Co0000
5onbY]P2o`0001WoQ9fJ0ol0002Gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07kooooo0_l0000[oi]nR0;o00006Oo2b>02o`0001;oYkSR1Ol00008ol^[a`Go003o1oo;
ZlL3o`0000[oQ8VG0_l0000MolVba`Go00008_n/c:P3o`0000;o[mo@1?l0000Hok2/[P?o00002_nT
`Y/3o`0000KoPZUi0_l0000Lono8]0;o00009OoIi=48o`0001Go/ZKH0_l0000IohBMVP;o0000V?oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1nooooo`?o0000:OnKOXP3
o`0001Wo`/SP0ol0000BojNhhP?o00002_o;ZlL3o`00o`Oobj_70ol0000;ohB9U`?o00007?o9//L4
o`0000oo[<bX0ol00?lBojc<Z0Oo00006_n`[:h4o`0000WoY<:K0_l00006oh:YN@;o00006_o_b;@4
o`0002CofNCA1?l00002oigSe0Go00004_nbY]P3o`0001SoQ9fJ0ol0002Hooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000Yoi]nR0;o00006oo2b>03o`00
017oYkSR0_l0000Dol^[a`?o00003On4RIL2o`0001gobK;70_l0000?ojc<Z0Go003o4_n/c:P4o`00
01go/:b^1?l00008ojC2V`?o00001?n2ZGT3o`0001KoklRd2?l0000RomWTd@Co00001_nMhm@4o`00
017o/ZKH0_l0000HohBMVP?o0000VOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1oooooo`;o0000:?nKOXP3o`0001co`/SP0_l0000@ojNhhP?o00004oo;ZlL3o`0000ko
Q8VG0ol0000LolVba`;o00003on/c:P5o`00oa?o[<bX0_l0000Pok2/[P?o00002?nT`Y/2o`0000Co
PZUi0_l0000Cono8]0Wo000000CokNCko`000?l0003o00007ooIi=45o`0000WoWN?D1?l0000?ok:V
f0;o00005on4WIX3o`0009[ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Ooooool2o`0002OoVgj80ol0000?ol;8h0?o003o2oo2b>03o`0000ooYkSR0_l0000Col^[a`?o
00004?n4RIL2o`0001_obK;70ol0000?ojc<Z0Go003o4on/c:P2o`0001Go/:b^0ol00?l9ok2/[PCo
00001_nT`Y/3o`0000;oPZUi1_l0000<ono8]0Wo00001_o]i?/3o`0001gofNCA1?l0000<oigSe0Go
00003OnbY]P2o`0001OoQ9fJ0_l0002Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo07oooooo0ol0000Voi]nR0;o00003oo2b>05o`00o`_o`/SP0ol0000>ojNhhP;o0000
4_o;ZlL3o`00017oQ8VG0ol0000HolVba`Co00004On/c:P3o`00oaCo[<bX0_l0000Dok2/[PGo003o
2On`[:h4o`0000KoY<:K3ol00003ono8]0Wo00002oo]i?/3o`0001[ofNCA1?l0000@oigSe0Go0000
2onbY]P2o`0001KoQ9fJ0ol0002Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo083ooooo0_l0000Uoi]nR0?o00003oo2b>05o`00o`co`/SP0_l0000=ojNhhP?o00004Oo;
ZlL3o`0001?oQ8VG0_l0000EolVba`Oo0000:?n/c:P3o`0001?o/:b^1Ol00?l;ok2/[PCo00001?nT
`Y/5o`0000Co[XV:3_l0000@ongTn`?o00005ooIi=45o`0001?oWN?D1Ol00009ok:Vf0;o00005On4
WIX3o`0009cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool2
o`0002GoVgj80_l0000@ol;8h0Go003o3?o2b>03o`0000coYkSR0_l0000Aol^[a`?o00005?n4RIL3
o`00013obK;72?l000001?nCVI_o0000o`000?l0000Vojc<Z0Go00004_n`[:h5o`00o`co/:b^1?l0
0002ojC2V`Co00002on^RHX5o`0001GokNCk0ol0000DomWTd@Go00005onMhm@5o`0000Oo/ZKH0_l0
000DohBMVP?o0000WOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20
ooooo`;o00009?nKOXP3o`00017o`/SP0ol00?l>ol;8h0Wo00001OnW^>82o`00013obj_70ol00006
ohB9U`?o003o3On4RIL3o`0000cobK;72?l00005oi>IV`?o00009?n/c:P3o`000004ok:KTOl0003o
0000o`0001;o/:b^0ol00?l?ok2/[PKo00003on^RHX2o`0001OokNCk0ol0000BomWTd@Co00006onM
hm@5o`0000Go/ZKH0_l0000DohBMVP;o0000W_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`20ooooo`?o00008onKOXP2o`0002?o`/SP4?l0000?ol^[a`?o00001_n4RIL5
o`00o`goQ8VG0_l00009olVba`Oo00002_nCVI/3o`0002;o[<bX0ol00003ok:KT@?o00009?n`[:h4
o`00013o[XV:0ol0000GongTn`?o00003ooIi=44o`0001ooWN?D1?l00003ok:Vf0?o00004on4WIX3
o`0009kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POoooolWo`00
02;o`/SP0ol00006ojNn/@So00003_o;ZlL3o`0000OoQ8VG1Ol00?l=ohB9U`?o00001?o9//L8o`00
00koTiVK0_l0000Qojc<Z0?o00001OnbVi43o`0002Co/:b^0_l0000Bojj9RP;o00006?o]i?/2o`00
00gofNCA1Ol0000RoigSe0Co000000?o/ZKHo`000?l000004on4WIX3o`0009oooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0POoooolVo`0002;o`/SP0ol0000=ojNn/@?o
00003?o;ZlL3o`0000SoQ8VG1Ol00?l>ohB9U`;o000000?obK;7o`000?l000001_l0000Aoi>IV`?o
00007on/c:P3o`0000Oo/Y^A0ol0000Rok2/[P?o00004_n^RHX2o`0001SokNCk0ol0000;omWTd@Co
00009OnMhm@6o`00017oQ9fJ1?l0002Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo087ooooo0_l0000RohVh/0?o00008?o2b>03o`0000ooYkja0ol0000:ol^[a`?o0000
2_n4RIL3o`00o`ooQ8VG1ol0000Foi>IV`?o00007On/c:P3o`0000Wo/Y^A0ol0000Ook2/[PCo0000
4on^RHX2o`0001WokNCk0ol00008omWTd@Co0000:OnMhm@4o`0000koQ9fJ1_l0002Qooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0ol0000SohVh/0?o00007_o2
b>03o`00017oYkja0ol00008ol^[a`?o00007_n4RIL3o`0001[oTiVK0_l0000Lojc<Z0?o00002onb
Vi43o`0001co/:b^1Ol0000Dojj9RP?o00006Oo]i?/3o`0000GofNCA1Ol0000/oigSe0;o00002on4
WIX7o`000:?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool2
o`0002GoRKR`0ol0000Lol;8h0?o00004onW_[43o`0000Kobj_70ol0000OohB9U`;o00006onCVI/3
o`0001[o[<bX0ol0000=ok:KT@Co00006?n`[:h8o`0001Co[XV:0_l0000JongTn`?o00000ooIi=44
o`0002koWN?D0ol00007ohBMVPOo0000Y_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`20ooooo`;o00009_n9^;03o`0001[o`/SP0ol0000EojNn/@?o00001?o;ZlL3o`00
01ooQ8VG0ol0000Loi>IV`?o00006?n/c:P3o`0000oo/Y^A1?l0000Eok2/[PGo00000on<VJ@2o`00
01Co[XV:0_l0000KongTn`Oo0000<OnMhm@3o`0000?oQ9fJ1ol0002Yooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0ol0000WohVh/0;o00006Oo2b>03o`0001Oo
Ykja0ol00002ol^[a`?o00008?n4RIL2o`0001koTiVK0ol0000Fojc<Z0?o00004_nbVi43o`0001;o
/:b^1Ol00005ohbIY0;o00005?n^RHX2o`0000OokNCk0ol00?lBongTn`Go0000<onMhm@9o`000:co
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002SoRKR`
0ol0000Gol;8h0?o00006OnW_[46o`00027oQ8VG0_l0000Ooi>IV`;o00005On/c:P3o`0001Co/Y^A
0ol0000?ok2/[PGo00001on<VJ@3o`0001?o[XV:0ol00005ongTn`Go003o4_o]i?/2o`0003GoWN?D
1_l0002_ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0
000YohVh/0?o00005Oo2b>03o`0001_oYkja1?l0000QohB9U`?o00007onCVI/3o`0001?o[<bX0ol0
000Fok:KT@?o00003?n`[:h5o`0000[oS9VT0_l0000Dojj9RP;o00001Oo]i?/5o`00oa;okNCk0_l0
000foigSe0;o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1o
ooooo`;o0000:_n9^;03o`0001?o`/SP0ol0000MojNn/@;o00008_n4RIL2o`00027oTiVK0ol0000A
ojc<Z0?o00006?nbVi43o`0000Wo/:b^1Ol0000<ohbIY0;o00005?n^RHX2o`0000GokNCk1Ol00?lB
ongTn`;o0000=_nMhm@2o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0001ooooo
o`;o0000:on9^;02o`0001;o`/SP0ol0000NojNn/@?o00008On4RIL2o`00013oTiVK0ol00?l?oi>I
V`;o00004?n/c:P3o`0001[o/Y^A0ol00006ok2/[PGo00003_n<VJ@3o`0000_o[XV:0ol00?l5ojj9
RP?o00001Oo]i?/3o`00oa;okNCk0ol0000BoigSe0?o003o8OnMhm@2o`000;3ooooo0ol0000:oooo
o`006_ooool00ol0003oooooooooo`1oooooo`?o0000:_n9^;03o`00013o`/SP0ol0000PojNn/@?o
00007on4RIL3o`0000ooTiVK1Ol00?l>oi>IV`?o00003_n/c:P3o`0001co/Y^A0ol00003ok2/[PGo
00004On<VJ@2o`0000[o[XV:1Ol00?l5ojj9RP;o00006_o]i?/2o`0001;oWN?D1Ol00?lPoigSe0;o
0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o0000
:on9^;03o`0000ko`/SP0ol0000QojNn/@Ko00007?n4RIL2o`00013oTiVK1Ol00?l?oi>IV`?o0000
3?n/c:P3o`0001ko/Y^A2?l0000CohbIY0;o00002_n^RHX5o`00o`Go[XV:0_l0000JongTn`;o0000
4_nMhm@5o`00oaooWN?D0ol0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo083ooooo0_l0000/ohVh/0?o00003?o2b>03o`00027oYkja2_l0000IohB9U`;o00004?nC
VI/5o`00oa3oTiVK1ol00004ojc<Z0Go00008?nbVi45o`0001GoS9VT0ol00009ojj9RPGo003o1On^
RHX2o`0001[okNCk0_l0000BoigSe0Go003o7onMhm@2o`000;?ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0P?ooool2o`0002goRKR`1_l00007ol;8h0?o00003onW_[43
o`00o`ooYkja0ol00004okfGS0Ko00005_n4RIL3o`00017oTiVK0ol00?lAoi>IV`oo00008_nbVi42
o`0001SoS9VT0_l0000:ojj9RP?o003o1_n^RHX3o`0001WokNCk0_l0000CoigSe0?o003o8?nMhm@2
o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool2o`00
02koRKR`2_l000001?o2b>3o0000o`000?l0000?ojNn/@Go003o3_nW_[42o`0000So_IN<1_l0000B
ohB9U`Co00009?nCVI/3o`0000Co/kjm1_l000001?n5SjKo0000o`000?l0000Qok:KT@;o00006?n<
VJ@2o`0001Co[XV:0_l0000HongTn`?o0000=_nMhm@2o`000;?ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0P?ooool2o`0002goRKR`0ol00002ol^NZ`Wo00004?nW_[45
o`00o`goYkja0ol0000:okfGS0Ko00003on4RIL8o`00023oTiVK0ol00008ok>n_@;o00000on5SjH3
o`00023o/Y^A0_l0000HohbIY0?o00004on^RHX2o`0001SokNCk0_l0000foigSe0?o0000/oooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`?o0000:on9^;03o`00
00Sobij[0ol0000AojNn/@Go003o3OnW_[42o`0000ko_IN<1_l0000;ohB9U`?o00000_nSijH6o`00
01goTiVK0ol00009ok>n_@;o00001?n5SjH3o`0001oo/Y^A0_l0000IohbIY0;o00004on^RHX2o`00
01SokNCk0ol0000boigSe0Ko0000/oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`21ooooo`;o00006?n9^;03o`00oa3oRKR`0_l0000:ol^NZ`?o00004OnW_[43o`00o`go
Ykja0ol0000@okfGS0Oo00001on4RIL3o`0000KoXnNV1_l0000Ioi>IV`?o00002_nc_[d2o`0000Go
QHnV0ol0000?ok:KT@?o003o3?nbVi42o`0000goS9VT0ol00?l9ohbIY0;o00004on^RHX3o`0001Ko
kNCk1_l0000]oigSe0Wo0000/oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`21ooooo`;o00005on9^;05o`00o`koRKR`0ol0000;ol^NZbGo00005?nmUh`6o`0000CoQ8VG
0ol00009oj?WYPKo00005_nCVI/3o`0000_o/kjm0_l00006ohF?YP;o00003_nbVi45o`00o`_o/Y^A
0_l0000<ohbIY0Go003o2?n<VJ@3o`0001;o[XV:6ol000000ooPbKOo0000o`000003o`0002WoWN?D
1_l00003oif5[0?o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`21ooooo`;o00005on9^;05o`00o`goRKR`0ol0000=ol^NZb?o00006?nmUh`9o`0000goXnNV1_l0
000Boi>IV`?o00003?nc_[d2o`0000KoQHnV0ol0000=ok:KT@Go003o2onbVi42o`0000coS9VT1Ol0
0?l9ohbIY0;o00004On^RHXKo`0000Coh<Vg1?l0000UoigSe0Ko00001onMQJ`2o`000;;ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0001OoRKR`1Ol00?l=
ohVh/0;o00003_o;WZ/3o`0000oojm7Z0ol00?l<on_AjP;o00006_nmUh`6o`00013oXnNV1ol0000>
oi>IV`?o00003Onc_[d2o`0000OoQHnV0ol0000<ok:KT@Go003o2onbVi42o`0000coS9VT1Ol00?l9
ohbIY0;o00004?n^RHX3o`0001Oob;Zh0_l00006on39]`Co00008?nMhm@7o`0000WoWHF/0_l0002b
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000HohVh
/0?o003o3On9^;03o`0000oobij[0_l0000>on_AjPGo003o2_o[dNX3o`0001go_IN<0_l0000Doj?W
YPKo00002onCVI/3o`0000ko/kjm0_l00008ohF?YP?o00003?nbVi43o`00o`co/Y^A0_l0000=ohbI
Y0?o003o2_n<VJ@3o`0000ko[XV:0ol0000GolRj^0?o00001ooPbKL5o`0001_oWN?D1ol0000<oif5
[0?o0000/Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`?o
00009_n9^;03o`00013obij[0ol0000=on_AjPGo003o2_o[dNX2o`0001ko_IN<0_l0000Goj?WYPKo
00001onCVI/3o`0000oo/kjm0_l00009ohF?YP?o00006_nbVi42o`0001_oS9VT0_l0000=ojj9RP?o
00006?o8^[P2o`0000[oh<Vg1Ol0000GoigSe0Ko00004?nMQJ`2o`000;7ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0P_ooool2o`0002KoRKR`0_l0000Bol^NZ`;o0000
3Oo[dNX5o`00o`[ojm7Z0_l0000NokfGS0;o00006OnSijH6o`0000CoTiVK0ol0000@ok>n_@;o0000
2_n5SjH2o`0001[o/Y^A0_l0000KohbIY0;o00003?n^RHX3o`0001Wob;Zh0_l0000<on39]`Go0000
4_nMhm@6o`0001?oWHF/0_l0002aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo08;ooooo0_l0000UohVh/0?o00004Oo;WZ/4o`0000gojm7Z0ol00?l;on_AjP;o00007_nm
Uh`2o`0001coXnNV2Ol0000Aok>n_@;o00002_n5SjH3o`0001Wo/Y^A8?l00009ojj9RPCo00006Oo8
^[P3o`0000koh<Vg1Ol0000=oigSe0Oo00005OnMQJ`2o`000;7ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0P_ooool2o`0002CoRKR`0ol0000Bol^NZ`Go00006Oo[dNX3
o`0001go_IN<0ol0000Noj?WYPKo00004_nc_[d2o`0000_oQHnV0ol0000Hok:KTB3o00002?n^RHX4
o`0001[ob;Zh0_l0000Aon39]`Co00002_nMhm@6o`0001SoWHF/0ol0002`ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000TohVh/0;o00004_o;WZ/3o`00
0004ok2XXol0003o0000o`0001Sojm7Z0_l0000MokfGS0Co00008OnSijH2o`0001?o/kjm0_l0000<
ohF?YP?o00005_nbVi43o`0001coRi6Y0ol00006ojj9RP?o00007?o8^[P2o`0001?oh<Vg1?l00005
oigSe0Ko00007?nMQJ`2o`000;3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0P_ooool2o`0002?oRKR`0ol0000Bol^NZ`;o00000on`Z:<3o`0001Oojm7Z0_l0000KokfG
S0Oo00008?nSijH2o`0001?o/kjm0_l0000=ohF?YP;o00005_nbVi42o`0001koRi6Y0ol00004ojj9
RP?o00007?o8^[P3o`0001Coh<Vg3?l0000Noif5[0;o0000/?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`22ooooo`?o00008On9^;03o`0001;obij[0ol00004ok2XX`;o
00005oo[dNX2o`0000_o_IN<0ol00?l<okfGS0Co00000_n[V;T2o`00013oXnNV0ol00?l=oj?WYP;o
00004onc_[d2o`0000goQHnV0ol0000Eok:KT@;o00003_n;TJT3o`00o`koRi6Y0ol00002ojj9RP?o
00003_o8^[P3o`00o`cob;Zh0_l0000Gon39]`Oo00008OnMQJ`2o`000;3ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0Poooool2o`00023oRKR`0ol0000Col^NZ`;o0000
1On`Z:<3o`0001Gojm7Z0ol0000:okfGS0Go003o2OnmUh`4o`0000CoZiRi0_l0000?oj?WYPGo003o
3?nSijH2o`0001?o/kjm0_l0000>ohF?YP?o00004onbVi43o`0000goRi6Y1Ol00?l>oh^AZ@Ko0000
3_o8^[P5o`00o`_ob;Zh0_l0000Ion39]`;o00009?nMQJ`2o`000;3ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Poooool2o`00023oRKR`0_l0000Col^NZ`?o00001_n`
Z:<3o`0001Cojm7Z0_l0000;okfGS0Go003o2?nmUh`4o`0000GoZiRi0ol0000>oj?WYPGo003o3?nS
ijH2o`0001?o/kjm0_l0000?ohF?YP?o00004_nbVi42o`0000koRi6Y1Ol00?l?oh^AZ@Co00003oo8
^[P5o`00o`[ob;Zh0ol0000Ion39]`;o00008onMQJ`3o`000;3ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0Poooool2o`0001ooRKR`0ol0000Col^NZ`;o00002?n`Z:<3
o`0001?ojm7Z0_l0000;okfGS0Go003o1_nmUh`4o`0000SoZiRi0_l0000>oj?WYPGo003o2onSijH3
o`0001?o/kjm0_l0000@ohF?YP?o00004?nbVi43o`0000koRi6Y1Ol00?l@oh^AZ@;o00004?o8^[P5
o`00o`[ob;Zh0_l0000Jon39]`;o00008onMQJ`2o`000;7ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Poooool2o`0001koRKR`0ol0000=ol^NZ`?o003o0oo;WZ/3o`00
00Wo/:RS0ol0000Bon_AjP;o00003?nmUh`3o`00o`Ko_IN<1?l00009oj^H^@;o00003onSijH3o`00
o`coXnNV0_l0000>ok>n_@?o003o0onc_[d2o`0000?oQHnV0ol00?l;ohF?YP;o00004?nbVi42o`00
013oRi6Y0ol00?lAoh^AZ@;o00004Oo8^[P3o`00o`_ob;Zh0_l0000Ion39]`?o00008onMQJ`2o`00
0;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Poooool2o`0001ko
RKR`0_l0000=ol^NZ`Go003o0_o;WZ/2o`0000_o/:RS0_l0000Aon_AjP?o00004onmUh`4o`0000_o
ZiRi0ol0000Moj?WYP;o00003Onc_[d5o`00o`;o/kjm0_l00002ohF?YPGo003o2_n5SjH3o`0000oo
/Y^A0_l0000Toh^AZ@;o00007_o8^[P3o`0001Woh<Vg0_l0000Toif5[0;o0000/Oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`23ooooo`?o00007?n9^;03o`0000gobij[
1Ol00?l01?o;WZ_o0000o`000?l0000;ok2XX`?o00004?o[dNX2o`0001?o_IN<1?l0000=oj^H^@;o
00007OnSijH2o`0000go/kjm1Ol00?l2ok>n_@;o00000_n5SjH5o`00o`_oQHnV0ol0000=ok:KT@?o
00009?n;TJTRo`0001[oh<Vg0_l0000Toif5[0;o0000/Oooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`24ooooo`;o00006on9^;03o`0000kobij[1Ol00?l00oo;WZ_o0000
o`00000=ok2XX`?o00003oo[dNX2o`0001;o_IN<0ol0000?oj^H^@;o00007?nSijH3o`0000go/kjm
1Ol00?l2ok>n_@;o00000_n5SjH5o`00o`coQHnV0ol0000<ok:KT@;o00009On;TJTRo`0001[oh<Vg
0_l0000Soif5[0?o0000/Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`24ooooo`Go00006?n9^;02o`00013obij[0ol00?l01?o;WZ_o0000o`000?l00003o`00o`_o/:RS
0ol0000>on_AjP;o00004?nmUh`4o`00013oZiRi0ol0000Hoj?WYPKo00003_nc_[d3o`00o`?o/kjm
0_l00003ohF?YP?o003o3_n5SjH9o`0000Go/Y^A0_l0000Toh^AZ@?o00004OoIYKH3o`00o`[ofJFf
0_l0000<on39]`?o003o2ooPbKL2o`0002?oWHF/0_l0002booooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08?ooooo2ol0000BohVh/0?o00005?o;WZ/2o`0000Go003o2on`
Z:<2o`0000gojm7Z0ol0000?okfGS0Co00004_n[V;T2o`0001KoXnNV2Ol0000Cok>n_@;o00004on5
SjHAo`0002?oRi6Y0ol0000AomVU]PGo003o2OoIYKH2o`0000_oh<Vg1Ol00?l:on39]`;o00008onM
QJ`2o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool3
o`0000?oe<G02ol0000<ohVh/0?o00005?o;WZ/3o`0000Go003o2on`Z:<3o`0000[ojm7Z1Ol0000=
okfGS0Co00005?n[V;T2o`0001?oXnNV1_l00004ol20YP?o00004_nc_[d2o`0001;oQHnV0ol00007
olF`[POo00008on;TJT5o`00013ofJFf1Ol00?l9omVU]P;o00002ooPbKL5o`00o`Woh<Vg0ol0000S
oif5[0;o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22oooo
o`;o00002OoDaL0;o`0000OoRKR`0_l0000Dol^NZ`?o000000?o/:RSo`00ool00?l00ol00?l<ok2X
X`?o00001Oo[dNX:o`0000_o_IN<1?l0000Eoj^H^@?o00004?nSijH6o`0000Oo`82V0_l0000Bok>n
_@;o00004On5SjH3o`0000goaK2^0ol0000Poh^AZ@Co000000Coeio9o`000?l0003o00003ooIYKH5
o`00o`WofJFf0_l0000;on39]`Go003o2OoPbKL2o`0002CoWHF/0_l0002booooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000>omC5`0_o000000CoRKR`o`00
0?l0003o00005?o;WZ/2o`0000?o/:RS0ol00?l>ok2XX`?o000000?ojm7Zo`000?l000001_l00003
oicK^P?o00002?nmUh`4o`0000OoZiRi0ol00?l>oj^H^@;o00003OnSijH6o`0000[o`82V0ol0000A
ok>n_@;o00003on5SjH4o`0000ooaK2^0ol0000Noh^AZ@Co00000ooGWlT3o`0000oofJFf0ol00?l:
omVU]P;o00003?oPbKL3o`00o`[oh<Vg0_l0000<oif5[0?o003o5?nMQJ`3o`000;;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool2o`0001?oe<G02Ol0000Dol^N
Z`?o00005On`Z:<7o`0000SoW=^j1?l00005okfGS0Co00001on[V;T5o`00o`goZiRi0_l0000;oj?W
YPKo00003Oo0P:H3o`00013o/kjm0_l0000>ohF?YPCo00004Oo5/:h3o`0001_oRi6Y1?l00006omNO
b@?o00006ooIYKH2o`0001Woh<Vg0_l0000;oif5[0Go003o4onMQJ`2o`000;?ooooo00?o0000oooo
ooooool02?ooool001[ooooo0ol00022ooooo`;o00006?oDaL03o`0001Gobij[0_l0000Gok2XX`?o
00003?nLfkX4o`0000;o_IN<1?l00009oj^H^@Go003o3On[V;T3o`0000SoXnNV1Ol0000Aol20YP;o
00004?nc_[d2o`0000goQHnV0ol0000DolF`[P;o00006_n;TJT4o`0000Soeio90ol0000JomVU]P;o
00006OoPbKL2o`0000_oWHF/1Ol00?lCoif5[0;o0000/Oooool3o`0000[ooooo000Jooooo`03o`00
0?oooooooooo08;ooooo0_l0000IomC5`0?o00004oo;WZ/3o`0001Ko/:RS0ol0000?oicK^POo0000
2_n[V;T5o`00o`koZiRi0_l00005oj?WYPKo00004oo0P:H3o`0000oo/kjm0_l0000;ohF?YPCo0000
5Oo5/:h3o`0001SoRi6Y0ol0000;omNOb@?o00006OoIYKH2o`0001Woh<Vg0_l0000;oif5[0Go003o
4onMQJ`2o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_oo
ool2o`0001[oe<G00ol0000Bol^NZ`;o00005_n`Z:<3o`00017oW=^j1?l0000=oj^H^@?o003o3on[
V;T2o`0000?oXnNV1_l0000Fol20YP?o00003_nc_[d2o`0000[oQHnV1?l0000GolF`[PSo00004?n;
TJT4o`0000goeio90ol0000HomVU]P;o00006?oPbKL3o`0000coWHF/0ol00?lDoif5[0;o0000/ooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`;o00006ooDaL03
o`00013obij[0ol0000Eok2XX`?o00004onLfkX2o`00023oZiRi2?l0000Jol20YP;o00003_nc_[d2
o`0000WoQHnV0ol0000JolF`[Q;o00001?n;TJT4o`0000ooeio90ol0000GomVU]P;o00006?oPbKL2
o`0002?oWHF/0ol0002cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08;ooooo0_l0000LomC5`0?o00003oo;WZ/2o`0001Ko/:RS0_l0000DoicK^P?o00008?n[V;T5o`00
01co`82V0ol0000=ok>n_@;o00002?n5SjH3o`0001_oaK2^0_l00004omO2ia;o00004_oGWlT3o`00
01KofJFf0_l0000Gon39]`Co00008_nMQJ`2o`000;Cooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0POooool3o`0001goe<G00ol0000=ol^NZ`?o00005On`Z:<3o`0001Go
W=^j0_l0000Poj^H^@;o00004_o0P:H3o`00o`_o`82V0ol0000<ok>n_@;o00001_n5SjH4o`0001_o
aK2^0ol0000?omO2i`Ko00005?oGWlT3o`0001GofJFf0_l0000Fon39]`Oo00008?nMQJ`2o`000;Co
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0001ooe<G0
0ol0000<ol^NZ`;o00005On`Z:<3o`0001KoW=^j0ol0000Ooj^H^@;o00004Oo0P:H5o`00o`_o`82V
0_l0000<ok>n_@;o00001On5SjH4o`0001coaK2^0_l0000DomO2i`;o00005OoGWlT3o`0001CofJFf
0_l0000Don39]`Co00000_nOTVh4o`0001ooWHF/0_l0002dooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo087ooooo0_l0000PomC5`0?o00002_o;WZ/3o`0001Co/:RS0ol0
000HoicK^P?o00007_n[V;T2o`00017o`82V1Ol00?l;ol20YP?o00002onc_[d2o`0000CoQHnV0ol0
000NolF`[P;o00005?oG`^L2o`0001Koeio96?l0000Con39]`Co00001OnOTVh4o`0001goWHF/0_l0
002dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000Q
omC5`0?o00002Oo;WZ/2o`0001Go/:RS0_l0000JoicK^P;o00007On[V;T3o`00017o`82V1Ol00?l<
ol20YPCo00002Onc_[d2o`0000;oQHnV1?l0000NolF`[P?o00005?oG`^L3o`0001Koeio95ol0000A
on39]`Co00002?nOTVh5o`0001[oWHF/0ol0002dooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo087ooooo0_l0000RomC5`0?o00001oo;WZ/3o`0001Co/:RS0ol0000JoicK
^P?o00006On[V;T6o`0001;o`82V0ol00?l;ol20YPSo00001onc_[d2o`000003ohF?Y_l0003o0000
00;o00003_o5/:h3o`00o`koaK2^0_l0000FomO2i`;o00005_oGWlT2o`0001?o[jW@0ol0000?on39
]`Co00002onOTVh4o`0001WoWHF/0_l0002eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo087ooooo0_l0000SomC5`0?o00001_o;WZ/2o`0001Co/:RS0ol0000LoicK^P;o
00005on[V;T9o`0001go`82V1Ol00002oijmSPKo00001?nc_[d5o`0000ooaK2^1Ol00?l=olF`[P;o
00005_oG`^L2o`0001Goeio90ol0000DojnYd0?o00003?oPbKL4o`0000ooWi9^1?l0000Goif5[0;o
0000]Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o0000
9?oDaL0;o`0001;o/:RS0ol0000MoicK^P?o00005?n[V;T5o`0000CoaMfa0ol0000Jol20YPGo0000
1_nN_Hh6o`0000;o/kjm1?l0000@olF`[PGo003o3Oo5/:h2o`0001Koel;W0_l0000EomNOb@;o0000
5_n_ZM03o`0000[oh<Vg1?l0000AoinBKPGo00005OnMQJ`2o`000;Gooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002Goe<G03ol0000=ok2XX`;o00007onL
fkX2o`00017oZiRi1_l00007olGM/@?o00005oo0P:H5o`0000_oW[f>2?l0000AolF`[PGo003o3?o5
/:h3o`0001Koel;W0_l0000EomNOb@;o00005on_ZM05o`0000Goh<Vg1?l0000EoinBKPGo00004onM
QJ`2o`000;Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2
o`0002Coe<G00ol00007ogR6X`_o00001on`Z:<3o`0000ooW=^j0ol00?l=oicK^P?o00003_n[V;T6
o`0000[oaMfa0_l0000Eol20YPGo00003onN_Hh5o`0001?oaK2^0ol00?l=olF`[P;o00005ooG`^L2
o`0000_oeio90ol00?l7omNOb@;o00006?n_ZM07o`000003on39]ol0003o000000;o00006?nOTVh4
o`00017oWHF/0ol0002eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
087ooooo0_l0000TomC5`0;o00003OmhQZ<;o`000004ok2XXol0003o0000o`0000ooW=^j1Ol00?l=
oicK^P;o00002on[V;T6o`0000goaMfa0ol0000Bol20YPGo00004onN_Hh2o`0002CoaK2^0_l0000G
omO2i`?o00002OoGWlT5o`00o`Koeio90_l0000GojnYd0?o000000?oPJRmo`000?l000001Ol0000L
oinBKPCo00003onMQJ`2o`000;Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0POooool2o`0002Coe<G00_l0000BogR6X`Wo00004?nLfkX5o`00o`goW=^j0ol00008oj^H
^@Ko00004?o5gK43o`00013o`82V1?l0000EoijmSP;o00008oo5/:h3o`0001Soel;W0_l00009omNO
b@Go003o1OoGWlT3o`0001Ko[jW@0ol00005oh6X_@?o00007_nOTVh5o`0000goWHF/0_l0002foooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000SomC5`0?o
00005omhQZ<3o`00017oW=^j1Ol00?l>oicK^P?o00001On[V;T5o`0001CoaMfa0_l0000>ol20YPCo
00005onN_Hh3o`0002;oaK2^0_l0000IomO2i`;o00002OoGWlT5o`00o`Goeio90_l0000FojnYd0?o
00001on1Z;d3o`0001ooWi9^1?l0000;oif5[0?o0000]_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`21ooooo`;o00004OoDaL03o`00o`ooe<G00_l0000IogR6X`?o0000
4OnLfkX3o`00oa3oW=^j0_l00002oj^H^@Ko00005_o5gK43o`0000_o`82V1Ol0000IoijmSP;o0000
8_o5/:h2o`0000koel;W0ol00?l8omO2i`;o00002_oGWlT3o`00o`Koeio90_l00008ojnYd0?o003o
2on_ZM02o`0000WoPJRm0_l0000?oinBKP?o003o3onOTVh4o`0000SoWHF/0ol0002gooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000@omC5`0Go003o3_oD
aL02o`0001[oN8JS0_l0000ToicK^PSo00006Oo5gK43o`0000So`82V1Ol0000KoijmSP;o00008_o5
/:h2o`0000goel;W1Ol00?l7omO2i`;o00004ooGWlT2o`0000Oo[jW@1Ol00?l9ojnYd0?o00002On1
Z;d3o`0000goWi9^1Ol00?l?oinBKPGo00001OnMQJ`3o`000;Sooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0POooool2o`00013oe<G01Ol00?l=omC5`0?o00006_mhQZ<3
o`0002CoW=^j1Ol0000LolGM/@?o00001Oo0P:H5o`0001goW[f>0ol0000PolF`[P?o00003OoG`^L5
o`00o`Ooel;W0ol0000BomNOb@;o00001on_ZM05o`00o`So[jW@0ol0000;oh6X_@;o00003OnOTVh5
o`00oa7oWi9^1?l00003oif5[0?o0000^Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`21ooooo`;o00004?oDaL05o`00o`goe<G00_l0000LogR6X`;o00008onLfkX3o`00
0004oh^]`_l0003o0000o`0001coaMfa0_l00003ol20YPGo00008?nN_Hh2o`00023oaK2^0_l0000>
omO2i`Go003o2?oG`^L2o`00017oeio90ol00007ojnYd0Go003o1on_ZM03o`0000coPJRm0ol0000<
oinBKPGo003o4onOTVh7o`000;[ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0P?ooool3o`00017oe<G00ol00?l>omC5`0;o00007?mhQZ<2o`0002;oW=^j0ol00003oh^]
`P?o00006oo5gK48o`0000_oW[f>0ol00?lDoijmSP;o00008?o5/:h2o`0000ooel;W0ol00?l9omO2
i`;o00004OoGWlT2o`0000Wo[jW@0ol00?l8ojnYd0;o00003_n1Z;d2o`0000goWi9^0ol00?lEoinB
KPGo0000^oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o
00008_oDaL03o`0001coN8JS0ol0000QoicK^P;o00001On;[L83o`0001_oaMfa1Ol0000<oijmSPGo
003o4onN_Hh2o`0001ooaK2^0ol0000KomO2i`;o00004OoGWlT2o`0001?o[jW@0ol0000>oh6X_@?o
00009_nOTVh2o`000;cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
P?ooool2o`0002;oe<G00_l0000NogR6X`;o00008?nLfkX3o`0000KoRjg20ol0000KolGM/@;o0000
3_nN_Hh5o`00oa?oW[f>0ol0000JolF`[PKo00007?oG`^L2o`00017oeio90_l0000BojnYd0?o0000
4?n1Z;d2o`0002GoWi9^0ol0002looooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo083ooooo0_l0000RomC5`0;o00007_mhQZ<3o`0001koW=^j0ol00008oh^]`P?o00006_o5
gK42o`0000koW[f>1Ol00?lDoijmSP;o00004_o5/:h>o`0001coel;W0_l0000AomNOb@;o00004On_
ZM03o`00017oPJRm0_l0000UoinBKP;o0000_Oooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`20ooooo`;o00008OoDaL03o`0001ooN8JS0_l0000NoicK^P;o00002_n;[L83
o`0000SoaMfa0ol00?l>olGM/@;o00003onN_Hh3o`00oaGoW[f>0_l0000;olF`[Q3o00000onNWi43
o`0001_oel;W0ol0000?omNOb@?o00004?n_ZM03o`0001;oPJRm0ol0000SoinBKP?o0000_Oooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o00008OoDaL02o`00
023oN8JS0ol0000LoicK^P?o00002on;[L83o`0000KoaMfa1Ol00?l=olGM/@;o00009onN_Hh3o`00
00;oaK2^4?l0000<oijOT@?o00006ooG`^L2o`0000ooeio90_l0000AojnYd0;o00005?n1Z;d2o`00
02?oWi9^0_l0002nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083o
oooo0_l0000QomC5`0;o00008OmhQZ<2o`0001coW=^j0_l0000=oh^]`P?o00001Oo5gK45o`00o`go
aMfa0ol0000WoijmSPgo00005?nNWi43o`0001[oel;W0_l0000?omNOb@;o00004?n_ZM03o`0001Co
PJRm0ol0000RoinBKP;o0000__ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`20ooooo`;o00008?oDaL03o`0000koN8JS0ol00?l@ogR6X`;o00006onLfkX3o`0000koRjg2
0ol00004olGM/@Go003o3_o5gK42o`0002OoW[f>1Ol0000MoijOT@?o00006OoG`^L2o`0000ooeio9
0_l0000?ojnYd0?o00001on1Z;d3o`00o`coPJRm0_l0000QoinBKP?o0000__ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o00008?oDaL02o`0000koN8JS1Ol0
0?l?ogR6X`Oo00005OnLfkX3o`00013oRjg20ol00004olGM/@?o003o3oo5gK42o`0002KoW[f>0ol0
000QoijOT@;o00006OoG`^L2o`0000ooeio90_l0000>ojnYd0?o00001on1Z;d5o`00o`_oPJRm0ol0
000PoinBKP;o0000_oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20
ooooo`?o00007ooDaL02o`0000koN8JS1Ol00?l@ogR6X`oo00003?nLfkX2o`0001;oRjg20ol0000E
olGM/@;o00009_nN_Hh2o`0002;oWYnA0ol0000HomO2i`;o00003_oGWlT3o`0000ko[jW@0_l00008
oh6X_@Go003o3?n1Z;d2o`0001ooWi9^0ol0002oooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo087ooooo0ol0000MomC5`0?o00003_mhQZ<5o`00o`ooN8JS0ol00003ok:/
Ua;o00000onLfkX3o`0001?oRjg20ol0000DolGM/@;o00009_nN_Hh2o`0002?oWYnA0ol0000GomO2
i`?o00003OoGWlT2o`0000ko[jW@0ol00008oh6X_@Go003o3?n1Z;d7o`0001[oWi9^0_l00030oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0ol0000LomC5`0;o
00004?mhQZ<3o`00oa3oN8JS0_l0000=ok:/U`ko00004On;[L83o`00o`04oh^]`_l0003o0000o`00
01?oaMfa0_l0000UoijmSP?o00009?nNWi43o`0001Ooel;W0_l00006omNOb@[o00003?n_ZM03o`00
00[oPJRm0ol00?l>oh6X_@go00004_nOTVh3o`000<3ooooo00?o0000ooooooooool02?ooool001[o
oooo0ol00023ooooo`?o00006ooDaL02o`0002;oN8JS0ol0000Eok:/U`Go00004On;[L85o`00o`04
oh^]`_l0003o0000o`0001;oaMfa0_l0000UoijmSP;o00009_nNWi47o`0001;oel;W5?l00009ojnY
d0?o00006on1Z;d3o`0000?o/ZJc4?l0000:oinBKP;o0000_oooool3o`0000[ooooo000Jooooo`03
o`000?oooooooooo08Cooooo0_l0000IomC5`0Co00008_mhQZ<2o`0001Wo/ZbG1?l0000?oh^]`PGo
003o0_n;[L83o`00017oaMfa0_l0000UoijmSP;o00009onNWi4=o`0000[oel;W2_l00008omkO``Ko
00001_n_ZM02o`0001_oPJRm0ol0000;ok:V/a3o00000onOTVh2o`000<7ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0Q?ooool3o`0001Ooe<G02?l0000NogR6X`?o0000
6_nb[9L6o`0000coRjg21Ol00?l3oh^]`P?o00004?o5gK42o`0002CoW[f>0ol0000VoijOT@?o0000
0onc^jh?o`0000;oel;W0ol0000BomkO``Ko00000on_ZM03o`0001_oPJRm0_l0000Dok:V/`go0000
`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`?o00005?oD
aL04o`0000;o^L^j1_l0000LogR6X`;o00006onb[9L9o`0000[oRjg20ol00?l5oh^]`P?o00003oo5
gK43o`0001koW[f>1ol0000GoijOT@?o003o3OnNWi42o`0000_o/k^^3?l0000FomkO``So00006on1
Z;d3o`0001_o/ZJc1Ol00032ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08Kooooo0ol0000BomC5`0Co00001_nibkX6o`0001SoN8JS0ol0000Kok:/U`;o00000onJN887
o`00013oRjg20ol0000?olGM/@;o00005OnN_Hh@o`0001KoWYnA1Ol00?l;oijOT@?o00004_nc^jh4
o`0001Wog]o31Ol0000Koh6X_@?o00007onbY[<2o`000<;ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Qoooool3o`0000ooe<G01?l0000:okW;^PKo00005OmhQZ<3o`00
01co/ZbG0_l00006oiYhPPOo00003_n;[L83o`0000koaMfa0_l0000<oijmSQ?o00001?nPTiL3o`00
01GoWYnA1Ol00?l;oijOT@;o00005Onc^jh2o`0001_og]o30_l0000Loh6X_@;o00008?nbY[<2o`00
0<;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0R?ooool3o`0000go
e<G01?l0000>okW;^PKo00004_mhQZ<2o`0001go/ZbG0_l00009oiYhPPOo00003?n;[L83o`0000go
aMfa0_l00003oijmSQ?o00003_nPTiL2o`0001GoWYnA1Ol00?l:oijOT@?o00005Onc^jh2o`0001_o
g]o30ol0000Joh6X_@?o00008?nbY[<2o`000<;ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0ROooool2o`0000_oe<G01?l0000BokW;^PKo00003omhQZ<3o`0001go/ZbG
0_l0000<oiYhPPOo00002_n;[L83o`0000[oaMfa4Ol0000Goj2CU`;o00005_nNWi43o`00o`[oWYnA
0ol0000Fok>k[P;o00007?oNgl<3o`0001SoPJRm0ol0000Qok:V/`?o0000`Oooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`29ooooo`?o00002OoDaL04o`0001Ko^L^j1_l0
000<ogR6X`;o00007_nb[9L2o`0000ooVWR21ol00008oh^]`P?o00001Oo5gK4<o`00023oX9>G0ol0
000RoijOT@;o00005onc^jh2o`0001gog]o30_l0000Hoh6X_@;o00008onbY[<2o`000<7ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0R_ooool3o`0000Goe<G01Ol0000J
okW;^PKo00002OmhQZ<3o`0001ko/ZbG0_l0000BoiYhPPOo00001_n;[L83o`000003olGM/Ol0003o
000000Ko000000?oQ9o;o`000?l000009OnPTiL2o`00027oWYnA0ol0000Gok>k[P;o00007OoNgl<3
o`0001KoPJRm0ol0000Sok:V/`;o0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2;ooooo`?o000000?oe<G0o`000?l000001_l0000MokW;^PKo00001_mhQZ<2o`00
01oo/ZbG0_l0000EoiYhPPOo00001?n;[L87o`0000GoQ9o;0ol0000Soj2CU`Co00008?nNWi42o`00
01So/k^^0_l0000NomkO``?o00005On1Z;d2o`0002Co/ZJc0_l00031ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo08cooooo1ol00002okFVX`?o00007_nibkX6o`0000?o
N8JS0ol0000?ok:/U`?o003o3Onb[9L2o`0000goVWR20ol00?l8oiYhPPco00002On4Wl/2o`0002;o
X9>G1_l0000NoijOT@?o00006?nc^jh2o`0001oog]o30_l0000Doh6X_@?o00002onbY[<3o`00oaKo
/ZJc0_l00031ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08gooooo
0ol00006okFVX`?o00008?nibkX8o`0000oo/ZbG1Ol00?l<ok:/U`;o00003?nJN885o`00o`[oVWR2
1_l0000<ohBOb`;o00008OnPTiL3o`0000;oN8:j0_l0000NoijOT@;o00006Onc^jh2o`0001oog]o3
0ol0000Boh6X_@?o00002onbY[<5o`00oaCo/ZJc0ol00031ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08cooooo0ol00008okFVX`?o00008OnibkX6o`0000oo/ZbG1Ol0
0?l<ok:/U`;o00003?nJN885o`00o`goVWR20_l0000=ohBOb`;o00008?nPTiL3o`0000?oN8:j0ol0
000LoijOT@?o00006Onc^jh2o`00023og]o31Ol0000?oh6X_@;o00003?nbY[<5o`00oaCo/ZJc0_l0
0032ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0_l0000:
okFVX`?o00008onibkX2o`00013o/ZbG1Ol00?l<ok:/U`;o00003?nJN885o`00o`coVWR20ol0000=
ohBOb`;o00007onPTiL3o`0000GoN8:j0_l0000LoijOT@;o00006_nc^jh2o`00027og]o31ol0000;
oh6X_@?o00003?nbY[<5o`00oa?o/ZJc0ol00032ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo08_ooooo0ol0000;okFVX`?o00003onibkX3o`00oa3o^L^j0_l0000Aok:/
U`?o003o3Onb[9L2o`0000goVWR20ol00?l<oiYhPP?o00003_n4Wl/3o`0001goX9>G0ol00006ogR2
^P?o00006_nNWi43o`0000_o/k^^0ol00?l<ok>k[P;o00003OoNgl<3o`00oa3og]o30ol000000oo@
XJ;o0000o`000005o`0000OoPJRm0ol0000>ok:V/`?o003o5?nbY[<2o`000<?ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Roooool2o`0000go]JJS0ol0000=okW;^PGo
003o3onibkX2o`00027o/ZbG0_l0000KoiYhPP?o00004?n4Wl/2o`0001coX9>G0ol00008ogR2^PCo
00006?nNWi42o`0000_o/k^^1Ol00?l;ok>k[P;o00003?oNgl<5o`00o`kog]o30ol00005om2QXPOo
00001?n1Z;d2o`0002Go/ZJc0ol00033ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08[ooooo0ol0000>okFVX`?o00003?nibkX5o`00o`oo^L^j0_l0000Qok:/U`;o0000
6_nJN883o`00017oQ9o;0_l0000Koj2CU`?o00002_mhP[X6o`0001CoWYnA0ol0000;ok>k[PGo003o
2onc^jh2o`0000cog]o31Ol00?l=omkO``?o00002Oo@XJ8:o`0002Go/ZJc0_l00034ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08[ooooo0_l0000@okFVX`?o00002oni
bkX5o`00o`oo^L^j0ol0000Pok:/U`;o00006OnJN883o`0001;oQ9o;0_l0000?oj2CU`?o003o2?nP
TiL3o`0000[oN8:j2_l0000AoijOT@;o00003?nc^jh5o`00o`_o/k^^0_l0000<omkO``Go003o3?oN
gl<3o`0000god:6R1_l0000Uok:V/`?o0000a?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`29ooooo`?o00004OneYZ<3o`0000_o^L^j0ol00?lAokW;^P;o00008?nb[9L2
o`0001SoVWR20ol0000CohBOb`?o00003OnPTiL5o`00o`KoX9>G0ol0000;ogR2^P;o00001?ne/KL7
o`0000goWYnA0ol0000=ok>k[P?o003o3?nc^jh2o`0000gog]o30ol00?l<omkO``?o00004Oo@XJ82
o`0002Ko/ZJc0_l00035ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08Wooooo0_l0000CokFVX`?o00007_nibkX2o`00023o/ZbG0_l0000HoiYhPP;o00005On4Wl/2o`00
00goX9>G1Ol00?l5oj2CU`?o00003?mhP[X2o`0000Oo]K6g1_l0000:oijOT@?o00007Onc^jh2o`00
01cog]o30_l0000Bom2QXP?o00009?nbY[<3o`000<Gooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0ROooool2o`0001Co]JJS0ol0000MokW;^P;o00008?nb[9L2o`0001Oo
VWR20ol0000EohBOb`;o00003OnPTiL5o`00o`CoX9>G0ol0000<ogR2^P?o00002_ne/KL6o`0000Oo
WYnA0_l0000Nok>k[P;o00006ooNgl<3o`0001?od:6R0_l0000Tok:V/`;o0000a_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`28ooooo`?o00005OneYZ<3o`0001co^L^j
1?l0000Nok:/U`Ko00004_nJN883o`0001KoQ9o;0_l0000>oj2CU`?o003o1?nPTiL3o`0000goN8:j
0_l0000=okFa]`Oo00000onNWi43o`0001ko/k^^0_l0000JomkO``?o00005?o@XJ83o`0002?o/ZJc
0_l00036ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Sooooo0_l0
000GokFVX`?o00006onibkX7o`0001_o/ZbG3Ol0000:oiYhPP?o00005on4Wl/3o`0001?oX9>G0ol0
000>ogR2^P;o00004?ne/KL9o`0001oo/k^^0_l0000IomkO``?o00005_o@XJ82o`0002;o/ZJc0ol0
0036ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Oooooo0ol0000H
okFVX`?o00006OnibkX3o`000003ok;5_Ol0003o000000Go00005onb[9L3o`0000?o]9jC3ol00002
oiYhPP?o00006On4Wl/2o`0001;oX9>G0ol0000>ogR2^P?o00004one/KL6o`0001oo/k^^0_l0000H
omkO``?o00005oo@XJ86o`0001ko/ZJc0_l00037ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo08Oooooo0_l0000JokFVX`?o00005onibkX3o`0000Go//Fm2?l0000Bok:/
U`?o00002ondWY<<o`0001[oQ9o;0_l0000Aoj2CU`?o00003omhP[X2o`0001Oo]K6g0_l0000Pok>k
[P;o00005ooNgl<3o`0001Wod:6R3?l0000Fok:V/`?o0000aoooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`26ooooo`?o00006oneYZ<3o`0001Go^L^j0ol00009ok;5_@So
00003_nb[9L3o`0001?o]9jC1?l0000;ohBOb`?o003o3On4Wl/2o`00013oX9>G0ol00002ogR2^P?o
003o2omhP[X2o`0001Oo]K6g0ol0000Ook>k[P;o00005_oNgl<3o`0001[od:6R0_l00002ok2fc0ko
00004?nbY[<2o`000<Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
Q_ooool2o`0001go]JJS0ol0000DokW;^P;o00003_nbaKd8o`0000Wo/ZbG0ol0000FokBNT`;o0000
2_n4Wl/5o`00o`coQ9o;0_l0000?oj2CU`?o00000_mhP[X5o`00o`WoN8:j0ol0000HokFa]`;o0000
7Onc^jh5o`0001Gog]o30_l0000Jom2QXP?o00002On`]/`=o`0000Wo/ZJc0ol00038ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Kooooo0ol0000MokFVX`?o00004_ni
bkX3o`00017o//Fm2?l00005ok:/U`?o00005ondWY<3o`0000WoQ9o;1Ol00?l<ohBOb`?o00003OnP
TiL3o`0000?oN8:j1Ol00?l9ogR2^P;o00006One/KL3o`0001Wo/k^^2Ol0000ComkO``?o00006_o@
XJ82o`00013o/;K<3_l00002ok:V/`;o0000bOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`27ooooo`;o00007_neYZ<3o`00013o^L^j0ol0000Fok;5_@Oo000000Co/ZbG
o`000?l0003o00006OndWY<2o`0000WoQ9o;1Ol00?l=ohBOb`;o00003?nPTiL3o`0000CoN8:j1Ol0
0?l9ogR2^P;o00006_ne/KL2o`0001Go/k^^2?l00003ohR3ZP?o00004OoNgl<3o`0001_od:6R0_l0
000Fok2fc0co0000bOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`27
ooooo`;o00004_neYZ<3o`00o`[o]JJS0ol0000>okW;^P?o00006_nbaKd7o`0001[o]9jC0_l0000:
ohBOb`?o003o3_n4Wl/2o`0000_oX9>G0ol00006ogR2^P?o003o2OmhP[X3o`0001[o]K6g0ol0000A
ok>k[PSo00001on8PjX3o`0000oog]o30ol0000;om2QXP?o003o3_o@XJ82o`0001go/;K<1?l0003:
ooooo`03o`000?oooooooooo00Sooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2
o`0000[ooooo00?o0000ooooooooool0Qoooool3o`00013o]JJS1Ol00?l:okFVX`?o00003OnibkX2
o`0001ko//Fm0ol0000KokBNT`?o00006_n4Wl/2o`0000[oX9>G0ol0000CogR2^P;o00007?ne/KL3
o`0000co/k^^2?l0000<ohR3ZP?o00003OoNgl<3o`0000_od:6R1Ol00?l<om2QXP?o00007on`]/`2
o`000<[ooooo00?o0000ooooooooool02?ooool000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0R?oo
ool2o`00013o]JJS1Ol00?l;okFVX`?o00002onibkX3o`0001oo//Fm0_l0000LokBNT`;o00006_n4
Wl/3o`0000SoX9>G0ol0000DogR2^P;o00007One/KL2o`0000Wo/k^^2?l0000@ohR3ZQ7o00003?o@
XJ85o`00o`cod:6R0_l0000Pok2fc0;o0000b_ooool00ol0003oooooooooo`08ooooo`000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`28ooooo`?o00003oneYZ<5o`00o`co]JJS0ol00009okW;^P?o0000
8?nbaKd2o`0001co]9jC0_l0000KohBOb`;o00001onPTiL3o`0001CoN8:j0ol0000MokFa]`?o0000
1?nc^jh8o`0001GoR8>Z3ol0000=om2QXPGo003o3?o@XJ82o`00023o/;K<0ol00039ooooo`03o`00
0?oooooooooo00Sooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00009ooooo`Go0000Qoooool2o`00013o]JJS0ol00?l>okFVX`?o
00001_nibkX4o`00027o//Fm0ol0000?okBNT`?o003o2OndWY<3o`0001[oQ9o;0_l00006oj2CU`?o
00005OmhP[X2o`0000[o]K6g0ol00?lBokFa]`;o000000?o/k^^o`000?l000001_l0000HohR3ZP;o
00002ooWajL3o`0000god:6R0ol00?l=om2QXP;o00008On`]/`2o`000<Gooooo1Ol0000:ooooo`00
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`29ooooo`;o00008_neYZ<3o`0000Co^L^j1ol0000Pok;5
_@;o00003_ndWY<5o`00o`Wo]9jC0_l0000JohBOb`;o00001OnPTiL3o`0001KoN8:j0_l00009okFa
]`Go003o4One/KL7o`0001coR8>Z0_l0000<onO7Y`?o00006oo@XJ83o`00027o/;K<0_l00039oooo
o`03o`000?oooooooooo00Sooooo00000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`29ooooo`?o00008_neYZ<3
o`0000;o^L^j0ol00002okn[ePGo00007_nbaKd2o`0000ko]9jC1Ol00?l9okBNT`;o00006_n4Wl/2
o`0000CoX9>G0ol0000FogR2^P?o00002One/KL5o`00oa;o]K6g0ol0000NohR3ZP?o00003OoWajL3
o`0001[od:6R0_l0000Rok2fc0;o0000bOooool00ol0003oooooooooo`08ooooo`000_ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool0R_ooool2o`00
02?o]JJS1_l00005okn[ePGo00007?nbaKd2o`0000ko]9jC1Ol00?l9okBNT`?o00006On4Wl/3o`00
00;oX9>G0ol0000GogR2^P;o00002_ne/KL5o`00oa;o]K6g0_l0000OohR3ZP;o00003ooWajL3o`00
01Wod:6R0_l0000Rok2fc0;o0000bOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2:ooooo`?o00008oneYZ<4o`0000So_j_F1Ol00009ok;5_@?o003o3_nbaKd2o`0000oo
]9jC0ol00?l;okBNT`;o00006_n4Wl/7o`0001OoN8:j0_l0000;okFa]`?o003o4_ne/KL3o`0001oo
R8>Z0_l0000@onO7Y`;o00006Oo@XJ82o`0000ko/;K<0ol00?lAok2fc0?o0000b?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`;o00009?neYZ<2o`0000_o_j_F
1Ol00006ok;5_@Go003o3OnbaKd2o`0001go]9jC0_l0000JohBOb`[o00004omhP[X3o`00023o]K6g
0_l0000PohR3ZP;o00004?oWajL3o`0001Ood:6R0ol0000=ok2fc0Go003o4On`]/`2o`000<Sooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Roooool3o`0002;o]JJS0ol0
000=okn[ePGo00001?nbaKd5o`00o`go//Fm0_l0000MokBNT`?o00006?n4Wl/3o`0000Co/Jfo2?l0
000?ogR2^P;o00008One/KL2o`00023oR8>Z0_l0000AonO7Y`?o00005_o@XJ82o`0000ko/;K<1Ol0
0?lAok2fc0;o0000b?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<
ooooo`;o00008OneYZ<4o`0000oo_j_F1Ol00002ok;5_@Go003o3OnbaKd3o`0001go]9jC0_l0000G
ohBOb`?o00002?na[Kl8o`0000coN8:j0_l0000QokFa]`;o00008?n8PjX2o`0001;oilNW0ol0000E
om2QXP;o00003_n`]/`5o`00oa7o/;K<0_l00038ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo08cooooo0_l0000PokFVX`Ko00004?noZmH4o`0000;o//Fm0ol00?l?ok;5
_@;o00007OndWY<2o`0001KoQ9o;0ol0000=ok6]_`Oo00002?mhP[X3o`00027o]K6g0_l0000CohR3
ZP?o003o2_n8PjX2o`0001?oilNW0_l0000Eom2QXP;o00003on`]/`3o`00oa7o/;K<0ol00038oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0ol0000MokFVX`Co
00000_n2/KH3o`00017o_j_F1?l0000Bok;5_@;o00007OndWY<3o`0001CoQ9o;0ol0000Aok6]_`So
00001?mhP[X2o`00027o]K6g0ol0000BohR3ZPGo003o2?n8PjX3o`0001?oilNW0ol0000Com2QXP?o
00008_n`]/`3o`000<Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
SOooool2o`0001co]JJS1?l00004oh:a]P?o00004OnoZmH5o`0000oo//Fm1?l0000MokBNT`;o0000
4on4Wl/3o`0001Go/Jfo2?l000000omhP[[o0000o`00000QokFa]`;o00004on8PjX5o`00o`SoR8>Z
0_l0000EonO7Y`?o00004_o@XJ82o`0002?o/;K<0_l0003:ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08gooooo0ol0000JokFVX`?o00001on2/KH2o`00013o_j_F0ol0
0?l5o`0000co//Fm1ol0000KokBNT`;o00004_n4Wl/3o`0001[o/Jfo1ol0000QokFa]`?o00004_n8
PjX5o`00o`SoR8>Z0_l00009onO7Y`?o003o2_oWajL3o`00017od:6R0_l0000Rok2fc0?o0000b_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2>ooooo`;o00006?neYZ<4
o`0000SoP[6f0ol0000>okn[ePGo003o00?o_j_Fo`000?l000000ol00009ok;5_@?o00000_nWOHH4
o`0001[o]9jC0ol0000@ohBOb`?o00007_na[Kl3o`00027o]K6g1Ol0000BohR3ZP?o003o2On8PjX2
o`0000SoilNW1Ol00?l:onO7Y`?o00004?o@XJ82o`00027o/;K<0ol0003;ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08kooooo0_l0000GokFVX`Co00002_n2/KH3o`00
00go_j_F1Ol00?l3okn[ePGo00001_nbaKd3o`0000GoYgf61?l0000IokBNT`;o00003_n4Wl/4o`00
023o/Jfo0ol0000OokFa]`?o000000?ob]B_o`000?l000000_l0000LohR3ZP;o00002?oWajL5o`00
o`_oilNW0_l0000?om2QXP?o00008On`]/`2o`000<cooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0S_ooool4o`0001Co]JJS0ol0000=oh:a]P?o00003?noZmH5o`00o`Go
_j_F1Ol00003ok;5_@?o00001onWOHH5o`0001Oo]9jC0_l0000<ohBOb`Oo00008?na[Kl3o`0001go
]K6g0ol00003ol[D[`Co00006on8PjX2o`0000SoilNW1Ol00?l;onO7Y`?o00002oo@XJ85o`00027o
/;K<0ol0003<ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08oooooo
1?l0000BokFVX`?o00003on2/KH2o`0000go_j_F0ol00?l8okn[ePSo00002_nWOHH5o`0001Go]9jC
0ol00009ohBOb`Go00000_nkch@3o`00023o/Jfo8Ol00006ol[D[`Co00006?n8PjX3o`0000WoilNW
0ol00?l=onO7Y`?o00000oo@XJ8=o`0001oo/;K<0ol0003=ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo097ooooo1?l0000>okFVX`Co00004?n2/KH3o`0001Wo_j_F1Ol0
000=ojMmQPGo00005?ndWY<2o`0000OoQ9o;1Ol00005ok_?Q0?o00008?na[KlOo`0000Sob]B_1?l0
000GohR3ZP;o00006ooWajL=o`0000?onLg=0ol0000Nok2fc0;o0000c_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2Booooo`Go00002oneYZ<4o`0001;oP[6f0ol0000J
okn[eP;o00004?nWOHH4o`0001?o]9jC0_l00005ohBOb`Go00002?nkch@3o`0001oo/Jfo0_l0000K
oiF9a0;o00002_o:e:l4o`0001GoR8>Z0_l0000LonO7Y`Go00002ooicLd3o`0001co/;K<0ol0003>
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09Cooooo1?l00009okFV
X`?o00005On2/KH3o`0001So_j_F0ol0000BojMmQPCo00004OndWY<3o`0000;oQ9o;1Ol0000;ok_?
Q0?o00007Ona[Kl3o`0001_oUHW40_l0000;ol[D[`Co00005?n8PjX2o`0001_oilNW0ol0000?ooW=
c@?o00006on`]/`2o`000<oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0U_ooool4o`0000Go]JJS1?l0000Goh:a]P;o00005onoZmH3o`0001CoYgf62?l0000<okBNT`So
00003_nkch@3o`0000_o/Jfo0ol00?l>ok6]_`;o00006onERL@3o`0000gob]B_1?l0000BohR3ZP;o
00006_oWajL3o`00017onLg=0ol0000Iok2fc0?o0000coooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2Gooooo`Go00000_neYZ<4o`0001SoP[6f0ol0000Fokn[eP;o0000
5onWOHH=o`0000?o]9jC2?l0000Aok_?Q0?o00002Ona[Kl5o`00o`go/Jfo0_l0000KoiF9a0;o0000
3oo:e:l5o`00013oR8>Z0_l0000IonO7Y`?o00004ooicLd3o`0001Oo/;K<0ol0003@ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09Wooooo1ol0000Koh:a]P?o00005?no
ZmH3o`0001KoYgf60ol00003oiRId@ko00000onUaI03o`00017o^ln40ol00008ok6]_`Go003o3Ona
[Kl2o`0001_oUHW40_l0000Aol[D[`Co00003_n8PjX3o`0001SoilNW0ol0000EooW=c@?o00005_n`
]/`2o`000=7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Voooool4
o`0001goP[6f0_l0000Cokn[eP?o00005_nWOHH3o`0000_oV9WA1Ol00006ojG5T0;o00004_nkch@3
o`0000Oo/Jfo1Ol00?l=ok6]_`;o00006onERL@2o`0001?ob]B_1?l0000<ohR3ZP;o00006?oWajL3
o`0001OonLg=0ol0000Dok2fc0?o0000dOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2Looooo`;o00007_n2/KH3o`00017o_j_F0ol0000GojMmQP;o00003_nHVM43o`00
00KoYLF@0ol0000Bok_?Q0?o00001ona[Kl3o`00o`go/Jfo0ol0000KoiF9a0;o00005?o:e:l4o`00
00_oR8>Z0_l0000HonO7Y`;o00006OoicLd3o`00017o/;K<1?l0003Booooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo09cooooo0_l0000Ooh:a]P?o00004?noZmH2o`0001Oo
Ygf60ol0000>oiRId@;o00002?nUaI02o`0001?o^ln40ol0000Fok6]_`;o00007?nERL@2o`0001Ko
b]B_1?l00009ohR3ZP;o00005ooWajL3o`0001[onLg=0ol0000=ok2fc0Ko0000doooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Looooo`;o00008?n2/KH3o`0000ko_j_F
0ol0000FojMmQP?o00003onHVM42o`0000SoYLF@0ol0000Cok_?Q0?o00005Ona[Kl2o`0001coUHW4
0_l0000Gol[D[`Co00002?n8PjX2o`0001KoilNW0ol0000LooW=c@?o00002On`]/`7o`000=Gooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0W?ooool2o`00027oP[6f0_l0
000=okn[eP?o00005onWOHH2o`0000ooV9WA0ol00009ojG5T0;o00005?nkch@3o`0001Co/Jfo0_l0
000KoiF9a0?o00006Oo:e:l4o`0000KoR8>Z0_l0000EonO7Y`?o00007_oicLd3o`0000Go/;K<1ol0
003Hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09cooooo0ol0000D
oh:a]P?o003o2On2/KH3o`0000co_j_F0_l0000=ojMmQP?o003o1onWOHH3o`0000ooV9WA0_l0000:
ojG5T0?o00005?nkch@3o`0001;o/Jfo0ol0000=oiF9a0?o003o2onERL@2o`0001_ob]B_1?l00005
ohR3ZP;o00005?oWajL3o`00023onLg=0ol000000on`]/co0000o`000005o`000=_ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0WOooool2o`0001?oP[6f1Ol00?l9oh:a
]P?o00002_noZmH3o`0000coYgf61Ol00?l5ojMmQP?o00004?nHVM42o`0000_oYLF@0_l0000Eok_?
Q0?o00004Ona[Kl2o`0000goUHW41Ol00?l:oiF9a0;o00007Oo:e:l4o`0000;oR8>Z0ol0000DonO7
Y`;o00008_oicLd7o`000=kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0WOooool2o`0001?oP[6f1Ol00?l:oh:a]Pko00003OnWOHH5o`00o`GoYgf60_l0000@oiRId@?o
00002onUaI03o`0001Go^ln40ol0000@ok6]_`;o00003OnERL@5o`00o`[oUHW40_l0000Kol[D[`[o
00005?oWajL3o`0002?onLg=0ol0003Qooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo09gooooo0_l0000Coh:a]PGo003o2on2/KH<o`0000koYgf61Ol00?l4ojMmQP?o0000
4?nHVM42o`0000goYLF@0_l0000Fok_?Q0?o00003ona[Kl2o`0000goUHW41Ol00?l:oiF9a0;o0000
6Oo:e:l5o`0000;oT[9m1Ol0000ConO7Y`?o00009?oicLd2o`000>;ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0WOooool2o`0001CoP[6f0ol00?l;oh:a]P?o00002?nA
]9`3o`0000koYgf60ol00?l4ojMmQP?o00004OnHVM42o`0000goYLF@0ol0000=ok_?Q0?o003o1_nk
ch@3o`0000go/Jfo0ol0000>oiF9a0?o003o2onERL@2o`0000_ob]B_0ol00?l9ol[D[`Go00001onB
/Wd2o`0001;oilNW0ol0000?ooW=c@?o003o4ooicLd2o`000>;ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0WOooool2o`00027oP[6f0ol0000:oi6dW0?o00005?nWOHH2
o`00017oV9WA0ol0000>ojG5T0;o00003?nkch@5o`00o`Ko^ln40ol0000<ok6]_`;o00007OnERL@2
o`0000[ob]B_1Ol00?l6ol[D[`Go00002OnB/Wd3o`00013oilNW0ol0000?ooW=c@Go003o4OoicLd3
o`000>;ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0002Mooooo`;o00008?n2/KH3o`00
00coTKBL0ol0000BojMmQP?o00004OnHVM42o`0000ooYLF@0ol0000;ok_?Q0Go003o1onkch@3o`00
00_o/Jfo0_l0000LoiF9a0?o00002_o:e:l5o`00o`Cob]B_1Ol0000<oi:bOACo00004?oicLd5o`00
oa7onLg=0_l0003Qooooo`?o00002_ooool001[ooooo00?o0000ooooooooool0WOooool3o`0001ko
P[6f0ol0000>oi6dW0;o00004OnWOHH3o`0001;oV9WA0_l0000@ojG5T0;o00002onkch@5o`00o`So
^ln40ol0000:ok6]_`;o00007?nERL@2o`0000_ob]B_1Ol00?l2ol[D[`Go00003onB/WdBo`00017o
nLg=1Ol00?lAooW=c@;o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2Nooooo`;o00007_n2/KH2o`0000ooTKBL0ol0000?ojMmQP?o00001?nHVM43o`00o`_oV9WA
0ol0000@ojG5T0?o00002onkch@3o`00o`[o^ln40ol00009ok6]_`;o00007?nERL@2o`0000cob]B_
0ol00?l00oo:e:oo0000o`000003o`00013oT[9m0ol0000>olG=c`?o00004OoicLd3o`00oa;onLg=
0_l0003Sooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09kooooo0_l0
000Moh:a]P?o00004?nA]9`3o`0000koYgf60_l00004oiRId@Go003o2_nHVM42o`0001;oYLF@0_l0
000Iok_?Q0?o00001ona[Kl3o`0001coUHW40_l0000=ol[D[`Ko00004_nB/Wd2o`00013oaLg?0ol0
000UooW=c@;o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2N
ooooo`;o00007?n2/KH3o`0001;oTKBL0_l0000=ojMmQP?o00001?nHVM45o`00o`WoV9WA0ol0000B
ojG5T0?o00006Onkch@3o`0000Ko/Jfo1Ol0000JoiF9a0;o00002oo:e:l6o`0001CoT[9m0_l0000A
olG=c`?o00008ooicLd3o`000>?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0W_ooool2o`0001_oP[6f0ol0000Coi6dW0?o00002onWOHH3o`0000GoV9WA1Ol00?l9oiRI
d@;o00005?nUaI02o`0001[o^ln40ol00004ok6]_`_o00005OnERL@2o`0000Wob]B_1Ol00002oi:b
O@?o003o4OnB/Wd3o`0001;oaLg?0ol0000RooW=c@;o0000i?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`2Nooooo`?o00006On2/KH3o`0001GoTKBL0ol0000:ojMmQP;o
00001onHVM43o`00o`[oV9WA0_l0000DojG5T0Co00006Onkch@3o`0000;o/Jfo0ol00003oiEkV`_o
00004?nERL@2o`0000Oob]B_1Ol00003oi:bO@Go003o4?nB/Wd2o`0001CoaLg?0ol0000PooW=c@?o
0000i?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Oooooo`?o0000
5on2/KH3o`0001OoTKBL0ol00008ojMmQP?o00004onHVM43o`0001GoYLF@1_l0000Gok_?Q0Ko0000
2OnENi/;o`0000[oUHW40ol00005ol[D[`Go00001OnB/Wd5o`00oa3oT[9m0_l0000EolG=c`?o0000
7_oicLd4o`000>Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0X?oo
ool3o`0001KoP[6f0_l0000Ioi6dW0;o00001onWOHH3o`0001CoV9WA0_l0000EojG5T0Wo00005_nk
ch@4o`0000ooUG^K2ol00005oiF9a0;o00001?o:e:l5o`0000OoT[9m1Ol00?l?oi:bO@?o00005_o5
cLl3o`0001conLg=0ol0003Vooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0:7ooooo0ol0000Doh:a]P?o00002onA]9`3o`00o`_oTKBL0ol00006ojMmQP;o00005OnHVM42
o`0000[oYLF@0ol00?l8ojG5T0;o00001?nLZkP5o`0001Go^ln40_l0000EoiEkV`go00000_o:e:l5
o`0000[oT[9m0ol00?l@oi:bO@;o00006?o5cLl2o`0001_onLg=0ol0003Wooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0:;ooooo0ol0000Boh:a]P?o00002onA]9`5o`00
o`_oTKBL0ol00004ojMmQP?o00005?nHVM43o`0000WoYLF@1Ol00?l6ojG5T0?o00001_nLZkP6o`00
017o^ln40ol0000JoiEkV`go00007_nB/Wd3o`0001SoaLg?0ol0000IooW=c@?o0000j?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Sooooo`?o00004?n2/KH3o`0000co
TKBL1Ol00?l<oi6dW0;o00000onWOHH3o`0001GoV9WA0_l0000:ojG5T0Go003o1_nUaI02o`0000Wo
W:^h1_l0000?ok_?Q0;o00008?nENi/6o`00023oT[9m0_l0000JolG=c`?o00005ooicLd3o`000>Wo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Y?ooool3o`0000goP[6f
1?l0000=oi6dW0Go003o3?nA]9`3o`0000;oYgf60_l0000FoiRId@;o00002_nUaI05o`00o`GoYLF@
0ol0000<oib[^0Go00003?nkch@3o`0002;oUG^K0_l0000Roi:bO@;o00006oo5cLl3o`0001ConLg=
1?l0003Zooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:Gooooo0ol0
000:oh:a]PSo00003?nA]9`3o`00o`koTKBL1_l0000EoiRId@?o00002onUaI03o`00o`KoYLF@0_l0
000?oib[^0Ko00002?nkch@3o`0002?oUG^K0_l0000Qoi:bO@?o00007?o5cLl3o`0001;onLg=1?l0
003[ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:Kooooo0ol00006
oh:a]PKo00000_nDZZ05o`0001coTKBL1?l0000FoiRId@;o00005?nUaI03o`00017oW:^h1_l00006
ok_?Q0;o00009?nENi/3o`00023oT[9m0_l0000NolG=c`?o00004?oicLd3o`000>gooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Yoooool3o`0000?oP[6f1_l00006oiBZ
X0Go00006onA]9`2o`0001OoV9WA0_l0000DojG5T0;o00005OnLZkP5o`0000?o^ln40ol0000UoiEk
V`;o00008?nB/Wd2o`0001ooaLg?0ol0000>ooW=c@?o0000k_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`2Xooooo`So00002onDZZ05o`0001WoTKBL0_l0000BoiRId@Oo
00004onUaI03o`0001OoW:^h2?l0000VoiEkV`;o00007_nB/Wd4o`00023oaLg?0_l0000=ooW=c@?o
0000koooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yooooo`Go0000
3onDZZ05o`0001OoTKBL0ol00009oiRIdA3o00004_nUaI02o`0000KoW:^h0ol00?lAoib[^0Ko0000
5?nENi/3o`00o`ooUG^K0ol0000Koi:bO@Go00004?o5cLl3o`00o`koaLg?0ol0000:ooW=c@Co0000
l?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Zooooo`;o00004onD
ZZ05o`0001KoTKBL0_l00002oiRIdA3o00001OoXll/3o`00013oYLF@0ol00005oib[^0Go003o4onL
ZkP2o`0001CoUG^K1Ol00?l?oiEkV`;o00006?nB/Wd9o`0000koaLg?1Ol00?l>olG=c`?o00002?oi
cLd4o`000?7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Z_ooool2
o`0001GoU:ZP1Ol0000Doi6dW0co00003_oXll/3o`0000ooYLF@0_l00006oib[^0Go003o4onLZkP2
o`0001CoUG^K1Ol00?l?oiEkV`;o00005_nB/Wd6o`0000?o/L720ol0000=olG=c`Go003o3oo5cLl3
o`0000KonLg=0ol0003cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0:[ooooo0_l0000GoiBZX0Co00004onA]9`5o`0001Koj??;0ol0000=ojG5T0?o00001_nLZkP5o`00
oa?oW:^h0_l0000DoiEkV`Go003o3onENi/2o`0001CoT[9m1Ol00007ok71`P;o00003Oo5cLl5o`00
oa3oaLg?0ol00004ooW=c@?o0000m?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2Zooooo`;o00006OnDZZ04o`00013oTKBL0ol0000JonScb`?o00003?nUaI02o`0000So
W:^h0ol00?lDoib[^0;o00005OnENi/3o`00oa3oUG^K0ol0000Aoi:bO@Go00002Ona`L83o`0000go
aLg?0ol00?lBolG=c`?o00000_oicLd3o`000?Gooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Z_ooool2o`0001[oU:ZP1Ol0000>oi6dW0;o00007?oXll/3o`0000[oYLF@
0ol0000Ooib[^0;o0000:OnENi/2o`0000koT[9m1_l0000<ok71`P?o00008_o5cLl6o`000?Kooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0ZOooool3o`0001coU:ZP1Ol0
000;oi6dW0?o00007OoXll/3o`0000WoYLF@0_l0000Poib[^0;o0000:OnENi/2o`0000coT[9m1_l0
000?ok71`P;o00008oo5cLl4o`000?Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0ZOooool2o`0001ooU:ZP1Ol00009oi6dW0;o00007ooXll/3o`0000OoYLF@0ol0000P
oib[^0;o0000:OnENi/3o`0000WoT[9m1Ol0000Bok71`P?o00008_o5cLl3o`000?Sooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0ZOooool2o`0001?oU:ZP0ol00?l;oiBZ
X0Go00001OnA]9`4o`00023oj??;0ol00006ojG5T0;o00008OnLZkP^o`0000OoT[9m1Ol0000Eok71
`P?o00008?o5cLl4o`000?Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0ZOooool2o`0001;oU:ZP1Ol00?l<oiBZX0_o00008_oXll/3o`0000CoYLF@0ol0000Qoib[^2oo
00000onB/Wd6o`0001So/L720_l0000OolG=c`?o0000n_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2Yooooo`;o00004_nDZZ05o`00o`koU:ZP2_l0000RonScb`?o0000
0onUaI02o`0002;oW:^h0_l0000[oib_Y@Wo00006_na`L83o`0001coaLg?1?l0003kooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:Wooooo0_l0000BoiBZX0Go003o3_nD
ZZ04o`0000Coahf/0_l0000BonScb`?o003o3_oXll/3o`000004ojG5T?l0003o0000o`00027oW:^h
0ol0000Eoib_Y@?o003o5?nL[jD5o`0001ko/L720ol0000JolG=c`Co0000o?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yooooo`;o00004onDZZ03o`00o`koU:ZP0ol0
0006olN=[0?o00004?oXll/5o`00o`koj??;1Ol0000Roib[^0;o00005OnL[jD5o`00oaCoW:nU0_l0
000Qok71`P?o00006?o5cLl3o`000?kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0ZOooool3o`0002;oU:ZP0ol00008olN=[0?o00003ooXll/5o`00o`ooj??;1?l0000R
oib[^0;o00005OnL[jD5o`00oaCoW:nU0_l0000Rok71`P;o00005_o5cLl4o`000?oooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Z_ooool3o`00023oU:ZP0ol0000:olN=
[0;o00003ooXll/5o`00oa3oj??;0_l0000Roib[^0?o00005OnL[jD5o`00oa?oW:nU0ol0000Rok71
`P?o00005?o5cLl4o`000?oooooo0Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2[ooooo`?o00007_nDZZ03o`0000_oahf/0ol0000?onScb`?o003o4OoXll/3o`0001go
W:^h1_l0000Goib_Y@?o003o4onL[jD3o`0001Go/L720ol00?l<ok71`P?o00004_o5cLl3o`000?oo
oooo0oooool00ol0003oooooooooo`08ooooo`006_ooool3o`000:cooooo0_l0000MoiBZX0?o0000
3Oo7SJ`2o`0002Coj??;0_l0000Doib[^0oo0000;?nL[jD4o`0001Co/L721Ol00?l<ok71`P;o0000
4?o5cLl4o`000?oooooo0_ooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo0:cooooo0ol0
000KoiBZX0?o00003_o7SJ`3o`0002?oj??;0_l0000<oib[^1;o00000oniaY@3o`0002WoW:nU1ol0
000Cok71`PGo003o3?na`L83o`0000koaLg?1?l0003oooooo`Gooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0[Oooool3o`0001WoU:ZP0ol0000@olN=[0;o00008ooXll/3
o`0000;oW:^h4_l0000=okW6U0;o0000:?nL[jD4o`0000;oS::F0ol0000Bok71`PGo003o3Ona`L83
o`0000coaLg?0ol0003oooooo`Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0[_ooool3o`0001OoU:ZP0ol0000AolN=[0?o00008ooXll/>o`0001Go^LJD0ol0000Uoib_
Y@Co00001On<XYH2o`0001?o/L720ol00?l?ok71`P;o00002_o5cLl4o`000?oooooo2?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2_ooooo`;o00005_nDZZ03o`0001?o
ahf/0ol0000RonScb`Go00007oniaY@2o`0002CoW:nU1?l00006ohbRUP?o00009?na`L83o`0000So
aLg?1?l0003oooooo`Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
[oooool3o`0001CoU:ZP0ol0000EolN=[0;o00008OoXll/3o`0002;o^LJD0ol0000Qoib_Y@Co0000
2On<XYH3o`0002Co/L720ol00006olG=c`?o0000ooooool;ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0;3ooooo0ol0000BoiBZX0?o00005_o7SJ`3o`00023oj??;0_l0
000TokW6U0;o00008?nL[jD4o`0000_oS::F0_l0000Uok71`P;o00001?o5cLl4o`000?oooooo3?oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2aooooo`;o00004OnDZZ03
o`0001Soahf/0_l0000OonScb`?o00009?niaY@3o`0001goW:nU1?l0000=ohbRUP?o00009?na`L83
o`0000;oaLg?1?l0003oooooo`gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0/Oooool3o`0000ooU:ZP0ol0000IolN=[0?o00007_oXll/2o`0002Ko^LJD0_l0000Loib_
Y@Co00003on<XYH3o`0002Co/L721_l0003oooooo`oooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0/_ooool3o`0000goU:ZP0ol0000KolN=[0;o00007OoXll/3o`0002Ko
^LJD0ol0000Ioib_Y@Co00004_n<XYH2o`0002?o/L721_l0003ooooooa3ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0/oooool4o`0000[oU:ZP0ol0000LolN=[0?o0000
7?oXll/2o`0002So^LJD0_l0000Hoib_Y@Co00004on<XYH3o`00023o/L721?l000000ooooooo0000
o`00003ooooooa7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0]?oo
ool5o`0000OoU:ZP0ol0000>olN=[0?o003o3Oo7SJ`3o`0001[oj??;0ol0000XokW6U0?o00005_nL
[jD3o`0001KoS::F0ol0000Nok71`PCo0000oooooolEooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0;Kooooo1_l00003oiBZX0?o00003_o7SJ`5o`00o`goahf/0_l0000J
onScb`;o0000:_niaY@2o`0001CoW:nU1?l0000HohbRUP;o00007?na`L84o`000?oooooo5oooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2hooooo`Wo00003oo7SJ`5o`00
o`goahf/7_l0000ZokW6U0Co00004OnL[jD4o`0001WoS::F0ol0000Jok71`PCo0000oooooolHoooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;_ooooo1Ol0000@olN=[0Go
003o3_o7SJ`Lo`0002[o^LJD1_l0000>oib_Y@Co00007?n<XYH2o`0001So/L721?l0003ooooooa[o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0_Oooool2o`0001;oahf/
0ol00?l>olN=[0?o00006?oN`ZD2o`0001Co^LJD0ol00?lBokW6U0?o00000_o?h]/4o`0000_oW:nU
1?l0000MohbRUP?o00005Ona`L85o`000?oooooo6oooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2mooooo`?o00008_o7SJ`2o`0001Wog/:U0ol0000BokW6U0Go003o4?ni
aY@3o`0000Cocn;K1?l00008oib_Y@Co00008?n<XYH3o`0001?o/L721?l0003ooooooagooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool2o`00027oahf/0ol0000J
omk2Y@;o00004_niaY@5o`00o`ko^LJD1?l00007oloRf`?o00001_nL[jD4o`0002;oS::F0_l0000A
ok71`PCo0000oooooolOooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0;kooooo0ol0000PolN=[0;o00006ooN`ZD2o`0001;o^LJD1Ol00?l=okW6U0Co00002Oo?h]/4o`00
00;oW:nU1?l0000TohbRUP?o00003ona`L84o`000?oooooo8?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`2oooooo`;o00007oo7SJ`3o`0001_og/:U0ol0000BokW6U0?o
003o3OniaY@3o`0000cocn;K2?l0000CohbRUP?o003o4?n<XYH3o`0000co/L721?l0003oooooob;o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0_oooool2o`0001koahf/
0ol0000Momk2Y@;o00008OniaY@3o`0000oocn;K1?l0000DohbRUPGo003o4?n<XYH2o`0000_o/L72
1?l0003oooooob?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0_ooo
ool3o`0001goahf/0_l0000Nomk2Y@;o00007oniaY@4o`00017ocn;K0_l0000EohbRUPGo003o4?n<
XYH3o`0000Co/L722?l0003oooooobGooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0`?ooool2o`0001coahf/0ol0000Nomk2Y@;o00007_niaY@4o`0001;ocn;K0ol0000D
ohbRUPGo003o4On<XYH=o`000?oooooo9_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`30ooooo`Co00006_o7SJ`2o`0001oog/:U0ol0000LokW6U0?o00005Oo?h]/2o`00
01GoS::F0ol00?lCohbRUPKo0000ooooool/ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0<7ooooo1?l0000HolN=[0?o00008?oN`ZD2o`0001_o^LJD0ol0000FoloRf`;o
0000:_n<XYH3o`000?oooooo<?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`33ooooo`?o00005oo7SJ`2o`00027og/:U0_l0000IokW6U0Co00005oo?h]/3o`0002SoS::F
0ol0003ooooooc7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0a?oo
ool4o`0001Coahf/0ol0000=omk2Y@?o003o4OoN`ZD3o`0001Oo^LJD1?l0000IoloRf`;o0000:?n<
XYH2o`000?oooooo<_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`35
ooooo`Co00004oo7SJ`2o`0000gog/:U1Ol00?lAomk2Y@;o00005_niaY@3o`0001_ocn;K0_l0000W
ohbRUP?o0000oooooolbooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0<Oooooo0ol0000AolN=[0?o00003OoN`ZD5o`00oa7og/:U0_l0000EokW6U0?o00007?o?h]/3o`00
02GoS::F0ol0003ooooooc?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0b?ooool4o`0000koahf/0ol0000>omk2Y@Go003o4OoN`ZD2o`0001Co^LJD0ol0000NoloRf`;o
00009On<XYH2o`000?oooooo=?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`39ooooo`Co00003Oo7SJ`2o`00013og/:U0ol00?lBomk2Y@?o00004OniaY@4o`0001oocn;K
0_l0000TohbRUP?o0000ooooooldooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo0<_ooooo0ol0000;olN=[0?o00009_oN`ZD2o`00013o^LJD1?l0000PoloRf`?o00008on<
XYH2o`000?oooooo=Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3<
ooooo`Wo00001?o7SJ`2o`0002Oog/:U0_l0000?okW6U0?o00008oo?h]/2o`0002;oS::F0ol0003o
ooooocGooooo00?o0000ooooooooool02?ooool001[ooooo0ol0003=ooooo`ko00009ooN`ZD3o`00
00go^LJD0ol0000ToloRf`;o00008?n<XYH4o`000?oooooo=?ooool3o`0000[ooooo000Jooooo`03
o`000?oooooooooo0=Cooooo1_l0000Yomk2Y@;o00002oniaY@4o`0000kocn;K0ol00?lDoloRf`?o
00007On<XYH5o`000?oooooo=oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`3Hooooo`?o0000:?oN`ZD2o`0000[o^LJD1?l0000>oloRf`Go003o5?o?h]/2o`0001_oS::F
1Ol0003oooooocWooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0fOoo
ool3o`0002Oog/:U0_l00009okW6U0?o00004?o?h]/5o`00oaCocn;K0_l0000IohbRUPGo0000oooo
oolkooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0=[ooooo0ol0000V
omk2Y@?o00001oniaY@3o`00017ocn;K1Ol00?lDoloRf`?o00005_n<XYH5o`000?oooooo?Oooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Kooooo`?o00009_oN`ZD2o`00
00Go^LJD1?l0000ColoRf`?o003o5_o?h]/7o`0000ooS::F1Ol0003oooooocoooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0g?ooool2o`0002Kog/:U0_l00004okW6U0Co
0000;Oo?h]/@o`0000CoS::F1Ol0003ooooood7ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0g?ooool3o`0002Gog/:U0ol00002okW6U0?o0000;_o?h]/3o`0000Cooooo
4Ol0003ooooood?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0gOoo
ool3o`0002?og/:U2?l0000^oloRf`?o00003_ooool6o`000?ooooooAOooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`3Nooooo`?o00007ooN`ZD:o`0002kocn;K1?l0003o
oooooeWooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0goooool5o`00
01Wog/:U1ol00003ooooo`Go0000:oo?h]/3o`000?ooooooFoooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3Pooooo`Oo00004ooN`ZD7o`0000Sooooo1Ol0000WoloRf`Co
0000oooooomLooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>?ooooo
1ol0000=omk2Y@Oo00003Oooool4o`0002Gocn;K1?l0003ooooooegooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0i_ooool7o`0000Oog/:U1ol0000Booooo`Co00008_o?
h]/3o`000?ooooooGoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Y
ooooo`Oo000000?og/:Uo`000?l000001Ol0000Fooooo`Go00007_o?h]/4o`000?ooooooH?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3/ooooo`Wo00006oooool5o`00
01_ocn;K1?l0003oooooof7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0koooool3o`00023ooooo1Ol0000HoloRf`?o0000oooooomSooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo0?oooooo5Oooool5o`0001Cocn;K1?l0003oooooofCooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooolGooooo`Co00004_o?
h]/4o`000?ooooooIOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3o
oooooaWooooo1?l0000?oloRf`?o0000oooooomWooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0?oooooo6_ooool5o`0000Kocn;K2Ol0003oooooofSooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0oooooolLoooooa7o0000oooooomYooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?oooooo7_ooool8o`000?oooooo
L?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`03o`000?oooooooooo00Sooooo00001?oooooo0000o`000?l00002ooooo`Go00000oooool2o`00
00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`08ooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00002Oooooooo`000?oo0000V_l0000:ooooo`000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3o
ooooooooooooZoooool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0oooooooooooooj_ooooo00000ooooooo0000o`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0003ooooooooooooo
[Oooool000;ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0003ooooooooooooo[_oo
ool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooo
oooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooooonnoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 699}, {699, 0}} -> {16.0374, 16.3764, 0.150671, \
0.150671}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = 
      visualization[cellCoordinates \[Rule] \ xymeristem, 
        cellNumbers \[Rule] \ True, cellColors \[Rule] \ rcs, \ 
        ImageSize \[Rule] \ 700, Frame \[Rule] \ True, 
        PlotRange \[Rule] \ {{20, 120}, {20, 120}}, 
        AspetcRatio \[Rule] \ 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 700 700 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.2 0.01 -0.2 0.01 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .2 -12 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -12 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -12 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(40)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(80)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(100)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(120)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(40)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(60)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(80)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(100)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(120)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .2 m
1 .2 L
s
.99375 .4 m
1 .4 L
s
.99375 .6 m
1 .6 L
s
.99375 .8 m
1 .8 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .25 m
1 .25 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .45 m
1 .45 L
s
.99625 .5 m
1 .5 L
s
.99625 .55 m
1 .55 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .75 m
1 .75 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 .125 .182 .123 k
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
F
0 g
.004 w
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
s
.045 .194 .202 .25 k
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
F
0 g
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
s
.28 .187 .189 .044 k
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
F
0 g
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
s
.192 .297 .074 .029 k
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
F
0 g
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
s
.104 .089 .187 .229 k
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
F
0 g
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
s
.256 .272 .248 .05 k
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
F
0 g
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
s
.156 .148 .066 .227 k
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
F
0 g
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
s
.111 .254 .164 .277 k
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
F
0 g
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
s
.131 .067 .275 .233 k
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
F
0 g
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
s
.238 .07 .201 .204 k
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
F
0 g
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
s
.134 .281 .013 .275 k
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
F
0 g
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
s
.179 .009 .065 .225 k
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
s
.023 .161 .299 .298 k
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
F
0 g
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
s
.212 .207 .135 .021 k
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
F
0 g
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
s
.081 .139 .161 .088 k
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
s
.143 .07 .26 .184 k
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
s
.008 .089 .247 .209 k
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
s
.13 .08 .181 .284 k
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
F
0 g
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
s
.107 .219 .182 .286 k
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
F
0 g
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
s
.196 .013 .047 .265 k
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
F
0 g
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
s
.115 .173 .186 .177 k
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
s
.272 .104 .226 .294 k
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
F
0 g
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
s
.264 .015 .28 .085 k
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
F
0 g
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
s
.134 .235 .098 .101 k
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
s
.027 .016 .216 .114 k
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
s
.132 .003 .17 .149 k
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
F
0 g
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
s
.017 .13 .284 .272 k
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
F
0 g
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
s
.045 .026 .057 .278 k
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
F
0 g
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
s
.081 .011 .078 .193 k
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
s
.247 .076 .28 .093 k
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
F
0 g
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
s
.22 .06 .063 .278 k
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
F
0 g
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
s
.088 .057 .194 .129 k
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
F
0 g
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
s
.071 .227 .21 .157 k
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
s
.026 .201 .153 .179 k
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
F
0 g
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
s
.245 .19 .075 .286 k
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
F
0 g
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
s
.298 .113 .095 .193 k
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
s
.078 .053 .032 .215 k
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
s
.29 .296 .138 .085 k
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
F
0 g
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
s
.219 .069 .228 .228 k
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
s
.193 .168 .075 .049 k
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
s
.249 .278 .3 .063 k
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
F
0 g
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
s
.251 .165 .204 .17 k
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
s
.173 .112 .172 .255 k
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
s
.183 .116 .034 .17 k
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
F
0 g
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
s
.263 .047 .107 .242 k
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
s
.07 .18 .032 .193 k
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
s
.121 .201 .032 .13 k
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
F
0 g
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
s
.17 .036 .127 .26 k
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
s
.298 .224 .255 .005 k
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
F
0 g
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
s
.115 .108 .221 .135 k
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
s
.151 .06 .114 .194 k
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
s
.081 .181 .082 .001 k
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
F
0 g
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
s
.26 .28 .05 .17 k
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
s
.09 .244 .223 .21 k
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
s
.092 .02 .268 .205 k
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
F
0 g
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
s
.277 .212 .047 .069 k
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
s
.126 .152 .233 .176 k
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
F
0 g
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
s
.044 .271 .151 .175 k
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
F
0 g
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
s
.084 .292 .101 .005 k
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
s
.295 .048 .178 .095 k
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
F
0 g
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
s
.202 .028 .21 .19 k
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
s
.225 .116 .163 .121 k
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
s
.099 .264 .23 .245 k
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
F
0 g
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
s
.055 .293 .079 .07 k
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
F
0 g
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
s
.27 .001 .278 .065 k
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
F
0 g
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
s
.276 .253 .099 .27 k
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
s
.073 .225 .189 .08 k
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
s
.148 .109 .026 .259 k
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
s
.049 .144 .096 .015 k
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
F
0 g
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
s
.294 .151 .017 .245 k
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
F
0 g
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
s
.024 .15 .04 .18 k
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
F
0 g
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
s
.048 .197 .241 .21 k
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
F
0 g
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
s
.275 .272 .052 .13 k
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
F
0 g
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
s
.127 .164 .026 .17 k
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
F
0 g
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
s
.078 .019 .23 .156 k
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
F
0 g
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
s
.083 .168 .213 .211 k
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
F
0 g
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
s
.059 .018 .173 .031 k
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
s
.011 .121 .232 .121 k
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
s
.036 .149 .18 .291 k
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
s
.209 .285 .155 .12 k
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
F
0 g
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
s
.132 .266 .225 .265 k
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
F
0 g
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
s
.048 .098 .012 .054 k
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
F
0 g
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
s
.289 .08 .139 .023 k
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
s
.279 .26 .207 .202 k
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
F
0 g
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
s
.243 .111 .027 .212 k
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
F
0 g
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
s
.034 .126 .172 .091 k
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
F
0 g
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
s
.202 .16 .248 .127 k
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
s
.154 .061 .235 .073 k
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
s
.165 .281 .096 .05 k
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
F
0 g
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
s
.186 .021 .189 .148 k
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
F
0 g
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
s
.243 .211 .162 .236 k
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
F
0 g
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
s
.209 .085 .29 .145 k
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
s
.007 .225 .042 .018 k
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
s
.153 .164 .107 .245 k
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
F
0 g
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
s
.289 .183 .011 .195 k
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
F
0 g
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
s
.103 .161 .122 .047 k
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
F
0 g
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
s
.16 .251 .26 .111 k
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
s
.25 .166 .27 .267 k
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
s
.243 .241 .228 .249 k
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
s
.09 .077 .121 .004 k
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
F
0 g
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
s
.102 .194 .11 .11 k
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
F
0 g
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
s
.299 .032 .288 .063 k
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
F
0 g
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
s
.139 .081 .028 .251 k
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
s
.189 .215 .058 .285 k
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
s
.246 .275 .13 .036 k
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
s
.156 .198 .01 .031 k
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
F
0 g
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
s
.054 .004 .2 .221 k
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
s
.055 .272 .212 .159 k
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
F
0 g
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
s
.216 .191 .185 .208 k
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
F
0 g
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
s
.026 .275 .127 .223 k
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
F
0 g
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
s
.08 .001 .297 .187 k
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
s
.225 .103 .287 .156 k
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
s
.17 .098 .087 .235 k
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
F
0 g
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
s
.115 .126 .175 .076 k
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
F
0 g
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
s
.2 .235 .29 .168 k
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
s
.173 .26 .163 .245 k
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
F
0 g
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
s
.093 .259 .166 .058 k
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
s
.168 .156 .179 .202 k
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
s
.298 .058 .091 .267 k
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
F
0 g
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
s
.182 .232 .217 .192 k
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
s
.283 .297 .227 .024 k
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
F
0 g
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
s
.11 .037 .064 .078 k
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
F
0 g
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
s
.017 .078 .198 .02 k
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
s
.149 .222 .02 .118 k
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
F
0 g
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
s
.151 .163 .228 .151 k
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
s
.269 .231 .012 .259 k
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
F
0 g
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
s
.286 .234 .085 .236 k
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
s
.177 .197 .02 .157 k
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
F
0 g
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
s
.16 .118 .122 .137 k
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
F
0 g
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
s
.01 .197 .102 .019 k
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
s
.159 .033 .174 .168 k
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
s
.19 .102 .162 .208 k
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
F
0 g
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
s
.204 .168 .077 .273 k
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
s
.027 .271 .057 .115 k
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
F
0 g
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
s
.167 .153 .235 .278 k
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
F
0 g
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
s
.157 .256 .134 .26 k
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
s
.298 .223 .26 .092 k
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
F
0 g
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
s
.108 .121 .098 .184 k
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
s
.204 .253 .021 .211 k
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
F
0 g
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
s
.177 .282 .263 .096 k
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
s
.01 .129 .028 .117 k
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
s
.153 .173 .194 .158 k
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
s
.155 .251 .234 .066 k
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
F
0 g
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
s
.047 .13 .136 .182 k
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
s
.143 .177 .116 .272 k
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
F
0 g
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
s
.265 .195 .153 .176 k
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
F
0 g
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
s
.255 .066 .125 .059 k
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
F
0 g
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
s
.102 .193 .23 .201 k
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
F
0 g
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
s
.247 .242 .296 .135 k
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
F
0 g
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
s
.2 .112 .159 .252 k
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
F
0 g
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
s
.057 .236 .043 .281 k
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
s
.092 .04 .191 .105 k
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
s
.136 .275 .066 .046 k
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
F
0 g
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
s
.034 .082 .136 .145 k
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
F
0 g
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
s
.087 .14 .14 .011 k
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
s
.187 .028 .281 .058 k
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
s
.13 .092 .238 .078 k
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
s
.038 .052 .047 .273 k
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
s
.202 .077 .281 .227 k
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
s
.168 .295 .145 .081 k
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
F
0 g
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
s
.081 .155 .005 .07 k
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
s
.194 .127 .024 .012 k
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
s
.064 .035 .086 .234 k
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
F
0 g
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
s
.025 .284 .04 .262 k
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
F
0 g
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
s
.124 .207 .059 .035 k
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
F
0 g
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
s
.256 .212 .214 .254 k
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
F
0 g
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
s
.175 .057 .209 .183 k
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
F
0 g
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
s
.281 .23 .185 .171 k
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
F
0 g
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
s
.217 .194 .099 .237 k
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
F
0 g
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
s
.192 .21 .059 .275 k
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
F
0 g
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
s
.068 .003 0 .24 k
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
F
0 g
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
s
.113 .091 .087 .287 k
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
F
0 g
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
s
.238 .034 .178 .104 k
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
F
0 g
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
s
.257 .104 .292 .232 k
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
F
0 g
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
s
.039 .21 .194 .296 k
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
s
.147 .299 .135 .021 k
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
F
0 g
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
s
.079 .296 .134 .08 k
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
F
0 g
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
s
.266 .205 .048 .094 k
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
s
.029 .171 .17 .29 k
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
F
0 g
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
s
.072 .067 .177 .058 k
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
F
0 g
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
s
.033 .157 .284 .062 k
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
s
.186 .158 .149 .041 k
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
s
.107 .162 .015 .261 k
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
F
0 g
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
s
.14 .257 .267 .167 k
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
F
0 g
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
s
.112 .086 .097 .177 k
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
F
0 g
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
s
.04 .019 .22 .119 k
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
s
.007 .161 .236 .057 k
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
F
0 g
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
s
.121 .003 .087 .016 k
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
F
0 g
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
s
.015 .141 .072 .055 k
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
F
0 g
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
s
.174 .184 .105 .188 k
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
F
0 g
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
s
.063 .098 .007 .011 k
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
F
0 g
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
s
.023 .08 .087 .192 k
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
F
0 g
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
s
.016 .219 .151 .136 k
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
F
0 g
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
s
.195 .216 .064 .12 k
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
F
0 g
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
s
.18 .075 .292 .065 k
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
F
0 g
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
s
.006 .191 .187 .178 k
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
s
.244 .093 .18 .166 k
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
F
0 g
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
s
.221 .013 .093 .274 k
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
s
.204 .094 .242 .138 k
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
s
.009 .179 .178 .018 k
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
F
0 g
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
s
.129 .104 .186 .253 k
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
F
0 g
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
s
.123 .213 .299 .075 k
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
F
0 g
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
s
.179 .121 .119 .209 k
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
F
0 g
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
s
.258 .108 .026 .235 k
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
F
0 g
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
s
.054 .013 .085 .096 k
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
F
0 g
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
s
.045 .135 .207 .078 k
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
F
0 g
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
s
.216 .031 .021 .126 k
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
s
.093 .118 .022 .05 k
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
F
0 g
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
s
.214 .297 .203 .142 k
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
F
0 g
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
s
.255 .189 .176 .207 k
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
F
0 g
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
s
.201 .176 .092 .111 k
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
F
0 g
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
s
.157 .041 .185 .033 k
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
s
.241 .01 .164 .207 k
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
s
.148 .192 .143 .156 k
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
s
.234 .195 .24 .015 k
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
F
0 g
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
s
.279 .006 .064 .107 k
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
F
0 g
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
s
.078 .13 .272 .297 k
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
s
.221 .089 .087 .264 k
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
F
0 g
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
s
.28 .079 .222 .057 k
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
F
0 g
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
s
.131 .187 .08 .201 k
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
F
0 g
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
s
.197 .291 .14 .186 k
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
F
0 g
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
s
.218 .286 .076 .079 k
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
s
.14 .156 .104 .082 k
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
s
.22 .067 .017 .118 k
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
s
.24 .288 .095 .061 k
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
F
0 g
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
s
.109 .101 .015 .16 k
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
s
.212 .11 .176 .274 k
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
s
.294 .124 .1 .195 k
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
F
0 g
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
s
.153 .268 .296 .113 k
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
F
0 g
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
s
.234 .202 .278 .296 k
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
s
.293 .214 .184 .235 k
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
F
0 g
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
s
.185 .113 .168 .075 k
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
s
.273 .003 .293 .101 k
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
F
0 g
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
s
.279 .179 .193 .205 k
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
F
0 g
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
s
.126 .211 .197 .092 k
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
F
0 g
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
s
.192 .01 .219 .096 k
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
s
.199 .096 .035 .161 k
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
F
0 g
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
s
.014 .283 .167 .087 k
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
s
.041 .28 .174 .286 k
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
s
.062 .1 .282 .08 k
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
s
.236 .189 .084 .288 k
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
F
0 g
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
s
.044 .179 .166 .192 k
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
F
0 g
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
s
.145 .084 .131 .03 k
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
s
.131 .101 .264 .244 k
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
s
.09 .121 .089 .258 k
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
s
.028 .021 .108 .178 k
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
s
.092 .132 .023 .19 k
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
s
.048 .253 .157 .298 k
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
F
0 g
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
s
.203 .169 .027 .267 k
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
F
0 g
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
s
.072 .068 .063 .024 k
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
F
0 g
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
s
.283 .247 .274 .066 k
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
F
0 g
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
s
.255 .226 .167 .188 k
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
F
0 g
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
s
.163 .094 .144 .298 k
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
F
0 g
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
s
gsave
.14765 .35881 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.15834 .40188 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16128 .31342 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.16357 .46193 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19065 .41555 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18844 .2554 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19385 .31108 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19753 .36626 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.21202 .45951 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19586 .52747 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.22123 .27878 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.21824 .20041 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2351 .33344 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2243 .41392 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2263 .73148 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.22525 .16334 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25673 .36775 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.23773 .49817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.23081 .59883 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.23489 .6596 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.23712 .79429 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24529 .22508 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2674 .39689 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25267 .25333 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26056 .27124 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.2448 .30511 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24905 .45183 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.25355 .53925 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26394 .77687 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26777 .16036 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27653 .49192 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27412 .5691 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27657 .44386 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27465 .67989 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.27399 .73847 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.26831 .85108 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28442 .24394 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29192 .59132 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28803 .29914 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28641 .63415 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.28799 .70452 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.282 .8904 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30035 .18235 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3011 .54368 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30396 .43496 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30969 .48356 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.29144 .81977 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3116 .86947 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31135 .80027 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31249 .12834 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32099 .64791 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30986 .67647 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31221 .34363 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(53) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.30898 .38792 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32774 .52519 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.31979 .60469 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32594 .76523 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32336 .9212 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33116 .23365 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(59) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33135 .72019 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34042 .14452 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(61) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33872 .59435 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3313 .83847 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(63) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34617 .18509 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35409 .28192 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(65) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35075 .55342 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.33391 .57173 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(67) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34665 .4786 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35777 .50007 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(69) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36563 .33032 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.34882 .62142 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35437 .67214 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35883 .86042 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(73) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36036 .37842 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(74) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35358 .4422 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36343 .80748 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3681 .90009 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(77) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36629 .94361 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37231 .58337 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(79) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3717 .7105 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37074 .77123 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(81) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.36633 .09342 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(82) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.38441 .19823 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(83) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37391 .64012 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(84) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37116 .74963 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(85) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37382 .52861 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(86) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37389 .22963 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(87) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40149 .74505 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(88) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39344 .11187 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(89) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39542 .41274 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.3896 .55144 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(91) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39025 .85967 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(92) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40015 .36158 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(93) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39125 .48197 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40243 .79171 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40425 .14793 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39712 .30956 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(97) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41097 .50036 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40927 .57287 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(99) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41261 .24002 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41417 .61078 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(101) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40388 .67747 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(102) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41907 .88843 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(103) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4227 .3343 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4208 .38645 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42059 .52075 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.40977 .93114 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(107) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41923 .45466 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42184 .65143 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(109) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4177 .71386 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.42894 .85391 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(111) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4437 .73995 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43372 .08554 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(113) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44788 .23543 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(114) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44199 .37118 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(115) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4417 .4228 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(116) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45023 .47435 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(117) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43617 .55512 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(118) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.44117 .58877 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(119) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43455 .77277 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4476 .83187 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(121) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45214 .95963 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45023 .16642 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(123) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4475 .29009 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(124) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47261 .51499 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.46466 .78421 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.46494 .1295 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(127) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45589 .32071 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(128) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45444 .68747 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(129) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47498 .35011 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47444 .62929 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(131) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47317 .2021 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(132) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47815 .68749 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(133) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48936 .09935 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(134) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48182 .56633 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47516 .87236 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(136) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.47867 .90022 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(137) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50137 .80766 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(138) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49369 .83863 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(139) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50027 .30382 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49829 .15643 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(141) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48842 .38456 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(142) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48711 .4351 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(143) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49535 .71456 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51744 .25809 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(145) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51281 .37681 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(146) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51029 .59086 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(147) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51407 .66672 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(148) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.4988 .75429 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(149) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.51033 .93247 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.53053 .4175 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(151) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52953 .06414 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(152) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.53129 .12204 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(153) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.50531 .46766 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(154) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5163 .54826 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(155) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52316 .3226 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(156) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52184 .83916 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(157) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.52785 .62944 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54637 .86396 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(159) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55183 .31319 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(160) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55089 .38466 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(161) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.53628 .51005 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(162) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54467 .77846 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(163) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54487 .20384 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(164) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54978 .73569 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(165) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55321 .45255 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(166) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.54681 .59898 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(167) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55331 .65488 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(168) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56156 .68758 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(169) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55375 .82036 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(170) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55291 .90818 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(171) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.56019 .09602 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(172) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.55861 .55685 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(173) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57426 .59662 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(174) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57257 .4302 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58092 .15785 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(176) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58345 .72569 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(177) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58297 .06104 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(178) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.57854 .6451 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(179) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58706 .77311 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58997 .82709 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(181) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58953 .87774 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(182) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58494 .48918 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(183) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58828 .53071 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(184) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60259 .11544 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(185) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59069 .34304 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(186) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59979 .60819 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(187) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60103 .28071 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(188) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60132 .57351 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(189) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61469 .39582 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(190) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62089 .64471 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(191) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60755 .67474 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(192) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60217 .69594 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(193) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61376 .73291 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(194) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62728 .50127 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(195) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6234 .79977 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(196) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62583 .15915 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(197) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63116 .33218 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(198) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63124 .45452 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(199) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63344 .84887 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62011 .21896 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(201) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62843 .5521 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63287 .08064 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(203) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63741 .74367 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(204) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6461 .60483 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(205) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.65018 .69465 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(206) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6516 .42274 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(207) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.65602 .12723 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(208) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.67308 .1757 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(209) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.67756 .562 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(210) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6696 .81742 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(211) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.67427 .44269 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(212) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.66857 .51891 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(213) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.67939 .76728 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(214) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68822 .36227 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(215) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69508 .65049 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(216) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.684 .73498 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(217) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6729 .27222 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(218) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69393 .07756 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(219) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69205 .21692 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(220) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70839 .70072 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(221) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68184 .48995 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(222) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71783 .46669 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(223) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70044 .52699 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(224) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.70381 .58588 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71869 .13916 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(226) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72238 .17734 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(227) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.71654 .30069 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(228) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73519 .2283 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(229) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73056 .41677 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(230) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.73809 .51623 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(231) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74058 .38961 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(232) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74921 .36598 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(233) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75438 .59452 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(234) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74441 .32947 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(235) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75304 .44535 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(236) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76115 .11735 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(237) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76291 .478 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(238) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76399 .17332 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(239) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76561 .27758 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(240) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78811 .34482 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(241) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78704 .23751 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(242) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78068 .3022 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(243) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.77711 .52572 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(244) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.78603 .39878 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(245) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80208 .48952 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(246) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80307 .28845 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(247) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80639 .44478 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.81147 .14954 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(249) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82526 .20445 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82286 .36789 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(251) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.84084 .26361 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(252) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83977 .32457 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(253) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 700},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0002_2000`400?l00000o`00003ooooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo
003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool009_ooooo0ol00003ooooo`;o0000Noooool3o`0000Cooooo0_l0001looooo`?o0000
1?ooool2o`0007Wooooo0ol00004ooooo`;o00001?ooool2o`0007Gooooo0ol00002ooooo`Go0000
0oooool2o`0000Cooooo002Looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`1gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001joooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`00VOooool5o`0000;ooooo00Co0000oooooooooooo0000NOooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo0000N_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000MOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool009Wooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool0001iooooo`Co00000oooool01?l0003oooooooooool0001koooo
o`?o00000oooool01?l0003oooooooooool0001iooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo007ooooo002Jooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0007[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0007Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0007Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00Oooool009_ooooo0_l00003ooooo`04o`000?oooooooooo
o`0007[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001jooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0001hooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0007Cooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`00W?ooool00ol0003ooooooooo
o`02ooooo`;o0000O?ooool2o`0000Cooooo0_l0001looooo`?o00001?ooool2o`0007[ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l0001fooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o00001?ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool0
0?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooo
oonnooooo`006_ooooooo`000?oo0000V_l0000:ooooo`006_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooo
oooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooo
oooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooo
oiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooomioooooaWo0000ooooool4ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooN?oooolKo`000?oooooo0oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooogKooooo1?l0000Goj>cf`?o0000
ooooool2ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooG_oo
ool7o`0000oooooo1Ol0000Ioj>cf`?o0000ooooool1ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0?ooooooE_oooolAo`0000cooooo1?l0000Loj>cf`?o0000ooooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodkooooo4Ol00005olgJ
]0Ko00001oooool4o`0001ooXk?K1?l0003mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0?ooooooB_ooool=o`0000oocMZd1_l00003ooooo`Go00008OnS/m/4o`0002Oo
oooo1Ol0003@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000oooooom9ooooo`Ko0000
6_o=f[@9o`0002GoXk?K0ol0000Sooooo`_o0000boooool3o`0000[ooooo000Jooooo`03o`000?oo
oooooooo0?ooooooB?ooool3o`00023ocMZd1Ol0000Xoj>cf`?o00007oooool7o`0000?oZMfh2?l0
0039ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooAoooool3
o`0002?ocMZd0_l0000Zoj>cf`?o00001Oooool:o`0000cooooo1ol00009ojWM^0So0000a_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodKooooo0ol0000TolgJ
]0;o0000:onS/m/Do`0000Kooooo1ol0000@ojWM^0Oo0000`oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3oooooodGooooo0ol0000UolgJ]0;o0000;?nS/m/7o`0000So
W:^/3_l0000FojWM^0Ko0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodCooooo0ol0000VolgJ]0;o00002_nS/m/3o`0000CoXk?K00?o0000oj>cfonS/m/0
0_nS/m/3o`0001;oXk?K0ol0000@oib[[0So00007?nYgKP3o`000<7ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0oooooom3ooooo`?o00009oo=f[@3o`0000[oXk?K00?o
0000oj>cfonS/m/00onS/m/01Ol0003oXk?Koj>cfonS/m_o000000?oXk?K00?o0000oj>cfonS/m/0
3onS/m/2o`0001CoW:^/0_l0000PojWM^0?o0000`?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`3ooooood;ooooo0ol0000@olgJ]0?o00000oo=f[@3o`0000;ocMZd1Ol0
0009olgJ]0;o00002_nS/m/00ol0003oXk?Koj>cf`04oj>cf`04o`000?nS/m_oXk?Ko`0000?oXk?K
00?o0000oj>cfonS/m/03_nS/m/3o`0001CoW:^/0_l0000QojWM^0?o0000_oooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooob[ooooo2Ol0000>ooooo`?o00004_o=
f[@01Ol0003ocMZdolgJ]?o=f[Co000000?ocMZd00Co0000olgJ]?o=f[Co00000_o=f[@00ol0003o
cMZdolgJ]007olgJ]0;o00002_nS/m/00ol0003oXk?Koj>cf`04oj>cf`04o`000?nS/m_oXk?Koj>c
f`?o00004OnS/m/2o`0001GoW:^/0ol0000QojWM^0?o0000__ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3ooooooagooooo6Ol0000:ooooo`?o00004oo=f[@00ol0003o
cMZdolgJ]005olgJ]005o`000?o=f[CocMZdolgJ]?l000002oo=f[@3o`0000WoXk?K00?o0000oj>c
fonS/m/01OnS/m/00ol0003oXk?Ko`000003oj>cf`03o`000?nS/m_oXk?K00goXk?K0ol0000Foib[
[0;o00008_nYgKP3o`000;gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0moooool5o`0001Sooooo5_l00007oiRZ[@Ko00001oooool3o`0001CocMZd00?o0000olgJ]?o=
f[@01Oo=f[@00ol0003ocMZdolgJ]002olgJ]003o`000?o=f[CocMZd00SocMZd1?l00007oj>cf`;o
00000onS/m/01ol0003oXk?Koj>cfonS/m_o0000oj>cfol000000onS/m/00ol0003oXk?Koj>cf`0=
oj>cf`;o00005onLZj`2o`0002?oZMfh0_l0002mooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0?Cooooo2ol0000Dooooo`[o00005onHZZd<o`0001GocMZd00Co0000olgJ
]?o=f[CocMZd1?l00002olgJ]005o`000?o=f[CocMZdolgJ]?l000002?o=f[@6o`0000OoXk?K00Co
0000oj>cfonS/m_oXk?K1Ol00002oj>cf`?o00003onS/m/3o`0001OoW:^/0_l0000SojWM^0?o0000
_?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3aooooo`Oo00000ooU
fNl6o`00013ooooo1?l0000QoiRZ[@Wo00005Oo=f[@2o`0000?ocMZd00?o0000olgJ]?o=f[@00oo=
f[@01Ol0003ocMZdolgJ]?o=f[Co000000OocMZd0ol00002oiVOX0?o00008onS/m/2o`0001SoW:^/
0_l0000TojWM^0?o0000^oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`3^ooooo`Oo00002OoUfNl6o`0000cooooo1?l0000RoiRZ[@;o00001OoKWM<3o`0001GocMZd00Co
0000olgJ]?o=f[CocMZd1Ol00002olgJ]0?o00002?o=f[@2o`0000CoVInP0ol0000Qoj>cf`?o0000
6?nLZj`3o`0002CoZMfh0ol0002jooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo0>_ooooo1ol0000>onGIk`Oo00002?ooool3o`0002?oV:Z]0ol00006om^Md`?o0000:Oo=
f[@3o`0000GoVInP0ol0000Poj>cf`;o00006_nLZj`2o`0002GoZMfh0ol0002iooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>Sooooo1ol0000DonGIk`Ko00001?ooool4
o`0002CoV:Z]0_l00008om^Md`?o00009oo=f[@3o`0000OoVInP0ol0000Noj>cf`?o00006_nLZj`2
o`0002KoZMfh0_l0002iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0>Gooooo1ol0000JonGIk`[o00009OnHZZd2o`0000WofigC0ol0000VolgJ]0;o00002OnIWj03o`00
01goXk?K0_l0000Koib[[0;o00003OnYgKP5o`0000;oZMfh0ol00003ojWM^0;o00002_nYgKP3o`00
0;Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0hoooool6o`0001oo
iMW_1_l0000WoiRZ[@;o00002_oKWM<3o`0002CocMZd0ol0000:oiVOX0?o00006onS/m/3o`0001_o
W:^/0_l0000>ojWM^004o`000?nYgKSoZMfho`0000?oZMfh00?o0000ojWM^?nYgKP01?nYgKP00ol0
003oZMfhojWM^008ojWM^0?o0000]oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`3Sooooo`?o00009OoUfNl2o`0002OoV:Z]0ol0000;om^Md`?o00008_o=f[@3o`0000co
VInP0ol0000Joj>cf`;o00000onLZj`5o`0000?oW:^/0_l00003oib[[0?o00002OnLZj`3o`0000ko
ZMfh00?o0000ojWM^?nYgKP00onYgKP00ol0003oZMfhojWM^005ojWM^003o`000?nYgKSoZMfh00So
ZMfh0ol0002fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>;ooooo
0ol0000VonGIk`;o00009onHZZd2o`0000gofigC0ol0000PolgJ]0?o00003_nIWj03o`0001SoXk?K
0ol00004oib[[004o`000?nLZjcoW:^/o`0000;oW:^/00Ko0000oib[[?nLZjco0000oib[[?l00003
oib[[003o`000?nLZjcoW:^/00OoW:^/0_l0000?ojWM^003o`000?nYgKSoZMfh00;oZMfh00?o0000
ojWM^?nYgKP00_nYgKP4o`0000_oZMfh0_l0002fooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0>;ooooo0_l0000WonGIk`;o00009onHZZd2o`0000kofigC0ol0000OolgJ
]0;o00004?nIWj03o`0001OoXk?K0_l00006oib[[003o`000?nLZjcoW:^/00;oW:^/00Co0000oib[
[?nLZjco00001OnLZj`00ol0003oW:^/oib[[007oib[[0;o00003?nYgKP01Ol0003oZMfhojWM^?nY
gKSo000000?oZMfh00Go0000ojWM^?nYgKSoZMfho`000003ojWM^003o`000?nYgKSoZMfh00WoZMfh
0ol0002eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>7ooooo0ol0
000WonGIk`;o00002?nHZZd3o`0000?oV:Z]0ol00003oiRZ[@?o00004?nHZZd2o`0000oofigC0_l0
000NolgJ]0?o00004OnIWj03o`0001GoXk?K0ol00007oib[[005o`000?nLZjcoW:^/oib[[?l00000
0_nLZj`01?l0003oW:^/oib[[?nLZj`2o`0000[oW:^/0_l0000<ojWM^005o`000?nYgKSoZMfhojWM
^?l000000_nYgKP2o`0000?oZMfh00Go0000ojWM^?nYgKSoZMfho`00000<ojWM^0?o0000]?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Qooooo`;o0000:?oUfNl2o`00
00WoV:Z]00?o0000oiRZ[OnHZZd00onHZZd01Ol0003oV:Z]oiRZ[OnHZZgo000000?oV:Z]00?o0000
oiRZ[OnHZZd03?nHZZd3o`0000oofigC0ol0000LolgJ]0?o00004onIWj03o`0001CoXk?K0_l00005
oib[[005o`000?nLZjcoW:^/oib[[?l000000_nLZj`01?l0003oW:^/oib[[?l00005oib[[003o`00
0?nLZjcoW:^/00OoW:^/0_l0000=ojWM^0?o00001?nYgKP00ol0003oZMfhojWM^002ojWM^0?o0000
3_nYgKP3o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0h?oo
ool3o`0002SoiMW_0_l00009oiRZ[@03o`000?nHZZgoV:Z]00?oV:Z]00?o0000oiRZ[OnHZZd01OnH
ZZd00ol0003oV:Z]oiRZ[@0<oiRZ[@;o00004OoKWM<3o`0001_ocMZd0_l0000EoiVOX0?o00004_nS
/m/3o`0000GoW:^/00Go0000oib[[?nLZjcoW:^/o`000002oib[[006o`000?nLZjcoW:^/o`000?nL
Zjco00000onLZj`00ol0003oW:^/oib[[007oib[[0?o0000:_nYgKP3o`000;;ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0h?ooool2o`0002WoiMW_0_l00009oiRZ[@03
o`000?nHZZgoV:Z]00?oV:Z]00?o0000oiRZ[OnHZZd00onHZZd2o`0000ooV:Z]0_l0000Bom^Md`?o
00006Oo=f[@3o`0001KoVInP0ol0000Aoj>cf`;o00001onLZj`3o`0000CoW:^/0_l00003oib[[0?o
00002onLZj`2o`0002_oZMfh0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0=oooooo0ol0000XonGIk`?o00002OnHZZd00ol0003oV:Z]oiRZ[@03oiRZ[@03o`00
0?nHZZgoV:Z]00GoV:Z]00?o0000oiRZ[OnHZZd03?nHZZd2o`0001?ofigC0ol0000GolgJ]0?o0000
6?nIWj03o`0000ooXk?K0ol0000Qoib[[0;o0000:onYgKP3o`0000[ooooo3_l0002Iooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0=kooooo0ol0000XonGIk`Co00002?nH
ZZd2o`0000CoV:Z]0_l00003oiRZ[@05o`000?nHZZgoV:Z]oiRZ[Ol000003_nHZZd2o`0001CofigC
0ol0000FolgJ]0;o00006_nIWj03o`0000koXk?K0_l0000Roib[[0;o0000;?nYgKPKo`0009Sooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0g_ooool2o`0000_oiMW_0ol0
0002onGIk`Go00004ooUfNl6o`0000SoV:Z]00?o0000oiRZ[OnHZZd00onHZZd00ol0003oV:Z]oiRZ
[@02oiRZ[@?o00003_nHZZd3o`0001GofigC0ol0000DolgJ]0?o00006onIWj03o`0000WoXk?K1_l0
000Roib[[0;o0000:onYgKP>o`0000coXkk=1?l0002Fooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0=gooooo0ol0000:onGIk`05o`000?oUfNooiMW_onGIkol000000_oU
fNl01?l0003oiMW_onGIkol0000AonGIk`Co00000_o8ZmX2o`0002CoV:Z]0_l0000Gom^MdaSo0000
1_nIWj03o`0000CoVInP00Co0000oiVOX?nIWj3oVInP1Ol00007oiVOX0?o00000_nS/m/;o`0002?o
W:^/0ol0000YojWM^0?o00006OnS_/d4o`0009Gooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0gOooool2o`0000_oiMW_00Go0000onGIkooUfNooiMW_o`000003onGIk`03
o`000?oUfNooiMW_013oiMW_1?l00003olR[fP?o00008onHZZd2o`0001SofigC5_l00008oiVOX003
o`000?nIWj3oVInP00?oVInP00?o0000oiVOX?nIWj000_nIWj001?l0003oVInPoiVOX?l00008oiVO
X0_o00000_nf_;T3o`0002?oW:^/0_l0000WojWM^0Co00007?nS_/d3o`0009Cooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0g?ooool3o`0000coiMW_0ol00005onGIk`03
o`000?oUfNooiMW_00koiMW_0ol00006olR[fP;o00008onHZZd2o`0000KofigC0ol00003om^Md`?o
00001?oKWM<3o`0000;ofigC0_l0000Bom6]h`?o00001onIWj000ol0003oVInPoiVOX004oiVOX003
o`000?nIWj3oVInP00;oVInP00?o0000oiVOX?nIWj002OnIWj04o`0000Wo][bi0ol0000Qoib[[0Co
00009?nYgKP5o`0001koXkk=1?l0002Booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0<Sooooo3?l00008ooooo`;o00003?oUfNl01ol0003oiMW_onGIkooUfNoo0000onGI
kol000000ooUfNl00ol0003oiMW_onGIk`0;onGIk`Co00001oo8ZmX3o`00027oV:Z]0ol00007om^M
d`05o`000?oKWM?ofigCom^Mdol000000ooKWM<00ol0003ofigCom^Md`02om^Md`04o`000?oKWM?o
figCom^Md`;o00004ooA[N<2o`0000OoVInP00?o0000oiVOX?nIWj001?nIWj000ol0003oVInPoiVO
X003oiVOX003o`000?nIWj3oVInP00OoVInP0ol0000<okJl^@?o00007onLZj`7o`00023oZMfh2?l0
000Noj>nc@Co0000TOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`37
oooooaOo00003?oUfNl01ol0003oiMW_onGIkooUfNoo0000onGIkol000000ooUfNl00ol0003oiMW_
onGIk`0:onGIk`Co00002Oo8ZmX2o`00023oV:Z]0ol00008om^Md`03o`000?oKWM?ofigC00GofigC
00?o0000om^Mdol000001?l00002om^Md`;o00004ooA[N<3o`0000KoVInP00?o0000oiVOX?nIWj00
1OnIWj000ol0003oVInPo`000003oiVOX003o`000?nIWj3oVInP00KoVInP0_l0000>okJl^@?o0000
7OnLZj`3o`0000;ofmC]1Ol0000LojWM^0Go00000onk_M<2o`00023oXkk=1?l0002?ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`?o0000a_ooool3o`0000[o_l6T2_l0000>onGIk`?o00000ooU
fNl3o`0000coiMW_0ol0000;olR[fP?o00007_nHZZd4o`0000SofigC00?o0000om^MdooKWM<00ooK
WM<2o`0000;ofigC00Co0000om^MdooKWM?o00000_oKWM<3o`0001CodJgS0_l00005oiVOX0;o0000
0onIWj001ol0003oVInPoiVOX?nIWj3o0000oiVOX?l000000onIWj000ol0003oVInPoiVOX005oiVO
X0?o00003onf_;T3o`0001_oW:^/0ol00005om_Dk@Go00006?nYgKP5o`0000Go^kgC0_l0000Qoj>n
c@Co0000S?ooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo0<Gooooo0ol0000Coko1Y0?o
00008?oUfNl4o`0000gob:_J0_l0000MoiRZ[@Ko00001ooKWM<00ol0003ofigCom^Md`05om^Md`06
o`000?oKWM?ofigCo`000?oKWM?o00000_oKWM<2o`0001GodJgS0ol00005oiVOX004o`000?nIWj3o
VInPoiVOX0Go00000_nIWj03o`0000OoVInP0ol0000AokJl^@?o00006?nLZj`4o`0000SofmC]1Ol0
000DojWM^0Go00001onk_M<3o`0002;oXkk=0ol0002=ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0<Cooooo0ol0000Eoko1Y0;o00007ooUfNl4o`0000kob:_J0ol0000J
oiRZ[@Co00000_mjQjd2o`0000KofigC0_l00003om^Md`05o`000?oKWM?ofigCom^Mdol000000ooK
WM<2o`0000;ofigC0_l0000Fom6]h`;o00006_nIWj02o`0001?o][bi0_l0000Goib[[0Co00002ooK
e>d6o`00013oZMfh1?l0000:ok^md`;o00008onS_/d3o`0008cooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0`oooool3o`0001Ko_l6T0ol0000MonGIk`?o00004Oo8ZmX2
o`0001WoV:Z]1?l00003ogZ7[@?o00001_oKWM<00ol0003ofigCom^Md`02om^Md`?o00001OoKWM<0
0ol0003ofigCom^Md`02o`0001KodJgS0ol0000HoiVOX0?o00004onf_;T3o`0001GoW:^/0ol0000?
om_Dk@Ko00003?nYgKP4o`0000co^kgC0ol0000Soj>nc@;o0000S?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`32ooooo`?o00006?no`J@3o`0001[oiMW_1?l0000BolR[
fP?o00005onHZZd3o`0000KoNXN]0_l0000Fom^Md`;o00005ooA[N<2o`0001SoVInP0_l0000EokJl
^@?o00004onLZj`3o`0001?ofmC]1Ol00008ojWM^0Go00003_nk_M<2o`0002?oXkk=0ol0002;oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<7ooooo0ol0000Joko1Y0;o
00006OoUfNl4o`0001Cob:_J0_l0000EoiRZ[@Co00001omjQjd3o`0001GofigC0_l0000Gom6]h`?o
00005_nIWj03o`0001Ko][bi0ol0000@oib[[0Co00005_oKe>d5o`0000CoZMfh1Ol0000@ok^md`;o
00009?nS_/d2o`0008_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
`?ooool3o`0001_o_l6T1?l0000FonGIk`?o00000_o8ZmX3o`0000?ob:_J0_l0000<olR[fP?o0000
4onHZZd4o`0000WoNXN]0_l0000Eom^Md`;o00006?oA[N<2o`0001KoVInP0_l0000HokJl^@?o0000
3_nLZj`4o`0001WofmC]2_l0000Bok^md`?o00008onS_/d3o`0008[ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0__ooool4o`0001go_l6T1?l0000ConGIk`Co00000_o8
ZmX01Ol0003ob:_JolR[f_o8Zm[o000000Cob:_J00?o0000olR[f_o8ZmX02_o8ZmX2o`00017oV:Z]
1?l0000;ogZ7[@?o00004ooKWM<3o`0001SodJgS0ol0000DoiVOX0?o00006Onf_;T3o`0000coW:^/
0ol0000Mom_Dk@Ko00005Onk_M<2o`0002CoXkk=0_l0002:ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0;gooooo1?l0000Moko1Y0Ko00004OoUfNl4o`0000?ob:_J00Go
0000olR[f_o8Zm[ob:_Jo`000005olR[fP03o`000?o8Zm[ob:_J00Wob:_J0ol0000?oiRZ[@Co0000
3OmjQjd2o`0001?ofigC0_l0000Jom6]h`;o00004onIWj03o`0000Oo][bi0ol00003okJl^@?o0000
0onf_;T3o`0000Go][bi0_l0000;oib[[0?o00008?oKe>d2o`0001Oo^kgC0ol0000Soj>nc@?o0000
ROooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2looooo`?o00007_no
`J@3o`0000;oVlRI0ol0000?onGIk`?o00001_o8ZmX3o`0000?ob:_J1?l0000:olR[fPCo00003_nH
ZZd3o`0000ooNXN]0ol0000Bom^Md`;o00006_oA[N<3o`0001;oVInP0_l00009okJl^@05o`000?nf
_;Wo][biokJl^Ol000000onf_;T00ol0003o][bio`000003okJl^@03o`000?nf_;Wo][bi00;o][bi
0ol00009oib[[0?o00008OoKe>d2o`0001So^kgC0_l00008oj>nc@Go00000_nS_/d3o`0000CoXkk=
00?o0000oj>ncOnS_/d02onS_/d2o`0008Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0^oooool3o`0001oo_l6T0_l00004oi_8V@?o00003?oUfNl4o`0000Kob:_J00Oo
0000olR[f_o8Zm[ob:_Jo`000?o8Zm[o000000?ob:_J00?o0000olR[f_o8ZmX01_o8ZmX7o`0000_o
V:Z]1?l0000AogZ7[@;o00004_oKWM<2o`0001_odJgS0_l0000AoiVOX0?o00002Onf_;T01Ol0003o
][biokJl^Onf_;Wo000000?o][bi00?o0000okJl^Onf_;T00onf_;T00ol0003o][biokJl^@03okJl
^@?o00001_nLZj`4o`00027ofmC]0ol0000Hok^md`;o00002OnS_/d01_l0003oXkk=oj>ncOl0003o
Xkk=o`0000?oXkk=00Go0000oj>ncOnS_/goXkk=o`00000=oj>nc@?o0000R?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`2jooooo`?o00007ono`J@3o`0000GoVlRI1?l0
0009onGIk`Co00001oo8ZmX01ol0003ob:_JolR[f_o8Zm[o0000olR[f_l000000oo8ZmX00ol0003o
b:_JolR[fP05olR[fPCo00000_oIb]@3o`0000WoV:Z]1?l0000BogZ7[@?o00004OoKWM<2o`0001_o
dJgS0_l0000AoiVOX0;o00002_nf_;T00ol0003o][biokJl^@02okJl^@?o00001_nf_;T00ol0003o
][biokJl^@04okJl^@?o00001?nLZj`4o`0002;ofmC]0_l0000Iok^md`?o00002OnS_/d00ol0003o
Xkk=oj>nc@05oj>nc@03o`000?nS_/goXkk=00;oXkk=00?o0000oj>ncOnS_/d02onS_/d3o`0008Oo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0^Oooool3o`0001oo_l6T
0ol00007oi_8V@Co00001ooUfNl3o`0000[ob:_J0ol00003olR[fP?o00001_o8ZmX4o`0000GofL[D
0ol00007oiRZ[@?o00005OmjQjd2o`00017ofigC0_l0000Kom6]h`?o00003onIWj03o`0000[o][bi
00Go0000okJl^Onf_;Wo][bio`000003okJl^@03o`000?nf_;Wo000000?o00002?nf_;T3o`0000;o
W:^/0ol0000Tom_Dk@;o00006_nk_M<2o`0000[oXkk=00?o0000oj>ncOnS_/d00_nS_/d2o`0000Go
Xkk=00?o0000oj>ncOnS_/d03?nS_/d2o`0008Oooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0^?ooool3o`00023o_l6T0_l0000:oi_8V@?o00001?oUfNl4o`0001Wob:_J
1?l00007omW:e0?o00001?nHZZd4o`0001KoNXN]0ol0000@om^Md`;o00002OoA[N<3o`0000?odJgS
0ol00003om6]h`?o00001?oA[N<2o`0000ooVInP0_l0000:okJl^@;o00000onf_;T01ol0003o][bi
okJl^Onf_;Wo0000okJl^Ol000003?nf_;T6o`0002GofmC]0_l0000Jok^md`?o00001_nS_/d01Ol0
003oXkk=oj>ncOnS_/go000000GoXkk=00?o0000oj>ncOnS_/d00onS_/d00ol0003oXkk=oj>nc@0;
oj>nc@?o0000Q_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2goooo
o`?o00008?no`J@3o`0000_oVlRI0ol00002onGIk`Co00006?o8ZmX4o`0000[ofL[D0ol00002oiRZ
[@Co00006?mjQjd2o`00013ofigC0_l0000:om6]h`05o`000?oA[N?odJgSom6]hol000000ooA[N<0
0ol0003odJgSo`000003om6]h`04o`000?oA[N?odJgSom6]h`?o00003OnIWj03o`0000_o][bi00?o
0000okJl^Onf_;T00_nf_;T3o`0000;o][bi1Ol00009okJl^@Co00009_oKe>d2o`0001_o^kgC0_l0
0006oj>nc@07o`000?nS_/goXkk=oj>ncOl0003oXkk=o`000003oj>nc@03o`000?nS_/go000000?o
Xkk=00?o0000oj>ncOnS_/d03?nS_/d2o`0008Kooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0[oooool6o`000004ooooool0003o0000o`00023o_l6T0ol0000=oi_8V@Ko
00006Oo8ZmX4o`0000cofL[D1_l0000JogZ7[@?o00003_oKWM<3o`0000[odJgS00?o0000om6]hooA
[N<01OoA[N<00ol0003odJgSom6]h`03om6]h`03o`000?oA[N?odJgS00;odJgS0_l0000=oiVOX0;o
00009Onf_;T2o`0002KofmC]0ol0000Kok^md`;o00001onS_/d3o`0000?oXkk=0ol00002oj>nc@Go
00003_nS_/d3o`0008Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
[Oooool;o`00027o_l6T0_l0000?oi_8V@Co00006?o8ZmX4o`0000oofL[D1?l0000LogZ7[@;o0000
3_oKWM<2o`0000_odJgS00?o0000om6]hooA[N<01OoA[N<01?l0003odJgSom6]hooA[N<2o`0000Go
dJgS0ol0000;oiVOX0?o00009Onf_;T2o`0000KofmC]1Ol00003om_Dk@;o00000ooKe>d3o`00013o
fmC]0_l0000Lok^md`?o00009OnS_/d2o`0008Gooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0[?ooool4o`0000CoZ=BP0ol0000@oko1Y0?o00001?no`J@2o`0000So_l6T
0ol0000@oi_8V@;o00006?o8ZmX4o`00017ofL[D0_l0000=ogZ7[@?o00000_mjQjd5o`0000?oNXN]
00?o0000ogZ7[OmjQjd00ol0000=om^Md`;o00002ooA[N<01?l0003odJgSom6]hooA[N<4o`0000Ko
dJgS00?o0000om6]hooA[N<00ooA[N<2o`0000[oVInP0ol0000VokJl^@;o00001ooKe>d01?l0003o
fmC]om_DkOl00002om_Dk@06o`000?oKe>gofmC]o`000?oKe>go00000ooKe>d00ol0003ofmC]om_D
k@0=om_Dk@;o00007Onk_M<2o`0002GoXkk=2Ol0001nooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0:[ooooo1?l00007ojSDX0?o00003_no`J@01Ol0003o_l6Toko1Y?no
`JCo000000;o_l6T00Co0000oko1Y?no`JCo00001_no`J@3o`00017oVlRI0ol0000EolR[fPCo0000
4ooIb]@3o`0000goNXN]00?o0000ogZ7[OmjQjd00_mjQjd01?l0003oNXN]ogZ7[Ol00003ogZ7[@04
o`000?mjQjgoNXN]ogZ7[@;o00003OoKWM<2o`0000[odJgS0_l00003om6]h`03o`000?oA[N?odJgS
00?odJgS00Go0000om6]hooA[N?odJgSo`000005om6]h`?o00002OnIWj02o`0002Oo][bi0_l00008
om_Dk@03o`000?oKe>gofmC]00;ofmC]00Ko0000om_DkOoKe>go0000om_DkOl00003om_Dk@03o`00
0?oKe>gofmC]00gofmC]0_l0000Mok^md`?o00009OnS_/d:o`0007cooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Z?ooool5o`0000WoZ=BP0ol0000Aoko1Y004o`000?no
`JCo_l6To`0000;o_l6T00?o0000oko1Y?no`J@01?no`J@2o`0001?oVlRI0_l0000DolR[fPCo0000
5OoIb]@2o`0000goNXN]00?o0000ogZ7[OmjQjd00omjQjd00ol0003oNXN]ogZ7[@04ogZ7[@03o`00
0?mjQjgoNXN]00?o00003?oKWM<2o`0000_odJgS00Co0000om6]hooA[N?odJgS1Ol00002om6]h`?o
00001ooA[N<2o`0000OoVInP1?l0000WokJl^@;o00002OoKe>d01Ol0003ofmC]om_DkOoKe>go0000
00;ofmC]00?o0000om_DkOoKe>d00ol0000@om_Dk@;o00007_nk_M<2o`0002CoXkk=0ol00005ohN@
]0Go0000N_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Vooooo`Go
00003?nXe:02o`00017o_l6T00Co0000oko1Y?no`JCo00000_no`J@00ol0003o_l6Toko1Y003oko1
Y0?o00004onKb9T2o`0001?ob:_J0ol0000GomW:e0;o00003OmjQjd00ol0003oNXN]ogZ7[@04ogZ7
[@03o`000?mjQjgoNXN]00?oNXN]00Co0000ogZ7[OmjQjgoNXN]0_l0000<om^Md`;o00008?oA[N<3
o`0000?oVInP2Ol0000UokJl^@;o00001_oKe>d01Ol0003ofmC]om_DkOoKe>go000000;ofmC]00Ko
0000om_DkOoKe>go0000om_DkOl00003om_Dk@03o`000?oKe>gofmC]00cofmC]0ol0000Nok^md`;o
00008onS_/d3o`0000SoQi2d1Ol0001hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0:Cooooo1Ol0000>ojSDX0?o00003?no`J@4o`0000?o_l6T00Co0000oko1Y?no`JCo
00001?no`J@3o`0001CoVlRI0ol0000@olR[fPCo00006?oIb]@6o`0000WoNXN]00Go0000ogZ7[Omj
QjgoNXN]o`000003ogZ7[@03o`000?mjQjgoNXN]00?oNXN]00?o0000ogZ7[OmjQjd00ol0000;om^M
d`;o00008OoA[N<9o`0000;oe:kH1_l0000RokJl^@;o00001_oKe>d01Ol0003ofmC]om_DkOoKe>go
000000;ofmC]00Ko0000om_DkOoKe>go0000om_DkOl00003om_Dk@03o`000?oKe>gofmC]00cofmC]
0_l0000Ook^md`?o00008OnS_/d3o`0000_oQi2d1Ol0001fooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0:?ooooo1?l0000AojSDX0?o00002ono`J@00ol0003o_l6Toko1
Y004oko1Y004o`000?no`JCo_l6To`0000Co_l6T0_l0000Foi_8V@;o00003oo8ZmX4o`0001[ofL[D
2ol00002ogZ7[@;o00000omjQjd01ol0003oNXN]ogZ7[OmjQjgo0000ogZ7[Ol000000omjQjd01?l0
003oNXN]ogZ7[OmjQjd2o`0000[ofigC0ol0000Qom6]h`Ko00001ooD[]P6o`0001oo][bi0ol00007
om_Dk@?o00001?oKe>d2o`0000?ofmC]0ol0000?om_Dk@;o00008?nk_M<2o`00027oXkk=0_l0000>
ohN@]0Go0000M?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Qoooo
o`Co00005?nXe:02o`0000_o_l6T1Ol00003oko1Y0;o00001?no`J@3o`0001KoVlRI0ol0000<olR[
fPCo00006ooIb]@3o`0000;om^K83Ol00002ogZ7[@?o00000_mjQjd5o`0000?oNXN]0ol00009om^M
d`;o00008ooA[N<2o`0000goe:kH1Ol0000KokJl^@Ko00009?oKe>d2o`00023o^kgC0ol0000Ooj>n
c@?o00004?n7T;@5o`0007;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0T_oooolBo`0001GoZ=BP0ol0000Hoko1Y0;o00006?nKb9T2o`0000_ob:_J1?l0000LomW:e0;o
00002Oofi/P<o`0000_oNXN]0_l00009om^Md`;o00008_oA[N<3o`0000ooe:kH1_l0000FokJl^@Go
000000CoUkfWo`000?l0003o00008ooKe>d2o`0000Wo^kgC1Ol000000onk_M?o0000o`000003o`00
00;o^kgC0ol00008ok^md`;o00007_nS_/d3o`0001?oQi2d1Ol0001`ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo097ooooo4Ol0000HojSDX0?o00005_no`J@3o`0001So
VlRI0_l00009olR[fPCo00007_oIb]@2o`0000oom^K83?l00005ogZ7[@?o00001_oKWM<5o`00023o
dJgS0ol0000BomB^f0Ko00004_nf_;T5o`0000CoUkfW0ol0000Qom_Dk@?o00002_nk_M<01?l0003o
^kgCok^mdol00002ok^md`06o`000?nk_M?o^kgCo`000?nk_M?o00000onk_M<00ol0003o^kgCok^m
d`05ok^md`;o00007_nS_/d2o`0001KoQi2d1Ol0001^ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo093ooooo0ol0000=ojbnSP;o00006OnXe:02o`0001Go_l6T0ol0000I
oi_8V@?o00001oo8ZmX4o`0001kofL[D0ol0000DooKVb0oo000000?ofigCo`000?l000002ol0000L
om6]h`?o00005_oD[]P5o`0000go][bi1_l00007oiNmY`?o00008?oKe>d2o`0000co^kgC00?o0000
ok^mdonk_M<00onk_M<01Ol0003o^kgCok^mdonk_M?o000000?o^kgC00?o0000ok^mdonk_M<01Onk
_M<3o`0001coXkk=0ol0000HohN@]0Co0000KOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2?ooooo`?o00003_n/_Xh2o`0001WoZ=BP0ol0000Doko1Y0;o00001_nKb9T3
o`0000?oVlRI0ol0000<oi_8V@;o00001Oo8ZmX4o`00023ofL[D0_l0000KooKVb13o00000ooO`MX7
o`0001WodJgS0_l0000IomB^f0Go00002Onf_;T6o`0000[oUkfW0ol0000Oom_Dk@;o00003Onk_M<0
0ol0003o^kgCok^md`03ok^md`03o`000?nk_M?o^kgC00Co00002Onk_M<2o`0001_oXkk=0ol0000K
ohN@]0;o0000KOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2>oooo
o`?o00003on/_Xh3o`0001WoZ=BP0_l0000Coko1Y0?o00001OnKb9T01Ol0003oVlRIoi_8VOnKb9Wo
000000?oVlRI00?o0000oi_8VOnKb9T02onKb9T3o`0000?ob:_J1?l0000QomW:e0;o00008Oofi/P5
o`0000_ogl7J1_l0000Fom6]h`?o00006ooD[]P6o`0000Co][bi1Ol0000>oiNmY`?o00007_oKe>d2
o`0000[o^kgC00Oo0000ok^mdonk_M?o^kgCo`000?nk_M?o000000?o^kgC00?o0000ok^mdol00000
3?nk_M<3o`0001GoXkk=1ol0000LohN@]0?o0000K?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2=ooooo`?o00004On/_Xh2o`0001WoZ=BP0ol0000Aoko1Y0?o00001_nK
b9T01Ol0003oVlRIoi_8VOnKb9Wo000000?oVlRI00?o0000oi_8VOnKb9T03?nKb9T2o`000003olR[
f_l0003o000000;o00008_oIb]@3o`0002;om^K80ol0000?omo1fPKo00004_oA[N<3o`0001koe:kH
2ol0000AoiNmY`?o00007OoKe>d2o`0000[o^kgC00Oo0000ok^mdonk_M?o^kgCo`000?nk_M?o0000
00?o^kgC00Co0000ok^mdonk_M?o00003?nk_M<2o`0000coXkk=3ol0000NohN@]0?o0000Joooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<ooooo`?o00004_n/_Xh2o`00
01[oZ=BP0ol0000@oko1Y0;o00001onKb9T4o`0000CoVlRI00?o0000oi_8VOnKb9T03?nKb9T6o`00
00kofL[D0_l00004omW:e0?o00003?oIb]@2o`0002?om^K80_l0000Bomo1fPKo00003ooA[N<3o`00
02;oe:kH1_l0000DoiNmY`?o00006ooKe>d3o`0000_o^kgC0ol00003ok^md`?o00001?nk_M<2o`00
00[o^kgC0_l00003oj>ncA?o00000on/KhX2o`0001ooQi2d0_l0001[ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo08_ooooo0ol0000CojbnSP;o00006onXe:02o`0000oo
_l6T0ol00007oi_8V@03o`000?nKb9WoVlRI00GoVlRI00?o0000oi_8VOnKb9T03?nKb9T4o`0001;o
fL[D00Co0000omW:e?oIb]Co00000ooIb]@00ol0003ofL[DomW:e009omW:e0;o00008oofi/P2o`00
01Gogl7J1_l0000;om6]h`?o00009OoD[]P2o`0001OoUkfW0ol0000Jom_Dk@;o00009Onk_M<?o`00
00co[6n:0ol00005ohN@]0Go00000on7T;@3o`0000;oQi2d0_l0000:ohN@]0?o0000J_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2:ooooo`?o00005?n/_Xh2o`0001_o
Z=BP0ol0000=oko1Y0?o00002OnKb9T00ol0003oVlRIoi_8V@03oi_8V@;o00003onKb9T2o`0001Co
fL[D00?o0000omW:e?l000000ooIb]@00ol0003ofL[DomW:e008omW:e0?o00008_ofi/P3o`0001Oo
gl7J1ol00008om6]h`;o00009_oD[]P2o`0001SoUkfW0ol0000Iom_Dk@;o00009_nk_M<5o`0001Ko
[6n:0_l00006ohN@]004o`000?n7T;CoQi2do`0000CoQi2d00?o0000ohN@]?n7T;@00on7T;@00ol0
003oQi2dohN@]008ohN@]0?o0000JOooool00ol0003oooooooooo`08ooooo`006_ooool3o`0008Wo
oooo0ol0000EojbnSP?o00006onXe:03o`0000co_l6T0_l0000;oi_8V@;o00001?nKb9T00ol0003o
VlRIoi_8V@0<oi_8V@?o00004OoIb]@4o`000003omW:e?l0003o000000;o00002ooIb]@2o`0002?o
m^K80_l0000Komo1fPKo00001OoA[N<3o`0002Koe:kH0_l0000IoiNmY`?o00006?oKe>d2o`0002Go
^kgC0ol0000Ioja_RP;o00001on7T;@01?l0003oQi2dohN@]?n7T;@5o`0000GoQi2d00?o0000ohN@
]?n7T;@02?n7T;@2o`0006Oooooo0ol0000:ooooo`006_ooool00ol0003oooooooooo`28ooooo`?o
00005on/_Xh2o`0001coZ=BP0_l0000;oko1Y0?o00007OnKb9T6o`00013ofL[D00Oo0000omW:e?oI
b]CofL[Do`000?oIb]Co000000kofL[D0_l0000SooKVb0;o00007_oO`MX6o`000004om6]hol0003o
0000o`0002Koe:kH0ol0000JoiNmY`?o00005ooKe>d2o`0002Co^kgC0ol0000Joja_RP;o00002?n7
T;@01?l0003oQi2dohN@]?l00002ohN@]004o`000?n7T;CoQi2dohN@]0Co00002_n7T;@3o`0006So
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Qoooool3o`0001So[;j>
0_l0000LojSDX0?o00002Ono`J@3o`0001_oVlRI2_l0000?omW:e005o`000?oIb]CofL[DomW:e?l0
00000_oIb]@00ol0003ofL[DomW:e00:omW:e0?o00008_ofi/P3o`000004omo1f_l0003o0000o`00
00Cogl7J0ol00002omo1fP?o00004?oO`MX7o`0002Ooe:kH0_l0000LoiNmY`?o00005OoKe>d3o`00
023o^kgC1_l0000Koja_RP;o00001On7T;@01Ol0003oQi2dohN@]?n7T;Co000000;oQi2d00?o0000
ohN@]?l000000_n7T;@01Ol0003oQi2dohN@]?n7T;Co000000_oQi2d0ol0001Wooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Kooooo0ol0000IojbnSP;o00007OnXe:05
o`0000Ko_l6T0_l0000Ioi_8V@Oo00001?oOXmT3o`0000oofL[D0ol00004omW:e0;o00002_oIb]@2
o`0002?om^K80_l00003omo1fP03o`000?oO`M[ogl7J00Cogl7J00?o0000omo1f_oO`MX00_oO`MX0
0ol0003ogl7Jomo1fP0Bomo1fPCo00004?oD[]P3o`0000Coe:kH00?o0000omB^f?oD[]P00_oD[]P3
o`0000Soe:kH0_l0000MoiNmYaWo00006_nk_M<<o`0001co[6n:0ol00004ohN@]005o`000?n7T;Co
Qi2dohN@]?l000000on7T;@2o`0000;oQi2d00Go0000ohN@]?n7T;CoQi2do`00000<ohN@]0;o0000
Ioooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`?o00006_n/
_Xh2o`0001koZ=BP2?l000001?no`JCo0000o`000?l0000Foi_8V@Oo00002?oOXmT2o`0002;ofL[D
0_l0000RooKVb0?o00000ooO`MX01?l0003ogl7Jomo1f_oO`MX5o`0000?ogl7J00?o0000omo1f_oO
`MX04OoO`MX6o`00013oe:kH00?o0000omB^f?oD[]P00ooD[]P01Ol0003oe:kHomB^f?oD[]So0000
00?oe:kH00?o0000omB^f?oD[]P01OoD[]P2o`0000GoUkfW0ol00003oiNmY`;o00001OnG_JL00ol0
003oUkfWoiNmY`09oiNmYaWo00004_nk_M<?o`0000;oPif<0_l0000Moja_RP;o00001On7T;@3o`00
00GoQi2d00Co0000ohN@]?n7T;CoQi2d0ol0000=ohN@]0;o0000Ioooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00006on/_Xh2o`0000KoZ=BP0ol00004ojSD
X0;o00003_nXe:03o`000003oi:RT_l0003o000000Ko00005?nKb9T7o`0000_ogj?I0ol0000PomW:
e0?o00008_ofi/P2o`0000Cogl7J00Go0000omo1f_oO`M[ogl7Jo`000002omo1fP03o`000?oO`M[o
gl7J00;ogl7J00?o0000omo1f_oO`MX04OoO`MX2o`0000;o]WBb0ol0000?omB^f003o`000?oD[]So
e:kH00Coe:kH00Co0000omB^f?oD[]So00000ooD[]P00ol0003oe:kHomB^f005omB^f0;o00001_nG
_JL00ol0003oUkfWoiNmY`04oiNmY`03o`000?nG_JOoUkfW00;oUkfW00?o0000oiNmYonG_JL02?nG
_JL3o`0001GoY8nW0ol0000:ok^md`oo00002On3WH`2o`0001go[6n:0_l0000QohN@]0;o0000Iooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00006on/_Xh3
o`0000CoZ=BP00Go0000ojSDX?nXe:3oZ=BPo`000002ojSDX004o`000?nXe:3oZ=BPo`0000coZ=BP
0ol00006oi:RTPCo00004OnKb9T7o`0000oogj?I1?l0000NomW:e0;o00008oofi/P2o`0000Cogl7J
00?o0000omo1f_oO`MX00_oO`MX00ol0003ogl7Jo`000004omo1fP03o`000?oO`M[ogl7J013ogl7J
0ol00003okId/P?o00003_oD[]P00ol0003oe:kHomB^f004omB^f003o`000?oD[]Soe:kH00Co0000
2?oD[]P2o`0000KoUkfW00?o0000oiNmYonG_JL01OnG_JL00ol0003oUkfWoiNmY`02oiNmY`03o`00
0?nG_JOoUkfW00OoUkfW0_l0000GojB?Y`?o00000_nk_M<?o`00013oPif<0_l0000Moja_RP;o0000
8On7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0QOoo
ool2o`0000Ko[;j>0ol00003ojbnSP?o00003On/_Xh2o`0000SoZ=BP00Co0000ojSDX?nXe:3o0000
0_nXe:000ol0003oZ=BPojSDX009ojSDX0?o00002OnBXY83o`0000goVlRI1ol0000ComnSf@Go0000
7?oIb]@2o`0002;om^K80ol00003omo1fP;o00001OoO`MX2o`0000?ogl7J0_l0000Bomo1fP;o0000
1OnfM;83o`0000goe:kH00?o0000omB^f?oD[]P01OoD[]P00ol0003oe:kHo`00000;omB^f0;o0000
1_nG_JL00ol0003oUkfWoiNmY`02oiNmY`Co00001?nG_JL00ol0003oUkfWoiNmY`07oiNmY`;o0000
6?nTSjL<o`0001OoPif<0ol0000Loja_RP?o00008?n7T;@2o`0006Oooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0QOooool2o`0000Oo[;j>00Go0000ojbnS_n/_Xko[;j>
o`000003ojbnSP03o`000?n/_Xko[;j>00[o[;j>0_l00006ojSDX0;o00000onXe:001?l0003oZ=BP
ojSDX?l0000:ojSDX0?o00002onBXY83o`0000WoVlRI1ol0000EomnSf@So00006OoIb]@3o`0002;o
m^K80_l00005omo1fP03o`000?oO`M[ogl7J00Cogl7J00?o0000omo1f_oO`MX00_oO`MX00ol0003o
gl7Jomo1fP0?omo1fP?o00001_nfM;83o`0000_oe:kH0_l00003omB^f005o`000?oD[]Soe:kHomB^
f?l000000_oD[]P00ol0003oe:kHomB^f007omB^f0?o00001_nG_JL01Ol0003oUkfWoiNmYonG_JOo
000000?oUkfW00?o0000oiNmYonG_JL00onG_JL00ol0003oUkfWoiNmY`05oiNmY`?o00006OnTSjL4
o`0001ooPif<0_l0000Moja_RP;o00008?n7T;@2o`0006Oooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0QOooool2o`0000Oo[;j>00Go0000ojbnS_n/_Xko[;j>o`000003
ojbnSP03o`000?n/_Xko[;j>00[o[;j>0_l00008ojSDX004o`000?nXe:3oZ=BPo`0000;oZ=BP00?o
0000ojSDX?nXe:001onXe:03o`0000goTZ:B0ol00005oi_8V@Oo00005ooOXmT3o`0000?o/>GF1Ol0
000GomW:e0;o00002Oofi/P3o`0000;om^K81Ol00002ooKVb0?o00002oofi/P2o`0002?ogl7J0_l0
0008okId/P?o00002ooD[]P01?l0003oe:kHomB^f?oD[]P5o`0000?oe:kH0_l00007omB^f0;o0000
1_nG_JL2o`0000?oUkfW00Oo0000oiNmYonG_JOoUkfWo`000?nG_JOo000000?oUkfW00?o0000oiNm
YonG_JL01OnG_JL2o`0001[oY8nW0_l0000Qoh>MS0;o00007On/KhX2o`00023oQi2d0_l0001Woooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l00007ojbnSP04
o`000?n/_Xko[;j>ojbnSPCo00003On/_Xh2o`0000CoZ=BP00Go0000ojSDX?nXe:3oZ=BPo`000002
ojSDX004o`000?nXe:3oZ=BPo`0000WoZ=BP0_l0000?oi:RTP?o000000?oVlRIo`000?l000001Ol0
000JomnSf@;o00001_n`iMH5o`0001GofL[D0_l0000:ooKVb003o`000?ofi/Som^K800;om^K800Ko
0000ooKVb?ofi/So0000ooKVb?l00003ooKVb003o`000?ofi/Som^K800Oom^K80ol0000Romo1fP?o
00002OnfM;83o`0001ooe:kH0_l00007oiNmY`03o`000?nG_JOoUkfW00;oUkfW0ol00002oiNmY`Go
00001_nG_JL3o`0001[oY8nW0_l0000Qoh>MS0;o00007On/KhX2o`00023oQi2d0_l0001Wooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l00007ojbnSP05o`00
0?n/_Xko[;j>ojbnS_l000004?n/_Xh3o`0000CoZ=BP0ol00004ojSDX0;o00002OnXe:03o`00013o
TZ:B1ol0000LomnSf@?o00002?n`iMH5o`0001;ofL[D0ol0000:ooKVb003o`000?ofi/Som^K800?o
m^K800?o0000ooKVb?ofi/P01Oofi/P00ol0003om^K8ooKVb007ooKVb0;o00008ooO`MX2o`0000_o
]WBb0ol0000NomB^f0;o00007?nG_JL2o`0001_oY8nW0_l0000Qoh>MS0;o00007On/KhX3o`0001ko
Qi2d0ol0001Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo
0_l00006ojbnSP;o00001?n/_Xh00ol0003o[;j>ojbnSP0>ojbnSP;o00005OnXe:03o`0001;oTZ:B
0ol0000OomnSf@;o00002on`iMH5o`00013ofL[D0_l0000;ooKVb003o`000?ofi/Som^K800Com^K8
00?o0000ooKVb?ofi/P00_ofi/P2o`0000Wom^K80ol0000Romo1fP?o00003?nfM;83o`0001goe:kH
0_l0000KoiNmY`?o00006onTSjL2o`00027oPif<0_l0000Noja_RP;o00007_n7T;@2o`0006Sooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0QOooool2o`0000Oo[;j>00?o
0000ojbnS_n/_Xh00on/_Xh2o`0000ko[;j>0_l0000DojSDX0?o00004onBXY82o`0001oogj?I0ol0
000=ok3UePGo00003_oIb]@2o`0000_om^K800Go0000ooKVb?ofi/Som^K8o`000003ooKVb003o`00
0?ofi/Som^K800?om^K800?o0000ooKVb?ofi/P01_ofi/P2o`0002?ogl7J0_l0000>okId/P?o0000
7?oD[]P2o`0001_oUkfW0_l0000LojB?Y`?o00008?n3WH`2o`0001ko[6n:0_l0000NohN@]0;o0000
J?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00007On/
_Xh2o`0001?oZ=BP0ol0000Doi:RTP;o00007_oOXmT3o`00013o/>GF1Ol0000;omW:e0?o00002_of
i/P2o`0000?om^K800Oo0000ooKVb?ofi/Som^K8o`000?ofi/So000000?om^K800?o0000ooKVb?of
i/P01_ofi/P2o`0002;ogl7J0ol0000?okId/P?o00006ooD[]P2o`0001_oUkfW0_l0000MojB?Y`;o
00008?n3WH`2o`0000?o[6n:1Ol00002oja_RP?o00000on/KhX2o`0000co[6n:0_l0000NohN@]0;o
0000J?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o0000
7On/_Xh2o`0001;oZ=BP0ol0000Eoi:RTP?o00007OoOXmT2o`0001?o/>GF1Ol00009omW:e0;o0000
3?ofi/P00ol0003om^K8ooKVb002ooKVb0?o00000oofi/P3o`0000Som^K80ol0000Romo1fP;o0000
4OnfM;83o`0001Woe:kH0ol0000JoiNmY`?o00002?nTSjL5o`0000?oY8nW0_l00003ojB?Y`;o0000
1_nTSjL2o`00023oPif<0ol00003oja_RP06o`000?n/Kh[o[6n:o`000?n/Kh[o00000on/KhX00ol0
003o[6n:oja_RP02oja_RP03o`000?n/Kh[o[6n:00Wo[6n:0_l0000NohN@]0;o0000J?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25ooooo`;o00007On/_Xh3o`00017o
Z=BP0_l0000Goi:RTP;o00007?oOXmT3o`0001Go/>GF1Ol00007omW:e0;o00008_ofi/P2o`0002;o
gl7J0ol0000BokId/P?o00006?oD[]P2o`0001_oUkfW0_l0000:ojB?Y`04o`000?nTSjOoY8nWo`00
00;oY8nW00Co0000ojB?YonTSjOo00001?nTSjL00ol0003oY8nWojB?Y`03ojB?Y`;o00002On3WH`5
o`000003oh>MS?l0003o000000?o00000on3WH`00ol0003oPif<oh>MS007oh>MS0;o00001?n/KhX0
0ol0003o[6n:oja_RP05oja_RP03o`000?n/Kh[o[6n:00?o[6n:00?o0000oja_R_n/KhX02?n/KhX3
o`0001goQi2d0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08Gooooo0_l0000NojbnSP;o00004?nXe:03o`0001OoTZ:B0_l0000LomnSf@;o00006?n`iMH5o`00
00CofL[D0ol0000RooKVb0;o00008_oO`MX2o`0001Co]WBb0ol0000GomB^f0;o00006_nG_JL3o`00
00_oY8nW00?o0000ojB?YonTSjL00_nTSjL01?l0003oY8nWojB?Yol00005ojB?Y`03o`000?nTSjOo
Y8nW00;oY8nW0_l0000:oh>MS004o`000?n3WHcoPif<o`0000;oPif<00Co0000oh>MS?n3WHco0000
0on3WH`00ol0003oPif<oh>MS007oh>MS0;o00001On/KhX00ol0003o[6n:oja_RP02oja_RP;o0000
0on/KhX4o`0000_o[6n:0_l0000MohN@]0;o0000J?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`25ooooo`;o00007_n/_Xh2o`0000ooZ=BP0ol0000Hoi:RTP;o00006ooO
XmT3o`0001[o/>GF1Ol00002omW:e0;o00008Oofi/P4o`00027ogl7J0ol0000EokId/P?o00005_oD
[]P2o`0001[oUkfW0_l0000=ojB?Y`05o`000?nTSjOoY8nWojB?Yol000000_nTSjL00ol0003oY8nW
ojB?Y`04o`0000CoY8nW0_l0000;oh>MS003o`000?n3WHcoPif<00?oPif<00?o0000oh>MS?n3WH`0
1?n3WH`00ol0003oPif<oh>MS006oh>MS0;o00000_n/KhX01Ol0003o[6n:oja_R_n/Kh[o000000Go
[6n:00?o0000oja_R_l000000on/KhX00ol0003o[6n:oja_RP09oja_RP;o00007On7T;@2o`0006So
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0QOooool4o`0001co[;j>
0_l0000>ojSDX0?o00006OnBXY82o`0001[ogj?I0ol0000Mok3UePOo00007oofi/P7o`00023ogl7J
0_l0000GokId/P?o00005OoD[]P2o`0001WoUkfW0ol0000:ojB?Y`05o`000?nTSjOoY8nWojB?Yol0
00000_nTSjL01_l0003oY8nWojB?Yol0003oY8nWo`0000?oY8nW00?o0000ojB?YonTSjL00_nTSjL2
o`0000coPif<00?o0000oh>MS?n3WH`00on3WH`00ol0003oPif<oh>MS003oh>MS003o`000?n3WHco
Pif<00KoPif<0_l00002oja_RP07o`000?n/Kh[o[6n:oja_R_l0003o[6n:o`000003oja_RP03o`00
0?n/Kh[o000000?o[6n:00?o0000oja_R_n/KhX02On/KhX2o`0001_oQi2d1Ol0001Wooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Cooooo2?l0000IojbnSP;o00003OnX
e:03o`0000WoTZ:B0ol00002oi:RTP?o00002OnBXY82o`0001[ogj?I0_l0000Pok3UePGo00007?of
i/P6o`0000;oV[2Q1?l0000Momo1fP?o00006?nfM;83o`0001Coe:kH0_l0000IoiNmY`;o00002onT
SjL01Ol0003oY8nWojB?YonTSjOo000000;oY8nW00Ko0000ojB?YonTSjOo0000ojB?Yol00003ojB?
Y`03o`000?nTSjOoY8nW00;oY8nW0_l00009oh>MS007o`000?n3WHcoPif<oh>MS?l0003oPif<o`00
0003oh>MS003o`000?n3WHcoPif<00?oPif<00?o0000oh>MS?n3WH`01On3WH`2o`0000?o[6n:0ol0
0003oja_RP?o00000on/KhX3o`0000co[6n:0ol0000FohN@]0[o0000I_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`23ooooo`?o00000_nHa;D8o`0001Go[;j>0_l0000=
ojSDX0;o00002onBXY801?l0003oTZ:Boi:RT_l00003oi:RTP03o`000?nBXY;oTZ:B00KoTZ:B0_l0
000;omnSf@?o00001?oOXmT3o`0000Cogj?I0ol0000Rok3UeP;o00006oofi/P6o`0000GoV[2Q1?l0
000Lomo1fP;o00006_nfM;83o`0001?oe:kH0_l0000IoiNmY`;o00003?nTSjL3o`0000CoY8nW0_l0
0003ojB?Y`?o00001OnTSjL2o`0000WoPif<00Oo0000oh>MS?n3WHcoPif<o`000?n3WHco000000?o
Pif<00?o0000oh>MS?l000000on3WH`00ol0003oPif<oh>MS005oh>MS0;o00007on/KhX2o`0001;o
Qi2d2Ol00003onOXj@?o0000IOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`22ooooo`?o00001_nHa;D8o`0001;o[;j>0ol0000;ojSDX0?o00002?nBXY85o`0000GoTZ:B
00?o0000oi:RT_nBXY801_nBXY83o`0000Wogj?I00Go0000omnSfOoOXmWogj?Io`000004omnSf@03
o`000?oOXmWogj?I00?ogj?I0_l0000Sok3UeP?o00006?ofi/P5o`0000[oV[2Q1?l0000Iomo1fP?o
00006onfM;83o`00017oe:kH0ol0000HoiNmY`?o00008?nTSjL2o`0000[oPif<0ol00003oh>MS0?o
00000_n3WH`5o`0000OoPif<0_l0000Ooja_RP;o00003On7T;@:o`0000SoinSY0ol0001Tooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0ol0000;oiS4]@Oo0000
4?n/_Xh2o`0000[oZ=BP0ol00009oi:RTP04o`000?nBXY;oTZ:Bo`0000CoTZ:B0_l0000:oi:RTP;o
00002OoOXmT01_l0003ogj?IomnSfOoOXmWo0000omnSf@Go00000ooOXmT3o`0002Co/>GF0_l0000E
ooKVb0Ko00003OnJ/:44o`0001Sogl7J0_l0000MokId/P?o00004?oD[]P2o`0001WoUkfW0_l0000Q
ojB?Y`;o00008On3WH`3o`0001ko[6n:0_l00009ohN@]0[o00003OoWj>T3o`0006?ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool3o`0000ooV<Be2?l0000<ojbn
SP;o00002OnXe:03o`0000_oTZ:B00?o0000oi:RT_l000001_nBXY800ol0003oTZ:Boi:RTP07oi:R
TP;o00002OoOXmT4o`0000;ogj?I00Co0000omnSfOoOXmWo00000ooOXmT3o`0002Go/>GF0ol0000B
ooKVb0Ko00004OnJ/:44o`0001Gogl7J0ol0000NokId/P?o00003ooD[]P2o`0001SoUkfW0ol0000Q
ojB?Y`?o00008On3WH`2o`0001ko[6n:0_l00005ohN@]0Wo00004ooWj>T3o`0006;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool3o`0001?oV<Be2?l00009ojbn
SP;o00002?nXe:03o`0000goTZ:B0_l00002oi:RTP05o`000?nBXY;oTZ:Boi:RT_l000002OnBXY82
o`0000Wogj?I00?o0000omnSfOoOXmT01?oOXmT00ol0003ogj?Io`000003omnSf@;o00009on`iMH2
o`00013om^K81Ol0000EoiZ`X@Co00005?oO`MX2o`00023o]WBb0ol0000>omB^f0;o00006?nG_JL2
o`0002?oY8nW0_l0000Qoh>MS0;o00007_n/KhX<o`0001SoinSY0_l0001Rooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo07kooooo0ol0000HoiS4]@So00001On/_Xh2o`00
00OoZ=BP0ol0000?oi:RTP04o`000?nBXY;oTZ:Boi:RTP?o00002_nBXY82o`0000[ogj?I00?o0000
omnSfOoOXmT01?oOXmT2o`0000;ogj?I0ol0000Wok3UeP?o00003?ofi/P6o`0001WoV[2Q1?l0000A
omo1fP?o00008OnfM;83o`0000goe:kH0_l0000GoiNmY`?o00008onTSjL2o`00027oPif<0_l0000O
oja_RPOo00007?oWj>T2o`0006;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0OOooool3o`0001coV<Be2?l00002ojbnSP?o00001_nXe:02o`00027oTZ:B0_l0000;omnS
f@;o00001OoOXmT00ol0003ogj?Io`000002o`0002Wo/>GF0_l0000:ooKVb0Ko00007?nJ/:44o`00
013ogl7J0_l0000SokId/P?o00003?oD[]P2o`0001OoUkfW0_l0000TojB?Y`;o00008On3WH`2o`00
01oo[6n:0ol0000PonOXj@;o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1looooo`?o00008OnHa;D9o`0000GoZ=BP0ol0000Qoi:RTP;o00005?oOXmT2o`0002[o
/>GF0_l00008ooKVb0Go00008OnJ/:44o`0000gogl7J0ol0000TokId/P?o00002ooD[]P2o`0001Oo
UkfW0_l0000SojB?Y`Co00008?n3WH`2o`0001ko[6n:0ol0000QonOXj@?o0000HOooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1kooooo`?o00009OnHa;D6o`0000CoZ=BP
0ol0000Roi:RTP?o00004_oOXmT3o`0002[o/>GF0ol00004ooKVb0Ko00009?nJ/:44o`0000cogl7J
0_l0000VokId/P?o00002OoD[]P3o`00013oUkfW2Ol0000RojB?Y`Ko00007on3WH`2o`0001go[6n:
0ol0000SonOXj@;o0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1kooooo`;o0000:OnHa;D4o`0000;oZ=BP0ol0000Toi:RTP;o00004_oOXmT2o`0000ko/>GF0ol0
0003ok3UeP?o00005On`iMH2o`0000;om^K81_l0000XoiZ`X@Co00002OoO`MX3o`0002Oo]WBb0ol0
0008omB^f0;o00001?nG_JLGo`00023oY8nW0ol00002oj^L^0Co00007On3WH`2o`0001go[6n:0_l0
000TonOXj@;o0000HOooool00ol0003oooooooooo`08ooooo`002?ooool3o`0000?ooooo0_l0000:
ooooo`03o`000?oooooooooo07_ooooo0_l0000[oiS4]@Ko00009OnBXY82o`00017ogj?I0ol0000=
ok3UeP07o`000?n`iMKo/>GFok3Ue_l0003o/>GFo`000003ok3UeP03o`000?n`iMKo/>GF017o/>GF
2?l0000/oiZ`X@Co00002?oO`MX2o`0002Wo]WBb0ol00006omB^f1Go00001onNY8l3o`0001goY8nW
1?l00004oj^L^0Go00006on3WH`3o`0001So[6n:1_l0000TonOXj@;o0000HOooool00ol0003ooooo
ooooo`08ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1kooooo`;o00003?nHa;D3o`0000;oV<Be1Ol0000FoiS4]@Co0000
9_nBXY82o`00013ogj?I0ol0000>ok3UeP05o`000?n`iMKo/>GFok3Ue_l000001On`iMH00ol0003o
/>GFok3UeP0>ok3UePWo0000<?nJ/:44o`0000Gogl7J0ol0000ZokId/P?o00001?oD[]P9o`0001Go
WZB?0ol0000KojB?Y`Co00001on[W;P4o`0001_oPif<0_l0000Coja_RP[o00009OoWj>T2o`00067o
oooo00?o0000ooooooooool02?ooool000Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wo
oooo1Ol0001iooooo`;o00003OnHa;D00ol0003oV<BeoiS4]@02oiS4]@04o`000?nHa;GoV<Beo`00
01GoV<Be1_l0000Uoi:RTP;o00004?oOXmT2o`00013o/>GF0ol00004ok3UeP;o00003_n`iMH>o`00
01?oV[2Q0ol00003oiZ`X@?o00000_nJ/:45o`0000coV[2Q1?l00004omo1fP;o0000;?nfM;83o`00
00;oe:kH0ol0000MoijTS`?o00006?nTSjL4o`0000_oZibh1?l0000Ioh>MS0;o00003_n/KhX;o`00
00;o`j6T0ol0000TonOXj@;o0000GOooool5o`0000[ooooo0006ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1kooooo`;o00003OnHa;D0
0ol0003oV<BeoiS4]@03oiS4]@03o`000?nHa;GoV<Be01CoV<Be0ol000000om_VW[o0000o`000004
o`0002;oTZ:B0_l0000?omnSf@?o00003on`iMH01Ol0003o/>GFok3Ue_n`iMKo000000Go/>GF00?o
0000ok3Ue_n`iMH02?n`iMH7o`0000?oZkJO0_l00002onO[g`Co00004onJ/:401Ol0003oV[2QoiZ`
XOnJ/:7o000000?oV[2Q00Co0000oiZ`XOnJ/:7o00000_nJ/:400ol0003oV[2QoiZ`X@0<oiZ`X@Co
000000Cogl7Jo`000?l0003o00002OnfM;83o`0000?o]WBb0ol00004okId/P?o00005?nfM;86o`00
01ooWZB?0ol0000FojB?Y`Co00003On[W;P5o`00017oPif<2Ol00008oja_RP_o00002?o3XJ@2o`00
00_oinSY1Ol00002onOXj@?o00001?oWj>T2o`0000WoinSY0ol0001Pooooo`03o`000?oooooooooo
00Sooooo0007ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`1kooooo`;o00003OnHa;D00ol0003oV<BeoiS4]@04oiS4]@03o`000?nHa;GoV<Be
01;oV<Be0ol00002ofnJNPWo00007onBXY82o`0000oogj?I0_l0000@ok3UeP07o`000?n`iMKo/>GF
ok3Ue_l0003o/>GFo`000003ok3UeP03o`000?n`iMKo/>GF00Go/>GF1ol00005oj^fW`?o00000_oW
jml5o`0001;oV[2Q00?o0000oiZ`XOnJ/:401OnJ/:401Ol0003oV[2QoiZ`XOnJ/:7o0000017oV[2Q
1_l0000;okId/P05o`000?nfM;;o]WBbokId/_l000000onfM;800ol0003o]WBbokId/P02okId/P03
o`000?nfM;;o]WBb01Co]WBb1?l0000QoijTS`?o00005?nTSjL3o`00017oZibh1?l00005oh>MS1Go
00000_n/KhX;o`0000go`j6T0ol0000;onOXj@06o`000?oWj>WoinSYo`000?oWj>Wo00000ooWj>T0
1?l0003oinSYonOXjOl00002onOXj@03o`000?oWj>WoinSY00OoinSY0_l0001Pooooo`03o`000?oo
oooooooo00Sooooo0008ooooo`;o00000oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo07_ooooo0_l0000=oiS4]@05o`000?nHa;GoV<BeoiS4]Ol000000onHa;D00ol0003oV<Be
oiS4]@0?oiS4]@Co00000om_VWX2o`0000?o];_01ol0000Loi:RTP?o00003OoOXmT3o`00017o/>GF
0ol00003ok3UeP?o00001On`iMH7o`0000OoZkJO0ol00003onO[g`;o000000Coclboo`000?l0003o
00004OnJ/:400ol0003oV[2QoiZ`X@03oiZ`X@;o00001OnJ/:400ol0003oV[2QoiZ`X@0@oiZ`X@Co
00002onfM;801Ol0003o]WBbokId/_nfM;;o000000?o]WBb00?o0000okId/_l000001?l0000FokId
/P;o00008onNY8l4o`00013oY8nW1?l0000Doj^L^1?o00001onkWYL:o`0001?o`j6T0_l0000<onOX
j@03o`000?oWj>WoinSY00GoinSY00Co0000onOXjOoWj>Wo00000_oWj>T00ol0003oinSYonOXj@07
onOXj@;o0000H?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`02oooo
o`;o00002_ooool00ol0003oooooooooo`1kooooo`;o00003?nHa;D2o`0000?oV<Be00Go0000oiS4
]OnHa;GoV<Beo`00000@oiS4]@Co00001?m_VWX2o`0000Ko];_01ol0000Joi:RTP;o00003?oOXmT3
o`0001go/>GF1ol0000:oj^fW`;o00001?oWjml2o`0000;oclbo0ol0000@oiZ`X@03o`000?nJ/:7o
V[2Q00GoV[2Q00?o0000oiZ`XOl000000onJ/:400ol0003oV[2QoiZ`X@0@oiZ`X@;o00003?nfM;80
1?l0003o]WBbokId/_nfM;84o`0000;o]WBb00Co0000okId/_nfM;;o00005_nfM;83o`0002CoWZB?
1?l0000>ojB?Y`Co00005_n[W;P7o`0001?o^ijG1?l0000Hol>QY0?o00003?oWj>T00ol0003oinSY
onOXj@04onOXj@04o`000?oWj>WoinSYo`0000;oinSY00?o0000onOXjOoWj>T01ooWj>T2o`00063o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Noooool2o`0000goV<Be
00?o0000oiS4]OnHa;D00_nHa;D3o`00013oV<Be0ol00006ofnJNP;o00002Ond^l07o`0001OoTZ:B
0_l0000<omnSf@;o00006on`iMH7o`0000coZkJO0ol00004onO[g`;o00000oo?c;l4o`0000goV[2Q
0_l00003oiZ`X@07o`000?nJ/:7oV[2QoiZ`XOl0003oV[2Qo`000003oiZ`X@03o`000?nJ/:7oV[2Q
013oV[2Q0_l0000<okId/P05o`000?nfM;;o]WBbokId/_l000001_nfM;800ol0003o]WBbo`00000F
okId/P;o00009onNY8l3o`0000coY8nW0ol0000Hoj^L^0;o00006?nkWYL2o`0001_o`j6T0_l00009
onOXj@06o`000?oWj>WoinSYonOXjOl0003oinSY1?l00003onOXj@04o`000?oWj>WoinSYo`0000Wo
inSY0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07[ooooo
0ol0000ToiS4]@?o00001om_VWX2o`0000co];_01_l0000Doi:RTPGo00002OoOXmT3o`0001So/>GF
1ol0000?oj^fW`;o00001OoWjml2o`0000Coclbo1?l0000=oiZ`X@03o`000?nJ/:7oV[2Q00;oV[2Q
0ol00003oiZ`X@?o00004onJ/:43o`0000[o]WBb0_l00004okId/P03o`000?nfM;;o]WBb00Co]WBb
0_l0000FokId/P;o0000:?nNY8l3o`0000WoY8nW1?l0000Ioj^L^0;o00006?nkWYL2o`0001_o`j6T
0ol00008onOXj@07o`000?oWj>WoinSYonOXjOl0003oinSYo`000006onOXj@04o`000?oWj>WoinSY
o`0000WoinSY0ol0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
07[ooooo0_l0000ToiS4]@?o00002?m_VWX2o`0000oo];_01_l0000?oi:RTP_o00001OoOXmT2o`00
01Ko/>GF1ol0000Aoj^fW`?o00001OoWjml2o`0000Koclbo0ol0000^oiZ`X@;o00002onfM;800ol0
003o]WBbokId/P03okId/P;o00001OnfM;800ol0003o]WBbokId/P0CokId/P?o0000:OnNY8l3o`00
00OoY8nW1?l0000Ioj^L^0?o00006?nkWYL2o`0001co`j6T0_l00009onOXj@?o00000_oWj>T5o`00
00?oinSY0_l0000;onOXj@;o0000Goooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1jooooo`;o00008_nHa;D4o`0000WoKiYj0_l0000AokBk`0Oo00002_nBXY85o`0000?o
jK?T2?l000001?oOXmWo0000o`000?l0000Cok3UePOo00004on[]Yl3o`0000Koin_O0_l00007olo<
_`?o0000;OnJ/:42o`0002ko]WBb0_l0000[oijTS`?o00001?nTSjL4o`0001_oZibh0_l0000Iok^N
U`;o00007?o3XJ@3o`0002;oinSY0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo07[ooooo0_l0000QoiS4]@Co00002_m_VWX2o`0001Co];_01ol00005oi:RTPGo
00002OoY/n@7o`00017o/>GF1ol0000Foj^fW`;o00001ooWjml2o`0000Soclbo0ol0000/oiZ`X@;o
0000;_nfM;82o`0002coWZB?0ol00002ojB?Y`Co00007?n[W;P2o`0001Wo^ijG0_l0000Mol>QY0;o
00008_oWj>T2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
N_ooool2o`00023oV<Be0ol0000<ofnJNP;o00005ond^l0<o`0000kojK?T1Ol0000=ok3UePOo0000
6?n[]Yl3o`0000Ooin_O0_l00009olo<_`?o0000:onJ/:42o`0002go]WBb0ol0000]oijTS`Ko0000
2?n[W;P5o`000003oj^L^?l0003o000000?o00000on[W;P2o`0000KoZibh0_l0000Iok^NU`;o0000
7Oo3XJ@3o`00027oinSY0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07[ooooo0_l0000OoiS4]@?o00003Om_VWX2o`0001[o];_01ol0000ConVci0?o00002On`
iMH7o`0001_oZkJO0_l00008onO[g`;o00002_o?c;l4o`0002WoV[2Q0ol0000/okId/P;o00003?nN
Y8l5o`0000?oWZB?0_l00003oijTS`?o00004onNY8l4o`0000[oZibh00Co0000oj^L^?n[W;So0000
0_n[W;P01?l0003oZibhoj^L^?l00002oj^L^004o`000?n[W;SoZibho`0000GoZibh0_l0000Iok^N
U`;o00007_o3XJ@2o`00027oinSY0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo07[ooooo0_l0000MoiS4]@Co00003_m_VWX2o`0001go];_00_l0000FonVci0?o
00001On`iMH7o`0001goZkJO0ol00008onO[g`;o00002oo?c;l4o`0002WoV[2Q0_l0000/okId/P;o
00003OnNY8l01?l0003oWZB?oijTSol00002oijTS`04o`000?nNY8ooWZB?o`0000?oWZB?00?o0000
oijTSonNY8l04onNY8l2o`0000coZibh00?o0000oj^L^?n[W;P00on[W;P00ol0003oZibhoj^L^002
oj^L^004o`000?n[W;SoZibho`0000GoZibh0_l0000Iok^NU`;o00007_o3XJ@3o`00023oinSY0ol0
001Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07[ooooo0_l0000L
oiS4]@Co00003om_VWX2o`0001go];_00_l0000GonVci0?o000000?o/>GFo`000?l000001Ol0000O
oj^fW`?o00002OoWjml2o`0000goclbo0ol0000WoiZ`X@Co0000:_nfM;83o`0000koWZB?00?o0000
oijTSonNY8l00_nNY8l01?l0003oWZB?oijTSol00003oijTS`03o`000?nNY8ooWZB?01?oWZB?0_l0
000=oj^L^003o`000?n[W;SoZibh00?oZibh00Go0000oj^L^?n[W;SoZibho`000002oj^L^003o`00
0?n[W;SoZibh00;oZibh0ol0000Iok^NU`;o00007oo3XJ@2o`00027oinSY0_l0001Nooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07Wooooo1?l0000JoiS4]@?o00004Om_
VWX2o`0001co];_00ol0000HonVci0Oo00008_n[]Yl2o`0000[oin_O0_l0000>olo<_`?o00009?nJ
/:47o`0002Wo]WBb0_l0000@oijTS`05o`000?nNY8ooWZB?oijTSol000000_nNY8l01Ol0003oWZB?
oijTSonNY8oo000001GoWZB?0_l0000:oj^L^007o`000?n[W;SoZibhoj^L^?l0003oZibho`000003
oj^L^004o`000?n[W;SoZibho`0000;oZibh00?o0000oj^L^?n[W;P00_n[W;P2o`0001[o^ijG0_l0
000Ool>QY0?o00008?oWj>T2o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0Moooool7o`0001SoV<Be0ol000000om_VW[o0000o`000003o`000003ofnJN_l0003o
000000?o00001_m_VWX2o`0001co];_00_l0000JonVci0?o00009?n[]Yl3o`0000[oin_O0_l0000?
olo<_`?o00008OnJ/:45o`0000;oUHfL1?l0000WokId/P;o00003OnNY8l01Ol0003oWZB?oijTSonN
Y8oo000000;oWZB?00Co0000oijTSonNY8oo00000onNY8l00ol0003oWZB?oijTS`0CoijTS`;o0000
2_n[W;P01ol0003oZibhoj^L^?n[W;So0000oj^L^?l000000on[W;P01?l0003oZibhoj^L^?l00002
oj^L^003o`000?n[W;SoZibh00;oZibh0_l0000Jok^NU`;o00008?o3XJ@2o`00023oinSY0_l0001N
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07Gooooo1Ol00002ok6]
/`Co00005?nHa;D4o`0000?oKiYj00Co0000ofnJN_m_VW[o00000_m_VWX01?l0003oKiYjofnJN_l0
0006ofnJNP;o00007?nd^l02o`0001[ojK?T0_l0000Uoj^fW`;o00002ooWjml2o`00013oclbo1?l0
000MoiZ`X@Go00001OnESI`4o`0002Go]WBb0ol0000=oijTS`05o`000?nNY8ooWZB?oijTSol00000
0_nNY8l01?l0003oWZB?oijTSol00002oijTS`;o00005OnNY8l2o`0000_oZibh0ol00003oj^L^0?o
00001?n[W;P2o`0000GoZibh0_l0000Jok^NU`;o00008?o3XJ@2o`0001ooinSY0ol0001Nooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07?ooooo1Ol00005ok6]/`Co0000
4_nHa;D4o`0000GoKiYj00?o0000ofnJN_m_VWX00om_VWX00ol0003oKiYjofnJNP05ofnJNP?o0000
7?nd^l02o`0001[ojK?T0ol0000Soj^fW`?o00002ooWjml2o`00017oclbo1?l0000KoiZ`X@Co0000
2OnESI`4o`0002?o]WBb0_l0000?oijTS`?o00001?nNY8l2o`0000CoWZB?00?o0000oijTSonNY8l0
4onNY8l2o`0001ooZibh0_l00006ok^NU`Go000000?o^ijGo`000?l000000ol00002ok^NU`;o0000
1OnkWYL2o`00023o`j6T0ol0000NonOXj@;o0000Goooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1aooooo`Go00002Ona[K<4o`0000ooV<Be0ol00008ofnJNP03o`000?m_
VW[oKiYj00?oKiYj00?o0000ofnJN_m_VWX00om_VWX4o`0001_o];_00ol0000KonVci0;o00002?n[
]Yl3o`0000CoZkJO00?o0000oj^fWon[]Yl04?n[]Yl3o`0000coin_O0_l0000Colo<_`?o00006?nJ
/:44o`0000coUHfL1?l0000QokId/P?o0000<_nNY8l2o`0001ooZibh0_l00007ok^NU`04o`000?nk
WYOo^ijGo`0000;o^ijG00Co0000ok^NUonkWYOo00001?nkWYL00ol0003o^ijGok^NU`02ok^NU`;o
00008Oo3XJ@2o`0001koinSY0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo06oooooo1Ol0000<ok6]/`Co00003OnHa;D3o`0000KoKiYj00Oo0000ofnJN_m_VW[o
KiYjo`000?m_VW[o000000?oKiYj00Co0000ofnJN_m_VW[oKiYj1_l0000JokBk`0;o00007?oY/n@2
o`0000OoZkJO00Go0000oj^fWon[]YooZkJOo`000003oj^fW`03o`000?n[]YooZkJO013oZkJO0_l0
000=onO[g`;o00005?o?c;l3o`0001GoV[2Q1Ol0000?oiF=W0Co00007onfM;82o`0003?oWZB?0_l0
000Noj^L^0?o00002?nkWYL00ol0003o^ijGok^NU`03ok^NU`03o`000?nkWYOo^ijG00Go^ijG00Co
0000ok^NUonkWYOo^ijG0_l0000Qol>QY0?o00007?oWj>T3o`0005oooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0K_ooool4o`00013o/Jfc0ol0000;oiS4]@?o00001om_
VWX01ol0003oKiYjofnJN_m_VW[o0000ofnJN_l000000om_VWX00ol0003oKiYjofnJNP03o`0000;o
`jW=0_l0000JokBk`0;o00007?oY/n@3o`0000KoZkJO00Go0000oj^fWon[]YooZkJOo`000004oj^f
W`03o`000?n[]YooZkJO00koZkJO0ol0000=onO[g`;o00005Oo?c;l3o`0001;oV[2Q1Ol0000BoiF=
W0Co00007_nfM;82o`0003?oWZB?0_l0000Noj^L^0;o00002_nkWYL00ol0003o^ijGok^NU`03ok^N
U`04o`000?nkWYOo^ijGok^NU`Co00000onkWYL2o`0002;o`j6T0_l0000LonOXj@;o0000H?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1^ooooo`;o00004ona[K<4o`00
00OoV<Be1?l00009ofnJNP?o00000om_VWX3o`0000;oKiYj0ol00003ol>Yc@;o00006_nd^l02o`00
00[ojK?T0ol00003onVci0;o00002ooY/n@2o`0000OoZkJO0ol00005oj^fW`03o`000?n[]YooZkJO
00koZkJO0_l0000>onO[g`;o00005_o?c;l3o`0000ooV[2Q1Ol0000FoiF=W0Co00006onfM;83o`00
03?oWZB?0_l0000Noj^L^0;o00001onkWYL01ol0003o^ijGok^NUonkWYOo0000ok^NUol000000onk
WYL00ol0003o^ijGo`000003ok^NU`04o`000?nkWYOo^ijGok^NU`;o00008_o3XJ@3o`0001_oinSY
0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06gooooo0ol0
000Dok6]/`Co00001OnHa;D4o`0001CoKiYj0ol00004ol>Yc@;o00006Ond^l03o`0000WojK?T00Go
0000onVci?oY/nCojK?To`000004onVci003o`000?oY/nCojK?T00SojK?T0_l00006oj^fW`05o`00
0?n[]YooZkJOoj^fWol000001On[]Yl00ol0003oZkJOoj^fW`0<oj^fW`?o00003_oWjml2o`0000?o
clbo0ol00003olo<_`?o00001?o?c;l3o`0000Coclbo1?l0000;oiZ`X@Go00006OnESI`4o`0001[o
]WBb0_l0000doijTS`;o00007_n[W;P2o`0000Oo^ijG00Oo0000ok^NUonkWYOo^ijGo`000?nkWYOo
000000?o^ijG00?o0000ok^NUol000000onkWYL01?l0003o^ijGok^NUonkWYL2o`0002?o`j6T0_l0
000JonOXj@?o0000H?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1]
ooooo`;o00005ona[K<4o`0000;oV<Be0ol0000EofnJNP?o00001Oo3ZLd2o`0001Wo];_00_l0000>
onVci003o`000?oY/nCojK?T00?ojK?T00?o0000onVci?oY/n@01ooY/n@2o`0000KoZkJO00Oo0000
oj^fWon[]YooZkJOo`000?n[]Yoo000000?oZkJO00?o0000oj^fWon[]Yl02on[]Yl3o`0000ooin_O
0_l00004olo<_`03o`000?o?c;ooclbo00?oclbo00?o0000olo<_oo?c;l01?o?c;l00ol0003oclbo
olo<_`04olo<_`Co00002?nJ/:45o`0001goUHfL1?l0000HokId/P;o0000=?nNY8l2o`0001koZibh
0_l00008ok^NU`?o00000onkWYL3o`0000?o^ijG0ol00004ok^NU`;o00003?o3XJ@5o`0000?o`j6T
0ol000000oo3XJCo0000o`000003o`0000Ko`j6T0ol0000GonOXj@Co0000HOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1/ooooo`?o00006?na[K<7o`0001GoKiYj0ol0
0006ol>Yc@?o00006?nd^l02o`0000kojK?T00?o0000onVci?oY/n@01?l00009onVci0?o00001_n[
]Yl3o`0000;oZkJO1Ol0000=oj^fW`;o00004?oWjml2o`0000Coclbo00?o0000olo<_oo?c;l00oo?
c;l01?l0003oclboolo<_oo?c;l5o`0000Ooclbo0ol00006oiZ`X@Co00008?nESI`5o`0001Go]WBb
0ol0000doijTS`Co00007?n[W;P2o`0001_o^ijG0_l0000=ol>QY004o`000?o3XJCo`j6To`0000Co
`j6T00Go0000ol>QY?o3XJCo`j6To`000002ol>QY003o`000?o3XJCo`j6T00Go`j6T0_l0000ConOX
j@So0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1/ooooo`;o
00006ona[K<4o`0001GoKiYj0ol00008ol>Yc@;o00006?nd^l02o`0000[ojK?T1?l00002onVci005
o`000?oY/nCojK?TonVci?l000002_oY/n@2o`0001coZkJO1?l00004onO[g`;o00001?oWjml2o`00
00?oin_O0_l00004olo<_`03o`000?o?c;ooclbo00?oclbo00Go0000olo<_oo?c;ooclboo`000002
olo<_`03o`000?o?c;ooclbo00Ooclbo0ol00003oiZ`X@Co00009?nESI`4o`0001Co]WBb0_l0000e
oijTS`Oo00006?n[W;P3o`0001_o^ijG0_l0000>ol>QY004o`000?o3XJCo`j6Tol>QY0Go00000oo3
XJ@00ol0003o`j6Tol>QY007ol>QY0?o00003_oWj>T9o`000004ohjFYOl0003o0000o`00063ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0K?ooool2o`0001co/Jfc0_l0
000EofnJNP?o00002Oo3ZLd2o`0001Oo];_00ol0000:onVci003o`000?oY/nCojK?T00?ojK?T00Go
0000onVci?oY/nCojK?To`00000:onVci0;o00007?n[]Yl3o`0000Coin_O00Co0000onO[gooWjmoo
00000_oWjml01?l0003oin_OonO[gol00002onO[g`;o00001?o?c;l00ol0003oclboolo<_`03olo<
_`03o`000?o?c;ooclbo00;oclbo00?o0000olo<_ol000002_o?c;l8o`0002OoUHfL1?l0000BokId
/P;o0000=?nNY8l3o`000003oh>UY_l0003o000000Go00005On[W;P2o`0001co^ijG0_l0000?ol>Q
Y004o`000?o3XJCo`j6To`0000;o`j6T00?o0000ol>QY?o3XJ@00oo3XJ@00ol0003o`j6Tol>QY007
ol>QY0;o00002_oWj>T9o`0000KoSYJU0ol0001Oooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo06_ooooo0ol0000Lok6]/`?o00004om_VWX3o`0000[o`jW=0_l00006okBk
`0?o00001?nd^l000ol0003o];_0okBk`007okBk`0;o00002ooY/n@5o`0000;ojK?T0ol0000;onVc
i0?o00006_n[]Yl4o`0000Coin_O00Co0000onO[gooWjmoo00000_oWjml01?l0003oin_OonO[gol0
0002onO[g`;o00000oo?c;l2o`0000Coclbo0_l00005olo<_`;o00002oo?c;l5o`0002[oUHfL1?l0
000@okId/P?o0000<onNY8l3o`0000GoPjFV2?l0000Aoj^L^0;o00007?nkWYL2o`0000co`j6T00Go
0000ol>QY?o3XJCo`j6To`000002ol>QY003o`000?o3XJCo000000;o`j6T00Go0000ol>QY?o3XJCo
`j6To`000008ol>QY0?o00001OoWj>T9o`0000_oSYJU0ol0001Nooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06_ooooo0_l0000Nok6]/`;o00004_m_VWX3o`0000_o`jW=
0_l00005okBk`005o`000?nd^l3o];_0okBk`?l000000ond^l000ol0003o];_0okBk`007okBk`0;o
00008?oY/n@3o`0001WoZkJO0ol000000ooWjmoo0000onO[g`03onO[g`04o`000?oWjmooin_Oo`00
00;oin_O00Co0000onO[gooWjmoo00000_oWjml2o`0000Coclbo00?o0000olo<_oo?c;l00oo?c;l0
0ol0003oclboolo<_`04olo<_`03o`000?o?c;ooclbo00[oclbo0_l0000^oiF=W0Co00003_nfM;82
o`0003?oWZB?0ol00009oh>UYPSo00003_n[W;P2o`0001co^ijG0_l0000<ol>QY005o`000?o3XJCo
`j6Tol>QY?l000000oo3XJ@2o`0000;o`j6T00Go0000ol>QY?o3XJCo`j6To`000009ol>QY0;o0000
00?oinSYo`000?l000001ol0000@ohjFY@?o0000GOooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Zooooo`?o00007_na[K<2o`00017oKiYj0ol0000<ol>Yc@?o00002?nd
^l000ol0003o];_0okBk`002okBk`003o`000?nd^l3o];_000Go];_00ol0000OonVci0Go00006?n[
]Yl2o`0000;oin_O00?o0000onO[gooWjml00_oWjml01?l0003oin_OonO[gol00002onO[g`04o`00
0?oWjmooin_Oo`0000;oin_O0_l0000Nolo<_`;o0000;onESI`4o`0000go]WBb0_l0000coijTS`;o
00003_n3YJH7o`0000_oZibh0_l0000Lok^NU`;o00003Oo3XJ@3o`0000Go`j6T00Co0000ol>QY?o3
XJCo`j6T0ol0000:ol>QY0So00005On>UZD3o`0005cooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0J_ooool2o`0001oo/Jfc0ol0000?ofnJNP?o00003_o3ZLd2o`0000Ko
];_00_l00005okBk`003o`000?nd^l3o];_000Go];_00_l0000OonVci0?o000000CoZ^nXo`000?l0
003o00005_n[]Yl3o`000003onO[gol0003o000000Coin_O00Co0000onO[gooWjmoo00000_oWjml0
1?l0003oin_OonO[gol00002onO[g`;o00007_o?c;l2o`00037oUHfL1?l00009okId/PGo0000<OnN
Y8l3o`00017oPjFV2?l00007oj^L^0;o00007?nkWYL2o`0002Oo`j6T0ol0000JohjFY@?o0000Fooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`?o00008?na[K<2
o`0000koKiYj0ol0000?ol>Yc@;o00002?nd^l000ol0003o];_0okBk`003okBk`003o`000?nd^l3o
];_000Co];_00_l0000MonVci0Co00000onZkjP3o`0001GoZkJO0_l00003onO[g`03o`000?oWjmoo
in_O00?oin_O0_l00004onO[g`;o00000ooWjml2o`0001goclbo0ol0000boiF=W0Co00001_nfM;8:
o`0002goWZB?0ol0000Eoh>UYPSo00000on[W;P3o`0001co^ijG0_l0000Vol>QY0?o00007?n>UZD3
o`0005[ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool2o`00
027o/Jfc0ol0000<ofnJNP?o00004?o3ZLd2o`0000Co];_000Oo0000okBk`?nd^l3o];_0o`000?nd
^l3o000000?o];_000?o0000okBk`?nd^l001?nd^l02o`0001cojK?T1?l00005oj[_Z0?o00004on[
]Yl3o`0001Coin_O0_l0000Molo<_`;o0000=OnESI`4o`0000?o]WBb1?l00003omcki@Oo0000:OnN
Y8l3o`0001[oPjFV2Ol0000Mok^NU`;o00009Oo3XJ@3o`0001koSYJU0ol0001Iooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`?o0000J?ooool3o`0002;o/Jfc0_l0000;ofnJNP?o00004Oo3ZLd2
o`0000Go];_00ol00002okBk`0Go00001Ond^l03o`0001_ojK?T0ol00008oj[_Z0?o00004On[]Yl3
o`0001Goin_O0_l0000Molo<_`;o0000=_nESI`8o`0000Sog?_U1ol0000VoijTS`;o00007_n3YJH6
o`0001go^ijG0_l0000Uol>QY0;o00008?n>UZD3o`0005Kooooo0ol0000:ooooo`006_ooool00ol0
003oooooooooo`1Xooooo`;o00008ona[K<3o`0000WoKiYj0ol00002ol>Yc@Go00000oo3ZLd3o`00
00Go`jW=0ol0000CokBk`0;o00006ooY/n@3o`0000[oZ^nX0ol0000@oj^fW`;o00005_oWjml2o`00
01goclbo0_l0000hoiF=W0Go00003?oLnnD7o`0002;oWZB?0ol0000Qoh>UYP?o00007?nkWYL5o`00
027o`j6T1?l0000QohjFY@?o0000Eoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Wooooo`?o00003_na[K<3o`0001?o/Jfc0_l00008ofnJNP?o00001?o3ZLd01?l0003o
`jW=ol>YcOl00004ol>Yc@03o`000?o3ZLgo`jW=00Go`jW=0_l0000CokBk`0;o00006OoY/n@4o`00
00coZ^nX0ol0000>oj^fW`?o00005_oWjml2o`0001goclbo0_l0000ioiF=W0;o00004OoLnnD7o`00
01koWZB?0ol0000Soh>UYP?o00006_nkWYL;o`0001Wo`j6T1_l0000SohjFY@?o0000E_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Wooooo`;o00003_na[K<01Ol0003o
/Jfcok6]/ona[K?o000001;o/Jfc0_l00007ofnJNP?o00001_o3ZLd01?l0003o`jW=ol>YcOo3ZLd5
o`0000Ko`jW=0_l0000CokBk`0;o00006?oY/n@4o`0000koZ^nX0ol0000=oj^fW`;o00005ooWjml2
o`0001coclbo0ol0000hoiF=W0?o00005?oLnnD7o`0001[oWZB?0ol0000Uoh>UYP?o00006?nkWYL3
o`0000?ofm6S2ol0000Aol>QY0[o00008on>UZD2o`0005Kooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Ioooool2o`0000ko/Jfc00Go0000ok6]/ona[K?o/Jfco`00000B
ok6]/`Co00001?m_VWX3o`0000So`jW=00Co0000ol>YcOo3ZLgo00000_o3ZLd00ol0003o`jW=ol>Y
c@05ol>Yc@;o00004_nd^l03o`0001OojK?T0ol0000Aoj[_Z0?o00002on[]Yl3o`0001Ooin_O0_l0
000Lolo<_`;o00004onESI`3o`0000CoUHfL0ol00002oiF=W0?o00005onESI`2o`0001Sog?_U1ol0
000GoijTS`;o00009on3YJH3o`0001Go^ijG1?l00009om_AX`_o00002Oo3XJ@7o`0000Co]jg90_l0
000SohjFY@;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1V
ooooo`?o00003_na[K<4o`0001;o/Jfc1_l00002ofnJNP?o00001_o3ZLd01Ol0003o`jW=ol>YcOo3
ZLgo000000;o`jW=00?o0000ol>YcOl000001oo3ZLd2o`0001;o];_00_l0000FonVci0Co00004onZ
kjP3o`0000WoZkJO0ol0000HonO[g`;o00007?o?c;l2o`0001CoUHfL00?o0000oiF=W?nESI`01?nE
SI`01?l0003oUHfLoiF=W?l00003oiF=W003o`000?nESIcoUHfL01CoUHfL0_l0000Komcki@Oo0000
4onNY8l3o`0002SoPjFV2?l0000>ok^NU`Co00003ooKdJ<;o`000003ol>QY?l0003o000000Go0000
1ong[LT3o`0002;oSYJU0_l0001Fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo06Kooooo0_l0000?ok6]/`03o`000?na[K?o/Jfc01;o/Jfc0ol00002oiMa]PKo00001oo3
ZLd01Ol0003o`jW=ol>YcOo3ZLgo000000?o`jW=0_l00007ol>Yc@?o00004Ond^l02o`0001GojK?T
1?l0000Eoj[_Z0?o00002?n[]Yl2o`0001Woin_O0_l0000Lolo<_`;o00005?nESI`01?l0003oUHfL
oiF=W?nESI`5o`0000GoUHfL00?o0000oiF=W?nESI`04onESI`3o`0001kog?_U1ol0000?oijTS`?o
0000:_n3YJH@o`0000Co^ijG0ol0000Fom_AX`_o00002ong[LT2o`0002;oSYJU0ol0001Eooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Gooooo0ol0000@ok6]/`03o`00
0?na[K?o/Jfc00oo/Jfc1?l00004oiMa]PCo00002Oo3ZLd3o`0000Go`jW=00?o0000ol>YcOo3ZLd0
1_o3ZLd2o`00017o];_00_l0000DonVci0?o00006?nZkjP3o`0000KoZkJO0ol0000IonO[g`;o0000
7?o?c;l2o`0001CoUHfL00Go0000oiF=W?nESIcoUHfLo`000002oiF=W003o`000?nESIcoUHfL00Co
UHfL00?o0000oiF=W?nESI`04onESI`2o`0002;og?_U1ol0000;oijTS`?o0000:_n3YJH3o`0000Co
PZjd4?l0000Lom_AX`?o00003_ng[LT2o`0002?oSYJU0_l0001Eooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06Gooooo0_l0000Bok6]/`;o00003_na[K<4o`0000KoUg6f
8?l0000?okBk`0?o00004ooY/n@3o`0001[oZ^nX0ol00005oj^fW`;o00006_oWjml2o`0001_oclbo
0ol0000DoiF=W003o`000?nESIcoUHfL00;oUHfL00?o0000oiF=W?l000000_nESI`4o`0001KoUHfL
0_l0000Uomcki@Oo00002?nNY8l2o`0002_oPjFV0_l0000>oh:^]0Ko00007_oKdJ<2o`0000ko]jg9
0ol00007ohjFY@Go00000_n>UZD3o`0000;oSYJU1Ol0000:ohjFY@;o0000EOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Uooooo`;o00008Ona[K<3o`0000WoUg6f8?l0
000>okBk`0;o00004_oY/n@4o`0001coZ^nX0ol00003oj^fW`?o00006_oWjml2o`0001_oclbo0_l0
000DoiF=W0;o00001OnESI`2o`0000;oUHfL00?o0000oiF=W?nESI`05_nESI`3o`0002Sog?_U1ol0
0004oijTS`?o0000:_n3YJH3o`0001;oPZjd0_l0000Nom_AX`;o00003ong[LT2o`0000SoSYJU00Ko
0000ohjFYOn>UZGo0000ohjFYOl00003ohjFY@04o`000?n>UZGoSYJUo`0000;oSYJU00?o0000ohjF
YOn>UZD02?n>UZD2o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0IOooool2o`00023o/Jfc0ol0000:oiMa]P;o00007?oKgZ/4o`0000co];_00_l0000AonVci0Co
00007_nZkjP3o`000004oj^fWol0003o0000o`0001_oin_O0_l0000Iolo<_`Co00005OnESI`00ol0
003oUHfLoiF=W004oiF=W003o`000?nESIcoUHfL00Go00005?nESI`2o`0002cog?_U2_l0000Zoh>U
YP?o00004on2[[@2o`0001kofm6S0_l0000?okN]b@?o00002?n>UZD00ol0003oSYJUohjFY@05ohjF
Y@05o`000?n>UZGoSYJUohjFYOl000003?n>UZD2o`0005Gooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0IOooool2o`0001ko/Jfc1?l0000;oiMa]P;o00007OoKgZ/4o`00
00_o];_00_l0000@onVci0?o00008OnZkjP5o`0001coin_O0_l0000Eolo<_`So0000>?nESI`2o`00
02oog?_U1_l0000[oh>UYP;o00005?n2[[@2o`0001gofm6S0ol0000@okN]b@;o00002On>UZD00ol0
003oSYJUohjFY@04ohjFY@03o`000?n>UZGoSYJU00;oSYJU00?o0000ohjFYOn>UZD02On>UZD2o`00
05Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool2o`0001go
/Jfc1?l0000<oiMa]P;o00007ooKgZ/4o`0000So];_00ol0000>onVci0Co00008onZkjP4o`0001co
in_O0_l0000Aolo<_`Wo000000Co^jSLo`000?l0003o0000=_nESI`3o`0003;og?_U0_l0000[oh>U
YP?o00005?n2[[@3o`0001cofm6S0_l0000AokN]b@?o00001On>UZD01_l0003oSYJUohjFYOn>UZGo
0000ohjFY@Co00000_n>UZD01Ol0003oSYJUohjFYOn>UZGo000000[oSYJU0ol0001Dooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Gooooo0ol0000Kok6]/`?o00003_nG
LKH3o`0000gofmj[1Ol00002om_NZ`?o00002?oKgZ/4o`0000?o];_01ol0000=onVci0Co00009OnZ
kjP2o`0001goin_O0_l0000<olo<_`[o00001_nkZ=`3o`0003GoUHfL0_l0000comcki@?o00002on3
YJH5o`0000;oPjFV0ol00003oh>UYP?o00003on3YJH2o`0001KoPZjd0_l0000Lom_AX`;o00004_ng
[LT2o`0000GoSYJU00Oo0000ohjFYOn>UZGoSYJUo`000?n>UZGo000000GoSYJU00Go0000ohjFYOn>
UZGoSYJUo`00000;ohjFY@;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Vooooo`;o00006Ona[K<4o`00013oUg6f0_l0000>om_NZ`06o`000?oKgZ_ofmj[o`00
0?oKgZ_o00000ooKgZ/00ol0003ofmj[om_NZ`07om_NZ`go00002ooY/n@3o`0002OoZ^nX0ol0000L
onO[g`;o00002?o?c;l:o`0000_o^jSL0ol0000doiF=W0;o0000=?oLnnD2o`0000coPjFV00Co0000
oh>UY_n3YJKo00000on3YJH01Ol0003oPjFVoh>UY_n3YJKo000000?oPjFV00?o0000oh>UY_n3YJH0
2on3YJH3o`0001KoPZjd0_l0000Lom_AX`;o00004_ng[LT2o`0000KoSYJU0ol00002ohjFY@Go0000
0_n>UZD3o`0000coSYJU0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo06Kooooo0_l0000Hok6]/`Co00004OnGLKH2o`0000oofmj[00?o0000om_NZooKgZ/01OoK
gZ/00ol0003ofmj[om_NZ`08om_NZ`Go00001On=/h/4o`0000SojK?T0ol0000Yoj[_Z0;o00007?oW
jml2o`0000Coclbo2Ol0000Aok^Xg0;o0000<onESI`3o`0003Cog?_U0_l0000=oh>UYP03o`000?n3
YJKoPjFV00?oPjFV00Go0000oh>UY_n3YJKoPjFVo`000003oh>UYP03o`000?n3YJKoPjFV00[oPjFV
0ol0000Goh:^]0;o00007?oKdJ<2o`0001;o]jg90ol0000PohjFY@;o0000E?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Vooooo`;o00005ona[K<3o`0001?oUg6f0_l0
000@om_NZ`03o`000?oKgZ_ofmj[00Cofmj[00?o0000om_NZooKgZ/01ooKgZ/3o`0000WoSK>;1?l0
0005onVci0Co0000:_nZkjP2o`0001coin_O2ol0000Eok^Xg0?o0000<_nESI`2o`0003Gog?_U0ol0
000=oh>UYP03o`000?n3YJKoPjFV00;oPjFV00?o0000oh>UY_n3YJH00_n3YJH3o`0000goPjFV0_l0
000Hoh:^]0;o00007?oKdJ<2o`0001?o]jg90_l0000PohjFY@;o0000E?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1Vooooo`;o00005_na[K<3o`0001CoUg6f0_l0000=
om_NZ`06o`000?oKgZ_ofmj[om_NZol0003ofmj[1?l00009om_NZ`?o00003?n=/h/4o`0000;ojK?T
1?l0000[oj[_Z0Ko00005ooWjml8o`0001[o^jSL0ol0000aoiF=W0;o0000=_oLnnD2o`0000[oPjFV
00Go0000oh>UY_n3YJKoPjFVo`000003oh>UYP05o`000?n3YJKoPjFVoh>UY_l000000on3YJH00ol0
003oPjFVoh>UYP09oh>UYP?o00006?n2[[@2o`0000Gofm6S1Ol00003om_AX`?o00000ooKdJ<2o`00
00Oofm6S0_l0000CokN]b@?o00007on>UZD2o`0005Cooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0IOooool4o`0001?o/Jfc1?l0000;oiMa]P?o00000onGLKH3o`000003
oiMa]_l0003o000000gofmj[00Oo0000om_NZooKgZ_ofmj[o`000?oKgZ_o000000_ofmj[0ol0000>
ohfcR`Oo0000;_nZkjP;o`00013oin_O1Ol0000Ook^Xg0Go0000;OnESI`3o`0003Kog?_U0_l0000:
oh>UYP05o`000?n3YJKoPjFVoh>UY_l000000_n3YJH2o`0000?oPjFV00Go0000oh>UY_n3YJKoPjFV
o`00000;oh>UYP;o00006On2[[@2o`0000Kofm6S00Co0000om_AXooKdJ?o00001?oKdJ<01Ol0003o
fm6Som_AXooKdJ?o000000;ofm6S00?o0000om_AXooKdJ<01?oKdJ<2o`0001Co]jg90_l0000OohjF
Y@;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Tooooo`So
00003ona[K<4o`0000goUg6f00?o0000oiMa]_nGLKH00onGLKH00ol0003oUg6foiMa]P02o`0000ko
fmj[0ol00002om_NZ`Go00001ooKgZ/2o`00017oSK>;1?l0000^oj[_Z0?o00000_njXj4=o`0000Wo
in_O0ol0000Sok^Xg0So0000:?nESI`3o`0001Gog?_U0ol00003omcki@?o00000ooLnnD3o`0001?o
g?_U0ol0000:oh>UYP?o00001?n3YJH00ol0003oPjFVoh>UYP02oh>UYP?o00002on3YJH3o`0001Wo
PZjd0ol00006om_AX`04o`000?oKdJ?ofm6Som_AX`Go00000_oKdJ<01?l0003ofm6Som_AXol00005
om_AX`?o00005?ng[LT3o`0001koSYJU0ol0001Cooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo06?ooooo0ol00002ojg4a0Ko00003?na[K<3o`0000ooUg6f00?o0000oiMa
]_nGLKH00onGLKH00ol0003oUg6foiMa]P02o`0001kofmj[0ol0000BohfcR`;o00005onZkjP3o`00
00?oZ^nX0ol0000>oj[_Z0?o00002OnjXj4=o`0000;oin_O0ol0000Tok^Xg0;o000000?o^YnTo`00
0?l000001ol0000RoiF=W0Go00005_oLnnD01Ol0003og?_UomckiOoLnnGo000000?og?_U00?o0000
omckiOl000000ooLnnD00ol0003og?_Uomcki@0Aomcki@;o00008on3YJH3o`0001_oPZjd0_l00007
om_AX`04o`000?oKdJ?ofm6So`0000;ofm6S00Go0000om_AXooKdJ?ofm6So`000002om_AX`03o`00
0?oKdJ?ofm6S00?ofm6S0_l0000FokN]b@;o00007on>UZD2o`0005?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0HOooool4o`0000Ko[LC44Ol0000@oiMa]P03o`000?nG
LKKoUg6f00?oUg6f00?o0000oiMa]_nGLKH00_l0000Mom_NZ`?o00004on=/h/3o`0001GoZ^nX00Oo
0000oj[_Z?nZkjSoZ^nXo`000?nZkjSo000000?oZ^nX00?o0000oj[_Z?nZkjP02_nZkjP3o`00013o
^Z>Q2ol0000Tok^Xg0?o00001OnjWj@9o`0001coUHfL2?l0000Eomcki@05o`000?oLnnGog?_Uomck
iOl000000ooLnnD00ol0003og?_Uo`000003omcki@03o`000?oLnnGog?_U017og?_U0ol0000Roh>U
YP;o00007?n2[[@2o`0000Cofm6S00Go0000om_AXooKdJ?ofm6So`000002om_AX`03o`000?oKdJ?o
000000?ofm6S00Co0000om_AXooKdJ?o00001OoKdJ<2o`0001Ko]jg90ol0000NohjFY@;o0000Dooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Pooooo`Co00002On]a<@>
o`00017oUg6f00?o0000oiMa]_nGLKH00onGLKH00ol0003oUg6foiMa]P03o`0001cofmj[0_l0000E
ohfcR`;o00005OnZkjP01Ol0003oZ^nXoj[_Z?nZkjSo000000GoZ^nX00?o0000oj[_Z?nZkjP02_nZ
kjP2o`0001Oo^Z>Q1?l0000Uok^Xg0;o00002_njWj@:o`0001CoUHfL1_l00003ol2OaP;o00005OoL
nnD00ol0003og?_Uomcki@02omcki@?o00000ooLnnD3o`0001Gog?_U0_l0000Qoh>UYP?o00007?n2
[[@2o`0000Cofm6S00Go0000om_AXooKdJ?ofm6So`000003om_AX`;o00000ooKdJ<01?l0003ofm6S
om_AXol00004om_AX`?o00005ong[LT2o`0001koSYJU0_l0001Cooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo05oooooo0ol0000;ojg4a0;o00002_nMWk@3o`0000ooUg6f
0_l00004oiMa]P;o00000onGLKH2o`0001_ofmj[0ol0000EohfcR`?o00005?nZkjP4o`0000KoZ^nX
00?o0000oj[_Z?nZkjP02OnZkjP3o`0001Wo^Z>Q0ol0000Tok^Xg0;o00003_njWj@:o`0000koUHfL
1_l00005ol2OaP?o00005?oLnnD01Ol0003og?_UomckiOoLnnGo000000?og?_U00?o0000omckiOl0
00000ooLnnD00ol0003og?_Uomcki@0Bomcki@;o00008On3YJH2o`0001goPZjd0_l00005om_AX`?o
00001OoKdJ<00ol0003ofm6Som_AX`02om_AX`;o00001?oKdJ<4o`0001Oo]jg90_l0000MohjFY@?o
0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Nooooo`?o0000
3?n]a<@3o`0000[oWInd0ol0000?oiMa]P03o`000?nGLKKoUg6f00?oUg6f00Co0000oiMa]_nGLKKo
Ug6f0_l0000Jom_NZ`?o00005on=/h/3o`0001?oZ^nX00?o0000oj[_Z?nZkjP00onZkjP4o`0000_o
Z^nX0ol0000KokZSX@;o00008onkZ=`3o`0001?o^YnT2Ol00008oiF=W0Go00002Oo0WlH2o`0001?o
g?_U0_l00003omcki@07o`000?oLnnGog?_UomckiOl0003og?_Uo`000003omcki@03o`000?oLnnGo
g?_U01;og?_U0ol0000Ooh>UYP?o00007On2[[@2o`0001Kofm6S3?l00003okN]b@?o00000ong[LT0
0ol0003o]jg9okN]b@05okN]b@?o00007?n>UZD2o`0005Cooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0GOooool3o`0000ko[LC40_l0000;oifO]0?o00006?nGLKHNo`00
01WoSK>;0_l0000Doj[_Z003o`000?nZkjSoZ^nX00;oZ^nX00?o0000oj[_Z?nZkjP02onZkjP3o`00
01co^Z>Q0_l00007ok^Xg0?o00000_nkZ=`5o`0000?o^jSL0ol0000<ok^Xg0;o00006?njWj@9o`00
00;oUHfL1Ol0000;ol2OaP?o00004ooLnnD00ol0003og?_Uomcki@02omcki@?o00000ooLnnD3o`00
01Kog?_U0_l0000Noh>UYP?o00007_n2[[@2o`0001Gofm6S1?l00002om?ReP;o000000Go]jg9o`00
0?ng[LWo]jg9o`000004okN]b@03o`000?ng[LWo]jg900;o]jg900?o0000okN]bOng[LT01_ng[LT2
o`0001_oSYJU0ol0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
05gooooo0_l0000?ojg4a0;o00003?nMWk@2o`0001SoUg6f7Ol0000JohfcR`?o00005?nZkjP2o`00
00;oZ^nX1Ol00008oj[_Z0?o00007OnjXj43o`0000Oo^jSL00?o0000ok^Xg?nkZ=`00_nkZ=`01?l0
003o^jSLok^Xg?l00004ok^Xg003o`000?nkZ=co^jSL00_o^jSL0_l0000LokZOY0[o00003_o0WlH2
o`0003Oog?_U0_l0000Noh>UYP;o00007on2[[@3o`0001;ofm6S1?l00004om?ReP?o000000?o]jg9
o`000?ng[LT00_ng[LT5o`0000Co]jg900?o0000okN]bOng[LT01Ong[LT3o`0001WoSYJU0ol0001E
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05cooooo0ol0000?ojg4
a0;o00003?nMWk@3o`0001OoUg6f0_l0000IokSI[P;o00006on=/h/2o`0002GoZ^nX0_l0000OokZS
X@;o00001onkZ=`00ol0003o^jSLok^Xg003ok^Xg004o`000?nkZ=co^jSLok^Xg0Go00003?nkZ=`2
o`00023o^YnT1_l0000>ol2OaP?o0000=_oLnnD3o`0001coPjFV0ol0000Poh:^]0;o00004OoKdJ<4
o`0000Kodn;F0_l00002okN]b@04o`000?ng[LWo]jg9o`0000;o]jg900?o0000okN]bOng[LT00ong
[LT00ol0003o]jg9okN]b@06okN]b@;o00006On>UZD2o`0005Kooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0G?ooool2o`00013o[LC40ol0000<oifO]0?o00005_nGLKH2
o`0001So^=V^0ol0000KohfcR`?o00008onZkjP3o`0001oo^Z>Q0_l00007ok^Xg003o`000?nkZ=co
^jSL00Co^jSL00Co0000ok^Xg?nkZ=co00000_nkZ=`00ol0003o^jSLok^Xg00:ok^Xg0?o00008?nj
Wj@3o`000003ol7YZOl0003o000000oo`9o60ol0000fomcki@;o00007?n3YJH2o`00027oPZjd0_l0
000?om_AX`Co00002?oCh]H3o`0000;o]jg900Ko0000okN]bOng[LWo0000okN]bOl00006okN]b@03
o`000?ng[LWo]jg900Go]jg90ol0000GohjFY@?o0000E_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1Kooooo`?o00004On]a<@2o`0000goWInd0ol0000EoiMa]P;o0000
6?nhfJh2o`0001goSK>;0_l0000Roj[_Z0?o00008?njXj43o`0000Ko^jSL00Go0000ok^Xg?nkZ=co
^jSLo`000003ok^Xg006o`000?nkZ=co^jSLo`000?nkZ=co00003?nkZ=`2o`00023o^YnT0ol00002
ol7YZ@;o00004?o0WlH2o`0003Kog?_U0ol0000Joh>UYP?o00008On2[[@2o`0000gofm6S1Ol0000:
om?ReP;o00000_ng[LT01?l0003o]jg9okN]bOng[LT2o`0000;o]jg900Go0000okN]bOng[LWo]jg9
o`000008okN]b@;o00005on>UZD2o`0005Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Foooool2o`0001;o[LC40_l0000>oifO]0?o00004onGLKH3o`0001So^=V^0_l0
000MohfcR`?o00007_nZkjP5o`0002;o^Z>Q0_l00005ok^Xg0;o00000onkZ=`01Ol0003o^jSLok^X
g?nkZ=co000000?o^jSL0_l0000<ok^Xg0;o00008?njWj@2o`0000?o`NVY0_l0000@ol2OaP?o0000
=_oLnnD2o`0001[oPjFV0_l0000Roh:^]0;o00003?oKdJ<4o`0000codn;F1?l00005okN]b@03o`00
0?ng[LWo]jg900Go00002?ng[LT2o`0001KoSYJU0ol0001Gooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05_ooooo0_l0000Bojg4a0;o00003onMWk@2o`0001?oUg6f0_l0
000HokSI[P?o00001On=/h/3o`0000?oSK>;0_l0000AohfcR`;o00006OnZkjP9o`0002?o^Z>Q0_l0
0006ok^Xg003o`000?nkZ=co^jSL00;o^jSL0ol00005ok^Xg003o`000?nkZ=co^jSL00Wo^jSL0ol0
000OokZOY0?o00000oo1jJT2o`00017o`9o60_l0000fomcki@;o00006On3YJH3o`0002;oPZjd0_l0
000:om_AX`Co00003ooCh]H2o`0001Ko]jg90ol0000DohjFY@?o0000F?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`?o00004_n]a<@2o`0000ooWInd0ol0000B
oiMa]P;o00006?nhfJh2o`0000GoSK>;00Go0000ohfcRon=/h_oSK>;o`000004ohfcR`03o`000?n=
/h_oSK>;00koSK>;0ol0000Coj[_Z0_o000000CoMYZlo`000?l0003o00008_njXj43o`0001ko^jSL
0_l0000OokZOY0?o00001?o1jJT2o`00017o`9o60ol0000eomcki@?o00005on3YJH3o`0000OoPZjd
1Ol000000on2[[Co0000o`000003o`0000;oPZjd0ol0000<oh:^]0;o00002OoKdJ<4o`00013odn;F
0ol0000FokN]b@;o00005?n>UZD2o`0005Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0F_ooool2o`0001?o[LC40ol0000?oifO]0?o00004OnGLKH2o`0001So^=V^0_l0
0009ohfcR`03o`000?n=/h_oSK>;00?oSK>;00?o0000ohfcRon=/h/03_n=/h/3o`0000koZ^nX2_l0
0007ogJJ_0;o00008onjXj42o`0001ko^jSL0_l0000OokZOY0;o00001Oo1jJT2o`0001;o`9o60_l0
000fomcki@;o00005on3YJH2o`0000WoPZjd00Co0000oh:^]?n2[[Co00000_n2[[@01_l0003oPZjd
oh:^]?l0003oPZjdo`0000?oPZjd00?o0000oh:^]?n2[[@02On2[[@3o`0000Kofm6S1?l00002om?R
ePGo00000ooCh]H3o`0000;odn;F0ol000000ooCh]Ko0000o`00000FokN]bASo0000FOooool00ol0
003oooooooooo`08ooooo`006_ooool3o`0005Wooooo0ol0000Dojg4a0;o00004?nMWk@3o`00013o
Ug6f0_l0000GokSI[P?o00001on=/h/2o`0000?oSK>;1?l0000AohfcR`;o00002OnZkjP:o`0000co
MYZl0_l0000SokZSX@;o00007_nkZ=`2o`0000Oo^YnT0ol00004okZOY0?o00000onjWj@2o`0000So
^YnT0ol00005ol7YZ@;o00004_o0WlH3o`0003Gog?_U0_l0000Foh>UYP?o00002_n2[[@00ol0003o
PZjdoh:^]003oh:^]005o`000?n2[[CoPZjdoh:^]?l000000on2[[@00ol0003oPZjdoh:^]00:oh:^
]0;o00001OoKdJ<4o`0000Codn;F00Co0000om?Re_oCh]Ko00001?oCh]H01?l0003odn;Fom?Re_l0
0003om?RePCo00005Ong[LTGo`0005Sooooo0ol0000:ooooo`006_ooool00ol0003oooooooooo`1I
ooooo`;o00005On]a<@2o`00017oWInd0_l0000@oiMa]P;o00000_nhfJh5o`0000;o^=V^0ol0000;
okSI[P;o00002_n=/h/00ol0003oSK>;o`000003ohfcR`03o`000?n=/h_oSK>;00ooSK>;1Ol00000
0onZkjSo0000o`000009o`00013oMYZl0ol0000RokZSX@?o00007?nkZ=`3o`0000So^YnT00?o0000
okZOY?njWj@01?njWj@01Ol0003o^YnTokZOY?njWjCo000000;o^YnT00?o0000okZOY?njWj@01?nj
Wj@3o`0000Ko`NVY0_l0000Col2OaP;o0000=OoLnnD4o`0001CoPjFV0_l0000<oh:^]003o`000?n2
[[CoPZjd00?oPZjd00Co0000oh:^]?n2[[CoPZjd0ol0000=oh:^]0;o00000ooKdJ<4o`0000Oodn;F
00Co0000om?Re_oCh]Kodn;F1Ol00005om?ReP04o`000?oCh]Ko0000o`0001Co]jg90ol0000CohVK
SP?o0000FOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Hooooo`?o
00005On]a<@2o`00017oWInd0ol0000?oiMa]P;o00000onhfJh01_l0003o^=V^okSI[_l0003o^=V^
o`0000?o^=V^00?o0000okSI[_nhfJh02?nhfJh2o`0000KoSK>;00Oo0000ohfcRon=/h_oSK>;o`00
0?n=/h_o000000?oSK>;00?o0000ohfcRon=/h/03on=/h/<o`0001KoMYZl0_l0000QokZSX@Go0000
6onkZ=`2o`0000Wo^YnT00Co0000okZOY?njWjCo^YnT1Ol00002okZOY004o`000?njWjCo^YnTo`00
00Go^YnT0ol00007ol7YZ@;o00004oo0WlH3o`00037og?_U2?l0000Boh>UYP?o00002On2[[@01ol0
003oPZjdoh:^]?n2[[Co0000oh:^]?l000000on2[[@00ol0003oPZjdo`000003oh:^]003o`000?n2
[[CoPZjd00WoPZjd2Ol00009om?ReP04o`000?oCh]Kodn;Fo`0000;odn;F00?o0000om?Re_oCh]H0
0_oCh]H2o`0000;odn;F0ol0000BokN]b@?o00005On9Vhh2o`0005Wooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0F?ooool2o`0001Ko[LC40ol0000AoifO]0?o00003_nG
LKH2o`0000Co^=V^00Go0000okSI[_nhfJko^=V^o`000003okSI[P03o`000?nhfJko^=V^00Oo^=V^
0ol00007ohfcR`?o00000on=/h/3o`00017oSK>;0ol00002oi6<a`?o00006omfV[`2o`00023o^Z>Q
0ol000001?n6OjSo0000o`000?l0000Jok^Xg0;o00002OnjWj@01Ol0003o^YnTokZOY?njWjCo0000
00;o^YnT00Go0000okZOY?njWjCo^YnTo`000002okZOY003o`000?njWjCo^YnT00?o^YnT0_l00008
ol7YZ@;o00005?o0WlH2o`0002kog?_U1ol00002oh6fXP?o00004?n3YJH3o`0000[oPZjd00Oo0000
oh:^]?n2[[CoPZjdo`000?n2[[Co000000?oPZjd00?o0000oh:^]?l000000on2[[@00ol0003oPZjd
oh:^]008oh:^]0So00002?oCh]H01Ol0003odn;Fom?Re_oCh]Ko000000;odn;F00?o0000om?Re_l0
00001_oCh]H00ol0003odn;Fom?ReP02o`00017o]jg90ol0000FohVKSP?o0000F?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Gooooo`?o00005on]a<@2o`0001;oWInd
0ol0000<oiMa]P?o00001OnhfJh00ol0003o^=V^okSI[P04o`0000[o^=V^0_l0000QohfcR`?o0000
0onAS<L3o`0001_oMYZl0ol00008okZSX@;o00001OnjXj400ol0003o^Z>QokZSX@0<okZSX@?o0000
0on6OjP3o`0001So^jSL0ol00009okZOY003o`000?njWjCo^YnT00;o^YnT00?o0000okZOY?l00000
0onjWj@01?l0003o^YnTokZOY?l00004okZOY0?o00002?o1jJT2o`0001Co`9o60ol0000[omcki@Ko
00001_n1]Z84o`0000koPjFV0_l0000<oh:^]0?o00000on2[[@3o`0000?oPZjd0ol0000:oh:^]0?o
00000oo8/[H4o`0000Oodn;F00Go0000om?Re_oCh]Kodn;Fo`000003om?ReP;o00000_oCh]H01Ol0
003odn;Fom?Re_oCh]Ko000000;odn;F0_l0000@okN]b@?o00006?n9Vhh3o`0005Oooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Eoooool2o`0001So[LC40_l00009oifO
]003o`000?nMWkCoWInd00OoWInd0ol0000;oiMa]P;o00000onhfJh01ol0003o^=V^okSI[_nhfJko
0000okSI[_l000003OnhfJh2o`00023oSK>;0ol00005oi6<a`;o00007?mfV[`2o`0000[o^Z>Q00?o
0000okZSXOnjXj400_njXj400ol0003o^Z>QokZSX@0;okZSX@?o00001On6OjP3o`0001?o^jSL1_l0
0009okZOY0;o00001OnjWj@2o`0000?o^YnT00Co0000okZOY?njWjCo00000onjWj@3o`0000Wo`NVY
0_l0000Eol2OaP;o0000:?oLnnD6o`0000[oPKJR1?l0000<oh>UYP?o00008on2[[@4o`0000Kob;:f
1?l00006om?ReP?o00001OoCh]H01?l0003odn;Fom?Re_oCh]H3o`0000?odn;F0ol0000>okN]b@?o
00006_n9Vhh2o`0005Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
Eoooool2o`0001So[LC40_l00009oifO]003o`000?nMWkCoWInd00SoWInd0_l0000;oiMa]P;o0000
0onhfJh01Ol0003o^=V^okSI[_nhfJko000000;o^=V^00?o0000okSI[_nhfJh02OnhfJh3o`0001oo
SK>;0ol00006oi6<a`;o00007?mfV[`3o`0000[o^Z>Q00?o0000okZSXOnjXj400_njXj400ol0003o
^Z>QokZSX@09okZSX@?o00001on6OjP3o`0000_o^jSL3Ol0000:okZOY003o`000?njWjCo^YnT00Co
^YnT00?o0000okZOY?njWj@00_njWj@2o`0000Co^YnT0_l0000:ol7YZ@;o000000Co`9o6o`000?l0
003o00000oo0WlH3o`0000Co`9o60_l00005ol2OaP?o00009?oLnnD7o`0000koPKJR0ol0000;oh>U
YP;o00008on2[[@4o`0000Sob;:f1?l0000Hom?ReP;o00003Ong[LT3o`0001_oRI^>0ol0001Foooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Kooooo0ol0000=ojg4a0?o
00002?n]a<@3o`0000WoWInd00?o0000oifO]?nMWk@01onMWk@3o`0000SoUg6f1Ol00003okSI[P?o
00001?nhfJh2o`0000Wo^=V^0_l0000OohfcR`?o00001onAS<L3o`0001coMYZl0_l00007okZSX@Co
00001?njXj400ol0003o^Z>QokZSX@08okZSX@?o00002On6OjP3o`0000?o^jSL3ol00003ojZUdP?o
00006_njWj@3o`0000[o`NVY0_l00002ol2OaP05o`000?o0WlKo`9o6ol2Oa_l000000oo0WlH01?l0
003o`9o6ol2Oa_l00002ol2OaP03o`000?o0WlKo`9o600?o`9o60ol0000Pomcki@Oo00004_n1]Z84
o`0000SoPjFV0ol0000Roh:^]0?o00003?o8/[H4o`0001Kodn;F0ol0000;okN]b@?o00007On9Vhh2
o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E_ooool2o`00
00go[LC400Go0000ojg4a?n]a<Co[LC4o`000008ojg4a0;o00002OnMWk@00ol0003oWIndoifO]008
oifO]0?o00000_nGLKH<o`0001?o^=V^0_l0000NohfcR`?o00002OnAS<L2o`0001coMYZl0_l00006
okZSX@05o`000?njXj7o^Z>QokZSXOl000001OnjXj400ol0003o^Z>QokZSX@06okZSX@?o00002on6
OjP=o`0000_oZZGB0ol0000HokZOY0?o00002oo1jJT2o`0000;o`9o600Go0000ol2Oa_o0WlKo`9o6
o`000003ol2OaP04o`000?o0WlKo`9o6o`0000;o`9o600?o0000ol2Oa_o0WlH01?o0WlH2o`0001ko
g?_U1_l0000Foh6fXPCo00001_n3YJH3o`0002;oPZjd0ol0000>olRb]PCo00005_oCh]H2o`0000[o
]jg90ol0000NohVKSP?o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1Eooooo`?o00004On]a<@00ol0003o[LC4ojg4a006ojg4a0;o00002_nMWk@00ol0003oWInd
oifO]008oifO]0[o00000on]RVL4o`00017o^=V^0ol0000MohfcR`?o00002_nAS<L2o`0001coMYZl
0ol00005okZSX@07o`000?njXj7o^Z>QokZSXOl0003o^Z>Qo`000003okZSX@03o`000?njXj7o^Z>Q
00Go^Z>Q0ol0000=ohIoZ0Go00004onZYM82o`0001So^YnT0_l0000<ol7YZ@;o00000_o0WlH01?l0
003o`9o6ol2Oa_o0WlH4o`0000?o`9o600Co0000ol2Oa_o0WlKo00001_o0WlH3o`0001[og?_U1_l0
000Koh6fXP?o00001On3YJH2o`00027oPZjd1?l0000AolRb]P?o00005OoCh]H3o`0000So]jg90ol0
000PohVKSP?o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1E
ooooo`;o00004?n]a<@2o`0000Wo[LC40_l00006oifO]005o`000?nMWkCoWIndoifO]?l000002OnM
Wk@6o`0000[o[HYW1?l0000?okSI[P;o00007On=/h/3o`0000_oTHc70ol0000LogJJ_0;o00001_nj
Xj43o`0000;o^Z>Q1Ol00006okZSX@?o00003_n6OjP2o`0001KoZZGB0ol0000FokZOY0?o00003?o1
jJT2o`0000;o`9o600Go0000ol2Oa_o0WlKo`9o6o`000006ol2OaP04o`000?o0WlKo`9o6o`0000Oo
`9o60_l0000Gomcki@Oo00007_n1]Z89o`00023oPZjd1?l0000ColRb]PCo00005?oCh]H2o`0000Oo
]jg90ol0000RohVKSP;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1Eooooo`;o00004_n]a<@00ol0003o[LC4ojg4a006ojg4a0?o00001OnMWk@5o`0000SoWInd
0ol0000?ojf:I`Go00003OnhfJh2o`0001coSK>;0ol0000=oi6<a`;o00007?mfV[`3o`0001Co^Z>Q
0ol0000?ohIoZ0;o000000CoZZGBo`000?l0003o00000_nZYM85o`0000;oZZGB0ol00007ojZUdP?o
00005?njWj@3o`0000go`NVY0_l000000oo0WlKo0000o`000004ol2OaP03o`000?o0WlKo`9o600?o
`9o600Co0000ol2Oa_o0WlKo00001oo0WlH3o`0001Cog?_U1_l0000Roh6fXP[o00007On2[[@3o`00
01Kob;:f1?l0000Com?ReP?o00001Ong[LT3o`0002?oRI^>0ol0001Cooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo05Gooooo0ol0000=ojg4a005o`000?n]a<Co[LC4ojg4
a?l000002On]a<@2o`00017oWInd0ol0000Bojf:I`Co00002onhfJh3o`0001_oSK>;0ol0000>oi6<
a`;o00007OmfV[`2o`0001?o^Z>Q0ol0000@ohIoZ0;o00000_nZYM800ol0003oZZGBojZUdP02ojZU
dP06o`000?nZYM;oZZGBo`000?nZYM;o00000onZYM800ol0003oZZGBojZUdP05ojZUdP?o00004onj
Wj@2o`0000ko`NVY0_l00002ol2OaP03o`000?o0WlKo`9o600?o`9o60_l00004ol2OaP;o00002Oo0
WlH2o`00017og?_U1_l0000Toh6fXP?o00001Oo0b[h4o`0001[oPZjd1?l0000IolRb]POo00003ooC
h]H2o`0000Co]jg90ol0000UohVKSP;o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Fooooo`;o00003_n]a<@3o`0000[o[LC40_l0000@oifO]0?o00005On]RVL4
o`0000Wo^=V^0_l0000KohfcR`?o00003onAS<L3o`0001coMYZl0_l0000BokZSX@?o00004On6OjP2
o`0000;oZZGB00?o0000ojZUd_nZYM800onZYM801Ol0003oZZGBojZUd_nZYM;o000000?oZZGB00?o
0000ojZUd_nZYM801_nZYM82o`0001;o^YnT1?l00003ol7YZ@?o00000oo1jJT3o`000003ol7YZOl0
003o000001Wo`9o62_l00006omcki@Oo00009_n1]Z82o`0000So`<Zn1?l0000Goh:^]0Co00006oo8
/[H>o`0000Oodn;F0ol00002okN]b@?o00009_n9Vhh2o`0005?ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0E_ooool2o`0001_o[LC40_l0000?oifO]0?o00005on]RVL5
o`0000Oo^=V^0_l0000JohfcR`?o00004OnAS<L2o`0001coMYZl0ol0000@okZSX@?o00004_n6OjP2
o`0000;oZZGB00?o0000ojZUd_nZYM801?nZYM801?l0003oZZGBojZUd_nZYM83o`0000WoZZGB0ol0
000@okZOY0Co00000oo1jJT01ol0003o`NVYol7YZOo1jJWo0000ol7YZOl000000oo1jJT3o`0001[o
`9o64ol0000Xoh6fXP?o00002Oo0b[h5o`0001CoPZjd0ol0000LolRb]P?o00000omiQJ0@o`000004
om?Re_l0003o0000okN]b@?o00002On9Vhh5o`0000;oRI^>0ol00003ohVKSP?o00003_n9Vhh2o`00
05?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E_ooool2o`0001_o
[LC40ol0000=oifO]0?o00006_n]RVL4o`0000Go^=V^0ol0000IohfcR`?o00004_nAS<L2o`0001go
MYZl0_l0000?okZSX@?o00004on6OjP2o`0000;oZZGB00Go0000ojZUd_nZYM;oZZGBo`000003ojZU
dP03o`000?nZYM;o000000?oZZGB00?o0000ojZUd_nZYM801onZYM84o`0000ko^YnT0_l000000oo1
jJWo0000ol7YZ@06ol7YZ@03o`000?o1jJWo000000?o`NVY0ol0000Iol2OaP?o00001_oGg:T8o`00
02_oPKJR0_l0000<ol3:_PCo00004On2[[@4o`0001gob;:f0_l0000<ogV5X0ko00002on9Vhh01_l0
003oRI^>ohVKS_l0003oRI^>o`0000?oRI^>00?o0000ohVKS_l000000on9Vhh00ol0003oRI^>ohVK
SP0;ohVKSP;o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1F
ooooo`?o00006on]a<@2o`0000coWInd0ol0000Mojf:I`Co00000onhfJh2o`0001WoSK>;0ol0000C
oi6<a`?o00007?mfV[`2o`0000ko^Z>Q0ol0000DohIoZ0;o000000?oZZGBo`000?l000000onZYM80
1ol0003oZZGBojZUd_nZYM;o0000ojZUd_l000000onZYM800ol0003oZZGBojZUdP05ojZUdPOo0000
3?njWj@3o`000003ol7YZOl0003o`NVY00Ko`NVY00?o0000ol7YZOl000000ol000000oo1jJWo0000
o`00000Iol2OaP;o00003OoGg:T3o`0002WoPKJR0ol0000>ol3:_PCo00003_n2[[@4o`0001kob;:f
0_l0000CogV5X0Ko00003On9Vhh00ol0003oRI^>ohVKSP05ohVKSP03o`000?n9VhkoRI^>00?oRI^>
00?o0000ohVKS_n9Vhh02_n9Vhh3o`0005?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Eoooool3o`0001[o[LC40_l0000;oifO]0?o00007on]RVL5o`000003okSI[_l0
003o000001SoSK>;0ol0000Eoi6<a`;o00007?mfV[`3o`0000co^Z>Q0ol0000EohIoZ0;o00000_nZ
YM800ol0003oZZGBojZUdP02ojZUdP?o00000onZYM83o`0000KoZZGB1Ol00002ooS8h@?o00002_nj
Wj@3o`0000;o`NVY00Co0000ol7YZOo1jJWo`NVY1?l00002ol7YZ@03o`000?o1jJWo`NVY00;o`NVY
0_l0000Iol2OaP;o00003_oGg:T2o`0002SoPKJR0ol0000@ol3:_PGo00002on2[[@3o`0000Oob;:f
1Ol00002olRb]P?o00000oo8/[H3o`0000Sob;:f0ol0000GogV5X0?o00003On9Vhh00ol0003oRI^>
ohVKSP04ohVKSP04o`000?n9VhkoRI^>ohVKSP;o00003On9Vhh2o`0005Cooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0Eoooool6o`0001Oo[LC40_l0000:oifO]0?o0000
8_n]RVL6o`0001OoSK>;0ol0000Foi6<a`;o00003_mfV[`00ol0003oMYZlogJJ_003ogJJ_0;o0000
1omfV[`2o`0000_o^Z>Q0ol0000FohIoZ0;o00005?nZYM85o`0000Gon<SQ0ol00008okZOY0?o0000
0_o1jJT2o`0000?o`NVY00?o0000ol7YZOo1jJT01?o1jJT01?l0003o`NVYol7YZOo1jJT2o`0001So
`9o60ol0000>omOLZ@?o00009on1]Z82o`0001?o`<Zn1?l00009oh:^]0?o00002Oo8/[H01_l0003o
b;:folRb]_l0003ob;:fo`0000?ob;:f00?o0000olRb]_l000000oo8/[H00ol0003ob;:folRb]P05
olRb]P;o00006?miQJ05o`0000SoRI^>00Ko0000ohVKS_n9VhkoRI^>o`000?n9Vhh4o`0000KoRI^>
00?o0000ohVKS_n9Vhh02_n9Vhh2o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0E_ooool:o`0001Co[LC40_l00009oifO]0?o00009On]RVL3o`0001OoSK>;0ol0
000Goi6<a`?o00003OmfV[`00ol0003oMYZlogJJ_002ogJJ_004o`000?mfV[coMYZlo`0000KoMYZl
0ol00009okZSX@?o00005on6OjP2o`0001;oZZGB1Ol00008ooS8h@?o00001onjWj@2o`0000Co`NVY
00Co0000ol7YZOo1jJWo`NVY1Ol00003ol7YZ@;o000000?o`NVYo`000?l000006?o0WlH2o`00013o
embY0_l0000:oh6fXP?o00000on1]Z82o`0000CoPKJR0ol0000=oh6fXP?o00005Oo0b[h4o`0000Go
PZjd1?l0000;olRb]P03o`000?o8/[Kob;:f00Gob;:f00?o0000olRb]_o8/[H00oo8/[H00ol0003o
b;:folRb]P05olRb]P;o00006?miQJ06o`0000OoRI^>00Oo0000ohVKS_n9VhkoRI^>o`000?n9Vhko
000000GoRI^>00Go0000ohVKS_n9VhkoRI^>o`00000<ohVKSP;o0000E?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1Eooooo`?o00001?o6`;46o`0001;o[LC40ol00007
oifO]0?o00004on]RVL3o`0000?o[HYW0ol0000;ojf:I`;o00005_n=/h/3o`0001WoTHc70_l0000>
ogJJ_005o`000?mfV[coMYZlogJJ_?l000000_mfV[`00ol0003oMYZlogJJ_005ogJJ_0;o00002?nj
Xj43o`0000GoQWnX0ol00004ohIoZ0;o00001?n6OjP3o`0000?oQWnX0_l0000@ojZUdPGo00002ooh
b>43o`0000Go^YnT0ol0000Col7YZ@;o00005oo0WlH3o`00013oembY0ol0000:oh6fXP03o`000?n1
]Z;oPKJR00CoPKJR00Co0000oh6fX_n1]Z;o00000on1]Z800ol0003oPKJRoh6fXP0:oh6fXP;o0000
5oo0b[h5o`0000;oPZjd1?l0000=olRb]P03o`000?o8/[Kob;:f00;ob;:f0_l00006olRb]P03o`00
0?o8/[Kob;:f00Cob;:f0ol0000GogV5X0?o00000_nV[jP4o`0000KoRI^>0ol00002ohVKSPGo0000
0_n9Vhh3o`0000goRI^>0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo05Cooooo0ol00008olK0/@Ko00004?n]a<@2o`0000KoWInd0ol0000Eojf:I`05o`000?n]
RVOo[HYWojf:Iol000000on]RVL00ol0003o[HYWojf:I`08ojf:I`?o00005?n=/h/3o`0001[oTHc7
0ol0000=ogJJ_005o`000?mfV[coMYZlogJJ_?l000000_mfV[`00ol0003oMYZlogJJ_005ogJJ_0;o
00001onjXj43o`0000OoQWnX00?o0000ohIoZ?n6OjP00_n6OjP01?l0003oQWnXohIoZ?l00004ohIo
Z003o`000?n6OjSoQWnX00;oQWnX0_l0000>ojZUdPGo00003_ohb>43o`0000?o^YnT0ol0000Dol7Y
Z@;o00005oo0WlH2o`0001;oembY0_l0000:oh6fXP03o`000?n1]Z;oPKJR00GoPKJR00?o0000oh6f
X_l000000on1]Z800ol0003oPKJRoh6fXP09oh6fXP?o00006Oo0b[h7o`0000cob;:f00Go0000olRb
]_o8/[Kob;:fo`000005olRb]P03o`000?o8/[Ko000000?o00001oo8/[H2o`0001SoNHFP0_l00004
ojJ_Z0Go00008?n9Vhh2o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Doooool3o`0000_oa/2a1ol0000=ojg4a0;o00001OnMWk@3o`0001Ko[HYW00?o0000ojf:
Ion]RVL01On]RVL00ol0003o[HYWojf:I`09ojf:I`;o00004on=/h/3o`0001coTHc70_l0000>ogJJ
_004o`000?mfV[coMYZlo`0000;oMYZl00?o0000ogJJ_?mfV[`01OmfV[`3o`0000Go^Z>Q0ol00008
ohIoZ003o`000?n6OjSoQWnX00;oQWnX00Go0000ohIoZ?n6OjSo0000ohIoZ005o`0000?oQWnX0_l0
000<ojZUdPGo00004Oohb>43o`0000;o^YnT0_l0000Eol7YZ@;o00005oo0WlH2o`0001;oembY0ol0
0009oh6fXP03o`000?n1]Z;oPKJR00;oPKJR1?l00002oh6fXP?o00003?n1]Z82o`0001co`<Zn1?l0
000=olRb]P07o`000?o8/[Kob;:folRb]_l0003ob;:fo`000003olRb]P03o`000?o8/[Ko000000[o
b;:f0_l0000HogV5X0;o00001_nV[jP4o`0001ooRI^>0_l0001Dooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo05;ooooo0ol0000?olK0/@Oo00002_n]a<@2o`0000CoWInd
0ol0000Gojf:I`03o`000?n]RVOo[HYW00?o[HYW0_l0000<ojf:I`?o00004On=/h/3o`0001goTHc7
0_l0000:ogJJ_005o`000?mfV[coMYZlogJJ_?l000000_mfV[`01?l0003oMYZlogJJ_?l00008ogJJ
_0;o00001?njXj43o`0000WoQWnX00?o0000ohIoZ?n6OjP00_n6OjP01_l0003oQWnXohIoZ?l0003o
QWnXo`0000;oQWnX00?o0000ohIoZ?n6OjP00_n6OjP2o`0000_oZZGB1?l0000DooS8h@Ko00005Oo1
jJT2o`0001Ko`9o60ol0000ComOLZ@;o00002On1]Z801Ol0003oPKJRoh6fX_n1]Z;o000000?oPKJR
00?o0000oh6fX_l000000on1]Z800ol0003oPKJRoh6fXP08oh6fXP?o00007Oo0b[h2o`0000oob;:f
0ol00003olRb]P?o00000_o8/[H5o`0000Gob;:f0ol0000GogV5X0?o00002?nV[jP4o`0001coRI^>
0ol0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05;ooooo0_l0
000ColK0/@Ko00002?n]a<@8o`0001So[HYW00?o0000ojf:Ion]RVL01On]RVL00ol0003o[HYWojf:
I`0:ojf:I`?o00003on=/h/3o`0001koTHc70ol00009ogJJ_0Go00000omfV[`2o`0000WoMYZl0_l0
0003okZSX@?o00002_n6OjP00ol0003oQWnXohIoZ002ohIoZ004o`000?n6OjSoQWnXo`0000;oQWnX
00?o0000ohIoZ?l000001?n6OjP2o`0000WoZZGB1?l0000GooS8h@Co00005_o1jJT2o`0001Ko`9o6
0_l0000DomOLZ@?o00001on1]Z82o`0000?oPKJR00Oo0000oh6fX_n1]Z;oPKJRo`000?n1]Z;o0000
00?oPKJR00?o0000oh6fX_n1]Z802?n1]Z82o`0001ko`<Zn0ol0000SolRb]P;o00006?miQJ02o`00
00[oYZnX1Ol0000JohVKSP;o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Aooooo`?o00005_o6`;46o`0000Go[LC42Ol0000Fojf:I`;o00000on]RVL01Ol0003o
[HYWojf:Ion]RVOo000000go[HYW0_l0000>ohfcR`?o00008?nAS<L2o`0001coMYZl1ol0000:ohIo
Z0;o00001?n6OjP01?l0003oQWnXohIoZ?l00003ohIoZ0;o00001?n6OjP2o`0000OoZZGB1Ol0000I
ooS8h@;o00005oo1jJT2o`0001Go`9o60ol0000EomOLZ@;o00002?n1]Z800ol0003oPKJRoh6fXP02
oh6fXP?o00000on1]Z83o`0000[oPKJR0ol0000Ool3:_PCo00008Oo8/[H2o`0001SoNHFP0_l0000<
ojJ_Z0Co00006On9Vhh2o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0D?ooool3o`0001Woa/2a3Ol00003oiahS`?o00005_n]RVL00ol0003o[HYWojf:I`02ojf:
I`?o00003_n]RVL4o`0000_oSK>;0ol0000Qoi6<a`;o00006omfV[`:o`0000WoQWnX00?o0000ohIo
Z?n6OjP00on6OjP2o`0000GoQWnX00?o0000ohIoZ?n6OjP00_n6OjP2o`0000GoZZGB1Ol0000KooS8
h@;o00005oo1jJT2o`0001Go`9o60_l00004omOLZ@?o00000ooGg:T3o`0000?oembY0ol00003omOL
Z@?o00007on1]Z82o`00023o`<Zn1ol0000MolRb]P?o00005omiQJ03o`0000koYZnX1?l0000GohVK
SP;o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1?ooooo`?o
00007Oo6`;47o`0000OoW7R?0ol0000Yojf:I`Oo00002On=/h/3o`0000_oTHc70ol00003oi6<a`?o
00003_nAS<L3o`0001WoMYZl0ol00005ooW1l0Co00006_n6OjP2o`0000?oZZGB1Ol0000MooS8h@;o
00005oo1jJT2o`0001Co`9o60ol00005omOLZ@05o`000?oGg:WoembYomOLZOl000000ooGg:T00ol0
003oembYo`000003omOLZ@04o`000?oGg:WoembYomOLZ@;o00007_n1]Z83o`00023o`<Zn0_l00000
0onPiI_o0000o`000005o`0001[ob;:f0_l00006ogV5X0Go00000omiQJ03o`0000;oNHFP0ol00002
ogV5X0;o00004?nV[jP5o`0001GoRI^>0_l0001Eooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo04kooooo0ol0000QolK0/@;o00002_nLN8l4o`0002Go[HYW1Ol00002olRc
R`?o00001on=/h/3o`0000_oTHc700Oo0000oi6<aonAS<OoTHc7o`000?nAS<Oo000000?oTHc700?o
0000oi6<aonAS<L03?nAS<L2o`0001SoMYZl0ol00008ooW1l0Co00006?n6OjP2o`000003ojZUd_l0
003o000000?o00007oohb>43o`0001Ko`NVY0_l0000Dol2OaP;o00001_oGg:T01Ol0003oembYomOL
ZOoGg:Wo000000?oembY00?o0000omOLZOl000000ooGg:T01?l0003oembYomOLZOoGg:T3o`0001co
PKJR0ol0000Qol3:_P;o00001?nPiI/8o`0001Kob;:f0_l00007ogV5X004o`000?miQJ3oNHFPo`00
00CoNHFP00?o0000ogV5X?miQJ000_miQJ001?l0003oNHFPogV5X?miQJ02o`0001;oYZnX1Ol0000C
ohVKSP;o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1=oooo
o`?o00008_o6`;42o`0000_oW7R?1?l0000Rojf:I`Go00001Oo8/h/4o`0000CoSK>;0ol0000@oi6<
a`03o`000?nAS<OoTHc700?oTHc700?o0000oi6<aonAS<L03?nAS<L2o`0001OoMYZl0ol0000:ooW1
l0Go00005_n6OjP6o`0002;on<SQ0_l0000Fol7YZ@;o00005?o0WlH2o`0000KoembY00?o0000omOL
ZOoGg:T00_oGg:T3o`0000;oembY1?l00005omOLZ@;o00007?n1]Z82o`0002;o`<Zn0_l00007oj3U
V`So00004_o8/[H3o`0000SoNHFP00Co0000ogV5X?miQJ3oNHFP1Ol00003ogV5X003o`000?miQJ3o
NHFP00?o00005?nV[jP4o`0001;oRI^>0_l0001Eooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo04gooooo0_l0000RolK0/@?o00003OnLN8l3o`0001oo[HYW1Ol00008olRc
R`Co00000_n=/h/3o`00017oTHc700Co0000oi6<aonAS<OoTHc70_l0000?oi6<a`?o00005OmfV[`3
o`0000gonL7`1?l0000EohIoZ0Co00009?ohb>43o`0001Go`NVY0_l0000Col2OaP?o00001_oGg:T0
1Ol0003oembYomOLZOoGg:Wo000000?oembY00?o0000omOLZOl000002?oGg:T3o`0001[oPKJR0ol0
000Rol3:_P;o00002onPiI/7o`0000oob;:f0_l0000:ogV5X004o`000?miQJ3oNHFPo`0000;oNHFP
00?o0000ogV5X?miQJ000_miQJ000ol0003oNHFPogV5X002o`0001OoYZnX1?l0000?ohVKSP?o0000
EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1=ooooo`;o00008_o6
`;42o`0000ooW7R?0ol0000Lojf:I`Go00003?o8/h/6o`0000koTHc71?l00006oi6<a`03o`000?nA
S<OoTHc700goTHc70_l0000DogJJ_0?o00004?oi`O04o`0001;oQWnX1?l0000=ooS8h@?o00000ooh
b>43o`0000Con<SQ0_l00008ooS8h@Ko00004oo1jJT2o`0001?o`9o60_l00006omOLZ@;o00000ooG
g:T01Ol0003oembYomOLZOoGg:Wo000000;oembY00?o0000omOLZOoGg:T01_oGg:T2o`0001[oPKJR
0_l0000Sol3:_P;o00003_nPiI/7o`0000cob;:f0_l00007ogV5X005o`000?miQJ3oNHFPogV5X?l0
00000_miQJ000ol0003oNHFPo`000004ogV5X003o`000?miQJ3oNHFP00;o00006?nV[jP5o`0000go
RI^>0_l0001Fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04gooooo
0_l0000RolK0/@;o00004?nLN8l4o`0001So[HYW1Ol0000?olRcR`Co00003onAS<L00ol0003oTHc7
oi6<a`03oi6<a`05o`000?nAS<OoTHc7oi6<aol000003onAS<L2o`0001?oMYZl0ol0000BooW1l0Go
00003_n6OjP7o`0000gon<SQ00Go0000ooS8hOohb>7on<SQo`000003ooS8h@04o`000?ohb>7on<SQ
o`0000;on<SQ00?o0000ooS8hOohb>401?ohb>43o`000003ohnQZol0003o000000Co00004?o1jJT2
o`0001;o`9o60ol00007omOLZ@03o`000?oGg:WoembY00;oembY0ol00004omOLZ@;o00001_oGg:T3
o`0001SoPKJR0ol0000Sol3:_P;o00004OnPiI/8o`0000Oob;:f0ol00007ogV5X005o`000?miQJ3o
NHFPogV5X?l000000omiQJ02o`0000?oNHFP0_l000001?miQJ3o0000o`000?l0000JojJ_Z0Co0000
3?n9Vhh2o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo0ol0001=ooooo`;o00008_o6
`;42o`00017oW7R?1?l0000Eojf:I`Go00004_o8/h/2o`00013oTHc71Ol00002oi6<a`?o00004?nA
S<L3o`00017oMYZl0ol0000EooW1l0Co00002on6OjP5o`0000;oXIR:1?l0000;ooS8h@03o`000?oh
b>7on<SQ00Gon<SQ00Co0000ooS8hOohb>7o00000_ohb>400ol0003on<SQooS8h@03ooS8h@?o0000
1?n?XJ/6o`0000ko`NVY0_l0000Bol2OaP;o00007OoGg:T2o`0001SoPKJR0_l0000Tol3:_P;o0000
5?nPiI/8o`0000Cob;:f0_l00009ogV5X0?o00001OmiQJ000ol0003oNHFPogV5X002ogV5X004o`00
0?miQJ3o0000o`0001goYZnX1?l00009ohVKSP?o0000E?ooool3o`0000[ooooo000Jooooo`03o`00
0?oooooooooo04cooooo0ol0000RolK0/@;o00004onLN8l3o`0001?o[HYW1?l0000DolRcR`?o0000
:_nAS<L2o`0000coMYZl1ol0000HooW1l0Co00001on6OjP5o`0000GoXIR:1?l0000:ooS8h@03o`00
0?ohb>7on<SQ00?on<SQ0_l00003ooS8h@04o`000?ohb>7on<SQo`0000Con<SQ0ol00008ohnQZ`Go
00003?o1jJT2o`0001;o`9o60_l0000MomOLZ@?o00005_n1]Z83o`0002Co`<Zn0_l0000Hoj3UV`Oo
000000?ob;:fo`000?l000006?miQJ02o`0001koYZnX1Ol00006ohVKSPCo0000E_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1<ooooo`;o00008_o6`;43o`0001CoW7R?
0ol0000@ojf:I`Co00005oo8/h/2o`0002[oTHc70_l00003ogJJ_0oo00006_oi`O05o`0000?oQWnX
1Ol00009oj6HRPCo00002?ohb>400ol0003on<SQooS8h@05ooS8h@04o`000?ohb>7on<SQo`0000;o
n<SQ00Co0000ooS8hOohb>7on<SQ0ol0000;ohnQZ`Ko00001oo1jJTHo`0001koembY0_l0000Foh6f
XP;o00009Oo0b[h2o`0001_oX>FK1ol0000GogV5X0?o00008?nV[jP4o`0000?oRI^>1?l0001Hoooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04cooooo0_l0000RolK0/@;o
00005_nLN8l3o`0000go[HYW1Ol0000HolRcR`?o0000:OnAS<L?o`0000?o/j[=0_l0000LooW1l0Wo
00003?nQV8X4o`0000Kon<SQ0_l00003ooS8h@05o`000?ohb>7on<SQooS8hOl000000_ohb>401?l0
003on<SQooS8hOl00002ooS8h@?o00003_n?XJ/6o`000003ol7YZOl0003o000001Wo00007ooGg:T3
o`0001CoPKJR0ol0000Uol3:_P;o00007_nPiI/4o`0001OoNHFP0_l0000SojJ_Z0So0000FOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1<ooooo`;o00003oo6`;43o`00
013oa/2a0_l0000GoiahS`Co00002On]RVL5o`0001_ob;>;0_l0000Yoi6<a`Ko00003?ncZ/d3o`00
01gonL7`1Ol0000@oj6HRPCo00001Oohb>400ol0003on<SQooS8h@02ooS8h@?o00001?ohb>42o`00
00;on<SQ0ol0000BohnQZ`Wo00005?oIa^`3o`0001ooembY0_l0000Doh6fXP;o00009_o0b[h2o`00
023oX>FK0ol0000FogV5X0;o00009?nV[jP5o`0005_ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0C?ooool2o`00013oa/2a00?o0000olK0/Oo6`;403oo6`;42o`0001So
W7R?1?l00006ojf:I`Go00007Oo8/h/3o`0002OoTHc70ol0000Aok>Zc@;o00007_oi`O02o`0001?o
XIR:1Ol0000BooS8h@?o00005On?XJ/3o`0001WofLK/0_l0000OomOLZ@?o00004_n1]Z83o`0002Ko
`<Zn0ol0000Poj3UV`?o00005?miQJ03o`0002KoYZnX0_l0001Looooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo04cooooo0_l0000@olK0/@03o`000?o6`;7oa/2a00ooa/2a
0_l0000JoiahS`?o00000on]RVL5o`00023ob;>;0_l0000Voi6<a`?o00004_ncZ/d2o`0000_onL7`
0_l00004ooW1l0?o00002_oi`O02o`0001GoXIR:1?l0000@ooS8h@?o00005_n?XJ/2o`0001[ofLK/
0ol0000OomOLZ@;o00004_n1]Z82o`00017o`<Zn1Ol00002ol3:_P?o00000oo0b[h3o`0000Ko`<Zn
1Ol0000Ooj3UV`?o00004omiQJ02o`0002OoYZnX0_l0001Looooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo04cooooo0_l0000@olK0/@03o`000?o6`;7oa/2a00koa/2a0ol0
000KoiahS`So00008_o8/h/2o`0002GoTHc70ol0000Cok>Zc@?o00003?oi`O001?l0003onL7`ooW1
l?l00003ooW1l003o`000?oi`O3onL7`00OonL7`0_l0000Goj6HRPCo00003Oohb>43o`0001OoSj6[
0_l0000KomW6k0;o00007ooGg:T3o`00013oPKJR0ol0000Bol3:_P04o`000?o0b[ko`<Zno`0000?o
`<Zn00Go0000ol3:__o0b[ko`<Zno`000003ol3:_P03o`000?o0b[ko`<Zn00?o`<Zn1ol0000Noj3U
V`?o00004_miQJ02o`0002KoYZnX0ol0001Looooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo04cooooo0_l0000@olK0/@03o`000?o6`;7oa/2a00koa/2a0_l0000MoiahS`Go
00009?o8/h/3o`0002?oTHc70ol0000Eok>Zc@;o00003Ooi`O000ol0003onL7`ooW1l003ooW1l003
o`000?oi`O3onL7`00KonL7`1?l0000Goj6HRPCo00002_ohb>44o`0001SoSj6[0_l0000KomW6k0?o
00007ooGg:T2o`0000ooPKJR0ol0000Dol3:_P03o`000?o0b[ko`<Zn00?o`<Zn00?o0000ol3:__o0
b[h01Oo0b[h00ol0003o`<Znol3:_P03ol3:_P;o00000_nmcl45o`0000WoX>FK1Ol00002oj3UV`?o
00000onPiI/3o`0000CoX>FK0ol0000@ogV5X0?o00009_nV[jP2o`0005gooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0C?ooool2o`0000ooa/2a0_l0000@olK0/@;o0000
3OnLN8l3o`0000koW7R?0_l0000WolRcR`;o00008_nAS<L3o`0001Ko/j[=0_l0000:ooW1l0Co0000
0ooi`O02o`0000SonL7`1Ol0000Ioj6HRPCo00001oohb>45o`0001SoSj6[0_l0000LomW6k0;o0000
7_oGg:T6o`0000coPKJR0_l0000Fol3:_P03o`000?o0b[ko`<Zn00;o`<Zn00?o0000ol3:__o0b[h0
1Oo0b[h00ol0003o`<Znol3:_P02ol3:_P?o00001?nmcl45o`0000SoX>FK00Ko0000oj3UVonPiI_o
0000oj3UVol00003oj3UV`03o`000?nPiI_o000000?oX>FK00?o0000oj3UVonPiI/00_nPiI/3o`00
00ooNHFP0_l0000WojJ_Z0;o0000GOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1;ooooo`?o00004?o6`;400ol0003oa/2aolK0/@0>olK0/@;o00003?nLN8l01Ol0003o
W7R?oiahSonLN8oo000000goW7R?0_l0000AolRcR`?o00001?o8/h/00ol0003ob;>;olRcR`0<olRc
RbKo00005oncZ/d3o`0000SonL7`00Go0000ooW1l?oi`O3onL7`o`000005ooW1l003o`000?oi`O3o
nL7`00ConL7`0ol000001?ng/=Go0000o`000?l0000Ioj6HRPCo00001Oohb>43o`000004ok2[YOl0
003o0000o`0001OoSj6[0_l0000LomW6k0?o00006_oGg:T>o`0000KoPKJR0ol0000Col3:_P05o`00
0?o0b[ko`<Znol3:__l000000oo0b[h01?l0003o`<Znol3:__o0b[h4o`0000Go`<Zn0_l00007okg?
`@Go00001onPiI/00ol0003oX>FKoj3UV`05oj3UV`03o`000?nPiI_oX>FK00?oX>FK00?o0000oj3U
VonPiI/00onPiI/3o`0000koNHFP0_l00008ojJ_Z0Go00000_nV[jP3o`0000?oYZnX0ol0000>ojJ_
Z0?o0000GOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1;ooooo`;o
00008_o6`;42o`0000coW7R?00Go0000oiahSonLN8ooW7R?o`00000=oiahS`;o00004_o8/h/00ol0
003ob;>;olRcR`03olRcR`03o`000?o8/h_ob;>;00gob;>;9?l0000Iok>Zc@;o00002?oi`O001ol0
003onL7`ooW1l?oi`O3o0000ooW1l?l000000ooi`O000ol0003onL7`ooW1l004ooW1l0;o00000ong
/=D2o`0001_oXIR:1?l00002ooS8h@?o00000on`ZjD3o`0001KoSj6[0_l0000MomW6k0;o00005ooG
g:T7o`0000CoXj2d2ol000000on1]Z;o0000o`00000Dol3:_P05o`000?o0b[ko`<Znol3:__l00000
0_o0b[h2o`0000?o`<Zn00?o0000ol3:__o0b[h01_o0b[h2o`0000Wo_Lo11Ol00006oj3UV`03o`00
0?nPiI_oX>FK00;oX>FK0_l00004oj3UV`;o00001onPiI/3o`0000coNHFP0ol00009ojJ_Z006o`00
0?nV[jSoYZnXo`000?nV[jSo00000onV[jP01Ol0003oYZnXojJ_Z?nV[jSo000000ooYZnX0_l0001N
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04_ooooo0_l0000QolK0
/@?o00003OnLN8l3o`0000goW7R?0ol0000BolRcR`03o`000?o8/h_ob;>;00Cob;>;00?o0000olRc
Roo8/h/03?o8/h/2o`00023o/h^A0_l0000Iok>Zc@;o00002Ooi`O03o`0000?onL7`0ol00006ooW1
l0?o00000ong/=D3o`000004oj6HR_l0003o0000o`0000?oXIR:0ol00003oj6HRP?o00002onQV8X7
o`0000Go/:^U0ol0000EohnQZ`;o00007OoIa^`3o`0001?oembY1ol0000<oj>P]0Wo00005Oo0b[h3
o`0000Co`<Zn00Co0000ol3:__o0b[ko`<Zn1Ol00004ol3:_P;o00002onmcl45o`000003oj3UVol0
003oX>FK00;oX>FK00?o0000oj3UVonPiI/00onPiI/00ol0003oX>FKoj3UV`03oj3UV`03o`000?nP
iI_oX>FK00GoX>FK0ol00009ogV5X0Go00002_nV[jP00ol0003oYZnXojJ_Z005ojJ_Z005o`000?nV
[jSoYZnXojJ_Z?l000003onV[jP2o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Boooool2o`00027oa/2a0_l0000=oiahS`05o`000?nLN8ooW7R?oiahSol00000
3?nLN8l2o`0001?ob;>;00?o0000olRcRoo8/h/01?o8/h/00ol0003ob;>;olRcR`0<olRcR`;o0000
8?ncRi43o`0001So/j[=0ol0000FooW1l0?o00001Ong/=D2o`0000;oXIR:00?o0000oj6HR_nQV8X0
0onQV8X01Ol0003oXIR:oj6HR_nQV8[o000000?oXIR:00?o0000oj6HR_nQV8X02_nQV8X4o`0000Oo
/:^U0ol0000DohnQZ`;o00007_oIa^`2o`0000ooembY2?l0000Doj>P]0?o0000:_o0b[h2o`0000go
_Lo11Ol00003oj3UV`03o`000?nPiI_o000000?oX>FK00?o0000oj3UVol000000onPiI/00ol0003o
X>FKoj3UV`06oj3UV`?o00001OmiQJ09o`0000[oYZnX00?o0000ojJ_Z?nV[jP01?nV[jP01Ol0003o
YZnXojJ_Z?nV[jSo000000koYZnX0ol0001Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo04_ooooo0_l0000OolK0/@Co00003OnLN8l01Ol0003oW7R?oiahSonLN8oo0000
00coW7R?0_l0000ColRcR`03o`000?o8/h_ob;>;00Gob;>;00?o0000olRcRoo8/h/02_o8/h/3o`00
027o/h^A0_l0000Iok>Zc@;o00005Ooi`O03o`0000Ko]k3E0ol000000onQV8[o0000oj6HRP04oj6H
RP03o`000?nQV8[oXIR:00GoXIR:00?o0000oj6HR_nQV8X02onQV8X2o`0000Wo/:^U0ol0000CohnQ
Z`;o00007_oIa^`3o`0000_oembY2?l0000Hoj>P]0;o0000:_o0b[h2o`0000oo_Lo11_l00003oj3U
V`?o00000onPiI/3o`0000[oX>FK0ol000000omiQJ3o0000o`000005o`0000?oYYjW0ol00006ojJ_
Z006o`000?nV[jSoYZnXojJ_Z?l0003oYZnX1?l00004ojJ_Z003o`000?nV[jSoYZnX00coYZnX0_l0
001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04_ooooo0ol0000K
olK0/@Oo00003_nLN8l3o`0000goW7R?0_l0000BolRcR`;o00000oo8/h/01Ol0003ob;>;olRcRoo8
/h_o000000cob;>;0_l0000Rok>;T@;o00006OncZ/d2o`0001GonL7`0_l00008okN`e@;o000000?o
XIR:o`000?nQV8X01?nQV8X00ol0003oXIR:oj6HRP05oj6HRP03o`000?nQV8[oXIR:00_oXIR:0_l0
000:ok2[Y@?o00004_n?XJ/2o`0001oofLK/0_l00008omOLZ@Oo00007?nSX;@3o`0002So`<Zn0ol0
000Aokg?`@Go00005_nPiI/7o`0000OoYYjW1?l00004ojJ_Z007o`000?nV[jSoYZnXojJ_Z?l0003o
YZnXo`000006ojJ_Z0;o00003_nV[jP2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0C?ooool3o`0001Ooa/2a1ol000001?ndSXco0000o`000?l0000MoiahS`;o
00004oo8/h/01?l0003ob;>;olRcRoo8/h/5o`0000cob;>;0_l0000Rok>;T@?o00006?ncZ/d3o`00
01?onL7`0ol00008okN`e@Co00001OnQV8X01?l0003oXIR:oj6HR_nQV8X4o`0000koXIR:0_l0000;
ok2[Y@?o00000_n?XJ/3o`0000CoSj6[0ol00002ohnQZ`Go00007ooIa^`3o`0000CoembY1ol0000P
oj>P]0;o0000:?o0b[h2o`0001Co_Lo11Ol0000Eoj3UV`?o00002onVWZL4o`0000CoYZnX0ol00002
ojJ_Z0Go00000onV[jP00ol0003oYZnXojJ_Z00;ojJ_Z0?o0000Goooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1=ooooo`?o00004_o6`;48o`0000Go]8j<0ol0000Loiah
S`;o00009_o8/h/4o`0002?o/h^A0_l00009ok>Zc@03o`000?ncZ/go/j[=00?o/j[=0ol00007ok>Z
c@;o00004_oi`O03o`0000[o]k3E0ol00004oj6HRP;o00000onQV8X00ol0003oXIR:oj6HRP0>oj6H
RP?o00003?n`ZjD3o`0000;oSj6[00?o0000ohnQZon?XJ/01?n?XJ/01?l0003oSj6[ohnQZol00003
ohnQZ`;o00008?oIa^`2o`000003omOLZOl0003o000000Go00008onSX;@2o`0002So`<Zn0_l0000F
okg?`@Go00004_nPiI/3o`0000koYYjW0ol0000NojJ_Z0;o0000H?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1>ooooo`?o00003_o6`;48o`0000Wo]8j<0ol0000Koiah
S`;o00008_o8/h/8o`0002?o/h^A0_l00009ok>Zc@03o`000?ncZ/go/j[=00Co/j[=00?o0000ok>Z
cOncZ/d01_ncZ/d2o`00017onL7`0ol0000;okN`e@?o00001OnQV8X01?l0003oXIR:oj6HR_nQV8X5
o`0000coXIR:0_l0000>ok2[Y@?o000000?oSj6[o`000?n?XJ/00_n?XJ/5o`000003ohnQZol0003o
Sj6[00;oSj6[0_l0000PomW6k0Oo00009_nSX;@2o`0002So`<Zn0_l0000Hokg?`@Go00003onPiI/3
o`00013oYYjW1?l0000LojJ_Z0;o0000H?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1?ooooo`?o00002Oo6`;48o`0000ko]8j<0_l0000JoiahS`?o00007_o8/h/9o`00
0003ojKVX_l0003o000002?o/h^A0_l0000:ok>Zc@03o`000?ncZ/go/j[=00Go00001oncZ/d3o`00
013onL7`0_l0000=okN`e@;o00006_nQV8X2o`0000oo/:^U1?l00003ohnQZ`04o`000?n?XJ_oSj6[
o`0000;oSj6[1_l0000QomW6k0?o0000:OnSX;@3o`0002Oo`<Zn0_l0000Jokg?`@Go00003?nPiI/3
o`0001;oYYjW1?l0000JojJ_Z0?o0000H?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1@ooooo`?o00001Oo6`;48o`00017o]8j<0ol0000IoiahS`;o00006oo8/h/9o`00
00GoY^JR0_l0000Sok>;T@?o00002OncZ/d01?l0003o/j[=ok>ZcOl00002ok>Zc@03o`000?ncZ/go
/j[=00Oo/j[=0_l0000?ooW1l0?o00003Ong/=D3o`0001WoXIR:0_l0000@ok2[Y@?o00001?n?XJ/0
0ol0003oSj6[o`000002ohnQZ`04o`000?n?XJ_oSj6[ohnQZ`;o00008OoIa^`2o`0002_oXj2d0_l0
000Wol3:_P;o00007?nmcl45o`0000WoX>FK0ol0000EojJNY`?o00006OnV[jP2o`00067ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0DOooool3o`000003olK0/Ol0003o
000000Go00005_ndSX`3o`0001SoW7R?0_l0000GolRcR`Wo00002OnViZ82o`0002Co/h^A0_l0000:
ok>Zc@06o`000?ncZ/go/j[=o`000?ncZ/go00002OncZ/d2o`0000konL7`0ol0000?okN`e@;o0000
6OnQV8X2o`000004ok2[YOl0003o0000o`0000Co/:^U0ol000000on`ZjGo0000o`000006o`0000Co
Sj6[0_l00003ohnQZ`03o`000?n?XJ_oSj6[00;o00002?oIa^`3o`0000?ofLK/0ol00003omW6k0?o
00002_oIa^`2o`0002_oXj2d0_l0000Wol3:_P;o00007_nmcl45o`0000KoX>FK0ol0000GojJNY`Co
00005onV[jP2o`00067ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
D_ooool7o`0001[o]8j<0_l0000HoiahS`;o00004oo8/h/9o`0000goY^JR0_l0000Tok>;T@;o0000
1_ncZ/d01Ol0003o/j[=ok>ZcOncZ/go000000?o/j[=0_l00009ok>Zc@?o00003Ooi`O02o`000004
okN`eOl0003o0000o`0000Co]k3E0_l00003okN`e@Go00006?nQV8X3o`0000;o/:^U00?o0000ok2[
YOn`ZjD01?n`ZjD01Ol0003o/:^Uok2[YOn`ZjGo000000;o/:^U00?o0000ok2[YOl000000_l00004
ohnQZ`03o`000?n?XJ_oSj6[00;oSj6[1?l00009omW6k005o`000?oIa^cofLK/omW6k?l000000ooI
a^`01Ol0003ofLK/omW6k?oIa^co000000_ofLK/0_l0000[oj>P]0?o00009Oo0b[h3o`00023o_Lo1
1Ol00003oj3UV`?o00006OnVWZL4o`0001GoYZnX0ol0001Qooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05?ooooo0ol0000MokB>S0?o00005onLN8l2o`00013ob;>;2?l0
000AojKVXP;o00002oncRi43o`0000Co/h^A0ol0000?ok>;T@;o00001_ncZ/d5o`0000Co/j[=00?o
0000ok>ZcOncZ/d02?ncZ/d2o`0000conL7`0ol00002okN`e@03o`000?ng/=Go]k3E00;o]k3E00Ko
0000okN`eOng/=Go0000okN`eOl00003okN`e@?o00005onQV8X2o`0000?o/:^U00Co0000ok2[YOn`
ZjGo/:^U1Ol00003ok2[Y@03o`000?n`ZjGo/:^U00;o/:^U0ol0000:ohnQZ`;o00002OoIa^`01Ol0
003ofLK/omW6k?oIa^co000000?ofLK/00Go0000omW6k?oIa^cofLK/o`00000;omW6k0;o0000;?nS
X;@2o`0002Go`<Zn0_l0000Sokg?`@So00007?nVWZL4o`0001?oYZnX0_l0001Rooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo05?ooooo0_l0000OokB>S0?o00005_nLN8l2
o`0000cob;>;2?l0000EojKVXP;o00002_ncRi401Ol0003o/h^Aok>;TOncRi7o000000Co/h^A00?o
0000ok>;TOncRi403_ncRi43o`0001Wo/j[=0_l0000;ooW1l0?o00000ong/=D00ol0003o]k3EokN`
e@02okN`e@04o`000?ng/=Go]k3Eo`0000Go]k3E0ol0000Goj6HRP;o00000on`ZjD01Ol0003o/:^U
ok2[YOn`ZjGo000000;o/:^U00?o0000ok2[YOn`ZjD00on`ZjD00ol0003o/:^Uok2[Y@02ok2[Y@?o
00002On?XJ/2o`0000WofLK/00Co0000omW6k?oIa^cofLK/1?l00004omW6k003o`000?oIa^cofLK/
00WofLK/0_l0000/oj>P]0;o00009Oo0b[h2o`0000go_Lo11Ol00002okg?`@?o00000_nmcl45o`00
00Oo_Lo11Ol0000NojJNY`Co00004_nV[jP2o`0006;ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Doooool2o`00023o]8j<0ol0000EoiahS`;o00002?o8/h/9o`0001So
Y^JR0_l0000>ok>;T@03o`000?ncRi7o000000Co00004?ncRi42o`0001Wo/j[=0ol00009ooW1l0?o
00001?ng/=D00ol0003o]k3EokN`e@02okN`e@04o`000?ng/=Go]k3Eo`0000Go]k3E1?l0000Foj6H
RP;o00000on`ZjD00ol0003o/:^Uok2[Y@02ok2[Y@03o`000?n`ZjGo000000;o/:^U00Go0000ok2[
YOn`ZjGo/:^Uo`000004ok2[Y@?o00002?n?XJ/2o`0000WofLK/00Go0000omW6k?oIa^cofLK/o`00
0007omW6k003o`000?oIa^cofLK/00WofLK/0_l0000/oj>P]0;o00009Oo0b[h2o`0000ko_Lo100Ko
0000okg?`Onmcl7o0000okg?`Ol00003okg?`@04o`000?nmcl7o_Lo1o`0000;o_Lo100?o0000okg?
`Onmcl401onmcl42o`00027oYYjW0ol0000@ojJ_Z0?o0000H_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Cooooo`;o00008OndSX`2o`0001CoW7R?0ol00004olRcR`Wo
00007?nViZ82o`0000ko/h^A00?o0000ok>;TOl000000_ncRi400ol0003o/h^Aok>;T@0?ok>;T@;o
00006_ncZ/d2o`0000WonL7`0_l00005okN`e@03o`000?ng/=Go]k3E00;o]k3E00Go0000okN`eOng
/=Go0000okN`e@04o`0000;o]k3E0_l0000Foj6HRP;o00000_n`ZjD2o`0000Go/:^U0_l00002ok2[
Y@05o`000?n`ZjGo/:^Uok2[YOl000001On`ZjD3o`0000OoSj6[0_l00008omW6k0;o00001?oIa^`0
0ol0003ofLK/omW6k003omW6k0;o00002ooIa^`2o`0002coXj2d0ol0000Tol3:_P;o00003onmcl40
0ol0003o_Lo1okg?`@05okg?`@05o`000?nmcl7o_Lo1okg?`Ol000002_nmcl43o`0002;oYYjW1?l0
000=ojJ_Z0?o0000Hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1C
ooooo`;o00008OndSX`3o`0001?oW7R?0_l000000oo8/h_o0000o`000007o`00023oY^JR0ol00009
ok>;T@Co00000oncRi400ol0003o/h^Ao`00000Aok>;T@?o00006OncZ/d2o`0000SonL7`0ol00004
okN`e@;o00001?ng/=D01_l0003o]k3EokN`eOl0003o]k3Eo`0000Go]k3E0ol0000Eoj6HRP;o0000
0on`ZjD00ol0003o/:^Uok2[Y@04ok2[Y@04o`000?n`ZjGo/:^Uok2[Y@?o00001on`ZjD3o`0000Ko
Sj6[0_l00009omW6k003o`000?oIa^cofLK/00?ofLK/0_l00004omW6k003o`000?oIa^cofLK/00So
fLK/0ol0000]oj>P]0Co00008_o0b[h2o`00013o_Lo100?o0000okg?`Onmcl400_nmcl42o`0000Go
_Lo100?o0000okg?`Onmcl401onmcl42o`0002CoYYjW1?l0000;ojJ_Z0Co0000Hoooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Cooooo`;o00008_ndSX`4o`00013oW7R?
2Ol0000UojKVXP;o00002OncRi400ol0003o/h^Aok>;T@05ok>;T@;o00004_ncRi42o`0001Wo/j[=
0ol00006ooW1l0?o00001_ng/=D00ol0003o]k3EokN`e@03okN`e@;o00000_ng/=D5o`0000;o]k3E
0_l0000Doj6HRP?o00006On`ZjD3o`0000GoSj6[0_l0000PomW6k0;o00004OnSX;@3o`0000?oXj2d
0_l00005oj>P]0;o00003_nSX;@7o`0001ko`<Zn0ol0000=okg?`@05o`000?nmcl7o_Lo1okg?`Ol0
00001Onmcl400ol0003o_Lo1o`000003okg?`@03o`000?nmcl7o_Lo100Go_Lo10ol0000VojJNY`?o
00002?nV[jP4o`0006Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
Doooool2o`0002;o]8j<1ol0000;oiahS`Oo00006?nViZ85o`0000;oY^JR0ol00007ojKVXP;o0000
2OncRi45o`0000Co/h^A00?o0000ok>;TOncRi404?ncRi42o`0001Wo/j[=2ol0000HokN`e@?o0000
4onQV8X2o`0001_o/:^U0ol00004ohnQZ`;o00008?oIa^`2o`0001;oXj2d00?o0000oj>P]?nSX;@0
1?nSX;@01Ol0003oXj2doj>P]?nSX;Co000000;oXj2d00?o0000oj>P]?nSX;@02_nSX;@3o`000003
ojSGf_l0003o000000Go00006oo0b[h2o`0000ko_Lo100Oo0000okg?`Onmcl7o_Lo1o`000?nmcl7o
000000?o_Lo100?o0000okg?`Ol000000onmcl400ol0003o_Lo1okg?`@05okg?`@;o0000:?nVWZL4
o`0000GoYZnX1?l0001Vooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
05?ooooo0_l0000QokB>S0?o000000?oZZjEo`000?l000001Ol00005oiahS`Ko00000_o4aMP3o`00
01SoY^JR00Ko0000ojKVX_nViZ;o0000ojKVX_l00003ojKVXP03o`000?nViZ;oY^JR00CoY^JR0_l0
000Uok>;T@;o00006?ncZ/d=o`0001So]k3E0_l0000Coj6HRP;o00007?n`ZjD3o`0000?oSj6[0_l0
000PomW6k0;o00004_nSX;@00ol0003oXj2doj>P]005oj>P]004o`000?nSX;CoXj2do`0000;oXj2d
00?o0000oj>P]?nSX;@02OnSX;@3o`0000GoZ=OJ1ol0000Hol3:_PKo00002onmcl43o`0000?o_Lo1
0ol00003okg?`@?o00001onmcl43o`0000CoYYjW1Ol00003ojJNY`?o00000_nVWZL3o`0001GoYYjW
1?l00002ojJ_Z0Co0000J?ooool00ol0003oooooooooo`08ooooo`001oooool3o`0000Cooooo0_l0
000:ooooo`03o`000?oooooooooo05?ooooo0_l0000PokB>S0?o00001OnZ[YD=o`0000Goa<GH0ol0
000HojKVXP03o`000?nViZ;oY^JR00GoY^JR00?o0000ojKVX_nViZ801?nViZ82o`0002Go/h^A0ol0
000Fok>Zc@?o00002OnZe:T3o`0001Oo]k3E0ol0000Boj6HRP;o00007On`ZjD3o`0000;oSj6[0_l0
000PomW6k0;o00004_nSX;@00ol0003oXj2doj>P]002oj>P]0Co00000_nSX;@01?l0003oXj2doj>P
]?l0000:oj>P]0?o00002OnXemX8o`0001?o`<Zn3_l0000Jokg?`@;o00001_nVWZL01?l0003oYYjW
ojJNYol00004ojJNY`04o`000?nVWZOoYYjWo`0000?oYYjW00?o0000ojJNYonVWZL05?nVWZL7o`00
06Wooooo00?o0000ooooooooool02?ooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0Doooool2o`0000ko]8j<1Ol0000<
okB>S0?o00002OnZ[YD7o`0000Woa<GH0ol0000HojKVXP03o`000?nViZ;oY^JR00;oY^JR0_l00007
ojKVXP;o00009_ncRi42o`0001Co/j[=1?l0000;oj[DZ@?o00005ong/=D2o`0001;oXIR:0_l0000N
ok2[Y@Oo00007ooIa^`2o`0001;oXj2d00Go0000oj>P]?nSX;CoXj2do`000003oj>P]004o`000?nS
X;CoXj2do`0000;oXj2d00?o0000oj>P]?nSX;@01onSX;@3o`0000goZ=OJ2?l0000?ol3:_P?o0000
1?mhP6d@o`0001;o_Lo10_l00007ojJNY`04o`000?nVWZOoYYjWojJNY`Go00001OnVWZL00ol0003o
YYjWojJNY`0EojJNY`Co0000Joooool00ol0003oooooooooo`08ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00002Oooool5o`00057ooooo0_l0000?okB>
S004o`000?ndSXco]8j<o`0000_o]8j<0ol0000=ojZ^U@;o00003?o4aMP3o`0001CoY^JR00Go0000
ojKVX_nViZ;oY^JRo`000005ojKVXP03o`000?nViZ;oY^JR00CoY^JR0_l0000Vok>;T@;o00004onc
Z/d4o`0000goZ]BY0ol0000FokN`e@?o00004?nQV8X3o`0001_o/:^U2ol0000NomW6k0;o00004OnS
X;@2o`0000?oXj2d00Go0000oj>P]?nSX;CoXj2do`000002oj>P]004o`000?nSX;CoXj2do`0000So
Xj2d0ol0000BojSGfPOo00002oo0b[h3o`0000coN81]4?l0000:okg?`@?o00002?nVWZL01?l0003o
YYjWojJNYol00002ojJNY`03o`000?nVWZOoYYjW00CoYYjW00?o0000ojJNYonVWZL05_nVWZL2o`00
06Sooooo1Ol0000:ooooo`001_ooool4o`0000?ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`1Cooooo`?o00003ondSX`00ol0003o]8j<okB>S00:okB>S0?o00003_nZ[YD2o`00
00goa<GH0ol0000CojKVXP07o`000?nViZ;oY^JRojKVX_l0003oY^JRo`000003ojKVXP03o`000?nV
iZ;oY^JR00CoY^JR0_l0000Vok>;T@;o00004_ncZ/d3o`00013oZ]BY0ol0000FokN`e@;o00004?nQ
V8X2o`0001Wo/:^U1ol00005ojUk[@Co00007?oIa^`2o`0001;oXj2d00?o0000oj>P]?nSX;@00_nS
X;@3o`0000CoXj2d0_l00008oj>P]0?o00005_nXemX7o`0000Oo`<Zn0ol0000EogR0K@oo00000onm
cl42o`0000KoYYjW00Go0000ojJNYonVWZOoYYjWo`000002ojJNY`03o`000?nVWZOo000000;oYYjW
1?l0000IojJNY`;o0000K?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0E?ooool2o`00013o]8j<
00?o0000okB>S?ndSX`02?ndSX`3o`0000ooZZjE0_l0000>olC5f0?o00004onViZ83o`0000?oY^JR
0ol00007ojKVXP;o00009_ncRi43o`0000oo/j[=1?l0000Boj[DZ@?o00005Ong/=Dao`0000WoZG^]
1?l0000JomW6k0Co00009_nSX;@3o`0001[oZ=OJ1ol00003ol3:_P?o00007OmhP6d=o`0000KoYYjW
00Go0000ojJNYonVWZOoYYjWo`000003ojJNY`;o00000_nVWZL00ol0003oYYjWojJNY`0IojJNY`?o
0000K?ooool00ol0003oooooooooo`08ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool0E?ooool2o`0000go]8j<00Go0000okB>S?nd
SXco]8j<o`000008okB>S0?o00004?nZ[YD2o`0000ooa<GH0ol0000RojKVXP?o00009_ncRi42o`00
00ko/j[=1?l0000Doj[DZ@Co00004Ong/=D`o`0000koZG^]0ol0000GomW6k0Oo00009?nSX;@3o`00
01koZ=OJ2Ol0000UogR0K@Go00002?nVWZL3o`0000GoYYjW00?o0000ojJNYonVWZL01Ol0000GojJN
Y`;o0000KOooool00ol0003oooooooooo`08ooooo`002?ooool2o`0000Cooooo0_l0000:ooooo`03
o`000?oooooooooo05Cooooo0_l0000=okB>S005o`000?ndSXco]8j<okB>S?l000001ondSX`3o`00
017oZZjE0_l0000@olC5f0?o00007onViZ88o`0002?o/h^A0_l0000<ok>Zc@Co00005onZe:T4o`00
00ko]k3E1Ol0000AoiAnU`;o00006?o7[[<2o`0000ooZG^]1?l0000ComW6k0Go00000_nZOX84o`00
027oXj2d0ol0000RojSGfPGo0000:OmhP6d3o`0002koYYjW0_l0001]ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo05Cooooo0_l0000>okB>S0?o00001ondSX`3o`0001;o
ZZjE0_l0000AolC5f0?o00007OnViZ84o`000003ogjfY_l0003o000000Go00008?ncRi43o`0000[o
/j[=1?l0000Joj[DZ@?o00002ong/=D5o`0001?oU7jG0_l0000HolN^/`;o00004?nYNjd4o`00013o
fLK/1Ol00005ojYnPPGo00007onSX;@2o`0002;oZ=OJ0ol000000oo?kLSo0000o`00000ZogR0K@;o
0000;_nVWZL2o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
E?ooool2o`0001Oo]8j<0ol0000CojZ^U@;o00004_o4aMP3o`0001[oY^JR1_l00004ogjfYPKo0000
7oncRi42o`0000Wo/j[=0ol0000=oj[DZ@;o00001OnZe:T2o`0000OoZ]BY0ol00009okN`e@Co0000
5OnDOYL3o`0001Ooajjc0_l0000BojUk[@Co00003?oIa^`5o`0000WoZWj21?l0000Moj>P]0?o0000
8OnXemX3o`0000;ocng80ol0000YogR0K@?o0000;?nVWZL3o`0006gooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0E?ooool2o`0001Ko]8j<0ol0000DojZ^U@;o00002?o4
aMP3o`0000Coa<GH0ol000001?o4aMSo0000o`000?l0000GojKVXPGo000000CoaIfRo`000?l0003o
00001_mn]ZH6o`0001co/h^A0_l00007ok>Zc@Co00004?nZe:T01Ol0003oZ]BYoj[DZOnZe:Wo0000
00;oZ]BY00?o0000oj[DZOnZe:T01OnZe:T3o`0000Ko]k3E1?l0000HoiAnU`;o00005oo7[[<2o`00
01?oZG^]1?l0000:omW6k0Co00003OnZOX84o`0001[oXj2d0ol0000QojSGfP?o00001?o?kLP2o`00
02[oN81]0_l0000[ojJNY`?o0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Dooooo`;o00005OndSX`3o`0000_oZZjE0ol00007ojZ^U@;o00002Oo4aMP00ol0003o
a<GHolC5f004olC5f004o`000?o4aMSoa<GHolC5f0?o00005OnViZ84o`0000CoaIfR0_l00008ogjf
YPOo00006OncRi42o`0000Ko/j[=1?l0000Boj[DZ@04o`000?nZe:WoZ]BYo`0000;oZ]BY00?o0000
oj[DZOnZe:T01_nZe:T3o`0000?o]k3E1Ol0000IoiAnU`;o00005oo7[[<2o`0001GoZG^]0ol00007
omW6k0Co00004?nZOX85o`0001OoXj2d0ol0000QojSGfP?o00001Oo?kLP2o`0002[oN81]0_l0000Y
ojJNY`Go0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Doooo
o`;o00005?ndSX`3o`0000_oZZjE00Go0000ojZ^UOnZ[YGoZZjEo`000006ojZ^U@;o00002Oo4aMP0
1?l0003oa<GHolC5f?o4aMP5o`0000?oa<GH0ol0000BojKVXPCo00001_o5WJ82o`0000_oO[JV1ol0
000Fok>;T@?o00001?ncZ/d3o`00017oZ]BY1?l00002oj[DZ@04o`000?nZe:WoZ]BYo`0000WoZ]BY
2?l0000KoiAnU`;o00005oo7[[<2o`0001KoZG^]1?l00003omW6k0Go00004onZOX84o`0001GoXj2d
0ol0000QojSGfP?o00001_o?kLP3o`0000coN81]1Ol00002ogR0K@?o00001?mhP6d2o`0000goN81]
1?l0000TojJNY`Wo0000KOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Dooooo`;o00004ondSX`3o`00013oZZjE00?o0000ojZ^UOnZ[YD01?nZ[YD2o`0000Woa<GH00Go
0000olC5f?o4aMSoa<GHo`000002olC5f003o`000?o4aMSoa<GH00?oa<GH0ol0000?ojKVXPGo0000
1oo5WJ82o`0000koO[JV1_l0000Dok>;T@Wo00004OnZe:T01Ol0003oZ]BYoj[DZOnZe:Wo000000;o
Z]BY00Co0000oj[DZOnZe:Wo00002_nZe:T5o`0001goU7jG0_l0000GolN^/`;o00001_nYNjd3o`00
00?oZG^]0ol00003ojUk[@?o00000_nYNjd9o`0001OoZWj21?l0000Boj>P]0?o00008OnXemX3o`00
00Socng80_l0000=ogR0K@06o`000?mhP6goN81]o`000?mhP6go00000omhP6d01?l0003oN81]ogR0
KOl00002ogR0K@03o`000?mhP6goN81]00[oN81]1Ol0000QojJNY`Ko00000onWLX/2o`0006gooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E?ooool2o`0001;o]8j<0ol0
000AojZ^U@03o`000?nZ[YGoZZjE00CoZZjE0_l00009olC5f003o`000?o4aMSoa<GH00;oa<GH00?o
0000olC5f?l000001_o4aMP3o`0000goY^JR1?l00009olFMXP;o00004Omn]ZH6o`00013o/h^A2_l0
000Aoj[DZ@05o`000?nZe:WoZ]BYoj[DZOl000000_nZe:T01?l0003oZ]BYoj[DZOl0000;oj[DZ@;o
00007onDOYL3o`0001Koajjc0_l00007ojUk[@05o`000?nYNjgoZG^]ojUk[Ol000000onYNjd01Ol0
003oZG^]ojUk[OnYNjgo000000GoZG^]1Ol0000JojYnPPCo00004?nSX;@3o`00027oZ=OJ0ol00009
olo]b0;o00003_mhP6d00ol0003oN81]ogR0K@05ogR0K@04o`000?mhP6goN81]o`0000;oN81]00?o
0000ogR0KOmhP6d02OmhP6d3o`000004okKT[ol0003o0000o`0001koYYjW1Ol00006ojMbR`?o0000
K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Dooooo`;o00004Ond
SX`3o`0000koZZjE1?l00007ojZ^U@;o00002?o4aMP2o`0000Goa<GH0_l00007olC5f0?o00002_nV
iZ84o`0000_oaIfR0ol0000BogjfYPOo00003?ncRi43o`0000Koa=>M0ol0000Aoj[DZ@?o00001?nZ
e:T2o`0000_oZ]BY0ol0000PoiAnU`;o00005_o7[[<2o`0000OoZG^]00?o0000ojUk[OnYNjd01OnY
Njd01Ol0003oZG^]ojUk[OnYNjgo000000KoZG^]0_l0000NojYnPPCo00003OnSX;@3o`00027oZ=OJ
0ol0000:olo]b0;o00003omhP6d00ol0003oN81]ogR0K@02ogR0K@;o00000omhP6d01?l0003oN81]
ogR0KOl0000:ogR0K@?o00000onfi:l3o`0001[oYYjW1_l00009ojMbR`;o0000K?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Dooooo`?o00003ondSX`3o`0000ooZZjE
00?o0000ojZ^UOnZ[YD02?nZ[YD2o`0000Woa<GH00?o0000olC5f?o4aMP01?o4aMP00ol0003oa<GH
olC5f006olC5f0?o00002?nViZ84o`0000goaIfR0_l0000EogjfYPKo00002?ncRi44o`0000Soa=>M
0ol0000Toj[DZ@;o00001_nDOYL3o`0000?oU7jG0ol00003oiAnU`?o00003?nDOYL2o`0001Koajjc
0_l00007ojUk[@03o`000?nYNjgoZG^]00GoZG^]00Go0000ojUk[OnYNjgoZG^]o`000006ojUk[@;o
00007onZOX85o`0000SoXj2d1Ol00008ojSGfPGo00000onXemX2o`0000CoZ=OJ00?o0000ojSGf_nX
emX02?nXemX3o`0000_ocng80ol0000;ogR0K@05o`000?mhP6goN81]ogR0KOl000001OmhP6d01?l0
003oN81]ogR0KOl00002ogR0K@03o`000?mhP6goN81]00OoN81]0ol00005okKT[`?o00005onVWZL6
o`0000_oYg:;0_l0001/ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
05Gooooo0ol0000=okB>S0?o00004?nZ[YD5o`0000KoZZjE0_l0000JolC5f0?o00001OnViZ84o`00
00ooaIfR0_l0000HogjfYPKo00001?ncRi44o`0000[oa=>M0ol0000Soj[DZ@;o00001onDOYL00ol0
003oU7jGoiAnU`03oiAnU`05o`000?nDOYOoU7jGoiAnUol000000onDOYL00ol0003oU7jGoiAnU`09
oiAnU`;o00005_o7[[<2o`0000OoZG^]00Co0000ojUk[OnYNjgoZG^]1?l00004ojUk[@03o`000?nY
NjgoZG^]00?oZG^]1?l0000PojYnPPCo00000_nSX;@9o`0000[oZ=OJ00Co0000ojSGf_nXem[o0000
0_nXemX01?l0003oZ=OJojSGf_l00003ojSGfP03o`000?nXem[oZ=OJ00OoZ=OJ0ol0000=olo]b0;o
00002omhP6d01ol0003oN81]ogR0KOmhP6go0000ogR0KOl000000omhP6d01?l0003oN81]ogR0KOl0
0002ogR0K@03o`000?mhP6goN81]00KoN81]0ol00007okKT[`?o00005?nVWZL5o`0000koYg:;0ol0
001[ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Kooooo0ol0000;
okB>S0?o00007?nZ[YD2o`0001_oa<GH0ol00002ojKVXPGo00004?o5WJ82o`0001[oO[JV2_l0000=
olCCW@?o00008OnZe:T3o`0000OoU7jG00?o0000oiAnUonDOYL00onDOYL01Ol0003oU7jGoiAnUonD
OYOo000000?oU7jG00?o0000oiAnUonDOYL02OnDOYL2o`0001Koajjc0_l00006ojUk[@;o00000onY
Njd00ol0003oZG^]ojUk[@04ojUk[@;o00001?nYNjd5o`0002;oZWj22_l000001?nXa9ko0000o`00
0?l0000:ojSGfP03o`000?nXem[oZ=OJ00;oZ=OJ00Co0000ojSGf_nXem[o00001?nXemX00ol0003o
Z=OJojSGfP05ojSGfP?o00003_o?kLP2o`0000coN81]0ol00003ogR0K@?o00001?mhP6d2o`0000So
N81]0ol00009okKT[`?o00004OnVWZL5o`00017oYg:;0_l0001[ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo05Oooooo0ol00009okB>S0?o00007OnZ[YD2o`0001coa<GH
1ol0000BolFMXP;o00007Omn]ZH6o`0000ooa=>M0ol0000Poj[DZ@;o00002?nDOYL00ol0003oU7jG
oiAnU`03oiAnU`04o`000?nDOYOoU7jGoiAnU`Co00003?nDOYL3o`0001Goajjc0_l00007ojUk[@04
o`000?nYNjgoZG^]ojUk[@Go00000onYNjd01?l0003oZG^]ojUk[OnYNjd3o`000004ogf8R?l0003o
0000o`0002;oZWj21?l00007ojS4WP?o00002_nXemX01Ol0003oZ=OJojSGf_nXem[o000000;oZ=OJ
00?o0000ojSGf_nXemX00_nXemX00ol0003oZ=OJojSGfP04ojSGfP?o00003oo?kLP3o`00027oN81]
0ol0000;okKT[`?o00003OnVWZL6o`0001?oYg:;0ol0001Zooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05Sooooo0ol00005okB>S0Go00007_nZ[YD2o`0001goa<GH1?l0
000DolFMXP?o00007omn]ZH2o`00017oa=>M0ol0000Ooj[DZ@?o00001onDOYL00ol0003oU7jGoiAn
U`03oiAnU`05o`000?nDOYOoU7jGoiAnUol000004?nDOYL2o`0001Goajjc0_l0000FojUk[@?o0000
0ommR8P2o`0002;oZWj20_l0000:ojS4WP?o00001_nXemX01Ol0003oZ=OJojSGf_nXem[o000000;o
Z=OJ00Co0000ojSGf_nXem[o00001OnXemX00ol0003oZ=OJojSGfP02ojSGfP?o00004Oo?kLP2o`00
023oN81]0ol0000=okKT[`?o00002_nVWZL6o`0001KoYg:;0_l0001Zooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo05Wooooo0ol000000ondSXco0000o`000009o`0001_o
ZZjE0_l0000NolC5f0;o00005_o5WJ82o`0001ooO[JV0_l0000BolCCW@?o00007OnZe:T5o`0000Go
U7jG0_l00004oiAnU`;o00001?nDOYL00ol0003oU7jGoiAnU`0=oiAnU`;o00005Oo7[[<2o`0001Go
ZG^]0ol00004ogf8R0?o00000onZOX83o`0000CoZWj200?o0000ojYnP_nZOX800_nZOX83o`0000ko
ZWj20ol0000;ojS4WP?o00001OnXemX01Ol0003oZ=OJojSGf_nXem[o000000;oZ=OJ00Ko0000ojSG
f_nXem[o0000ojSGf_l00003ojSGfP04o`000?nXem[oZ=OJojSGfP?o00004_o?kLP2o`0001ooN81]
0ol0000?okKT[`?o00001onVWZL5o`0001WoYg:;0ol0001Yooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05[ooooo1ol00003olN/i@Ko00006OnZ[YD2o`0001goa<GH0ol0
000FolFMXP;o00007_mn]ZH3o`0001?oa=>M0ol0000Koj[DZ@?o000000CobI6Qo`000?l0003o0000
1OnDOYL00ol0003oU7jGoiAnU`03oiAnU`03o`000?nDOYOoU7jG00?oU7jG0_l0000=oiAnU`;o0000
5Oo7[[<2o`0001CoZG^]0ol00006ogf8R0;o00001?nZOX800ol0003oZWj2ojYnPP03ojYnPP05o`00
0?nZOX;oZWj2ojYnP_l000000onZOX800ol0003oZWj2ojYnPP0;ojYnPP;o00003OnXa9h3o`0000Go
Z=OJ0ol00004ojSGfP;o00000_nXemX5o`0000;oZ=OJ0ol0000Colo]b0;o00007_mhP6d3o`00017o
]^B_0ol00003ojJNY`Ko00007?nWLX/2o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Foooool3o`0000WoajcU1Ol0000GojZ^U@;o00007?o4aMP5o`0001GoaIfR
0_l0000NogjfYP;o00005Oo4did3o`0001WoZ]BY0ol00003olVAX@?o00007onDOYL2o`0001Goajjc
0_l0000CojUk[@?o00001ommR8P3o`0000?oZWj200?o0000ojYnP_nZOX801?nZOX800ol0003oZWj2
ojYnPP04ojYnPP03o`000?nZOX;oZWj200_oZWj20_l0000>ojS4WP?o00005OnXemX3o`0001Cocng8
0ol0000LogR0K@?o00004onfi:l9o`0001koYg:;0_l0001Yooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05_ooooo0_l0000<olN/i@Ko00005?nZ[YD2o`0001_oa<GH0ol0
00001?nfVG7o0000o`000?l0000DolFMXP;o00001_mn]ZH3o`0000;oO[JV0ol0000@ogjfYP;o0000
5_o4did3o`0001OoZ]BY0ol00005olVAX@?o00007_nDOYL5o`0000Coajjc0ol00002olN^/`?o0000
1_o7[[<2o`0001?oZG^]0_l00009ogf8R0;o00000onZOX800ol0003oZWj2ojYnPP04ojYnPP03o`00
0?nZOX;oZWj200CoZWj200?o0000ojYnP_nZOX802onZOX82o`0000ooZ<BN0ol0000CojSGfP?o0000
5_o?kLP2o`0001_oN81]0ol0000EokKT[`Go00008OnWLX/3o`0006Sooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Foooool2o`0000koajcU1_l0000BojZ^U@;o00006_o4
aMP3o`0000?o]YUa0_l0000DolFMXP?o00001_mn]ZH01?l0003oO[JVogjfY_l00003ogjfYP03o`00
0?mn]ZKoO[JV00goO[JV0_l0000GolCCW@?o00005_nZe:T2o`0000OobI6Q0ol0000NoiAnU`?o0000
1_o7[[<01?l0003oajjcolN^/ol00003olN^/`03o`000?o7[[?oajjc00?oajjc0_l0000BojUk[@?o
00002OmmR8P3o`0000;oZWj200?o0000ojYnP_nZOX801OnZOX800ol0003oZWj2o`000003o`0000go
ZWj20ol0000@ojS4WP?o00004OnXemX3o`0001Oocng80_l0000JogR0K@?o00005onfi:l2o`0002Co
Yg:;0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo
0_l0000AolN/i@Go00004?nZ[YD2o`0001Woa<GH0ol00004okJIL@?o00005?o5WJ82o`0000?oO[JV
1Ol00005ogjfYP03o`000?mn]ZKoO[JV00goO[JV0_l0000HolCCW@?o00005?nZe:T3o`0000SobI6Q
0ol0000MoiAnU`?o00000oo7[[<5o`0000Goajjc00?o0000olN^/oo7[[<00oo7[[<2o`00017oZG^]
0ol0000;ogf8R0;o000000?oZWj2o`000?l000000onZOX801ol0003oZWj2ojYnP_nZOX;o0000ojYn
P_l000004?nZOX82o`0001;oZ<BN0ol0000?ojSGfP?o00006?o?kLP2o`0001WoN81]0ol0000HokKT
[`;o00009?nWLX/2o`0006Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Foooool2o`0001?oajcU1_l0000<ojZ^U@Co00005oo4aMP3o`0000Ko]YUa0ol0000ColFMXP;o
00000omn]ZH01?l0003oO[JVogjfY_l00006ogjfYP03o`000?mn]ZKoO[JV00coO[JV0ol0000IolCC
W@?o00004_nZe:T3o`0000[obI6Q0ol0000LoiAnU`?o00000oo7[[<01?l0003oajjcolN^/ol00004
olN^/`;o00001_o7[[<2o`00013oZG^]0ol0000<ogf8R0?o000000?oZWj2o`000?nZOX800_nZOX85
o`000003ojYnP_l0003o000000?o00003?nZOX82o`0001?oZ<BN0_l0000>ojSGfP?o00006Oo?kLP3
o`0001OoN81]0ol0000IokKT[`;o00008onWLX/3o`0006Sooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Foooool2o`0001GoajcU1_l00008ojZ^U@So00005?o4aMP3o`00
00So]YUa0_l0000ColFMXP;o00001?mn]ZH00ol0003oO[JVo`000002ogjfYPCo00003omn]ZH2o`00
01_oa=>M0ol0000@oj[DZ@?o00003?o9TJ43o`0001_oU7jG0ol00004olN^/`03o`000?o7[[?o0000
00Koajjc00?o0000olN^/oo7[[<00oo7[[<2o`0000ooZG^]0ol0000>ogf8R0;o00007?nZOX82o`00
01?oZ<BN0ol0000<ojSGfP?o00006oo?kLP2o`0001KoN81]0ol0000JokKT[`;o00008onWLX/2o`00
06Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Foooool2o`0001So
ajcU1Ol00005ojZ^U@Co00000_nR/gd6o`00013oa<GH0ol00009okJIL@?o00004_o5WJ82o`0000Go
O[JV0_l00002ogjfYP03o`000?mn]ZKoO[JV013oO[JV0_l00007olCCW@03o`000?o4digoa=>M00;o
a=>M0ol0000=olCCW@?o00003_nZe:T3o`0000kobI6Q0ol0000JoiAnU`?o00001Oo7[[<2o`0000;o
ajjc00Go0000olN^/oo7[[?oajjco`000005olN^/`;o00003_nYNjd3o`0000ooOHR80ol0000JojYn
PP?o00005?nXa9h3o`0000[oZ=OJ2?l00002olo]b0?o00000_o?kLP5o`0000_ocng80_l0000EogR0
K@?o00006onfi:l2o`0002?oYg:;0_l0001Yooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo05_ooooo0_l0000JolN/i@[o00001_nR/gd6o`0000goa<GH0ol0000;okJIL@?o
00001?o5WJ83o`0000?oaIfR0ol00004olFMXP?o00001Omn]ZH00ol0003oO[JVogjfYP05o`0000ko
O[JV0_l00007olCCW@05o`000?o4digoa=>MolCCWOl000000oo4did00ol0003oa=>MolCCW@0;olCC
W@?o00003OnZe:T2o`00013obI6Q0ol0000JoiAnU`;o00001_o7[[<01?l0003oajjcolN^/oo7[[<3
o`0000Koajjc0_l0000;ojUk[@Go00004OmmR8P2o`0001[oZWj20_l0000FojS4WP?o00002?nXemX3
o`0000;ocng800Co0000olo]b?o?kLSo00000oo?kLP00ol0003ocng8olo]b002olo]b004o`000?o?
kLSocng8o`0000_ocng80ol0000CogR0K@?o00007?nfi:l2o`0002;oYg:;0ol0001Yooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0000LolN/i@Oo00002_nR
/gd5o`0000[oa<GH0ol0000=okJIL@;o00000oo5WJ801ol0003oaIfRolFMX_o5WJ;o0000olFMX_l0
00000oo5WJ800ol0003oaIfRolFMXP02olFMXP;o00006_mn]ZH3o`0000Soa=>M00?o0000olCCWOo4
did01?o4did00ol0003oa=>MolCCW@0<olCCW@?o00002onZe:T3o`00017obI6Q0ol0000IoiAnU`;o
00004oo7[[<2o`0000OoZG^]2?l0000Bogf8R0?o00006OnZOX82o`0001OoZ<BN0ol00006ojSGfP?o
00001?o?kLP00ol0003ocng8olo]b003olo]b003o`000?o?kLSocng800?ocng800?o0000olo]b?o?
kLP02oo?kLP4o`00017oN81]0ol000000onfi:oo0000o`000003o`0000;o]^B_0ol00003okKT[`?o
00003?nfi:l2o`0000GoYg:;1Ol00003ojMbR`?o00000_nWLX/3o`0000goYg:;0_l0001Zooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0000OolN/i@;o0000
3_nR/gd5o`0000Ooa<GH0ol0000>okJIL@?o00001_o5WJ800ol0003oaIfRolFMXP03olFMXP03o`00
0?o5WJ;oaIfR00;oaIfR0_l0000JogjfYP;o00002Oo4did00ol0003oa=>MolCCW@04olCCW@03o`00
0?o4digoa=>M00goa=>M0ol00009oj[DZ@?o00004oo9TJ43o`0001SoU7jG0_l0000ColN^/`;o0000
1?nYNjd8o`000004om;5^?l0003o0000o`0001;oOHR80_l0000HojYnPP?o00006?nXa9h3o`0000Co
Z=OJ0ol00006olo]b003o`000?o?kLSocng800;ocng800?o0000olo]b?o?kLP01?o?kLP00ol0003o
cng8olo]b009olo]b0Oo00003_mhP6d3o`0000?o]^B_00Ko0000okKT[onfi:oo0000okKT[ol00003
okKT[`03o`000?nfi:oo000000?o]^B_00?o0000okKT[onfi:l02Onfi:l2o`0000KoYg:;00Co0000
ojMbRonWLX_o00001?nWLX/01?l0003oYg:;ojMbRol00003ojMbR`03o`000?nWLX_oYg:;00[oYg:;
0_l0001Zooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0
000NolN/i@?o00004?nR/gd6o`0000?oa<GH0ol0000@okJIL@?o00000oo5WJ82o`0000CoaIfR0_l0
0005olFMXP;o00006_mn]ZH2o`0000[oa=>M00?o0000olCCWOl000000ol0000AolCCW@?o00001onZ
e:T3o`0001GobI6Q0ol0000GoiAnU`;o00004oo7[[<:o`0000Kod/Fh0_l0000Bogf8R0?o00005onZ
OX82o`0001[oZ<BN0ol00002ojSGfP?o00001?o?kLP01Ol0003ocng8olo]b?o?kLSo000000?ocng8
00Go0000olo]b?o?kLSocng8o`000003olo]b003o`000?o?kLSocng800Oocng80ol00002olO3d0Go
00002omhP6d3o`0000Go]^B_00?o0000okKT[onfi:l01Onfi:l00ol0003o]^B_o`000003okKT[`03
o`000?nfi:oo]^B_00Wo]^B_0_l00007ojMbR`04o`000?nWLX_oYg:;ojMbR`Go000000?oYg:;o`00
0?nWLX/00_nWLX/00ol0003oYg:;ojMbR`09ojMbR`?o0000J_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Jooooo`?o00007_o7[>D2o`0001?oX[=m2Ol0000BokJIL@?o
00001?o5WJ800ol0003oaIfRolFMXP03olFMXP03o`000?o5WJ;oaIfR00;oaIfR0_l0000JogjfYP;o
00001_o4did01ol0003oa=>MolCCWOo4digo0000olCCWOl000005Oo4did3o`0000KoZ]BY0_l0000G
olVAX@?o00005_nDOYL3o`00017oajjc2?l00009om;5^0;o00004ommR8P2o`0001OoZWj20_l0000K
ojS4WPKo00001Oo?kLP01Ol0003ocng8olo]b?o?kLSo000000;ocng80_l00003olo]b005o`000?o?
kLSocng8olo]b?l000002?o?kLP3o`0000Goal?@1Ol00008ogR0K@?o00001onfi:l00ol0003o]^B_
okKT[`02okKT[`;o00000_nfi:l4o`0000co]^B_0_l00008ojMbR`04o`000?nWLX_oYg:;o`0000;o
Yg:;00Co0000ojMbRonWLX_oYg:;0ol0000<ojMbR`;o0000Joooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Jooooo`;o00007oo7[>D2o`0001KoX[=m1Ol00004okJIL@Go
00000onfVG400ol0003o]YUaokJIL@05okJIL@?o00000oo5WJ800ol0003oaIfRo`000003olFMXP03
o`000?o5WJ;oaIfR00;oaIfR0ol0000IogjfYP;o00001_o4did5o`000003olCCWOl0003o000000?o
00004_o4did3o`0000CoZ]BY0ol0000HolVAX@?o00005_nDOYL2o`0000ooajjc1_l0000=om;5^0?o
00004_mmR8P2o`0001OoZWj20_l0000LojS4WPCo00001oo?kLP3o`0000Cocng800?o0000olo]b?o?
kLP00_o?kLP3o`0000Socng80ol00008olO3d0Co00001_mhP6d3o`0000Go]^B_00Go0000okKT[onf
i:oo]^B_o`000005okKT[`03o`000?nfi:oo000000oo]^B_0_l00005ojMbR`05o`000?nWLX_oYg:;
ojMbRol000000_nWLX/00ol0003oYg:;o`000002ojMbR`05o`000?nWLX_oYg:;ojMbRol000002onW
LX/2o`0006_ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0001Jooooo`;o00007_o7[>D3
o`0001SoX[=m0_l00006okJIL@04o`000?nfVG7o]YUao`0000?o]YUa00?o0000okJILOnfVG401Onf
VG46o`0000?oaIfR0ol00006olFMXP;o00006?mn]ZH3o`0002Coa=>M0ol00002oj[DZ@?o00006_o9
TJ4Jo`0000goajjc1Ol0000Aom;5^0;o00001?mmR8P3o`0000?oOHR80ol00003ogf8R0Go00005OnZ
OX83o`0001goZ<BN0_l0000Nolo]b0?o00002oo7`m04o`0000?oN81]0ol00006okKT[`07o`000?nf
i:oo]^B_okKT[ol0003o]^B_o`000003okKT[`04o`000?nfi:oo]^B_o`0000co]^B_1?l00005ojMb
R`05o`000?nWLX_oYg:;ojMbRol000000onWLX/2o`0000;oYg:;00Go0000ojMbRonWLX_oYg:;o`00
000:ojMbR`?o0000JOooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo05[ooooo0_l0000N
olN/i@;o00006OnR/gd2o`0000Oo]YUa00?o0000okJILOnfVG401?nfVG400ol0003o]YUaokJIL@05
okJIL@?o00003_o5WJ82o`0001SoO[JV0_l0000VolCCW@Ko00001Oo9TJ43o`0000CobI6Q0_l00003
olVAX@?o00001oo9TJ4Jo`0000_oajjc1Ol0000Com;5^0?o00001?mmR8P01Ol0003oOHR8ogf8R?mm
R8So000000?oOHR800?o0000ogf8R?l000000ommR8P2o`0001GoZWj20_l0000<ojS4WP?o00000onX
a9h2o`0000CoZ<BN0_l00004ojS4WP?o00007?o?kLP3o`0000goal?@2?l00008okKT[`?o00000onf
i:l3o`0000Co]^B_0_l00005okKT[`Wo00001_nWLX/3o`0000GoYg:;00Co0000ojMbRonWLX_oYg:;
0ol0000;ojMbR`;o0000K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Jooooo`;o00007_o7[>D2o`0001WoX[=m0_l00008okJIL@03o`000?nfVG7o]YUa00?o]YUa00?o
0000okJILOnfVG401_nfVG42o`0000koaIfR0_l0000HogjfYP;o00009oo4did4o`0000OobI6Q00?o
0000olVAXOo9TJ400_o9TJ401_l0003obI6QolVAXOl0003obI6Qo`0000?obI6Q00?o0000olVAXOo9
TJ400oo9TJ43o`0001KofJk60ol00008olN^/`Go00005_oBaKP2o`0000CoOHR800Go0000ogf8R?mm
R8SoOHR8o`000003ogf8R003o`000?mmR8So000000?oOHR80ol0000DojYnPP;o00003OnXa9h00ol0
003oZ<BNojS4WP04ojS4WP03o`000?nXa9koZ<BN00?oZ<BN00?o0000ojS4W_nXa9h00_nXa9h2o`00
01_ocng80ol0000@olO3d0Go00006Onfi:l:o`000004onJQ__l0003o0000o`0001ooYg:;0_l0001/
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05[ooooo0_l0000MolN/
i@?o00006OnR/gd3o`0000Co]YUa00Go0000okJILOnfVG7o]YUao`000005okJIL@03o`000?nfVG7o
]YUa00Go]YUa0ol0000=olFMXP;o00006?mn]ZH2o`0002Koa=>M1_l00006olVAX@03o`000?o9TJ7o
bI6Q00;obI6Q00Ko0000olVAXOo9TJ7o0000olVAXOl00003olVAX@03o`000?o9TJ7obI6Q00;obI6Q
0ol0000HomV^aP?o00001Oo7[[<5o`0001Sod/Fh0_l00004ogf8R004o`000?mmR8SoOHR8ogf8R0Co
00000_mmR8P4o`000003ogf8R?l0003o000001CoZWj20_l0000=ojS4WP03o`000?nXa9koZ<BN00Go
Z<BN00?o0000ojS4W_nXa9h00onXa9h01?l0003oZ<BNojS4W_nXa9h2o`0001[ocng80ol0000ColO3
d0;o00005_nfi:l9o`0000OoiZ6n0_l0000OojMbR`;o0000K?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Jooooo`;o00007Oo7[>D2o`0001_oX[=m0_l00004okJIL@07
o`000?nfVG7o]YUaokJILOl0003o]YUao`000003okJIL@03o`000?nfVG7o]YUa00Ko]YUa0ol0000<
olFMXP?o00005omn]ZH2o`0002Goa=>M0ol00002oiZGY@?o00001Oo9TJ400ol0003obI6QolVAX@02
olVAX@04o`000?o9TJ7obI6Qo`0000;obI6Q0ol00004olVAX@?o00006_oI[/H2o`0000?oajjc1Ol0
000Jom;5^0?o00000ommR8P01Ol0003oOHR8ogf8R?mmR8So000000GoOHR800?o0000ogf8R?mmR8P0
0_mmR8P3o`0001;oZWj20ol0000=ojS4WP03o`000?nXa9koZ<BN00;oZ<BN1?l00002ojS4WPCo0000
0onXa9h3o`0001Oocng81?l0000DolO3d0?o00004?nfi:l:o`0000_oiZ6n0ol0000MojMbR`?o0000
K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00007Oo7
[>D2o`0000goX[=m0_l0000<oj:cO@;o00001OnfVG43o`0000;o]YUa1Ol00009okJIL@;o00003Oo5
WJ82o`0001KoO[JV0ol0000TolCCW@?o00001?nJUjD3o`0000CobI6Q00?o0000olVAXOo9TJ400_o9
TJ401_l0003obI6QolVAXOl0003obI6Qo`0000?obI6Q00?o0000olVAXOo9TJ400ol0000KomV^aPSo
00007OoBaKP2o`0000;oOHR80_l00004ogf8R003o`000?mmR8SoOHR800?oOHR800?o0000ogf8R?mm
R8P00_mmR8P2o`0001;oZWj20_l0000>ojS4WP05o`000?nXa9koZ<BNojS4W_l000000onXa9h00ol0
003oZ<BNo`000003ojS4WP03o`000?nXa9koZ<BN00;oZ<BN0_l0000Folo]b0Co00005_o7`m03o`00
00_o]^B_2_l0000@onJQ_P;o00007OnWLX/2o`0006gooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0F_ooool2o`0000coajcU0ol0000=olN/i@?o00003onR/gd00ol0003o
X[=moj:cO@09oj:cO@;o00006?nfVG43o`0000_oaIfR7Ol0000RolCCW@?o00001_nJUjD3o`0000;o
bI6Q0_l00004olVAX@06o`000?o9TJ7obI6Qo`000?o9TJ7o00000oo9TJ400ol0003obI6Qo`000002
o`0001gofJk61Ol0000Oom;5^0?o00000_mmR8P00ol0003oOHR8ogf8R003ogf8R0;o00001?mmR8P2
o`0000;oOHR80ol0000AojYnPP;o00003OnXa9h2o`0000?oZ<BN00Oo0000ojS4W_nXa9koZ<BNo`00
0?nXa9ko000000?oZ<BN00?o0000ojS4W_nXa9h00_nXa9h2o`0001Gocng80ol0000IolO3d0;o0000
1onfi:l9o`0001GoiZ6n0_l0000MojMbR`;o0000KOooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Jooooo`;o00003Oo7[>D00ol0003oajcUolN/i@0<olN/i@;o00004OnR
/gd00ol0003oX[=moj:cO@08oj:cO@;o00006OnfVG43o`0000WoaIfR8Ol0000NolCCW@?o00002?nJ
UjD3o`0000;obI6Q00?o0000olVAXOo9TJ400oo9TJ42o`0000?obI6Q0ol000001?o9TJ7o0000o`00
0?l0000OomV^aP;o00008_oBaKP2o`0001?oOHR80_l0000AojYnPP;o00003_nXa9h00ol0003oZ<BN
ojS4WP02ojS4WP?o00000onXa9h3o`0000GoZ<BN0ol0000Colo]b0?o00006_o7`m03o`000003okKT
[ol0003o000000So00006OoVXKh5o`0001WoYg:;0ol0001]ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo05[ooooo0_l0000:olN/i@Go00003Oo7[>D2o`0000koX[=m1?l0
000:oj:cO@;o00006_nfVG42o`0000SoaIfR0ol0000HokbPaP;o000000?oUj6go`000?l000001Ol0
000JolCCW@?o00002_nJUjD3o`0000oobI6Q0ol0000PomV^aP;o00008_oBaKP3o`0001;oOHR80ol0
000?ojYnPP?o00008_nXa9h2o`0001;ocng80ol0000LolO3d0Wo00007_oVXKh8o`0001GoYg:;0_l0
001^ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05[ooooo0_l0000:
olN/i@04o`000?o7[>GoajcUo`0000goajcU0ol0000=oj:cO@05o`000?nR/ggoX[=moj:cOOl00000
2_nR/gd2o`0001[o]YUa0ol00006olFMXP?o00006OnlX<H2o`0000CoUj6g1ol0000FolCCW@?o0000
3?nJUjD4o`0000cobI6Q0ol0000QomV^aP;o00008ooBaKP2o`0001?oOHR80_l0000>ojYnPPCo0000
8_nXa9h2o`00017ocng80ol0000=olO3d0Go000000?oal?@o`000?l000000ol00002olO3d0?o0000
00Coal?@o`000?l0003o00008_oVXKh3o`000003ol_=]_l0003o000000Oo00004OnWLX/2o`0006ko
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool2o`0000_oajcU
00?o0000olN/iOl000003Oo7[>D2o`0000koX[=m00Go0000oj:cOOnR/ggoX[=mo`00000:oj:cO@?o
00006_nfVG46o`000004olFMX_l0003o0000o`0001[o_:360_l00007oiNQ]`So00004Oo4did3o`00
00koVYNU1?l0000:olVAX@?o00008_oI[/H2o`0000God/Fh0ol00003om;5^0?o00001?oBaKP3o`00
00kod/Fh0_l0000Cogf8R0?o00002_nZOX88o`00027oZ<BN0ol0000?olo]b0?o00003oo7`m001?l0
003oal?@olO3d?l00002olO3d006o`000?o7`m3oal?@o`000?o7`m3o00000oo7`m03o`0002?oiZ6n
0_l00006ol_=]PWo00003?nWLX/3o`0006kooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0F_ooool3o`0000_oajcU0_l0000=olN/i@;o00003onR/gd3o`0000coX[=m0_l0
000GokJIL@co00006onlX<H2o`0000[oUj6g2?l0000=olCCW@?o00004OnJUjD3o`0000SobI6Q0ol0
000SomV^aP;o00001_oBaKP01Ol0003od/Fhom;5^?oBaKSo000000?od/Fh00?o0000om;5^?oBaKP0
0_oBaKP00ol0003od/Fhom;5^00=om;5^0?o00004ommR8P2o`0000OoZWj21ol00002oj6C^@?o0000
8OnXa9h2o`0000kocng80ol0000AolO3d003o`000?o7`m3oal?@00?oal?@00?o0000olO3d?o7`m00
1Oo7`m04o`00027oiZ6n0ol0000:ol_=]PSo00002OnWLX/2o`0006oooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Foooool3o`0000_oajcU00?o0000olN/iOo7[>D02_o7
[>D3o`0001koX[=m0_l0000DokJIL@Oo00001?n0ZJP3o`0001_o_:360ol0000>oiNQ]`Oo00002Oo4
did3o`0001?oVYNU0ol00006olVAX@?o00009?oI[/H2o`0000Kod/Fh00?o0000om;5^?oBaKP01OoB
aKP00ol0003od/Fho`000004o`0000ood/Fh0_l0000Cogf8R0?o00000onZOX87o`0000KoXI>i1?l0
000OojS4WP;o00003Oo?kLP3o`0001?oal?@00?o0000olO3d?o7`m000oo7`m000ol0003oal?@olO3
d002olO3d0;o00000_o7`m02o`00027oiZ6n0_l0000?ol_=]PSo00001OnWLX/2o`0006oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0G?ooool3o`0001OoajcU0_l0000N
oj:cO@Co00004?nfVG47o`0000SoP:VX0_l0000KokbPaP;o00004_nGXKL7o`0000Goa=>M0ol0000E
oiZGY@?o00001?o9TJ43o`0002GofJk60_l00006om;5^003o`000?oBaKSod/Fh00God/Fh00?o0000
om;5^?l000000_oBaKP00ol0003od/Fhom;5^00>om;5^0?o00004ommR8P9o`0000[oXI>i1?l0000N
ojS4WP?o00002oo?kLP3o`00017oal?@00Oo0000olO3d?o7`m3oal?@o`000?o7`m3o000000?oal?@
00?o0000olO3d?o7`m000oo7`m001?l0003oal?@o`000?l0000PonJQ_P?o00004_o;cKH<o`0006oo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0GOooool3o`0001KoajcU
0_l0000Moj:cO@So00002onfVG46o`0000_oP:VX0_l0000KokbPaP;o00005OnGXKL7o`000004olCC
WOl0003o0000o`0001OoVYNU0ol00002olVAX@?o00002OoI[/H3o`0000?ofJk60ol00004omV^aP03
o`000?oI[/KofJk600gofJk60_l00006om;5^004o`000?oBaKSod/Fhom;5^0Co00000ooBaKP00ol0
003od/Fho`00000Aom;5^0;o00004ommR8P6o`0000ooXI>i0ol0000NojS4WP;o00002Oo?kLP4o`00
01;oal?@00Oo0000olO3d?o7`m3oal?@o`000?o7`m3o000000?oal?@00?o0000olO3d?l000000oo7
`m001?l0003oal?@o`000?l0000PonJQ_P;o00005oo;cKH7o`00073ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0G_ooool3o`0001CoajcU0ol0000Loj:cO@?o00000_nF
XXP6o`0000Ko]YUa1_l0000>oh2YZ0?o00006_nlX<H2o`0001SoUj6g1ol0000IoiZGY@Ko00002ooI
[/H00ol0003ofJk6omV^aP03omV^aP03o`000?oI[/KofJk600?ofJk600?o0000omV^a_oI[/H03OoI
[/H2o`0000God/Fh0_l00003om;5^003o`000?oBaKSod/Fh00God/Fh0_l0000Aom;5^0;o00005?mm
R8P2o`0001?oXI>i0ol0000MojS4WP;o00001oo?kLP8o`00017oal?@0ol00003olO3d0?o00000oo7
`m03o`0000;oal?@0_l0000OonJQ_P?o00006oo;cKH3o`00073ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0Goooool3o`0001?oajcU0_l0000Loj:cO@?o00001_nFXXP=
o`00017oP:VX0_l0000JokbPaP;o00006onGXKL3o`0001_oVYNU1?l0000<omV^aP03o`000?oI[/Ko
fJk600?ofJk600?o0000omV^a_oI[/H01?oI[/H00ol0003ofJk6omV^aP0<omV^aP;o00001_oBaKP0
1?l0003od/Fhom;5^?oBaKP5o`0000Cod/Fh00?o0000om;5^?oBaKP03ooBaKP3o`0001;oOHR80ol0
000Doj6C^@Ko00006OnXa9h3o`0000Cocng81Ol00002ok>Rf0Go00008?o7`m03o`0001koiZ6n0_l0
000Mol_=]P;o0000L?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1P
ooooo`;o00004oo7[>D2o`0001_oX[=m0ol00009oiJRR0So00005?n0ZJP2o`0001[o_:360_l00006
oiNQ]`?o00000onGXKL3o`0000goUj6g0_l0000LoiZGY@;o00003OoI[/H00ol0003ofJk6omV^aP03
omV^aP03o`000?oI[/KofJk600CofJk600?o0000omV^a_oI[/H03?oI[/H2o`0002Kod/Fh0_l0000A
ogf8R0?o00005_nQTkT;o`0001CoZ<BN0_l00002olo]b0Go00001_ncX]P5o`0001ooal?@0_l00009
onJQ_PGo00000_oVXKh3o`0000?oiZ6n0ol00004onJQ_P?o00007Oo;cKH2o`00073ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0H?ooool3o`00017oajcU0ol0000Joj:c
O@?o00003OnFXXP2o`0001OoP:VX0_l0000JokbPaP;o00001OnGXKL01ol0003oUj6goiNQ]onGXKOo
0000oiNQ]ol000000onGXKL00ol0003oUj6goiNQ]`0:oiNQ]`;o00007?nJUjD3o`0000cofJk600?o
0000omV^a_oI[/H00ooI[/H00ol0003ofJk6omV^aP05omV^aP03o`000?oI[/KofJk600_ofJk60_l0
000Vom;5^0?o00003ommR8P3o`0001OoXI>i0_l00002ol7LY0ko00003OnXa9h7o`0000[o/j;H1Ol0
000MolO3d0;o00002_oVXKh01_l0003oiZ6nonJQ__l0003oiZ6no`0000?oiZ6n00?o0000onJQ__l0
00000ooVXKh01?l0003oiZ6nonJQ__oVXKh2o`0001goblff0ol0001`ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo067ooooo0ol0000@olN/i@;o00006_nR/gd3o`0000ko
UZ:80ol0000Foh2YZ0;o00006_nlX<H2o`0000GoUj6g00Oo0000oiNQ]onGXKOoUj6go`000?nGXKOo
000000?oUj6g00?o0000oiNQ]onGXKL02_nGXKL2o`0000GoVYNU0_l00005oiZGY@?o00003_nJUjD2
o`0000_ofJk60_l00004omV^aP;o00000ooI[/H01Ol0003ofJk6omV^a_oI[/Ko000000gofJk60_l0
000Wom;5^0;o00003_mmR8P3o`0001OoXI>i0ol00008ol7LY0ko00001onXa9h5o`0000ko/j;H1Ol0
000KolO3d0;o00002ooVXKh00ol0003oiZ6nonJQ_P05onJQ_P03o`000?oVXKko000000?oiZ6n00?o
0000onJQ__oVXKh00ol0000Mol_=]P;o0000LOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Rooooo`?o00003oo7[>D2o`0001WoX[=m0ol0000@oiJRR0;o00005_n0ZJP2
o`0000[o_:360ol00002okbPaP?o00002?nlX<H2o`0000GoUj6g1?l00003oiNQ]`?o00003OnGXKL2
o`0000OoVYNU00?o0000oiZGYOnJUjD00onJUjD00ol0003oVYNUoiZGY@0=oiZGY@;o00003?oI[/H0
0ol0003ofJk6omV^aP03omV^aP04o`000?oI[/KofJk6omV^aPGo00003OoI[/H2o`0002Ood/Fh0_l0
000=ogf8R0?o00006?nQTkT2o`00013o`MbT3Ol00002ojS4WP;o00004_ncX]P5o`0001Woal?@0_l0
000<onJQ_P03o`000?oVXKkoiZ6n00;oiZ6n0_l00003onJQ_P?o00000ooVXKh2o`0001koblff0_l0
001aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06?ooooo0ol0000=
olN/i@?o00006?nR/gd3o`00017oUZ:80ol0000Eoh2YZ0;o00002onlX<H01?l0003o_:36okbPa_l0
0003okbPaP03o`000?nlX<Ko_:3600Co_:360ol00005oiNQ]`03o`000?nGXKOoUj6g00?oUj6g00Go
0000oiNQ]onGXKOoUj6go`00000<oiNQ]`;o00002?nJUjD00ol0003oVYNUo`000004o`0000koVYNU
0ol0000WomV^aP;o00009ooBaKP6o`0000SoOHR80ol0000Ioj6C^@;o00005_o1g:@;o`0001Co/j;H
1Ol0000GolO3d0?o00002?oVXKh01Ol0003oiZ6nonJQ__oVXKko000000GoiZ6n00?o0000onJQ__l0
00000ooVXKh00ol0003oiZ6no`000002o`0001goblff0ol0001aooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06Cooooo0ol0000<olN/i@;o00006?nR/gd3o`0001?oUZ:8
0_l0000Eoh2YZ0?o00001onlX<H5o`000003okbPa_l0003o_:3600;o_:3600?o0000okbPa_nlX<H0
1?nlX<H2o`0000OoUj6g00?o0000oiNQ]onGXKL00_nGXKL01Ol0003oUj6goiNQ]onGXKOo000000co
Uj6g0_l00005oiZGY@Co000000GoVYNUo`000?nJUjGoVYNUo`00000@oiZGY@;o00009ooI[/H2o`00
02Cod/Fh3_l00002ogf8R0?o00006_nQTkT2o`0001co`MbT1?l0000Gok>Rf0Go00005Oo7`m04o`00
00OoiZ6n00Oo0000onJQ__oVXKkoiZ6no`000?oVXKko000000?oiZ6n00?o0000onJQ__l000000ooV
XKh01?l0003oiZ6no`000?l0000Nol_=]P;o0000L_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Uooooo`;o00003?o7[>D2o`0001OoX[=m0ol0000DoiJRR0;o00005_n0
ZJP2o`0000Oo_:3600Co0000okbPa_nlX<Ko00000_nlX<H4o`0000Oo_:360_l00008oiNQ]`;o0000
0onGXKL3o`0000goUj6g0_l00004oiZGY@05o`000?nJUjGoVYNUoiZGYOl000000_nJUjD00ol0003o
VYNUo`00000@oiZGY@;o00009ooI[/H2o`0002;od/Fh1_l00004ol_LmP[o00006_nQTkT3o`0001ko
`MbT0_l0000Iok>Rf0Go00004_o7`m06o`0000OoiZ6n0ol00003onJQ_P?o00000ooVXKh3o`000004
onJQ__l0003o0000o`0001koblff0_l0001booooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06Gooooo0ol0000:olN/i@?o00005_nR/gd3o`0001GoUZ:80ol0000Eoh2YZ0;o
00002?nlX<H00ol0003o_:36o`000002okbPaP03o`000?nlX<Ko_:3600So_:360_l0000MoiNQ]`;o
00001?nJUjD01Ol0003oVYNUoiZGYOnJUjGo000000?oVYNU0_l0000?oiZGY@Co00009?oI[/H4o`00
023od/Fh1Ol0000<ol_LmPCo00001OnQTkT3o`0000?oXI>i0ol00003oj6C^@?o00001onQTkT2o`00
01oo`MbT0ol0000Jok>Rf0Go00003oo7`m03o`0000;oN8fD1?l0000EonJQ_P;o00001oo;cKH5o`00
00?oblff0ol00002ol_=]P?o00001oo;cKH3o`0007;ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0I_ooool3o`0000SoajcU7?l0000GoiJRR0;o00005On0ZJP2o`0000Wo
_:360_l00003okbPaP03o`000?nlX<Ko_:3600Oo_:368Ol00005oiZGY@?o00001OnJUjD00ol0003o
VYNUoiZGY@0:oiZGY@So00007_oI[/H9o`0001god/Fh1_l0000@ol_LmP?o00001OnQTkT01Ol0003o
XI>ioj6C^OnQTkWo000000?oXI>i00?o0000oj6C^Ol000000onQTkT00ol0003oXI>ioj6C^@04oj6C
^@;o00007oo1g:@4o`0000Co/j;H1Ol000000oncX]So0000o`000003o`000003ok>Rf?l0003o0000
00?o00001_ncX]P5o`0000coal?@0ol00004ogR=U0Go00004_oVXKh3o`0000Soblff00Co0000ol_=
]_o;cKKo00001?o;cKH01?l0003oblffol_=]_l00003ol_=]P03o`000?o;cKKoblff00Coblff0_l0
001cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Oooooo0ol00005
olN/iAgo00006?nFXXP3o`0000SoP:VX0ol00003oh2YZ0?o00000on0ZJP2o`0000[o_:3600?o0000
okbPa_nlX<H00_nlX<H2o`0000Oo_:368Ol0000GoiZGY@Oo00000_mkTGH3o`0001SofJk62ol00000
1?nb[iko0000o`000?l0000Jom;5^0Ko00004oo;g?H2o`0000GoXI>i00Go0000oj6C^OnQTkWoXI>i
o`000003oj6C^@03o`000?nQTkWoXI>i00?oXI>i00?o0000oj6C^OnQTkT01?nQTkT2o`0001ko`MbT
1_l00004ok>Rf004o`000?ncX]So/j;Ho`0000;o/j;H00Co0000ok>Rf?ncX]So00000_ncX]P01?l0
003o/j;Hok>Rf?l00008ok>Rf0Go00002Oo7`m03o`0000OoN8fD1?l0000AonJQ_P;o00002_o;cKH0
1?l0003oblffol_=]_o;cKH5o`000003ol_=]_l0003oblff00;oblff00?o0000ol_=]_o;cKH01?o;
cKH2o`0007?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0J?ooool3
o`0000?oajcU1?l0000HohjiV0?o00006?nFXXP2o`0000OoP:VX00Go0000oh2YZ?n0ZJSoP:VXo`00
0003oh2YZ003o`000?n0ZJSoP:VX00;oP:VX0_l0000HokbPaP;o00007Oo_en<2o`0001CoVYNU1ol0
0006og^AMP?o00004_oI[/H;o`0000Oo/ZnN0ol0000Gom;5^0Go00005_o;g?H2o`0000GoXI>i00?o
0000oj6C^OnQTkT00_nQTkT3o`0000CoXI>i0_l00006oj6C^@?o00007_o1g:@2o`0000;oSLRQ0ol0
0004ok>Rf003o`000?ncX]So/j;H00?o/j;H00?o0000ok>Rf?ncX]P00oncX]P00ol0003o/j;Hok>R
f00:ok>Rf0Go00001_o7`m03o`0000[oN8fD1?l0000>onJQ_P?o00002oo;cKH01?l0003oblffol_=
]_l00002ol_=]P03o`000?o;cKKoblff00Co00001_o;cKH3o`0007?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0JOooool7o`0001_oS[VH0_l0000HoiJRR0?o00002_n0
ZJP01Ol0003oP:VXoh2YZ?n0ZJSo000000CoP:VX0_l0000GokbPaP?o00007Oo_en<2o`00017oVYNU
1ol0000:og^AMP?o00003OoI[/H:o`0000go/ZnN0ol0000Com;5^0Ko00006?o;g?H3o`0000CoXI>i
00Go0000oj6C^OnQTkWoXI>io`000003oj6C^@03o`000?nQTkWoXI>i00?oXI>i00?o0000oj6C^OnQ
TkT00onQTkT2o`0001ko`MbT0ol00003ohg8X@?o00001?ncX]P00ol0003o/j;Hok>Rf003ok>Rf003
o`000?ncX]So/j;H00?o/j;H00?o0000ok>Rf?ncX]P02oncX]P5o`0000?oal?@0ol0000<ogR=U0Go
00003?oVXKh2o`0000Woblff00Go0000ol_=]_o;cKKoblffo`000002ol_=]P03o`000?o;cKKo0000
00;oblff00?o0000ol_=]_o;cKH01oo;cKH2o`0007Cooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0J_ooool5o`0001coS[VH0ol0000HoiJRR0;o00002?n0ZJP2o`0000Co
P:VX00?o0000oh2YZ?n0ZJP00_n0ZJP3o`0001Ko_:360_l0000NonoGh`;o00003OnJUjD8o`0000ko
Ni5f0ol00007omV^aP[o00004onb[ih3o`00013od/Fh1_l0000Kol_LmP;o00000onQTkT2o`0000?o
XI>i00Oo0000oj6C^OnQTkWoXI>io`000?nQTkWo000000?oXI>i00?o0000oj6C^OnQTkT00onQTkT2
o`0001ko`MbT0_l00005ohg8X@Co00000oncX]P00ol0003o/j;Ho`000003ok>Rf003o`000?ncX]So
000000?o/j;H00?o0000ok>Rf?ncX]P03?ncX]P8o`0000ooN8fD1?l0000:onJQ_P?o00002Oo;cKH0
1Ol0003oblffol_=]_o;cKKo000000?oblff0_l00003ol_=]P03o`000?o;cKKoblff00Koblff0_l0
001dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06_ooooo0_l0000O
ohjiV0;o00002?nFXXP3o`0000?oUZ:80ol00007oiJRR0;o00002_n0ZJP01Ol0003oP:VXoh2YZ?n0
ZJSo000000GoP:VX0_l0000FokbPaP;o00007_o_en<3o`0000WoVYNU2?l0000Bog^AMP?o000000?o
fJk6o`000?l000002Ol0000Hok:_WP?o00003OoBaKP5o`0001kobmcf0_l00004oj6C^@03o`000?nQ
TkWoXI>i00;oXI>i0ol00003oj6C^@?o00001_nQTkT2o`0001go`MbT0ol00006ohg8X@Co00000_nc
X]P00ol0003o/j;Ho`000003ok>Rf003o`000?ncX]So000000?o/j;H00?o0000ok>Rf?ncX]P03_nc
X]P5o`0001;oN8fD1?l00008onJQ_P;o00002oo;cKH3o`0000Goblff00?o0000ol_=]_o;cKH00_o;
cKH2o`0000Goblff0ol0001dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo06_ooooo0_l0000OohjiV0?o00002?nFXXP01Ol0003oUZ:8oiJRR?nFXXSo000000?oUZ:800?o
0000oiJRR?nFXXP01?nFXXP3o`0000GoP:VX00Go0000oh2YZ?n0ZJSoP:VXo`000002oh2YZ0;o0000
1On0ZJP2o`0001Go_:360ol0000?onoGh`?o00000oo_en<2o`0000SokmOS0_l00006oiZGY@Oo0000
5omkTGH9o`0001ko/ZnN0_l0000:om;5^0Ko00008?o;g?H3o`0001KoXI>i0ol0000Lol7LY0?o0000
2On=b:44o`0000?o/j;H0ol00003ok>Rf0?o00004_ncX]P3o`0001CoN8fD1Ol00004onJQ_PCo0000
7oo;cKH2o`0007Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0J_oo
ool3o`00023oS[VH0_l00008oiJRR005o`000?nFXXSoUZ:8oiJRR?l000000onFXXP00ol0003oUZ:8
oiJRR005oiJRR0;o00001_n0ZJP3o`0000CoP:VX00?o0000oh2YZ?n0ZJP00on0ZJP2o`0001Co_:36
1?l0000>onoGh`05o`000?o_en?okmOSonoGhol000001?o_en<00ol0003okmOSonoGh`05onoGh`;o
00000onJUjD7o`0000SoNi5f0_l00004og^AMP?o00002?mkTGH5o`0002?o/ZnN0ol00007om;5^0Ko
00008oo;g?H2o`0001KoXI>i0_l00006ol7LY0?o00000oo1g:@2o`0000Co`MbT0ol00008ol7LY0;o
00002on=b:43o`0001_o/j;H1Ol0000GogR=U0ko00007?o;cKH2o`0007Gooooo00?o0000oooooooo
ool02?ooool001[ooooo0ol0001Zooooo`;o00008On>^IP3o`0000OoUZ:800?o0000oiJRR?nFXXP0
0_nFXXP3o`0000SoUZ:80ol0000Boh2YZ0;o00004OnlX<H8o`0000gokmOS00Go0000onoGhoo_en?o
kmOSo`000005onoGh`03o`000?o_en?okmOS00CokmOS2Ol0000=og^AMP04o`000?mkTGKoNi5fo`00
00?oNi5f00?o0000og^AM_mkTGH01?mkTGH5o`0002Go/ZnN0ol00004om;5^0Go00009_o;g?H2o`00
01KoXI>i0_l00007ol7LY003o`000?o1g:Co`MbT00Co`MbT00Co0000ol7LY?o1g:Co00000oo1g:@0
0ol0003o`MbTol7LY004ol7LY0?o00003?n=b:44o`0001Go/j;H2?l0000JogR=U0Ko00000_nOYgd6
o`0001Woblff0ol0001cooooo`?o00002_ooool001[ooooo00?o0000ooooooooool0J_ooool2o`00
02;oS[VH0_l00007oiJRR005o`000?nFXXSoUZ:8oiJRR?l000000onFXXP00ol0003oUZ:8oiJRR006
oiJRR0;o00004_n0ZJP2o`0000ko_:361ol00002ok?6QP?o00003?o_en<4o`0000?okmOS1?l00006
onoGh`Ko00004OmkTGH00ol0003oNi5fo`000003og^AMP03o`000?mkTGKoNi5f00;oNi5f1?l00000
0oo@aOGo0000o`00000Vok:_WPWo0000:?o;g?H3o`0001GoXI>i0_l00007ol7LY003o`000?o1g:Co
`MbT00Go`MbT00?o0000ol7LY?o1g:@00oo1g:@00ol0003o`MbTol7LY004ol7LY0;o00003_n=b:44
o`00013o/j;H2Ol000000onYd=go0000o`00000KogR=U0;o00002?nOYgd5o`0001Ooblff0_l0001f
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Wooooo0ol0000Rohji
V0?o00001OnFXXP2o`0000?oUZ:800Go0000oiJRR?nFXXSoUZ:8o`000008oiJRR0?o00004On0ZJP2
o`0000_o_:361ol00006ok?6QP?o00002oo_en<00ol0003okmOSonoGh`03onoGh`05o`000?o_en?o
kmOSonoGhol000001_o_en<3o`00017oNi5f1?l00002og^AMP?o00001?mkTGH4o`0000;od<Ge0ol0
000Vok:_WPKo0000:oo;g?H2o`0001CoXI>i0ol00007ol7LY003o`000?o1g:Co`MbT00;o`MbT1?l0
0005ol7LY003o`000?o1g:Co`MbT00?o`MbT0ol0000@ohg8X@?o00002oncX]P9o`0000GoZM3M0_l0
000KogR=U0;o00002_nOYgd6o`0001Coblff0_l0001fooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo06Wooooo0_l0000TohjiV0;o00001_nFXXP00ol0003oUZ:8oiJRR002
oiJRR0?o00002_nFXXP2o`00017oP:VX0ol00007okbPaPOo00002_ncaXH3o`0000_okmOS00?o0000
onoGhoo_en<00_o_en<01Ol0003okmOSonoGhoo_en?o000000GokmOS1?l0000@og^AMP07o`000?mk
TGKoNi5fog^AM_l0003oNi5fo`000003og^AMP03o`000?mkTGKoNi5f00?o00001Oo@aOD2o`0002Oo
/ZnN0_l0000^ol_LmP;o00005?nQTkT2o`0000So`MbT00Go0000ol7LY?o1g:Co`MbTo`000003ol7L
Y003o`000?o1g:Co000000?o00001_o1g:@2o`0001;oSLRQ0ol00006ok>Rf0Wo00002OnYd=d2o`00
01[oN8fD0ol0000<oinWO@Ko00004Oo;cKH3o`0007Kooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0JOooool2o`0002CoS[VH0ol0000GoiJRR0;o00004_n0ZJP2o`0000Co
_:361ol0000>ok?6QPCo00002_o_en<2o`0000?okmOS0ol00005onoGh`Ko00003omkTGH01ol0003o
Ni5fog^AM_mkTGKo0000og^AM_l000000omkTGH5o`0000Kod<Ge0_l0000Wok:_WP;o0000;_o;g?H3
o`0001?oXI>i0_l00007ol7LY0;o00000oo1g:@01ol0003o`MbTol7LY?o1g:Co0000ol7LY?l00000
2?o1g:@3o`0001?oSLRQ0ol000000oncX]So0000o`000007o`0000goZM3M0_l0000JogR=U0;o0000
4?nOYgd5o`0000ooblff0_l0001gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo06Sooooo0ol0000UohjiV0;o00005onFXXP3o`00013oP:VX2ol0000Bok?6QPCo00005?o_
en<4o`0000;oglRl0ol0000?og^AMP?o00000omkTGH7o`0000Ood<Ge0_l0000Wok:_WP;o00004Oo;
g?H3o`0000?obmcf0ol00002ol_LmPGo00003_o;g?H2o`0001?oXI>i0_l00008ol7LY003o`000?o1
g:Co`MbT00;o`MbT0ol00002ol7LY0Go00001?o1g:@2o`0001GoSLRQ2?l0000AojW@g@;o00006_mh
SI@2o`0001;oWjMm1_l0000<ol_=]P;o0000Moooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Xooooo`;o00009_n>^IP3o`0001OoUZ:80_l0000?oh2YZ0Wo00005oncaXH3
o`0001;okmOS1?l00004omo8_0Co00005?mkTGH4o`0000Wod<Ge0_l0000Wok:_WP;o00004_o;g?H0
1Ol0003obmcfol_Lm_o;g?Ko000000?obmcf00Co0000ol_Lm_o;g?Ko00000_o;g?H00ol0003obmcf
ol_LmP0<ol_LmP;o00004_nQTkT3o`0001[o`MbT0ol0000Fohg8X@?o00005OnYd=d2o`0001[oN8fD
0_l0000DoinWO@Ko00002Oo;cKH3o`0007Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0J?ooool2o`0002OoS[VH0_l0000GoiJRR0Go00002_n0ZJP4o`0000GoYKK;0ol0
000Gok?6QP?o00003oo_en<4o`0000OoglRl1?l0000Bog^AMPCo00002_o@aOD2o`0002Oo/ZnN0_l0
000Bol_LmP05o`000?o;g?Kobmcfol_Lm_l000000oo;g?H01Ol0003obmcfol_Lm_o;g?Ko0000013o
bmcf5ol0000Jol7LY0;o00005on=b:43o`0001GoZM3M0_l0000IogR=U0?o00005onOYgd5o`0000Oo
blff0_l0001hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Sooooo
0ol0000VohjiV0?o00004onFXXP;o`0000GoP:VX1Ol00007ojFfb`;o00006?ncaXH3o`0000gokmOS
1?l0000:omo8_0?o00004?mkTGH3o`0000cod<Ge0ol0000>ok:_WP?o00000_nb[ih5o`0000;o/ZnN
0ol00009ok:_WP?o00004Oo;g?H01?l0003obmcfol_Lm_o;g?H4o`0000Gobmcf00?o0000ol_Lm_o;
g?H03_o;g?HGo`0001So`MbT0ol0000Hohg8X@;o00005OnYd=d2o`0001WoN8fD0_l0000JoinWO@Ko
00001?o;cKH2o`0007Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
JOooool2o`0002OoS[VH0_l0000AoiJRR0Ko00000on]/ZX7o`000003oh2YZ?l0003o000000;o0000
2OnU]//3o`0001So/lJ61?l0000:onoGh`?o00003OoOb;`4o`0000coNi5f1?l0000>om35m@;o0000
3onb[ih00ol0003o/ZnNok:_WP02ok:_WP06o`000?nb[iko/ZnNo`000?nb[iko00000onb[ih00ol0
003o/ZnNok:_WP07ok:_WP;o00004Oo;g?H01Ol0003obmcfol_Lm_o;g?Ko000000Gobmcf00Go0000
ol_Lm_o;g?Kobmcfo`00000>ol_LmP?o00004onaTi04o`0001Ko`MbT0_l0000Iohg8X@;o00005OnY
d=d2o`0000?oN8fD1Ol00002ogR=U0?o00000omhSI@3o`0000KoN8fD0_l0000LoinWO@[o0000N?oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`;o00009on>^IP3
o`0000koUZ:81Ol00009ojfbZPOo00003?nU]//2o`0001Wo/lJ61?l00007onoGh`Co00003ooOb;`4
o`0000[oNi5f1?l0000?om35m@;o00003onb[ih00ol0003o/ZnNok:_WP03ok:_WP03o`000?nb[iko
/ZnN00Go/ZnN00?o0000ok:_W_nb[ih01onb[ih2o`00013obmcf0_l00004ol_LmP03o`000?o;g?Ko
bmcf00;obmcf00Go0000ol_Lm_o;g?Kobmcfo`00000>ol_LmP;o00005OnaTi04o`0001Co`MbT0ol0
000Iohg8X@?o00005?nYd=d2o`0000CoN8fD00Ko0000ogR=U?mhSICo0000ogR=U?l00003ogR=U005
o`000?mhSICoN8fDogR=U?l000001omhSI@2o`0001ooWjMm1_l0001iooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo06Wooooo0ol0000WohjiV0;o00002onFXXP6o`0000ko
[K:Z0ol0000=ojFfb`?o00006_ncaXH3o`0000GokmOS1?l0000Bomo8_0?o00002?mkTGH3o`00017o
d<Ge0_l0000?ok:_WP03o`000?nb[iko/ZnN00Co/ZnN00?o0000ok:_W_nb[ih01?nb[ih00ol0003o
/ZnNok:_WP07ok:_WP;o00004Oo;g?H00ol0003obmcfol_LmP03ol_LmP;o00000oo;g?H3o`0000ko
bmcf0ol0000Gok6CT0Co00004Oo1g:@3o`0000SoSLRQ1Ol00002ohg8X@?o00000on=b:43o`0000?o
SLRQ0_l0000DojW@g@;o00001OmhSI@00ol0003oN8fDogR=U005ogR=U005o`000?mhSICoN8fDogR=
U?l000001_mhSI@3o`00027oWjMm0_l0001kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06[ooooo0_l0000WohjiV0?o00002?nFXXP6o`00017o[K:Z0_l0000>ojFfb`;o
00006oncaXH3o`0000;okmOS1?l0000Eomo8_0Co00001?mkTGH7o`0000Cod<Ge0_l00003om35m@?o
00000oo@aOD2o`0000oo/ZnN00Go0000ok:_W_nb[iko/ZnNo`000003ok:_WP03o`000?nb[iko0000
00?o00002_nb[ih3o`0002cobmcf0_l0000Iok6CT0Co00004?o1g:@2o`0000[oSLRQ00Co0000ohg8
XOn=b:7o00000on=b:401Ol0003oSLRQohg8XOn=b:7o000000?oSLRQ00?o0000ohg8XOn=b:400_l0
000DojW@g@;o00001_mhSI@00ol0003oN8fDogR=U002ogR=U0;o00001?mhSI@00ol0003oN8fDogR=
U004ogR=U0;o00008OnOYgd3o`0007_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0J_ooool2o`0002SoS[VH0_l00006oiJRR0Go00005?n]/ZX2o`0000koYKK;0ol0000K
ok?6QPOo00005ooOb;`4o`0000;oNi5f1?l00002om35m@03o`000?o@aOGod<Ge00;od<Ge00Ko0000
om35mOo@aOGo0000om35mOl00003om35m@03o`000?o@aOGod<Ge00;o00003_nb[ih2o`0000?o/ZnN
00Oo0000ok:_W_nb[iko/ZnNo`000?nb[iko000000go/ZnN1_l0000Xol_LmP?o00006onaTi04o`00
00go`MbT0ol0000;ohg8X@03o`000?n=b:7oSLRQ00?oSLRQ00?o0000ohg8XOn=b:401On=b:400ol0
003oSLRQohg8X@03o`0001?oZM3M0_l00003ogR=U005o`000?mhSICoN8fDogR=U?l000001OmhSI@0
1Ol0003oN8fDogR=U?mhSICo000000KoN8fD0_l0000QoinWO@;o0000O?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1Zooooo`?o00009on>^IP3o`0000;oUZ:81_l0000F
ojfbZP;o00003onU]//2o`0001co/lJ61?l0000Komo8_0Ko00001?o@aOD00ol0003od<Geom35m@02
om35m@06o`000?o@aOGod<Geo`000?o@aOGo00000oo@aOD00ol0003od<Geom35m@02o`0000oo/ZnN
00?o0000ok:_W_nb[ih00_nb[ih3o`0000;o/ZnN1Ol00008ok:_WPWo00009_o;g?H2o`0001go/I>@
1?l0000<ol7LY0;o00003On=b:400ol0003oSLRQohg8X@02ohg8X@03o`000?n=b:7oSLRQ00?oSLRQ
0_l00004ohg8X@;o00004onYd=d2o`0000?oN8fD00Oo0000ogR=U?mhSICoN8fDo`000?mhSICo0000
00?oN8fD00?o0000ogR=U?mhSI@00_l00006ogR=U0;o00008OnOYgd2o`0007cooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Joooool2o`0002SoS[VH2?l0000HojfbZP;o
00003onU]//3o`0000So/lJ60ol00003ok?6QP?o00002oncaXH2o`0001goglRl1?l00005om35m@03
o`000?o@aOGod<Ge00;od<Ge00Go0000om35mOo@aOGo0000om35m@04o`0000?od<Ge0ol0000Uok:_
WP;o00001?oVfMT6o`0002?obmcf0_l0000Ook6CT0Co00001oo1g:@5o`0000[oSLRQ00Go0000ohg8
XOn=b:7oSLRQo`000003ohg8X@03o`000?n=b:7oSLRQ00GoSLRQ00Co0000ohg8XOn=b:7oSLRQ0_l0
000CojW@g@;o00001?mhSI@3o`0000?oN8fD0ol00004ogR=U003o`000?mhSICoN8fD00?oN8fD0ol0
0003oinWO@Go00000onOYgd3o`0000?oWjMm0ol0000<oinWO@?o0000O?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o0000:?n>^IP5o`0001_o[K:Z0_l0000@
ojFfb`;o00001oncaXH01ol0003o/lJ6ok?6Q_ncaXKo0000ok?6Q_l000000oncaXH00ol0003o/lJ6
ok?6QP08ok?6QP;o00007OoOb;`3o`0000Kod<Ge00?o0000om35mOo@aOD00_o@aOD01_l0003od<Ge
om35mOl0003od<Geo`0000Ood<Ge0_l0000Tok:_WP?o00001_oVfMT7o`0001oobmcf0ol0000Pok6C
T0Co000000?o`MbTo`000?l000001ol0000;ohg8X@05o`000?n=b:7oSLRQohg8XOl000000_n=b:42
o`0000?oSLRQ00Go0000ohg8XOn=b:7oSLRQo`000003ohg8X@Ko000000?oZM3Mo`000?l000000ol0
0003ojW@g@?o00000onYd=d2o`0001OoN8fD0_l00005oinWO@04o`000?nOYggoWjMmo`0000CoWjMm
00?o0000oinWOOnOYgd00onOYgd00ol0003oWjMmoinWO@0;oinWO@;o0000OOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`?o00003?n>^IP3o`0000CoS[VH0_l0
000CohjiV0;o00007On]/ZX2o`00013oYKK;0ol0000:ok?6QP03o`000?ncaXKo/lJ600?o/lJ600?o
0000ok?6Q_ncaXH01oncaXH3o`0000WoglRl0ol00003omo8_0?o00002_oOb;`4o`0000God<Ge0_l0
0004om35m@04o`000?o@aOGod<Geo`0000;od<Ge00?o0000om35mOo@aOD01?o@aOD2o`0002Co/ZnN
0_l0000:onKIf@Ko00007Oo;g?H2o`0002?o/I>@2Ol000001?o=]Z3o0000o`000?l0000;ohg8X@?o
00001?n=b:400ol0003oSLRQohg8X@02ohg8X@?o00001On=b:42o`0000;oZM3M00Co0000ojW@gOnY
d=go00000_nYd=d00ol0003oZM3MojW@g@02ojW@g@03o`000?nYd=goZM3M00;oZM3M0_l0000GogR=
U0;o00001_nOYgd01?l0003oWjMmoinWOOnOYgd5o`000003oinWOOl0003o000000?o00003?nOYgd2
o`0007gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0K?ooool2o`00
00goS[VH00?o0000ohjiV?n>^IP00_n>^IP01?l0003oS[VHohjiV?l0000AohjiV0?o00007On]/ZX2
o`00017oYKK;0_l0000:ok?6QP03o`000?ncaXKo/lJ600?o/lJ600?o0000ok?6Q_ncaXH01_ncaXH4
o`0000SoglRl00Oo0000omo8_?oOb;coglRlo`000?oOb;co000000?oglRl00?o0000omo8_?oOb;`0
1_oOb;`6o`0000God<Ge00?o0000om35mOo@aOD00oo@aOD2o`0000Cod<Ge0_l00004om35m@;o0000
9?nb[ih2o`0000goi]WI1_l0000Iol_LmP?o00009?naTi03o`0000OocKJP0ol0000Nohg8X@?o0000
1OnYd=d01?l0003oZM3MojW@gOnYd=d5o`0000?oZM3M0_l0000FogR=U0?o00001onOYgd01?l0003o
WjMmoinWOOl00002oinWO@04o`000?nOYggoWjMmo`0000;oWjMm00?o0000oinWOOnOYgd02_nOYgd3
o`0007gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0K?ooool2o`00
00goS[VH00?o0000ohjiV?n>^IP00_n>^IP01?l0003oS[VHohjiV?l0000AohjiV0;o00007_n]/ZX2
o`00017oYKK;0ol00005ok?6QPCo00000_ncaXH4o`0000So/lJ61_l00007omo8_007o`000?oOb;co
glRlomo8_?l0003oglRlo`000003omo8_003o`000?oOb;coglRl00GoglRl0ol00002ohF=VP?o0000
5_o@aOD2o`0002?o/ZnN0ol0000?onKIf@Ko00005oo;g?H2o`0000Ko/I>@0ol00003ok6CT0?o0000
1?naTi03o`0000ko/I>@0ol00009olffX0?o00007On=b:44o`0000GoZM3M00Co0000ojW@gOnYd=go
00000_nYd=d00ol0003oZM3MojW@g@02ojW@g@;o00005_mhSI@2o`0000GoWjMm00Go0000oinWOOnO
YggoWjMmo`000002oinWO@03o`000?nOYggo000000?oWjMm00?o0000oinWOOl000003?nOYgd2o`00
07kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0K?ooool3o`0000co
S[VH00?o0000ohjiV?n>^IP00_n>^IP01?l0003oS[VHohjiV?l0000AohjiV0;o00007_n]/ZX2o`00
01;oYKK;0_l00005ok?6QP03o`000?ncaXKo/lJ600?o/lJ600?o0000ok?6Q_ncaXH02?ncaXH3o`00
00;oM7ZQ0ol00007omo8_0?o00000_oOb;`4o`0000OoglRl0ol00004ohF=VP;o00005_o@aOD2o`00
02?o/ZnN0_l0000ConKIf@Ko00004_o;g?H4o`0000Oo/I>@00Go0000ok6CT?naTi3o/I>@o`000003
ok6CT003o`000?naTi3o/I>@00;o/I>@00?o0000ok6CT?naTi003?naTi03o`0000_ocKJP0_l0000M
ohg8X@?o000000CoZM3Mo`000?nYd=go00000onYd=d01_l0003oZM3MojW@gOl0003oZM3Mo`0000Co
ZM3M0_l0000FogR=U0;o00001OnOYgd01Ol0003oWjMmoinWOOnOYggo000000?oWjMm0_l00004oinW
O@;o00002onOYgd3o`0007kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0KOooool2o`0000coS[VH00?o0000ohjiV?n>^IP00_n>^IP01?l0003oS[VHohjiV?l0000@ohji
V0?o00007_n]/ZX2o`0001;oYKK;0_l00005ok?6QPGo000000?o/lJ6o`000?l000000ol00004ok?6
QPCo00001?mdNZ42o`0000KoglRl00Oo0000omo8_?oOb;coglRlo`000?oOb;co000000WoglRl0ol0
0005ohF=VP?o00005Oo@aOD3o`00027o/ZnN0ol0000EonKIf@Oo00003?o;g?H6o`0000So/I>@00Go
0000ok6CT?naTi3o/I>@o`000003ok6CT003o`000?naTi3o000000Co00003?naTi03o`0000cocKJP
0ol0000Lohg8X@Go000000?oZM3Mo`000?nYd=d00_nYd=d01?l0003oZM3MojW@gOnYd=d2o`0000Co
ZM3M0_l0000FogR=U0;o00001_nOYgd3o`0000GoWjMm00?o0000oinWOOnOYgd00onOYgd00ol0003o
WjMmoinWO@09oinWO@;o0000Ooooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1]ooooo`;o00002on>^IP2o`0000CoS[VH00Co0000ohjiV?n>^ISo00004?n>^IP2o`0001oo
[K:Z0_l0000BojFfb`?o00004_ncaXH4o`0000GoM7ZQ0ol00005omo8_005o`000?oOb;coglRlomo8
_?l000000_oOb;`00ol0003oglRlomo8_005omo8_0?o00001on5SIX2o`0001Kod<Ge0_l0000Qok:_
WP;o00006OoVfMT6o`0000Oobmcf2_l00007ok6CT003o`000?naTi3o/I>@00;o/I>@0ol00002ok6C
T004o`000?naTi3o/I>@o`0000go/I>@0_l0000>olffX0?o00007?n=b:43o`0000?oZM3M0ol00005
ojW@g@03o`000?nYd=goZM3M00;oZM3M0_l0000EogR=U0?o00008?nOYgd2o`0007oooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0KOooool3o`0000_oS[VH00?o0000ohji
V?n>^IP00on>^IP2o`00013oS[VH0ol0000OojfbZP;o00004onU]//2o`00017o/lJ60ol00008ogAj
X@?o00001OoOb;`3o`0000CoglRl0_l00004omo8_0?o00002?n5SIX3o`0001Cod<Ge1Ol0000Nok:_
WP?o00007?oVfMT6o`000003ol_Lm_l0003o000000Go00001?nXg;L3o`0000Ko/I>@00Go0000ok6C
T?naTi3o/I>@o`000003ok6CT006o`000?naTi3o/I>@o`000?naTi3o00003?naTi03o`0000oocKJP
0_l0000Mohg8X@;o00004?nYd=d2o`0001GoN8fD0_l0000PoinWO@?o0000Ooooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1^ooooo`;o00008on>^IP2o`0000[o[K:Z1Ol0
0002ojfbZP?o00003?n]/ZX2o`0001?oYKK;0ol0000?ok?6QP?o00002_mdNZ42o`00017oglRl0ol0
000:ohF=VP?o00004_o@aOD9o`0001_o/ZnN0_l0000OonKIf@Wo00002?nXg;L3o`0000Co/I>@0_l0
0003ok6CT005o`000?naTi3o/I>@ok6CT?l000000onaTi02o`0000_o/I>@0ol0000@olffX0?o0000
7?n=b:43o`0000ooZM3M0_l0000EogR=U0;o00008?nOYgd2o`00083ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0K_ooool2o`0002;oS[VH0ol0000;ojfbZP06o`000?n]
/Z[o[K:Zo`000?n]/Z[o00000on]/ZX00ol0003o[K:ZojfbZP09ojfbZP;o00005?nU]//2o`0000go
/lJ61?l0000;ogAjX@?o00003ooOb;`3o`0000coQHfJ0_l0000Aom35m@?o00000onQY9h8o`0001Oo
/ZnN0_l0000RonKIf@?o00003?nXg;L3o`0000Co/I>@00?o0000ok6CT?naTi000_naTi03o`0000Go
/I>@00?o0000ok6CT?naTi002OnaTi02o`0001;ocKJP0ol0000Lohg8X@;o00003onYd=d2o`0001Go
N8fD0_l0000PoinWO@;o0000P?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1^ooooo`?o00008On>^IP2o`0000go[K:Z00Go0000ojfbZ_n]/Z[o[K:Zo`000003ojfbZP03
o`000?n]/Z[o[K:Z00Wo[K:Z0_l0000DojFfb`?o00002oncaXH4o`0000goM7ZQ0ol0000=omo8_0?o
00003On5SIX3o`0000ood<Ge0ol00007oj6TWPSo00004_nb[ih4o`0002;oi]WI0_l0000>ojSL]`?o
00006onaTi03o`0001?ocKJP0ol0000Kohg8X@;o00003onYd=d2o`0001CoN8fD0ol0000OoinWO@?o
0000P?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1_ooooo`;o0000
8On>^IP2o`0000ko[K:Z00Co0000ojfbZ_n]/Z[o[K:Z0ol0000<ojfbZP;o00002_nU]//3o`0000?o
YKK;0ol00002ojFfb`;o00002_ncaXH3o`00013oM7ZQ0_l0000<omo8_0?o00003on5SIX3o`0000co
d<Ge1?l0000<oj6TWPOo00003Onb[ih5o`0002?oi]WI0_l0000?ojSL]`?o00006OnaTi03o`0001Go
cKJP0_l0000Kohg8X@?o00003_nYd=d2o`0001CoN8fD0_l0000PoinWO@;o0000POooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1_ooooo`;o00008?n>^IP3o`0000_o[K:Z
00Oo0000ojfbZ_n]/Z[o[K:Zo`000?n]/Z[o000000?o[K:Z00?o0000ojfbZ_n]/ZX02On]/ZX2o`00
00_oYKK;00?o0000ojFfbonU]//00onU]//01?l0003oYKK;ojFfbonU]//3o`0000So/lJ60ol0000A
ogAjX@?o00002_oOb;`3o`00017oQHfJ0_l0000;om35m@Co00004?nQY9h8o`0000Ko/ZnN2Ol0000Q
onKIf@?o00004?nXg;L3o`0001Oo/I>@0ol0000FolffX0?o00006on=b:42o`0000koZM3M0_l0000D
ogR=U0;o00008?nOYgd2o`00087ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Koooool3o`0001ooS[VH0_l0000<ojfbZP07o`000?n]/Z[o[K:ZojfbZ_l0003o[K:Zo`00
0003ojfbZP03o`000?n]/Z[o[K:Z00Wo[K:Z0_l00008ojFfb`Go000000?oYKK;o`000?l000000ol0
0003ojFfb`;o00001oncaXH3o`0001?oM7ZQ0ol00008omo8_0?o00004_n5SIX3o`0000Wod<Ge0ol0
000Eoj6TWPSo000000?o/ZnNo`000?l000001?l00003ohjAO0;o00008OoVfMT2o`0001;oZ=bg0ol0
000Fok6CT0;o00006?o=]Z07o`0001KoSLRQ0_l0000>ojW@g@;o00005?mhSI@2o`0001ooWjMm0ol0
0021ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo073ooooo0_l0000N
ohjiV0?o00003On]/ZX3o`0000?o[K:Z0ol0000<ojfbZP;o00002?nU]//01?l0003oYKK;ojFfbol0
0002ojFfb`04o`000?nU]/_oYKK;o`0000CoYKK;0ol00004ok?6QPCo00005OmdNZ42o`0000OoglRl
0ol0000DohF=VP?o00001oo@aOD3o`0001[oXJBN2?l00006ohjAO0?o00001_oVfMT3o`0000?oi]WI
0ol00003onKIf@?o00002ooVfMT2o`0001?oZ=bg0_l0000Eok6CT0?o00006Oo=]Z0=o`0000ooSLRQ
0ol0000=ojW@g@;o00004omhSI@3o`0001ooWjMm0_l00022ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo073ooooo0_l0000NohjiV0;o00008on]/ZX2o`0000WoYKK;00?o
0000ojFfbol000000onU]//00ol0003oYKK;o`000005ojFfb`;o00000oncaXH4o`0001KoM7ZQ0ol0
0005omo8_0?o00005_n5SIX2o`0000God<Ge1?l0000Noj6TWP?o00002On>TG`3o`0000Koi]WI00Go
0000onKIfOoVfMWoi]WIo`000003onKIf@03o`000?oVfMWo000000?oi]WI00?o0000onKIfOoVfMT0
2?oVfMT2o`0001?oZ=bg0ol0000Cok6CT0?o00006Oo=]Z03o`0000?oRIZM4?l00008ohg8X@;o0000
3OnYd=d2o`0001?oN8fD0_l0000OoinWO@?o0000P_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1`ooooo`?o00007?n>^IP3o`0002?o[K:Z0_l0000:ojFfb`;o00001?nU
]//2o`0000GoYKK;0ol000001?ncaXKo0000o`000?l0000IogAjX@?o00000ooOb;`3o`0001OoQHfJ
0ol00003om35m@Co00007onQY9h3o`0000[oSY5l0_l00006onKIf@03o`000?oVfMWoi]WI00Goi]WI
00?o0000onKIfOoVfMT00ooVfMT00ol0003oi]WIonKIf@08onKIf@;o00005?nXg;L3o`0001;o/I>@
0_l0000JolffX0;o00002on9VYd@o`000003ohg8XOl0003o000000goZM3M0_l0000CogR=U0;o0000
7onOYgd2o`0008?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0LOoo
ool2o`0001coS[VH0_l0000RojfbZPGo00002_nU]//00ol0003oYKK;ojFfb`03ojFfb`03o`000?nU
]/_oYKK;00CoYKK;1Ol0000KogAjX@;o00000_oOb;`3o`0000CoQHfJ0_l00004ohF=VP?o00003?n5
SIX2o`0000;od<Ge0ol0000Qoj6TWP;o00002on>TG`3o`0000Goi]WI00?o0000onKIfOoVfMT01OoV
fMT00ol0003oi]WIonKIf@03onKIf@03o`000?oVfMWoi]WI00Soi]WI0_l0000EojSL]`?o00004?na
Ti03o`0000?ocKJP1Ol00003olffX0;o00000_o=]Z05o`0000KocKJP0_l0000CohVJW@co00003?nY
d=d2o`0001?oN8fD0_l0000OoinWO@;o0000Poooool00ol0003oooooooooo`08ooooo`006_ooool3
o`00077ooooo0_l0000LohjiV0;o00007on]/ZX9o`0001KoYKK;1?l0000>ogAjX@?o00000omdNZ43
o`0000GoM7ZQ1_l00007ohF=VP03o`000?n5SI[oQHfJ00;oQHfJ00?o0000ohF=V_n5SIX02on5SIX6
o`00027oXJBN0ol0000<ohjAO0;o00001OoVfMT01?l0003oi]WIonKIfOoVfMT4o`0000;oi]WI1?l0
000:onKIf@?o00005_nXg;L3o`0000ko/I>@0ol00005olffX004o`000?o=]Z3ocKJPo`0000;ocKJP
00Co0000olffX?o=]Z3o00000_o=]Z001?l0003ocKJPolffX?l00005olffX0?o00006_n9VYd5o`00
00KoZM3M2_l0000@ogR=U0?o00007_nOYgd3o`00087ooooo0ol0000:ooooo`006_ooool00ol0003o
ooooooooo`1aooooo`?o00006_n>^IP3o`0001co[K:Z1ol00003olS@[@?o00005_nU]//2o`0000ko
M7ZQ00Oo0000ogAjXOmdNZ7oM7ZQo`000?mdNZ7o000000?oM7ZQ00?o0000ogAjXOmdNZ400omdNZ44
o`0000WoQHfJ00Go0000ohF=V_n5SI[oQHfJo`00000>ohF=VPCo00000_nQY9h3o`0000?oXJBN0ol0
0003oj6TWP?o00004OnQY9h2o`0000goSY5l0ol00003onKIf@;o00000ooVfMT00ol0003oi]WIonKI
f@03onKIf@03o`000?oVfMWoi]WI00_oi]WI0_l0000HojSL]`?o00002_naTi05o`0000OocKJP00?o
0000olffX?o=]Z000_o=]Z001?l0003ocKJPolffX?l00003olffX003o`000?o=]Z3ocKJP00GocKJP
0_l0000NohVJWAKo00002_mhSI@5o`0001koWjMm0_l00024ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo07;ooooo0ol0000IohjiV0;o00006_n]/ZX7o`0000Oob=2]0ol0
000DojFfb`?o00003_mdNZ401ol0003oM7ZQogAjXOmdNZ7o0000ogAjXOl000000omdNZ400ol0003o
M7ZQogAjX@04ogAjX@;o00001on5SIX4o`0000?oQHfJ00?o0000ohF=V_n5SIX02_n5SIX5o`0000Co
XJBN00?o0000oj6TW_nQY9h00onQY9h01Ol0003oXJBNoj6TW_nQY9ko000000?oXJBN00?o0000oj6T
W_nQY9h03OnQY9h3o`0000koSY5l0_l00004onKIf@04o`000?oVfMWoi]WIonKIf@Go000000?oi]WI
o`000?l000000ol00009onKIf@;o00000_nXg;L3o`0000CoZ=bg00?o0000ojSL]onXg;L00_nXg;L3
o`0000SoZ=bg0ol00005ok6CT0So00002Oo=]Z001Ol0003ocKJPolffX?o=]Z3o000000;ocKJP00?o
0000olffX?o=]Z000_o=]Z000ol0003ocKJPolffX004olffX0;o00007on9VYd8o`0000So/ZKH2?l0
0002ogR=U0co00007?nOYgd2o`0008Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0L_ooool4o`0001OoS[VH0ol0000GojfbZPOo00002oo8d:d4o`0001;oYKK;0_l0000?
ogAjX@Co00000_mdNZ44o`0000OoM7ZQ0ol00005ohF=VP05o`000?n5SI[oQHfJohF=V_l000000on5
SIX00ol0003oQHfJohF=VP07ohF=VPOo00001OnQY9h00ol0003oXJBNoj6TWP03oj6TWP05o`000?nQ
Y9koXJBNoj6TW_l000000onQY9h00ol0003oXJBNoj6TWP0<oj6TWP?o00003on>TG`3o`0001_oi]WI
0_l00003ojSL]`03o`000?nXg;OoZ=bg00?oZ=bg00Go0000ojSL]onXg;OoZ=bgo`000003ojSL]`03
o`000?nXg;OoZ=bg00KoZ=bg0ol000000onaTi3o0000o`000006o`000004onk=gol0003o0000o`00
00GocKJP00Go0000olffX?o=]Z3ocKJPo`000002olffX006o`000?o=]Z3ocKJPo`000?o=]Z3o0000
0oo=]Z000ol0003ocKJPolffX002olffX0?o00007_n9VYd3o`0001;o/ZKH3?l00003ohBMVPKo0000
5onOYgd4o`0008Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0M?oo
ool3o`0001KoS[VH0_l0000EojfbZPOo00003oo8d:d4o`00017oYKK;0_l0000?ogAjX@03o`000?md
NZ7oM7ZQ00?oM7ZQ00?o0000ogAjXOmdNZ402?mdNZ44o`0000CoQHfJ00Go0000ohF=V_n5SI[oQHfJ
o`000002ohF=VP;o00001_n5SIX7o`000004oh:2QOl0003o0000o`0000CoXJBN00?o0000oj6TW_nQ
Y9h00onQY9h00ol0003oXJBNoj6TWP02oj6TWP?o00003onQY9h2o`00017oSY5l0_l0000KonKIf@;o
00000onXg;L00ol0003oZ=bgojSL]`04ojSL]`03o`000?nXg;OoZ=bg00CoZ=bg00?o0000ojSL]onX
g;L01onXg;L7o`0000Kok/gO0ol00004olffX005o`000?o=]Z3ocKJPolffX?l000000_o=]Z001_l0
003ocKJPolffX?l0003ocKJPo`0000?ocKJP00?o0000olffX?o=]Z000_o=]Z02o`0001ooRIZM0_l0
000Fok:Vf0Co00002_n4WIX6o`0001?oWjMm1Ol00025ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo07Gooooo0ol0000DohjiV0?o00004_n]/ZX7o`0001Cob=2]0ol0000?
ojFfb`?o00004?mdNZ400ol0003oM7ZQogAjX@03ogAjX@03o`000?mdNZ7oM7ZQ00KoM7ZQ1_l00004
ohF=VP?o00001?n5SIX01?l0003oQHfJohF=V_n5SIX7o`0000GoPX:50_l00004oj6TWP03o`000?nQ
Y9koXJBN00?oXJBN00Go0000oj6TW_nQY9koXJBNo`000003oj6TWP03o`000?nQY9koXJBN00_oXJBN
0ol0000AohjAO0?o00006_oVfMT2o`0000?oZ=bg00?o0000ojSL]onXg;L01?nXg;L00ol0003oZ=bg
ojSL]`02ojSL]`;o00002onXg;L3o`0000[ok/gO0ol00004olffX0?o00001?o=]Z02o`0000?ocKJP
0ol00005olffX0;o00007_n9VYd3o`0001Oo/ZKH0_l0000>ohBMVPGo00004?nOYgd4o`0008Oooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0M_ooool3o`0001?oS[VH0_l0
000@ojfbZPOo00006?o8d:d3o`0000koYKK;0_l0000BogAjX@;o00001?mdNZ42o`0000GoM7ZQ0ol0
0002ojb?Q`Co00002_n5SIX7o`0000SoPX:50ol00002oj6TWP;o00001?nQY9h2o`0000?oXJBN00Go
0000oj6TW_nQY9koXJBNo`00000=oj6TWP;o00004on>TG`3o`0001Soi]WI0ol00003ojSL]`03o`00
0?nXg;OoZ=bg00GoZ=bg00?o0000ojSL]onXg;L00onXg;L00ol0003oZ=bgojSL]`07ojSL]`?o0000
3?o^cMl3o`0001KocKJP0ol00009ohVJW@Go00000_n9VYd3o`0000CoRIZM0_l00005ohVJW@;o0000
6?nbY]P2o`00013oQ9fJ1Ol0000<oinWO@Co0000ROooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1gooooo`Co00004On>^IP2o`0000go[K:Z1ol0000LolS@[@?o00003OnU
]//2o`0001koM7ZQ0ol00004ojb?Q`Go00001On5SIX7o`0000coPX:50ol00002oj6TWP03o`000?nQ
Y9koXJBN00?oXJBN00?o0000oj6TW_nQY9h00_nQY9h3o`0000goXJBN0ol0000DohjAO0;o00006?oV
fMT2o`0000?oZ=bg0_l00003ojSL]`07o`000?nXg;OoZ=bgojSL]ol0003oZ=bgo`000003ojSL]`03
o`000?nXg;OoZ=bg00OoZ=bg0_l0000>onk=g`?o00005Oo=]Z02o`0000_oRIZM00Co0000ohVJWOn9
VYgo00000on9VYd00ol0003oRIZMohVJW@02ohVJW@04o`000?n9VYgoRIZMo`0000?oRIZM0ol0000H
ok:Vf0;o00004_n4WIX5o`0000SoWjMm1Ol0002:ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo07Sooooo1?l0000>ohjiV0Go00002On]/ZX7o`00023ob=2]1?l0000:ojFf
bb?o00001on/ShL4o`000003ohF=V_l0003o000000Go00004?n2PXD2o`0001goXJBN0_l000001?n>
TGco0000o`000?l00003ohjAO0?o00000on>TG`3o`0000GoSY5l0ol0000GonKIf@;o00001?nXg;L0
1?l0003oZ=bgojSL]onXg;L5o`0000;oZ=bg0ol00009ojSL]`?o00003oo^cMl3o`0001CocKJP0_l0
000<ohVJW@03o`000?n9VYgoRIZM00?oRIZM00?o0000ohVJWOn9VYd00_n9VYd01?l0003oRIZMohVJ
WOl00003ohVJW@;o00006?nbY]P3o`0001CoQ9fJ1_l00004oinWO@Co0000S?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1jooooo`?o00002_n>^IP<o`0000;o[K:Z1ol0
000TolS@[@Co00002OnU]//Ro`0000[o[8n71ol0000Coh:2Q@?o00006onQY9h3o`0000;oSY5l00Go
0000ohjAO?n>TGcoSY5lo`000003ohjAO003o`000?n>TGco000000?oSY5l00?o0000ohjAO?n>TG`0
0on>TG`2o`0001Ooi]WI0_l0000KojSL]`;o00004Oo^cMl3o`0001;ocKJP0ol0000=ohVJW@03o`00
0?n9VYgoRIZM00;oRIZM00?o0000ohVJWOn9VYd00_n9VYd01?l0003oRIZMohVJWOl00002ohVJW@?o
00006?nbY]P2o`0001OoQ9fJ2_l0002>ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo07_ooooo0ol00007ohjiV0Ko00000onKOXP;o`0001Gob=2]0ol00002olS@[@Go0000
2_o8d:d3o`0000OoYKK;0ol0000MomRa^`?o00002on/ShL3o`0001OoPX:50_l0000Koj6TWP;o0000
0on>TG`00ol0003oSY5lohjAO005ohjAO003o`000?n>TGcoSY5l00?oSY5l00?o0000ohjAO?n>TG`0
0on>TG`4o`0001Goi]WI0_l0000KojSL]`;o00004_o^cMl3o`00017ocKJP0_l0000;ohVJW@05o`00
0?n9VYgoRIZMohVJWOl000000on9VYd00ol0003oRIZMohVJW@02ohVJW@04o`000?n9VYgoRIZMo`00
00;oRIZM0_l0000Iok:Vf0;o00006_n4WIX6o`0008oooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0O?ooool3o`0000CoS[VH1Ol0000:oi]nR0Go00005_o8d:d01Ol0003o
b=2]olS@[Oo8d:go000000;ob=2]00Co0000olS@[Oo8d:go00002oo8d:d3o`0000GoYKK;0ol0000N
omRa^`;o00003?n/ShL2o`0001SoPX:50ol0000Ioj6TWP?o00000on>TG`00ol0003oSY5lohjAO003
ohjAO0;o00001_n>TG`00ol0003oSY5lohjAO004ohjAO0Go00004ooVfMT2o`0001[oZ=bg0ol0000C
onk=g`?o00004?o=]Z02o`0000_oRIZM00Go0000ohVJWOn9VYgoRIZMo`000002ohVJW@;o00001?n9
VYd01Ol0003oRIZMohVJWOl0003oRIZM00?o00006OnbY]P2o`0001coQ9fJ0_l0002Aooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo2Ol0000?oi]nR0?o00006Oo8
d:d01Ol0003ob=2]olS@[Oo8d:go000000kob=2]1?l00003ojFfb`;o00002?oH/K/3o`0000Cof;6k
00?o0000omRa^ooH/K/03?oH/K/3o`0000co[8n70_l0000Ioh:2Q@;o00006?nQY9h3o`0000CoSY5l
00?o0000ohjAO?n>TG`01On>TG`00ol0003oSY5lo`000003o`0000KoSY5l2?l0000@onKIf@?o0000
6_nXg;L2o`0001Gok/gO0ol0000>olffX0?o00003?n9VYd3o`0000CoRIZM00?o0000ohVJWOn9VYd0
0on9VYd2o`0000;oRIZM0_l0000Jok:Vf0;o00007?n4WIX2o`00097ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0O_ooool6o`0001;oVgj80ol0000FolS@[@;o00001Oo8
d:d00ol0003ob=2]olS@[@09olS@[@_o00001ooH/K/01Ol0003of;6komRa^ooH/K_o000000?of;6k
00?o0000omRa^ooH/K/03?oH/K/2o`0000go[8n70ol0000:oh:2Q@;o00001?n2PXD2o`0000KoPX:5
0ol0000Goj6TWP;o00001?n>TG`2o`0000?oSY5l00Oo0000ohjAO?n>TGcoSY5lo`000?n>TGco0000
00WoSY5l0_l00003ojoOd0Go00003_oVfMT2o`0001[oZ=bg0ol00003onk=g`?o00000oo^cMl3o`00
00?ok/gO0_l00005onk=g`?o00003Oo=]Z02o`0001goRIZM0ol0000Jok:Vf0;o00007?n4WIX2o`00
097ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0001Ko
Vgj80ol0000GolS@[@03o`000?o8d:go000000?ob=2]00?o0000olS@[Oo8d:d01_o8d:d5o`0000;o
Wik61Ol00008omRa^`05o`000?oH/K_of;6komRa^ol000001?oH/K/00ol0003of;6komRa^`0:omRa
^`?o00003_n/ShL2o`0000coPX:500?o0000oh:2QOn2PXD00on2PXD00ol0003oPX:5oh:2Q@04oh:2
Q@?o00005OnQY9h3o`0000GoSY5l00?o0000ohjAO?n>TG`00_n>TG`3o`0000;oSY5l1Ol00004ohjA
O0?o00001On_gm05o`0000coi]WI0_l0000JojSL]`;o00001Oo^cMl01Ol0003ok/gOonk=goo^cMoo
000000?ok/gO00?o0000onk=goo^cMl00_o^cMl00ol0003ok/gOonk=g`03onk=g`?o00003?o=]Z02
o`0001goRIZM0_l0000Kok:Vf0;o00007?n4WIX2o`00097ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Ooooool2o`0001OoVgj80ol0000BolS@[@07o`000?o8d:gob=2]
olS@[Ol0003ob=2]o`000003olS@[@03o`000?o8d:gob=2]00Cob=2]1Ol00006oinNaP?o00002?oH
/K/4o`0000Gof;6k00?o0000omRa^ooH/K/02_oH/K/2o`0000oo[8n70_l0000=oh:2Q@03o`000?n2
PXGoPX:500?oPX:500?o0000oh:2QOn2PXD01?n2PXD2o`0001GoXJBN0_l0000IohjAO0;o00002?n_
gm05o`0000[oi]WI0_l0000IojSL]`?o00001Oo^cMl01Ol0003ok/gOonk=goo^cMoo000000?ok/gO
00?o0000onk=goo^cMl00oo^cMl00ol0003ok/gOonk=g`03onk=g`?o00002_o=]Z03o`0001coRIZM
0ol0000Kok:Vf0;o00007?n4WIX3o`00093ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0O_ooool3o`0001SoVgj81?l0000AolS@[@?o00000oo8d:d3o`0000Gob=2]1Ol0
0008oinNaPGo00001_oH/K/00ol0003of;6komRa^`07omRa^`03o`000?oH/K_of;6k00Sof;6k0ol0
000?ojb?Q`;o00002_n2PXD4o`0000;oPX:51?l00006oh:2QAWo00006?n>TG`3o`0000[o[mo@1?l0
0009onKIf@;o00006OnXg;L2o`0000Kok/gO00?o0000onk=goo^cMl00_o^cMl3o`0000?ok/gO1?l0
0006onk=g`?o00002Oo=]Z02o`0001goRIZM0_l0000Kok:Vf0?o00007On4WIX2o`00093ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2o`0001[oVgj81?l0000L
olS@[@Go00002_nOW/H6o`0000Kof;6k00?o0000omRa^ooH/K/00_oH/K/01Ol0003of;6komRa^ooH
/K_o000000[of;6k0_l0000@ojb?Q`;o00002On2PXD01ol0003oPX:5oh:2QOn2PXGo0000oh:2QOl0
00000on2PXD00ol0003oPX:5oh:2Q@05oh:2QAOo00006On>TG`2o`0000go[mo@1?l00007onKIf@;o
00006OnXg;L2o`0000Kok/gO00Go0000onk=goo^cMook/gOo`000003onk=g`03o`000?o^cMoo0000
00?ok/gO00?o0000onk=goo^cMl01Oo^cMl3o`0000SocKJP0_l0000LohVJW@?o00006onbY]P2o`00
01koQ9fJ0_l0002@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07ko
oooo0_l0000Loi]nR0?o00006Oo8d:d5o`0000_oWik60ol00002ojNhhPCo00001OoH/K/2o`0000;o
f;6k1Ol0000:omRa^`;o00004?n/ShL2o`0000WoPX:500Oo0000oh:2QOn2PXGoPX:5o`000?n2PXGo
000000?oPX:500?o0000oh:2QOn2PXD01?n2PXD3o`0001?oKjbT0ol0000GohjAO0?o00003_n_gm05
o`0000Coi]WI0ol0000EojSL]`Ko00001Oo^cMl2o`0000?ok/gO00Oo0000onk=goo^cMook/gOo`00
0?o^cMoo000000?ok/gO00?o0000onk=goo^cMl01_o^cMl3o`0000KocKJP0ol0000LohVJW@;o0000
7?nbY]P2o`0001koQ9fJ0_l0002@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07kooooo0_l0000Moi]nR0?o00005_o8d:d5o`0000goWik60_l00004ojNhhPGo00005OoH
/K/3o`00013o[8n70ol00009oh:2Q@?o00000on2PXD3o`0000OoPX:50_l0000Eofn/Y0;o00005on>
TG`2o`00017o[mo@1Ol00002onKIf@;o00003onXg;L<o`0000Ook/gO00?o0000onk=goo^cMl00_o^
cMl3o`0000?ok/gO0ol0000:onk=g`?o00001Oo=]Z02o`0001coRIZM0ol0000Lok:Vf0;o00007_n4
WIX2o`00093ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2
o`0001koVgj80ol0000ColS@[@Go00003onOW/H2o`0000KoYkSR1?l0000DomRa^`;o00001_n/ShL0
0ol0003o[8n7ojb?Q`02ojb?Q`;o00001On/ShL2o`0001WoPX:50_l0000Eofn/Y0;o00005_n>TG`3
o`0001?o[mo@2ol00004ojSL]`oo00000_n2ZGT3o`0001ook/gO0ol00004olffX0;o00007?n9VYd2
o`0001go/ZKH0_l0000NohBMVP;o0000T?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1mooooo`?o00007onKOXP4o`0000oob=2]1Ol0000@oinNaP?o00002?nW^>85o`00
013of;6k0ol00006ojb?Q`03o`000?n/ShOo[8n700Co[8n700?o0000ojb?Qon/ShL00_n/ShL2o`00
01SoPX:50ol0000Eofn/Y0?o00005On>TG`2o`0001Ko[mo@5Ol0000:oh:YN@;o00008?o^cMl3o`00
00;ocKJP0ol0000KohVJW@?o00000_nbY]P5o`000003ok:Vf?l0003o000000?o00000_nbY]P3o`00
00_o/ZKH0_l0000NohBMVP;o0000T?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1mooooo`;o00008OnKOXP4o`0000cob=2]1Ol0000BoinNaP;o00002_nW^>89o`0000_o
f;6k0_l00008ojb?Q`03o`000?n/ShOo[8n700Co[8n700Co0000ojb?Qon/ShOo[8n70_l0000Hoh:2
Q@;o00005om_[:@2o`0001CoSY5l0ol0000HojoOd0;o00001?nT`Y/6o`00017oPZUi0ol0000Ponk=
g`So00006_n9VYd2o`0000Co/ZKH00Co0000ok:Vf?nbY]So00000_nbY]P01_l0003o/ZKHok:Vf?l0
003o/ZKHo`0000?o/ZKH00?o0000ok:Vf?nbY]P02?nbY]P2o`0001koQ9fJ0ol0002?ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0_l0000Soi]nR0?o00002Oo8
d:d5o`0001CoWik60_l0000:ojNhhP;o000000?oYl>go`000?l000002?l00006omRa^`?o00002?n/
ShL01?l0003o[8n7ojb?Qon/ShL4o`0000?o[8n70_l0000Goh:2Q@?o00000_m_[:@3o`0000?oKjbT
0ol00003ofn/Y0;o00001om_[:@3o`0001;oSY5l0ol0000HojoOd0?o00001_nT`Y/3o`0001?oPZUi
0ol0000Ponk=g`_o00005On9VYd3o`0000Go/ZKH00?o0000ok:Vf?nbY]P00onbY]P00ol0003o/ZKH
ok:Vf005ok:Vf003o`000?nbY]So/ZKH00So/ZKH0_l0000OohBMVP;o0000Soooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1mooooo`;o00009?nKOXP3o`0000Kob=2]1Ol0
000FoinNaP;o00002_nW^>83o`0000GoYl>g2_l000000ooH/K_o0000o`00000:ojb?Q`03o`000?n/
ShOo000000?o[8n700Co0000ojb?Qon/ShOo[8n70_l0000Goh:2Q@;o00001?m_[:@00ol0003oKjbT
ofn/Y003ofn/Y003o`000?m_[:CoKjbT00CoKjbT00?o0000ofn/Y?m_[:@01Om_[:@2o`0001;oSY5l
0_l0000IojoOd0;o00002?nT`Y/2o`0001CoPZUi0_l0000Qonk=g`;o00000ooIi=48o`0001;oRIZM
0_l00007ok:Vf003o`000?nbY]So/ZKH00?o/ZKH00?o0000ok:Vf?nbY]P01?nbY]P00ol0003o/ZKH
ok:Vf007ok:Vf0?o00007on4WIX2o`0008oooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0OOooool2o`0002GoVgj80ol00003olS@[@Go00002onOW/H3o`0000?oWik60ol0
0003oinNaP?o00002onW^>82o`0000WoYl>g2Ol00006ojb?Q`07o`000?n/ShOo[8n7ojb?Qol0003o
[8n7o`000003ojb?Q`04o`000?n/ShOo[8n7ojb?Q`;o00005on2PXD2o`0000CoKjbT00?o0000ofn/
Y?m_[:@00om_[:@00ol0003oKjbTofn/Y005ofn/Y003o`000?m_[:CoKjbT00CoKjbT0_l0000AohjA
O0?o000000Co[mo@o`000?l0003o00001?n_gm03o`0000?o[mo@00?o0000ojoOd?n_gm002?n_gm02
o`0000SoY<:K0ol0000Coh:YN@Go00007Oo^cMl3o`0000OofNCA2?l0000=ohVJW@?o00001?nbY]P0
1ol0003o/ZKHok:Vf?nbY]So0000ok:Vf?l000000onbY]P00ol0003o/ZKHo`000003o`0000[o/ZKH
0_l0000PohBMVP;o0000Soooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1looooo`?o00009_nKOXP8o`0000coWik600Oo0000oinNa_nOW/KoWik6o`000?nOW/Ko000000?o
Wik600?o0000oinNa_nOW/H00_l0000<ojNhhP;o00003_nW`kL3o`0000Oo[8n71Ol00002ojb?Q`?o
00001?n/ShL3o`0001CoPX:51?l00004ofn/Y003o`000?m_[:CoKjbT00?oKjbT00?o0000ofn/Y?m_
[:@00_m_[:@4o`0000KoKjbT0ol0000@ohjAO0;o00000on_gm000ol0003o[mo@ojoOd004ojoOd003
o`000?n_gm3o[mo@00;o[mo@00?o0000ojoOd?n_gm001on_gm03o`0000WoY<:K0_l0000Doh:YN@Wo
00005oo^cMl3o`0000_ofNCA2Ol00009ohVJW@;o00001OnbY]P01ol0003o/ZKHok:Vf?nbY]So0000
ok:Vf?l000000onbY]P00ol0003o/ZKHo`00000=ok:Vf0;o00008?n4WIX2o`0008oooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O?ooool2o`0002SoVgj81Ol0000BoinN
aP03o`000?nOW/Ko000000?oWik600?o0000oinNa_nOW/H00_l0000<ojNhhP?o00000_nW`kL3o`00
00;oYl>g1Ol00002ojO3]`?o00005On/ShL2o`00017oPX:51_l00005ofn/Y003o`000?m_[:CoKjbT
00?oKjbT00Go0000ofn/Y?m_[:CoKjbTo`000003ofn/Y003o`000?m_[:CoKjbT00GoKjbT0_l0000?
ohjAO0?o00000on_gm001?l0003o[mo@ojoOd?n_gm05o`0000Co[mo@00?o0000ojoOd?n_gm001_n_
gm02o`0000[oY<:K0ol0000Coh:YN@;o000000?oklRdo`000?l000002Ol0000Bonk=g`;o00004?oI
i=48o`0000GoRIZM0ol00006ok:Vf0?o00000onbY]P3o`0000;o/ZKH1Ol00009ok:Vf0;o00001On4
WIX5o`0000;oQ9fJ0ol00004ohBMVP?o00002_n4WIX2o`0008oooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0O?ooool2o`0002WoVgj80_l0000BoinNaP;o00000onOW/H3
o`0000;oWik60ol0000=ojNhhP;o000000?oYl>go`000?nW`kL00_nW`kL01?l0003oYl>gojO3]ol0
0002ojO3]`04o`000?nW`kOoYl>gojO3]`?o00005?n/ShL2o`0000koPX:52_l00003ofn/Y0;o0000
1?m_[:@2o`0000?oKjbT00Go0000ofn/Y?m_[:CoKjbTo`000007ofn/Y0?o00003_n>TG`2o`0000Co
[mo@00Go0000ojoOd?n_gm3o[mo@o`000002ojoOd003o`000?n_gm3o[mo@00?o[mo@00?o0000ojoO
d?n_gm001On_gm03o`0000_oY<:K0_l0000Coh:YN@;o00001_o_b;@;o`0000cok/gO0ol0000DomWT
d@So000000?oRIZMo`000?l000008?nbY]P2o`0000KoQ9fJ00Ko0000ohBMV_n4WI[o0000ohBMV_l0
0003ohBMVP03o`000?n4WI[oQ9fJ00;oQ9fJ00?o0000ohBMV_n4WIX02On4WIX2o`0008oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O?ooool2o`0002WoVgj80_l0000D
oinNaP03o`000?nOW/Ko000000?oWik600Co0000oinNa_l0003o00003_nW^>82o`000003ojO3]ol0
003oYl>g00;oYl>g00Go0000ojO3]onW`kOoYl>go`000006ojO3]`?o00004on/ShL2o`0000_oPX:5
1ol00004olVba`;o00001?m_[:@00ol0003oKjbTofn/Y003ofn/Y003o`000?m_[:CoKjbT00;oKjbT
0ol00009ofn/Y0;o00003On>TG`3o`0000Co[mo@00?o0000ojoOd?n_gm000_n_gm000ol0003o[mo@
o`000006ojoOd003o`000?n_gm3o[mo@00Co[mo@0_l0000<ojC2V`?o00001?n2ZGT3o`0000CoPZUi
00?o0000oh:YNOn2ZGT00on2ZGT3o`0000_oklRd2ol00007onk=g`;o00006?oIi=48o`00023o/ZKH
0_l00007ohBMVP03o`000?n4WI[oQ9fJ00GoQ9fJ00?o0000ohBMV_l000001?l0000:ohBMVP?o0000
S_ooool00ol0003oooooooooo`08ooooo`001oooool3o`0000Cooooo0_l0000:ooooo`03o`000?oo
oooooooo07cooooo0_l0000Coi]nR0?o00000onKOXP2o`0000koVgj80ol0000?oinNaP07o`000?nO
W/KoWik6oinNa_l0003oWik6o`000003oinNaP04o`000?nOW/Ko0000o`0000koYkSR1ol00005ojO3
]`03o`000?nW`kOoYl>g00CoYl>g0_l0000Cojb?Q`;o00002On2PXD6o`0000OobK;70ol0000Jofn/
Y0;o00003On>TG`2o`0000Co[mo@0_l00005ojoOd0;o00000_n_gm001Ol0003o[mo@ojoOd?n_gm3o
000000Ko[mo@0_l000001?nT`Y_o0000o`000?l00003ojC2V`?o00000onT`Y/2o`0000GoPZUi00?o
0000oh:YNOn2ZGT00on2ZGT00ol0003oPZUioh:YN@03oh:YN@;o00004Oo_b;@;o`000004onk=gol0
003o0000o`0001cofNCA0ol0000Qok:Vf0;o00002?n4WIX00ol0003oQ9fJohBMVP02ohBMVP;o0000
0_n4WIX01?l0003oQ9fJohBMV_l0000<ohBMVP;o0000S_ooool00ol0003oooooooooo`08ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`1kooooo`?o00005?nKOXP00ol0003oVgj8oi]nR004oi]nR003o`000?nKOXSoVgj8
00coVgj80_l0000@oinNaP?o00000onOW/H3o`000004oinNa_l0003o0000o`0000ooYkSR0ol00005
ojO3]`05o`000?nW`kOoYl>gojO3]ol000001OnW`kL3o`0001;o[8n70_l00006oh:2Q@Ko00002oo9
//L3o`0001WoKjbT1?l0000:ohjAO0?o00001On_gm000ol0003o[mo@ojoOd004ojoOd003o`000?n_
gm3o[mo@00Go00001On_gm03o`0000;oY<:K00Go0000ojC2VonT`Y_oY<:Ko`000003ojC2V`03o`00
0?nT`Y_oY<:K00?o00001?n2ZGT00ol0003oPZUioh:YN@04oh:YN@03o`000?n2ZGWoPZUi00Go0000
5Oo_b;@9o`0001kofNCA0ol0000Ook:Vf0?o00001On4WIX01Ol0003oQ9fJohBMV_n4WI[o000000Go
Q9fJ00Ko0000ohBMV_n4WI[o0000ohBMV_l0000<ohBMVP;o0000S_ooool00ol0003oooooooooo`08
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`1kooooo`;o00005OnKOXP00ol0003oVgj8oi]nR005oi]nR003o`000?nK
OXSoVgj800_oVgj80_l0000JoinNaP;o00004?nW^>82o`000003ojO3]ol0003oYl>g00?oYl>g00Go
0000ojO3]onW`kOoYl>go`000006ojO3]`Co00004?n/ShL3o`0000;oPX:51ol0000>olVba`;o0000
6?m_[:@8o`0000OoSY5l0_l0000JojoOd0;o00000onT`Y/01Ol0003oY<:KojC2VonT`Y_o000000?o
Y<:K00Co0000ojC2VonT`Y_oY<:K0_l00004oh:YN@03o`000?n2ZGWoPZUi00CoPZUi00Go0000oh:Y
NOn2ZGWo0000oh:YN@02o`0001_oklRd0ol0000PomWTd@;o00007onbY]P2o`0000KoQ9fJ00Oo0000
ohBMV_n4WI[oQ9fJo`000?n4WI[o000000?oQ9fJ00Co0000ohBMV_n4WI[oQ9fJ0_l0000<ohBMVP;o
0000S_ooool00ol0003oooooooooo`08ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo
00002Oooool5o`0007Wooooo0_l0000Eoi]nR003o`000?nKOXSoVgj800;oVgj81?l0000=oi]nR0?o
00006OnOW/H2o`00013oYkSR0ol000000onW`kOo0000o`000003ojO3]`?o00001onW`kL7o`0000ko
[8n72?l0000AolVba`?o00005_m_[:@3o`0000;o[<bX1ol00003ohjAO0?o00006On_gm03o`0000?o
Y<:K00Co0000ojC2VonT`Y_oY<:K1?l00004ojC2V`?o00000on2ZGT00ol0003oPZUioh:YN@05oh:Y
N@03o`000?n2ZGWoPZUi00?o00007?o_b;@2o`00023ofNCA0ol0000Nok:Vf0;o00001on4WIX3o`00
00?oQ9fJ0ol00005ohBMVP03o`000?n4WI[oQ9fJ00[oQ9fJ0_l0002:ooooo`Go00002_ooool000Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0Noooool2o`0001GoVgj800Go0000oi]nR?nKOXSoVgj8o`000003oi]nR003o`000?nK
OXSoVgj800coVgj80_l0000IoinNaP;o00001_nW^>83o`0000?oYkSR0ol00002ojNhhP;o00003onW
`kL3o`000003ol^[aol0003o000000Go00002on/ShL5o`0001GobK;70_l0000Eofn/Y0?o00001_n/
c:P9o`0001[o[mo@0_l00004ojC2V`05o`000?nT`Y_oY<:KojC2Vol000002?nT`Y/2o`0000;oPZUi
0_l00003oh:YN@05o`000?n2ZGWoPZUioh:YNOl000000on2ZGT2o`0001coklRd0_l00002omWTd@Go
00000ooIi=42o`0000?ofNCA0ol0000?omWTd@;o00007_nbY]P2o`00027oQ9fJ0ol0002>ooooo`03
o`000?oooooooooo00Sooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo07_ooooo0ol0000Coi]nR0;o00000onKOXP01Ol0
003oVgj8oi]nR?nKOXSo000000koVgj80_l0000HoinNaP?o00001OnW^>801ol0003oYkSRojNhh_nW
^>;o0000ojNhh_l000000onW^>801?l0003oYkSRo`000?l0000>ojO3]`?o00001Oo;ZlL7o`0000So
[8n70_l0000HolVba`?o00004om_[:@3o`0000[o[<bX1_l0000JojoOd0;o00000onT`Y/2o`0000Co
Y<:K00?o0000ojC2VonT`Y/00_nT`Y/00ol0003oY<:KojC2V`03o`0000;oPZUi00Co0000oh:YNOn2
ZGWoPZUi1Ol00002oh:YN@?o00007?o_b;@2o`0000?ofNCA00Co0000omWTdOoIi=7o00000_oIi=40
1_l0003ofNCAomWTdOl0003ofNCAo`0000?ofNCA00?o0000omWTdOoIi=403?oIi=42o`0001ko/ZKH
0_l0000PohBMVP?o0000Soooool00ol0003oooooooooo`08ooooo`001oooool3o`0000Cooooo0_l0
000:ooooo`03o`000?oooooooooo07cooooo0_l0000Doi]nR003o`000?nKOXSoVgj800;oVgj80ol0
000?oi]nR0?o00005onOW/H2o`0000[oYkSR00?o0000ojNhh_l000000onW^>801?l0003oYkSRo`00
0?l0000=ojO3]`?o00002Oo;ZlL7o`0000Co[8n70ol0000IolVba`;o00004Om_[:@4o`0000ko[<bX
0_l0000IojoOd0Co00001?nT`Y/00ol0003oY<:KojC2V`03ojC2V`;o00000_nT`Y/6o`0000goPZUi
0_l00003ono8]0?o00000oo_b;@3o`0000CoklRd00?o0000ono8]?o_b;@02Oo_b;@3o`0000CofNCA
00?o0000omWTdOoIi=400_oIi=401?l0003ofNCAomWTdOl00005omWTd@03o`000?oIi=7ofNCA00co
fNCA0ol0000Mok:Vf0;o00007on4WIX3o`00093ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0O?ooool2o`0002coVgj80_l0000GoinNaP;o00002_nW^>800ol0003oYkSR
o`000003o`0000;oYkSR0ol0000;ojO3]`?o00003Oo;ZlL7o`000003ojb?Qol0003o000001[obK;7
0ol0000?ofn/Y0Co00003on/c:P3o`0001Oo[mo@1_l0000AojC2V`?o00003?n2ZGT2o`0000CoklRd
00Go0000ono8]?o_b;CoklRdo`000003ono8]005o`000?o_b;CoklRdono8]?l000002oo_b;@2o`00
00KofNCA00Go0000omWTdOoIi=7ofNCAo`000002omWTd@03o`000?oIi=7ofNCA00?ofNCA00?o0000
omWTdOoIi=403OoIi=42o`0001go/ZKH0_l0000OohBMVP;o0000TOooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1looooo`;o0000;?nKOXP2o`0001KoWik60ol00006ojNh
hPCo00000_nW^>800ol0003oYkSRojNhhP04ojNhhP;o00002_nW`kL3o`00017obj_71ol00009olVb
a`?o00001?o9//L2o`0000?obK;70ol00003olVba`?o00003Om_[:@3o`0001;o[<bX0ol0000DojoO
d0Co00000_n`[:h3o`00017oY<:K0ol0000;oh:YN@;o00001?o_b;@01Ol0003oklRdono8]?o_b;Co
000000?oklRd00?o0000ono8]?o_b;@00_o_b;@00ol0003oklRdono8]008ono8]0;o00000ooIi=40
1Ol0003ofNCAomWTdOoIi=7o000000;ofNCA00Go0000omWTdOoIi=7o0000omWTd@04o`00013ofNCA
0ol0000Lok:Vf0;o00007_n4WIX3o`00097ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0O?ooool3o`0002_oVgj80ol0000BoinNaPGo00001onW^>800ol0003oYkSRojNh
hP04ojNhhP03o`000?nW^>;oYkSR00?oYkSR0_l00009ojO3]`?o00005?o;ZlL4o`0000_obK;700?o
0000olVbaoo9//L00_o9//L01?l0003obK;7olVbaol00003olVba`03o`000?o9//OobK;700?obK;7
0_l0000<ofn/Y0?o00005?n/c:P3o`0001;o[mo@1?l00004ok2/[PCo00004?nT`Y/2o`0000_oPZUi
0_l00004ono8]003o`000?o_b;CoklRd00;oklRd0ol00005ono8]003o`000?o_b;CoklRd00SoklRd
0_l00003omWTd@05o`000?oIi=7ofNCAomWTdOl000000_oIi=401_l0003ofNCAomWTdOl0003ofNCA
o`0001CofNCA0_l0000Kok:Vf0?o00007On4WIX3o`0009;ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0OOooool2o`0002coVgj80_l0000=oinNaP[o00001onW^>85o`00
00?oYkSR0_l00003ojNhhP?o00001onW`kL3o`0001Cobj_71_l0000:olVba`03o`000?o9//OobK;7
00;obK;700Co0000olVbaoo9//Oo00000oo9//L00ol0003obK;7olVba`03olVba`?o00002_m_[:@3
o`0001Ko[<bX0ol0000@ojoOd0?o00001on`[:h4o`0000ooY<:K0ol0000:oh:YN@;o00001?o_b;@0
1Ol0003oklRdono8]?o_b;Co000000?oklRd00?o0000ono8]?o_b;@00oo_b;@00ol0003oklRdono8
]007ono8]0;o00001?oIi=43o`0000CofNCA0_l00002omWTd@Go00004?oIi=43o`0001[o/ZKH0_l0
000MohBMVP?o0000Toooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1m
ooooo`;o0000;?nKOXP2o`0000OoWik63?l00002ol;8h0?o00005?nW^>82o`0000KoYl>g0ol0000D
ol^[a`?o00000_n4RIL2o`0000[obK;700?o0000olVbaoo9//L00_o9//L01?l0003obK;7olVbaol0
0003olVba`03o`000?o9//OobK;700CobK;70_l00009ofn/Y0?o00006?n/c:P3o`0000go[mo@1?l0
000:ok2/[PCo00003_nT`Y/2o`0000[oPZUi0_l00003ono8]0;o00000oo_b;@01ol0003oklRdono8
]?o_b;Co0000ono8]?l000000oo_b;@00ol0003oklRdono8]007ono8]0;o00009OoIi=42o`0001[o
/ZKH0_l0000MohBMVP;o0000U?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1mooooo`;o0000;?nKOXP3o`000003oinNa_l0003o000000[o00002?o2b>03o`0001?oYkSR
0_l00005ojO3]`?o00005?o;ZlL3o`0000?oQ8VG0ol00009olVba`03o`000?o9//OobK;700;obK;7
00Co0000olVbaoo9//Oo00000oo9//L00ol0003obK;7olVba`04olVba`?o00001_m_[:@4o`0001[o
[<bX0ol0000;ojoOd0Co00003?n`[:h4o`0000goY<:K0ol00008oh:YN@?o00001?o_b;@00ol0003o
klRdono8]002ono8]0?o00000_o_b;@5o`0000WoklRd0_l0000UomWTd@;o00006_nbY]P2o`0001co
Q9fJ0ol0002Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo
0ol0000/oi]nR0Wo00003oo2b>02o`0001?oYkSR0ol00003ojO3]`?o00005?o;ZlL3o`0000GoQ8VG
0_l00008olVba`;o00001?o9//L01?l0003obK;7olVbaol00002olVba`;o00001oo9//L2o`0000Go
KjbT1?l0000Lojc<Z0;o00002On_gm04o`00013o/:b^0ol0000=ojC2V`;o00002?n2ZGT2o`0001go
klRd0_l0000UomWTd@?o00006OnbY]P2o`0001_oQ9fJ0ol0002Eooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo07kooooo0_l0000/oi]nR0Co00005?o2b>03o`0001?oYkSR
0_l00002ojO3]`?o00005?o;ZlL3o`0000KoQ8VG0ol00008olVba`03o`000?o9//OobK;700?obK;7
0_l00004olVba`03o`000?o9//OobK;700GobK;70ol00003ofn/Y0?o00007_n/c:P3o`0000Oo[mo@
1?l0000Bok2/[PCo00002onT`Y/3o`0000OoPZUi0_l0000Lono8]0?o00009_oIi=42o`0001Wo/ZKH
0_l0000JohBMVP?o0000U_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1nooooo`;o0000:onKOXP3o`0001Oo`/SP0ol0000BojNhhP;o000000?oYl>go`000?l000000_l0
0004ol^[a`?o00003?o;ZlL3o`0000SoQ8VG0ol0000LolVba`?o000000CoKjbTo`000?l0003o0000
8?n/c:P3o`0000Go[mo@0ol0000Eok2/[PCo00002onT`Y/2o`0000OoPZUi0_l0000Lono8]0;o0000
9ooIi=44o`0001Oo/ZKH0_l0000IohBMVP?o0000Uoooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1nooooo`;o0000:onKOXP2o`0001Wo`/SP0_l0000BojNhhPGo000000?o
bj_7o`000?o;ZlL01?o;ZlL00ol0003obj_7ol^[a`0:ol^[a`?o00002_n4RIL2o`0001gobK;71Ol0
000Rojc<Z0?o00000_n_gm04o`0001So/:b^0ol0000:ojC2V`?o00001_n2ZGT2o`0001coklRd0_l0
000UomWTd@So00005OnbY]P2o`0001WoQ9fJ0_l0002Hooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo07kooooo0ol0000Yoi]nR0?o00006Oo2b>03o`0001;oYkSR0ol00003
ol^[a`03o`000?o;ZlOobj_700;obj_700?o0000ol^[aoo;ZlL02Oo;ZlL3o`0000_oQ8VG0ol0000L
olVba`Co00009?n/c:P7o`0001[o/:b^1?l00009ojC2V`;o00001_n2ZGT2o`0001[oklRd1?l0000T
omWTd@Co00000_nMhm@5o`0001;o/ZKH0ol0000HohBMVP?o0000V?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1oooooo`;o0000:OnKOXP2o`0001_o`/SP0ol0000AojNh
hP;o00001?o;ZlL00ol0003obj_7ol^[a`02ol^[a`03o`000?o;ZlOobj_700Sobj_70ol0000=ohB9
U`;o00007Oo9//L2o`0002Ko[<bX1?l0000Mok2/[PCo00002?nT`Y/3o`0000CoPZUi0ol0000Fono8
]0So00008_oIi=44o`0000KoWN?D1?l0000Aok:Vf0;o00006?n4WIX3o`0009Wooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002SoVgj80ol0000Lol;8h0;o
00004?nW^>83o`0000Gobj_700Go0000ol^[aoo;ZlOobj_7o`000009ol^[a`?o00003_n4RIL3o`00
01cobK;70_l0000Wojc<Z0;o00008?n`[:h3o`0000SoY<:K0_l00004oh:YN@;o00004oo_b;@9o`00
0004ongTnol0003o0000o`0001oofNCA1Ol00009oigSe0Co00003onbY]P2o`0001OoQ9fJ0ol0002J
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000Woi]n
R0?o00007Oo2b>03o`0000ooYkSR0_l00002ol^[a`05o`000?o;ZlOobj_7ol^[aol000000_o;ZlL2
o`0000Sobj_70ol0000@ohB9U`;o00006oo9//L3o`0000ko[<bX0ol00003ojc<Z0?o00000on/c:P3
o`0000[o[<bX0_l00008ok2/[P?o00000on`[:h3o`0000?o/:b^0ol0000:ok2/[PCo00001_nT`Y/3
o`0000;oPZUi1_l0000<ono8]0Wo00001_o]i?/3o`0001gofNCA1?l0000<oigSe0Go00003OnbY]P2
o`0001OoQ9fJ0_l0002Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
07oooooo0ol0000Voi]nR0;o00007oo2b>03o`0000koYkSR0_l00002ol^[a`Go00000oo;ZlL00ol0
003obj_7ol^[a`05ol^[a`?o00004On4RIL3o`0001SobK;71?l0000@ojc<Z005o`000?n/c:So[<bX
ojc<Z?l000000on/c:P01Ol0003o[<bXojc<Z?n/c:So000000_o[<bX0_l00009ok2/[P05o`000?n`
[:ko/:b^ok2/[_l000000on`[:h00ol0003o/:b^o`000003ok2/[P03o`000?n`[:ko/:b^00So/:b^
1?l00006ojC2V`oo00000oo_b;@9o`0000_okNCk0ol0000JomWTd@Co00004?nMhm@5o`0000_o/ZKH
0_l0000FohBMVP?o0000Voooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`20ooooo`;o00009OnKOXP3o`00023o`/SP0_l0000=ojNhhP?o00004Oo;ZlL3o`0001?oQ8VG0_l0
000EolVba`Oo00004?n/c:P00ol0003o[<bXojc<Z005ojc<Z005o`000?n/c:So[<bXojc<Z?l00000
2on/c:P3o`0000So/:b^00?o0000ok2/[_n`[:h01On`[:h00ol0003o/:b^o`000003ok2/[P03o`00
0?n`[:ko/:b^00[o/:b^1?l00004ojC2V`Go00001?n^RHX>o`00013okNCk0ol0000GomWTd@Go0000
4onMhm@5o`0000Wo/ZKH0_l0000EohBMVP?o0000W?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`20ooooo`;o00009OnKOXP2o`0000ko`/SP0ol00003ol;8h0;o00002oo2
b>03o`0000coYkSR0_l0000Aol^[a`?o00005?n4RIL3o`00013obK;72?l000001?nCVI_o0000o`00
0?l0000?ojc<Z003o`000?n/c:So[<bX00?o[<bX0_l00004ojc<Z003o`000?n/c:So[<bX00So[<bX
1Ol00007ok2/[P03o`000?n`[:ko/:b^00Go/:b^00?o0000ok2/[_n`[:h00ol0000>ok2/[PCo0000
0_nT`Y/4o`0000_o[XV:1Ol0000EongTn`?o00005?oIi=45o`0001OoWN?D1Ol00007ok:Vf0;o0000
5?n4WIX3o`0009gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?oo
ool2o`0002CoVgj80ol0000?ol;8h005o`000?o2b>3o`/SPol;8h?l000000_o2b>000ol0003o`/SP
ol;8h009ol;8h0Wo00001OnW^>82o`00013obj_70ol0000FohB9U`?o00003?o9//L8o`0000GoTiVK
0ol0000>ojc<Z003o`000?n/c:So[<bX00Go[<bX00Go0000ojc<Z?n/c:So[<bXo`000009ojc<Z0?o
000000Co/Y^Ao`000?l0003o00001_n`[:h01?l0003o/:b^ok2/[_n`[:h4o`0000;o/:b^00Go0000
ok2/[_n`[:ko/:b^o`00000?ok2/[PKo00003on^RHX2o`0001OokNCk0ol0000BomWTd@Co00006onM
hm@5o`0000Go/ZKH0_l0000DohBMVP;o0000W_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`20ooooo`?o00008onKOXP2o`0000go`/SP1Ol00002ol;8h004o`000?o2b>3o
`/SPo`0000_o`/SP4?l0000?ol^[a`?o00006?n4RIL2o`0000WobK;71ol0000:oi>IV`?o00003?n/
c:P2o`0000?o[<bX00Go0000ojc<Z?n/c:So[<bXo`000002ojc<Z0;o00002?n/c:P3o`0000?o/Y^A
0ol00004ok2/[P;o00000on`[:h00ol0003o/:b^ok2/[P03ok2/[P05o`000?n`[:ko/:b^ok2/[_l0
00004?n`[:h4o`00013o[XV:0ol0000GongTn`?o00003ooIi=44o`0001ooWN?D1?l00003ok:Vf0?o
00004on4WIX3o`0009kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
POoooolWo`0000go`/SP00Co0000ol;8h?o2b>3o00000oo2b>001?l0003o`/SPol;8h?l0000:ol;8
h0?o00001_nW_[48o`0000kobj_70ol0000IohB9U`?o00001?o9//L8o`0000koTiVK0_l0000=ojc<
Z003o`000?n/c:So[<bX00;o[<bX0ol00004ojc<Z003o`000?n/c:So[<bX00Go[<bX0ol00005ok:K
T@?o00001?n`[:h01?l0003o/:b^ok2/[_n`[:h5o`0000;o/:b^0ol0000Bok2/[P;o00004_n^RHX2
o`0001SokNCk0_l0000=omWTd@Go00008_nMhm@4o`000003ok:Vf?l0003o000001?oQ9fJ0ol0002O
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo9_l0000?ol;8
h003o`000?o2b>3o000000?o`/SP00Co0000ol;8h?o2b>3o00002Oo2b>03o`0000goYkja0ol0000<
ol^[a`?o00001On4RIL3o`0000CoQ8VG0ol0000<ohB9U`;o000000?obK;7o`000?l000001_l0000A
oi>IV`?o00007on/c:P3o`0000Oo/Y^A0ol0000Rok2/[P?o00004_n^RHX2o`0001SokNCk0ol0000;
omWTd@Co00009OnMhm@6o`00017oQ9fJ1?l0002Pooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo087ooooo0_l0000RohVh/0?o00003oo2b>02o`0000?o`/SP00Co0000ol;8
h?o2b>3o00002?o2b>03o`0000ooYkja0ol0000:ol^[a`?o00001On4RIL01Ol0003oQ8VGohB9Uon4
RIOo000000CoQ8VG00?o0000ohB9Uon4RIL02on4RIL7o`0001KoTiVK0ol0000Mojc<Z0?o00002Onb
Vi43o`0001oo/:b^1?l0000Cojj9RP;o00006Oo]i?/3o`0000SofNCA1?l0000YoigSe0Co00003_n4
WIX6o`000:7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool3
o`0002?oRKR`0ol0000?ol;8h003o`000?o2b>3o`/SP00;o`/SP0_l00008ol;8h0?o00004OnW_[43
o`0000Sobj_70ol00006ohB9U`06o`000?n4RIOoQ8VGohB9Uol0003oQ8VG1Ol0000=ohB9U`?o0000
6_nCVI/2o`0001co[<bX0ol0000;ok:KT@?o00007?n`[:h5o`0001Co[XV:0ol0000IongTn`?o0000
1OoIi=45o`0002coWN?D0_l0000;ohBMVPOo0000Xoooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`20ooooo`;o00009On9^;03o`0001co`/SP0ol0000CojNn/@?o00001_o;
ZlL3o`0000SoQ8VG0ol00002ohB9U`04o`000?n4RIOoQ8VGo`0000koQ8VG0_l0000Koi>IV`?o0000
6_n/c:P3o`0000go/Y^A1?l0000Hok2/[PSo00005?n^RHX2o`0000KokNCk0ol00003ongTn`;o0000
1?o]i?/3o`0000GokNCk0ol00003omWTd@Co0000;_nMhm@3o`0000OoQ9fJ1ol0002Vooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000VohVh/0?o00006_o2
b>03o`0001GoYkja0ol00004ol^[a`?o00002?n4RIL01Ol0003oQ8VGohB9Uon4RIOo000000;oQ8VG
00?o0000ohB9Uol000003On4RIL3o`0001coTiVK0ol0000Hojc<Z0?o00003onbVi44o`0001Go/:b^
1Ol00003ohbIY0Go00001?n^RHX00ol0003o[XV:ojj9RP02ojj9RP;o00001_n^RHX2o`0000OokNCk
00?o0000ongTnoo]i?/01?o]i?/00ol0003okNCkongTn`02ongTn`03o`000?o]i?_okNCk00GokNCk
1ol0000aoigSe0?o00000on4WIX7o`000:Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Ooooool3o`0002OoRKR`0_l0000Iol;8h0?o00005onW_[43o`0000;obj_70ol0
0009ohB9U`05o`000?n4RIOoQ8VGohB9Uol000000on4RIL2o`0000goQ8VG0_l0000Noi>IV`?o0000
5_n/c:P3o`0001;o/Y^A0ol0000Bok2/[PGo00001On<VJ@2o`000003ojj9R_l0003o[XV:00Co[XV:
00?o0000ojj9R_n^RHX01?n^RHX00ol0003o[XV:ojj9RP03ojj9RP;o00001oo]i?/00ol0003okNCk
ongTn`05ongTn`05o`000?o]i?_okNCkongTnol000002?o]i?/5o`0003?oWN?D2Ol0002/ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000XohVh/0?o0000
5oo2b>03o`0000OoYkja0ol00003ojNn/@?o00002OnW_[46o`0000_oQ8VG0ol00005ohB9U`03o`00
0?n4RIOoQ8VG00_oQ8VG0_l0000Ooi>IV`;o00005On/c:P3o`0001Co/Y^A0ol0000?ok2/[PGo0000
1on<VJ@4o`0000Ko[XV:00?o0000ojj9R_n^RHX01?n^RHX00ol0003o[XV:ojj9RP02ojj9RP?o0000
1_o]i?/00ol0003okNCkongTn`02ongTn`Co00000oo]i?/00ol0003okNCkongTn`07ongTn`;o0000
=OnMhm@6o`000:oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Oooo
ool2o`0002WoRKR`0ol0000Eol;8h0?o00001onW_[401Ol0003oYkjaojNn/OnW_[7o000000?oYkja
00?o0000ojNn/OnW_[402OnW_[44o`00027oQ8VG0ol0000Ooi>IV`?o00004on/c:P3o`0001Ko/Y^A
0ol0000<ok2/[PGo00002_n<VJ@3o`0000Ko[XV:00Co0000ojj9R_n^RH[o[XV:1?l00005ojj9RP;o
00001_o]i?/01Ol0003okNCkongTnoo]i?_o000000?okNCk00Go0000ongTnoo]i?_okNCko`000009
ongTn`;o00005onMhm@5o`0000;oWN?D0ol00003oigSe0?o00003onMhm@2o`000;;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002[oRKR`0ol0000Col;8
h0?o00003?nW_[401Ol0003oYkjaojNn/OnW_[7o000000coYkja0_l0000RohB9U`;o00001_nCVI/3
o`0000CoTiVK0_l00003oi>IV`;o00003OnCVI/3o`00017o[<bX0ol0000Hok:KT@?o00002On`[:h5
o`0000coS9VT0ol00007ojj9RP03o`000?n^RH[o000000?o[XV:00?o0000ojj9R_n^RHX00on^RHX2
o`0000GokNCk0_l00003ongTn`05o`000?o]i?_okNCkongTnol000000_o]i?/2o`0000WokNCk0_l0
000HoigSe004o`000?nMhmCoWN?Do`0000?oWN?D00Go0000oigSe?nMhmCoWN?Do`000003oigSe003
o`000?nMhmCoWN?D00coWN?D0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000
Ooooool2o`0002_oRKR`0_l0000Bol;8h0?o00003OnW_[401Ol0003oYkjaojNn/OnW_[7o000000co
Ykja0ol0000QohB9U`;o00001onCVI/00ol0003oTiVKoi>IV`02oi>IV`04o`000?nCVI_oTiVKo`00
00CoTiVK00?o0000oi>IVonCVI/02onCVI/2o`00013o[<bX0ol0000Jok:KT@?o00001_n`[:h5o`00
00koS9VT0ol00003ojj9RP07o`000?n^RH[o[XV:ojj9R_l0003o[XV:o`000003ojj9RP03o`000?n^
RH[o[XV:00?o[XV:0ol00005ongTn`03o`000?o]i?_okNCk00;okNCk0ol00004ongTn`03o`000?o]
i?_okNCk00KokNCk0ol0000IoigSe003o`000?nMhmCoWN?D00?oWN?D00Go0000oigSe?nMhmCoWN?D
o`000003oigSe003o`000?nMhmCoWN?D00coWN?D0_l0002`ooooo`?o00002_ooool001[ooooo00?o
0000ooooooooool0Ooooool3o`0002[oRKR`0ol0000@ol;8h0?o00002_nW_[44o`0000CoYkja00?o
0000ojNn/OnW_[402onW_[43o`0001ooQ8VG0ol00007oi>IV`03o`000?nCVI_oTiVK00;oTiVK00Co
0000oi>IVonCVI_o00001OnCVI/00ol0003oTiVKoi>IV`0:oi>IV`?o00003_n/c:P3o`0001co/Y^A
0ol00003ok2/[PSo00000on<VJ@3o`0000?oS9VT0ol00002ohbIY0;o00000on^RHX5o`0000;o[XV:
0ol00007ojj9RP;o00006_o]i?/2o`0001_oWN?D00?o0000oigSe?nMhm@00_nMhm@01?l0003oWN?D
oigSe?nMhm@4o`0000ooWN?D0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo083ooooo0_l0000[ohVh/0?o00003_o2b>03o`0000_oYkja00?o0000ojNn/OnW_[40
1?nW_[42o`0000goYkja1_l0000LohB9U`;o00002?nCVI/00ol0003oTiVKoi>IV`02oi>IV`04o`00
0?nCVI_oTiVKo`0000;oTiVK1?l0000=oi>IV`?o00003?n/c:P3o`0001ko/Y^A2?l00003ohbIY005
o`000?n<VJCoS9VTohbIY?l000000on<VJ@00ol0003oS9VTo`000003ohbIY004o`000?n<VJCo0000
o`0001Co[XV:0_l0000JongTn`;o00006?nMhm@01Ol0003oWN?DoigSe?nMhmCo000000?oWN?D00Go
0000oigSe?nMhmCoWN?Do`00000AoigSe0?o0000/_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`20ooooo`;o0000;?n9^;03o`0000co`/SP0ol0000<ojNn/@Go00000onW
_[400ol0003oYkjaojNn/@0:ojNn/@[o00006On4RIL2o`0000SoTiVK00?o0000oi>IVonCVI/00_nC
VI/01_l0003oTiVKoi>IVol0003oTiVKo`0000?oTiVK00?o0000oi>IVonCVI/03?nCVI/7o`0000Co
[<bX1Ol0000Pok:KT@Go00001On<VJ@01Ol0003oS9VTohbIY?n<VJCo000000?oS9VT00?o0000ohbI
Y?l000000on<VJ@00ol0003oS9VTo`000002o`0001?o[XV:0_l0000JongTn`;o00006?nMhm@01Ol0
003oWN?DoigSe?nMhmCo000000;oWN?D0_l00004oigSe003o`000?nMhmCoWN?D00koWN?D0_l0002c
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000AohVh
/0Go00000on9^;02o`0001;oRKR`1_l00007ol;8h0?o00008OnW_[43o`0000Co_IN<1_l0000FohB9
U`?o00001onCVI/2o`0000CoTiVK00Ko0000oi>IVonCVI_o0000oi>IVol00003oi>IV`03o`000?nC
VI_oTiVK00coTiVK3ol0000Rok:KT@;o00001on<VJ@01?l0003oS9VTohbIY?n<VJ@4o`0000?oS9VT
0ol00003ohbIY0;o00004on^RHX3o`0001WokNCk0_l0000IoigSe0?o00001?nMhm@00ol0003oWN?D
oigSe003oigSe0;o00003_nMhm@2o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0P?ooool2o`0001;oRKR`00Co0000ohVh/?n9^;3o00000_n9^;001?l0003oRKR`
ohVh/?l0000BohVh/0[o000000Co`/SPo`000?l0003o00008_nW_[42o`0000So_IN<1_l0000BohB9
U`Co00002?nCVI/00ol0003oTiVKoi>IV`03oi>IV`;o00000onCVI/3o`0000koTiVK0ol00004ok>n
_@Ko000000CoQHnVo`000?l0003o00008OnbVi42o`0000OoS9VT00Go0000ohbIY?n<VJCoS9VTo`00
0005ohbIY005o`000?n<VJCoS9VTohbIY?l000000_n<VJ@2o`0001Co[XV:0_l0000HongTn`?o0000
=_nMhm@2o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?oo
ool2o`0001?oRKR`00?o0000ohVh/?n9^;000_n9^;001?l0003oRKR`ohVh/?l0000AohVh/0?o0000
0_o;WZ/9o`0002;oYkja0ol0000:okfGS0Ko00003on4RIL8o`00023oTiVK0ol00008ok>n_@;o0000
0on5SjH3o`00023o/Y^A0_l00006ohbIY0;o00001?n<VJ@00ol0003oS9VTohbIY002ohbIY005o`00
0?n<VJCoS9VTohbIY?l000000_n<VJ@3o`0001?o[XV:0_l0000HongTn`;o0000=_nMhm@3o`000;?o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool3o`0001?oRKR`
00Go0000ohVh/?n9^;3oRKR`o`000002ohVh/003o`000?n9^;3oRKR`00koRKR`0ol00008ol^NZ`?o
00008onW_[42o`0000ko_IN<1_l0000;ohB9U`?o00000_nSijH6o`0001goTiVK0ol00009ok>n_@;o
00001?n5SjH3o`0001oo/Y^A0_l00007ohbIY003o`000?n<VJCoS9VT00?oS9VT0_l00003ohbIY0?o
00001?n<VJ@2o`0001?o[XV:0_l0000HongTn`?o0000<_nMhm@6o`000;?ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`00013oRKR`00Go0000ohVh/?n9^;3o
RKR`o`000002ohVh/004o`000?n9^;3oRKR`o`00013oRKR`0_l0000:ol^NZ`?o00008OnW_[43o`00
013o_IN<1ol00007ohB9U`?o00001_nSijH6o`0001WoTiVK0ol0000:ok>n_@;o00001On5SjH3o`00
01ko/Y^A0_l0000IohbIY0;o00004on^RHX3o`0001KokNCk1_l0000]oigSe0Wo0000/oooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o00004?n9^;001Ol0003o
RKR`ohVh/?n9^;3o000000;oRKR`00Co0000ohVh/?n9^;3o00003on9^;03o`0000_obij[9Ol0000D
okfGS0Ko00001?n4RIL3o`0000WoXnNV1_l0000Foi>IV`?o00002onc_[d2o`0000KoQHnV0_l0000<
ok:KT@?o00001?nbVi43o`0000;o/Y^A0ol00003ok:KT@;o00006On<VJ@3o`0001;o[XV:6ol00000
0ooPbKOo0000o`000003o`0002WoWN?D1_l00003oif5[0?o0000/_ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o00004On9^;03o`0000CoRKR`0_l0000?ohVh
/0?o00003Oo;WZ/So`0001So_IN<2Ol0000=oj?WYPKo00004_nCVI/3o`0000co/kjm0_l00006ohF?
YP?o00003?nbVi400ol0003o/Y^Aok:KT@04ok:KT@04o`000?nbVi7o/Y^Ao`0000?o/Y^A00?o0000
ok:KTOnbVi400_l0000JohbIY0;o00004On^RHXKo`0000Coh<Vg1?l0000UoigSe0Ko00001onMQJ`2
o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`00
02WoRKR`0_l0000>ol^NZ`?o00007_o[dNX2o`0001[o_IN<1_l0000@oj?WYPOo00003_nCVI/3o`00
00go/kjm0_l00007ohF?YP?o00002onbVi401?l0003o/Y^Aok:KTOnbVi45o`000003ok:KTOl0003o
/Y^A00;o/Y^A00?o0000ok:KTOnbVi400_l0000JohbIY0;o00004?n^RHX3o`0001Oob;Zh0_l00006
on39]`Co00008?nMhm@7o`0000WoWHF/0_l0002booooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo087ooooo0_l0000XohVh/0?o00003oo;WZ/2o`0001gojm7Z0ol0000MokfG
S0;o00005?nSijH6o`0000_oTiVK0ol0000>ok>n_@;o00002?n5SjH3o`0000[o/Y^A00Go0000ok:K
TOnbVi7o/Y^Ao`000002ok:KT@04o`000?nbVi7o/Y^Aok:KT@?o00000onbVi42o`0001[oS9VT0ol0
000>ojj9RP?o00005oo8^[P3o`0000Ooh<Vg1Ol0000KoigSe0Oo00003?nMQJ`3o`000;7ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool3o`0002KoRKR`0ol0000@
ol^NZ`?o00007?o[dNX2o`0000Ko_IN<00Co0000okfGS?nmUhco_IN<1Ol0000?okfGS0;o00005onS
ijH6o`0000OoTiVK0ol0000?ok>n_@;o00002On5SjH3o`0000Wo/Y^A00?o0000ok:KTOnbVi400_nb
Vi400ol0003o/Y^Ao`000002ok:KT@05o`000?nbVi7o/Y^Aok:KTOl000000_nbVi42o`0001_oS9VT
0_l0000=ojj9RP?o00006?o8^[P2o`0000[oh<Vg1Ol0000GoigSe0Ko00004?nMQJ`2o`000;7ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool2o`0002KoRKR`0_l0
000Bol^NZ`;o00007?o[dNX2o`0000Ko_IN<00?o0000okfGS?nmUh`00_nmUh`01?l0003o_IN<okfG
S?l0000?okfGS0;o00006OnSijH6o`0000CoTiVK0ol0000@ok>n_@;o00002_n5SjH2o`0000So/Y^A
0_l00005ok:KT@;o00000_nbVi401Ol0003o/Y^Aok:KTOnbVi7o000000;o/Y^A0_l0000KohbIY0;o
00003?n^RHX4o`0000?ob;Zh0_l00003olRj^0Go00002oo8^[P2o`0000coh<Vg1Ol0000BoigSe0Ko
00004onMQJ`2o`000;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
P_ooool2o`0002GoRKR`0ol0000Aol^NZ`Co00006oo[dNX2o`0000Oo_IN<00?o0000okfGS?nmUh`0
0_nmUh`00ol0003o_IN<okfGS00?okfGS0;o00007?nSijH9o`00017o/kjm0_l0000:ohF?YP?o0000
2?nbVi400ol0003o/Y^Aok:KT@04ok:KT@04o`000?nbVi7o/Y^Aok:KT@?o00000onbVi4Po`0000Wo
[XV:1Ol00006olRj^005o`000?o8^[Sob;ZholRj^?l000000_o8^[P00ol0003ob;ZholRj^008olRj
^0?o00003_oPbKL5o`0000goWN?D1ol0000Eoif5[0;o0000/Oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`22ooooo`;o00009?n9^;03o`0001;obij[1Ol00003on_AjP?o
00000_o[dNX5o`0000cojm7Z0ol00007okfGS003o`000?nmUhco_IN<00?o_IN<00?o0000okfGS?nm
Uh`03OnmUh`3o`0000?oXnNV0ol00004oj?WYP;o00000_nSijH5o`0000_oXnNV1_l0000Bok>n_@;o
00002on5SjH3o`0001So/Y^A8?l00008ojj9RPCo000000?ob;Zho`000?o8^[P01_o8^[P01Ol0003o
b;ZholRj^?o8^[So000000cob;Zh0_l0000Aon39]`Co00002_nMhm@6o`0001SoWHF/0ol0002`oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000TohVh/0;o
00004_o;WZ/3o`000006ok2XXol0003o0000o`000?o[dN[o00000oo[dNX01?l0003ojm7Zon_Aj_l0
0002on_AjP03o`000?o[dN[ojm7Z00[ojm7Z0_l00009okfGS003o`000?nmUhco000000?o_IN<00?o
0000okfGS?nmUh`02onmUh`4o`0000CoXnNV00?o0000oj?WY_nSijH00_nSijH01?l0003oXnNVoj?W
Y_l00002oj?WYP04o`000?nSijKoXnNVo`0000koXnNV0_l0000Cok>n_@;o00003?n5SjH3o`0001Ko
/Y^A0ol0000Loh^AZ@?o00001_n^RHX3o`0000?ob;Zh00?o0000olRj^?o8^[P00_o8^[P4o`0000Co
b;Zh00?o0000olRj^?o8^[P02Oo8^[P2o`0001?oh<Vg1?l00005oigSe0Ko00007?nMQJ`2o`000;3o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool2o`0002?oRKR`
0ol00004ol^NZ`?o00001?o;WZ/3o`0000Cobij[0_l00003ok2XX`?o00001?o[dNX01Ol0003ojm7Z
on_Aj_o[dN[o000000kojm7Z0_l00005okfGS007o`000?nmUhco_IN<okfGS?l0003o_IN<o`000003
okfGS003o`000?nmUhco_IN<00Wo_IN<1ol00003oj?WYP03o`000?nSijKoXnNV00;oXnNV00Co0000
oj?WY_nSijKo00000onSijH00ol0003oXnNVoj?WYP0>oj?WYP;o00004onc_[d2o`0000goQHnV0_l0
000Fok:KT@;o00007_n;TJT3o`0000Co[XV:0ol00004olRj^005o`000?o8^[Sob;ZholRj^?l00000
0oo8^[P00ol0003ob;Zho`000003olRj^003o`000?o8^[Sob;Zh00Oob;Zh0ol0000Don39]`co0000
7_nMQJ`2o`000;3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_oo
ool3o`00027oRKR`0ol00004ol^NZ`05o`000?o;WZ_obij[ol^NZol000001?o;WZ/00ol0003obij[
ol^NZ`02ol^NZ`?o00001?n`Z:<2o`0000Cojm7Z00?o0000on_Aj_o[dNX00_o[dNX00ol0003ojm7Z
on_AjP0;on_AjP;o00001OnmUh`5o`0000;o_IN<0ol0000;okfGS0Co00000_n[V;T2o`0000?oXnNV
00?o0000oj?WY_nSijH00_nSijH01?l0003oXnNVoj?WY_l00004oj?WYP03o`000?nSijKoXnNV00go
XnNV0_l0000Cok>n_@;o00003On5SjH3o`0001Go/Y^A0_l0000Ooh^AZ@?o00000_n^RHX3o`0000Co
b;Zh0_l00003olRj^007o`000?o8^[Sob;ZholRj^?l0003ob;Zho`000003olRj^003o`000?o8^[So
b;Zh00Oob;Zh0_l0000Gon39]`Oo00008OnMQJ`2o`000;3ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Poooool2o`00023oRKR`0ol00009ol^NZ`03o`000?o;WZ_o0000
00Co00000oo;WZ/2o`0000Go/:RS1_l00002on_AjP05o`000?o[dN[ojm7Zon_Aj_l000002oo[dNX3
o`0001So_IN<1?l00004oj^H^@;o00000onSijH00ol0003oXnNVoj?WYP02oj?WYP06o`000?nSijKo
XnNVo`000?nSijKo00000onSijH00ol0003oXnNVoj?WYP0<oj?WYP;o00004onc_[d2o`0000koQHnV
0ol0000Cok:KT@?o00008?n;TJT6o`0000Kob;Zh00?o0000olRj^?o8^[P00_o8^[P3o`0000?ob;Zh
0ol0000:olRj^0;o00006OoPbKL2o`0002CoWHF/0_l0002`ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08?ooooo0_l0000PohVh/0;o00002?o;WZ/2o`0000;obij[00Co
0000ol^NZoo;WZ_o00000oo;WZ/3o`0000Ko/:RS0ol00004on_AjP05o`000?o[dN[ojm7Zon_Aj_l0
00002oo[dNX2o`0001So_IN<1?l00005oj^H^@?o000000?oXnNVo`000?l000001?nSijH01_l0003o
XnNVoj?WY_l0003oXnNVo`0000?oXnNV00?o0000oj?WY_nSijH03?nSijH2o`0001?o/kjm0_l0000?
ohF?YP?o00004_nbVi42o`0002;oRi6Y1?l0000NolRj^0?o00006OoPbKL2o`0002?oWHF/0ol0002`
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08?ooooo0_l0000OohVh
/0?o00002_o;WZ/01_l0003obij[ol^NZol0003obij[o`0000?obij[0_l00008ok2XX`Go00000_o[
dNX3o`0000cojm7Z0_l0000FokfGS0Co00002?n[V;T2o`0000;oXnNV00?o0000oj?WY_nSijH00onS
ijH2o`0000?oXnNV0ol0000>oj?WYP?o00004onc_[d2o`00013oQHnV0ol0000@ok:KT@?o00008on;
TJT2o`0001oob;Zh0_l0000Jon39]`;o00008onMQJ`2o`000;7ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0Poooool2o`0001koRKR`0ol00007ol^NZ`05o`000?o;WZ_o
bij[ol^NZol000000oo;WZ/2o`0000;obij[0ol00009ok2XX`?o00004_o[dNX2o`0001Go_IN<1?l0
0009oj^H^@;o00007_nSijH2o`0000;o/kjm0ol00002ok>n_@Go00000_nc_[d2o`0000;o/kjm1?l0
0002ohF?YP?o00000on5SjH3o`0000KoQHnV0_l0000@ok:KT@;o00003on;TJT3o`0000?oRi6Y0ol0
0003oh^AZ@;o00001on;TJT2o`0001oob;Zh0_l0000Ion39]`?o00008onMQJ`2o`000;7ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Poooool2o`0001koRKR`0_l00009
ol^NZ`?o00001Oo;WZ/00ol0003obij[ol^NZ`02o`0000_o/:RS0_l0000Aon_AjP?o00004onmUh`4
o`0000_oZiRi0ol0000Moj?WYP;o00000onc_[d00ol0003o/kjmok>n_@02ok>n_@04o`000?nc_[go
/kjmo`0000Co/kjm00?o0000ok>n_Onc_[d00ol000000on5SjKo0000ohF?YP02ohF?YP03o`000?n5
SjKo000000?oQHnV00?o0000ohF?Y_n5SjH00on5SjH3o`0000oo/Y^A0_l0000@oh^AZ@05o`000?n;
TJWoRi6Yoh^AZOl000000on;TJT00ol0003oRi6Yoh^AZ@02oh^AZ@03o`000?n;TJWoRi6Y00CoRi6Y
0_l0000NolRj^0?o00006OoPbKL2o`0002CoWHF/0_l0002aooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08?ooooo0ol0000LohVh/0?o00004oo;WZ/3o`0000_o/:RS0ol0
000@on_AjP;o00004onmUh`4o`0000goZiRi0_l0000Moj?WYP;o00000onc_[d00ol0003o/kjmok>n
_@03ok>n_@03o`000?nc_[go/kjm00Go/kjm00?o0000ok>n_Ol000000_l00005ohF?YP03o`000?n5
SjKoQHnV00?oQHnV00?o0000ohF?Y_n5SjH01?n5SjH3o`0000go/Y^A0ol0000@oh^AZ@05o`000?n;
TJWoRi6Yoh^AZOl000000on;TJT00ol0003oRi6Yoh^AZ@03oh^AZ@03o`000?n;TJWoRi6Y00?oRi6Y
8_l0000Jon39]`;o00009?nMQJ`2o`000;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Q?ooool2o`0001_oRKR`0ol0000Dol^NZ`;o00003On`Z:<3o`0000oojm7Z0_l0
000BokfGS0?o00003on[V;T2o`0001coXnNV0ol00003ok>n_@03o`000?nc_[go/kjm00Co/kjm00Co
0000ok>n_Onc_[go/kjm1?l000001?nc_[go0000o`000?l00003ohF?YP;o00001?n5SjH2o`0000So
QHnV0ol0000<ok:KT@;o00004On;TJT01?l0003oRi6Yoh^AZOn;TJT4o`0000?oRi6Y1?l00005oh^A
ZB;o00006_oPbKL2o`0002?oWHF/0ol0002aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo08Cooooo1Ol0000HohVh/0;o00005?o;WZ/3o`0000ko/:RS0ol0000>on_AjP;o
00004?nmUh`4o`00013oZiRi0ol0000Hoj?WYPKo00000onc_[d01Ol0003o/kjmok>n_Onc_[go0000
00?o/kjm00?o0000ok>n_Ol000000onc_[d00ol0003o/kjmo`000002o`0000GoQHnV00?o0000ohF?
Y_n5SjH00on5SjH00ol0003oQHnVohF?YP06ohF?YPWo00001OnbVi42o`00017oRi6Y00Go0000oh^A
ZOn;TJWoRi6Yo`000005oh^AZ@05o`000?n;TJWoRi6Yoh^AZOl000001?n;TJT3o`0001kofJFf0_l0
000Jon39]`;o00008onMQJ`2o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0Poooool;o`0001;oRKR`0ol0000Dol^NZ`;o00004?n`Z:<2o`0000gojm7Z0ol0000?
okfGS0Co00004_n[V;T2o`0001KoXnNV2Ol000000onc_[go0000o`000003ok>n_@07o`000?nc_[go
/kjmok>n_Ol0003o/kjmo`000003ok>n_@Go000000?oQHnVo`000?n5SjH00_n5SjH00ol0003oQHnV
o`000003ohF?YP03o`000?n5SjKoQHnV00GoQHnV4Ol0000@oh^AZ@;o00001?n;TJT00ol0003oRi6Y
oh^AZ@02oh^AZ@05o`000?n;TJWoRi6Yoh^AZOl000000on;TJT3o`0000CofJFf0ol00003omVU]P;o
00001?oIYKH3o`0000cofJFf0_l00002on39]`Go00000ooPbKL2o`0000?oh<Vg0ol00008on39]`;o
00008onMQJ`2o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
P_ooool3o`0000?oe<G02ol0000<ohVh/0?o00005?o;WZ/3o`00013o/:RS0ol0000:on_AjPGo0000
3OnmUh`4o`0001CoZiRi0_l0000Coj?WYPKo00001?o0P:H3o`000003ok>n_Ol0003o/kjm00?o/kjm
0ol00003ok>n_@?o00000_nc_[d3o`0000;oQHnV0ol00003ohF?YP?o00001on5SjH3o`0000OoaK2^
1ol0000Boh^AZ@03o`000?n;TJWoRi6Y00?oRi6Y0_l00003oh^AZ@?o00000on;TJT5o`0000CofJFf
00?o0000omVU]_oIYKH01?oIYKH01?l0003ofJFfomVU]_l00003omVU]P03o`000?oIYKKofJFf00Wo
fJFf0_l00003on39]`04o`000?oPbKOoh<Vgo`0000;oh<Vg00Ko0000on39]ooPbKOo0000on39]ol0
0003on39]`03o`000?oPbKOoh<Vg00Coh<Vg0ol0000Soif5[0;o0000/_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`;o00002OoDaL0;o`0000OoRKR`0_l0000D
ol^NZ`?o00004_n`Z:<3o`0000Gojm7Z2_l0000;okfGS0Co00005On[V;T3o`00013oXnNV1_l00007
ol20YP;o00004_nc_[d2o`00017oQHnV0ol0000=olF`[P?o00008?n;TJT4o`000004omNObOl0003o
0000o`0000?ofJFf00?o0000omVU]_oIYKH01OoIYKH00ol0003ofJFfomVU]P03omVU]P03o`000?oI
YKKofJFf00WofJFf0_l00004on39]`03o`000?oPbKOoh<Vg00;oh<Vg00Ko0000on39]ooPbKOo0000
on39]ol00003on39]`03o`000?oPbKOoh<Vg00Coh<Vg0_l0000Toif5[0;o0000/_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`;o00003_oDaL0;o`000004ohVh
/?l0003o0000o`0001Cobij[0_l0000Dok2XX`?o000000?ojm7Zo`000?l000001_l00003oicK^P?o
00002?nmUh`4o`0001SoZiRi0_l0000=oj?WYPKo00002_o0P:H3o`00017o/kjm0_l0000?ohF?YPCo
00003oo5/:h3o`0001koRi6Y1?l00003omNOb@?o00000_oIYKH00ol0003ofJFfomVU]P02omVU]PCo
00000ooIYKH2o`0000cofJFf0_l00005on39]`05o`000?oPbKOoh<Vgon39]ol000000_oPbKL00ol0
003oh<Vgo`000003o`0000Ooh<Vg0_l0000Soif5[0?o0000/_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`22ooooo`;o00004ooDaL09o`0001Cobij[0ol0000Eok2XX`Oo
00002?nLfkX4o`0000Go_IN<1?l0000Ioj^H^@;o00002onSijH6o`0000go`82V0ol0000@ok>n_@;o
00003_n5SjH4o`00017oaK2^0ol0000Koh^AZ@Co00001_oGWlT3o`000003omVU]_l0003ofJFf00;o
fJFf00Go0000omVU]_oIYKKofJFfo`000005omVU]P03o`000?oIYKKofJFf00WofJFf0_l00002on39
]`05o`000?oPbKOoh<Vgon39]ol000000_oPbKL01_l0003oh<Vgon39]ol0003oh<Vgo`0000[oh<Vg
0_l0000>oif5[0Go000000?oWHF/o`000?l000000ol00002oif5[0?o00001OnMQJ`2o`000;?ooooo
00?o0000ooooooooool02?ooool001[ooooo0ol00022ooooo`;o00006?oDaL03o`0001Gobij[0_l0
000Gok2XX`?o00003?nLfkX4o`0000;o_IN<1?l0000Koj^H^@?o00002?nSijH5o`00017o`82V0_l0
000@ok>n_@;o00003On5SjH3o`0001CoaK2^0_l0000Joh^AZ@Co00002?oGWlT4o`0000?ofJFf00Oo
0000omVU]_oIYKKofJFfo`000?oIYKKo000000?ofJFf00?o0000omVU]_oIYKH02OoIYKH2o`0000;o
h<Vg00Go0000on39]ooPbKOoh<Vgo`000002on39]`04o`000?oPbKOoh<Vgo`0000;oh<Vg00?o0000
on39]ooPbKL01ooPbKL2o`0000ooWHF/00Co0000oif5[?nMQJco00000_nMQJ`01?l0003oWHF/oif5
[?l00003oif5[003o`000?nMQJcoWHF/00CoWHF/0_l0002aooooo`?o00002_ooool001[ooooo00?o
0000ooooooooool0P_ooool2o`0001Woe<G00ol0000Col^NZ`?o00000_n`Z:<3o`0000;o/:RS0ol0
000<ok2XX`?o00003onLfkX7o`0001goZiRi0_l00005oj?WYPKo00004oo0P:H3o`0000oo/kjm0_l0
000;ohF?YPCo00005Oo5/:h3o`0001SoRi6Y0ol0000;omNOb@?o00001?oIYKH3o`0000?ofJFf0ol0
000<omVU]P;o00000ooPbKL3o`0000Coh<Vg0_l00004on39]`;o00001ooPbKL2o`00013oWHF/00?o
0000oif5[?nMQJ`00onMQJ`00ol0003oWHF/oif5[003oif5[003o`000?nMQJcoWHF/00CoWHF/0_l0
002cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000J
omC5`0?o00004_o;WZ/2o`0000Co/:RS00?o0000ok2XXon`Z:<00_n`Z:<00ol0003o/:RSok2XX`0:
ok2XX`?o00004OnLfkX4o`0001ooZiRi0_l00003oj?WYPKo00005_o0P:H3o`0000ko/kjm0_l0000:
ohF?YPCo00005oo5/:h8o`00013oRi6Y1?l0000=omNOb@?o00006?oIYKH2o`0001Soh<Vg0ol0000A
oif5[003o`000?nMQJcoWHF/00?oWHF/00?o0000oif5[?nMQJ`00_nMQJ`00ol0003oWHF/oif5[004
oif5[0;o0000/oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22oooo
o`;o00006ooDaL03o`00013obij[0ol000000on`Z:?o0000o`000003o`0000?o/:RS00?o0000ok2X
Xon`Z:<02On`Z:<3o`0001?oW=^j0_l0000Poj^H^@So00006_o0P:H2o`0000ko/kjm0_l00009ohF?
YP?o00006_o5/:hBo`0000CoRi6Y1?l0000?omNOb@?o00005ooIYKH2o`0001Soh<Vg0_l0000?oif5
[007o`000?nMQJcoWHF/oif5[?l0003oWHF/o`000003oif5[005o`000?nMQJcoWHF/oif5[?l00000
1OnMQJ`3o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_oo
ool2o`0001coe<G00ol0000?ol^NZ`;o00000_n`Z:<01?l0003o/:RSok2XXol00004ok2XX`03o`00
0?n`Z:?o/:RS00Wo/:RS0_l0000DoicK^P?o00008?n[V;T5o`0001co`82V0ol0000=ok>n_@;o0000
2?n5SjH3o`0001_oaK2^0_l00004omO2ia;o00004_oGWlT3o`0001KofJFf0_l0000Gon39]`Co0000
3_nMQJ`01ol0003oWHF/oif5[?nMQJco0000oif5[?l000000onMQJ`00ol0003oWHF/oif5[002o`00
00GoWHF/0_l0002dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087o
oooo0ol0000MomC5`0?o00003Oo;WZ/3o`0000?o/:RS00?o0000ok2XXol000001?n`Z:<00ol0003o
/:RSok2XX`08ok2XX`?o00005OnLfkX2o`0000_oZiRi0ol00004oj^H^@;o00003?n[V;T2o`00023o
`82V0ol0000<ok>n_@;o00001_n5SjH4o`0001_oaK2^0ol0000?omO2i`Ko00005?oGWlT3o`0001Go
fJFf0_l0000Fon39]`Oo00003OnMQJ`3o`0000?oWHF/0ol00004oif5[003o`000?nMQJcoWHF/00?o
WHF/0_l0002dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo
0_l0000OomC5`0?o00003?o;WZ/2o`0000Go/:RS0_l00003ok2XX`;o00002On`Z:<3o`0001KoW=^j
0ol00009oj^H^@05o`000?n[V;WoZiRioj^H^Ol000000_n[V;T01?l0003oZiRioj^H^Ol0000;oj^H
^@;o00008Oo0P:H2o`0000co/kjm0_l00005ohF?YPCo00007?o5/:h2o`0001Coel;W0_l0000EomNO
b@?o00005?oIYKH2o`0001Coh<Vg1?l00002oinBKPCo00007onMQJ`2o`000;Cooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`00023oe<G00ol0000:ol^NZ`?o
00001_n`Z:<00ol0003o/:RSok2XX`02ok2XX`03o`000?n`Z:?o/:RS00Ko/:RS0ol0000HoicK^P?o
00002?n[V;T01Ol0003oZiRioj^H^On[V;Wo000000;oZiRi00Co0000oj^H^On[V;Wo00002on[V;T2
o`0000Go`82V0ol00003ol20YP?o00001?o0P:H2o`0000go`82V0ol0000;ok>n_@;o00001?n5SjH3
o`0001koaK2^0_l0000DomO2i`;o00005_oGWlTHo`0001?oh<Vg1?l00005oinBKPCo00007OnMQJ`2
o`000;Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`00
027oe<G00ol00009ol^NZ`;o00005On`Z:<2o`0001[oW=^j0_l00009oj^H^@?o00000on[V;T01?l0
003oZiRioj^H^Ol0000:oj^H^@?o00001_o0P:H00ol0003o`82Vol20YP03ol20YP03o`000?o0P:Ko
`82V00;o`82V00Co0000ol20Y_o0P:Ko00003Oo0P:H4o`0000Wo/kjm0_l00002ohF?YPCo00000_o5
/:h3o`0000CoaK2^0ol00003olF`[P?o00003?o5/:h3o`0001Coel;W0ol0000FomNObAOo00004OoP
bKL4o`0000SoWi9^1Ol0000Joif5[0?o0000]?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`21ooooo`;o00008_oDaL03o`0000Oobij[0ol0000Dok2XX`?o00006_nLfkX3
o`0000OoZiRi00Go0000oj^H^On[V;WoZiRio`000002oj^H^@04o`000?n[V;WoZiRio`0000OoZiRi
1_l00006ol20YP03o`000?o0P:Ko`82V00?o`82V00?o0000ol20Y_o0P:H00_o0P:H01?l0003o`82V
ol20Y_l0000;ol20YPSo00001onc_[d2o`000003ohF?Y_l0003o000000;o00001?o5/:h00ol0003o
aK2^olF`[P04olF`[P03o`000?o5/:koaK2^00?oaK2^00?o0000olF`[_o5/:h02oo5/:h2o`0001Ko
el;W0_l0000FomNOb@;o00004on_ZM03o`0000ooh<Vg1?l0000;oinBKPCo00006OnMQJ`2o`000;Go
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002?oe<G0
0ol00006ol^NZ`;o00005?n`Z:<3o`0001coW=^j0_l00007oj^H^@05o`000?n[V;WoZiRioj^H^Ol0
00000_n[V;T01?l0003oZiRioj^H^Ol00005oj^H^@Wo00001Oo0P:H00ol0003o`82Vol20YP03ol20
YP03o`000?o0P:Ko`82V00;o`82V00Co0000ol20Y_o0P:Ko00002Oo0P:H5o`0000;oW[f>1_l00004
ok>n_@Go00001_o5/:h01?l0003oaK2^olF`[_o5/:h5o`000003olF`[_l0003o000000?o00003?o5
/:h2o`0001Koel;W0_l0000EomNOb@?o00005?n_ZM03o`0000coh<Vg1?l0000?oinBKPCo00005onM
QJ`2o`000;Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2
o`0002Coe<G02ol0000Bok2XX`?o00007OnLfkX3o`0000OoZiRi0ol00004oj^H^@;o00001?n[V;T5
o`0000CoaMfa0ol00004ol20YP03o`000?o0P:Ko`82V00?o`82V00?o0000ol20Y_o0P:H00_o0P:H0
1?l0003o`82Vol20Y_l00007ol20YPGo00001_nN_Hh6o`0000;o/kjm1?l00007olF`[P05o`000?o5
/:koaK2^olF`[_l000000_o5/:h01?l0003oaK2^olF`[_l00002olF`[P03o`000?o5/:koaK2^00_o
aK2^0_l0000FomO2i`;o00005OoGWlT2o`0001Ko[jW@0ol0000:on39]`Co00004OnOTVh5o`0001Go
WHF/0_l0002eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo
0_l0000UomC5`0oo00003On`Z:<2o`0000koW=^j0ol00004oicK^P;o00002?nLfkX2o`00017oZiRi
1_l00007olGM/@?o00000_o0P:H2o`0000Co`82V0_l00004ol20YP04o`000?o0P:Ko`82Vo`0000Go
`82V1Ol0000;oijmSPSo00002?o5/:h00ol0003oaK2^olF`[P02olF`[P03o`000?o5/:ko000000?o
aK2^00?o0000olF`[_l000003?o5/:h3o`0001Koel;W0_l0000EomNOb@;o00005on_ZM05o`0000Go
h<Vg1?l0000EoinBKPGo00004onMQJ`2o`000;Gooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0POooool2o`0002Coe<G00ol00007ogR6X`_o00001on`Z:<3o`0000goW=^j
00Go0000oicK^_nLfk[oW=^jo`000002oicK^P04o`000?nLfk[oW=^jo`0000OoW=^j0ol0000>oj^H
^@Ko00002_o5gK42o`0000?o`82V00?o0000ol20Y_o0P:H00oo0P:H00ol0003o`82Vol20YP03ol20
YP;o00001?o0P:H5o`0000ooW[f>1Ol00008olF`[P;o00001Oo5/:h2o`0000CoaK2^0_l0000<olF`
[P;o00005ooG`^L2o`0001Goeio90_l0000HojnYd0Oo000000?oh<Vgo`000?l000000_l0000HoinB
KPCo00004OnMQJ`3o`000;Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0POooool2o`0002Coe<G00_l0000=ogR6X`_o000000Co/:RSo`000?l0003o00003_nLfkX01Ol0
003oW=^joicK^_nLfk[o000000;oW=^j00Co0000oicK^_nLfk[o00002?nLfkX2o`0000_oZiRi1_l0
000=olGM/@?o00004_o0P:H5o`0001?oW[f>0_l0000:olF`[P03o`000?o5/:koaK2^00CoaK2^00?o
0000olF`[_o5/:h00oo5/:h00ol0003oaK2^olF`[P0:olF`[P;o00005ooG`^L3o`0001Coeio90_l0
000GojnYd0?o000000?oPJRmo`000?l000001Ol0000LoinBKPCo00003onMQJ`2o`000;Kooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002Coe<G00_l0000B
ogR6X`Wo00003onLfkX4o`0000?oW=^j00Co0000oicK^_nLfk[o00002?nLfkX3o`0000SoZiRi1_l0
000@olGM/@?o00004?o0P:H4o`0001GoW[f>0_l0000SolF`[P?o00006?oG`^L2o`0000?oeio90ol0
0004omNOb@03o`000?oGWlWoeio900?oeio900?o0000omNObOoGWlT00ol0000FojnYd0?o00001On1
Z;d3o`0001koWi9^1Ol0000=oif5[0;o0000]_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`21ooooo`;o00008ooDaL03o`0001OoN8JS0ol0000@oicK^P03o`000?nLfk[o
W=^j00CoW=^j00Co0000oicK^_nLfk[o00002OnLfkX3o`0000GoZiRi1Ol0000DolGM/@;o00003_o0
P:H4o`0001OoW[f>0ol0000RolF`[P;o00006OoG`^L2o`0000Coeio900?o0000omNObOoGWlT00ooG
WlT00ol0003oeio9omNOb@03omNOb@03o`000?oGWlWoeio900;o00005_n_ZM03o`0000OoPJRm0ol0
000OoinBKPCo00002onMQJ`3o`000;Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0POooool2o`0002?oe<G00_l0000IogR6X`?o00004?nLfkX00ol0003oW=^joicK^P03
oicK^P04o`000?nLfk[oW=^jo`0000[oW=^j0_l00002oj^H^@Ko00005_o5gK43o`0000_o`82V1Ol0
000IoijmSP;o00008_o5/:h2o`0001Woel;W0_l00004omNOb@03o`000?oGWlWoeio900Coeio900?o
0000omNObOoGWlT00ooGWlT01?l0003oeio9o`000?l0000FojnYd0;o00002On1Z;d2o`00027oWi9^
1?l00008oif5[0?o0000]oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`21ooooo`;o00008ooDaL02o`0001[oN8JS0_l0000AoicK^P;o00001?nLfkX2o`0000_oW=^j2?l0
000IolGM/@?o00002?o0P:H5o`0001_oW[f>0_l0000RolF`[P;o00006OoG`^L2o`0000Coeio900?o
0000omNObOoGWlT01?oGWlT00ol0003oeio9omNOb@03omNOb@04o`000?oGWlWo0000o`0001Go[jW@
0ol00009oh6X_@?o00008OnOTVh5o`0000GoWHF/0ol0002hooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo087ooooo0_l0000;omC5`0?o00000ooDaL03o`0000koe<G00ol0
000JogR6X`?o00009?nLfkX5o`0001coaMfa0ol00005ol20YPGo00007OnN_Hh3o`00023oaK2^0ol0
000IomO2i`?o00000ooGWlT00ol0003oeio9omNOb@05omNOb@03o`000?oGWlWoeio900?oeio90ol0
000DojnYd0?o00002on1Z;d2o`0002?oWi9^1?l00003oif5[0?o0000^Oooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o00003?oDaL001Ol0003oe<G0omC5`?oD
aL3o000000?oe<G000?o0000omC5`?oDaL002ooDaL02o`0001coN8JS0_l0000SoicK^P?o000000Co
Rjg2o`000?l0003o00007?o5gK42o`0000?o`82V1Ol0000PoijmSP;o00008?o5/:h2o`0001_oel;W
0_l00002omNOb@;o00000ooGWlT01ol0003oeio9omNObOoGWlWo0000omNObOl000000ooGWlT3o`00
00;o[jW@0ol00003ojnYd0;o00001On_ZM03o`000004ojnYd?l0003o0000o`0000coPJRm0ol0000T
oinBKPOo0000^_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20oooo
o`?o00003?oDaL000ol0003oe<G0omC5`005omC5`003o`000?oDaL3oe<G000_oe<G00_l0000LogR6
X`;o00008_nLfkX3o`0000?oRjg20ol0000KolGM/@So00008_nN_Hh2o`00023oaK2^0_l0000KomO2
i`;o00000ooGWlT01?l0003oeio9omNObOoGWlT5o`000003omNObOl0003o000000Co00001?n_ZM00
0ol0003o[jW@ojnYd004ojnYd003o`000?n_ZM3o[jW@00?o[jW@00?o0000ojnYd?n_ZM000_l0000>
oh6X_@;o00002onOTVh5o`0000;oWi9^0ol00004oinBKP03o`000?nOTVkoWi9^00WoWi9^1Ol0002k
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000=omC5
`003o`000?oDaL3oe<G000Goe<G000?o0000omC5`?oDaL002_oDaL03o`0001coN8JS0ol0000QoicK
^P;o00001On;[L83o`0001_oaMfa1Ol0000ToijmSP;o00007oo5/:h3o`0000Woel;W0ol00003omO2
i`?o00000ooG`^L3o`0000?oel;W0_l0000AomNOb@;o00001?n_ZM000ol0003o[jW@ojnYd005ojnY
d003o`000?n_ZM3o000000Oo00003_n1Z;d3o`0000_oWi9^00Co0000oinBK_nOTVko00000onOTVh0
0ol0003oWi9^oinBKP03oinBKP03o`000?nOTVkoWi9^00_oWi9^0_l0002looooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000=omC5`004o`000?oDaL3oe<G0
omC5`0Co00003OoDaL02o`0001koN8JS0_l0000PoicK^P?o00001_n;[L83o`0001_oaMfa0_l0000V
oijmSP?o00006_o5/:h6o`0000_oel;W00Go0000omO2iooG`^Ooel;Wo`000003omO2i`03o`000?oG
`^Oo000000?oel;W00?o0000omO2iooG`^L00_l0000AomNOb@;o00001?n_ZM000ol0003o[jW@ojnY
d002ojnYd0Co000000Co[jW@o`000?n_ZM3o[jW@1?l0000@oh6X_@;o00003?nOTVh00ol0003oWi9^
oinBKP03oinBKP03o`000?nOTVkoWi9^00CoWi9^00?o0000oinBK_nOTVh02OnOTVh3o`000;cooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool2o`0000coe<G00_l0
0003omC5`003o`000?oDaL3oe<G000koe<G00_l00008ogR6X`?o00000omhQZ<3o`0000goN8JS0ol0
000NoicK^P?o00002?n;[L83o`0001[oaMfa0_l0000WoijmSP;o00004_o5/:h>o`0000_oel;W00Go
0000omO2iooG`^Ooel;Wo`000003omO2i`03o`000?oG`^Ooel;W00?oel;W00?o0000omO2iooG`^L0
0_l0000AomNOb@;o00001?n_ZM001Ol0003o[jW@ojnYd?n_ZM3o000000?o[jW@00Go0000ojnYd?n_
ZM3o0000ojnYd003o`00017oPJRm0_l0000=oinBKP03o`000?nOTVkoWi9^00;oWi9^00?o0000oinB
K_nOTVh01?nOTVh00ol0003oWi9^oinBKP09oinBKP;o0000_Oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`20ooooo`;o00003OoDaL001?l0003oe<G0omC5`?oDaL05o`00
00_oe<G00ol00007ogR6X`07o`000?mhQZ?oN8JSogR6Xol0003oN8JSo`000003ogR6X`03o`000?mh
QZ?oN8JS00_oN8JS0_l0000NoicK^P;o00002_n;[L83o`0001WoaMfa0_l0000<oijmSP?o00000onN
_Hh3o`0000;oW[f>1Ol0000;oijmSP;o00002oo5/:h@o`0000?oWYnA0ol0000:omO2i`04o`000?oG
`^Ooel;WomO2i`Co00001_oG`^L00ol0003oel;WomO2i`03o`0000ooeio90ol00003ojnYd0;o0000
0on_ZM001Ol0003o[jW@ojnYd?n_ZM3o000000?o[jW@0ol0000Boh6X_@?o00002OnOTVh01Ol0003o
Wi9^oinBK_nOTVko000000?oWi9^00?o0000oinBK_nOTVh01OnOTVh00ol0003oWi9^oinBKP07oinB
KP?o0000_Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o
00008OoDaL02o`0000coN8JS00?o0000ogR6XomhQZ<00omhQZ<00ol0003oN8JSogR6X`0;ogR6X`?o
00007?nLfkX3o`0000_oRjg20ol0000HolGM/@;o00003OnN_Hh00ol0003oW[f>oijmSP03oijmSP03
o`000?nN_HkoW[f>00;oW[f>00Co0000oijmS_nN_Hko00002onN_Hh3o`0000;oaK2^4?l0000<oijO
T@?o00002OoG`^L01Ol0003oel;WomO2iooG`^Oo000000Goel;W1?l00004omO2i`;o00003ooGWlT2
o`0000Go[jW@00?o0000ojnYd?n_ZM000_n_ZM03o`0000Co[jW@0_l0000Doh6X_@;o00002OnOTVh0
1Ol0003oWi9^oinBK_nOTVko000000;oWi9^0_l00003oinBKP05o`000?nOTVkoWi9^oinBK_l00000
2OnOTVh2o`000;kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?oo
ool2o`00027oe<G00_l0000:ogR6X`;o00001_mhQZ<00ol0003oN8JSogR6X`0<ogR6X`;o00007?nL
fkX2o`0000goRjg20ol0000GolGM/@?o00003?nN_Hh00ol0003oW[f>oijmSP03oijmSP03o`000?nN
_HkoW[f>00?oW[f>00?o0000oijmS_nN_Hh03?nN_Hh=o`0001CoWYnA0ol00007omO2i`;o00001?oG
`^L00ol0003oel;WomO2i`02omO2i`03o`000?oG`^Ooel;W00Goel;W0_l0000?omNOb@;o00004?n_
ZM08o`0000?oPJRm0_l00004oh6X_@?o00000on1Z;d3o`0000WoWi9^0ol00004oinBKP04o`000?nO
TVkoWi9^oinBKPGo00002OnOTVh2o`000;kooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0P?ooool2o`00023oe<G00ol0000<ogR6X`03o`000?mhQZ?o000000?o00003omh
QZ<2o`0001_oW=^j0ol0000>oh^]`P?o00002oo5gK43o`0000?oaMfa0ol00003olGM/@;o00003?nN
_Hh00ol0003oW[f>oijmSP03oijmSP03o`000?nN_HkoW[f>00CoW[f>00?o0000oijmS_nN_Hh02onN
_Hh5o`0001goWYnA0ol00007omO2i`03o`000?oG`^Ooel;W00?oel;W0_l00002omO2i`Go00000ooG
`^L2o`0000ooeio90_l0000?ojnYd0?o00000_n1Z;d01?l0003oPJRmoh6X_Ol00002oh6X_@04o`00
0?n1Z;goPJRmo`0000CoPJRm00?o0000oh6X_On1Z;d00on1Z;d2o`00027oWi9^0ol0002nooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000PomC5`0;o0000
2OmhQZ<01ol0003oN8JSogR6XomhQZ?o0000ogR6Xol000004_mhQZ<7o`0001GoW=^j0ol0000@oh^]
`P?o00002Oo5gK401ol0003oaMfaolGM/Oo5gK7o0000olGM/Ol000000oo5gK400ol0003oaMfaolGM
/@02o`0000coW[f>00?o0000oijmS_nN_Hh00onN_Hh01Ol0003oW[f>oijmS_nN_Hko000000?oW[f>
00?o0000oijmS_nN_Hh02OnN_Hh3o`00027oWYnA0_l0000IomO2i`;o00003ooGWlT2o`0000ko[jW@
0ol00004oh6X_@03o`000?n1Z;goPJRm00;oPJRm00Go0000oh6X_On1Z;go0000oh6X_@05o`0000Co
PJRm0ol0000PoinBKP;o0000_oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`20ooooo`?o00007ooDaL02o`0000[oN8JS0ol00002ogR6X`Go00003omhQZ<?o`0000coW=^j
0_l0000Boh^]`P?o00002?o5gK401ol0003oaMfaolGM/Oo5gK7o0000olGM/Ol000000oo5gK400ol0
003oaMfaolGM/@02o`0000_oW[f>0_l00004oijmSP;o00000onN_Hh01Ol0003oW[f>oijmS_nN_Hko
000000_oW[f>0_l0000RoijOT@?o00006?oG`^L2o`0000koeio90ol0000>ojnYd0;o00001_n1Z;d0
1Ol0003oPJRmoh6X_On1Z;go000000;oPJRm00?o0000oh6X_Ol000000_n1Z;d00ol0003oPJRmoh6X
_@04oh6X_@;o00007onOTVh3o`000;oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0POooool3o`0001goe<G00ol0000RogR6X`?o00000onb[9LBo`0000?oW=^j0ol0000:
oh^]`P?o00000on;[L86o`0000SoaMfa0ol00003olGM/@?o00000oo5gK42o`0000coW[f>00?o0000
oijmS_nN_Hh00onN_Hh00ol0003oW[f>oijmSP02oijmSP?o00003?nN_Hh2o`0002?oWYnA0ol0000G
omO2i`?o00003OoGWlT2o`0000ko[jW@0ol00003oh6X_@05o`000?n1Z;goPJRmoh6X_Ol000000_n1
Z;d01?l0003oPJRmoh6X_Ol00002oh6X_@03o`000?n1Z;go000000KoPJRm1ol0000JoinBKP;o0000
`?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`?o00007?oD
aL02o`0002?oN8JS0_l0000=ok:/U`ko00002_n;[L801ol0003oRjg2oh^]`_n;[L;o0000oh^]`_l0
00000on;[L84o`0000KoaMfa00Oo0000olGM/Oo5gK7oaMfao`000?o5gK7o000000?oaMfa00?o0000
olGM/Oo5gK400_l0000UoijmSP?o00009?nNWi43o`0001Ooel;W0_l00006omNOb@[o00003?n_ZM03
o`0000CoPJRm00Go0000oh6X_On1Z;goPJRmo`000002oh6X_@04o`000?n1Z;goPJRmo`0000?oPJRm
0_l00007oh6X_@go00004_nOTVh3o`000<3ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0
0023ooooo`?o00006ooDaL02o`0002;oN8JS0ol0000Eok:/U`Go00002on;[L801Ol0003oRjg2oh^]
`_n;[L;o000000GoRjg200?o0000oh^]`_l000000_l00005olGM/@07o`000?o5gK7oaMfaolGM/Ol0
003oaMfao`000003olGM/@03o`000?o5gK7oaMfa00;o00009OnN_Hh2o`0002KoWYnA1ol0000BomO2
iaCo00002On_ZM03o`0000KoPJRm0ol00004oh6X_@;o00001On1Z;d00ol0003oPJRmoh6X_@04oh6X
_@?o00000onbY[<@o`0000[oWi9^0_l0002oooooo`?o00002_ooool001[ooooo00?o0000oooooooo
ool0Q?ooool2o`0001Woe<G01?l0000RogR6X`;o00006Onb[9L4o`0000[oRjg20ol00006oh^]`P03
o`000?n;[L;oRjg200?o00001Oo5gK43o`0000?oaMfa0ol00003olGM/@;o00009OnN_Hh2o`0000Wo
WYnA0ol00004oijOT@?o00000_nNWi42o`00013oWYnA3Ol0000:omO2i`[o00002?oNgl<6o`0000Ko
[jW@0_l0000Koh6X_@?o00002onbY[<@o`0000?oWi9^0_l00031ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08Cooooo0ol0000GomC5`0So00007_mhQZ<3o`0001[o/ZbG
1_l00006oh^]`P06o`000?n;[L;oRjg2oh^]`_l0003oRjg21?l00004oh^]`P?o00004?o5gK42o`00
02CoW[f>0ol0000:oijOT@03o`000?nNWi7oWYnA00CoWYnA00?o0000oijOTOnNWi400onNWi400ol0
003oWYnAoijOT@0<oijOT@?o00000onc^jh?o`0000;oel;W0ol0000BomkO``Ko00000on_ZM03o`00
01_oPJRm0_l0000Dok:V/`go0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`25ooooo`?o00005?oDaL04o`0000;o^L^j1_l0000LogR6X`;o00006onb[9L9o`0000?o
Rjg200Oo0000oh^]`_n;[L;oRjg2o`000?n;[L;o000000SoRjg20ol0000?olGM/@?o00007_nN_Hh7
o`0000_oWYnA00Co0000oijOTOnNWi7oWYnA1Ol00005oijOT@03o`000?nNWi7oWYnA00_oWYnA0_l0
000;ok>k[Pco00005_oNgl<8o`0001_oPJRm0ol0000Kok:V/`Go0000`_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`26ooooo`?o00004_oDaL04o`0000Ko^L^j1_l0000H
ogR6X`?o00006onb[9L2o`0000?oVWR21ol000001?n;[L;o0000o`000?l00002oh^]`PGo00001On;
[L83o`0000ooaMfa0_l0000EoijmSQ3o00002onNWi401Ol0003oWYnAoijOTOnNWi7o000000;oWYnA
00Co0000oijOTOnNWi7oWYnA1?l0000<oijOT@?o00004_nc^jh4o`0001Wog]o31Ol0000Koh6X_@?o
00007onbY[<2o`000<;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
Qoooool3o`0000ooe<G01?l0000:okW;^PKo00005OmhQZ<3o`0001co/ZbG0_l00006oiYhPPOo0000
3_n;[L83o`0000koaMfa0_l0000<oijmSQ?o00001?nPTiL3o`0000[oWYnA00?o0000oijOTOnNWi40
0_nNWi400ol0003oWYnAo`000002oijOT@05o`000?nNWi7oWYnAoijOTOl000003?nNWi42o`0001Go
/k^^0_l0000KomkO``;o00007?n1Z;d2o`00023o/ZJc0_l00032ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08Sooooo0ol0000=omC5`0Co00003_nibkX6o`0001;oN8JS
0_l0000Mok:/U`;o00002OnJN887o`0000coRjg20ol0000=olGM/@;o00000onN_HhCo`0000koX9>G
0_l00009oijOT@;o00001OnNWi42o`0000;oWYnA00Go0000oijOTOnNWi7oWYnAo`00000;oijOT@?o
00005Onc^jh2o`0001_og]o30ol0000Joh6X_@?o00008?nbY[<2o`000<;ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0ROooool2o`0000_oe<G01?l0000BokW;^PKo0000
3omhQZ<3o`0001go/ZbG0_l0000<oiYhPPOo00002_n;[L83o`0000[oaMfa4Ol0000Goj2CU`;o0000
2_nNWi400ol0003oWYnAoijOT@04oijOT@04o`000?nNWi7oWYnAoijOT@?o00002onNWi43o`0001Ko
/k^^0_l0000LomkO``?o00006?n1Z;d3o`00027o/ZJc0ol00031ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08Wooooo0ol00009omC5`0Co00005_nibkX6o`0000coN8JS
0_l0000=ok:/U`?o00001?nb[9L00ol0003o/ZbGok:/U`07ok:/U`;o00003onJN887o`0000SoRjg2
0ol00005olGM/@co00008?nPTiL3o`0002;oWYnA0_l0000Gok>k[P;o00007OoNgl<2o`0001SoPJRm
0_l0000Sok:V/`;o0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`2:ooooo`?o00001OoDaL05o`0001[o^L^j1_l00009ogR6X`?o00003?nb[9L01Ol0003o/ZbGok:/
Uonb[9Oo000000?o/ZbG00?o0000ok:/Uonb[9L01onb[9L2o`0001;oVWR21ol00006oh^]`P?o0000
00?oaMfao`000?l000001_l000000on4Wl_o0000o`00000Uoj2CU`;o00008OnNWi43o`0001Oo/k^^
0_l0000MomkO``?o00005_n1Z;d3o`0002?o/ZJc0_l00031ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08_ooooo0ol000000ooDaL3o0000o`000006o`0001go^L^j1_l0
0006ogR6X`;o00004Onb[9L00ol0003o/ZbGok:/U`02ok:/U`03o`000?nb[9Oo/ZbG00Ko/ZbG0_l0
000EoiYhPPOo00001?n;[L87o`0000GoQ9o;0ol0000Soj2CU`Co00008?nNWi42o`0001So/k^^0_l0
000NomkO``?o00005On1Z;d2o`0000[o/ZJc1Ol00002ok:V/`?o00001?nbY[<3o`0000Wo/ZJc0_l0
0031ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo1ol00002
okFVX`?o00007_nibkX6o`0000?oN8JS0ol0000Aok:/U`03o`000?nb[9Oo/ZbG00;o/ZbG00?o0000
ok:/Uonb[9L01_nb[9L2o`0001SoVWR23?l00009ohBOb`;o00008_nPTiL6o`0001koWYnA0ol0000H
ok>k[P;o00007ooNgl<2o`0001CoPJRm0ol0000;ok:V/`04o`000?nbY[?o/ZJco`0000?o/ZJc00?o
0000ok:V/onbY[<01?nbY[<00ol0003o/ZJcok:V/`08ok:V/`;o0000`Oooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2=ooooo`?o00001_neYZ<3o`00023o^L^j2?l0000>
ok:/U`Co00001_nb[9L00ol0003o/ZbGok:/U`05ok:/U`;o00002onJN883o`0000?oVWR20ol00007
oiYhPPKo00003?n4Wl/2o`00027oX9>G0ol00002ogR2^P;o00007_nNWi42o`0001Wo/k^^0_l0000O
omkO``?o00004_n1Z;d3o`0000go/ZJc00?o0000ok:V/onbY[<00onbY[<01?l0003o/ZJcok:V/onb
Y[<5o`0000So/ZJc0ol00031ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08cooooo0ol00008okFVX`?o00008OnibkX6o`0000ko/ZbG00?o0000ok:/Uonb[9L00onb[9L0
1Ol0003o/ZbGok:/Uonb[9Oo000000Oo/ZbG0_l0000:oiYhPP05o`000?nJN8;oVWR2oiYhP_l00000
0onJN8800ol0003oVWR2oiYhPP09oiYhPP;o00003On4Wl/2o`0000?oX9>G0ol00002oj2CU`Go0000
0onPTiL2o`0000koX9>G0ol00003ogR2^P?o00007?nNWi43o`0001Wo/k^^0_l0000PomkO``Go0000
3on1Z;d2o`0000oo/ZJc00?o0000ok:V/onbY[<00_nbY[<01Ol0003o/ZJcok:V/onbY[?o000000;o
/ZJc00?o0000ok:V/onbY[<01onbY[<2o`000<;ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0S?ooool2o`0000[o]JJS0ol0000SokW;^P;o00003onb[9L5o`000003ok:/
Uol0003o000000?o00001onb[9L2o`0000[oVWR200Go0000oiYhP_nJN8;oVWR2o`000003oiYhPP03
o`000?nJN8;oVWR200SoVWR20ol0000=ohBOb`;o00001?nPTiL00ol0003oX9>Goj2CU`02oj2CU`04
o`000?nPTiOoX9>Go`0000;oX9>G00Co0000oj2CUonPTiOo00003?nPTiL3o`0000GoN8:j0_l0000L
oijOT@;o00006_nc^jh2o`0000Gog]o30ol00003omkO``?o00001?oNgl<2o`0000gog]o31ol0000;
oh6X_@?o00003?nbY[<01Ol0003o/ZJcok:V/onbY[?o000000?o/ZJc00?o0000ok:V/onbY[<00_nb
Y[<00ol0003o/ZJco`000008ok:V/`?o0000`_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2;ooooo`?o00002oneYZ<3o`0002;o^L^j0_l0000Qok:/U`;o00002onJN883
o`0000CoVWR200?o0000oiYhP_nJN8801onJN883o`0000koQ9o;0ol00003oj2CU`03o`000?nPTiOo
X9>G00?oX9>G00?o0000oj2CUonPTiL00_nPTiL01?l0003oX9>Goj2CUol0000;oj2CU`?o00001_mh
P[X3o`0001[oWYnA0ol0000Jok>k[P;o00001_oNgl<01Ol0003og]o3omkO`ooNgl?o000000?og]o3
00Co0000omkO`ooNgl?o00000_oNgl<00ol0003og]o3omkO``09omkO``?o000000?od:6Ro`000?l0
00001Ol00007oh6X_@?o00003OnbY[<01Ol0003o/ZJcok:V/onbY[?o000000;o/ZJc0_l00005ok:V
/`;o00002?nbY[<2o`000<?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Roooool2o`0000go]JJS0ol00009okW;^PGo00000_nibkX2o`0000oo^L^j0_l0000Qok:/U`;o
00002_nJN8801Ol0003oVWR2oiYhP_nJN8;o000000?oVWR200?o0000oiYhP_nJN8801_nJN883o`00
013oQ9o;0_l00003oj2CU`03o`000?nPTiOoX9>G00CoX9>G00Go0000oj2CUonPTiOoX9>Go`000002
oj2CU`03o`000?nPTiOoX9>G00SoX9>G0ol00008ogR2^PCo00006?nNWi42o`0001_o/k^^0_l00006
omkO``05o`000?oNgl?og]o3omkO`ol000000ooNgl<01?l0003og]o3omkO`ol00002omkO``03o`00
0?oNgl?og]o300Sog]o30ol00005om2QXPOo00001?n1Z;d2o`0000oo/ZJc0ol00004ok:V/`03o`00
0?nbY[?o/ZJc00Co/ZJc00?o0000ok:V/onbY[<01OnbY[<3o`000<?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0R_ooool3o`0000ko]JJS0ol00009okW;^P04o`000?ni
bk[o^L^jo`0000Co^L^j00?o0000okW;^_nibkX03?nibkX2o`00027o/ZbG0_l0000:oiYhPP05o`00
0?nJN8;oVWR2oiYhP_l000000_nJN882o`0000OoVWR20ol0000AohBOb`;o00000onPTiL01Ol0003o
X9>Goj2CUonPTiOo000000?oX9>G00Co0000oj2CUonPTiOo00000_nPTiL00ol0003oX9>Goj2CU`07
oj2CU`?o00002_mhP[X6o`0001CoWYnA0ol00006ok>k[P?o00000onc^jh3o`0000?o/k^^0ol00006
ok>k[P;o00001_oNgl<00ol0003og]o3omkO``02omkO``?o00000ooNgl<01?l0003og]o3omkO`ol0
0009omkO``?o00002Oo@XJ8:o`0002Go/ZJc0_l00034ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo08[ooooo0_l0000@okFVX`?o00002OnibkX00ol0003o^L^jokW;^P05
okW;^P03o`000?nibk[o^L^j00_o^L^j0ol0000Pok:/U`;o00002onJN883o`0000CoVWR200?o0000
oiYhP_nJN8801?nJN883o`0001;oQ9o;0_l00002oj2CU`;o00000onPTiL01Ol0003oX9>Goj2CUonP
TiOo000000;oX9>G00Co0000oj2CUonPTiOo00002?nPTiL3o`0000[oN8:j2_l0000AoijOT@;o0000
2?nc^jh01Ol0003o/k^^ok>k[_nc^jko000000?o/k^^00?o0000ok>k[_l000000onc^jh00ol0003o
/k^^ok>k[P03ok>k[P;o00001_oNgl<01Ol0003og]o3omkO`ooNgl?o000000?og]o300Co0000omkO
`ooNgl?o00000_oNgl<00ol0003og]o3omkO``06omkO``?o00003Oo@XJ86o`0002Go/ZJc0ol00034
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Wooooo0ol0000AokFV
X`?o00002OnibkX01?l0003o^L^jokW;^_nibkX4o`0000ko^L^j0_l0000Pok:/U`;o00006?nJN883
o`0001?oQ9o;0ol00002oj2CU`03o`000?nPTiOoX9>G00;oX9>G0ol00004oj2CU`;o00002?nPTiL3
o`0000_oN8:j0_l00004okFa]`Oo00003OnNWi43o`0000So/k^^00Go0000ok>k[_nc^jko/k^^o`00
0003ok>k[P03o`000?nc^jko/k^^00?o/k^^00?o0000ok>k[_nc^jh00onc^jh2o`0000Gog]o30_l0
0003omkO``05o`000?oNgl?og]o3omkO`ol000000_oNgl<01?l0003og]o3omkO`ol00007omkO``?o
00004Oo@XJ82o`0002Ko/ZJc0_l00035ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08Wooooo0_l0000CokFVX`?o00001OnibkX01ol0003o^L^jokW;^_nibk[o0000okW;
^_l000000onibkX00ol0003o^L^jokW;^P0<okW;^P;o00008?nb[9L2o`0001SoVWR20_l0000EohBO
b`;o00005onPTiL3o`0000coN8:j0_l00007okFa]`Ko00002_nNWi43o`0000Wo/k^^00Co0000ok>k
[_nc^jko/k^^1?l00004ok>k[P;o00001_nc^jh2o`0000Kog]o300?o0000omkO`ooNgl<00_oNgl<3
o`0000Cog]o30_l00008omkO``;o00004_o@XJ83o`0002Co/ZJc0ol00035ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08Wooooo0_l0000DokFVX`?o00001?nibkX01ol0
003o^L^jokW;^_nibk[o0000okW;^_l000000onibkX00ol0003o^L^jokW;^P0<okW;^P;o00008?nb
[9L2o`0001OoVWR20ol0000EohBOb`;o00005OnPTiL4o`000003ogR2^_l0003o000000?o00000_mh
P[X3o`000004ogR2^_l0003o0000o`0000[o]K6g1_l00007oijOT@;o00002_nc^jh01Ol0003o/k^^
ok>k[_nc^jko000000Wo/k^^00?o0000ok>k[_nc^jh00onc^jh2o`0001_og]o30ol0000Com2QXP;o
00009?nbY[<2o`000<Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
R?ooool3o`0001Go]JJS0ol00004okW;^P?o00000onibkX3o`0000oo^L^j1?l0000Nok:/U`Ko0000
4_nJN883o`0001KoQ9o;0_l0000Eoj2CU`?o00000omhP[X01_l0003oN8:jogR2^_l0003oN8:jo`00
00?oN8:j0ol0000=okFa]`Oo00000onNWi43o`0000Wo/k^^0_l00004ok>k[P03o`000?nc^jko/k^^
00;o/k^^00Go0000ok>k[_nc^jko/k^^o`000005ok>k[P;o00006_oNgl<3o`0001Cod:6R0ol0000S
ok:V/`;o0000a_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`28oooo
o`;o00005oneYZ<3o`0001_o^L^j1ol0000Kok:/U`go00002_nJN883o`0001OoQ9o;0ol0000Coj2C
U`?o00001OmhP[X01Ol0003oN8:jogR2^_mhP[[o000000?oN8:j0ol0000@okFa]`Wo00002onc^jh0
0ol0003o/k^^ok>k[P03ok>k[P;o00000onc^jh3o`0000Ko/k^^0_l0000IomkO``?o00005_o@XJ82
o`0002;o/ZJc0ol00036ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08Oooooo0ol0000HokFVX`?o00006OnibkX3o`000003ok;5_Ol0003o000000Go00005onb[9L3o`00
00?o]9jC3ol00002oiYhPP?o00006On4Wl/2o`0001;oX9>G1?l00006ogR2^P03o`000?mhP[[oN8:j
00Oo00004one/KL6o`0001oo/k^^0_l0000HomkO``?o00005oo@XJ86o`0001ko/ZJc0_l00037oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l0000JokFVX`?o
00005onibkX3o`0000Go//Fm2?l0000Bok:/U`?o00002ondWY<<o`0001[oQ9o;0_l0000Aoj2CU`?o
000000?oN8:jo`000?mhP[X00_mhP[X01ol0003oN8:jogR2^_mhP[[o0000ogR2^_l000000omhP[X2
o`0001Oo]K6g0_l0000Pok>k[P;o00005ooNgl<3o`0001Wod:6R3?l0000Fok:V/`?o0000aoooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`26ooooo`?o00006oneYZ<3o`00
01Go^L^j0ol00009ok;5_@So00003_nb[9L3o`0001?o]9jC1?l0000;ohBOb`;o00001?n4Wl/3o`00
00OoQ9o;0_l0000@oj2CU`?o000000?oN8:jo`000?l000000omhP[X01Ol0003oN8:jogR2^_mhP[[o
000000;oN8:j00?o0000ogR2^_mhP[X00_l0000GokFa]`?o00007onc^jh2o`0001Kog]o30ol0000J
om2QXP;o00000_n`]/`>o`00013o/ZJc0_l00038ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo08Kooooo0_l0000MokFVX`?o00005?nibkX2o`0000ko//Fm2?l00009ok:/
U`?o00005_ndWY<2o`0000goQ9o;00Co0000ohBObon4Wl_o00000on4Wl/00ol0003oQ9o;ohBOb`04
ohBOb`;o00003onPTiL3o`0000?oN8:j00?o0000ogR2^_mhP[X00_mhP[X3o`0000CoN8:j1?l0000H
okFa]`;o00007Onc^jh5o`0001Gog]o30_l0000Jom2QXP?o00002On`]/`=o`0000Wo/ZJc0ol00038
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Kooooo0ol0000;okFV
X`Go00000_neYZ<3o`0000So]JJS0ol0000BokW;^P?o00004OnbaKd8o`0000Go/ZbG0ol0000GokBN
T`?o00003On4Wl/00ol0003oQ9o;ohBOb`03ohBOb`03o`000?n4Wl_oQ9o;00CoQ9o;0ol0000=oj2C
U`?o00004OmhP[X2o`0001Wo]K6g0ol0000Iok>k[PWo00004ooNgl<3o`0001[od:6R0_l0000@ok2f
c0ko00000_nbY[<2o`000<Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Qoooool2o`0000co]JJS00Co0000okFVXoneYZ?o00000oneYZ<00ol0003o]JJSokFVX`08okFV
X`?o00004?nibkX3o`0001Ko//Fm1ol000001?nb[9Oo0000o`000?l0000IokBNT`;o00002_n4Wl/4
o`0000GoQ9o;00?o0000ohBObon4Wl/01On4Wl/2o`0000coX9>G0ol0000BogR2^P;o00006_ne/KL2
o`0001Go/k^^2?l00003ohR3ZP?o00004OoNgl<3o`0001_od:6R0_l0000Fok2fc0co0000bOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`27ooooo`;o00003OneYZ<00ol0
003o]JJSokFVX`03okFVX`03o`000?neYZ?o]JJS00Wo]JJS0ol0000>okW;^P?o00006_nbaKd7o`00
01[o]9jC0_l00009ohBOb`06o`000?n4Wl_oQ9o;ohBObol0003oQ9o;1?l00008ohBOb`;o00002onP
TiL3o`0001;oN8:j0ol0000JokFa]`?o00004Onc^jh8o`0000OoR8>Z0ol0000?omkO``?o00007?o@
XJ82o`0001go/;K<1?l0003:ooooo`03o`000?oooooooooo00Sooooo00001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool0Qoooool3o`0000go]JJS00?o
0000okFVXoneYZ<00_neYZ<00ol0003o]JJSokFVX`0:okFVX`?o00003OnibkX2o`0001ko//Fm0ol0
000KokBNT`?o00002?n4Wl/01ol0003oQ9o;ohBObon4Wl_o0000ohBObol000002on4Wl/2o`0000[o
X9>G0ol0000CogR2^P;o00007?ne/KL3o`0000co/k^^2?l0000<ohR3ZP?o00003OoNgl<3o`0000Wo
d:6R0ol00003om2QXP;o00001?o@XJ83o`0000Cod:6R0ol0000Ook2fc0;o0000b_ooool00ol0003o
ooooooooo`08ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`28ooooo`;o00002_neYZ<01Ol0
003o]JJSokFVXoneYZ?o000000?o]JJS00?o0000okFVXoneYZ<02oneYZ<3o`0000_o^L^j0ol0000<
ok;5_@?o00000_nbaKd2o`0000co//Fm0_l0000LokBNT`;o00002On4Wl/3o`0000;oQ9o;1Ol00007
ohBOb`?o00002?nPTiL3o`0001CoN8:j0_l0000MokFa]`;o00002Onc^jh8o`00013oR8>Z4Ol0000;
om2QXP03o`000?o@XJ;od:6R00Cod:6R00Co0000om2QX_o@XJ;o00000oo@XJ801?l0003od:6Rom2Q
X_o@XJ82o`00023o/;K<0_l0003:ooooo`03o`000?oooooooooo00Sooooo0002ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo08Sooooo0ol00009okFVX`05o`000?neYZ?o]JJSokFVXol000000_neYZ<2o`00
00ko]JJS0ol00009okW;^P?o00003_nbaKd00ol0003o//Fmok;5_@03ok;5_@03o`000?nbaKgo//Fm
00Wo//Fm0_l0000LokBNT`;o00006on4Wl/2o`0000OoX9>G0ol0000DogR2^P?o00007One/KL3o`00
00Co/k^^2?l0000EohR3ZPoo00003?o@XJ800ol0003od:6Rom2QXP05om2QXP03o`000?o@XJ;o0000
00?od:6R00Co0000om2QX_o@XJ;od:6R0_l0000Pok2fc0?o0000bOooool00ol0003oooooooooo`08
ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00002Oooool5o`0008Oooooo0_l0000:okFVX`?o00001?neYZ<00ol0003o]JJSokFV
X`0=okFVX`?o00001_nibkX4o`0000co//Fm1Ol00005ok;5_@03o`000?nbaKgo//Fm00So//Fm0ol0
000KokBNT`?o00006_n4Wl/2o`0000KoX9>G0ol0000EogR2^P;o00007one/KL2o`000003ok>k[_l0
003o000000Ko00006?n8PjX2o`0000_oilNW0ol0000;om2QXP03o`000?o@XJ;od:6R00;od:6R1?l0
00000oo@XJ;o0000o`000002o`0000Cod:6R0_l0000Qok2fc0;o0000aOooool5o`0000[ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo08Wooooo0_l0000RokFVX`?o00001?nibkX7o`0000[o//Fm
00Co0000ok;5_OnbaKgo00000onbaKd4o`0000_o//Fm0_l0000LokBNT`;o00006_n4Wl/2o`0000Go
X9>G0ol0000FogR2^P;o00007one/KL7o`0001coR8>Z0_l0000<onO7Y`?o00002_o@XJ801Ol0003o
d:6Rom2QX_o@XJ;o000000?od:6R00?o0000om2QX_l000001_o@XJ83o`00027o/;K<0_l00039oooo
o`03o`000?oooooooooo00Sooooo00000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`29ooooo`?o00008_neYZ<3
o`0000;o^L^j0ol00002okn[ePGo00002OnbaKd00ol0003o//Fmo`000002ok;5_@05o`000?nbaKgo
//Fmok;5_Ol000002onbaKd2o`0000go]9jC00?o0000okBNTondWY<00_ndWY<3o`0000Oo]9jC0_l0
000JohBOb`;o00001?nPTiL3o`0001KoN8:j0ol0000PokFa]`?o00007_n8PjX3o`0000goilNW0ol0
0008om2QXP;o00000oo@XJ801Ol0003od:6Rom2QX_o@XJ;o000000;od:6R00?o0000om2QX_o@XJ80
0oo@XJ82o`0002;o/;K<0_l00039ooooo`03o`000?oooooooooo00Sooooo0002ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00002_ooool00ol0003oooooooooo`2:ooooo`;o00008one
YZ<6o`0000Go_j_F1Ol00008ok;5_@;o00000_nbaKd01Ol0003o//Fmok;5_OnbaKgo000000_o//Fm
0_l0000=okBNT`05o`000?ndWY?o]9jCokBNTol000000ondWY<00ol0003o]9jCokBNT`04okBNT`?o
00006On4Wl/3o`0000;oX9>G0ol0000GogR2^P;o00003?ne/KL3o`0000?o]K6g0ol00003okFa]`?o
00001_ne/KL2o`0001ooR8>Z0_l0000?onO7Y`?o00002?o@XJ800ol0003od:6Rom2QXP02om2QXP?o
00001?o@XJ82o`0000?od:6R0_l0000Rok2fc0;o0000bOooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2:ooooo`?o00008oneYZ<4o`0000So_j_F1Ol00007ok;5_@04o`00
0?nbaKgo//Fmok;5_@?o00003?nbaKd2o`0000ko]9jC00Co0000okBNTondWY?o00000ondWY<00ol0
003o]9jCokBNT`05okBNT`;o00006_n4Wl/7o`0001OoN8:j0_l0000=okFa]`05o`000?ne/KOo]K6g
okFa]ol000000one/KL00ol0003o]K6go`000003okFa]`03o`000?ne/KOo]K6g00;o]K6g0ol0000O
ohR3ZP;o00004?oWajL2o`0001Wod:6R0_l0000Rok2fc0?o0000b?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2;ooooo`;o00009?neYZ<2o`0000_o_j_F1Ol0000Hok;5
_@;o00003_ndWY<00ol0003o]9jCokBNT`04o`0000So]9jC0_l0000JohBOb`[o00004omhP[X3o`00
00go]K6g00?o0000okFa]one/KL01One/KL00ol0003o]K6go`000003okFa]`03o`000?ne/KOo]K6g
00;o]K6g0_l0000PohR3ZP;o00004?oWajL3o`0001Ood:6R0ol0000Sok2fc0;o0000b?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`?o00008_neYZ<3o`0000go
_j_F1Ol0000Fok;5_@;o00003ondWY<00ol0003o]9jCo`00000;okBNT`?o00006?n4Wl/3o`0000Co
/Jfo2?l0000?ogR2^P;o00003_ne/KL00ol0003o]K6gokFa]`03okFa]`;o00000one/KL3o`0000Go
]K6g0_l0000PohR3ZP;o00004OoWajL3o`0001Kod:6R0_l0000Tok2fc0;o0000b?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<ooooo`;o00008OneYZ<4o`0000oo_j_F
1Ol0000Dok;5_@?o00002_ndWY<01Ol0003o]9jCokBNTondWY?o000000;o]9jC00?o0000okBNTond
WY<02OndWY<2o`0001OoQ9o;0ol00008ok6]_`So00003?mhP[X2o`0000ko]K6g00?o0000okFa]one
/KL01One/KL00ol0003o]K6go`000003okFa]`03o`000?ne/KOo]K6g00;o]K6g0_l0000PohR3ZP;o
00004_oWajL3o`0001God:6R0_l0000Tok2fc0;o0000b?ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2<ooooo`;o00008?neYZ<6o`00013o_j_F1?l0000Dok;5_@;o0000
2_ndWY<5o`0000?o]9jC0_l00009okBNT`;o00005_n4Wl/3o`0000go/Jfo1ol00008ogR2^P?o0000
3One/KL2o`0000?o]K6g00Oo0000okFa]one/KOo]K6go`000?ne/KOo000000?o]K6g00?o0000okFa
]one/KL00_ne/KL2o`00023oR8>Z0_l0000ConO7Y`;o00005Oo@XJ82o`0002?o/;K<0ol00038oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0ol0000MokFVX`Co
00000_n2/KH3o`00017o_j_F1?l0000Bok;5_@;o00007OndWY<3o`0001CoQ9o;0ol0000Aok6]_`So
00001?mhP[X2o`0000oo]K6g00?o0000okFa]one/KL00_ne/KL3o`0000?o]K6g0ol00004okFa]`?o
00007on8PjX3o`0001?oilNW0ol0000Com2QXP?o00002_n`]/`5o`0000;o/;K<0ol00003ok2fc0?o
00002?n`]/`3o`000<Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
SOooool2o`0001co]JJS1?l00004oh:a]P?o00004OnoZmH5o`0000oo//Fm1?l0000MokBNT`;o0000
4on4Wl/3o`0001Go/Jfo2?l000000omhP[[o0000o`00000QokFa]`;o00008?n8PjX2o`0001GoilNW
0ol0000Bom2QXP;o00003?n`]/`01?l0003o/;K<ok2fc?l00003ok2fc003o`000?n`]/co/;K<00?o
/;K<00?o0000ok2fc?n`]/`01on`]/`2o`000<[ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0SOooool3o`0001[o]JJS0ol00007oh:a]P;o00001?noZmH3o`0000?o_j_F
00?o0000okn[e_noZmH01_noZmH5o`0000co//Fm1ol0000KokBNT`;o00004_n4Wl/3o`0001[o/Jfo
1ol0000QokFa]`?o00003?n8PjX3o`0000CoR8>Z00?o0000ohR3Z_n8PjX00on8PjX2o`0000CoR8>Z
0_l0000FonO7Y`?o00004Oo@XJ82o`0000go/;K<00?o0000ok2fc?n`]/`00on`]/`00ol0003o/;K<
ok2fc003ok2fc003o`000?n`]/co/;K<00Ko/;K<0ol0003:ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08kooooo0_l0000HokFVX`Co00002?n2/KH3o`0000Co_j_F00?o
0000okn[e_noZmH00_noZmH00ol0003o_j_Fokn[eP08okn[ePGo00002OnbaKd3o`0000;oYgf61?l0
000JokBNT`?o00004?n4Wl/3o`0001ko/Jfo0ol0000QokFa]`Go00003?n8PjX00ol0003oR8>ZohR3
ZP03ohR3ZP03o`000?n8Pj[oR8>Z00;oR8>Z00Co0000ohR3Z_n8Pj[o00000on8PjX2o`0001OoilNW
0ol0000@om2QXP;o00003_n`]/`00ol0003o/;K<ok2fc002ok2fc003o`000?n`]/co/;K<00?o/;K<
00?o0000ok2fc?n`]/`01On`]/`3o`000<_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0S_ooool2o`0001Oo]JJS1?l0000:oh:a]PSo00001?noZmH00ol0003o_j_Fokn[
eP09okn[ePGo00001_nbaKd3o`0000GoYgf61?l0000IokBNT`;o00003_n4Wl/4o`00023o/Jfo0ol0
000OokFa]`?o000000?ob]B_o`000?l000000_l0000:ohR3ZP03o`000?n8Pj[oR8>Z00CoR8>Z00Go
0000ohR3Z_n8Pj[oR8>Zo`000002ohR3ZP04o`000?n8Pj[oR8>ZohR3ZP;o00006?oWajL2o`0000oo
d:6R0ol0000;ok2fc005o`000?n`]/co/;K<ok2fc?l000000on`]/`00ol0003o/;K<ok2fc003ok2f
c003o`000?n`]/co/;K<00Go/;K<0_l0003<ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo08kooooo1?l0000DokFVX`?o00003On2/KH3o`0000;o_j_F00?o0000okn[e_no
ZmH00onoZmH00ol0003o_j_Fokn[eP0;okn[ePGo00000onbaKd3o`0000OoYgf61Ol0000GokBNT`;o
00003?n4Wl/7o`00023o/Jfo0ol0000MokFa]`?o00000oo:e:l4o`0000WoR8>Z00?o0000ohR3Z_n8
PjX01?n8PjX01Ol0003oR8>ZohR3Z_n8Pj[o000000;oR8>Z00Co0000ohR3Z_n8Pj[oR8>Z0_l0000H
onO7Y`?o00002oo@XJ85o`0000co/;K<00Go0000ok2fc?n`]/co/;K<o`000002ok2fc0;o00001?n`
]/`2o`0000Ko/;K<0ol0003<ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08oooooo1?l0000BokFVX`?o00003on2/KH3o`000003okn[e_l0003o_j_F00Go_j_F00?o0000
okn[e_noZmH03?noZmH8o`0000[oYgf61Ol0000EokBNT`?o00002On4Wl/5o`0000;o^ln40ol0000P
ok6]_b7o00001_o:e:l4o`0000OoR8>Z00?o0000ohR3Z_n8PjX01On8PjX01?l0003oR8>ZohR3Z_l0
0002ohR3ZP03o`000?n8Pj[oR8>Z00?o00000ooWajL3o`0000?oilNW0ol00003onO7Y`?o00001ooW
ajL3o`0000?od:6R3Ol0000<ok2fc0?o00001?n`]/`00ol0003o/;K<ok2fc003ok2fc003o`000?n`
]/co/;K<00?o/;K<0ol0003=ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo097ooooo1?l0000>okFVX`Co00004?n2/KH5o`0000;o_j_F00Go0000okn[e_noZmKo_j_Fo`00
000@okn[ePGo00003OnWOHH5o`0001Co]9jC0_l00007ohBOb`Go00001Onkch@3o`00023o/Jfo7ol0
0008ol[D[`Co00001On8PjX2o`0000?oR8>Z00Go0000ohR3Z_n8Pj[oR8>Zo`000002ohR3ZP04o`00
0?n8Pj[oR8>Zo`0000;oR8>Z0_l00005onO7Y`05o`000?oWajOoilNWonO7Yol000000ooWajL01Ol0
003oilNWonO7YooWajOo000000WoilNW3Ol00003ooW=c@?o00007_n`]/`2o`000<kooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0T_ooool5o`0000_o]JJS1?l0000Boh:a
]PCo00000_noZmH5o`0001;o_j_F0_l0000@ojMmQPCo00004ondWY<2o`0000GoQ9o;1Ol00008ok_?
Q0?o00007ona[Kl2o`0001_oUHW40_l0000:ol[D[`Co00001?n8PjX01?l0003oR8>ZohR3Z_n8PjX5
o`0000?oR8>Z0_l00003ohR3ZP;o00001OoWajL01Ol0003oilNWonO7YooWajOo000000?oilNW00Go
0000onO7YooWajOoilNWo`00000:onO7Y`Go00002ooicLd3o`0001co/;K<0ol0003>ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09Cooooo1?l00009okFVX`?o00005On2
/KH3o`0001So_j_F0ol0000BojMmQPCo00004OndWY<3o`0000;oQ9o;1Ol0000;ok_?Q0?o00007Ona
[Kl3o`0001_oUHW40_l0000;ol[D[`Co00005?n8PjX2o`0000GoilNW00?o0000onO7YooWajL00_oW
ajL3o`0000CoilNW00?o0000onO7YooWajL01ooWajL3o`0000oonLg=0ol0000Kok2fc0;o0000cooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Fooooo`Co00001OneYZ<4
o`0001OoP[6f0_l0000Gokn[eP?o00005?nWOHH8o`0000co]9jC2?l0000>ok_?Q0?o00001ona[Kl3
o`0000;o/Jfo1Ol00002ok6]_`?o00001_na[Kl2o`0001_oUHW40ol0000=ol[D[`Co00004_n8PjX2
o`0000GoilNW00Go0000onO7YooWajOoilNWo`000003onO7Y`05o`000?oWajOoilNWonO7Yol00000
2?oWajL3o`00017onLg=0ol0000Iok2fc0?o0000coooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2Gooooo`Go00000_neYZ<4o`0001SoP[6f0ol0000Fokn[eP;o00005onW
OHH=o`0000?o]9jC2?l0000Aok_?Q0?o00001ona[Kl00ol0003o/Jfook6]_`02ok6]_`04o`000?na
[Koo/Jfoo`0000?o/Jfo00?o0000ok6]_ona[Kl01Ona[Kl2o`0001_oUHW40_l0000?ol[D[`Go0000
4?n8PjX2o`0000CoilNW0_l00003onO7Y`05o`000?oWajOoilNWonO7Yol000000_oWajL2o`0000Oo
ilNW0ol0000CooW=c@?o00005on`]/`3o`000=3ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0VOooool7o`0001_oP[6f0ol0000Dokn[eP?o00005_nWOHH3o`0000?oV9WA
3_l00003ojG5T0?o00004Onkch@3o`0000Ko/Jfo00?o0000ok6]_ona[Kl00ona[Kl00ol0003o/Jfo
ok6]_`03ok6]_`03o`000?na[Koo/Jfo00Go/Jfo0_l0000KoiF9a0;o00004Oo:e:l4o`0000koR8>Z
0ol00005onO7Y`03o`000?oWajOoilNW00;oilNW0ol00004onO7Y`03o`000?oWajOoilNW00CoilNW
0ol0000EooW=c@?o00005_n`]/`2o`000=7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Voooool4o`0001goP[6f0_l0000Cokn[eP?o00005_nWOHH3o`0000_oV9WA1Ol0
0006ojG5T0;o00004_nkch@3o`0000Go/Jfo00?o0000ok6]_ona[Kl01?na[Kl00ol0003o/Jfook6]
_`02ok6]_`03o`000?na[Koo/Jfo00Go/Jfo0_l0000KoiF9a0;o00004oo:e:l4o`0000coR8>Z0_l0
000HonO7Y`?o00005ooicLd3o`0001Co/;K<0ol0003Aooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo09cooooo0_l0000Noh:a]P?o00004OnoZmH3o`000004ojMmQ_l0003o
0000o`0000?oYgf60ol0000=ojMmQP;o00003_nHVM43o`0000KoYLF@0ol0000Bok_?Q0?o00001?na
[Kl01Ol0003o/Jfook6]_ona[Koo000000?o/Jfo00Go0000ok6]_ona[Koo/Jfoo`000006ok6]_`?o
00001onERL@3o`0000?oUHW40ol00003oiF9a0;o00001OnERL@3o`0000?ob]B_0ol00004ol[D[`03
o`000?o:e:oob]B_00Oob]B_1?l0000;ohR3ZP;o00006?oWajL2o`0001WonLg=0ol0000Aok2fc0Co
0000d_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Looooo`;o0000
7on2/KH3o`00013o_j_F0_l000000onWOHKo0000ojMmQP02ojMmQP03o`000?nWOHKo000000?oYgf6
00?o0000ojMmQ_nWOHH02OnWOHH3o`0000koV9WA0_l00008ojG5T0;o00004onkch@3o`0000;o/Jfo
0_l00003ok6]_`05o`000?na[Koo/Jfook6]_ol000000_na[Kl2o`0000Ko/Jfo0_l00009oiF9a005
o`000?nERLCoUHW4oiF9a?l000000onERL@00ol0003oUHW4oiF9a002oiF9a003o`000?nERLCoUHW4
00?oUHW40_l00002ol[D[`05o`000?o:e:oob]B_ol[D[ol000000oo:e:l00ol0003ob]B_ol[D[`09
ol[D[`Co00002On8PjX2o`0001OoilNW0ol0000JooW=c@?o00003On`]/`6o`000=?ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0W?ooool2o`00023oP[6f0ol0000>okn[
eP?o000000?oYgf6o`000?nWOHH00_nWOHH00ol0003oYgf6ojMmQP03ojMmQP03o`000?nWOHKoYgf6
00SoYgf60ol0000?oiRId@;o00002?nUaI03o`0001?o^ln40ol00002ok6]_`03o`000?na[Koo/Jfo
00;o/Jfo0ol00004ok6]_`03o`000?na[Koo/Jfo00Co/Jfo0_l00009oiF9a003o`000?nERLCoUHW4
00GoUHW400?o0000oiF9a?nERL@00onERL@00ol0003oUHW4oiF9a002oiF9a0;o00001_o:e:l00ol0
003ob]B_ol[D[`02ol[D[`03o`000?o:e:oob]B_00Wob]B_1?l00008ohR3ZP;o00005_oWajL3o`00
01conLg=0ol00009ok2fc0Oo0000eOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2Looooo`;o00008On2/KH2o`0000go_j_F0ol00002ojMmQPCo00001?nWOHH2o`0000_o
Ygf60_l0000?oiRId@?o00002OnUaI02o`0001Co^ln40ol0000Dok6]_`;o00002OnERL@00ol0003o
UHW4oiF9a003oiF9a0;o00000onERL@4o`0000?oUHW40ol00006ol[D[`03o`000?o:e:oob]B_00;o
b]B_00?o0000ol[D[oo:e:l02oo:e:l4o`0000KoR8>Z0_l0000EonO7Y`?o00007_oicLd3o`0000Go
/;K<1ol0003Hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09cooooo
0ol0000Poh:a]P?o00003?noZmH2o`0000?oYgf600?o0000ojMmQ_nWOHH01onWOHH00ol0003oYgf6
ojMmQP07ojMmQP?o00003onHVM42o`0000[oYLF@0ol0000Dok_?Q0?o00004_na[Kl3o`0000WoUHW4
00?o0000oiF9a?nERL@01OnERL@00ol0003oUHW4o`000003oiF9a004o`000?nERLCoUHW4oiF9a0;o
00000oo:e:l4o`0000Kob]B_00?o0000ol[D[oo:e:l02oo:e:l4o`0000GoR8>Z0_l0000DonO7Y`?o
00008?oicLd3o`000003ok2fc?l0003o000000Go0000foooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2Mooooo`;o00008On2/KH3o`0000[o_j_F0ol00004ojMmQP03o`00
0?nWOHKoYgf600;oYgf600Go0000ojMmQ_nWOHKoYgf6o`000008ojMmQP?o00004?nHVM42o`0000_o
YLF@0_l0000Eok_?Q0?o00004Ona[Kl2o`0000WoUHW40_l00003oiF9a007o`000?nERLCoUHW4oiF9
a?l0003oUHW4o`000003oiF9a004o`000?nERLCoUHW4oiF9a0;o00000oo:e:l00ol0003ob]B_ol[D
[`03ol[D[`05o`000?o:e:oob]B_ol[D[ol000003oo:e:l4o`0000;oR8>Z0ol0000DonO7Y`;o0000
8_oicLd7o`000=kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0WOoo
ool2o`0002;oP[6f3_l00006ojMmQP;o00000onWOHH3o`0000WoYgf60_l0000@oiRId@?o00002onU
aI03o`0001Go^ln40ol0000@ok6]_`;o00002_nERL@00ol0003oUHW4oiF9a002oiF9a0?o00000onE
RL@3o`0000CoUHW40_l00003ol[D[`Go000000?ob]B_o`000?l000000ol0000=ol[D[`[o00005?oW
ajL3o`0002?onLg=0ol0003Qooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo09gooooo0_l0000Soh:a]Pco00005onWOHH3o`00013oV9WA0_l0000=ojG5T0;o00005_nkch@3
o`0000oo/Jfo0_l0000LoiF9a0;o00006Oo:e:l5o`0000;oT[9m1Ol0000ConO7Y`?o00003?oicLd5
o`0000?onLg=0_l00004ooW=c@;o00002?oicLd2o`000>;ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0WOooool2o`0000_oP[6f0ol00003oh:a]P?o00003_n2/KH3o`00
00SoTKBL0ol0000EojMmQP?o00004OnHVM42o`0000goYLF@0ol0000Fok_?Q0?o00003Ona[Kl3o`00
01coUHW40_l0000Gol[D[`Go00001onB/Wd2o`0001;oilNW0ol0000>ooW=c@04o`000?oicLgonLg=
o`0000;onLg=00Co0000ooW=cOoicLgo00000_oicLd01?l0003onLg=ooW=cOl00007ooW=c@;o0000
h_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Mooooo`;o00002_n2
/KH01ol0003oP[6foh:a]_n2/KKo0000oh:a]_l000000on2/KH00ol0003oP[6foh:a]P0:oh:a]P?o
00002_nA]9`3o`0001CoYgf60_l0000AoiRId@?o00003_nUaI02o`0001Oo^ln40ol0000<ok6]_`;o
00007OnERL@2o`0001Gob]B_1Ol00009oi:bO@?o00004?oWajL3o`00013onLg=00?o0000ooW=cOoi
cLd00_oicLd01?l0003onLg=ooW=cOl00002ooW=c@04o`000?oicLgonLg=o`0000KonLg=0ol0003R
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000WOooool2o`0000koP[6f00?o0000oh:a
]_l000000on2/KH00ol0003oP[6foh:a]P09oh:a]P?o00003?nA]9`3o`0001;oYgf60ol0000AoiRI
d@;o00003onUaI03o`0000Ko^ln40ol00003ok_?Q0?o00000onkch@3o`0000;o^ln40ol0000;ok6]
_`;o00007?nERL@3o`0001?ob]B_1Ol0000<oi:bOACo00004_oicLd01Ol0003onLg=ooW=cOoicLgo
000000;onLg=00Co0000ooW=cOoicLgo00000_oicLd00ol0003onLg=ooW=c@04ooW=c@;o0000hOoo
ool3o`0000[ooooo000Jooooo`03o`000?oooooooooo09gooooo0ol0000;oh:a]P;o00000_n2/KH4
o`0000_oP[6f0ol0000>oi6dW0;o00004OnWOHH3o`0001;oV9WA0_l0000@ojG5T0;o00001onkch@0
0ol0003o^ln4ok_?Q003ok_?Q003o`000?nkchCo^ln400?o^ln400?o0000ok_?Q?nkch@00_nkch@3
o`0000[o/Jfo0_l0000LoiF9a0;o00004_o:e:l5o`0000ooT[9m4_l0000@ooW=c@05o`000?oicLgo
nLg=ooW=cOl000000_oicLd01?l0003onLg=ooW=cOl00002ooW=c@04o`000?oicLgonLg=o`0000Ko
nLg=0_l0003Sooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09kooooo
0_l0000=oh:a]P03o`000?n2/KKo000000koP[6f0_l0000?oi6dW0?o00003onWOHH3o`0001;oV9WA
0ol0000@ojG5T0?o00001_nkch@00ol0003o^ln4ok_?Q003ok_?Q003o`000?nkchCo^ln400?o^ln4
00?o0000ok_?Q?nkch@00onkch@3o`0000Wo/Jfo0_l0000LoiF9a0;o00004?o:e:l5o`00013oT[9m
0ol0000>olG=c`?o00003ooicLd01Ol0003onLg=ooW=cOoicLgo000000;onLg=00Co0000ooW=cOoi
cLgo00000_oicLd01?l0003onLg=ooW=cOl00006ooW=c@;o0000hoooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2Nooooo`;o00002On2/KH01Ol0003oP[6foh:a]_n2/KKo
000000;oP[6f00?o0000oh:a]_n2/KH02_n2/KH3o`00013oTKBL0ol0000>ojMmQP;o00004onHVM42
o`0001;oYLF@0_l00006ok_?Q003o`000?nkchCo^ln400?o^ln400?o0000ok_?Q?nkch@00onkch@0
0ol0003o^ln4ok_?Q004ok_?Q0?o00001ona[Kl3o`0001coUHW40_l0000=ol[D[`Ko00004_nB/Wd2
o`00013oaLg?0ol0000?ooW=c@?o00001?oicLd2o`0000ConLg=0_l00007ooW=c@;o0000hoooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Nooooo`;o00002_n2/KH3o`00
00CoP[6f0_l00009oh:a]P?o00004_nA]9`2o`0000goYgf60ol0000BoiRId@?o00000onUaI02o`00
00?oYLF@1Ol00005ojG5T0?o00001Onkch@00ol0003o^ln4ok_?Q003ok_?Q003o`000?nkchCo^ln4
00?o^ln400?o0000ok_?Q?nkch@01Onkch@3o`0000Ko/Jfo1Ol0000JoiF9a0;o00002oo:e:l6o`00
01CoT[9m0_l0000AolG=c`?o00008ooicLd3o`000>?ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0W_ooool2o`0001_oP[6f0ol0000Coi6dW0?o00002onWOHH3o`0000Go
V9WA00?o0000oiRIdOnHVM400_nHVM43o`0000KoV9WA0_l00006ojG5T005o`000?nUaI3oYLF@ojG5
T?l000000_nUaI000ol0003oYLF@ojG5T004ojG5T0;o00001?nkch@2o`0000Co^ln40_l00004ok_?
Q0;o00002?nkch@3o`0000Co/Jfo2ol0000EoiF9a0;o00002Oo:e:l5o`0001KoT[9m0ol0000BolG=
c`?o00008_oicLd2o`000>Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0W_ooool3o`0001WoP[6f0ol0000Eoi6dW0?o00002_nWOHH2o`0000KoV9WA00Go0000oiRIdOnH
VM7oV9WAo`000003oiRId@03o`000?nHVM7oV9WA00?oV9WA0_l00007ojG5T005o`000?nUaI3oYLF@
ojG5T?l000002?nUaI04o`0000?o^ln400?o0000ok_?Q?nkch@00onkch@00ol0003o^ln4ok_?Q003
ok_?Q003o`000?nkchCo^ln400Oo^ln40ol00002ok6]_`?o00000onENi/;o`00013oUHW40_l00007
ol[D[`Go00006?nB/Wd2o`0001CoaLg?0ol0000PooW=c@?o0000i?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2Oooooo`?o00005on2/KH3o`0001OoTKBL0ol00008ojMm
QP?o00001onHVM400ol0003oV9WAoiRId@04oiRId@03o`000?nHVM7oV9WA00;oV9WA0ol00004ojG5
T0Co00001?nUaI000ol0003oYLF@ojG5T006ojG5T0Ko00005onkch@6o`0000WoUG^K2ol0000:oiF9
a0?o00001Oo:e:l5o`0000GoT[9m0ol00003oi:bO@?o00000onB/Wd2o`0000OoT[9m0_l0000EolG=
c`?o00007_oicLd4o`000>Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0X?ooool3o`0001KoP[6f0_l0000Ioi6dW0;o00001onWOHH3o`0000SoV9WA00?o0000oiRIdOnH
VM400_nHVM42o`0000GoV9WA0_l00004ojG5T007o`000?nUaI3oYLF@ojG5T?l0003oYLF@o`000003
ojG5T003o`000?nUaI3oYLF@00CoYLF@2Ol0000Fok_?Q0Co00003onENi/;o`0000GoUHW40_l00004
ol[D[`Go00002?nB/Wd01Ol0003oT[9moi:bOOnB/Wgo000000?oT[9m00?o0000oi:bOOnB/Wd00_nB
/Wd00ol0003oT[9moi:bO@03oi:bO@?o00005_o5cLl3o`0001conLg=0ol0003Vooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:7ooooo0ol0000Doh:a]P?o00006OnA]9`3
o`0000KoYgf60_l0000:oiRId@03o`000?nHVM7oV9WA00?oV9WA00?o0000oiRIdOnHVM400_nHVM42
o`0000CoYLF@00Oo0000ojG5T?nUaI3oYLF@o`000?nUaI3o000000?oYLF@00?o0000ojG5T?nUaI00
1?nUaI02o`0000CoW:^h1Ol0000Eok_?Q0;o00005OnENi/=o`0000;ob]B_1Ol0000:oi:bO@03o`00
0?nB/WgoT[9m00GoT[9m00?o0000oi:bOOnB/Wd00onB/Wd00ol0003oT[9moi:bO@02oi:bO@;o0000
6?o5cLl2o`0001_onLg=0ol0003Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo0:;ooooo0ol0000Boh:a]P?o00006onA]9`3o`0000CoYgf60ol00006oiRId@07o`000?nH
VM7oV9WAoiRIdOl0003oV9WAo`000003oiRId@04o`000?nHVM7oV9WAoiRId@?o00001OnUaI03o`00
00?oYLF@0ol00006ojG5T0?o00001_nLZkP6o`00017o^ln40ol0000JoiEkV`go00003?nB/Wd00ol0
003oT[9moi:bO@05oi:bO@03o`000?nB/WgoT[9m00Co00000onB/Wd3o`0001SoaLg?0ol0000IooW=
c@?o0000j?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Sooooo`?o
00004?n2/KH3o`0000ooTKBL0ol00002oi6dW0?o00001_nA]9`2o`0000?oYgf60ol00007oiRId@Go
00000_nHVM43o`0000CoV9WA0_l0000EojG5T0;o00002OnLZkP6o`0000oo^ln40_l0000PoiEkV`Ko
00003_nB/Wd01?l0003oT[9moi:bOOnB/Wd4o`0000;oT[9m00Go0000oi:bOOnB/WgoT[9mo`000003
oi:bO@;o00006_o5cLl3o`0001OonLg=0ol0003Yooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0:Cooooo0ol0000=oh:a]PCo00004OnA]9`01?l0003oTKBLoi6dW?l00003
oi6dW003o`000?nA]9coTKBL00?oTKBL0ol00002ojMmQP;o00005_nHVM42o`0001CoYLF@0ol0000<
oib[^0Go00003?nkch@3o`0002;oUG^K0_l0000?oi:bO@;o00000onB/Wd00ol0003oT[9moi:bO@03
oi:bO@05o`000?nB/WgoT[9moi:bOOl000000onB/Wd2o`0001_oaLg?0ol0000DooW=c@Co0000j_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Uooooo`?o00002_n2/KH8
o`0000coTKBL1Ol000000onA]9co0000oi6dW002oi6dW003o`000?nA]9coTKBL00CoTKBL1_l0000E
oiRId@?o00005?nUaI02o`0000ooW:^h1_l00008ok_?Q0?o00001OnENi/3o`0000?oUG^K0ol00003
oiEkV`?o00003onENi/2o`00013oT[9m00Co0000oi:bOOnB/WgoT[9m1Ol00002oi:bO@?o00000onB
/Wd3o`0001coaLg?0ol0000BooW=c@Co0000joooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2Vooooo`?o00001_n2/KH6o`0000;oU:ZP1Ol0000:oi6dW004o`000?nA]9co
TKBLo`0000?oTKBL0ol00008oi6dW0Co00005_nHVM42o`0001CoYLF@0ol0000Aoib[^0Ko00001_nk
ch@2o`0000OoUG^K00Go0000oiEkVonENi_oUG^Ko`000003oiEkV`03o`000?nENi_o000000?oUG^K
00?o0000oiEkVonENi/03?nENi/3o`00023oT[9m0_l0000NolG=c`?o00004?oicLd3o`000>gooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Yoooool3o`0000?oP[6f1_l0
0006oiBZX0Go00002OnA]9`00ol0003oTKBLo`000002oi6dW005o`000?nA]9coTKBLoi6dW?l00000
2?nA]9`2o`0001OoV9WA0_l0000DojG5T0;o00005OnLZkP5o`0000?o^ln40ol00007oiEkV`03o`00
0?nENi_oUG^K00GoUG^K00?o0000oiEkVol000000onENi/00ol0003oUG^KoiEkV`0=oiEkV`;o0000
8?nB/Wd2o`0001ooaLg?0ol0000>ooW=c@?o0000k_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2Xooooo`So00002onDZZ05o`0000SoTKBL0_l00002oi6dW005o`000?nA
]9coTKBLoi6dW?l000002?nA]9`2o`0001;oV9WA1ol0000CojG5T0?o00005onLZkP8o`0000SoUG^K
00?o0000oiEkVonENi/00onENi/2o`0000;oUG^K1?l0000@oiEkV`;o00007_nB/Wd4o`0000WoaLg?
0ol00003olG=c`?o00000_o5cLl5o`0000OoaLg?0_l0000=ooW=c@?o0000koooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yooooo`Go00003onDZZ05o`0000OoTKBL00Co
0000oi6dW?nA]9coTKBL0ol00009oi6dW0?o00002OnHVM4@o`0001;oYLF@0_l0000Joib[^0Ko0000
2?nENi/00ol0003oUG^KoiEkV`05oiEkV`03o`000?nENi_o000001?oUG^K0ol0000Koi:bO@Go0000
2oo5cLl01Ol0003oaLg?olG=coo5cLoo000000?oaLg?00Co0000olG=coo5cLoo00000_o5cLl00ol0
003oaLg?olG=c`05olG=c`?o00002_oicLd4o`000?3ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Z_ooool2o`0001?oU:ZP1Ol0000Foi6dW0;o00000_nHVM4@o`0000Go
j??;0ol0000@ojG5T0?o00007OnLZkP2o`0000SoUG^K0_l00003oiEkV`05o`000?nENi_oUG^KoiEk
Vol000000_nENi/00ol0003oUG^KoiEkV`0AoiEkV`;o00006?nB/Wd9o`0000[oaLg?00Go0000olG=
coo5cLooaLg?o`000003olG=c`05o`000?o5cLooaLg?olG=col000002_o5cLl3o`0000SonLg=1?l0
003aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:[ooooo0_l0000E
oiBZX0Go00005?nA]9`<o`0000koj??;0ol0000?ojG5T0;o00007_nLZkP2o`0000WoUG^K00?o0000
oiEkVonENi/00_nENi/3o`0000CoUG^K0_l0000AoiEkV`;o00005_nB/Wd6o`0000?o/L720ol00009
olG=c`03o`000?o5cLooaLg?00;oaLg?0ol00005olG=c`03o`000?o5cLooaLg?00SoaLg?0ol00006
ooW=c@?o0000loooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Zoooo
o`;o00005onDZZ04o`0001?oTKBL1Ol0000FonScb`?o00003OnUaI03o`0001koW:^h0_l0000XoiEk
V`;o00005?nB/Wd5o`0000Oo/L720_l00009olG=c`05o`000?o5cLooaLg?olG=col000000oo5cLl0
0ol0003oaLg?o`000003olG=c`03o`000?o5cLooaLg?00SoaLg?0ol00004ooW=c@?o0000m?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Zooooo`;o00006OnDZZ04o`00
013oTKBL0ol0000JonScb`?o00003?nUaI02o`0001ooW:^h0_l0000XoiEkV`?o00004OnB/Wd5o`00
00Wo/L720ol00007olG=c`;o00000oo5cLl01ol0003oaLg?olG=coo5cLoo0000olG=col000000oo5
cLl00ol0003oaLg?olG=c`09olG=c`?o00000_oicLd3o`000?Gooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0Z_ooool2o`0001[oU:ZP1Ol0000>oi6dW0;o00007?oXll/3
o`0000[oYLF@0ol0000Ooib[^0;o0000:OnENi/2o`0000koT[9m1_l0000<ok71`P?o00001oo5cLl0
0ol0003oaLg?olG=c`02olG=c`?o00000oo5cLl3o`0000goaLg?1_l0003fooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0:Wooooo0ol0000LoiBZX0Go00002onA]9`3o`00
01goj??;0ol00009ojG5T0;o00001OnLZkP3o`0000CoW:^h0_l00003oib[^0?o00003?nLZkP2o`00
02WoUG^K0_l0000<oi:bO@Ko00003ona`L82o`0002?oaLg?1?l0003gooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0:Wooooo0_l0000OoiBZX0Go00002OnA]9`2o`0001oo
j??;0ol00007ojG5T0?o00001_nLZkP00ol0003oW:^hoib[^002oib[^006o`000?nLZkSoW:^ho`00
0?nLZkSo00000onLZkP00ol0003oW:^hoib[^009oib[^0;o0000:OnENi/3o`0000WoT[9m1Ol0000B
ok71`P?o00008_o5cLl3o`000?Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0ZOooool2o`0000WoU:ZP0ol000000onDZZ3o0000o`000003o`0000ooU:ZP1Ol00005oi6d
W0Co00008?oXll/3o`0000KoYLF@0_l00007oib[^003o`000?nLZkSoW:^h00;oW:^h00Co0000oib[
^?nLZkSo00001OnLZkP00ol0003oW:^hoib[^009oib[^2ko00001onB/Wd5o`0001Go/L720ol0000P
olG=c`Co0000n?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yoooo
o`;o00002_nDZZ001Ol0003oU:ZPoiBZX?nDZZ3o000000;oU:ZP00?o0000oiBZX?nDZZ003onDZZ0;
o`0002;oj??;0ol00004ojG5T0?o00001onLZkP00ol0003oW:^hoib[^002oib[^004o`000?nLZkSo
W:^ho`0000?oW:^h0_l0000<oib[^2oo00000onB/Wd6o`0001So/L720_l0000OolG=c`?o0000n_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yooooo`;o00001onDZZ05
o`0000?oU:ZP00?o0000oiBZX?nDZZ004onDZZ0:o`0002;oj??;0ol00003ojG5T0;o00002?nLZkP0
0ol0003oW:^hoib[^002oib[^004o`000?nLZkSoW:^ho`0000GoW:^h00?o0000oib[^?nLZkP02OnL
ZkP2o`0002_oW:nU2Ol0000Jok71`P?o00007?o5cLl4o`000?_ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0ZOooool2o`0000OoU:ZP00Co0000oiBZX?nDZZ3o00001OnD
ZZ000ol0003oU:ZPoiBZX00BoiBZX0Co00001?o7SJ`2o`0002?oj??;0ol000001?nUaI3o0000o`00
0?l00007oib[^0;o00001?nLZkP01_l0003oW:^hoib[^?l0003oW:^ho`0000?oW:^h00?o0000oib[
^?nLZkP02?nLZkP3o`0002coW:nU1Ol0000Nok71`P?o00006_o5cLl4o`000?cooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0ZOooool2o`0000SoU:ZP00?o0000oiBZX?l0
00000_nDZZ001Ol0003oU:ZPoiBZX?nDZZ3o000001;oU:ZP0ol00006olN=[0?o00008ooXll/5o`00
00WoW:^h00?o0000oib[^?nLZkP00onLZkP2o`0000?oW:^h0ol0000;oib[^0;o0000;_nL[jD2o`00
027o/L720ol0000HolG=c`?o0000o_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2Yooooo`?o00002?nDZZ02o`0000;oU:ZP00Go0000oiBZX?nDZZ3oU:ZPo`00000AoiBZ
X0?o00002?o7SJ`3o`0002?oj??;1?l0000Roib[^0;o0000;_nL[jD2o`0002;o/L720_l0000FolG=
c`Co0000ooooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Zooooo`?o
00002?nDZZ001?l0003oU:ZPoiBZX?nDZZ03o`00017oU:ZP0ol0000:olN=[0;o00004OoXll/00ol0
003oj??;onScb`03onScb`03o`000?oXll_oj??;00[oj??;0_l0000Roib[^0?o00002onL[jD3o`00
00?oW:nU0ol00004oib_Y@03o`000?nL[jGoW:nU01;oW:nU0ol0000Rok71`P?o00005?o5cLl4o`00
0?oooooo0Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2[ooooo`?o
00007_nDZZ03o`0000_oahf/0ol0000@onScb`03o`000?oXll_oj??;00?oj??;00?o0000onScbooX
ll/02_oXll/3o`0001goW:^h1_l0000=oib_Y@05o`000?nL[jGoW:nUoib_YOl000000onL[jD01Ol0
003oW:nUoib_YOnL[jGo000001?oW:nU0ol0000Tok71`P?o00004_o5cLl3o`000?oooooo0oooool0
0ol0003oooooooooo`08ooooo`006_ooool3o`000:cooooo0_l0000MoiBZX0?o00003Oo7SJ`2o`00
017oj??;00?o0000onScbooXll/00ooXll/00ol0003oj??;onScb`0:onScb`;o00005?nLZkP?o`00
00goW:nU00?o0000oib_YOnL[jD01OnL[jD00ol0003oW:nUoib_Y@02oib_Y@03o`000?nL[jGoW:nU
00ooW:nU1?l0000Uok71`P;o00004?o5cLl4o`000?oooooo0_ooool3o`0000[ooooo000Jooooo`03
o`000?oooooooooo0:cooooo0ol0000KoiBZX0?o00003_o7SJ`3o`00013oj??;00?o0000onScbooX
ll/00ooXll/00ol0003oj??;onScb`0:onScb`;o00003?nLZkPBo`0000?o^LJD0ol0000<oib_Y@03
o`000?nL[jGoW:nU00?oW:nU0_l00005oib_Y@03o`000?nL[jGoW:nU00goW:nU1ol0000Tok71`P?o
00003_o5cLl4o`000?oooooo1Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2]ooooo`?o00006OnDZZ03o`00013oahf/0_l0000AonScb`03o`000?oXll_oj??;00?oj??;
00?o0000onScbooXll/02OoXll/3o`0000;oW:^h4_l0000=okW6U0;o00003?nL[jD00ol0003oW:nU
oib_Y@05oib_Y@03o`000?nL[jGoW:nU00?oW:nU00?o0000oib_YOnL[jD02onL[jD4o`0000;oS::F
0ol0000Tok71`P?o00003?o5cLl3o`000?oooooo1oooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2^ooooo`?o00005onDZZ03o`00017oahf/0ol0000<onScb`07o`000?oX
ll_oj??;onScbol0003oj??;o`000003onScb`03o`000?oXll_oj??;00[oj??;3_l0000EokW6U0?o
00002_nL[jD2o`0000?oW:nU00Oo0000oib_YOnL[jGoW:nUo`000?nL[jGo000000?oW:nU00?o0000
oib_YOnL[jD02OnL[jD4o`0000GoS::F0_l0000<ok71`P?o00001?na`L800ol0003o/L72ok71`P02
ok71`P?o00002_na`L82o`0000[oaLg?1?l0003oooooo`Sooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0[oooool2o`0001KoU:ZP0ol0000ColN=[0?o00002ooXll/5o`00
0003onScbol0003o000000?o00003?oXll/5o`0001oo^LJD0_l0000;oib_Y@03o`000?nL[jGoW:nU
00;oW:nU0ol00002oib_Y@Go00002_nL[jD4o`0000KoS::F0ol0000<ok71`P03o`000?na`L;o/L72
00?o/L7200?o0000ok71`_na`L800ona`L800ol0003o/L72ok71`P09ok71`P?o00002?o5cLl4o`00
0?oooooo2Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2_ooooo`?o
00005?nDZZ03o`0001Goahf/0_l0000QonScb`?o00008_niaY@3o`00027oW:nU1?l00009ohbRUP?o
00002ona`L800ol0003o/L72ok71`P04ok71`P03o`000?na`L;o/L7200;o/L7200?o0000ok71`_na
`L802_na`L83o`0000KoaLg?0ol0003oooooo`_ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0/?ooool3o`0001;oU:ZP0ol0000FolN=[0?o00008?oXll/2o`0002Co^LJD
0_l0000Poib_Y@Co00002on<XYH2o`0000_o/L7200?o0000ok71`_na`L801?na`L800ol0003o/L72
ok71`P02ok71`P03o`000?na`L;o/L7200_o/L720_l00004olG=c`Co0000ooooool<ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;7ooooo0_l0000AoiBZX0?o00006?o7
SJ`2o`0001ooj??;0ol0000TokW6U0?o00007OnL[jD4o`0000goS::F0ol0000:ok71`P03o`000?na
`L;o/L7200Go/L7200Go0000ok71`_na`L;o/L72o`00000=ok71`P?o00000_o5cLl4o`000?oooooo
3Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2aooooo`?o00003onD
ZZ03o`0001Woahf/0ol0000NonScb`;o00009_niaY@2o`0001coW:nU1?l0000?ohbRUP?o00002?na
`L82o`0000?o/L7200Go0000ok71`_na`L;o/L72o`000002ok71`P;o00003_na`L86o`000?oooooo
3oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2booooo`?o00003OnD
ZZ03o`0001_oahf/0_l0000MonScb`?o00009_niaY@3o`0001WoW:nU1?l0000BohbRUP;o00002Ona
`L801?l0003o/L72ok71`_na`L85o`0000?o/L7200?o0000ok71`_na`L802ona`L86o`000?oooooo
4?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2cooooo`Co00002_nD
ZZ03o`0001coahf/0ol0000LonScb`;o0000:?niaY@2o`0001SoW:nU1?l0000CohbRUP?o00008?na
`L84o`000003ooooool0003o00000?oooooo4Oooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`2dooooo`Go00001onDZZ03o`0001koahf/0ol0000JonScb`?o0000:?niaY@3
o`0001KoW:nU0ol0000FohbRUP?o00007_na`L84o`000?oooooo5Oooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2fooooo`Ko00000onDZZ03o`0000coahf/0ol00003olN=
[0?o00002oo7SJ`2o`0001[oj??;0_l0000ZokW6U0;o00005?nL[jD4o`0001SoS::F0_l0000Lok71
`PCo0000oooooolGooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;So
oooo2Ol0000<olN=[007o`000?o7SJcoahf/olN=[?l0003oahf/o`000003olN=[003o`000?o7SJco
ahf/00Soahf/7_l0000ZokW6U0Co00004OnL[jD4o`0001WoS::F0ol0000Jok71`PCo0000oooooolH
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;_ooooo1Ol0000AolN=
[003o`000?o7SJco000000?oahf/00?o0000olN=[?o7SJ`02Oo7SJ`Lo`0002[o^LJD1_l0000>oib_
Y@Co00007?n<XYH2o`0001So/L721?l0003ooooooa[ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0_Oooool2o`0001;oahf/00?o0000olN=[?o7SJ`00ol0000;olN=[0?o
00006?oN`ZD2o`0002Wo^LJD0ol00002oloRf`Co00002onL[jD4o`0001goS::F0ol0000Eok71`PGo
0000oooooolKooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;gooooo
0ol0000=olN=[0Co00000_o7SJ`01Ol0003oahf/olN=[?o7SJco000000[oahf/0_l0000Iomk2Y@?o
00009oniaY@3o`0000Cocn;K1?l00008oib_Y@Co00008?n<XYH3o`0001?o/L721?l0003ooooooago
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool2o`0000goahf/
00?o0000olN=[?o7SJ`00oo7SJ`01Ol0003oahf/olN=[?o7SJco000000Woahf/0ol0000Jomk2Y@;o
00009OniaY@4o`0000Oocn;K0ol00006oib_Y@Co00008_n<XYH2o`00017o/L721?l0003ooooooaoo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool3o`0000coahf/
1Ol00002olN=[0?o00002_o7SJ`2o`0001_og/:U0_l0000TokW6U0Co00002Oo?h]/4o`0000;oW:nU
1?l0000TohbRUP?o00003ona`L84o`000?oooooo8?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`2oooooo`;o00007oo7SJ`3o`0001_og/:U0ol00004okW6U0?o00001?ni
aY@2o`0000Co^LJD00?o0000okW6U?niaY@03_niaY@3o`0000cocn;K2?l0000>ohbRUP?o00000on<
XYH3o`0000CoS::F0_l00009ohbRUP?o00003?na`L84o`000?oooooo8_ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2oooooo`;o00007_o7SJ`3o`0001gog/:U0_l00005
okW6U003o`000?niaYCo^LJD00;o^LJD00Co0000okW6U?niaYCo00000oniaY@00ol0003o^LJDokW6
U00=okW6U0?o00003oo?h]/4o`00017oS::F00Go0000ohbRU_n<XYKoS::Fo`000003ohbRUP04o`00
0?n<XYKoS::Fo`0000;oS::F00?o0000ohbRU_n<XYH01on<XYH2o`0000_o/L721?l0003oooooob?o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0_oooool3o`0001goahf/
0_l0000Nomk2Y@;o00001OniaY@00ol0003o^LJDokW6U002okW6U004o`000?niaYCo^LJDo`0000Co
^LJD00?o0000okW6U?niaY@02_niaY@4o`00017ocn;K0_l0000BohbRUP03o`000?n<XYKoS::F00Go
S::F00Co0000ohbRU_n<XYKo00000_n<XYH00ol0003oS::FohbRUP07ohbRUP?o00001?na`L88o`00
0?oooooo9Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`30ooooo`;o
00007?o7SJ`3o`0001kog/:U0_l00005okW6U003o`000?niaYCo^LJD00;o^LJD00Co0000okW6U?ni
aYCo00001?niaY@00ol0003o^LJDokW6U009okW6U0Co00004_o?h]/3o`00017oS::F00?o0000ohbR
U_n<XYH01On<XYH01?l0003oS::FohbRU_l00002ohbRUP03o`000?n<XYKoS::F00SoS::F3Ol0003o
ooooobKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0`?ooool4o`00
01[oahf/0_l0000Oomk2Y@?o00001?niaY@00ol0003o^LJDokW6U002okW6U004o`000?niaYCo^LJD
o`0000Go^LJD00?o0000okW6U?niaY@01oniaY@3o`0001Gocn;K0_l0000AohbRUP04o`000?n<XYKo
S::FohbRUPCo00000on<XYH01?l0003oS::FohbRU_l0000;ohbRUPKo0000ooooool/ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<7ooooo1?l0000HolN=[0?o00008?oN
`ZD2o`0000?o^LJD0_l00004okW6U006o`000?niaYCo^LJDo`000?niaYCo00000oniaY@00ol0003o
^LJDokW6U006okW6U0?o00005_o?h]/2o`00013oS::F0_l00003ohbRUP03o`000?n<XYKoS::F00Co
S::F00Co0000ohbRU_n<XYKo00002_n<XYH3o`000?oooooo<?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`33ooooo`?o00005oo7SJ`2o`00027og/:U0_l00004okW6U003
o`000?niaYCo^LJD00?o^LJD0_l00002okW6U0Go00001_niaY@4o`0001Oocn;K0ol0000@ohbRUP04
o`000?n<XYKoS::FohbRUPGo00000on<XYH2o`0000[oS::F0ol0003ooooooc7ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0a?ooool4o`0001Coahf/0ol0000Qomk2Y@?o
00005oniaY@4o`0001Wocn;K0_l0000XohbRUP;o0000oooooolbooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo0<Gooooo1?l0000ColN=[0;o00003_oN`ZD00ol0003og/:U
omk2Y@02omk2Y@?o00003OoN`ZD2o`0001Ko^LJD0ol0000KoloRf`;o00009on<XYH3o`000?oooooo
<_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`37ooooo`?o00004Oo7
SJ`3o`0000kog/:U00Go0000omk2YOoN`ZGog/:Uo`000003omk2Y@03o`000?oN`ZGog/:U00[og/:U
0_l0000EokW6U0?o00007?o?h]/3o`0002GoS::F0ol0003ooooooc?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0b?ooool4o`0000koahf/0ol0000@omk2Y@04o`000?oN
`ZGog/:Uo`0000?og/:U00?o0000omk2YOoN`ZD02_oN`ZD2o`0001Co^LJD0ol0000NoloRf`;o0000
9On<XYH2o`000?oooooo=?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`39ooooo`Co00003Oo7SJ`2o`00017og/:U00Co0000omk2YOoN`ZGog/:U0ol0000=omk2Y@?o0000
4OniaY@4o`0001oocn;K0_l0000TohbRUP?o0000ooooooldooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0<_ooooo0ol0000;olN=[0?o00004_oN`ZD00ol0003og/:Uo`00
0003omk2Y@03o`000?oN`ZGog/:U00_og/:U0_l0000@okW6U0Co00008?o?h]/3o`0002?oS::F0_l0
003oooooocGooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0c?ooool9
o`0000Coahf/0_l0000?omk2Y@07o`000?oN`ZGog/:Uomk2YOl0003og/:Uo`000003omk2Y@03o`00
0?oN`ZGog/:U00_og/:U0_l0000?okW6U0?o00008oo?h]/2o`0002;oS::F0ol0003oooooocGooooo
00?o0000ooooooooool02?ooool001[ooooo0ol0003=ooooo`ko00003ooN`ZD5o`0000;og/:U0ol0
000>omk2Y@?o00003OniaY@3o`0002Cocn;K0_l0000PohbRUPCo0000ooooooldooooo`?o00002_oo
ool001[ooooo00?o0000ooooooooool0e?ooool6o`0002Wog/:U0_l0000;okW6U0Co00009Oo?h]/3
o`0001goS::F1Ol0003oooooocOooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0f?ooool3o`0002Sog/:U0_l0000:okW6U0Co00009oo?h]/2o`0001_oS::F1Ol0003ooooo
ocWooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0fOooool3o`0002Oo
g/:U0_l00009okW6U0?o0000:Oo?h]/2o`0001WoS::F1Ol0003ooooooc_ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0f_ooool3o`0002Kog/:U0ol00007okW6U0?o0000
4Oo?h]/3o`0000;ocn;K1Ol000000oo?h]_o0000o`000003o`0000Wocn;K0ol0000FohbRUPGo0000
oooooolmooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0=_ooooo0ol0
000Vomk2Y@;o00001OniaY@4o`0001?ocn;K00?o0000oloRfoo?h]/00_o?h]/01?l0003ocn;KoloR
fol00002oloRf`04o`000?o?h]_ocn;Ko`0000[ocn;K1ol0000?ohbRUPGo0000ooooooloooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0=cooooo0_l0000Vomk2Y@;o0000
1?niaY@4o`0001Cocn;K00?o0000oloRfoo?h]/00oo?h]/00ol0003ocn;KoloRf`03oloRf`03o`00
0?o?h]_ocn;K00[ocn;K4?l00004ohbRUPGo0000oooooom1ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0=cooooo0ol0000Uomk2Y@?o00000_niaY@3o`0001Kocn;K00?o
0000oloRfoo?h]/01?o?h]/00ol0003ocn;KoloRf`03oloRf`03o`000?o?h]_ocn;K00Socn;K0ol0
0004oooooa7o0000oooooom3ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0=gooooo0ol0000Somk2Y@So00005oo?h]/01Ol0003ocn;KoloRfoo?h]_o000000?ocn;K00?o
0000oloRfol000000oo?h]/00ol0003ocn;KoloRf`06oloRf`?o00003_ooool6o`000?ooooooAOoo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Nooooo`?o00007ooN`ZD:
o`0001Oocn;K0_l00003oloRf`07o`000?o?h]_ocn;KoloRfol0003ocn;Ko`000003oloRf`03o`00
0?o?h]_ocn;K00Gocn;K1?l0003ooooooeWooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0goooool5o`0001Wog/:U1ol00003ooooo`Go00005_o?h]/00ol0003ocn;KoloR
f`02oloRf`?o00000oo?h]/3o`0000Oocn;K0ol0003ooooooe_ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0h?ooool7o`0001?og/:U1ol00008ooooo`Go00009oo?h]/4
o`000?ooooooG?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Soooo
o`Oo00003OoN`ZD7o`0000gooooo1?l0000UoloRf`Co0000oooooomMooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0>Kooooo1ol00007omk2Y@Oo00004_ooool4o`0002;o
cn;K0ol0003ooooooeoooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
jOooool7o`000003omk2YOl0003o000000Go00005_ooool5o`0001kocn;K1?l0003oooooof3ooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0k?ooool9o`0001_ooooo1Ol0
000KoloRf`Co0000oooooomQooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0>oooooo0ol0000Pooooo`Go00006?o?h]/3o`000?ooooooHoooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`3ooooooaGooooo1Ol0000DoloRf`Co0000oooooomToooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?oooooo5oooool4o`0001;o
cn;K1?l0003oooooofGooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
oooooolIooooo`Co00003oo?h]/3o`000?ooooooIoooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`3ooooooa[ooooo1Ol00006oloRf`Wo0000oooooomXooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?oooooo7?oooolAo`000?ooooooJOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3ooooooakooooo2?l0003ooooo
og3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`08ooooo`0000Coooooo`000?l0003o00000_ooool5o`0000?ooooo0_l0
000:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`08ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02?ooool000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Woooooool0003oo`0009[o00002_ooool000;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
oooooooooooooj_ooooo0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo0?oooooooooooon[ooooo`0000?oooooo`000?l00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000oooooooooooo
ojgooooo0002ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o0000ooooooooooooojko
oooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooo
oooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 699}, {699, 0}} -> {16.0374, 16.3764, 0.150671, \
0.150671}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Identify and Mark the L1 Layer", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sc = 
      surfaceCells /. 
        boundedCellVoronoi[xymeristem, \ 
          surfaceCells \[Rule] \ True]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 6, 10, 12, 15, 16, 19, 20, 21, 30, 36, 42, 50, 58, 78, 82, 
      107, 113, 122, 134, 150, 152, 171, 178, 182, 200, 203, 211, 214, 216, 
      217, 219, 221, 234, 237, 244, 245, 246, 248, 249, 250, 251, 252, 
      253}\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(markColor[i_] := 
        If[MemberQ[sc, i], White, rc];\)\), "\[IndentingNewLine]", 
    \(\(rcs = markColor /@ Range[n];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(visualization[cellCoordinates \[Rule] \ xymeristem, 
      cellColors \[Rule] \ rcs, \ ImageSize \[Rule] \ 700, 
      Frame \[Rule] \ True, PlotRange \[Rule] \ {{20, 120}, {20, 120}}, 
      AspecRatio \[Rule] \ 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 700 700 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.2 0.01 -0.2 0.01 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .2 -12 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -12 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -12 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(40)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(80)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(100)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(120)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(40)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(60)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(80)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(100)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(120)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.2 .99375 m
.2 1 L
s
.4 .99375 m
.4 1 L
s
.6 .99375 m
.6 1 L
s
.8 .99375 m
.8 1 L
s
.125 Mabswid
.05 .99625 m
.05 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.25 .99625 m
.25 1 L
s
.3 .99625 m
.3 1 L
s
.35 .99625 m
.35 1 L
s
.45 .99625 m
.45 1 L
s
.5 .99625 m
.5 1 L
s
.55 .99625 m
.55 1 L
s
.65 .99625 m
.65 1 L
s
.7 .99625 m
.7 1 L
s
.75 .99625 m
.75 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .2 m
1 .2 L
s
.99375 .4 m
1 .4 L
s
.99375 .6 m
1 .6 L
s
.99375 .8 m
1 .8 L
s
.125 Mabswid
.99625 .05 m
1 .05 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .25 m
1 .25 L
s
.99625 .3 m
1 .3 L
s
.99625 .35 m
1 .35 L
s
.99625 .45 m
1 .45 L
s
.99625 .5 m
1 .5 L
s
.99625 .55 m
1 .55 L
s
.99625 .65 m
1 .65 L
s
.99625 .7 m
1 .7 L
s
.99625 .75 m
1 .75 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .95 m
1 .95 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
F
0 g
.004 w
.17204 .37189 m
.13144 .38349 L
.12002 .37167 L
.12207 .34461 L
.13721 .32629 L
.17871 .34185 L
.17204 .37189 L
s
1 g
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
F
0 g
.18715 .39305 m
.15421 .42599 L
.14389 .42828 L
.1325 .41744 L
.13144 .38349 L
.17204 .37189 L
.18715 .39305 L
s
1 g
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
F
0 g
.17871 .34185 m
.13721 .32629 L
.13497 .31406 L
.146 .28712 L
.1595 .27652 L
.17048 .2814 L
.18469 .33827 L
.17871 .34185 L
s
1 g
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
F
0 g
.16718 .49319 m
.14133 .46397 L
.14389 .42828 L
.15421 .42599 L
.19321 .44158 L
.17797 .4873 L
.16718 .49319 L
s
.222 .288 .052 .24 k
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
F
0 g
.2031 .39837 m
.2031 .43593 L
.19321 .44158 L
.15421 .42599 L
.18715 .39305 L
.2031 .39837 L
s
1 g
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
F
0 g
.22129 .25583 m
.21391 .23737 L
.1894 .22103 L
.17255 .22947 L
.15825 .25977 L
.1595 .27652 L
.17048 .2814 L
.18932 .2814 L
.22129 .25583 L
s
.091 .175 .259 .161 k
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
F
0 g
.21387 .31413 m
.19086 .33714 L
.18469 .33827 L
.17048 .2814 L
.18932 .2814 L
.21387 .31413 L
s
.257 .005 .206 .293 k
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
F
0 g
.22184 .36193 m
.19086 .33714 L
.18469 .33827 L
.17871 .34185 L
.17204 .37189 L
.18715 .39305 L
.2031 .39837 L
.21755 .39194 L
.22184 .36193 L
s
.237 .063 .237 .045 k
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
F
0 g
.23094 .44786 m
.23326 .46874 L
.2147 .4873 L
.17797 .4873 L
.19321 .44158 L
.2031 .43593 L
.23094 .44786 L
s
1 g
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
F
0 g
.21528 .56284 m
.23278 .52346 L
.2147 .4873 L
.17797 .4873 L
.16718 .49319 L
.16337 .50777 L
.17875 .55295 L
.19741 .56955 L
.21528 .56284 L
s
.243 .158 .3 .09 k
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
F
0 g
.22746 .25994 m
.22129 .25583 L
.18932 .2814 L
.21387 .31413 L
.22915 .31073 L
.23251 .2872 L
.22879 .2611 L
.22746 .25994 L
s
1 g
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.19218 .19387 L
.1894 .22103 L
.21391 .23737 L
.26239 .19859 L
.25762 .19382 L
.20607 .17909 L
s
.032 .022 .103 .196 k
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
F
0 g
.26524 .34023 m
.2595 .3297 L
.22915 .31073 L
.21387 .31413 L
.19086 .33714 L
.22184 .36193 L
.26524 .34023 L
s
.11 .035 .051 .256 k
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
F
0 g
.21755 .39194 m
.2031 .39837 L
.2031 .43593 L
.23094 .44786 L
.25182 .42698 L
.25218 .42618 L
.21818 .39218 L
.21755 .39194 L
s
1 g
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.19912 .74217 L
.20276 .69305 L
.20463 .69058 L
.24362 .69767 L
.26001 .7164 L
.2471 .75082 L
.23003 .76363 L
s
1 g
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
F
0 g
.20607 .17909 m
.25762 .19382 L
.24808 .1366 L
.22679 .13575 L
.20687 .15566 L
.20607 .17909 L
s
.019 .16 .091 .095 k
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.27792 .34868 L
.26524 .34023 L
.22184 .36193 L
.21755 .39194 L
.21818 .39218 L
.28288 .37601 L
.28513 .3655 L
s
.062 .156 .185 .102 k
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
F
0 g
.23278 .52346 m
.26336 .51036 L
.2495 .4757 L
.23326 .46874 L
.2147 .4873 L
.23278 .52346 L
s
1 g
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
F
0 g
.26532 .61516 m
.25856 .59152 L
.22796 .56601 L
.21528 .56284 L
.19741 .56955 L
.19098 .59877 L
.20117 .6352 L
.2553 .6352 L
.26532 .61516 L
s
1 g
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
F
0 g
.27116 .65635 m
.24362 .69767 L
.20463 .69058 L
.19718 .64585 L
.20117 .6352 L
.2553 .6352 L
.27116 .65635 L
s
1 g
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.21943 .76539 L
.20878 .78853 L
.22154 .82244 L
.24132 .83346 L
.27234 .8102 L
.27347 .80707 L
.23003 .76363 L
s
.125 .093 .248 .057 k
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
F
0 g
.264 .2002 m
.26239 .19859 L
.21391 .23737 L
.22129 .25583 L
.22746 .25994 L
.264 .2234 L
.264 .2002 L
s
.182 .234 .249 .267 k
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
F
0 g
.28288 .37601 m
.28505 .4042 L
.28327 .40674 L
.25218 .42618 L
.21818 .39218 L
.28288 .37601 L
s
.151 .212 .146 .071 k
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.22746 .25994 L
.264 .2234 L
.27154 .2611 L
s
.041 .177 .095 .115 k
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
F
0 g
.27154 .2611 m
.22879 .2611 L
.23251 .2872 L
.27367 .2872 L
.28532 .26971 L
.27154 .2611 L
s
.022 .017 .004 .019 k
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
F
0 g
.22915 .31073 m
.2595 .3297 L
.27367 .2872 L
.23251 .2872 L
.22915 .31073 L
s
.26 .161 .119 .218 k
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
F
0 g
.25182 .42698 m
.27697 .46471 L
.2495 .4757 L
.23326 .46874 L
.23094 .44786 L
.25182 .42698 L
s
.134 .069 .17 .16 k
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
F
0 g
.2785 .54917 m
.22796 .56601 L
.21528 .56284 L
.23278 .52346 L
.26336 .51036 L
.2785 .51372 L
.2785 .54917 L
s
.252 .134 .221 .194 k
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
F
0 g
.23003 .76363 m
.27347 .80707 L
.28008 .80129 L
.29411 .78259 L
.29276 .76908 L
.2471 .75082 L
.23003 .76363 L
s
1 g
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
F
0 g
.25762 .19382 m
.26239 .19859 L
.29834 .15365 L
.27949 .12349 L
.27086 .12258 L
.24808 .1366 L
.25762 .19382 L
s
.101 .222 .076 .123 k
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
F
0 g
.29138 .50657 m
.2785 .51372 L
.26336 .51036 L
.2495 .4757 L
.27697 .46471 L
.28458 .4658 L
.29138 .50657 L
s
.06 .045 .28 .009 k
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
F
0 g
.30279 .56941 m
.25856 .59152 L
.22796 .56601 L
.2785 .54917 L
.30279 .56941 L
s
.039 .028 .276 .289 k
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.25218 .42618 L
.25182 .42698 L
.27697 .46471 L
.28458 .4658 L
.29358 .4583 L
s
.079 .167 .158 .072 k
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
F
0 g
.28623 .65937 m
.28969 .6642 L
.29188 .66933 L
.26835 .7164 L
.26001 .7164 L
.24362 .69767 L
.27116 .65635 L
.28623 .65937 L
s
.245 .098 .288 .211 k
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
F
0 g
.2471 .75082 m
.26001 .7164 L
.26835 .7164 L
.29677 .72272 L
.30579 .74301 L
.29276 .76908 L
.2471 .75082 L
s
1 g
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.27234 .8102 L
.24132 .83346 L
.2441 .85637 L
.26238 .87542 L
.27933 .86906 L
s
.293 .264 .066 .017 k
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27154 .2611 L
.264 .2234 L
.264 .2002 L
.31085 .21582 L
.29763 .26869 L
s
.191 .042 .291 .194 k
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
F
0 g
.29909 .60953 m
.30959 .57279 L
.30904 .57128 L
.30279 .56941 L
.25856 .59152 L
.26532 .61516 L
.29909 .60953 L
s
.131 .296 .01 .186 k
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
F
0 g
.29763 .26869 m
.28532 .26971 L
.27367 .2872 L
.2595 .3297 L
.26524 .34023 L
.27792 .34868 L
.3249 .3017 L
.3105 .2777 L
.29763 .26869 L
s
.092 .268 .034 .197 k
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.28623 .65937 L
.27116 .65635 L
.2553 .6352 L
.26532 .61516 L
.29909 .60953 L
.31388 .63172 L
s
.013 .101 .176 .125 k
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
F
0 g
.26835 .7164 m
.29188 .66933 L
.31461 .69774 L
.29677 .72272 L
.26835 .7164 L
s
1 g
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.322 .8904 L
.29154 .92086 L
.2779 .9148 L
.26151 .89319 L
.26238 .87542 L
.27933 .86906 L
s
.069 .003 .188 .214 k
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.32565 .20909 L
.31085 .21582 L
.264 .2002 L
.26239 .19859 L
.29834 .15365 L
.31066 .15775 L
s
.076 .04 .122 .196 k
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
F
0 g
.31547 .5627 m
.30904 .57128 L
.30279 .56941 L
.2785 .54917 L
.2785 .51372 L
.29138 .50657 L
.29865 .50729 L
.32014 .55027 L
.31547 .5627 L
s
.184 .298 .131 .002 k
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
F
0 g
.29358 .4583 m
.28327 .40674 L
.28505 .4042 L
.33758 .4239 L
.3307 .4583 L
.29358 .4583 L
s
.053 .002 .121 .116 k
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3307 .4583 L
.29358 .4583 L
.28458 .4658 L
.29138 .50657 L
.29865 .50729 L
.3245 .4976 L
.32708 .4873 L
s
.261 .034 .087 .219 k
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
F
0 g
.27347 .80707 m
.27234 .8102 L
.29938 .844 L
.31427 .844 L
.32708 .82479 L
.28008 .80129 L
.27347 .80707 L
s
.248 .232 .211 .095 k
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
F
0 g
.27933 .86906 m
.29938 .844 L
.31427 .844 L
.33312 .87228 L
.33472 .87947 L
.3307 .8875 L
.322 .8904 L
.27933 .86906 L
s
.179 .229 .022 .181 k
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
F
0 g
.29411 .78259 m
.33517 .79432 L
.33758 .81603 L
.32708 .82479 L
.28008 .80129 L
.29411 .78259 L
s
1 g
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.34291 .10938 L
.33638 .09849 L
.30899 .09784 L
.27949 .12349 L
.29834 .15365 L
.31066 .15775 L
s
.104 .189 .2 .285 k
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
F
0 g
.31388 .63172 m
.33215 .63375 L
.3452 .6468 L
.34708 .65149 L
.33981 .6642 L
.28969 .6642 L
.28623 .65937 L
.31388 .63172 L
s
.219 .191 .069 .283 k
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
F
0 g
.29188 .66933 m
.28969 .6642 L
.33981 .6642 L
.33129 .69404 L
.31461 .69774 L
.29188 .66933 L
s
.166 .189 .248 .167 k
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.34665 .35535 L
.32925 .30315 L
.3249 .3017 L
.27792 .34868 L
.28513 .3655 L
s
.205 .155 .162 .248 k
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
F
0 g
.28513 .3655 m
.3365 .3655 L
.35059 .4148 L
.33758 .4239 L
.28505 .4042 L
.28288 .37601 L
.28513 .3655 L
s
.257 .223 .251 .153 k
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
F
0 g
.32014 .55027 m
.29865 .50729 L
.3245 .4976 L
.35176 .52032 L
.35125 .52538 L
.32014 .55027 L
s
.077 .295 .229 .272 k
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.30959 .57279 L
.29909 .60953 L
.31388 .63172 L
.33215 .63375 L
.3365 .6207 L
.32366 .58217 L
s
.274 .106 .028 .287 k
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
F
0 g
.3452 .7512 m
.34407 .7478 L
.30579 .74301 L
.29276 .76908 L
.29411 .78259 L
.33517 .79432 L
.3452 .78262 L
.3452 .7512 L
s
1 g
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
F
0 g
.34893 .9194 m
.3307 .8875 L
.322 .8904 L
.29154 .92086 L
.2975 .93438 L
.31556 .94817 L
.33175 .94947 L
.34893 .9194 L
s
.055 .215 .259 .004 k
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.34306 .21344 L
.32565 .20909 L
.31085 .21582 L
.29763 .26869 L
.3105 .2777 L
.35804 .24204 L
.35179 .2212 L
s
.189 .026 .011 .137 k
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
F
0 g
.35728 .72666 m
.3437 .7029 L
.33129 .69404 L
.31461 .69774 L
.29677 .72272 L
.30579 .74301 L
.34407 .7478 L
.35728 .72666 L
s
.284 .171 .149 .189 k
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
F
0 g
.31066 .15775 m
.32026 .16598 L
.36926 .14965 L
.36901 .14663 L
.36015 .12447 L
.34291 .10938 L
.31066 .15775 L
s
.028 .248 .198 .035 k
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
F
0 g
.32366 .58217 m
.35153 .58775 L
.35825 .59895 L
.3365 .6207 L
.32366 .58217 L
s
.25 .253 .27 .063 k
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
F
0 g
.31427 .844 m
.32708 .82479 L
.33758 .81603 L
.3615 .8297 L
.33312 .87228 L
.31427 .844 L
s
.276 .147 .241 .075 k
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
F
0 g
.34306 .21344 m
.37576 .15893 L
.36926 .14965 L
.32026 .16598 L
.32565 .20909 L
.34306 .21344 L
s
.222 .232 .282 .071 k
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
F
0 g
.3709 .29482 m
.32925 .30315 L
.3249 .3017 L
.3105 .2777 L
.35804 .24204 L
.3829 .2669 L
.38533 .2742 L
.3709 .29482 L
s
.032 .205 .271 .234 k
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.31547 .5627 L
.32014 .55027 L
.35125 .52538 L
.36956 .55284 L
.3707 .55738 L
.36405 .5627 L
s
.048 .035 .121 .046 k
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.32366 .58217 L
.30959 .57279 L
.30904 .57128 L
.31547 .5627 L
.36405 .5627 L
s
.02 .087 .223 .01 k
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
F
0 g
.32708 .4873 m
.3742 .4873 L
.3742 .4728 L
.3307 .4583 L
.32708 .4873 L
s
.07 .134 .254 .248 k
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
F
0 g
.37546 .50339 m
.35176 .52032 L
.3245 .4976 L
.32708 .4873 L
.3742 .4873 L
.37594 .50122 L
.37546 .50339 L
s
.094 .287 .012 .172 k
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
F
0 g
.38712 .33808 m
.37275 .35245 L
.34665 .35535 L
.32925 .30315 L
.3709 .29482 L
.38712 .33808 L
s
.172 .055 .031 .101 k
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
F
0 g
.3365 .6207 m
.33215 .63375 L
.3452 .6468 L
.38435 .60765 L
.35825 .59895 L
.3365 .6207 L
s
.14 .15 .06 .167 k
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
F
0 g
.34708 .65149 m
.3858 .66601 L
.3858 .67483 L
.3437 .7029 L
.33129 .69404 L
.33981 .6642 L
.34708 .65149 L
s
.092 .115 .238 .121 k
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
F
0 g
.36985 .87445 m
.38394 .83219 L
.3615 .8297 L
.33312 .87228 L
.33472 .87947 L
.36985 .87445 L
s
.071 .028 .015 .111 k
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
F
0 g
.37275 .35245 m
.34665 .35535 L
.3365 .3655 L
.35059 .4148 L
.3568 .4148 L
.38647 .39361 L
.37275 .35245 L
s
.001 .194 .062 .163 k
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
F
0 g
.3307 .4583 m
.33758 .4239 L
.35059 .4148 L
.3568 .4148 L
.3945 .4525 L
.3742 .4728 L
.3307 .4583 L
s
.208 .207 .049 .291 k
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
F
0 g
.37676 .78788 m
.39053 .82919 L
.38394 .83219 L
.3615 .8297 L
.33758 .81603 L
.33517 .79432 L
.3452 .78262 L
.37676 .78788 L
s
.035 .152 .019 .19 k
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.3916 .8962 L
.36985 .87445 L
.33472 .87947 L
.3307 .8875 L
.34893 .9194 L
.38725 .9194 L
s
1 g
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.34893 .9194 L
.33175 .94947 L
.34318 .96425 L
.3658 .97201 L
.39984 .96136 L
.38725 .9194 L
s
.195 .002 .259 .023 k
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
F
0 g
.36405 .5627 m
.35153 .58775 L
.35825 .59895 L
.38435 .60765 L
.38532 .60754 L
.38931 .60116 L
.38321 .56453 L
.3707 .55738 L
.36405 .5627 L
s
.104 .187 .02 .201 k
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
F
0 g
.36086 .72626 m
.35728 .72666 L
.3437 .7029 L
.3858 .67483 L
.39727 .70543 L
.39613 .71114 L
.36086 .72626 L
s
.032 .158 .005 .091 k
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
F
0 g
.39328 .76723 m
.3452 .7512 L
.3452 .78262 L
.37676 .78788 L
.39328 .76723 L
s
1 g
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
F
0 g
.34291 .10938 m
.36015 .12447 L
.409 .08782 L
.409 .07664 L
.38176 .06529 L
.34853 .07587 L
.33638 .09849 L
.34291 .10938 L
s
.031 .264 .243 .228 k
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.42582 .19614 L
.4177 .1799 L
.37576 .15893 L
.34306 .21344 L
.35179 .2212 L
s
.123 .057 .194 .237 k
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
F
0 g
.3452 .6468 m
.34708 .65149 L
.3858 .66601 L
.39586 .65721 L
.40244 .63749 L
.38532 .60754 L
.38435 .60765 L
.3452 .6468 L
s
.088 .205 .176 .047 k
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
F
0 g
.39872 .76412 m
.39328 .76723 L
.3452 .7512 L
.34407 .7478 L
.35728 .72666 L
.36086 .72626 L
.39872 .76412 L
s
.193 .203 .217 .025 k
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
F
0 g
.36956 .55284 m
.39958 .52283 L
.39955 .52266 L
.37546 .50339 L
.35176 .52032 L
.35125 .52538 L
.36956 .55284 L
s
.089 .016 .197 .123 k
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
F
0 g
.35179 .2212 m
.42495 .19682 L
.3829 .2669 L
.35804 .24204 L
.35179 .2212 L
s
.057 .158 .192 .032 k
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.41144 .73258 L
.39613 .71114 L
.36086 .72626 L
.39872 .76412 L
.41427 .76066 L
.41452 .7603 L
s
.026 .194 .248 .105 k
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
F
0 g
.409 .08782 m
.42002 .11262 L
.36901 .14663 L
.36015 .12447 L
.409 .08782 L
s
.203 .137 .054 .168 k
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
F
0 g
.39584 .39465 m
.38647 .39361 L
.3568 .4148 L
.3945 .4525 L
.41823 .42403 L
.42024 .41498 L
.39584 .39465 L
s
.115 .232 .179 .121 k
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
F
0 g
.3707 .55738 m
.38321 .56453 L
.41654 .55342 L
.41692 .55173 L
.39958 .52283 L
.36956 .55284 L
.3707 .55738 L
s
.222 .029 .262 .096 k
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.3945 .8295 L
.39053 .82919 L
.38394 .83219 L
.36985 .87445 L
.3916 .8962 L
s
.133 .013 .065 .273 k
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.39239 .33861 L
.38712 .33808 L
.37275 .35245 L
.38647 .39361 L
.39584 .39465 L
.42205 .3597 L
s
.076 .155 .173 .241 k
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
F
0 g
.37594 .50122 m
.3742 .4873 L
.3742 .4728 L
.3945 .4525 L
.41981 .47359 L
.42414 .48515 L
.37594 .50122 L
s
.05 .261 .225 .136 k
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
F
0 g
.41427 .76066 m
.42567 .8063 L
.41383 .81983 L
.3945 .8295 L
.39053 .82919 L
.37676 .78788 L
.39328 .76723 L
.39872 .76412 L
.41427 .76066 L
s
.147 .123 .17 .268 k
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
F
0 g
.4177 .1799 m
.43357 .13228 L
.43096 .12356 L
.42002 .11262 L
.36901 .14663 L
.36926 .14965 L
.37576 .15893 L
.4177 .1799 L
s
.033 .191 .292 .147 k
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.4293 .3017 L
.42238 .28093 L
.38533 .2742 L
.3709 .29482 L
.38712 .33808 L
.39239 .33861 L
s
.11 .162 .03 .051 k
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.42414 .48515 L
.37594 .50122 L
.37546 .50339 L
.39955 .52266 L
.43381 .49697 L
.43394 .49658 L
s
.277 .148 .265 .078 k
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.38321 .56453 L
.38931 .60116 L
.42157 .59041 L
.42847 .5743 L
.41654 .55342 L
s
.201 .293 .092 .137 k
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
F
0 g
.38533 .2742 m
.3829 .2669 L
.42495 .19682 L
.42582 .19614 L
.42816 .19716 L
.4293 .19896 L
.4293 .27487 L
.42238 .28093 L
.38533 .2742 L
s
.151 .033 .167 .001 k
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
F
0 g
.42157 .59041 m
.44012 .62133 L
.43884 .62709 L
.40244 .63749 L
.38532 .60754 L
.38931 .60116 L
.42157 .59041 L
s
.003 .209 .297 .033 k
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
F
0 g
.3858 .67483 m
.3858 .66601 L
.39586 .65721 L
.43924 .67456 L
.43739 .68938 L
.39727 .70543 L
.3858 .67483 L
s
.271 .018 .006 .186 k
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
F
0 g
.3916 .8962 m
.40972 .85995 L
.4496 .8759 L
.4496 .8875 L
.44689 .89835 L
.3945 .9049 L
.3916 .8962 L
s
.16 .157 .276 .136 k
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
F
0 g
.39239 .33861 m
.42253 .35583 L
.44049 .34686 L
.4409 .3452 L
.4409 .3133 L
.4293 .3017 L
.39239 .33861 L
s
.183 .008 .011 .058 k
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.4438 .4032 L
.42024 .41498 L
.39584 .39465 L
.42205 .3597 L
s
.282 .015 .219 .221 k
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
F
0 g
.43381 .49697 m
.43988 .53336 L
.41692 .55173 L
.39958 .52283 L
.39955 .52266 L
.43381 .49697 L
s
1 g
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
F
0 g
.38725 .9194 m
.3945 .9049 L
.44689 .89835 L
.45675 .92006 L
.40325 .96286 L
.4024 .96279 L
.39984 .96136 L
.38725 .9194 L
s
.131 .282 .051 .219 k
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
F
0 g
.41981 .47359 m
.3945 .4525 L
.41823 .42403 L
.4438 .4496 L
.41981 .47359 L
s
.128 .073 .054 .186 k
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
F
0 g
.39586 .65721 m
.43924 .67456 L
.45878 .65502 L
.43884 .62709 L
.40244 .63749 L
.39586 .65721 L
s
.158 .055 .049 .3 k
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
F
0 g
.41144 .73258 m
.4525 .71205 L
.43739 .68938 L
.39727 .70543 L
.39613 .71114 L
.41144 .73258 L
s
.297 .198 .073 .164 k
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.40972 .85995 L
.3945 .8295 L
.41383 .81983 L
.45637 .86237 L
.4496 .8759 L
s
.114 .19 .063 .106 k
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47425 .74105 L
.46853 .72006 L
.4525 .71205 L
.41144 .73258 L
.41452 .7603 L
s
1 g
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
F
0 g
.409 .07664 m
.42294 .06553 L
.46351 .06199 L
.47395 .06714 L
.46515 .09791 L
.43096 .12356 L
.42002 .11262 L
.409 .08782 L
.409 .07664 L
s
.132 .175 .144 .185 k
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
F
0 g
.4293 .19896 m
.4293 .27487 L
.47363 .26379 L
.47785 .24057 L
.4293 .19896 L
s
0 .193 .093 .266 k
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
F
0 g
.42205 .3597 m
.42253 .35583 L
.44049 .34686 L
.47485 .36976 L
.46816 .4032 L
.4438 .4032 L
.42205 .3597 L
s
.172 .12 .038 .08 k
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
F
0 g
.42024 .41498 m
.41823 .42403 L
.4438 .4496 L
.47744 .4496 L
.46816 .4032 L
.4438 .4032 L
.42024 .41498 L
s
.015 .065 .29 .08 k
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
F
0 g
.43394 .49658 m
.4844 .48537 L
.4844 .4583 L
.47744 .4496 L
.4438 .4496 L
.41981 .47359 L
.42414 .48515 L
.43394 .49658 L
s
.018 .167 .216 .216 k
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
F
0 g
.41654 .55342 m
.41692 .55173 L
.43988 .53336 L
.4757 .5453 L
.45913 .5743 L
.42847 .5743 L
.41654 .55342 L
s
.203 .277 .154 .11 k
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
F
0 g
.42847 .5743 m
.45913 .5743 L
.46928 .59799 L
.44012 .62133 L
.42157 .59041 L
.42847 .5743 L
s
.071 .102 .01 .225 k
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
F
0 g
.41452 .7603 m
.47015 .75334 L
.47338 .76222 L
.4293 .8063 L
.42567 .8063 L
.41427 .76066 L
.41452 .7603 L
s
.071 .209 .217 .259 k
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
F
0 g
.45637 .86237 m
.46224 .85722 L
.47063 .8237 L
.46637 .81689 L
.4293 .8063 L
.42567 .8063 L
.41383 .81983 L
.45637 .86237 L
s
1 g
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
F
0 g
.43513 .98202 m
.45505 .97995 L
.47929 .96182 L
.48137 .95819 L
.47117 .93015 L
.45675 .92006 L
.40325 .96286 L
.43513 .98202 L
s
.199 .089 .179 .179 k
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.4177 .1799 L
.42582 .19614 L
.42816 .19716 L
.47309 .17719 L
.48662 .14112 L
s
.184 .023 .19 .098 k
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
F
0 g
.4293 .3017 m
.4409 .3133 L
.47309 .30793 L
.48208 .27647 L
.47363 .26379 L
.4293 .27487 L
.42238 .28093 L
.4293 .3017 L
s
.166 .156 .273 .182 k
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.4844 .48537 L
.43394 .49658 L
.43381 .49697 L
.43988 .53336 L
.4757 .5453 L
.48923 .53853 L
.49951 .51798 L
s
.263 .179 .119 .072 k
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
F
0 g
.47338 .76222 m
.48086 .77343 L
.46637 .81689 L
.4293 .8063 L
.47338 .76222 L
s
.192 .077 .109 .147 k
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.43357 .13228 L
.43096 .12356 L
.46515 .09791 L
.48672 .14104 L
.48662 .14112 L
s
.121 .168 .192 .188 k
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
F
0 g
.4409 .3133 m
.47309 .30793 L
.48368 .32381 L
.4409 .3452 L
.4409 .3133 L
s
.222 .08 .012 .009 k
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
F
0 g
.43924 .67456 m
.45878 .65502 L
.4699 .65603 L
.4699 .71814 L
.46853 .72006 L
.4525 .71205 L
.43739 .68938 L
.43924 .67456 L
s
.038 .056 .123 .211 k
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.50113 .34587 L
.49952 .33702 L
.48368 .32381 L
.4409 .3452 L
.44049 .34686 L
.47485 .36976 L
s
.172 .2 .15 .029 k
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.47634 .65486 L
.4699 .65603 L
.45878 .65502 L
.43884 .62709 L
.44012 .62133 L
.46928 .59799 L
.48547 .60406 L
.50206 .62342 L
s
.208 .022 .031 .257 k
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
F
0 g
.47309 .17719 m
.42816 .19716 L
.4293 .19896 L
.47785 .24057 L
.51655 .21907 L
.51412 .20455 L
.47309 .17719 L
s
.017 .245 .221 .11 k
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.47634 .65486 L
.4699 .65603 L
.4699 .71814 L
s
1 g
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
F
0 g
.50719 .0929 m
.50086 .13718 L
.48672 .14104 L
.46515 .09791 L
.47395 .06714 L
.48444 .06636 L
.50719 .0929 L
s
.196 .077 .03 .222 k
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
F
0 g
.48923 .53853 m
.4757 .5453 L
.45913 .5743 L
.46928 .59799 L
.48547 .60406 L
.5047 .5656 L
.48923 .53853 L
s
.274 .297 .017 .212 k
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
F
0 g
.4496 .8759 m
.4496 .8875 L
.5163 .8875 L
.50967 .86761 L
.50794 .86484 L
.46224 .85722 L
.45637 .86237 L
.4496 .8759 L
s
.236 .241 .194 .002 k
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
F
0 g
.4496 .8875 m
.5163 .8875 L
.51974 .89266 L
.51929 .89808 L
.47117 .93015 L
.45675 .92006 L
.44689 .89835 L
.4496 .8875 L
s
.065 .04 .045 .273 k
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.52345 .80177 L
.51477 .78615 L
.48086 .77343 L
.46637 .81689 L
.47063 .8237 L
.51381 .8237 L
.52053 .81782 L
s
.156 .019 .014 .016 k
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
F
0 g
.51381 .8237 m
.47063 .8237 L
.46224 .85722 L
.50794 .86484 L
.51381 .8237 L
s
.14 .074 .093 .206 k
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.48208 .27647 L
.47309 .30793 L
.48368 .32381 L
.49952 .33702 L
.53163 .28886 L
s
.243 .297 .063 .284 k
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
F
0 g
.48662 .14112 m
.47309 .17719 L
.51412 .20455 L
.53998 .15283 L
.50086 .13718 L
.48672 .14104 L
.48662 .14112 L
s
.269 0 .046 .071 k
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
F
0 g
.47485 .36976 m
.4844 .3626 L
.52065 .39885 L
.5076 .4032 L
.46816 .4032 L
.47485 .36976 L
s
.032 .06 .152 .07 k
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
F
0 g
.47744 .4496 m
.46816 .4032 L
.5076 .4032 L
.5076 .4467 L
.4844 .4583 L
.47744 .4496 L
s
.267 .019 .107 .097 k
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
F
0 g
.4699 .71814 m
.5047 .6903 L
.52349 .69239 L
.53001 .70216 L
.52199 .73423 L
.47425 .74105 L
.46853 .72006 L
.4699 .71814 L
s
.111 .001 .093 .081 k
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
F
0 g
.51655 .21907 m
.56579 .25041 L
.55628 .27736 L
.5366 .2872 L
.53163 .28886 L
.48208 .27647 L
.47363 .26379 L
.47785 .24057 L
.51655 .21907 L
s
.271 .227 0 .176 k
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
F
0 g
.52065 .39885 m
.4844 .3626 L
.50113 .34587 L
.525 .35648 L
.525 .39823 L
.52065 .39885 L
s
.028 .23 .237 .192 k
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
F
0 g
.5047 .5656 m
.48547 .60406 L
.50206 .62342 L
.52804 .60486 L
.53675 .58163 L
.5047 .5656 L
s
.059 .229 .191 .121 k
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
F
0 g
.5308 .6729 m
.52349 .69239 L
.5047 .6903 L
.47634 .65486 L
.50154 .62966 L
.5308 .65405 L
.5308 .6729 L
s
.027 .17 .04 .051 k
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
F
0 g
.52199 .73423 m
.53302 .74966 L
.51477 .78615 L
.48086 .77343 L
.47338 .76222 L
.47015 .75334 L
.47425 .74105 L
.52199 .73423 L
s
1 g
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
F
0 g
.51929 .89808 m
.47117 .93015 L
.48137 .95819 L
.50918 .96002 L
.53072 .94952 L
.54127 .93325 L
.51929 .89808 L
s
.059 .151 .233 .254 k
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.525 .39823 L
.52065 .39885 L
.5076 .4032 L
.5076 .4467 L
.53133 .44077 L
.55018 .41877 L
.55092 .41674 L
s
1 g
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.53853 .04397 L
.5025 .04838 L
.48444 .06636 L
.50719 .0929 L
.5366 .0929 L
.55632 .06332 L
.55535 .05264 L
s
.248 .15 .14 .173 k
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
F
0 g
.5366 .0929 m
.55668 .13305 L
.54111 .15251 L
.53998 .15283 L
.50086 .13718 L
.50719 .0929 L
.5366 .0929 L
s
.277 .223 .14 .297 k
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
F
0 g
.4844 .4583 m
.5076 .4467 L
.53133 .44077 L
.54756 .48136 L
.49749 .50282 L
.4844 .48537 L
.4844 .4583 L
s
.249 .293 .202 .105 k
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.54598 .53541 L
.53843 .58069 L
.53675 .58163 L
.5047 .5656 L
.48923 .53853 L
.49951 .51798 L
s
.19 .064 .011 .284 k
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
F
0 g
.53163 .28886 m
.49952 .33702 L
.50113 .34587 L
.525 .35648 L
.5366 .3539 L
.5366 .2872 L
.53163 .28886 L
s
.163 .194 .271 .233 k
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
F
0 g
.52053 .81782 m
.55856 .84317 L
.50967 .86761 L
.50794 .86484 L
.51381 .8237 L
.52053 .81782 L
s
.103 .043 .039 .279 k
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
F
0 g
.50206 .62342 m
.50154 .62966 L
.5308 .65405 L
.56436 .63727 L
.56608 .63339 L
.52804 .60486 L
.50206 .62342 L
s
.155 .193 .199 .106 k
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.51974 .89266 L
.5163 .8875 L
.50967 .86761 L
.55856 .84317 L
.56668 .84622 L
.56947 .8498 L
s
.178 .27 .059 .109 k
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
F
0 g
.5366 .2872 m
.55628 .27736 L
.57932 .3196 L
.5656 .3539 L
.5366 .3539 L
.5366 .2872 L
s
.23 .277 .157 .004 k
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.57761 .37793 L
.5656 .3539 L
.5366 .3539 L
.525 .35648 L
.525 .39823 L
.55092 .41674 L
s
.04 .213 .146 .019 k
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
F
0 g
.49951 .51798 m
.49749 .50282 L
.54756 .48136 L
.56386 .48498 L
.57237 .5105 L
.56396 .52941 L
.54598 .53541 L
.49951 .51798 L
s
.177 .019 .175 .086 k
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
F
0 g
.5656 .78973 m
.52345 .80177 L
.51477 .78615 L
.53302 .74966 L
.5656 .75374 L
.5656 .78973 L
s
.074 .276 .136 .107 k
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
F
0 g
.51412 .20455 m
.51655 .21907 L
.56579 .25041 L
.57615 .24432 L
.59109 .20249 L
.54111 .15251 L
.53998 .15283 L
.51412 .20455 L
s
.219 .083 .237 .001 k
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
F
0 g
.5656 .75374 m
.53302 .74966 L
.52199 .73423 L
.53001 .70216 L
.56245 .70622 L
.56977 .75009 L
.5656 .75374 L
s
.04 .112 .178 .192 k
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
F
0 g
.55018 .41877 m
.57613 .47066 L
.56386 .48498 L
.54756 .48136 L
.53133 .44077 L
.55018 .41877 L
s
.111 .135 .021 .188 k
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
F
0 g
.53675 .58163 m
.52804 .60486 L
.56608 .63339 L
.57245 .62861 L
.54917 .58203 L
.53843 .58069 L
.53675 .58163 L
s
.071 .222 .175 .168 k
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
F
0 g
.56436 .63727 m
.5308 .65405 L
.5308 .6729 L
.57623 .6729 L
.56436 .63727 L
s
.193 .203 0 .082 k
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
F
0 g
.583 .68102 m
.583 .6874 L
.58203 .69223 L
.56245 .70622 L
.53001 .70216 L
.52349 .69239 L
.5308 .6729 L
.57623 .6729 L
.583 .68102 L
s
.12 .227 .164 .276 k
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
F
0 g
.56668 .84622 m
.55856 .84317 L
.52053 .81782 L
.52345 .80177 L
.5656 .78973 L
.57478 .7976 L
.56668 .84622 L
s
1 g
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
F
0 g
.58642 .91294 m
.55612 .9325 L
.54127 .93325 L
.51929 .89808 L
.51974 .89266 L
.56109 .87493 L
.58642 .91294 L
s
.201 .144 .227 .275 k
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
F
0 g
.55632 .06332 m
.58748 .09448 L
.56774 .12903 L
.55668 .13305 L
.5366 .0929 L
.55632 .06332 L
s
.161 .032 .049 .083 k
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
F
0 g
.54598 .53541 m
.56396 .52941 L
.5872 .5573 L
.57955 .57769 L
.54917 .58203 L
.53843 .58069 L
.54598 .53541 L
s
.05 .197 .028 .195 k
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
F
0 g
.57955 .57769 m
.54917 .58203 L
.57245 .62861 L
.57929 .62557 L
.58553 .58815 L
.57955 .57769 L
s
.279 .275 .153 .027 k
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
F
0 g
.55092 .41674 m
.5755 .40334 L
.60721 .42237 L
.5971 .4628 L
.57613 .47066 L
.55018 .41877 L
.55092 .41674 L
s
.086 .072 .153 .244 k
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
F
0 g
.60575 .14532 m
.59834 .19722 L
.59109 .20249 L
.54111 .15251 L
.55668 .13305 L
.56774 .12903 L
.60575 .14532 L
s
.266 .145 .289 .269 k
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
F
0 g
.59302 .74751 m
.6004 .7106 L
.58203 .69223 L
.56245 .70622 L
.56977 .75009 L
.59302 .74751 L
s
1 g
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
F
0 g
.55535 .05264 m
.57394 .03982 L
.60547 .04024 L
.62381 .05478 L
.60602 .09036 L
.58748 .09448 L
.55632 .06332 L
.55535 .05264 L
s
.065 .001 .062 .294 k
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
F
0 g
.56608 .63339 m
.57245 .62861 L
.57929 .62557 L
.59537 .62959 L
.60402 .6642 L
.583 .68102 L
.57623 .6729 L
.56436 .63727 L
.56608 .63339 L
s
.204 .27 .013 .211 k
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
F
0 g
.59402 .7976 m
.57478 .7976 L
.5656 .78973 L
.5656 .75374 L
.56977 .75009 L
.59302 .74751 L
.60936 .75568 L
.61734 .76845 L
.59402 .7976 L
s
.154 .073 .285 .015 k
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59412 .8498 L
.56947 .8498 L
.56668 .84622 L
.57478 .7976 L
.59402 .7976 L
.61537 .82429 L
s
1 g
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
F
0 g
.56947 .8498 m
.56109 .87493 L
.58642 .91294 L
.58769 .91304 L
.62398 .88595 L
.62402 .88568 L
.59412 .8498 L
.56947 .8498 L
s
.175 .099 .131 .288 k
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
F
0 g
.57237 .5105 m
.56386 .48498 L
.57613 .47066 L
.5971 .4628 L
.6109 .4743 L
.60185 .5105 L
.57237 .5105 L
s
.089 .027 .279 .044 k
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
F
0 g
.56396 .52941 m
.5872 .5573 L
.60504 .55284 L
.6236 .525 L
.60185 .5105 L
.57237 .5105 L
.56396 .52941 L
s
.123 .181 .29 .075 k
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
F
0 g
.58748 .09448 m
.56774 .12903 L
.60575 .14532 L
.63133 .13253 L
.6323 .1219 L
.60602 .09036 L
.58748 .09448 L
s
.058 .18 .228 .081 k
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.62111 .36343 L
.57761 .37793 L
.5656 .3539 L
.57932 .3196 L
.60025 .32169 L
s
.154 .21 .215 .17 k
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
F
0 g
.58553 .58815 m
.57929 .62557 L
.59537 .62959 L
.62517 .62108 L
.62789 .59662 L
.58553 .58815 L
s
.3 .137 .231 .155 k
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
F
0 g
.63878 .26519 m
.65292 .30194 L
.60025 .32169 L
.57932 .3196 L
.55628 .27736 L
.56579 .25041 L
.57615 .24432 L
.63878 .26519 L
s
.125 .038 .099 .166 k
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
F
0 g
.5872 .5573 m
.57955 .57769 L
.58553 .58815 L
.62789 .59662 L
.63686 .58466 L
.60504 .55284 L
.5872 .5573 L
s
.036 .012 .121 .123 k
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
F
0 g
.62332 .41968 m
.60721 .42237 L
.5755 .40334 L
.57761 .37793 L
.62111 .36343 L
.64157 .36854 L
.64786 .39163 L
.62332 .41968 L
s
.212 .13 .131 .047 k
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
F
0 g
.59537 .62959 m
.62517 .62108 L
.64446 .64358 L
.6429 .66073 L
.63893 .6642 L
.60402 .6642 L
.59537 .62959 L
s
.154 .251 .203 .266 k
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
F
0 g
.60402 .6642 m
.63893 .6642 L
.6323 .6874 L
.583 .6874 L
.583 .68102 L
.60402 .6642 L
s
0 .041 .287 .096 k
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
F
0 g
.583 .6874 m
.58203 .69223 L
.6004 .7106 L
.6323 .7106 L
.6323 .6874 L
.583 .6874 L
s
.001 .204 .057 .241 k
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
F
0 g
.60936 .75568 m
.6381 .71737 L
.6323 .7106 L
.6004 .7106 L
.59302 .74751 L
.60936 .75568 L
s
.176 .166 .257 .075 k
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
F
0 g
.60185 .5105 m
.6109 .4743 L
.65753 .48096 L
.65785 .48539 L
.63738 .52224 L
.6236 .525 L
.60185 .5105 L
s
.14 .154 .137 .252 k
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
F
0 g
.61537 .82429 m
.59402 .7976 L
.61734 .76845 L
.63995 .77598 L
.6454 .7858 L
.63636 .82196 L
.61537 .82429 L
s
.228 .024 .006 .205 k
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
F
0 g
.63133 .13253 m
.6526 .1538 L
.63559 .19349 L
.59834 .19722 L
.60575 .14532 L
.63133 .13253 L
s
.074 .073 .103 .238 k
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
F
0 g
.60025 .32169 m
.65292 .30194 L
.67089 .31577 L
.64157 .36854 L
.62111 .36343 L
.60025 .32169 L
s
.073 .032 .116 .142 k
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.65753 .48096 L
.6109 .4743 L
.5971 .4628 L
.60721 .42237 L
.62332 .41968 L
.64759 .44881 L
s
1 g
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
F
0 g
.6535 .85876 m
.62402 .88568 L
.59412 .8498 L
.61537 .82429 L
.63636 .82196 L
.65725 .84285 L
.6535 .85876 L
s
.073 .128 .059 .201 k
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
F
0 g
.59834 .19722 m
.59109 .20249 L
.57615 .24432 L
.63878 .26519 L
.6613 .23624 L
.6613 .21553 L
.63559 .19349 L
.59834 .19722 L
s
.197 .262 .102 .127 k
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
F
0 g
.60504 .55284 m
.63686 .58466 L
.63877 .58389 L
.65234 .54319 L
.63738 .52224 L
.6236 .525 L
.60504 .55284 L
s
1 g
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
F
0 g
.60602 .09036 m
.6323 .1219 L
.66384 .09562 L
.65563 .05869 L
.6425 .05278 L
.62381 .05478 L
.60602 .09036 L
s
.057 .108 .265 .175 k
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
F
0 g
.64873 .72091 m
.6381 .71737 L
.60936 .75568 L
.61734 .76845 L
.63995 .77598 L
.65966 .74641 L
.64873 .72091 L
s
.129 .084 .259 .27 k
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
F
0 g
.62789 .59662 m
.62517 .62108 L
.64446 .64358 L
.68875 .61827 L
.67902 .59396 L
.63877 .58389 L
.63686 .58466 L
.62789 .59662 L
s
.055 .011 .156 .032 k
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
F
0 g
.67153 .70572 m
.67531 .67925 L
.6429 .66073 L
.63893 .6642 L
.6323 .6874 L
.6323 .7106 L
.6381 .71737 L
.64873 .72091 L
.67153 .70572 L
s
.282 .278 .041 .189 k
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.69164 .40476 L
.64786 .39163 L
.62332 .41968 L
.64759 .44881 L
s
.209 .15 .282 .288 k
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
F
0 g
.6323 .1219 m
.66384 .09562 L
.69465 .11102 L
.68514 .1538 L
.6526 .1538 L
.63133 .13253 L
.6323 .1219 L
s
.012 .188 .18 .161 k
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
F
0 g
.69128 .1607 m
.6944 .19189 L
.6613 .21553 L
.63559 .19349 L
.6526 .1538 L
.68514 .1538 L
.69128 .1607 L
s
.255 .08 .215 .287 k
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
F
0 g
.69755 .54965 m
.70016 .55168 L
.67902 .59396 L
.63877 .58389 L
.65234 .54319 L
.69755 .54965 L
s
1 g
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
F
0 g
.67932 .83479 m
.69642 .80913 L
.69312 .79262 L
.6454 .7858 L
.63636 .82196 L
.65725 .84285 L
.67932 .83479 L
s
.127 .296 .255 .017 k
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
F
0 g
.64759 .44881 m
.6587 .47843 L
.67351 .47021 L
.70556 .44273 L
.69529 .40507 L
.69164 .40476 L
.64759 .44881 L
s
.072 .285 .099 .285 k
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.69755 .54965 L
.65234 .54319 L
.63738 .52224 L
.65785 .48539 L
.68316 .50648 L
s
1 g
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.70731 .76434 L
.69312 .79262 L
.6454 .7858 L
.63995 .77598 L
.65966 .74641 L
.70515 .75291 L
s
.09 .007 .058 .096 k
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
F
0 g
.7106 .35825 m
.70381 .3956 L
.69529 .40507 L
.69164 .40476 L
.64786 .39163 L
.64157 .36854 L
.67089 .31577 L
.6787 .3162 L
.70888 .33344 L
.7106 .33747 L
.7106 .35825 L
s
1 g
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
F
0 g
.72745 .65969 m
.73001 .64506 L
.72433 .63768 L
.68875 .61827 L
.64446 .64358 L
.6429 .66073 L
.67531 .67925 L
.72745 .65969 L
s
1 g
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
F
0 g
.70515 .75291 m
.65966 .74641 L
.64873 .72091 L
.67153 .70572 L
.71376 .73106 L
.70515 .75291 L
s
.181 .157 .077 .108 k
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
F
0 g
.6613 .23624 m
.70678 .24924 L
.71256 .25695 L
.6787 .3162 L
.67089 .31577 L
.65292 .30194 L
.63878 .26519 L
.6613 .23624 L
s
1 g
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
F
0 g
.65563 .05869 m
.66384 .09562 L
.69465 .11102 L
.72724 .09473 L
.73037 .08891 L
.72944 .0854 L
.70697 .05649 L
.68161 .0485 L
.65563 .05869 L
s
.169 .269 .197 .246 k
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
F
0 g
.71427 .2043 m
.70678 .24924 L
.6613 .23624 L
.6613 .21553 L
.6944 .19189 L
.71427 .2043 L
s
1 g
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
F
0 g
.71376 .73106 m
.72388 .7219 L
.73302 .6764 L
.72745 .65969 L
.67531 .67925 L
.67153 .70572 L
.71376 .73106 L
s
.214 .189 .282 .26 k
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.72148 .49419 L
.67351 .47021 L
.6587 .47843 L
.65753 .48096 L
.65785 .48539 L
.68316 .50648 L
s
.087 .193 .026 .243 k
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.70556 .44273 L
.67351 .47021 L
.72148 .49419 L
.73571 .48233 L
.73173 .46244 L
s
.015 .208 .227 .258 k
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
F
0 g
.68316 .50648 m
.7193 .49745 L
.7193 .55021 L
.70016 .55168 L
.69755 .54965 L
.68316 .50648 L
s
.225 .201 .169 .162 k
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
F
0 g
.67902 .59396 m
.68875 .61827 L
.72433 .63768 L
.73609 .55537 L
.7193 .55021 L
.70016 .55168 L
.67902 .59396 L
s
.044 .044 .092 .054 k
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.69128 .1607 L
.68514 .1538 L
.69465 .11102 L
.72724 .09473 L
.74691 .14719 L
.74281 .15334 L
s
.174 .075 .196 .108 k
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.71427 .2043 L
.6944 .19189 L
.69128 .1607 L
.74281 .15334 L
s
.26 .186 .214 .148 k
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
F
0 g
.70888 .33344 m
.6787 .3162 L
.71256 .25695 L
.74235 .25993 L
.74789 .30419 L
.70888 .33344 L
s
.173 .293 .188 .206 k
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
F
0 g
.7487 .20048 m
.7541 .20426 L
.7541 .25079 L
.74235 .25993 L
.71256 .25695 L
.70678 .24924 L
.71427 .2043 L
.7487 .20048 L
s
.158 .085 .26 .248 k
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.69529 .40507 L
.70556 .44273 L
.7251 .4525 L
.76347 .41413 L
.76033 .40368 L
s
.233 .184 .091 .086 k
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
F
0 g
.76209 .49882 m
.74863 .55269 L
.73609 .55537 L
.7193 .55021 L
.7193 .49745 L
.72148 .49419 L
.73571 .48233 L
.76209 .49882 L
s
.19 .141 .299 .032 k
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.70381 .3956 L
.7106 .35825 L
.76781 .38685 L
.76033 .40368 L
s
.015 .066 .103 .224 k
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
F
0 g
.76781 .38685 m
.7106 .35825 L
.7106 .33747 L
.7599 .3539 L
.77854 .37254 L
.76781 .38685 L
s
1 g
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
F
0 g
.7789 .5653 m
.74863 .55269 L
.73609 .55537 L
.72433 .63768 L
.73001 .64506 L
.75487 .63614 L
.78331 .59862 L
.7789 .5653 L
s
.055 .18 .189 .076 k
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
F
0 g
.7599 .3539 m
.77176 .31831 L
.75193 .30508 L
.74789 .30419 L
.70888 .33344 L
.7106 .33747 L
.7599 .3539 L
s
.182 .187 .002 .17 k
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
F
0 g
.73173 .46244 m
.7251 .4525 L
.76347 .41413 L
.7831 .43096 L
.7831 .4496 L
.73173 .46244 L
s
1 g
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
F
0 g
.74691 .14719 m
.78616 .14283 L
.79902 .12629 L
.7872 .10294 L
.76543 .08875 L
.73037 .08891 L
.72724 .09473 L
.74691 .14719 L
s
.023 .101 .041 .222 k
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.78818 .45975 L
.7831 .4496 L
.73173 .46244 L
.73571 .48233 L
.76209 .49882 L
.76979 .49651 L
s
.09 .217 .25 .136 k
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
F
0 g
.74281 .15334 m
.7487 .20048 L
.7541 .20426 L
.79285 .19651 L
.7976 .1886 L
.78616 .14283 L
.74691 .14719 L
.74281 .15334 L
s
.201 .076 .251 .104 k
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.7541 .25079 L
.74235 .25993 L
.74789 .30419 L
.75193 .30508 L
.78636 .28212 L
s
.185 .011 .147 .18 k
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
F
0 g
.77854 .37254 m
.7599 .3539 L
.77176 .31831 L
.80697 .32334 L
.80754 .32366 L
.80791 .32587 L
.79373 .3684 L
.77854 .37254 L
s
.131 .131 .258 .104 k
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
F
0 g
.79025 .25882 m
.7541 .25079 L
.7541 .20426 L
.79285 .19651 L
.81616 .24312 L
.8116 .25028 L
.79025 .25882 L
s
.249 .245 .257 .233 k
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.75193 .30508 L
.77176 .31831 L
.80697 .32334 L
.78636 .28212 L
s
1 g
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.79758 .55523 L
.7789 .5653 L
.74863 .55269 L
.76209 .49882 L
.76979 .49651 L
s
1 g
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
F
0 g
.76033 .40368 m
.76781 .38685 L
.77854 .37254 L
.79373 .3684 L
.83451 .39898 L
.83241 .40983 L
.7831 .43096 L
.76347 .41413 L
.76033 .40368 L
s
1 g
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
F
0 g
.76979 .49651 m
.81295 .51501 L
.81575 .51346 L
.82961 .47415 L
.82851 .47128 L
.78818 .45975 L
.76979 .49651 L
s
.226 .143 .215 .011 k
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
F
0 g
.78636 .28212 m
.79025 .25882 L
.8116 .25028 L
.8324 .2988 L
.80754 .32366 L
.80697 .32334 L
.78636 .28212 L
s
1 g
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
F
0 g
.78818 .45975 m
.82851 .47128 L
.84126 .4323 L
.83241 .40983 L
.7831 .43096 L
.7831 .4496 L
.78818 .45975 L
s
1 g
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
F
0 g
.78616 .14283 m
.7976 .1886 L
.8409 .17777 L
.84261 .15283 L
.83342 .1389 L
.8059 .12625 L
.79902 .12629 L
.78616 .14283 L
s
1 g
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
F
0 g
.7976 .1886 m
.8409 .17777 L
.84982 .18664 L
.85607 .22072 L
.85107 .2336 L
.81616 .24312 L
.79285 .19651 L
.7976 .1886 L
s
1 g
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
F
0 g
.79373 .3684 m
.80791 .32587 L
.85929 .35669 L
.84798 .38901 L
.83451 .39898 L
.79373 .3684 L
s
1 g
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
F
0 g
.8116 .25028 m
.81616 .24312 L
.85107 .2336 L
.86882 .25298 L
.87245 .28103 L
.8626 .2988 L
.8324 .2988 L
.8116 .25028 L
s
1 g
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
F
0 g
.80791 .32587 m
.80754 .32366 L
.8324 .2988 L
.8626 .2988 L
.87258 .31731 L
.8679 .34958 L
.85929 .35669 L
.80791 .32587 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 700},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0002_2000`400?l00000o`00003ooooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo
003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool009_ooooo0ol00003ooooo`;o0000Noooool3o`0000Cooooo0_l0001looooo`?o0000
1?ooool2o`0007Wooooo0ol00004ooooo`;o00001?ooool2o`0007Gooooo0ol00002ooooo`Go0000
0oooool2o`0000Cooooo002Looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`1gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001joooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`00VOooool5o`0000;ooooo00Co0000oooooooooooo0000NOooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo0000N_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000MOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000oooool009Wooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool0001iooooo`Co00000oooool01?l0003oooooooooool0001koooo
o`?o00000oooool01?l0003oooooooooool0001iooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0001eooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo007ooooo002Jooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo0000NOooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0007[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0007Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0007Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00Oooool009_ooooo0_l00003ooooo`04o`000?oooooooooo
o`0007[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0001jooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0001hooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0007Cooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00003ooooo`00W?ooool00ol0003ooooooooo
o`02ooooo`;o0000O?ooool2o`0000Cooooo0_l0001looooo`?o00001?ooool2o`0007[ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l0001fooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o00001?ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool0
0?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooo
oonnooooo`006_ooooooo`000?oo0000V_l0000:ooooo`006_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
oooooooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooo
oooooooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooo
oooooiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooo
oiKooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0oooooooooooooiKooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0oooooomioooooaWo0000ooooool4ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooN?oooolKo`000?oooooo0oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooogKooooo1?l0000Gooooo`?o0000
ooooool2ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooG_oo
ool7o`0000oooooo1Ol0000Iooooo`?o0000ooooool1ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0?ooooooE_oooolAo`0000cooooo1?l0000Looooo`?o0000ooooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodkooooo4Ol00005oooo
o`Ko00001oooool4o`0001oooooo1?l0003mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0?ooooooB_ooool=o`0000oooooo1_l00003ooooo`Go00008Oooool4o`0002Oo
oooo1Ol0003@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000oooooom9ooooo`Ko0000
6_ooool9o`0002Gooooo0ol0000Sooooo`_o0000boooool3o`0000[ooooo000Jooooo`03o`000?oo
oooooooo0?ooooooB?ooool3o`00023ooooo1Ol0000Xooooo`?o00007oooool7o`0000?ooooo2?l0
0039ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?ooooooAoooool3
o`0002?ooooo0_l0000Zooooo`?o00001Oooool:o`0000cooooo1ol00009ooooo`So0000a_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooodKooooo0ol0000Toooo
o`;o0000:ooooolDo`0000Kooooo1ol0000@ooooo`Oo0000`oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`3oooooodGooooo0ol0000Uooooo`;o0000;?ooool7o`0000So
oooo3_l0000Fooooo`Ko0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodCooooo0ol0000Vooooo`;o0000:oooool3o`00013ooooo2?l0000Looooo`?o0000
`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3ooooood?ooooo0ol0
000Wooooo`?o0000:_ooool2o`0001Cooooo0_l0000Pooooo`?o0000`?ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`3ooooood;ooooo0ol0000Yooooo`;o0000:Oooool3
o`0001Cooooo0_l0000Qooooo`?o0000_oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`3oooooob[ooooo2Ol0000>ooooo`?o0000:_ooool2o`0002Wooooo0_l0000Eoooo
o`?o00008Oooool3o`000;kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0oooooolMoooooaWo00002_ooool3o`0002_ooooo0ol0000Wooooo`?o00005_ooool2o`0002;o
oooo0ol0002mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?Oooooo
1Ol0000HoooooaKo00001oooool6o`0000Oooooo0ol0000/ooooo`Co00009_ooool2o`0001Oooooo
0_l0000Sooooo`;o0000_Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`3dooooo`_o00005?ooool:o`0001Oooooo3?l0000/ooooo`Ko00009?ooool3o`0001Oooooo0_l0
000Sooooo`?o0000_?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3a
ooooo`Oo00000oooool6o`00013ooooo1?l0000Qooooo`Wo0000;?ooool3o`0000;oQYAo0ol0000S
ooooo`;o00006?ooool2o`0002Cooooo0ol0002kooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0>kooooo1ol00009ooooo`Ko00003?ooool4o`0002;ooooo0_l00005oooo
o`?o0000:oooool2o`0000CoQYAo0ol0000Qooooo`?o00006?ooool3o`0002Cooooo0ol0002joooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>_ooooo1ol0000>ooooo`Oo
00002?ooool3o`0002?ooooo0ol00006ooooo`?o0000:Oooool3o`0000GoQYAo0ol0000Pooooo`;o
00006_ooool2o`0002Gooooo0ol0002iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0>Sooooo1ol0000Dooooo`Ko00001?ooool4o`0002Cooooo0_l00008ooooo`?o0000
9oooool3o`0000OoQYAo0ol0000Nooooo`?o00006_ooool2o`0002Kooooo0_l0002iooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>Gooooo1ol0000Jooooo`[o00009Ooo
ool2o`0000Wooooo0ol0000Vooooo`;o00002On6U7l3o`0001gooooo0_l0000Kooooo`;o00009_oo
ool3o`000;Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0hoooool6
o`0001oooooo1_l0000Wooooo`;o00002_ooool3o`0002Cooooo0ol0000:ohJDO`?o00006oooool3
o`0001_ooooo0_l0000Wooooo`?o0000]oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`3Sooooo`?o00009Oooool2o`0002Oooooo0ol0000;ooooo`?o00008_ooool3o`00
00coQYAo0ol0000Jooooo`;o00007?ooool3o`0002Oooooo0ol0002fooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0>;ooooo0ol0000Vooooo`;o00009oooool2o`0000go
oooo0ol0000Pooooo`?o00003_n6U7l3o`0001Sooooo0ol0000Mooooo`;o0000:?ooool2o`000;Ko
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0h_ooool2o`0002Oooooo
0_l0000Wooooo`;o00003_ooool3o`0001oooooo0_l0000@ohJDO`?o00005oooool2o`0001kooooo
0_l0000Xooooo`?o0000]Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`3Qooooo`?o00009oooool2o`0002Oooooo0_l0000?ooooo`;o00007_ooool3o`00017oQYAo0ol0
000Eooooo`?o00007_ooool2o`0002Wooooo0ol0002dooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0>7ooooo0_l0000Xooooo`;o00009_ooool3o`0000oooooo0ol0000L
ooooo`?o00004on6U7l3o`0001Cooooo0_l0000Oooooo`;o0000:_ooool3o`000;?ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0h?ooool3o`0002Sooooo0_l0000Voooo
o`;o00004Oooool3o`0001_ooooo0_l0000EohJDO`?o00004_ooool3o`0001oooooo0ol0000Zoooo
o`?o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3Pooooo`;o
0000:Oooool2o`0002Kooooo0_l0000Booooo`?o00006Oooool3o`0001KoQYAo0ol0000Aooooo`;o
00008Oooool2o`0002_ooooo0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0=oooooo0ol0000Xooooo`?o00009_ooool2o`0001?ooooo0ol0000Gooooo`?o0000
6?n6U7l3o`0000oooooo0ol0000Qooooo`;o0000:oooool3o`0000[ooooo3_l0002Iooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0=kooooo0ol0000Xooooo`Co00009_oo
ool2o`0001Cooooo0ol0000Fooooo`;o00006_n6U7l3o`0000kooooo0_l0000Rooooo`;o0000;?oo
oolKo`0009Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0g_ooool2
o`0002Sooooo1_l0000Tooooo`?o00005Oooool3o`0001Cooooo0ol0000KohJDO`?o00002Oooool6
o`0002;ooooo0_l0000[ooooo`ko00003?ooool4o`0009Kooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0gOooool3o`0002Kooooo1?l00002omjcY@;o00009?ooool2o`00
01Oooooo6?l0000MohJDO`?o00000_ooool;o`0002?ooooo0ol0000Yooooo`?o00006Oooool4o`00
09Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0gOooool2o`0002Ko
oooo1?l00003omjcY@?o00008oooool2o`0001Sooooo5_l0000OohJDO`_o00000_o=_Z83o`0002?o
oooo0_l0000Wooooo`Co00007?ooool3o`0009Cooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0g?ooool3o`0002Gooooo0ol00006omjcY@;o00008oooool2o`0001Sooooo
0_l0000BoiB][`?o00007on6U7l4o`0000WocKjR0ol0000Qooooo`Co00009?ooool5o`0001kooooo
1?l0002Booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<Sooooo3?l0
0008ooooo`;o00009?ooool4o`0000Oog[>U0ol0000Qooooo`?o00006?ooool2o`0001?oU:f_0_l0
000NohJDO`?o00003?o=_Z83o`0001oooooo1ol0000Pooooo`So00007_ooool4o`00097ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0aooooolGo`0002?ooooo1?l00009
omjcY@;o00008?ooool3o`0001Wooooo0_l0000CoiB][`?o00007On6U7l2o`0000kocKjR0ol0000M
ooooo`?o00000_n0Sfh5o`0001cooooo1Ol00003onKVfP;o00008?ooool4o`0008oooooo00?o0000
ooooooooool02?ooool001[ooooo0ol00036ooooo`?o00002_ooool:o`0002?ooooo0ol0000;omjc
Y@?o00007_ooool4o`0001Sooooo0ol0000DoiB][`;o00007?n6U7l3o`0000oocKjR0ol0000Koooo
o`?o00001On0Sfh5o`0001Sooooo1Ol00005onKVfP;o00008Oooool4o`0008cooooo0ol0000:oooo
o`006_ooool00ol0003oooooooooo`35ooooo`?o00004oooool3o`00023ooooo1?l0000=omjcY@;o
00007Oooool6o`0001Oooooo0_l0000EoiB][`?o00006_n6U7l3o`00017ocKjR0ol0000Hooooo`Co
00002?n0Sfh5o`0001Cooooo1Ol00007onKVfP?o00008_ooool3o`0008gooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0a?ooool3o`0001Gooooo0_l0000Oooooo`Co0000
3_oN/jD3o`0001[ooooo1?l00002ojW6_P;o00005oooool2o`0001KoU:f_0_l0000JohJDO`;o0000
4oo=_Z82o`0001Oooooo1?l0000;oh2?KPKo00004?ooool4o`0000[oi^KJ0_l0000Sooooo`?o0000
S?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`33ooooo`?o00005_oo
ool3o`0001gooooo0ol0000AomjcY@;o00006Oooool4o`0000?oZLJn0ol0000Fooooo`;o00005_nD
[Jl3o`0001SoQYAo0ol0000ColfnXP?o00005Oooool3o`0000ooP8m^1_l0000<ooooo`Co00003?oV
i]X3o`0002?ooooo0_l0002<ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0<;ooooo0ol0000Hooooo`?o00006_ooool4o`0001;og[>U0ol0000Gooooo`?o00001_nYa[h2
o`0001Kooooo0_l0000GoiB][`;o00006?n6U7l2o`0001GocKjR0ol0000Cooooo`?o00004on0Sfh5
o`0000Sooooo1Ol0000>onKVfP;o00008oooool3o`0008_ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0`Oooool3o`0001[ooooo0_l0000Iooooo`Co00005?oN/jD2o`00
01Gooooo1?l00007ojW6_P?o00005Oooool2o`0001OoU:f_0ol0000FohJDO`?o00005_o=_Z83o`00
013ooooo1?l0000Foh2?KPGo00001?ooool5o`00013oi^KJ0_l0000Tooooo`;o0000Roooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`30ooooo`?o00006oooool4o`0001Ko
oooo0ol0000FomjcY@?o00004oooool4o`0000WoZLJn0_l0000Eooooo`;o00006?nD[Jl2o`0001Ko
QYAo0_l0000HolfnXP?o00003_ooool4o`0001WoP8m^2_l0000BonKVfP?o00008oooool3o`0008[o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool4o`0001gooooo
1?l0000Cooooo`Co00006?oN/jD2o`00017ooooo1?l0000;ojW6_P?o00004oooool3o`0001SoU:f_
0ol0000DohJDO`?o00006Oo=_Z83o`0000cooooo0ol0000Moh2?KPKo00005OoVi]X2o`0002Cooooo
0_l0002:ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;gooooo1?l0
000Mooooo`Ko00004Oooool4o`0001Wog[>U0ol0000?ooooo`Co00003OnYa[h2o`0001?ooooo0_l0
000JoiB][`;o00004on6U7l3o`0001_ocKjR0_l0000;ooooo`?o00008?n0Sfh2o`0001Ooi^KJ0ol0
000Sooooo`?o0000ROooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2l
ooooo`?o00007_ooool3o`0000;oQZ>Y0ol0000?ooooo`?o00006_oN/jD4o`0000kooooo0ol0000?
ojW6_P?o00004_ooool2o`0001[oU:f_0ol0000BohJDO`;o00007?o=_Z83o`0000Wooooo0ol0000Q
oh2?KP;o00006?oVi]X2o`0002Cooooo0_l00029ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0;_ooooo0ol0000Oooooo`;o00001?n6XjT3o`0000cooooo1?l0000Iomjc
Y@Oo00002oooool4o`00017oZLJn0_l0000Booooo`;o00006onD[Jl2o`00017oQYAo0ol0000Molfn
XP?o00001_ooool4o`00027oP8m^0ol0000HonKVfP;o00009?ooool3o`0008Sooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0^_ooool3o`0001oooooo0ol00005ohJSZ@Co
00002Oooool4o`0001Wog[>U1?l00002oiFKS`?o00002Oooool4o`0001;oZLJn0ol0000Aooooo`;o
00006onD[Jl2o`00017oQYAo0_l0000OolfnXP?o00001?ooool4o`0002;oP8m^0_l0000IonKVfP?o
00009?ooool3o`0008Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
^Oooool3o`0001oooooo0ol00007ohJSZ@Co00001oooool3o`0001Wog[>U1?l00005oiFKS`?o0000
1oooool3o`0001GoZLJn0_l0000Aooooo`;o00006onD[Jl3o`0000ooQYAo0ol0000PolfnXP?o0000
0_ooool3o`0002CoP8m^0_l0000JonKVfP;o00009Oooool2o`0008Oooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0^?ooool3o`00023ooooo0_l0000:ohJSZ@?o00001?oo
ool4o`0001Wog[>U1?l00007oiFKS`?o00001?ooool4o`0001KoZLJn0ol0000@ooooo`;o00007?nD
[Jl2o`0000ooQYAo0_l0000RolfnXPKo00009On0Sfh2o`0001[oi^KJ0ol0000Tooooo`?o0000Q_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2gooooo`?o00008?ooool3
o`0000_oQZ>Y0ol00002ooooo`Co00006?oN/jD4o`0000[oUI^?0ol00002ooooo`Co00006?nYa[h2
o`00013ooooo0_l0000LoiB][`?o00003On6U7l3o`0002?ocKjR1?l0000Voh2?KP;o00006ooVi]X2
o`0002Gooooo0_l00026ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0:oooooo1_l000001?oooooo0000o`000?l0000Pooooo`?o00003On6XjT6o`0001Wog[>U1?l0000<
oiFKS`Ko00006_nYa[h3o`0000kooooo0ol0000MoiB][`;o00003On6U7l2o`0002GocKjR0_l0000V
oh2?KP?o00006ooVi]X2o`0002Gooooo0ol00025ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0:gooooo2ol0000Qooooo`;o00003on6XjT4o`0001Sog[>U1?l0000?oiFK
S`Co00007?nYa[h2o`0000kooooo0_l0000NoiB][`?o00002on6U7l3o`0002GocKjR0_l0000Voh2?
KP;o00007?oVi]X3o`0002Gooooo0_l00025ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0:cooooo1?l00004ooooo`?o00008Oooool3o`00013oQZ>Y0_l0000HomjcY@Co
00004OnEVhl2o`0001goZLJn0ol0000=ooooo`;o00007onD[Jl2o`0000[oQYAo0ol0000VolfnXP;o
00009_n0Sfh2o`0001goi^KJ0_l0000Uooooo`Wo0000O_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2Zooooo`Co00001oooool3o`0001oooooo0ol0000AohJSZ@?o0000
5OoN/jD4o`0001?oUI^?0ol0000MojW6_P;o00003Oooool2o`0001ooU:f_0ol00009ohJDO`;o0000
9oo=_Z82o`0002KoP8m^0_l0000MonKVfP?o00009Oooool:o`0007cooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Z?ooool5o`0000Wooooo0ol0000Nooooo`;o00004on6
XjT2o`0001Cog[>U1?l0000EoiFKS`;o00007OnYa[h3o`0000cooooo0_l0000PoiB][`;o00001on6
U7l4o`0002OocKjR0_l0000Voh2?KP;o00007_oVi]X2o`0002Cooooo0ol00005ooooo`Go0000N_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Vooooo`Go00003?ooool2
o`0001gooooo0ol0000CohJSZ@;o00004ooN/jD3o`0001OoUI^?0_l0000NojW6_P;o00003?ooool2
o`00023oU:f_0ol00003ohJDO`Wo00009Oo=_Z82o`0002GoP8m^0ol0000NonKVfP;o00008oooool3
o`0000Sooooo1Ol0001hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
0:Cooooo1Ol0000>ooooo`?o00006oooool3o`0001CoQZ>Y0ol0000@omjcY@Co00006?nEVhl6o`00
01[oZLJn0ol0000;ooooo`;o00008OnD[Jl9o`0000;oZjnJ1_l0000RolfnXP;o00009On0Sfh2o`00
01ooi^KJ0ol0000Qooooo`?o00002oooool5o`0007Kooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Xoooool4o`00017ooooo0ol0000Jooooo`;o00005_n6XjT2o`0000oo
g[>U1?l0000JoiFKS`_o00005OnYa[h2o`0000[ooooo0ol0000QoiB][`Ko00001on[[iX6o`0001oo
cKjR0ol0000Uoh2?KP;o00008?oVi]X2o`00027ooooo0_l0000>ooooo`Go0000M?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Qooooo`Co00005?ooool2o`0001Wooooo
0ol0000FohJSZ@?o00003?oN/jD4o`0001_oUI^?0ol00002oinkY0go00003onYa[h3o`0000Wooooo
0_l0000SoiB][`;o00003On[[iX5o`0001_ocKjR1_l0000Toh2?KP;o00008?oVi]X3o`0001oooooo
0ol0000@ooooo`Go0000L_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`2Boooooa;o00005Oooool3o`0001Sooooo0_l0000HohJSZ@;o00002ooN/jD4o`0001coUI^?0_l0
0009oinkY0co00002onYa[h2o`0000Wooooo0_l0000RoiB][`?o00003on[[iX6o`0001KocKjR1Ol0
00001?nAaLWo0000o`000?l0000Soh2?KP;o00008OoVi]X2o`0001kooooo0ol0000Cooooo`Go0000
L?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Aoooooa7o00006?oo
ool3o`0001Kooooo0ol0000HohJSZ@;o00002OoN/jD4o`0001koUI^?0_l0000?oinkY0co00001OnY
a[h3o`0000Kooooo1Ol0000PoiB][`?o00004_n[[iX6o`0001;ocKjR1Ol00004oi75b@?o00008On0
Sfh3o`00027oi^KJ0_l0000Nooooo`;o00005_ooool5o`0006kooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0T?ooool3o`0000gooooo0_l0000Iooooo`;o00005Oooool3
o`0001WoQZ>Y0ol00007omjcY@Co00007_nEVhl3o`0001CoWk^T3ol000000ooooooo0000o`00000;
o`0001coU:f_0ol0000Foj^_VPGo00003Oo=_Z86o`0000OoTLG90ol0000Poh2?KP;o00008_oVi]X3
o`0001cooooo0ol0000Hooooo`Co0000KOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2?ooooo`?o00003_ooool2o`0001Wooooo0ol0000Dooooo`;o00006on6XjT2o`00
00Gog[>U1?l0000PoiFKS`;o00006onO^j@@o`0000?oNF^W1ol0000IoiB][`;o00006On[[iX5o`00
00WocKjR1_l0000:oi75b@?o00007on0Sfh2o`0002?oi^KJ0_l0000Kooooo`?o00006oooool2o`00
06gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0S_ooool3o`0000oo
oooo0ol0000Iooooo`;o00004oooool3o`0001_oQZ>Y0ol00003omjcY@Co00008OnEVhl2o`00027o
Wk^T1Ol0000;ogU[Y`Ko00005_nD[Jl3o`0001_oZjnJ1_l00004olfnXPGo00003_nAaLT3o`0001ko
P8m^0_l0000SonKVfP?o00005Oooool7o`0001cooooo0ol0001/ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08gooooo0ol0000Aooooo`;o00006Oooool3o`00017ooooo
0ol0000MohJSZ@;o000000?og[>Uo`000?l000000_l0000RoiFKS`?o00008_nO^j@3o`0000ooNF^W
1_l0000BoiB][`?o00007_n[[iX;o`00017oTLG90ol0000Moh2?KP;o00009?oVi]X2o`0000cooooo
3ol0000Nooooo`?o0000Joooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`2<ooooo`?o00004_ooool2o`0001[ooooo0ol0000@ooooo`;o00007_n6XjT6o`0002?oUI^?0_l0
000SoinkY0;o00004_miJjL6o`0000ooU:f_0ol0000Roj^_VPKo00005?nAaLT3o`0001_oP8m^0ol0
000TonKVfP;o00000ooooolCo`0000?oaZFM0_l0000Oooooo`;o0000Joooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`?o00004oooool2o`0001_ooooo0_l0000?
ooooo`?o00007_n6XjT4o`0002GoUI^?0_l0000SoinkY0;o00005OmiJjL6o`0000_oU:f_0ol0000U
oj^_VP;o00005onAaLT3o`0001[oP8m^0_l0000UonKVfPoo00003?o6YId3o`0001kooooo0ol0001Z
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08[ooooo0ol0000Doooo
o`;o00006oooool3o`0000gooooo0ol0000PohJSZ@;o00009OnEVhl3o`0002;oWk^T0ol0000GogU[
Y`Oo00002?nD[Jl2o`0002KoZjnJ0_l0000Hoi75b@?o00006On0Sfh2o`0002Koi^KJ1Ol0000FolJU
W@;o00007oooool3o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo0ol00029ooooo`?o
00005Oooool3o`0001_ooooo0ol0000<ooooo`;o00008?n6XjT3o`0002GoUI^?0_l0000SoinkY0;o
00006omiJjL6o`0000GoU:f_0ol0000Voj^_VP;o00006OnAaLT3o`0001SoP8m^0_l0000UonKVfP?o
00006Oo6YId2o`00023ooooo0_l0001Wooooo`?o00002_ooool001[ooooo00?o0000ooooooooool0
R?ooool3o`0001Oooooo0_l0000Looooo`;o00002oooool3o`0001goQZ>Y1_l0000UoiFKS`;o0000
8onO^j@2o`0001koNF^W1_l000001?nD[Joo0000o`000?l0000Voj^_VP?o00006_nAaLT3o`0001Oo
P8m^0_l0000TonKVfP?o00006_o6YId2o`00023ooooo0ol0001Xooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08Oooooo0ol0000Hooooo`;o00007?ooool3o`0000Wooooo
0ol0000KohJSZ@[o00008onEVhl3o`0002;oWk^T0ol0000PogU[Y`Oo00009on[[iX2o`0001coTLG9
0ol0000Eoh2?KP?o00008?oVi]X6o`0001_oaZFM0_l0000Qooooo`?o0000Ioooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`26ooooo`?o00006Oooool2o`0001gooooo1Ol0
0006ooooo`;o00006On6XjT7o`0000CoY/N_0ol0000RoiFKS`;o00008onO^j@2o`0002CoNF^W1?l0
000Woj^_VP;o00007OnAaLTIo`0001[oi^KJ3?l0000LolJUW@?o00008Oooool2o`0006Oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0QOooool3o`0001[ooooo0_l0000N
ooooo`So000000Coooooo`000?l0003o00005_n6XjT7o`0000SoY/N_0_l0000RoiFKS`;o00008_nO
^j@3o`0002?oNF^W1_l0000Voj^_VP;o00007_nAaLTIo`0001;oi^KJ3ol00002okOA/P;o00007Oo6
YId2o`00027ooooo0_l0001Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08Gooooo0_l0000Kooooo`;o00007Oooool3o`000003okO8VOl0003o000000Ko00005?n6XjT7
o`0000_oY/N_0ol0000PoiFKS`?o00008_nO^j@2o`0002CoNF^W0_l00002om6M`@?o00009On[[iX2
o`0001goTLG90ol0000Eom>VZ0?o00002_oVi]X?o`0000Wo]m6b0_l0000MolJUW@;o00008Oooool2
o`0006Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0QOooool2o`00
01_ooooo0ol0000Kooooo`?o00001_ngb9T4o`00017oQZ>Y1ol0000?ojK7[`Co00007_nEVhl2o`00
02?oWk^T0_l0000SogU[Y`?o00000ooAWL43o`0002CoZjnJ0_l0000Moi75b@;o00005ooCYZP3o`00
00;oi^KJ3ol0000@okOA/P;o00007Oo6YId2o`00027ooooo0_l0001Wooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Looooo`;o00006_ooool3o`0000Wo
]lRI0ol0000=ohJSZ@Oo00004onVajl5o`0001coUI^?0_l0000RoinkY0?o00008omiJjL2o`0000Go
dIg10ol0000Soj^_VP;o00007OnAaLT2o`0001SodjJX3?l0000GokOA/P?o00007?o6YId3o`00023o
oooo0_l0001Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo
0_l0000Looooo`;o00006Oooool3o`0000_o]lRI0ol00009ohJSZ@Oo00005OnVajl8o`0001WoUI^?
0ol0000RoinkY0;o00008omiJjL3o`0000KodIg10ol0000Qoj^_VP?o00007?nAaLT3o`0001WodjJX
1?l0000OokOA/P;o00007Oo6YId2o`00023ooooo0_l0001Wooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Looooo`;o00006?ooool3o`0000go]lRI0ol0
0005ohJSZ@Oo00005onVajl3o`0000?o_H:71Ol0000GoiFKS`;o00008onO^j@2o`0002?oNF^W0_l0
0008om6M`@?o00008?n[[iX2o`0001goTLG90_l0000Jom>VZ0;o00008OngdK82o`0001goaZFM0_l0
000Pooooo`;o0000Ioooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`25
ooooo`;o00007?ooool2o`0001Sooooo0_l0000?okO8V@?o000000?oQZ>Yo`000?l000001Ol0000J
ojK7[`;o00001_nmPXL5o`0001GoUI^?0_l0000RoinkY0?o00008_miJjL3o`0000WodIg10ol0000O
oj^_VP;o00007?nAaLT3o`0001[odjJX0_l0000QokOA/P;o00007Oo6YId2o`00023ooooo0_l0001W
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Loooo
o`?o00005_ooool3o`00013o]lRI1ol0000LojK7[`?o00002?nmPXL5o`0001;oUI^?0ol0000Roink
Y0;o00008omiJjL2o`0000_odIg10ol0000Noj^_VP;o00007?nAaLT2o`0001_odjJX0_l0000QokOA
/P;o00007Oo6YId3o`0001kooooo0ol0001Wooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo08Gooooo0_l0000Mooooo`;o00005Oooool3o`0001;o]lRI0ol0000OojK7[`;o
00002onmPXL5o`00013oUI^?0_l0000RoinkY0?o00008_miJjL3o`0000codIg10ol0000Moj^_VP;o
00006onAaLT3o`0001_odjJX0_l0000QokOA/P;o00007_o6YId2o`0001kooooo0_l0001Xooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Mooooo`;o0000
5?ooool3o`0001?o]lRI0_l0000OojK7[`?o00003OnmPXL5o`0000koUI^?0_l0000RoinkY0;o0000
8omiJjL2o`0000kodIg10ol0000Loj^_VP;o00006onAaLT2o`0001codjJX0ol0000PokOA/P;o0000
7_o6YId2o`0001kooooo0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo08Gooooo0_l0000Mooooo`;o00004oooool3o`0001Co]lRI0_l0000NojK7[`?o00004?nm
PXL5o`0000_oUI^?0ol0000RoinkY0;o00008_miJjL3o`0000oodIg10ol0000Koj^_VP;o00006onA
aLT2o`0001godjJX0_l0000PokOA/P;o00007_o6YId2o`0001kooooo0_l0001Xooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Mooooo`;o00004_ooool3
o`0001Go]lRI0ol0000MojK7[`;o00004onmPXL5o`0000WoUI^?0_l0000RoinkY0?o00008_miJjL2
o`00017odIg10ol0000Ioj^_VP?o00006_nAaLT3o`0001godjJX0_l0000PokOA/P?o00007Oo6YId2
o`0001kooooo0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08Gooooo0_l0000Mooooo`?o00004Oooool2o`0001Oo]lRI0_l0000LojK7[`?o00005OnmPXL5o`00
00OoUI^?0_l0000RoinkY0;o00008_miJjL3o`0001;odIg10ol0000Hoj^_VP;o00006onAaLT2o`00
01kodjJX0_l0000QokOA/P;o00007Oo6YId3o`0001gooooo0_l0001Xooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo0_l0000Nooooo`;o00004?ooool3o`0001Oo
]lRI0_l0000LojK7[`;o00006?nmPXL5o`0000CoUI^?0ol0000RoinkY0;o00008_miJjL2o`0001Co
dIg10ol0000Goj^_VP;o00006_nAaLT3o`0001kodjJX0_l0000QokOA/P;o00007_o6YId2o`0001go
oooo0_l0001Xooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Gooooo
0_l0000Nooooo`;o00003oooool3o`0001So]lRI0_l0000KojK7[`?o00006_nmPXL5o`0000;oUI^?
0_l0000QoinkY0Co00008OmiJjL3o`0001GodIg10ol0000Foj^_VP;o00006_nAaLT2o`0001oodjJX
0_l0000QokOA/P;o00007_o6YId2o`0001gooooo0_l0001Xooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo08Gooooo1?l0000Looooo`;o00003_ooool3o`0001Wo]lRI0_l0
000JojK7[`?o00007OnmPXL7o`0001ooWk^T1ol0000PogU[Y`;o00005ooAWL43o`0001GoZjnJ0_l0
000Ioi75b@?o00007ooCYZP2o`00027o]m6b0_l0000NolJUW@;o00006oooool5o`0006Oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Q?ooool8o`0001Wooooo0_l0000=
ooooo`?o00006_ngb9T2o`0001[oY/N_0_l0000Pokf2Q`Go00007?nO^j@6o`0000;oR;Rf1?l0000M
ogU[Y`?o00006?oAWL43o`0001CoZjnJ0_l0000Ioi75b@;o00008?oCYZP2o`00027o]m6b0_l0000N
olJUW@?o00005_ooool:o`0006Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Poooool3o`0000;ooooo2?l0000Eooooo`;o00003Oooool2o`0001_o]lRI0_l0000IojK7
[`?o00008_nmPXL2o`0001_oWk^T1_l00005ohRh]PCo00007?miJjL2o`0001[odIg10ol0000Coj^_
VP;o00006OnAaLT2o`00023odjJX0_l0000QokOA/P;o00007oo6YId2o`0001;ooooo2Ol00003oooo
o`?o0000IOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`?o
00001_ooool8o`0001;ooooo0ol0000;ooooo`?o00006ongb9T3o`0001SoY/N_0_l0000Sokf2Q`?o
00006?nO^j@5o`0000[oR;Rf1?l0000IogU[Y`?o00006ooAWL43o`00017oZjnJ0ol0000Hoi75b@?o
00008?oCYZP2o`00027o]m6b0_l0000OolJUW@;o00003Oooool:o`0000Sooooo0ol0001Tooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0ol0000;ooooo`Oo0000
4?ooool2o`0000[ooooo0ol0000MokO8V@;o00005onVajl3o`0002Co_H:70_l0000EoinkY0Ko0000
3On8^;H4o`0001SoNF^W0_l0000Mom6M`@?o00004?n[[iX2o`0001WoTLG90_l0000Qom>VZ0;o0000
8OngdK83o`0001koaZFM0_l00009ooooo`[o00003Oooool3o`0006?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0P?ooool3o`0000oooooo2?l0000<ooooo`;o00002Ooo
ool3o`0001ko]lRI0_l0000FojK7[`?o00009OnmPXL3o`0001;oWk^T1_l0000AohRh]PCo00005Omi
JjL3o`0001kodIg10ol0000?oj^_VP;o00006?nAaLT3o`00027odjJX0ol0000QokOA/P;o00007_o6
YId2o`0000Gooooo2Ol0000Cooooo`?o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1oooooo`?o00004oooool8o`0000Wooooo0_l00008ooooo`?o00007ongb9T2
o`0001KoY/N_0_l0000Wokf2Q`;o00004?nO^j@5o`0001GoR;Rf1?l0000DogU[Y`;o00008?oAWL43
o`0000koZjnJ0_l0000Hoi75b@;o00008ooCYZP2o`00027o]m6b0_l0000NolJUW@co00006?ooool2
o`0006;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool3o`00
01Sooooo2?l00005ooooo`;o00001oooool3o`00023o]lRI0_l0000EojK7[`?o00009onmPXL3o`00
00coWk^T1_l0000IohRh]PCo00004OmiJjL3o`00027odIg10ol0000=oj^_VP;o00005onAaLT3o`00
02?odjJX0_l0000QokOA/P;o00007oo6YId7o`0001cooooo0_l0001Rooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0ol0000Looooo`So00000_ooool3o`0000Ko
oooo0_l0000QokO8V@;o00005?nVajl3o`0002Wo_H:70_l0000:oinkY0Ko00007?n8^;H4o`00013o
NF^W0_l0000Som6M`@?o00003?n[[iX2o`0001OoTLG90_l0000Tom>VZ0;o00008OngdK82o`0001oo
aZFM0ol0000Pooooo`;o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1looooo`?o00008Oooool9o`0000Gooooo0ol0000QokO8V@;o00005?nVajl2o`0002[o_H:7
0_l00008oinkY0Go00008On8^;H4o`0000goNF^W0ol0000Tom6M`@?o00002on[[iX2o`0001OoTLG9
0_l0000Som>VZ0Co00008?ngdK82o`0001koaZFM0ol0000Qooooo`?o0000HOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1kooooo`?o00009Oooool6o`0000Cooooo0ol0
000RokO8V@?o00004_nVajl3o`0002[o_H:70ol00004oinkY0Ko00009?n8^;H4o`0000coNF^W0_l0
000Vom6M`@?o00002On[[iX3o`00013oTLG92Ol0000Rom>VZ0Ko00007ongdK82o`0001goaZFM0ol0
000Sooooo`;o0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1k
ooooo`;o0000:Oooool4o`0000;ooooo0ol0000TokO8V@;o00004_nVajl2o`0002co_H:70_l00002
oinkY0Ko0000:?n8^;H4o`0000WoNF^W0ol0000Wom6M`@?o00002?n[[iX2o`0000CoTLG95ol0000P
om>VZ0?o00000_nEO8h4o`0001go]m6b0_l0000MolJUW@;o00009?ooool2o`00067ooooo00?o0000
ooooooooool02?ooool000Sooooo0ol00003ooooo`;o00002_ooool00ol0003oooooooooo`1koooo
o`;o0000:oooool6o`0002Go]lRI0_l0000AojK7[`?o0000:onmPXL8o`0002coR;Rf1?l00008ogU[
Y`;o0000:OoAWL43o`0000KoZjnJ5Ol00007okV[_@?o00007OoCYZP4o`0000CoUGb>1Ol0000KokOA
/P?o00006?o6YId6o`0002Cooooo0_l0001Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07_ooooo0_l0000/ooooo`Co00009_ngb9T2o`00013oY/N_0ol0000Yokf2Q`Wo0000<?n8^;H4o`00
00GoNF^W0ol0000Zom6M`@?o00001?n[[iX9o`0001Go^J^m0ol0000Kom>VZ0Co00001onEO8h4o`00
01_o]m6b0_l0000ColJUW@[o00009Oooool2o`00067ooooo00?o0000ooooooooool02?ooool000Ko
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo1Ol0001iooooo`;o0000:oooool6o`00
02Go]lRI0_l0000@ojK7[`;o00009onmPXL>o`0002ooR;Rf1?l00004ogU[Y`;o0000;?oAWL43o`00
00;oZjnJ0ol0000MokV[_@?o00006?oCYZP4o`0000_oUGb>1?l0000IokOA/P;o00003_o6YId;o`00
00;o`l>S0ol0000Tooooo`;o0000GOooool5o`0000[ooooo0006ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`1kooooo`;o0000:_ooool3
o`000003om7I/Ol0003o000000Co00008_ngb9T2o`0000ooY/N_0ol0000Tokf2Q`Oo00000oo9g:h2
o`0000;oZI751?l0000`ohRh]PCo000000CoNF^Wo`000?l0003o0000;OoAWL46o`0001oo^J^m0ol0
000Fom>VZ0Co00003OnEO8h5o`00017o]m6b2Ol00008olJUW@_o00002?o3`j<2o`0002Cooooo0ol0
001Pooooo`03o`000?oooooooooo00Sooooo0007ooooo`03o`000?oooooo000000?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`1kooooo`;o0000:Oooool3o`0000;odMVa2Ol0
000OokO8V@;o00003onVajl2o`0002;o_H:71ol00005olWL[P?o00000_nYTLD5o`00033oR;Rf1_l0
000_om6M`@Co00008OniZkd3o`0001CodjJX0ol0000AoiElSPCo00001OngdK8Eo`0000;oaZFM2ol0
000=ol?3X`?o00009?ooool2o`00063ooooo00?o0000ooooooooool02?ooool000Sooooo0_l00003
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0Noooool2o`0002Oooooo1?l0
0003om7I/@;o00000on`^>X7o`0001co]lRI0ol0000=ojK7[`?o00007onmPXL7o`0000OobMb^0ol0
0003ojVAa@;o000000Co[Z>[o`000?l0003o0000<On8^;H4o`00033odIg10_l0000SokV[_@Co0000
4?oCYZP4o`0001CoUGb>4ol00007oij0V`[o00004oo3`j<2o`0002Cooooo0_l0001Pooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l0000:ooooo`03o`000?oo
oooooooo07_ooooo0_l0000Vooooo`Co00001?oAfK42o`0000Ko/;SZ1ol0000JokO8V@;o00003?nV
ajl3o`0001go_H:71ol0000:olWL[P;o00001?nYTLD2o`0000;o[Z>[0ol0000aohRh]P;o0000<?oA
WL43o`0002Co^J^m1?l0000>om>VZ0Co00005_nEO8h7o`0001?oWX2K1?l0000Hol?3X`?o00008ooo
ool2o`00063ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Noooool2
o`0002Gooooo0ol00006om7I/@;o00002On`^>X7o`0001Oo]lRI0_l0000<ojK7[`;o00006onmPXL7
o`0000cobMb^0ol00004ojVAa@;o00000on^Xj/4o`0002ooR;Rf0_l0000`om6M`@;o00009oniZkd3
o`0000codjJX0ol0000HoiElSP;o00006?nNP9/2o`0001_o`l>S0_l0000Sooooo`;o0000H?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1jooooo`?o00009?ooool3o`00
00OodMVa0_l0000<ok2hjPKo00005?ngb9T5o`0000WoY/N_0ol0000Hokf2Q`Oo00003oo9g:h2o`00
00GoZI750_l00004ojjSZ`Co0000;_n8^;H3o`0002oodIg10_l0000XokV[_@?o00002OoCYZP4o`00
01WoUGb>0_l0000Hoij0V`;o00006oo3`j<3o`0002;ooooo0ol0001Oooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07[ooooo0_l0000Tooooo`?o00002?oAfK42o`0000oo
/;SZ1_l0000?okO8V@_o00001OnVajl2o`0001Ko_H:71ol0000AolWL[P?o00001OnYTLD2o`0000Ko
[Z>[0ol0000^ohRh]P;o0000;_oAWL43o`0002Wo^J^m0ol00007om>VZ0Co00006OnEO8h3o`0001So
WX2K0_l0000Lol?3X`;o00008oooool2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0N_ooool2o`0002;ooooo1?l00009om7I/@;o00004On`^>X7o`0000[o]lRI
1Ol00003oo37_0So000000CoY/N_o`000?l0003o00004onmPXL7o`0001?obMb^0ol00006ojVAa@;o
00001on^Xj/3o`0002goR;Rf0_l0000^om6M`@;o0000:oniZkd3o`0000CodjJX1?l0000KoiElSP;o
00006OnNP9/2o`0001co`l>S0ol0000Rooooo`;o0000Goooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1jooooo`;o00008Oooool4o`0000[odMVa0_l0000Dok2hjPOo0000
1Ongb9T5o`0000Wol<Nl1ol0000Aokf2Q`Oo00005_o9g:h2o`0000OoZI750_l00008ojjSZ`?o0000
;?n8^;H2o`0002kodIg10_l0000/okV[_@?o00000_oCYZP4o`0001coUGb>0_l0000Ioij0V`;o0000
7Oo3`j<2o`0002;ooooo0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07[ooooo0_l0000Pooooo`?o00003?oAfK42o`0001Oo/;SZ3?l0000>oo37_0Go00003Onm
PXL7o`0001SobMb^0ol00007ojVAa@;o00002On^Xj/3o`0002_oR;Rf0_l0000]om6M`@?o0000;Oni
Zkd6o`0001koUGb>0_l0000Ioij0V`;o00007Oo3`j<3o`00027ooooo0_l0001Oooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo07[ooooo0_l0000Oooooo`?o00003OoAfK42
o`0001[o/;SZ1ol0000Coo37_0?o00002OnmPXL7o`0001_obMb^0_l00008ojVAa@;o00002_n^Xj/4
o`0002WoR;Rf0ol0000/om6M`@;o0000;oniZkd4o`0001ooUGb>0_l0000Ioij0V`;o00007_o3`j<2
o`00027ooooo0_l0001Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
07[ooooo0_l0000Mooooo`Co00003_oAfK42o`0001go/;SZ0_l0000Foo37_0?o00001OnmPXL7o`00
01gobMb^0ol00008ojVAa@;o00002on^Xj/4o`0002WoR;Rf0_l0000/om6M`@;o0000<?niZkd2o`00
023oUGb>0_l0000Ioij0V`;o00007_o3`j<3o`00023ooooo0ol0001Nooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07[ooooo0_l0000Looooo`Co00003ooAfK42o`0001go
/;SZ0_l0000Goo37_0?o000000?o_H:7o`000?l000001Ol0000OolWL[P?o00002OnYTLD2o`0000go
[Z>[0ol0000WohRh]PCo0000:_oAWL43o`00033o^J^m0_l0000OoiElSP?o00006OnNP9/2o`0001oo
`l>S0_l0000Qooooo`;o0000G_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1iooooo`Co00006_ooool3o`00017odMVa0_l0000Lok2hjP?o00006?o`ak`7o`0002;obMb^
0_l0000:ojVAa@;o00003_n^Xj/3o`0002CoR;Rf1ol0000Yom6M`@;o0000<OniZkd2o`0001ooUGb>
0_l0000Joij0V`;o00007oo3`j<3o`00023ooooo0_l0001Nooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo07Oooooo1ol0000Hooooo`?o00004_oAfK42o`0001co/;SZ0_l0
000Joo37_0?o00009?o9g:h3o`0000[oZI750_l0000?ojjSZ`?o00008On8^;H5o`0000;oc^_C1?l0
000Wom6M`@;o0000<OniZkd2o`0001ooUGb>0_l0000Joij0V`;o00008?o3`j<2o`00023ooooo0_l0
001Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07Gooooo1Ol00002
ooooo`Co00005?ooool4o`0001?odMVa0_l0000Lok2hjP;o00006_o`ak`2o`0002GobMb^0_l0000;
ojVAa@;o00004?n^Xj/4o`0001goR;Rf1Ol00005olk[d`Co00009OoAWL43o`00037o^J^m0_l0000O
oiElSP;o00006_nNP9/2o`00023o`l>S0_l0000Oooooo`?o0000G_ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1cooooo`Go00001Oooool4o`0001;ooooo1?l0000Com7I
/@?o00007?n`^>X2o`0001[ol<Nl0ol0000SolWL[P?o00002onYTLD2o`00017o[Z>[1?l0000KohRh
]PCo00002Oo>jm<4o`0002?odIg10_l0000bokV[_@;o00007onEO8h2o`0001[oWX2K0_l0000Pol?3
X`?o00007_ooool2o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0LOooool5o`0000Wooooo1?l0000?ooooo`?o00005?oAfK44o`0001_o/;SZ0ol0000Koo37_0;o
00008_o9g:h3o`0000coZI750_l0000CojjSZ`?o00006?n8^;H4o`0000coc^_C1?l0000Qom6M`@?o
0000<_niZkd2o`0001ooUGb>0_l0000Joij0V`;o00008Oo3`j<2o`0001kooooo0_l0001Oooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06oooooo1Ol0000<ooooo`Co0000
3Oooool3o`0001CodMVa1_l0000Jok2hjP;o00007?o`ak`2o`0002;obMb^0_l0000=ojVAa@;o0000
5?n^Xj/3o`0001GoR;Rf1Ol0000?olk[d`Co00007ooAWL42o`0003?o^J^m0_l0000NoiElSP?o0000
6_nNP9/2o`00027o`l>S0ol0000Looooo`?o0000Goooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1^ooooo`Co00004?ooool3o`0000_ooooo0ol0000Dom7I/@?o00000_o7
]lP2o`0001[o/;SZ0_l0000Loo37_0?o00008?o9g:h3o`0000goZI750_l0000EojjSZ`?o00004_n8
^;H5o`0001;oc^_C1?l0000Nom6M`@;o0000<oniZkd2o`0001koUGb>0_l0000Koij0V`;o00008_o3
`j<2o`0001cooooo0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo06kooooo0_l0000Cooooo`Co00001oooool4o`0001CodMVa0ol00003olNgb0;o00006_n`^>X2
o`0001gol<Nl0_l0000PolWL[P;o00003_nYTLD2o`0001Ko[Z>[0ol0000?ohRh]PGo00005_o>jm<4
o`0001_odIg10ol0000cokV[_@;o00007_nEO8h2o`0001_oWX2K0_l0000Rol?3X`?o00006oooool2
o`00063ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0KOooool3o`00
01Cooooo1?l00005ooooo`Co00005?oAfK43o`0000CoakO80_l0000Iok2hjP?o00007Oo`ak`2o`00
01oobMb^0ol0000>ojVAa@;o00005on^Xj/4o`0000_oR;Rf1Ol0000Iolk[d`Co00006_oAWL42o`00
03Co^J^m0_l0000NoiElSP;o00006onNP9/2o`0002?o`l>S0_l0000Jooooo`?o0000H?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1]ooooo`;o00005oooool4o`0000;o
oooo0ol0000Eom7I/@?o00001Oo7]lP2o`0001Wo/;SZ0_l0000Noo37_0;o00007_o9g:h3o`0000oo
ZI750_l0000HojjSZ`Co00002?n8^;H5o`0001goc^_C1?l0000Hom6M`@;o0000=?niZkd2o`0001ko
UGb>0_l0000Koij0V`;o00008oo3`j<3o`0001Oooooo1?l0001Qooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06cooooo0ol0000Hooooo`Oo00005OoAfK43o`0000KoakO8
0ol0000Hok2hjP;o00007_o`ak`3o`0001gobMb^0_l0000@ojVAa@;o00006_n^Xj/3o`0000KoR;Rf
1?l0000Polk[d`Go00005OoAWL43o`0003Co^J^m1?l0000LoiElSP;o00006onNP9/2o`0002Co`l>S
0_l0000Cooooo`So0000HOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1/ooooo`;o00006oooool4o`0001GodMVa0ol00008olNgb0;o00006?n`^>X2o`0001ool<Nl0_l0
000LolWL[P?o00004?nYTLD2o`0001_o[Z>[0ol00003ohRh]PCo00009?o>jm<4o`0001CodIg10_l0
000eokV[_@Oo00006?nEO8h3o`0001_oWX2K0_l0000Tol?3X`?o00003_ooool9o`000004ooooool0
003o0000o`00063ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0K?oo
ool2o`0001cooooo0_l0000Eom7I/@?o00002Oo7]lP2o`0001Oo/;SZ0ol0000Ooo37_0;o00007?o9
g:h2o`00017oZI750_l0000LojjSZ`So00009oo>jm<4o`0001;odIg10_l0000dokV[_@?o000000?o
][c@o`000?l000001Ol0000EoiElSP;o00007?nNP9/2o`0002Go`l>S0_l0000:ooooo`Wo00001_oo
ool3o`0005oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Joooool3
o`0001cooooo0ol0000Com7I/@?o00002_o7]lP2o`0001Oo/;SZ0_l0000Poo37_0?o00006_o9g:h3
o`00017oZI750_l0000MojjSZ`Go0000:_o>jm<4o`00013odIg10ol0000cokV[_@?o00001Onf_=08
o`00017oUGb>0_l0000Loij0V`;o00009Oo3`j<3o`0000Gooooo2Ol0000;ooooo`?o0000G_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o00007_ooool2o`00
01;odMVa0ol0000;olNgb0;o00005on`^>X2o`00023ol<Nl0ol0000IolWL[P?o00004_nYTLD2o`00
01ko[Z>[0_l0000^olk[d`Co00003_oAWL42o`0003?o^J^m0ol00009okJld0So00003_nEO8h2o`00
01coWX2K0_l0000Vol?3X`;o000000?oooooo`000?l000001ol0000@ooooo`?o0000GOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Zooooo`?o00007_ooool2o`00017o
dMVa0ol0000<olNgb0?o00005On`^>X3o`0001ool<Nl1Ol0000HolWL[P;o00004onYTLD2o`0001ko
[Z>[0_l0000_olk[d`Co00003OoAWL42o`0003?o^J^m0_l0000>okJld0Oo00002onEO8h2o`0001co
WX2K0_l0000Vol?3X`So00005Oooool3o`0005cooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0J_ooool2o`0001oooooo0ol0000?om7I/@?o00003_o7]lP2o`0001Go/;SZ
0_l0000Ooo37_0?o000000Co];:Uo`000?l0003o00005_o9g:h3o`0001?oZI750_l0000NojjSZ`;o
0000<Oo>jm<4o`0000WodIg11Ol0000aokV[_@?o00004Onf_=08o`0000OoUGb>0_l0000Loij0V`;o
00009oo3`j<3o`0001[ooooo0ol0001Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo06Wooooo0ol0000Pooooo`;o00003_oAfK43o`0000ooakO80_l0000Eok2hjP;o0000
7Oo`ak`4o`0000?o];:U0ol0000EolWL[P;o00005?nYTLD2o`0001go[Z>[0ol0000bolk[d`Co0000
1_oAWL4:o`0002go^J^m0ol0000EokJld0So00000onEO8h3o`0001coWX2K0_l0000Vol?3X`?o0000
7?ooool3o`0005[ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOoo
ool2o`00027ooooo0ol0000<om7I/@?o00004?o7]lP2o`0001Go/;SZ0_l0000Loo37_0Co00001Ond
/ZD3o`0001?obMb^0ol0000DojVAa@;o00007On^Xj/2o`0003Goc^_C1?l00003om6M`@Co00000on;
]Id7o`0002Wo^J^m0ol0000JokJld0Wo00007OnNP9/2o`0002Go`l>S0ol0000Nooooo`?o0000FOoo
ool00ol0003oooooooooo`08ooooo`006_ooool3o`0006Sooooo0ol0000Rooooo`;o00002ooAfK43
o`00017oakO80_l0000Dok2hjP?o00006oo`ak`3o`0000So];:U0ol0000AolWL[P?o00005OnYTLD2
o`0001go[Z>[0_l0000folk[d`So00002?n;]Id7o`0002Ko^J^m0_l0000NokJld0Ko00007OnNP9/2
o`0002Go`l>S0_l0000Pooooo`?o0000E_ooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo
06Sooooo0_l0000Sooooo`?o00002OoAfK43o`0001;oakO80ol0000Cok2hjP;o00006oo`ak`3o`00
00[o];:U0ol0000@olWL[P;o00005_nYTLD2o`0001go[Z>[0_l0000holk[d`Go00003?n;]Id7o`00
02;o^J^m0ol0000QokJld0?o00007?nNP9/5o`00027o`l>S1?l0000Qooooo`?o0000Eoooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Wooooo`?o00009?ooool2o`0000So
dMVa0ol0000DolNgb0;o00004on`^>X2o`0001Wol<Nl1?l0000<okBbY@?o00003_o9g:h3o`0001Ko
ZI750_l0000MojjSZ`;o0000>Oo>jm<2o`00017oRkFM1ol0000NokV[_@?o00008onf_=03o`0001[o
WX2K2ol0000Iol?3X`Ko00008oooool3o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Ioooool2o`0002Gooooo0_l00007om7I/@?o00005Oo7]lP2o`0001?o/;SZ
0_l0000Hoo37_0Co00003_nd/ZD3o`0000gobMb^0_l0000GojVAa@;o00007?n^Xj/3o`0003Soc^_C
0ol0000Doh^eW@Oo00006_niZkd3o`0002Go][c@0ol0000Hoij0V`?o00000onadJD;o`00017o`l>S
2_l0000Sooooo`;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Wooooo`;o00009Oooool4o`0000CodMVa0ol0000FolNgb0;o00004_n`^>X3o`0001Ool<Nl0ol0
000AokBbY@?o00002oo9g:h3o`0001OoZI750_l0000LojjSZ`;o0000>Oo>jm<2o`0001SoRkFM1ol0
000GokV[_@;o00009onf_=03o`0001GoWX2K1?l00009ok7AY@_o00002Oo3`j<7o`0000Co`mS60_l0
000Sooooo`;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1V
ooooo`?o00009?ooool6o`0000;odMVa0ol0000GolNgb0;o00004_n`^>X2o`0001Kol<Nl1?l0000C
okBbY@?o00002Oo9g:h3o`0001SoZI750_l0000LojjSZ`;o0000>Oo>jm<2o`0001_oRkFM1ol0000C
okV[_@?o0000:?nf_=08o`0000koWX2K1?l0000?ok7AY@_o000000?o`l>So`000?l000001Ol00007
ol?HaP?o00008_ooool2o`0005Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0I_ooool2o`0002Cooooo0ol00002oj[0W0Ko00006?o7]lP3o`00017o/;SZ0_l0000Eoo37
_0Co00005Ond/ZD3o`0000SobMb^0_l0000IojVAa@;o00007?n^Xj/2o`0003Soc^_C0ol0000Noh^e
W@Oo00003oniZkd3o`0002[o][c@4?l00004oij0V`?o00005_nadJD;o`0000_o`mS60_l0000Roooo
o`?o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Uooooo`?o
00008_ooool4o`0000CoZ/2L1?l0000JolNgb0;o00004On`^>X2o`0001Col<Nl0ol0000HokBbY@?o
00001_o9g:h3o`0001WoZI750_l0000LojjSZ`;o0000>?o>jm<2o`0002;oRkFM1ol0000;okV[_@?o
0000:_nf_=03o`0000CoUjZS4?l0000Lok7AY@?o00003_o3f<H2o`0002?ooooo0_l0001Eooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Gooooo0_l0000Rooooo`Co0000
1_nZ`9`Po`0000oo/;SZ0ol0000Coo37_0?o00006_nd/ZD3o`0000GobMb^0_l0000JojVAa@;o0000
6on^Xj/3o`0003Soc^_C0_l0000Uoh^eW@Oo00002?niZkd2o`0002_o][c@0_l0000>oiNZX`Ko0000
7_nadJD2o`0000ko`mS60ol0000Rooooo`;o0000EOooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Uooooo`;o00008Oooool3o`0000WoZ/2L8?l0000>ok2hjP;o00004_o`
ak`4o`0001co];:U0ol00003olWL[P?o00006_nYTLD2o`0001_o[Z>[0_l0000holk[d`?o0000:?n;
]Id7o`0000Co^J^m0ol0000ZokJld0?o00004_nGZZ<2o`0001ko/M6U0_l0000?ol?HaP;o00008_oo
ool2o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool2
o`00023ooooo0ol0000:oj[0W0;o00007?oH]LX4o`0000co/;SZ0_l0000Aoo37_0Co00007_nd/ZD3
o`000004olWL[_l0003o0000o`0001_oZI750_l0000IojjSZ`Co0000>?o>jm<2o`0002coRkFM2_l0
000ZokJld0?o00004onGZZ<2o`0001ko/M6U0_l0000?ol?HaP?o00008Oooool2o`0005Gooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool2o`0001kooooo1?l0000;
oj[0W0;o00007OoH]LX4o`0000_o/;SZ0_l0000@oo37_0?o00008Ond/ZD5o`0001coZI750_l0000E
ojjSZ`So0000>?o>jm<2o`0002ooRkFM1_l0000[okJld0;o00005?nGZZ<2o`0001go/M6U0ol0000@
ol?HaP;o00008Oooool2o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0IOooool2o`0001gooooo1?l0000<oj[0W0;o00007ooH]LX4o`0000So/;SZ0ol0000>oo37
_0Co00008ond/ZD4o`0001coZI750_l0000AojjSZ`Wo000000Co]n6fo`000?l0003o0000=_o>jm<3
o`0003;oRkFM0_l0000[okJld0?o00005?nGZZ<3o`0001co/M6U0_l0000Aol?HaP?o00008?ooool3
o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool3o`00
01_ooooo0ol0000>oj[0W0?o00007ooH]LX4o`0000?o/;SZ1ol0000=oo37_0Co00009Ond/ZD2o`00
01goZI750_l0000<ojjSZ`[o00001_nghKH3o`0003Goc^_C0_l0000coh^eW@?o0000:_nf_=02o`00
01KoUjZS0_l0000Lok7AY@;o00004_o3f<H2o`00027ooooo0_l0001Dooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo06Kooooo0_l0000Iooooo`Co00004?nZ`9`2o`00027o
f;G:3Ol0000;oo37_0?o00009ond/ZD3o`0001coZI750_l00008ojjSZ`[o00002onghKH3o`0003Co
c^_C0_l0000doh^eW@;o0000:Onf_=03o`0001KoUjZS0_l0000Lok7AY@;o00004_o3f<H2o`00027o
oooo0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Kooooo
0_l0000Hooooo`Co00004OnZ`9`2o`0002;of;G:1Ol00005ojj4c@Co00002?o`ak`3o`0002Wo];:U
0_l0000LojVAa@;o00001?n^Xj/9o`00017o]n6f0_l0000colk[d`?o0000=?n;]Id2o`0002So][c@
0ol0000GoiNZX`;o00007?nadJD2o`0001;o`mS60ol0000Pooooo`;o0000E?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Vooooo`;o00005oooool3o`0001?oZ/2L0_l0
000QomRebP?o00002On^Q<d4o`0000Gol<Nl1?l0000ZokBbY@;o00007?nYTLD;o`0001Go]n6f0ol0
000bolk[d`;o0000=On;]Id3o`0002Oo][c@0_l0000HoiNZX`;o00007?nadJD2o`0001?o`mS60_l0
000Pooooo`;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1V
ooooo`;o00005_ooool3o`0001CoZ/2L0_l0000PomRebP?o00003?n^Q<d4o`0000;ol<Nl1?l0000[
okBbY@Ko00005onYTLD8o`0001[o]n6f0ol0000aolk[d`;o0000=_n;]Id2o`0002Ko][c@0ol0000H
oiNZX`;o00007?nadJD2o`0001?o`mS60ol0000Oooooo`;o0000E?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1Uooooo`Co00004oooool4o`0001GoZ/2L0_l0000OomRe
bP?o00003_n^Q<d7o`0002ko];:U2ol0000@ojVAa@Go00007onghKH5o`0002goc^_C0ol0000foh^e
W@;o00009_nf_=02o`0001WoUjZS0_l0000Lok7AY@;o00005?o3f<H2o`0001oooooo0_l0001Doooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06Cooooo2?l0000?ooooo`Co
00005_nZ`9`2o`0001oof;G:0_l0000Aojj4c@Co0000;_nd/ZD3o`0000;odJV?3Ol00009ojVAa@?o
00008onghKH8o`0002Soc^_C0ol0000goh^eW@?o00009?nf_=03o`0001WoUjZS0ol0000Jok7AY@?o
00005?o3f<H3o`0001kooooo0ol0001Cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo06?ooooo0ol00002ooooo`Ko00003?ooool3o`0001SoZ/2L0_l0000NomRebP?o0000
4_n^Q<d2o`0002ko];:U0ol00009om6YS`go00000_nYTLD3o`0002Co]n6f0_l000000onW^;?o0000
o`000007o`0002;oc^_C1Ol0000hoh^eW@;o00008onf_=03o`0001_oUjZS0_l0000Jok7AY@;o0000
5_o3f<H2o`0001oooooo0_l0001Cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo067ooooo1?l00006oooooa7o00006OnZ`9`2o`0001gof;G:0ol0000Cojj4c@?o0000;?nd
/ZD3o`00013odJV?2ol0000TokOQ]P?o00001OnW^;<9o`0001coc^_C2?l0000goh^eW@?o00008_nf
_=02o`0001coUjZS0_l0000Jok7AY@;o00005_o3f<H3o`0001kooooo0_l0001Cooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo063ooooo1?l00009ooooo`ko00006_nZ`9`3
o`0001cof;G:0_l0000Eojj4c@;o0000;?nd/ZD2o`0001OodJV?1?l0000UokOQ]P;o00002_nW^;<:
o`0001Coc^_C1_l00003okJNe0;o0000>?n;]Id2o`00027o][c@0ol0000LoiNZX`;o00006OnadJD3
o`0001Oo`mS60_l0000Nooooo`;o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1Oooooo`?o00002oooool2o`0000[o_jVD0ol0000Joj[0W0;o00006ooH]LX3o`00
01Go[XC=0ol0000ZokBbY@?o00006OoAZHl3o`0002Co]n6f0_l0000>ojNh/`[o00003_o>jm<6o`00
00Go]YkD0ol0000goh^eW@;o00008Onf_=02o`0001goUjZS0_l0000Hok7AY@Co00005oo3f<H2o`00
01gooooo0ol0001Cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05ko
oooo0ol0000<ooooo`?o00002_noZI@3o`0001WoZ/2L0_l0000JomRebP?o00005on^Q<d3o`0002So
];:U0ol0000Kom6YS`;o00008onghKH3o`0001?oYkRc2Ol00008olk[d`Go00002OnfW]@2o`0003Oo
RkFM0ol0000OokJld0?o00007OnGZZ<2o`0001Ko/M6U1ol0000Fol?HaP?o00007?ooool2o`0005Co
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0GOooool3o`0000kooooo
0_l0000;oknYU0?o00006?nZ`9`No`0001Wo[XC=0_l0000WokBbY@?o00007?oAZHl2o`0002?o]n6f
0_l0000HojNh/`Wo00000_o>jm<5o`0000_o]YkD0ol0000goh^eW@;o00007_nf_=03o`0001koUjZS
0_l0000Eok7AY@Co00000_n4QH82o`0001Oo`mS60_l0000Kooooo`?o0000E?ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Mooooo`;o00003oooool2o`0000co_jVD0_l0
000Hoj[0W1go00006_n^Q<d3o`0002Go];:U0ol0000Mom6YS`?o00008_nghKH2o`0001coYkRc2_l0
000>okJNe0;o0000=on;]Id2o`0001ko][c@0_l0000OoiNZX`?o00004_nadJD4o`0000CoQ8F20ol0
000Fol?HaP?o00006Oooool3o`0005Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0G?ooool3o`0000oooooo0_l0000<oknYU0?o00005onZ`9`2o`0001WomOKj0_l0000K
ojj4c@;o00009Ond/ZD2o`0001oodJV?0_l0000RokOQ]P;o00008?nW^;<6o`0000ko]YkD0ol0000f
oh^eW@?o00007?nf_=03o`00023oUjZS0_l0000Aok7AY@Co00001_n4QH82o`0001Oo`mS60_l0000I
ooooo`;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Loooo
o`;o00004?ooool3o`0000co_jVD0ol0000Foj[0W0;o00006?oem_X3o`0001_o[XC=0ol0000SokBb
Y@?o00007ooAZHl2o`00027o]n6f0ol0000PojNh/`?o000000?oQZJdo`000?l000003onfW]@3o`00
03KoRkFM0_l0000LokJld0;o00008OnGZZ<2o`0000oo/M6U1?l00008ohB5PP?o00005_o3f<H3o`00
01Oooooo0ol0001Fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_o
oooo0ol0000Aooooo`;o00003OnoZI@3o`0001GoZ/2L0_l0000HooGfnP;o00007On^Q<d2o`0002;o
];:U0ol0000Pom6YS`?o00008?nghKH2o`00023oYkRc0ol00002ohJV]0;o00004?nfW]@2o`0003Ko
RkFM0ol0000JokJld0?o00008OnGZZ<2o`0000go/M6U1Ol0000:ohB5PP;o00005oo3f<H2o`0001Oo
oooo0_l0001Gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo
0_l0000Booooo`;o00003_noZI@3o`0001?oZ/2L0ol0000HooGfnP;o00007On^Q<d3o`0001ko];:U
1Ol0000Rom6YS`;o00008?nghKH2o`00023oYkRc0_l00003ohJV]0;o00004?nfW]@3o`0003KoRkFM
0_l0000JokJld0;o00008_nGZZ<2o`0000co/M6U1?l0000<ohB5PP?o00005_o3f<H2o`0001Kooooo
0ol0001Gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0
000Booooo`;o00003onoZI@2o`0001?oZ/2L0_l0000HooGfnP?o00007_n^Q<d2o`0001Wo];:U2Ol0
000Som6YS`;o00007onghKH3o`0001ooYkRc0ol00003ohJV]0;o00004OnfW]@2o`0003KoRkFM0_l0
000IokJld0?o00008_nGZZ<2o`0000[o/M6U1?l0000?ohB5PP;o00005_o3f<H3o`0001Cooooo0ol0
001Hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05[ooooo0ol0000B
ooooo`;o00003onoZI@3o`0001;oZ/2L0_l0000HooGfnP;o00007on^Q<d3o`0001?o];:U2ol00000
1?nkR]3o0000o`000?l0000Rom6YS`?o00007_nghKH2o`0001ooYkRc0ol00004ohJV]0;o00004Onf
W]@3o`0003GoRkFM0ol0000GokJld0?o00008onGZZ<2o`0000Wo/M6U1?l0000@ohB5PP?o00005_o3
f<H2o`0001Cooooo0_l0001Iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo05[ooooo0_l0000Cooooo`?o00003onoZI@3o`00017oZ/2L0_l0000HooGfnP;o00008?n^Q<d3
o`0000ko];:U2_l00007ok^:d0;o00008ooAZHl2o`0001ko]n6f0_l0000OojNh/`;o00001On6Y[@2
o`0001;o]YkD0_l0000foh^eW@;o00005onf_=02o`0002CoUjZS0ol00006ok7AY@Co00004on4QH82
o`0001Ko`mS66?l0001Iooooo`03o`000?oooooooooo00Sooooo000Jooooo`?o0000FOooool3o`00
01Cooooo0_l0000@oknYU0?o00004?nZ`9`2o`0001OomOKj0ol0000Qojj4c@;o00002Ond/ZD:o`00
00co^h[@0_l0000Som6YS`;o00007_nghKH2o`0001koYkRc0ol00005ohJV]0;o00004_nfW]@3o`00
03GoRkFM0_l0000FokJld0?o00009OnGZZ<2o`0000Go/M6U1?l0000DohB5PP?o00005Oo3f<HGo`00
05Sooooo0ol0000:ooooo`006_ooool00ol0003oooooooooo`1Iooooo`;o00005Oooool2o`00017o
_jVD0_l0000@oj[0W0;o00005ooem_X2o`0002;o[XC=1Ol000000ond/ZGo0000o`000009o`00013o
^h[@0ol0000Rom6YS`?o00007?nghKH3o`0001goYkRc0ol00006ohJV]0;o00004onfW]@2o`0003Go
RkFM1?l0000DokJld0;o00009_nGZZ<2o`0000?o/M6U1?l0000GohB5PP;o00005?o3f<H3o`0001?o
oooo0ol0001Iooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Sooooo
0ol0000Eooooo`;o00004OnoZI@3o`0000ooZ/2L0_l0000GooGfnP;o00008_n^Q<d<o`0001Ko^h[@
0_l0000Qom6YS`Go00006onghKH2o`0001goYkRc0ol00007ohJV]0;o00004onfW]@3o`00037oRkFM
2?l0000BokJld0?o00009OnGZZ<9o`0001SoQ8F20ol0000Bol?HaP?o00005Oooool2o`0005Wooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F?ooool2o`0001Kooooo0ol0
000AoknYU0?o00003_nZ`9`2o`0001KomOKj0ol0000Qojj4c@?o00000_nZY9D3o`0001_o^h[@0_l0
000Pom6YS`?o000000Co];BFo`000?l0003o00006_nghKH2o`0001goYkRc0_l00008ohJV]0;o0000
5?nfW]@2o`0002koRkFM1ol00002ok2`Z0?o00004?nf_=03o`0002GoUjZS2?l0000KohB5PP;o0000
4Oo3f<H3o`0001Kooooo0ol0001Hooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo05Oooooo0ol0000Gooooo`;o00004_noZI@3o`0000coZ/2L0ol0000FooGfnP;o00008On^
Q<d3o`0000?oZZBE0ol0000Kok^:d0?o00007_oAZHl3o`0000?o];BF0ol0000HokOQ]P?o00007?nW
^;<3o`0000SoQZJd0_l0000DokJNe0?o0000:on;]Id6o`0000Ko/;2X1?l0000>okJld0;o00009OnG
ZZ<3o`0000?og[jl1?l0000JohB5PP;o00004?o3f<H3o`0001Sooooo0ol0001Gooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Oooooo0_l0000Hooooo`;o00004onoZI@3
o`0000_oZ/2L0_l0000GooGfnP;o00008?n^Q<d3o`0000GoZZBE0_l0000Lok^:d0;o00007OoAZHl3
o`0000Go];BF0ol0000CokOQ]PKo00007?nW^;<3o`0000WoQZJd0_l0000EokJNe0;o0000:?n;]Id6
o`0000[o/;2X1?l0000<okJld0?o00008onGZZ<4o`0000Kog[jl1?l0000HohB5PP?o00003_o3f<H3
o`0001[ooooo0_l0001Gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
05Oooooo0_l0000Hooooo`;o00005?noZI@2o`0000_oZ/2L0_l0000FooGfnP?o00007on^Q<d3o`00
00KoZZBE0_l0000Lok^:d0?o00006ooAZHl3o`0000Oo];BF0ol0000;okOQ]Pgo00007?nW^;<2o`00
00[oQZJd0_l0000EokJNe0?o00009?n;]Id7o`0000ko/;2X0ol0000;okJld0;o00008onGZZ<4o`00
00Sog[jl1?l0000HohB5PP;o00003Oo3f<H3o`0001_ooooo0ol0001Fooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo05Kooooo0ol0000Hooooo`?o00004onoZI@3o`0000So
Z/2L1Ol0000EooGfnP;o00007on^Q<d3o`0000OoZZBE0ol0000Lok^:d0;o00006_oAZHl3o`0000Wo
];BF0ol00003okOQ]Poo00000on`Y9h3o`0001[oYkRc0ol0000:ohJV]0;o00005_nfW]@3o`00023o
RkFM1ol0000Bok2`Z0Co00002?nf_=03o`0002;oUjZS0ol0000<omjn_0Co00005_n4QH83o`0000_o
`mS60ol0000Mooooo`;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1Fooooo`;o00006_ooool2o`0001Co_jVD0ol00002oj[0W0co00004ooem_X2o`0001ko[XC=
0ol00009ojZTU@;o00007?nkR]02o`0001WodJV?0ol0000;okBdUPgo00002on`Y9h3o`0001SoYkRc
0ol0000;ohJV]0;o00005onfW]@2o`0001koRkFM1_l0000Fok2`Z0Co00001_nf_=03o`0002;oUjZS
0ol0000>omjn_0Co00005_n4QH82o`0000[o`mS60ol0000Nooooo`?o0000EOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Eooooo`?o00006_ooool2o`0001Go_jVD2_l0
0003olG8/`Co00004Ooem_X3o`0001go[XC=0ol0000:ojZTU@;o00007?nkR]03o`0001OodJV?0ol0
000=okBdUPGo00004on`Y9h2o`0001SoYkRc0_l0000<ohJV]0;o00005onfW]@3o`0001[oRkFM1_l0
000Kok2`Z0?o00001Onf_=02o`00027oUjZS1?l0000Aomjn_0?o00005On4QH83o`0000So`mS60ol0
000Pooooo`?o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1E
ooooo`;o00006oooool2o`0001Co_jVD1_l0000:olG8/`Co00003ooem_X2o`0001go[XC=0ol0000;
ojZTU@?o00007?nkR]02o`0001KodJV?0ol0000>okBdUP;o00005_n`Y9h3o`0001KoYkRc0ol0000<
ohJV]0;o00006?nfW]@2o`0001OoRkFM1ol0000Nok2`Z0Wo00008?nGZZ<4o`0001?og[jl1?l0000D
ohB5PP;o00001oo3f<H3o`0002;ooooo0_l0001Dooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo05Gooooo0_l0000Kooooo`?o00004_noZI@3o`0000ooaLRc1Ol0000=ooGf
nP;o00007?n^Q<d3o`0000goZZBE0_l0000Lok^:d0?o00005?oAZHl3o`0000oo];BF0_l0000Gok2T
WP?o00005?nW^;<3o`0000goQZJd0_l0000HokJNe0?o00005?n;]Id6o`0002;o/;2X2_l0000MoiNZ
X`?o00005_oN_[`4o`0001?oQ8F20ol00005ol?HaP?o00008oooool3o`0005?ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0EOooool3o`0001_ooooo0_l0000AoknYU0?o
00004_o5b;<4o`0000_omOKj0ol0000Kojj4c@?o00003_nZY9D2o`0001go^h[@0_l0000Com6YS`?o
00004?nd]9H2o`0001So/:BN0ol0000CojNh/`;o00003_n6Y[@2o`0001Wo]YkD0_l0000Aoh^eW@Ko
00009?n`/:P3o`0000God>GH1?l0000JoiNZX`Co00006OoN_[`7o`0000ooQ8F20_l00004ol?HaP?o
00009Oooool2o`0005?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
E_ooool2o`0001_ooooo0_l0000@oknYU0?o00005Oo5b;<4o`0000WomOKj0_l0000Kojj4c@?o0000
3onZY9D3o`0001co^h[@0_l0000Bom6YS`?o00004Ond]9H2o`0001Wo/:BN0_l0000BojNh/`?o0000
3_n6Y[@2o`0001Wo]YkD2_l00006oh^eW@Oo00009_n`/:P2o`0000Sod>GH1?l0000GoiNZX`Co0000
6ooN_[`>o`0000OoQ8F20ol00002ol?HaP?o00009_ooool2o`0005?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0E_ooool2o`0001_ooooo0_l0000?oknYU0?o00005oo5
b;<5o`0000OomOKj0_l0000Jojj4c@?o00004OnZY9D2o`0001co^h[@0ol0000@om6YS`?o00004_nd
]9H2o`0001Wo/:BN0ol0000@ojNh/`?o00003on6Y[@2o`0001[o]YkD4ol0000Xok2`Z0?o00002Oo@
iMP5o`0001CoUjZS0ol0000Lomjn_0?o00000onRcj`@o`000004ohB5P_l0003o0000ol?HaP?o0000
9oooool2o`0005?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E_oo
ool2o`0001_ooooo0ol0000=oknYU0?o00006_o5b;<4o`0000GomOKj0ol0000Iojj4c@?o00004_nZ
Y9D2o`0001go^h[@0_l0000?om6YS`?o00004ond]9H2o`0001[o/:BN1?l0000>ojNh/`;o00004?n6
Y[@2o`0001Wo]YkD0ol00006ombm/0So0000:on`/:P2o`0000cod>GH1?l0000AoiNZX`Co00007OoN
_[`2o`0000coX/n/3_l0000Xooooo`;o0000Doooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Fooooo`?o00006oooool2o`0000co_jVD0ol0000MolG8/`Co00000ooem_X2
o`0001Wo[XC=0ol0000CojZTU@?o00007?nkR]02o`0000kodJV?0ol0000DokBdUP;o00006?n`Y9h7
o`0000coYkRc0ol0000@ohJV]0;o00006OnfW]@2o`0000gog;f`0ol0000Yok2`Z0?o00003_o@iMP4
o`0000koUjZS1?l0000Nomjn_0;o00004onRcj`6o`0002Sooooo0ol0001Cooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo05Oooooo0ol0000Jooooo`;o00002onoZI@3o`00
01ooaLRc1Ol000000ooem_[o0000o`00000Hojj4c@?o00005OnZY9D2o`0001co^h[@0ol0000<om6Y
S`?o00005Ond]9H2o`0001Ko/:BN1Ol00002ol2kZP?o00002_nW^;<3o`00017oQZJd0_l0000IokJN
e0;o00003_oL_K02o`0002So/;2X0ol0000@om3Uf0Go00002onGZZ<3o`0001oog[jl0ol0000Goj;?
[0?o00009oooool2o`0005Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Eoooool6o`0001Oooooo0_l0000:oknYU0?o00008_o5b;<6o`0001Oo[XC=0ol0000FojZTU@;o
00007OnkR]02o`0000_odJV?0ol0000FokBdUP;o00005?n`Y9h5o`0000Go`;^Z0ol00008ojNh/`?o
00004_n6Y[@2o`0001So]YkD0ol0000>ombm/0?o00009on`/:P2o`0001?od>GH1?l00009oiNZX`?o
00008?oN_[`2o`0001SoX/n/1Ol0000Uooooo`;o0000E?ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1Fooooo`[o00005?ooool2o`0000Wo_jVD0ol0000UolG8/`?o0000
5on^Q<d3o`0001OoZZBE0ol0000Lok^:d0?o00002OoAZHl3o`0001Oo];BF0_l0000Bok2TWPGo0000
2?o0^jX3o`0000OoYkRc0_l0000CohJV]0;o00006?nfW]@2o`00013og;f`0_l0000Vok2`Z0?o0000
5Oo@iMP4o`0000GoUjZS1?l0000Qomjn_0;o00006?nRcj`6o`0002Cooooo0_l0001Dooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Gooooo0ol00004ooooo`Ko00004_oo
ool3o`0000Oo_jVD0ol0000WolG8/`;o00005_n^Q<d3o`0001WoZZBE0_l0000Mok^:d0;o00002?oA
ZHl3o`0001So];BF0_l0000@ok2TWPGo00002oo0^jX3o`0000GoYkRc0ol0000CohJV]0;o00005onf
W]@3o`00013og;f`0ol0000Uok2`Z0;o00005oo@iMP5o`0000;oUjZS1?l0000Qomjn_0?o00005onR
cj`3o`0000;ooooo1?l0000Rooooo`;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Dooooo`?o00002?ooool6o`00013ooooo0_l00006oknYU0?o0000:?o5b;<3
o`0001Co[XC=0ol0000JojZTU@?o00007?nkR]02o`0000OodJV?0ol0000IokBdUP;o00003_n`Y9h5
o`0000ko`;^Z0ol00003ojNh/`?o00005?n6Y[@2o`0001Oo]YkD0_l0000Bombm/0;o00009?n`/:P3
o`0001Wod>GH1ol0000Somjn_0;o00006?nRcj`2o`0000Cooooo1Ol0000Pooooo`;o0000E?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Cooooo`?o00002oooool7o`00
00gooooo0_l00005oknYU0?o0000:_o5b;<2o`0001?o[XC=0ol0000LojZTU@;o00007?nkR]03o`00
00GodJV?0ol0000JokBdUP;o00003?n`Y9h5o`00017o`;^Z0ol00002ojNh/`;o00005On6Y[@2o`00
01Oo]YkD0_l0000Bombm/0?o00008on`/:P2o`0001cod>GH1?l0000Tomjn_0;o00006?nRcj`2o`00
00Kooooo1?l0000Oooooo`;o0000E?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1Booooo`?o00003oooool7o`0000[ooooo0_l00004oknYU0?o0000:oo5b;<3o`00017o
[XC=0ol0000MojZTU@;o00007OnkR]02o`0000CodJV?0ol0000KokBdUP;o00002on`Y9h4o`0001Co
`;^Z1_l0000EohJV]0;o00005_nfW]@3o`0001?og;f`0_l0000Rok2`Z0?o00007Oo@iMP2o`0002Co
g[jl0ol0000Goj;?[0?o00002?ooool4o`0001cooooo0ol0001Dooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo05;ooooo0_l0000Cooooo`Ko00002?ooool8o`0002goaLRc
0ol0000?ojj4c@?o00007_nZY9D3o`0001co^h[@0_l00003om6YS`?o00007?nd]9H2o`0000Wo/:BN
1?l0000Gol2kZPCo00005_n6Y[@2o`0001Ko]YkD0_l0000Dombm/0?o00008On`/:P2o`0001kod>GH
0ol0000Somjn_0;o00006?nRcj`2o`0000[ooooo1Ol0000Jooooo`;o0000EOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Aooooo`?o00005_ooool6o`0000Gooooo2Ol0
000]olG8/`;o00003_n^Q<d3o`00023oZZBE0_l0000Lok^:d0Oo00007Ond]9H2o`0000Oo/:BN1Ol0
000Iol2kZP;o00005on6Y[@2o`0001Go]YkD0ol0000Eombm/0;o00008?n`/:P3o`0001ood>GH1?l0
000Qomjn_0;o00006?nRcj`2o`0000cooooo1?l0000Iooooo`;o0000EOooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1@ooooo`?o00006Oooool=o`0000?oLk>00ol0000/
olG8/`Co00002on^Q<d3o`00027oZZBE0_l0000Kok^:d0[o00006ond]9H2o`0000Go/:BN1Ol0000K
ol2kZP;o00005on6Y[@2o`0001Go]YkD0_l0000Fombm/0?o00007on`/:P2o`00023od>GH1ol0000M
omjn_0?o00005onRcj`3o`0000kooooo1?l0000Gooooo`;o0000EOooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1?ooooo`?o00007Oooool7o`0000OoLk>00ol0000YolG8
/`Oo00002On^Q<d3o`0002;oZZBE0ol0000Iok^:d0?o00001OnH]ZT4o`0001[o];BF0_l00003ok2T
WPGo00007Oo0^jX2o`0001OoQZJd0_l0000DokJNe0?o00005ooL_K02o`0001ko/;2X0ol0000Pom3U
f0;o000000?o`[F/o`000?l000001Ol0000Jomjn_0;o00006?nRcj`2o`00013ooooo1Ol0000Eoooo
o`;o0000EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1>ooooo`?o
00008Oooool2o`0000[oLk>01?l0000UolG8/`Go00000_oR_]03o`0000Oo[XC=0ol0000TojZTU@;o
00006?nkR]03o`0000SoV;JY1?l0000HokBdUP;o000000?o/:BNo`000?l000000ol0000Ool2kZP?o
00005_n6Y[@2o`0001Co]YkD0_l0000Hombm/0?o00007?n`/:P3o`00027od>GH0_l00004ol:e[0So
00005_oN_[`2o`0001SoX/n/0_l0000Booooo`Go00004oooool2o`0005Gooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0COooool3o`0002;ooooo0_l0000;og>cP0Co0000
8_o5b;<5o`0000Goh[k@1?l00004ojj4c@?o00009OnZY9D2o`0001Oo^h[@0ol0000:oiRfZ@Go0000
5_nd]9H6o`0002;o`;^Z0_l0000FohJV]0;o00005?nfW]@2o`0001Wog;f`0_l0000Lok2`Z0;o0000
8_o@iMP2o`0000Oo`[F/2?l0000Bomjn_0?o00005onRcj`3o`0001Cooooo1?l0000Booooo`;o0000
EOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1=ooooo`;o00008_oo
ool3o`0000goLk>00ol0000OolG8/`Go00002?oR_]04o`0000;o[XC=0ol0000VojZTU@?o00005Onk
R]03o`0000goV;JY1?l0000EokBdUPCo00009?o0^jX3o`0001GoQZJd0_l0000CokJNe0?o00006OoL
_K03o`0001[o/;2X0ol0000Rom3Uf0;o00002oo2]J`7o`0000oog[jl0_l0000Hoj;?[0;o00005ooo
ool4o`0000oooooo0ol0001Eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo04gooooo0_l0000Rooooo`;o00003omc/h03o`0001coaLRc1Ol0000<on:nd0Ko0000:?nZY9D2
o`0001Co^h[@0ol0000@oiRfZ@Co00004_nd]9H4o`0002Co`;^Z1_l0000CohJV]0;o00004onfW]@2
o`0001_og;f`0_l0000Jok2`Z0;o00008oo@iMP2o`0000ko`[F/1ol0000<omjn_0;o00006?nRcj`2
o`0001Sooooo1Ol0000=ooooo`;o0000E_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1=ooooo`;o00008_ooool2o`00013oLk>01?l0000HolG8/`Go00003ooR_]04o`00
02WoZZBE0_l0000Cok^:d0?o00004_nH]ZT5o`0000ko];BF1ol0000Rol2kZP?o000000?oSISBo`00
0?l000001?l0000@ohJV]0;o00004_nfW]@3o`0001_og;f`0ol0000Hok2`Z0?o00008oo@iMP2o`00
017o`[F/2?l00007omjn_0?o00005onRcj`3o`0001[ooooo1?l0000<ooooo`;o0000E_ooool00ol0
003oooooooooo`08ooooo`006_ooool3o`0004gooooo0_l0000Rooooo`;o00004Omc/h04o`0001Go
aLRc1Ol0000Bon:nd0;o0000:_nZY9D3o`00017o^h[@0ol0000EoiRfZ@Co00002ond]9H5o`0000;o
^hZT1?l0000Ool2kZP?o00001?n=V=86o`0000koQZJd0_l0000BokJNe0;o00007OoL_K02o`0001So
/;2X0_l0000Tom3Uf0;o00005?o2]J`8o`0000Cog[jl0_l0000Hoj;?[0;o00007Oooool4o`0000Wo
oooo0ol0001Dooooo`?o00002_ooool001[ooooo00?o0000ooooooooool0C?ooool3o`0002;ooooo
0_l0000Cog>cP0?o00004oo5b;<4o`0001Coh[k@0ol0000ZojZTU@;o00003?nkR]07o`0001SoV;JY
1?l00007okBdUPGo00001OnkRZ@4o`0001go`;^Z0ol00008ohfHdPGo00003?n6Y[@2o`0001;o]YkD
0_l0000Mombm/0?o00005_n`/:P3o`0002Cod>GH0_l0000Hol:e[0Oo000000?og[jlo`000?l00000
6?nRcj`2o`0001kooooo1Ol00006ooooo`Co0000E_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1<ooooo`;o00008_ooool3o`0001CoLk>00ol0000@olG8/`Co00005ooR
_]02o`0002[oZZBE0_l00003ok^:d0oo00006_nH]ZT5o`0000?o];BF1Ol00009ok^:Y0Co00006_o0
^jX3o`0000_oSISB1_l00007ohJV]1So00007_oL_K02o`0001Ko/;2X0_l0000Uom3Uf0;o00006oo2
]J`7o`0001OoX/n/0ol0000Pooooo`Co00000oooool4o`0005Sooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0C?ooool2o`0002;ooooo0_l0000Fog>cP0?o00003Oo5b;<5
o`0001Soh[k@0ol0000YojZTU@oo00000ooAg=l2o`0001coV;JY2Ol0000<ok^:Y0Co00006?o0^jX3
o`0000koSISB1_l000000on6Y[Co0000o`00000Io`0001oog;f`0ol0000Dok2`Z0?o00009Oo@iMP2
o`0001ko`[F/1?l0000Goj;?[0;o00008oooool8o`0005Wooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0C?ooool2o`0002;ooooo0_l0000Gog>cP0Co00002Oo5b;<5o`00
01_oh[k@0_l0000YojZTU@Ko00003?oAg=l3o`0001goV;JY1Ol0000@ok^:Y0Co00005Oo0^jX3o`00
01;oSISB2Ol0000DolBheP?o00007ooL_K02o`0001Co/;2X0_l0000Vom3Uf0;o00008?o2]J`3o`00
01KoX/n/0_l0000Tooooo`Go0000Foooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1<ooooo`;o00008_ooool2o`0001SoLk>01?l00006olG8/`Go00007OoR_]03o`0002Oo
ZZBE0ol0000Aom7Lg`;o00007_nH]ZT2o`0001?o^hZT1Ol0000Bol2kZP?o00005On=V=83o`0001Wo
a;SF0_l0000Oombm/0?o00004_n`/:P3o`0002Kod>GH0ol0000Pol:e[0?o00005?nRcj`3o`0002Ko
oooo0_l0001Looooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04cooooo
0_l0000Rooooo`;o00006_mc/h03o`0000?oaLRc1Ol0000Pon:nd0;o00009_nZY9D3o`0001;odMcO
0_l0000NoiRfZ@;o00005OnkRZ@4o`00013o`;^Z0ol0000FohfHdP;o00006_o4^=H3o`0001oog;f`
0_l0000Bok2`Z0;o00009oo@iMP5o`0001oo`[F/0ol0000Coj;?[0;o00009oooool2o`0005cooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0C?ooool2o`00027ooooo0ol0
000Kog>cP0So00008_oR_]02o`0002GoZZBE0ol0000Com7Lg`?o00007OnH]ZT2o`0001Oo^hZT1?l0
000=ol2kZP?o00005on=V=82o`0001_oa;SF0_l0000Oombm/0?o00004?n`/:P3o`0002Ood>GH1ol0
000Nol:e[0?o00004_nRcj`2o`0002Kooooo0ol0001Looooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo04cooooo0_l0000Qooooo`;o00007Omc/h05o`0002Coh[k@0ol0000S
ojZTU@?o00005OoAg=l2o`0001coV;JY1?l0000Gok^:Y0Co00002_o0^jX4o`0001SoSISB0_l0000K
olBheP?o00007ooL_K02o`0000oo/;2X0ol0000Xom3Uf0;o00000_o7dj/5o`0001go`[F/0ol0000@
oj;?[0?o00009_ooool2o`0005gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0C?ooool2o`00027ooooo0_l0000Nog>cP0;o00009ooR_]02o`0002;oZZBE0ol0000Fom7L
g`;o00006onH]ZT5o`0001Wo^hZT1?l00007ol2kZPGo00006?n=V=82o`0001coa;SF0_l0000Nombm
/0Ko00003?n`/:P2o`0002Sod>GH0ol00004olOCZ`Go00007?o2]J`3o`0000ooX/n/0_l0000Woooo
o`;o0000GOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1;ooooo`?o
00008Oooool2o`0001koLk>00_l0000Won:nd2Ko00005ooAg=l3o`0001WoV;JY0ol000001?o2knko
0000o`000?l0000Iok^:Y0Co00001Oo0^jX3o`000004ojS]h_l0003o0000o`0001OoSISB0_l0000L
olBheP?o00006_oL_K0>o`0000Ko/;2X0ol0000Xom3Uf0;o00001oo7dj/5o`0001_o`[F/0ol0000>
oj;?[0;o00009_ooool3o`0005gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Boooool2o`0002;ooooo0_l0000Nog>cP0;o0000:?oR_]0To`0001WodMcO0_l0000IoiRf
Z@;o00000oo2knh2o`0001_o^hZT1?l00002ol2kZP?o00000onXkN83o`0001KoSISB0_l0000MolBh
eP;o00005ooL_K07o`0000Coemg12ol000000on`/:So0000o`00000Yom3Uf0;o00002Oo7dj/5o`00
01[o`[F/0ol0000<oj;?[0?o00009_ooool2o`0005kooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Boooool2o`00027ooooo0ol0000Mog>cP0?o0000:?oR_]02o`00023o
S9RG0_l0000Iom7Lg`;o00006?nH]ZT3o`0000?o`^o^0ol0000Kok^:Y0Oo00001OnXkN83o`0001Go
SISB0_l0000MolBheP?o00004ooL_K07o`0000coemg12Ol0000Yom3Uf0;o00002oo7dj/5o`0001Wo
`[F/0ol00009oj;?[0Go00009_ooool2o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Boooool2o`00027ooooo0_l0000Nog>cP0;o0000:OoR_]02o`00023oS9RG
0ol0000Hom7Lg`?o00005_nH]ZT3o`0000Go`^o^0_l0000Mok^:Y0Co00001onXkN83o`0001CoSISB
0_l0000NolBheP;o00003ooL_K08o`0001Coemg10ol0000Zom3Uf0;o00003Oo7dj/5o`0001So`[F/
0ol00005oj;?[0Wo00009?ooool3o`0005kooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Boooool2o`0001oooooo1?l0000Nog>cP0;o0000:?oR_]03o`00027oS9RG0_l0
000Iom7Lg`;o00005OnH]ZT3o`0000Ko`^o^0ol0000Mok^:Y0;o00002OnXkN83o`0001?oSISB0_l0
000NolBheP?o00002ooL_K08o`0001Soemg10_l0000Zom3Uf0;o00003oo7dj/5o`0001Oo`[F/0ol0
00000onRcjco0000o`000005o`0000?ooooo0ol0000Sooooo`;o0000Goooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`1;ooooo`?o00006oooool7o`0001koLk>00_l0000X
on:nd0;o00008_n<V9L2o`0001WodMcO0_l0000EoiRfZ@;o00002?o2knh2o`0001go^hZT0_l0000:
ojS]hP?o00004_n=V=82o`0001ooa;SF0_l00008ombm/0Oo00007?oGgL43o`0002Sod>GH0ol0000A
olOCZ`Go00005_o2]J`7o`0000Oooooo1?l0000Qooooo`;o0000Goooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1<ooooo`?o00005oooool7o`000004ooooool0003o0000
o`0001goLk>00_l0000Xon:nd0;o00008_n<V9L3o`0001SodMcO0ol0000CoiRfZ@?o00002?o2knh3
o`0001co^hZT0_l0000;ojS]hP?o00004On=V=82o`0001ooa;SF0ol00004ombm/0Oo00008?oGgL42
o`0002Sod>GH0_l0000DolOCZ`Go00005Oo2]J`3o`0000_ooooo1?l0000Oooooo`?o0000Goooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1=ooooo`?o00004_ooool8o`00
00Gooooo0ol0000Log>cP0;o00009_oR_]04o`0002?oS9RG0_l0000Iom7Lg`;o00004_nH]ZT3o`00
00[o`^o^0_l0000Kok^:Y0?o00003?nXkN83o`00013oSISB0_l0000PolBheP;o000000?og;f`o`00
0?l000001Ol0000SomOM`@;o0000:?o@iMP2o`0001Koam>[1Ol0000Bol:e[0?o00003_ooool3o`00
01kooooo0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04ko
oooo0ol0000>ooooo`So00002Oooool3o`0001_oLk>00_l0000Ron:nd0So00008on<V9L2o`0001Wo
dMcO0_l0000AoiRfZ@?o00002oo2knh3o`0001[o^hZT0_l0000>ojS]hP?o00003on=V=82o`00023o
a;SF1ol0000VomOM`@;o0000:?o@iMP2o`0001Soam>[1Ol0000?ol:e[0?o00004?ooool4o`0001co
oooo0_l0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo04oooooo
0ol00009ooooo`So00003_ooool2o`0001[oLk>00ol0000Non:nd0Wo000000?oSGmko`000?l00000
8on<V9L2o`0001WodMcO0ol0000@oiRfZ@;o00003Oo2knh2o`0001[o^hZT0_l0000?ojS]hP?o0000
3_n=V=82o`00027oa;SF0ol0000YomOM`@?o00009oo@iMP2o`0001[oam>[1Ol0000<ol:e[0?o0000
4_ooool4o`0001[ooooo0ol0001Pooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo053ooooo0ol00005ooooo`So00004Oooool3o`0001WoLk>00_l0000Kon:nd0Wo00001On=
Og/2o`0002?oS9RG0ol0000Iom7Lg`;o00003onH]ZT3o`0000go`^o^0ol0000Iok^:Y0;o00004?nX
kN83o`0000goSISB0_l0000QolBheP;o0000:ooGgL42o`0002Ood>GH0_l0000LolOCZ`Go00002Oo2
]J`3o`0001Gooooo0ol0000Iooooo`;o0000HOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Aooooo`?o000000?oooooo`000?l000001Ol0000Fooooo`?o00006?mc/h02
o`0001Ooh[k@2Ol00009oheoN`;o00009?n<V9L2o`0001WodMcO0_l0000>oiRfZ@?o00003oo2knh2
o`0001Wo^hZT0_l0000AojS]hP?o00003?n=V=82o`00027oa;SF0_l0000[omOM`@;o00009oo@iMP2
o`0001koam>[1Ol00006ol:e[0?o00005oooool4o`0001Oooooo0_l0001Qooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo05;ooooo1ol0000Jooooo`;o00006?mc/h02o`00
01?oh[k@2Ol0000=oheoN`;o00009?n<V9L2o`0001WodMcO0ol0000=oiRfZ@;o00004?o2knh2o`00
01So^hZT0ol0000BojS]hP?o00002on=V=82o`00027oa;SF0_l0000[omOM`@?o00009Oo@iMP3o`00
023oam>[1Ol00003ol:e[0?o00006Oooool4o`0001Gooooo0ol0001Qooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo05?ooooo0ol0000Mooooo`?o00005omc/h02o`00013o
h[k@2?l0000AoheoN`;o00009?n<V9L2o`0001[odMcO0_l0000<oiRfZ@?o00004?o2knh3o`0001Oo
^hZT0_l0000DojS]hP?o00002_n=V=82o`00027oa;SF0_l0000/omOM`@;o00009Oo@iMP2o`0002?o
am>[2?l0000Looooo`Co00004oooool2o`0006;ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Doooool2o`0001oooooo0ol0000Fog>cP0;o00003?oR_]08o`0001GoSGmk
0_l0000TohbHU`?o00006OoAg=l2o`0000_oV;JY0ol0000Bol;_kP;o00005onkRZ@2o`0001GoZ>gR
0ol00009ohfHdP;o00008Oo4^=H2o`0002coemg10_l0000Uom3Uf0;o00009Oo7dj/5o`0001kooooo
1?l0000Booooo`;o0000H_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1Cooooo`;o00008?ooool3o`0001GoLk>00_l00008on:nd0Wo00006?n=Og/2o`0002GoS9RG0_l0
000Iom7Lg`?o00002OnH]ZT3o`0001?o`^o^0ol0000Fok^:Y0;o00005_nXkN83o`0000SoSISB0_l0
000QolBheP;o0000;?oGgL42o`0002God>GH0_l0000WolOCZ`;o00008Oooool3o`00013ooooo0ol0
001Rooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05?ooooo0_l0000Q
ooooo`;o00005?mc/h03o`0000Coh[k@2Ol0000LoheoN`;o00009On<V9L2o`0001[odMcO0_l00009
oiRfZ@;o00005Oo2knh2o`0001Ko^hZT0_l0000GojS]hP?o00001on=V=82o`00027oa;SF0_l0000/
omOM`@?o00009?o@iMP2o`0002Koam>[0ol0000Rooooo`Co00003Oooool3o`0006?ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Doooool2o`00027ooooo0ol0000Cog>c
P0;o000000?oh[k@o`000?l000001ol0000PoheoN`?o00009?n<V9L3o`0001WodMcO0_l00008oiRf
Z@?o00005Oo2knh3o`0001Go^hZT0_l0000HojS]hP?o00001_n=V=82o`00023oa;SF0ol0000]omOM
`@Co00008_o@iMP2o`0002Koam>[0_l0000Tooooo`Co00002oooool4o`0006?ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Doooool2o`0002;ooooo1?l0000@og>cP0Wo
00009On=Og/2o`0002GoS9RG0_l0000Iom7Lg`?o00001_nH]ZT3o`0001Oo`^o^0_l0000Dok^:Y0?o
00006OnXkN83o`0000GoSISB0_l0000PolBheP;o0000;_oGgL47o`0001kod>GH0ol0000UolOCZ`?o
00009_ooool3o`0000Sooooo1?l0001Uooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo05?ooooo0_l0000Rooooo`Oo00002omc/h07o`0002WoSGmk0_l0000UohbHU`;o0000
6OoAg=l;o`0001So`^o^0ol0000Cok^:Y0;o00006onXkN83o`0000CoSISB0_l0000PolBheP;o0000
;OoGgL43o`000003ohN8aOl0003o000000Go00006oo@iMP2o`0002Koam>[0_l0000Xooooo`Co0000
1Oooool4o`0006Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Dooo
ool2o`00027ooooo0ol000000on9N;Go0000o`000005o`0000GoLk>01_l00002oj:e/@?o0000:?n=
Og/2o`0002GoS9RG0_l0000Hom7Lg`go00006?o2knh2o`0001?o^hZT0_l0000LojS]hP?o00000on=
V=82o`00023oa;SF0_l0000/omOM`@?o00001On7R<D7o`0001Sod>GH1_l0000QolOCZ`?o0000:Ooo
ool4o`0000;ooooo1?l0001Xooooo`03o`000?oooooooooo00Sooooo0007ooooo`?o00001?ooool2
o`0000[ooooo00?o0000ooooooooool0Doooool2o`00023ooooo0ol00005ohUh]@go00001OnR]K43
o`0002OoSGmk0_l0000UohbHU`?o00005_oAg=l3o`0000WoXK770ol0000Gol;_kP?o00004_nkRZ@2
o`0001goZ>gR0ol00002ohfHdP;o00008?o4^=H2o`0002_oemg10ol00009ohN8a@So00004oo@iMP>
o`0001[oam>[0_l0000/ooooo`Oo0000JOooool00ol0003oooooooooo`08ooooo`001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`1Cooooo`;o00007oooool3o`0000WoRGRe1ol00009oj:e/@?o00009_n=Og/2o`0002KoS9RG0_l0
000Dom7Lg`Co00002onQ/LL3o`0001Oo`^o^0_l0000Bok^:Y0;o00007_nXkN87o`0001ooa;SF0_l0
000ZomOM`@?o00003On7R<D8o`0000ood>GH0ol00004oiRZOA3o00004_o7dj/2o`0002gooooo1?l0
001[ooooo`03o`000?oooooooooo00Sooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00009ooooo`Go0000DOooool2o`0001kooooo0ol0000=ohUh]@;o0000
3?nR]K43o`0002GoSGmk0_l0000VohbHU`;o00004ooAg=l4o`0000goXK770ol0000Fol;_kP?o0000
4?nkRZ@3o`0001_oZ>gR2ol0000NolBheP;o0000:OoGgL43o`0001;oQhS51ol0000;om3Uf0?o0000
3?nHZWd@o`0000[oam>[0ol0000^ooooo`;o0000J?ooool5o`0000[ooooo0006ooooo`Co00000ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo05?ooooo0ol0000Looooo`?o0000
3_n9N;D2o`0000goX[Fa0ol0000ToheoN`;o00009_n<V9L2o`0001;odMcO0ol0000@oj6aa`?o0000
5_o2knh2o`00013o^hZT0_l0000IojS]hPOo00001On_V8<4o`0001coa;SF0_l0000XomOM`@?o0000
5_n7R<D7o`0000Ood>GH0ol0000EoiRZO@oo00000oo7dj/2o`0002oooooo0_l0001/ooooo`03o`00
0?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`1Dooooo`;o00006oooool3o`0000ooRGRe0_l0000>oj:e/@?o0000
8on=Og/2o`0002KoS9RG0ol0000?om7Lg`Co00004_nQ/LL3o`0001Go`^o^<Ol00009ojnHP`Co0000
6_o4^=H4o`0002Koemg10ol0000JohN8a@Oo00000oo@iMP3o`0001goV:Ym3Ol0000^ooooo`?o0000
K?ooool00ol0003oooooooooo`08ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool0E?ooool2o`0001[ooooo0ol0000@ohUh]@;o0000
3onR]K43o`0002;oSGmk0ol0000VohbHU`;o00003_oAg=l4o`0001CoXK771?l0000Aol;_kS3o0000
3_n_V8<3o`0001Ooa;SF1ol0000TomOM`@?o00007_n7R<D9o`0002GoV:Ym1Ol0000_ooooo`;o0000
KOooool00ol0003oooooooooo`08ooooo`002?ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oo
oooooooo05Cooooo0_l0000Iooooo`?o00004On9N;D2o`00013oX[Fa0ol0000OoheoN`So00008on<
V9L2o`0000codMcO1?l0000Goj6aa`Co00003_o2knh5o`00017o_lcQ0_l0000HonGNa`;o00003on_
V8<4o`0001?oa;SF1Ol00002ok6bd@Co00008OoGgL43o`0002;oQhS51Ol0000YoiRZO@?o0000;_oo
ool2o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E?ooool2
o`0001Sooooo0ol0000BohUh]@;o00004OnR]K43o`0001goSGmk1?l000000oo@/mgo0000o`000005
o`00023oS9RG0ol0000:om7Lg`Co00006_nQ/LL3o`0000_o`^o^1Ol0000Coko<h@;o00006?oUg/L2
o`00013o[iR31?l0000@olBhePGo00001Ona/]45o`0001ooemg10_l0000RohN8a@?o000000?ofjnj
o`000?l00000:_nHZWd2o`0002kooooo0_l0001]ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo05Cooooo0_l0000Gooooo`?o00004on9N;D2o`0001;oX[Fa0ol0000Joheo
N`Ko00001?o@/md6o`0001ooS9RG0_l00009om7Lg`?o00007OnQ/LL3o`0000Wo`^o^1?l0000Eoko<
h@?o00005ooUg/L2o`0001;o[iR31?l0000<olBhePGo00002Ona/]44o`0001goemg10ol0000QohN8
a@?o00000_oK[kX3o`0002WoV:Ym0ol0000/ooooo`?o0000KOooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Dooooo`;o00005_ooool3o`0001CoRGRe0_l0000Coj:e/@?o
00005on=Og/5o`000004ojb^Kol0003o0000o`0000Kod;?M1_l0000LohbHU`;o00001ooAg=l4o`00
01ooXK770ol00006ol;_kPCo00006?noc>42o`0001OoiMk70_l0000CojnHP`Co00002_o4^=H4o`00
00go/K;A1?l0000JomOM`@?o00008On7R<D3o`0000Cofjnj0_l0000ZoiRZO@;o0000:oooool3o`00
06kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0E?ooool2o`0001Go
oooo0ol0000EohUh]@;o00005?nR]K43o`0001GoSGmk1?l00004ojb^K`;o00002?o@/md7o`0001Wo
S9RG0_l00006om7Lg`Co00008OnQ/LL3o`0000?o`^o^1Ol0000Ioko<h@;o00005ooUg/L2o`0001Go
[iR30ol00007olBhePCo00004?na/]45o`0001Ooemg10ol0000QohN8a@?o00001OoK[kX2o`0002[o
V:Ym0_l0000Yooooo`Go0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1Dooooo`;o00005?ooool3o`0001KoRGRe0_l0000Eoj:e/@?o00004_n=Og/4o`0000Ko[:i_
0_l0000;om2cg@Oo00005_n<V9L3o`0000CodMcO0ol0000Toj6aa`So00006onoc>42o`0001OoiMk7
0_l0000FojnHP`Co00000oo4^=H5o`0001?o/K;A1?l0000EomOM`@?o00008On7R<D3o`0000Kofjnj
0ol0000YoiRZO@Co00009?ooool9o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0E?ooool2o`0001?ooooo0ol0000GohUh]@;o00005_nR]K43o`0000ooSGmk1Ol0
0007ojb^K`;o00003_o@/md6o`0001CoS9RG2Ol0000Voj6aa`Go00007Onoc>42o`0001OoiMk70_l0
000GojnHP`Wo00005ona/]44o`0001;oemg10ol0000QohN8a@?o00002?oK[kX2o`0002WoV:Ym1Ol0
000Qooooo`Ko00000oooool2o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0E?ooool2o`0001;ooooo0ol0000HohUh]@;o00005onR]K43o`0000goSGmk1?l00009
ojb^K`;o00004Oo@/md6o`00013oS9RG2_l0000Woj6aa`;o00007onoc>43o`0001KoiMk70_l0000I
ojnHP`Go00006_na/]44o`00013oemg10ol0000QohN8a@?o00002OoK[kX2o`0002SoV:Ym0ol00000
1?nUY=?o0000o`000?l0000Nooooo`Go00001_ooool3o`0006cooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0E?ooool2o`00017ooooo0ol0000IohUh]@;o00006?nR]K43
o`0000[oSGmk1?l0000;ojb^K`?o00004_o@/md7o`0000coS9RG0ol00006omJTaP?o00009OnQ/LL3
o`00023o_lcQ0_l0000FonGNa`;o00006_n_V8<2o`0001ko/K;A1?l0000=omOM`@?o00008On7R<D3
o`0000[ofjnj0_l0000WoiRZO@?o00000onUY=<3o`0001[ooooo1_l00009ooooo`;o0000K?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Dooooo`?o00003oooool3o`00
01[oRGRe0_l0000Ioj:e/@?o00002?n=Og/4o`0000go[:i_0_l0000Eom2cg@Ko00002?n<V9L4o`00
00SoeZC60ol0000Toj6aa`;o00008Onoc>42o`0001KoiMk70_l0000JojnHP`;o00007ona/]45o`00
00Soemg11Ol0000QohN8a@?o00002ooK[kX3o`0002GoV:Ym0ol00005ojFTd`?o00005oooool6o`00
00_ooooo0_l0001/ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Go
oooo0ol0000=ooooo`?o00006on9N;D2o`0001[oX[Fa0ol00005oheoN`Co00003on/[Vl2o`0001So
d;?M1_l00004ohbHU`Co00002_oFY<H3o`0002?oXK770_l0000Qoko<h@;o00005_oUg/L2o`0001Wo
[iR31?l0000Pok6bd@Co00000_oGgL49o`00027oQhS50ol0000=om^_^P;o00009?nHZWd3o`0000Oo
YJCC0ol0000Dooooo`Go00003_ooool3o`0006_ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0E_ooool3o`0000_ooooo0ol0000LohUh]@;o00006onR]K43o`0000;oSGmk
1Ol0000@ojb^K`;o00006_o@/md:o`0000goeZC60ol0000Qoj6aa`?o00008Onoc>42o`0001KoiMk7
0_l0000HojnHP`Go00008_na/]4:o`000004olSC_Ol0003o0000o`0001ooQhS50ol0000>om^_^P;o
00008onHZWd3o`0000WoYJCC0ol0000Aooooo`Go00004Oooool2o`0006_ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0Eoooool3o`0000Wooooo0ol0000MohUh]@;o0000
7?nR]K47o`0001;o[:i_0_l0000Mom2cg@Ko00003ooFY<H3o`00023oXK770_l0000Roko<h@?o0000
5OoUg/L2o`0001Oo[iR30ol000001?o4/Z7o0000o`000?l0000Rok6bd@Co00001oo8dkd3o`0001go
QhS50ol0000?om^_^P?o00008OnHZWd3o`0000_oYJCC0ol0000=ooooo`Ko00004oooool3o`0006[o
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F?ooool3o`0000Gooooo
1Ol0000NohUh]@;o00007OnR]K44o`0001Co[:i_0ol0000Oom2cg@;o00004OoFY<H3o`0001ooXK77
0ol0000Roko<h@;o00005OoUg/L2o`0001Ko[iR30ol00003olBbX@;o00008_na/]42o`0000[ob=>m
0ol0000KohN8a@?o00004OoK[kX2o`00023oV:Ym0ol0000=ojFTd`?o00002_ooool6o`0001Kooooo
0_l0001Zooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05Wooooo0ol0
00000ooooooo0000o`000009o`0001_oRGRe0_l0000Noj:e/@;o00005_n/[Vl2o`0001ood;?M0_l0
000BomJTaP?o00007OnQ/LL5o`00027o_lcQ0_l0000EonGNa`;o00005On_V8<3o`0000Coa;:Q0ol0
000Pok6bd@?o00002oo8dkd3o`0001WoQhS50ol0000Bom^_^P;o00007onHZWd3o`0000ooYJCC0ol0
0007ooooo`Go00006Oooool3o`0006Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0F_ooool7o`0000?ooooo1_l0000IohUh]@;o00007OnR]K43o`0001Ko[:i_0_l0000N
om2cg@?o00004ooFY<H3o`0001_oXK770ol000001?nVOk[o0000o`000?l0000Poko<h@;o00005OoU
g/L2o`0001Co[iR30ol00006olBbX@;o00008?na/]42o`0000gob=>m0ol0000GohN8a@?o00004ooK
[kX2o`0001koV:Ym0ol0000AojFTd`?o00000oooool6o`0001cooooo0_l0001Yooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0ol00009ooooo`Go00005on9N;D2
o`0001coX[Fa1Ol0000Eojb^K`;o00007_o@/md2o`0001GoeZC60ol0000Ioj6aa`?o00000onVOkX3
o`0001oo_lcQ0_l0000EonGNa`;o00004on_V8<3o`0000Ooa;:Q0ol0000Ook6bd@;o00003_o8dkd3
o`0001GoQhS50ol0000Dom^_^P?o00007?nHZWd3o`0001?oYJCC2Ol0000Nooooo`;o0000JOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Kooooo`;o00003?ooool6o`00
01CoRGRe0_l0000Koj:e/@?o000000CoQIjYo`000?l0003o00005?n/[Vl2o`0001kod;?M0_l0000F
omJTaP?o00005onQ/LL3o`0000GoYWnj0ol0000Noko<h@?o00005?oUg/L2o`0001?o[iR30_l00009
olBbX@;o00007ona/]42o`0000oob=>m0ol0000CohN8a@?o00005_oK[kX2o`0001_oV:Ym0ol0000E
ojFTd`Go00008Oooool3o`0006Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0Foooool2o`0000kooooo1_l0000BohUh]@;o00006_nR]K43o`0000?oQIjY0_l0000Dojb^
K`?o00007Oo@/md2o`0001OoeZC60ol0000Foj6aa`;o00001onVOkX3o`0001ko_lcQ0_l0000DonGN
a`;o00004_n_V8<3o`0000Woa;:Q0ol0000Mok6bd@?o00004?o8dkd3o`00017oQhS50ol0000Gom^_
^P;o00006_nHZWd3o`0001OoYJCC0_l0000Tooooo`;o0000J?ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1Kooooo`;o00004Oooool5o`00013oRGRe0_l0000Ioj:e/@?o
00001?n5WZT3o`0001Co[:i_0_l0000Mom2cg@;o00006?oFY<H3o`0001CoXK770ol00008ojIo^P?o
00007Onoc>42o`0001CoiMk70_l0000AojnHP`?o00002oo4/Z42o`0001go/K;A0_l0000BolSC_@?o
00003on7R<D3o`0001Sofjnj0_l0000IoiRZO@?o00006?nUY=<2o`0002Cooooo0_l0001Xooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_ooooo0_l0000Cooooo`Ko0000
3?n9N;D4o`0001OoX[Fa0ol00006ohFNZ@?o00004on/[Vl2o`0001cod;?M0ol0000IomJTaP?o0000
4_nQ/LL3o`0000[oYWnj0ol0000Loko<h@;o00005?oUg/L2o`00013o[iR30ol0000<olBbX@?o0000
7?na/]42o`0001?ob=>m0_l0000>ohN8a@?o00006OoK[kX3o`0001OoV:Ym0ol0000IojFTd`;o0000
8oooool3o`0006Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Fooo
ool2o`0001Gooooo1_l00008ohUh]@So00005?nR]K43o`0000SoQIjY0_l0000Cojb^K`;o00007?o@
/md2o`0001_oeZC60ol0000@oj6aa`?o00003?nVOkX3o`0001_o_lcQ0_l0000DonGNa`;o00003on_
V8<3o`0000koa;:Q0_l0000Lok6bd@;o00004oo8dkd3o`0000coQhS50ol0000Kom^_^P;o00005_nH
ZWd3o`0001[oYJCC0_l0000Sooooo`;o0000JOooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Kooooo`;o00006?ooool5o`0000GoRGRe1?l00002okOT]`Ko00004?nR]K43
o`0000WoQIjY0ol0000Bojb^K`;o00007?o@/md2o`0001coeZC60ol0000>oj6aa`?o00003_nVOkX3
o`0001[o_lcQ0ol0000ConGNa`;o00003_n_V8<3o`0000ooa;:Q0ol0000Jok6bd@?o00005?o8dkd3
o`0000[oQhS50ol0000Lom^_^P;o00005OnHZWd3o`0001_oYJCC0_l0000Sooooo`;o0000JOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Kooooo`;o00006_ooool:o`00
00Ko]nBg1_l0000=oj:e/@?o00002on5WZT3o`00017o[:i_0ol0000Kom2cg@;o00007OoFY<H3o`00
00goXK770_l0000@ojIo^P?o00006_noc>42o`0001?oiMk70_l0000;ojnHP`Go00004Oo4/Z42o`00
01[o/K;A0_l0000FolSC_@?o00002?n7R<D3o`0001gofjnj0ol0000CoiRZO@?o00007?nUY=<2o`00
02;ooooo0ol0001Yooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05_o
oooo0_l0000Looooo`Oo00002_ngi;L5o`0000[oX[Fa0ol0000=ohFNZ@;o00004_n/[Vl2o`0001[o
d;?M0ol0000NomJTaP?o00002onQ/LL3o`00017oYWnj0ol0000Ioko<h@;o00004ooUg/L2o`0000Oo
[iR32?l0000BolBbX@?o00006Ona/]42o`0001Oob=>m0ol00006ohN8a@?o00007_oK[kX4o`00017o
V:Ym0ol0000MojFTd`;o00008_ooool2o`0006[ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0Foooool2o`0001oooooo0_l0000>okOT]`Go00001onR]K43o`0000koQIjY
0ol0000Aojb^K`;o00006_o@/md2o`00023oeZC60ol00009oj6aa`?o00004onVOkX3o`0001So_lcQ
0_l0000ConGNa`;o00001?n_V8<8o`000004ofejT?l0003o0000o`0001;oa;:Q0_l0000Hok6bd@?o
00006?o8dkd3o`0000CoQhS50ol0000Nom^_^POo00003_nHZWd3o`0001koYJCC0_l0000Rooooo`;o
0000J_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Kooooo`;o0000
7_ooool3o`00013o]nBg1_l00003oj:e/@?o00004?n5WZT3o`00013o[:i_0_l0000Jom2cg@;o0000
8OoFY<H3o`0000OoXK770ol0000EojIo^P?o00005onoc>42o`0001?oiMk72_l00006ofejT0;o0000
4_o4/Z43o`0001Oo/K;A0_l0000JolSC_@?o00000_n7R<D3o`0001kofjnj0ol00002oj^@^`Go0000
2onHZWd3o`0001ooYJCC0_l0000Qooooo`?o0000J_ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1Jooooo`?o00007_ooool2o`0001?o]nBg2Ol0000BohFNZ@?o00003on/
[Vl2o`0001[od;?M0_l0000RomJTaP?o00001_nQ/LL2o`0001OoYWnj0ol0000Foko<h@?o00004OoU
g/L8o`0000WoKGZ@0_l0000ColBbX@;o00005ona/]42o`0001_ob=>m1_l0000Nom^_^P?o00001On[
T;/5o`0000SoV:Ym0ol0000PojFTd`;o00008Oooool2o`0006_ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0F_ooool2o`0001oooooo0_l0000FokOT]`Go00005?n5WZT2
o`0000oo[:i_0ol0000Iom2cg@;o00008ooFY<H3o`0000CoXK770ol0000HojIo^P?o00005_noc>42
o`0000ooiMk71_l0000=ofejT0?o00004_o4/Z42o`0001Oo/K;A0_l0000LolSC_@Co00007_oK[kX3
o`0000SoZi2k1?l00006oiRZO@?o00008OnUY=<2o`00027ooooo0_l0001[ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`?o0000F_ooool2o`0001kooooo0ol0000HokOT]`;o00005On5WZT3o`00
00oo[:i_0_l0000Hom2cg@?o00009?oFY<H3o`0000;oXK770ol0000JojIo^Q[o00003OoUg/L5o`00
017oKGZ@0_l0000BolBbX@?o00005Ona/]43o`0001gob=>m0_l0000Nom^_^P?o00002on[T;/4o`00
00?oV:Ym0ol0000PojFTd`Co00008?ooool3o`0006Wooooo0ol0000:ooooo`006_ooool00ol0003o
ooooooooo`1Jooooo`;o00007_ooool2o`0001Wo]nBg0_l0000FohFNZ@?o00003_n/[Vl2o`0001So
d;?M0_l0000VomJTaPKo00006onVOkXJo`0000_oiMk71Ol0000CofejT0?o00004_o4/Z42o`0001Go
/K;A0_l0000NolSC_@?o00007?oK[kX3o`0000goZi2k2?l0000LojFTd`Wo00008?ooool2o`0006co
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool2o`0001kooooo
0_l0000IokOT]`;o00005on5WZT2o`0000ko[:i_0_l0000Hom2cg@;o00009ooFY<H4o`0001_oYWnj
0ol0000FonOJX@?o00002?oUg/L5o`0001KoKGZ@0_l0000BolBbX@?o00005?na/]42o`0001oob=>m
0_l0000Kom^_^P?o00004?n[T;/5o`0001WoYJCC2_l000001?o1[Kco0000o`000?l0000Oooooo`;o
0000K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o0000
7Oooool3o`0001Wo]nBg0ol0000FohFNZ@?o00003On/[Vl2o`0001Sod;?M0_l0000VomJTaPKo0000
6OnVOkX3o`0001SoimZQ0ol00005onGNa`Go00006?m]NY02o`0001?oa;:Q0_l0000Dok6bd@;o0000
7oo8dkd2o`0001[ofjnj0ol0000Coj^@^`;o00005_nUY=<9o`0000Oo`Jfl0_l0000Oooooo`;o0000
K?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00007Ooo
ool2o`0001_o]nBg0_l0000GohFNZ@?o00003?n/[Vl3o`0001Ood;?M0_l0000UomJTaP?o00000_n^
VYH3o`0001OoYWnj0ol0000JonOJX@;o00000ooUg/L5o`0001[oKGZ@0ol0000BolBbX@?o00004_na
/]43o`0001oob=>m0ol0000Gom^_^PCo00005?n[T;/3o`00013oYJCC2_l0000;ol6]_0?o00007Ooo
ool3o`0006cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool2
o`0001gooooo0_l0000KokOT]`;o00006?n5WZT2o`0000go[:i_0_l0000Fom2cg@?o00009?oFY<H3
o`0000Co[YZF0ol0000EojIo^P?o00006ooWfZ48o`0001goKGZ@0_l0000ColBbX@;o00004_na/]42
o`00027ob=>m0_l0000Fom^_^PCo00005_n[T;/3o`0000_oYJCC2_l0000@ol6]_0;o00007Oooool2
o`0006gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool2o`00
01cooooo0ol0000KokOT]`;o00006?n5WZT3o`0000_o[:i_7Ol0000RomJTaP?o00001_n^VYH3o`00
01?oYWnj0ol0000MonOJX@Go00007om]NY03o`0001;oa;:Q0ol0000Aok6bd@;o00008Oo8dkd2o`00
01Gofjnj0ol0000Ioj^@^`;o00001onUY=<9o`0001Go`Jfl0_l0000Mooooo`;o0000KOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00007?ooool2o`0001co
]nBg0_l0000IohFNZ@?o00002On/[VlQo`0001koeZC60ol00008ojjJUP?o00004OnVOkX3o`0001oo
imZQ0_l0000RofejT0;o00004oo4/Z42o`00017o/K;A0_l0000QolSC_@?o00004ooK[kX3o`0001[o
Zi2k0ol000000onUY=?o0000o`000008o`0001Wo`Jfl1Ol0000Iooooo`?o0000KOooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Jooooo`;o00007?ooool2o`0001co]nBg
0_l0000JohFNZ@;o00002?n/[Vl3o`0001Soe>730_l000000oohilCo0000o`000005o`0001[oeZC6
0ol0000:ojjJUP?o00003onVOkX3o`00023oimZQ0_l0000RofejT0?o00004_o4/Z43o`0000oo/K;A
0ol0000RolSC_@;o00004_oK[kX3o`0001coZi2k2Ol0000Nol6]_0So00005Oooool2o`0006kooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0F_ooool2o`0001_ooooo0ol0
000LokOT]`;o00006_n5WZT3o`0000Ko[:i_0ol0000IomCQ``;o00001?ohil@7o`0001KoeZC60ol0
000<ojjJUPCo00003?nVOkX3o`00027oimZQ0_l0000SofejT0;o00004oo4/Z42o`0000ko/K;A1?l0
000RolSC_@;o00004OoK[kX3o`0001koZi2k0ol0000Rol6]_0?o000000?oooooo`000?l000001ol0
000Aooooo`;o0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1J
ooooo`;o00006oooool2o`0001go]nBg0ol0000JohFNZ@Ko000000Co[:i_o`000?l0003o00006_oD
hL<2o`0000Oon>O42?l0000AomJTaP?o00003_n^VYH4o`0000[oYWnj0ol0000RonOJX@;o00008om]
NY02o`0001?oa;:Q0ol0000:ok6bd@So00008Oo8dkd3o`0000oofjnj0ol0000Ooj^@^`;o00008oo1
[K`2o`0000Kooooo2Ol0000<ooooo`?o0000K_ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Jooooo`?o00006_ooool2o`0001ko]nBg0_l0000GohFNZ@co00006ooDhL<2
o`0000[on>O42?l0000=omJTaP?o00004On^VYH3o`0000SoYWnj0ol0000SonOJX@;o00008om]NY03
o`0001?oa;:Q0_l00007ok6bd@Oo00000_n9W9@3o`00027ob=>m0_l0000>om^_^P?o00008?n[T;/3
o`00027o`Jfl0ol0000:ooooo`So00002Oooool2o`0006oooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Foooool3o`0001Sooooo0ol0000NokOT]`;o00005?n5WZT7o`00
00CoaZO=0ol0000KomCQ``?o00003_ohil@7o`0000WoeZC60ol0000CojjJUP?o00001_nVOkX3o`00
02CoimZQ0_l0000TofejT0;o00004oo4/Z43o`0000?o/K;A1ol00006ohVLU0Co00007oo8dkd2o`00
00gofjnj0ol0000Roj^@^`;o00008Oo1[K`2o`0000oooooo2?l00005ooooo`;o0000Koooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Looooo`?o00005oooool2o`0001ko
]nBg1?l0000@ohFNZ@Oo00002?o6Yld2o`0001_oe>730_l0000BooSWa0Oo00001OoFY<H3o`0001Go
[YZF0ol00004ojIo^P?o00009OoWfZ42o`0002CoKGZ@0ol0000ColBbX@Wo00002_n9W9@4o`0001ko
b=>m0ol0000;om^_^P?o00008on[T;/2o`00023o`Jfl0ol0000Booooo`co0000Koooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Mooooo`?o00005_ooool2o`0001go]nBg
2?l0000;ohFNZ@Ko00002oo6Yld2o`0001_oe>730_l0000EooSWa0Oo000000CoeZC6o`000?l0003o
00005on^VYH3o`0000;oYWnj0ol0000VonOJX@;o00009Om]NY02o`0001?oa;:Q1_l0000?ohVLU0?o
00007_o8dkd2o`0000Wofjnj1?l0000Toj^@^`;o00008?o1[K`2o`0001Oooooo1ol0001`ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo05kooooo0ol0000Dooooo`?o0000
7?ngi;L3o`0000;oe[ff1_l00006ohFNZ@Ko00003_o6Yld3o`0001[oe>730_l0000HooSWa0Oo0000
6On^VYH6o`0002OoimZQ0_l0000UofejT0;o00005?o4/Z42o`0001?oRIbD0ol0000MolSC_@;o0000
1ooK[kX8o`0002;oZi2k0_l0000Ool6]_0?o00006oooool3o`00073ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Goooool3o`0001?ooooo0_l0000LokOT]`?o00001_oF
_KH=o`00017oaZO=0_l0000JomCQ``;o00006oohil@3o`0001_o[YZF1?l0000XonOJX@;o00009Om]
NY03o`0001;oa;:Q0ol0000DohVLU0Ko00006Oo8dkd3o`0000Cofjnj1Ol00002ohJ=M@Go00008?n[
T;/3o`0001ko`Jfl0_l0000Mooooo`;o0000L?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1Pooooo`;o00004oooool2o`0001_o]nBg0ol00009omJm]PSo00005?o6Yld2
o`0001[oe>730_l0000LooSWa0;o00007?n^VYH2o`0002WoimZQ0_l0000VofejT0;o00004Oo4/Z43
o`0001KoRIbD2ol0000DolSC_@;o00000_oK[kX5o`0000KoQXee1Ol0000Ooj^@^`;o00007Oo1[K`3
o`0001gooooo0_l0001`ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
063ooooo0ol0000Aooooo`?o00006_ngi;L3o`0000goe[ff0_l0000GolJWc@;o00006_oDhL<2o`00
01con>O40_l0000LojjJUP?o0000:?oWfZ42o`0002KoKGZ@0ol0000?olBbX@?o00005on9W9@2o`00
00;o_l:[3_l0000=olSC_@Oo00002_n6SGD5o`0001goZi2k0_l0000Mol6]_0;o00007Oooool3o`00
073ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0HOooool3o`00013o
oooo0_l0000JokOT]`?o00003_oF_KH3o`0001KoaZO=0_l0000JomCQ``;o00007?ohil@2o`0001go
[YZF0_l0000XonOJX@;o00009om]NY02o`0000koa;:Q0ol0000GohVLU0?o00002?no`Z/>o`0000Oo
b=>m1Ol0000>ohJ=M@Go00006on[T;/2o`0001co`Jfl0ol0000Mooooo`;o0000LOooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Rooooo`?o00003oooool2o`0001Wo]nBg
0ol0000@omJm]P;o00005_o6Yld2o`0001[oe>730_l0000LooSWa0;o00007On^VYH2o`0002SoimZQ
0_l0000WofejT0;o00003Oo4/Z43o`0001SoRIbD0_l0000@oko2Z`go00000_o8dkd2o`0001;oQXee
1Ol0000Ioj^@^`;o00007?o1[K`2o`0001kooooo0_l0001aooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo06?ooooo0ol0000=ooooo`?o00006?ngi;L3o`00017oe[ff0ol0
000EolJWc@;o00006OoDhL<3o`0001con>O40_l0000MojjJUP?o00009ooWfZ42o`0002OoKGZ@1_l0
0008olBbX@?o00006On9W9@2o`0001Ko_l:[2ol0000DohJ=M@Go00005on[T;/3o`0001[o`Jfl0ol0
000Mooooo`?o0000LOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1T
ooooo`?o00003?ooool2o`0001So]nBg0ol0000ComJm]P;o00005Oo6Yld3o`0001Soe>730_l0000M
ooSWa0;o00007_n^VYH2o`0002OoimZQ0_l0000TofejT0ko00000_o4/Z43o`0001[oRIbD0_l0000L
oko2Z`Co00005on6SGD5o`0001GoZi2k1?l0000Iol6]_0;o00007_ooool2o`0007;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0IOooool2o`0000cooooo0_l0000GokOT
]`?o00005?oF_KH2o`0001KoaZO=0_l0000HomCQ``;o00007Oohil@2o`0001ko[YZF0_l0000WonOJ
X@;o00008_m]NY06o`0000Col<CE2_l0000JohVLU0?o00007_no`Z/2o`0001WoQXee1Ol0000Boj^@
^`Ko00005oo1[K`3o`0001kooooo0_l0001booooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06Gooooo0ol0000:ooooo`?o00005_ngi;L3o`0001Goe[ff0ol0000EolJWc@;o
00006?oDhL<2o`0001gon>O40_l0000MojjJUPCo00009?oWfZ44o`00023oKGZ@1Ol0000<oo34e@Co
00006on9W9@2o`0001oo_l:[0ol0000JohJ=M@Go00003on[T;/3o`0000;o[[[B1?l0000Eol6]_0;o
00007_ooool3o`0007;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
I_ooool3o`0000Sooooo7?l0000GomJm]P;o00005Oo6Yld2o`0001Soe>738Ol0000JojjJUPSo0000
7_oWfZ49o`0001goKGZ@1_l0000@oo34e@?o00006_n9W9@2o`0001oo_l:[1?l0000KohJ=M@Go0000
3?n[T;/3o`0000Co[[[B1Ol0000Bol6]_0?o00007_ooool2o`0007?ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Ioooool3o`0000Gooooo7Ol0000HomJm]P?o00005?o6
Yld2o`0001Soe>738Ol0000GojjJUPOo00000_oFbN/3o`0001SoimZQ2ol000001?nVZH_o0000o`00
0?l0000JofejT0Ko00004oo`a=D2o`0001[oRIbD0_l0000Noko2Z`Ko00007?n6SGD5o`0000WoZi2k
0ol00007ojjjdPCo00004Oo1[K`2o`0001oooooo0_l0001cooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo06Sooooo0ol00003ooooo`Co00006?ooool3o`0001Soe[ff0_l0
000DolJWc@;o00006?oDhL<2o`0001go[Yio0_l0000DojjJUPOo00001_oFbN/3o`0001;oimZQ2ol0
0007ojJYR`?o00005om]NY05o`0001Kol<CE0_l0000IohVLU0?o00007_no`Z/2o`0000;oY6jM0ol0
000MohJ=M@Go00001_n[T;/3o`0000[o[[[B1?l0000>ol6]_0?o00007_ooool3o`0007?ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool7o`0001_ooooo0_l0000H
omJm]P?o00004oo6Yld2o`0001Ooe>730ol0000MojjNO`;o00004On^VYH7o`0000[oe/W[0ol0000=
onOJX@[o00003OnVZH/3o`0001?oKGZ@1_l0000Hoo34e@?o00006?n9W9@2o`0001ko_l:[0ol00003
ojA^W@?o00007_n6SGD5o`0000?oZi2k0ol0000<ojjjdPGo00003?o1[K`2o`0001oooooo0_l0001d
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06[ooooo1Ol0000Loooo
o`?o00006?oF_KH2o`0001?oaZO=0ol0000FomCQ``;o00007_n^WWl2o`0000go[YZF2?l0000>omK9
j`?o00001ooWfZ4:o`0001?oYZV;0ol0000@ofejT0Ko00006oo`a=D2o`0001SoRIbD0_l0000Noko2
Z`;o00001OnTKYd4o`0001koQXee2?l0000?ojjjdPCo00002_o1[K`3o`0001oooooo0_l0001doooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06_ooooo0_l0000Oooooo`;o
00006?oF_KH2o`0001CoaZO=0_l0000FomCQ``;o00007_n^WWl3o`0000Wo[YZF2?l0000BomK9j`?o
000000?oimZQo`000?l000002Ol0000HojJYR`?o00003Om]NY05o`0001kol<CE0_l0000HohVLU0;o
00007Ono`Z/3o`0000KoY6jM1?l0000OohJ=M@Go00004_n^^]84o`0000So`Jfl0_l0000Oooooo`?o
0000M?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1[ooooo`;o0000
7oooool3o`0001Ooe[ff0ol0000ColJWc@;o00005OoDhL<3o`0001oo[Yio0_l00006ojjJUPOo0000
5ooFbN/9o`0001koYZV;0_l0000:ofejT0Ko00008?o`a=D3o`0001KoRIbD0ol0000Loko2Z`?o0000
2OnTKYd3o`0001ooQXee0ol0000DojjjdPGo00001?o1[K`4o`0001oooooo0_l0001eooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06[ooooo0ol0000Pooooo`;o00006?oF
_KH2o`0001?oaZO=0_l0000DomCQ``Co00007on^WWl2o`0000?o[YZF1ol0000IomK9j`Go00008onV
ZH/3o`0000OoKGZ@1_l0000Soo34e@;o00005_n9W9@2o`0001go_l:[0_l0000;ojA^W@?o00006on6
SGD5o`0001Oo[[[B3_l0000Looooo`;o0000MOooool00ol0003oooooooooo`08ooooo`006_ooool3
o`0006[ooooo0_l0000Qooooo`?o00005ooF_KH3o`0001;oaZO=0_l0000AomCQ``So00007_n^WWl9
o`0001_oe/W[1Ol0000UojJYR`?o00001?m]NY05o`0002Kol<CE0_l0000FohVLU0;o00007?no`Z/3
o`0000coY6jM1?l0000EohJ=M@So00006_n^^]86o`0000;ooooo1_l0000Iooooo`?o0000Loooool3
o`0000[ooooo000Jooooo`03o`000?oooooooooo06[ooooo0_l0000Rooooo`;o00006?oF_KH2o`00
01;oaZO=0_l0000>omCQ``Oo00000_nGWiP3o`0001go[Yio1_l0000LomK9j`Co000000?oOl>?o`00
0?l000009_nVZH/9o`0002Sol<CE0ol0000EohVLU0;o00007?no`Z/2o`0000koY6jM1?l0000@ohJ=
M@Wo000000?o^XR3o`000?l000006on^^]82o`0000Sooooo1Ol0000Gooooo`;o0000M_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`?o00008_ooool3o`0001Oo
e[ff0ol0000AolJWc@;o00002ooDhL<7o`0000KoUinH0ol0000LojjNO`?o00007_oFbN/4o`0000;o
Ol>?0ol0000VojJYR`Ko0000:oo`a=D2o`0001CoRIbD0ol0000Koko2Z`?o00004?nTKYd3o`0000_o
QXee2Ol00005okZ8P`;o00006on^^]82o`0000[ooooo1_l0000Dooooo`;o0000M_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`;o00009?ooool2o`0001Soe[ff
0_l0000AolJWc@?o00001ooDhL<7o`0000[oUinH0ol0000JojjNO`Co00007OoFbN/3o`0000GoOl>?
0_l0000WojJYR`;o0000;_o`a=D2o`0001CoRIbD0_l0000Loko2Z`;o00004_nTKYd3o`0000KoQXee
2Ol00009okZ8P`;o00006_n^^]83o`0000cooooo1_l0000Aooooo`?o0000M_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`;o00009?ooool3o`0001Ooe[ff0_l0
000BolJWc@;o00001?oDhL<7o`0000koUinH1?l0000GojjNO`Ko00006_oFbN/4o`0000KoOl>?0_l0
000WojJYR`;o0000;_o`a=D3o`0001?oRIbD0_l0000Koko2Z`?o00004onTKYd3o`000003ohJ=MOl0
003o000000Oo00003OnjR8<2o`0001[o[[[B0_l0000@ooooo`Go00003oooool2o`0007Oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0J?ooool3o`0002Gooooo0_l0000G
omJm]P?o00004?o6Yld;o`0001;oUinH1?l0000DojjNO`Co00000_o8aL83o`0001Soe/W[1?l00007
ogo3S`;o00009onVZH/2o`0002ool<CE0_l0000CohVLU0;o00006ono`Z/2o`0001GoY6jM2?l0000A
okZ8P`;o00006_n^^]82o`0001;ooooo1_l0000<ooooo`;o0000Moooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1Xooooo`;o00009_ooool3o`0001Ooe[ff0_l0000?olJW
c@Wo00005onGWiP3o`0001;o[Yio1?l00004olS5`PCo00005?oFbN/4o`0000WoOl>?0_l0000WojJY
R`;o0000;oo`a=D2o`0001;oRIbD0ol0000Joko2Z`?o00005_nTKYd3o`0001Go^XR30_l0000Jojjj
dP;o00005?ooool6o`0000Wooooo0ol0001gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo06Sooooo0_l0000Wooooo`;o00005ooF_KH5o`0000[oaZO=1?l00005ok[3[P?o
00005onGWiP3o`0000oo[Yio1?l00007olS5`PCo00004_oFbN/4o`0000[oOl>?0_l0000WojJYR`;o
0000;oo`a=DGo`0001[o_l:[0_l0000GojA^W@?o00005OnjR8<2o`0001Wo[[[B0ol0000Gooooo`Go
00001oooool2o`0007Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
J?ooool3o`0002Kooooo0ol0000ComJm]P_o00001Oo6Yld5o`0000Oo^/>^0_l0000HoiNOV0?o0000
3On^WWl4o`0000[ob<G20ol0000@omK9j`?o00003?mo`hl3o`0002KoYZV;0ol0000_oo34eAOo0000
6?no`Z/3o`0001SoY6jM0_l0000EokZ8P`;o00006On^^]82o`0001[ooooo1_l00004ooooo`;o0000
N?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`;o00009ooo
ool2o`00017oe[ff1_l00003okC5Z`Oo000000?oaZO=o`000?l000000_l00009ok[3[P?o00006?nG
WiP4o`0000[o[Yio0ol0000=olS5`PCo00003?oFbN/4o`0000koOl>?0_l0000WojJYR`;o0000;_o`
a=D3o`0001?ogNf]1?l0000Foko2Z`;o00006OnTKYd2o`0001Go^XR30_l0000IojjjdP;o00007?oo
ool:o`0007Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0JOooool2
o`0002Oooooo0ol0000>omJm]PGo00002OndaJ/7o`0000co^/>^0_l0000IoiNOV0Co00001on^WWl4
o`0000oob<G21?l0000:omK9j`Co00003omo`hl2o`0002OoYZV;0_l0000^oo34e@;o00005OoMkJd4
o`0001Co_l:[0ol0000IojA^W@?o00005?njR8<2o`0001Wo[[[B0_l0000Oooooo`Ko0000NOooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1Yooooo`?o00009oooool2o`00
00_oe[ff1_l0000>okC5Z`?o00003Onj`jh3o`0001[oUinH0ol00005ojjNO`Co00004_o8aL83o`00
00Soe/W[0ol0000Aogo3S`;o00009onVZH/2o`0002gol<CE0ol0000Gomg][@Co00004Ono`Z/3o`00
01_oY6jM0_l0000DokZ8P`;o00006?n^^]83o`00027ooooo0_l0001kooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo06[ooooo0_l0000Wooooo`?o00002?oF_KH6o`00017o
]<F[0_l0000>ok[3[P;o00006onGWiP3o`0000;o[Yio1?l0000EolS5`PCo00001?oFbN/4o`0001;o
Ol>?0_l0000WojJYR`?o0000;?o`a=D2o`0001WogNf]1?l0000@oko2Z`;o00007?nTKYd2o`0001Co
^XR30_l0000HojjjdP;o00008Oooool3o`0007_ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0J_ooool2o`0002Sooooo0_l00006omJm]PGo00005?ndaJ/2o`0000ko^/>^
0ol0000KoiNOV0Oo00005oo8aL84o`0000;oe/W[1?l0000Cogo3S`;o00009onVZH/6o`0002Sol<CE
0ol0000Komg][@Co00003Ono`Z/3o`0001coY6jM0ol0000CokZ8P`;o00006?n^^]82o`00027ooooo
0_l0001looooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06[ooooo0ol0
000Wooooo`?o00000_oF_KH6o`0001Ko]<F[0_l0000?ok[3[P;o00007?nGWiP4o`0001_ob<G21_l0
000Eogo3S`;o00009_nVZH/9o`0002Kol<CE0_l0000Momg][@Co00003?no`Z/2o`0001koY6jM0_l0
000CokZ8P`;o00006?n^^]82o`00027ooooo0_l0001looooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo06_ooooo0_l0000Xooooo`So00006?ndaJ/2o`0000oo^/>^0ol0000L
oiNOV0;o00007Oo8aL84o`0001KoOl>?0ol0000UojJYR`;o00001?nUV[46o`0002?ol<CE0_l0000O
omg][@Co00001ono`Z/5o`0001koY6jM0_l0000CokZ8P`;o00005on^^]83o`00023ooooo0ol0001l
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06_ooooo0_l0000Xoooo
o`Go00006ondaJ/2o`00013o^/>^0_l0000LoiNOV0;o00007Oo8aL83o`0001SoOl>?0_l0000TojJY
R`?o00001_nUV[47o`0001ool<CE0ol0000Pomg][@Co000000?o_l:[o`000?l000001ol0000OojA^
W@?o00004_njR8<2o`0001Oo[[[B0_l0000Qooooo`;o0000OOooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1[ooooo`?o0000:?ooool2o`0001go]<F[0_l0000@ok[3[P?o
00006_nGWiP3o`0001cob<G21?l0000Hogo3S`;o00009?nVZH/2o`0000[oYIZa1_l0000Moo34e@;o
00008ooMkJd9o`000004ojfLaOl0003o0000o`0001ooY6jM0_l0000BokZ8P`;o00005on^^]82o`00
027ooooo0_l0001mooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06co
oooo0_l0000Wooooo`?o00007OndaJ/2o`00017o^/>^0_l0000IoiNOV0Co00006oo8aL86o`0001Oo
Ol>?0_l0000TojJYR`;o00003OnUV[46o`0001Wol<CE0ol0000Tomg][@?o00001on]W<D3o`0001ko
Y6jM0_l0000BokZ8P`;o00005_n^^]83o`00023ooooo0ol0001mooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo06cooooo0_l0000Wooooo`;o00007_ndaJ/2o`00017o^/>^
0ol0000GoiNOV0Ko00006Oo8aL83o`0000;o`jFc0ol0000Fogo3S`;o00008onVZH/3o`0000ooYIZa
1_l0000Goo34e@;o00009?oMkJd3o`0000Wo[Ic50ol0000MojA^W@?o00004OnjR8<2o`0001Ko[[[B
0_l0000Qooooo`;o0000O_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1/ooooo`?o00009_ooool2o`0001ko]<F[0_l0000Bok[3[P;o00005_nGWiP3o`0000;o^hmn0ol0
000GolS5`P?o00001?o3YK<2o`0001KoOl>?0_l0000SojJYR`;o00004onUV[46o`0001;ol<CE1?l0
000Somg][@?o00002on]W<D2o`0001koY6jM0_l0000AokZ8P`;o00005_n^^]82o`00023ooooo0ol0
001nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo06gooooo0_l0000U
ooooo`?o00007_ndaJ/2o`0001;o^/>^0_l0000DoiNOV0Co00001?nkSgh2o`0001Kob<G20ol00005
ol>U/`?o00005Omo`hl3o`00027oYZV;0ol0000EojFJ/@Oo00003?o`a=D6o`0002?ogNf]0ol0000<
ojfLa@?o00007OnTKYd3o`00013o^XR30_l0000FojjjdP;o00008?ooool2o`0007oooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0KOooool2o`0002Gooooo0_l0000OokC5
Z`;o00004_nj`jh3o`0001;oUinH1?l00005ok^?OP?o00005?o8aL83o`0000Oo`jFc0_l0000Fogo3
S`;o00008OnVZH/2o`0001WoYIZa1_l00007oo34e@[o00008_oMkJd2o`0000ko[Ic50ol0000MojA^
W@;o00004?njR8<2o`0001Go[[[B0ol0000Pooooo`;o0000Ooooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`1]ooooo`?o00008oooool3o`0001oo]<F[0_l0000Cok[3[P;o
00004OnGWiP3o`0000So^hmn0ol0000BolS5`P?o00002?o3YK<3o`0001CoOl>?1Ol0000NojJYR`?o
00007?nUV[46o`000003oo34eOl0003o000000Go00001?o1h]h3o`00023ogNf]0ol0000?ojfLa@;o
00007OnTKYd2o`00013o^XR30_l0000EojjjdP;o00008?ooool3o`0007oooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0K_ooool2o`0002?ooooo0_l0000PokC5Z`;o0000
4onj`jh3o`0000ooUinH0ol0000:ok^?OP;o00004Oo8aL83o`0000[o`jFc0ol0000Bogo3S`Wo0000
6onVZH/2o`0001ooYIZa2Ol00008ol7RgP?o00007_oMkJd3o`00013o[Ic50ol0000LojA^W@?o0000
3onjR8<2o`0001Go[[[B0_l0000Pooooo`;o0000P?ooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`1^ooooo`;o00008_ooool3o`00023o]<F[0_l0000Dok[3[P;o00003OnG
WiP4o`0000_o^hmn0ol0000?olS5`P?o00003?o3YK<2o`00017oOl>?0ol00003olBMT@So00005onV
ZH/2o`0002;oYIZa0ol0000<ol7RgP?o00007OoMkJd2o`0001;o[Ic50ol0000LojA^W@;o00003onj
R8<2o`0001Go[[[B0_l0000Pooooo`;o0000P?ooool00ol0003oooooooooo`08ooooo`006_ooool0
0ol0003oooooooooo`1^ooooo`?o00008Oooool2o`00027o]<F[0_l0000Dok[3[P?o00002onGWiP4
o`0000go^hmn0ol0000=olS5`P?o00003Oo3YK<3o`0000ooOl>?0ol00007olBMT@So00004_nVZH/4
o`0002;oYIZa0_l0000>ol7RgP?o00006ooMkJd3o`0001?o[Ic50ol0000KojA^W@;o00003onjR8<2
o`0001Co[[[B0ol0000Oooooo`?o0000P?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1_ooooo`;o00008Oooool2o`00027o]<F[0_l0000Eok[3[P;o00002_nGWiP3o`00
013o^hmn0_l0000<olS5`P?o00003oo3YK<3o`0000coOl>?1?l0000<olBMT@Oo00003OnVZH/5o`00
02?oYIZa0_l0000?ol7RgP?o00006OoMkJd3o`0001Go[Ic50_l0000KojA^W@?o00003_njR8<2o`00
01Co[[[B0_l0000Pooooo`;o0000POooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`1_ooooo`;o00008?ooool3o`00027o]<F[0_l0000Eok[3[P?o00002?nGWiP3o`00017o
^hmn0ol0000:olS5`P?o00004Oo3YK<2o`0000_oOl>?1?l0000@olBMT@So00001_nVZH/9o`00027o
YIZa0ol0000@ol7RgP?o00005ooMkJd3o`0001Ko[Ic50ol0000KojA^W@;o00003_njR8<2o`0001Co
[[[B0_l0000Pooooo`;o0000POooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1_ooooo`?o00007oooool2o`0002;o]<F[0_l0000Fok[3[P;o00001onGWiP3o`0001?o^hmn
0ol00008olS5`P?o00004_o3YK<3o`0000WoOl>?0ol0000EolBMT@So000000?oYZV;o`000?l00000
1?l00003oiBc_`;o00008OnUV[42o`0001;o`N;N0ol0000Fomg][@;o00006?n]W<D7o`0001KoY6jM
0_l0000>okZ8P`;o00005?n^^]82o`0001oooooo0ol00021ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo073ooooo0_l0000Nooooo`?o00008_ndaJ/2o`0001Ko^/>^0ol0
0004oiNOV0Co00005OnkSgh2o`0000Oob<G20ol0000Dol>U/`?o00001omo`hl3o`0001[oa9fA2?l0
0006oiBc_`?o00008?nUV[42o`0001?o`N;N0_l0000Eomg][@?o00006On]W<D=o`0000ooY6jM0ol0
000=okZ8P`;o00004on^^]83o`0001oooooo0_l00022ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo073ooooo0_l0000Nooooo`;o00008ondaJ/2o`0001Oo^/>^0_l00003
oiNOV0Co00005_nkSgh3o`0000Gob<G20ol0000Fol>U/`;o00001Omo`hl4o`0001koa9fA0ol00009
oiBc_`?o00007onUV[42o`0001?o`N;N0ol0000Comg][@?o00006On]W<D3o`0000?oMJ9o4?l00008
ojA^W@;o00003OnjR8<2o`0001?o[[[B0_l0000Oooooo`?o0000P_ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1`ooooo`?o00007?ooool3o`0002?o]<F[0_l0000Gok[3
[P?o000000CoUinHo`000?l0003o00006OnkSgh3o`0000?ob<G20ol0000Gol>U/`?o00000omo`hl4
o`0001ooa9fA0ol0000:oiBc_`;o00007onUV[42o`0001Co`N;N0ol0000Bomg][@;o00006_n]W<D2
o`0000_oMJ9o4?l000000onTKYgo0000o`00000=okZ8P`;o00004on^^]82o`0001oooooo0_l00023
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo077ooooo0_l0000Loooo
o`;o00008_ndaJ/5o`0001Oo^/>^1Ol0000Kok^?OP;o00000_o8aL83o`0001Wo`jFc0_l00002ogo3
S`?o00008Oo4WI42o`0000_oU;>o0ol0000NojFJ/@;o00005Oo1h]h3o`00013ogNf]0ol0000JojfL
a@;o00004omeXWl<o`0000co^XR30_l0000CojjjdP;o00007oooool2o`0008?ooooo00?o0000oooo
ooooool02?ooool001[ooooo0ol0001aooooo`;o00007?ooool2o`0001oo]<F[2Ol0000Fok[3[PCo
00007?nkSgh6o`0001[o`jFc1_l0000QolBMT@?o00003?nD/kl2o`0001goYIZa0ol0000Fol7RgP?o
00003_oMkJd3o`0001[o[Ic50ol0000JogFRO`Go00001_njR8<:o`00013o[[[B0ol0000Nooooo`?o
0000POooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo077ooooo0ol0000Jooooo`?o0000
7?ndaJ/7o`0000?ok_:f0ol0000Fok[3[P;o00007_nkSgh4o`0001co`jFc1?l0000RolBMT@;o0000
3OnD/kl3o`0001coYIZa0_l0000Hol7RgP?o00002_oMkJd5o`0001_o[Ic50_l0000NogFROaKo0000
2_n^^]85o`0001kooooo0_l00024ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07;ooooo0ol0000Iooooo`;o00006_ndaJ/7o`0000Ook_:f0ol0000Dok[3[P?o00007onk
Sgh2o`0001_o`jFc1Ol0000RolBMT@?o00003_nD/kl2o`0001coYIZa0_l0000Iol7RgP?o00001OoM
kJd8o`0001co[Ic50_l0000OogFRO`So00002?nLXj/8o`0000;o[[[B3?l0000Looooo`;o0000Q?oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1booooo`Co00005oooool3
o`0001Oo]<F[1ol0000;onkb]PCo00004_nj`jh2o`00023o^hmn0ol0000Gol>U/`Oo00008_o4WI43
o`0000ooU;>o0ol0000KojFJ/@;o00006_o1h]h3o`000003omg][Ol0003o000000Ko000000Co]L^l
o`000?l0003o00006_n]W<D3o`0001koMJ9o0ol0000BoibSZ`co00000oooool6o`0001Oooooo1?l0
0024ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07Cooooo0ol0000F
ooooo`;o00005OndaJ/7o`0000ook_:f1?l0000Aok[3[P;o00008?nkSgh4o`0001?o`jFc1ol00000
1?nUaZSo0000o`000?l0000QolBMT@;o00004OnD/kl2o`0001_oYIZa0_l0000Kol7RgPOo00001_ne
bk`3o`0001Wo[Ic50_l0000OogFRO`;o00005_nLXj/4o`0000[ooooo1_l0000Cooooo`Go0000QOoo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1eooooo`?o00005?ooool3
o`0001;o]<F[1ol0000Donkb]P?o00003onj`jh3o`0001oo^hmn1_l0000?ol>U/`Oo00001OnUaZP2
o`00023oa9fA0ol0000AoiBc_`?o00006_nUV[42o`0001co`N;N0ol0000:okG;_0?o00006?n]W<D2
o`0001koMJ9o0ol0000GoibSZ`;o00003_ooool5o`00013ooooo1?l00027ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo07Kooooo0ol0000Cooooo`;o00004?ndaJ/7o`00
01Sok_:f0ol0000>ok[3[P;o00007onkSgh3o`0000;ob?Vg1?l0000:ol>U/`Oo00002?nUaZP3o`00
01ooa9fA0_l0000CoiBc_`?o00006?nUV[43o`0001_o`N;N0ol0000<okG;_0?o00005_n]W<D3o`00
01koMJ9o0_l0000HoibSZ`;o00004?ooool5o`0000cooooo1?l00029ooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo07Oooooo1?l0000Aooooo`;o00003OndaJ/7o`0001co
k_:f0ol0000=ok[3[P;o00007_nkSgh3o`0000Cob?Vg1Ol00005ol>U/`Oo00003?nUaZP3o`0001go
a9fA0ol0000DoiBc_`;o00006?nUV[42o`0001co`N;N0_l0000>okG;_0?o00005On]W<D2o`0001ko
MJ9o0ol0000HoibSZ`;o00004_ooool5o`0000Sooooo1Ol0002:ooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo07Sooooo1?l0000>ooooo`Go00002OndaJ/7o`00023ok_:f
1?l0000:ok[3[R?o00001oo8nKL4o`000003ol>U/ol0003o000000Go00004?nUaZP2o`0001goa9fA
0_l0000EoiBc_`?o00005onUV[42o`0001_o`N;N0ol0000?okG;_0?o00005?n]W<D2o`0001koMJ9o
0_l0000HoibSZ`?o00005?ooool6o`0000Cooooo1?l0002<ooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo07[ooooo0ol0000:ooooo`co00000_ndaJ/7o`0002Cok_:f1?l0
0009ok[3[R;o00002_o8nKL7o`0001?oYLJX0ol0000KolBMT@?o00005_nD/kl2o`0001OoYIZa0_l0
000Kol7RgP;o00004Onebk`3o`0001;o[Ic50ol0000MogFRO`?o00006?nLXj/2o`0001Oooooo2_l0
002>ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07_ooooo0ol00007
ooooo`Ko00000oooool;o`0002Wok_:f0ol00007ok[3[P?o00007OoWjmD3o`0000_ob?Vg0ol0000G
ojG6Z0;o00006oo4WI42o`0001OoU;>o1?l0000EojFJ/@;o00006oo1h]h2o`0001;o]L^l0ol0000A
ojfLa@;o00007_meXWl2o`0001WoW:>[0_l0000Jooooo`Ko0000Soooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1looooo`?o00001?ooool5o`0000[ooooo1Ol0000/onkb
]P?o00001Onj`jh3o`0001koin_E0_l0000<olSi]`;o00006?nUaZP3o`0001Woa9fA0ol0000HoiBc
_`Go00004onUV[42o`0001[o`N;N0ol0000CokG;_0?o00004?n]W<D2o`0001goMJ9o0ol0000IoibS
Z`;o00007?ooool2o`00097ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0OOooool9o`0000oooooo0ol0000/onkb]PCo00000onj`jh2o`0001koin_E0ol0000<olSi]`;o
00006OnUaZP2o`0001Soa9fA0ol0000HoiBc_`So00004?nUV[43o`0001[o`N;N0_l0000EokG;_0?o
00003_n]W<D3o`0001goMJ9o0_l0000JoibSZ`;o00007?ooool2o`00097ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0O_ooool6o`0001;ooooo0ol0000Yonkb]P_o0000
7_oWjmD2o`0000gob?Vg0ol0000HojG6Z0?o00005oo4WI42o`0001WoU;>o0_l00003olNCTPGo0000
3_nUV[42o`0001[o`N;N0ol0000FokG;_0?o00003On]W<D2o`0001goMJ9o0ol0000JoibSZ`;o0000
7?ooool2o`00097ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Oooo
ool2o`0001Kooooo0ol0000Vonkb]PGo00000_nM`h<5o`0001koin_E0ol0000>olSi]`;o00006OnU
aZP3o`0001Goa9fA0ol0000HoiBc_`?o00001Oo7Ti85o`0000coYIZa0_l0000Jol7RgP;o00006?ne
bk`3o`0000co[Ic50_l0000MogFRO`;o00006onLXj/2o`0001cooooo0_l0002Aooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0_l0000Gooooo`?o00008oo^l[H5
o`0000KoWL>30ol0000NonO[e@;o00003oo8nKL2o`0001[oYLJX0_l0000EolBMT@;o00006OnD/kl2
o`0000Soai>B1Ol0000:ojFJ/@;o00006Oo1h]h3o`0001Wo]L^l0ol0000:ojfLa@?o00007?meXWl3
o`0001_oW:>[0_l0000Looooo`?o0000T?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`1nooooo`?o00006?ooool4o`0001ook_:f1Ol00008oig3P`Go00006ooWjmD3o`00
00oob?Vg0_l0000JojG6Z1Wo00006?nD/kl3o`0000[oai>B1?l00009ojFJ/@;o00006Oo1h]h2o`00
01_o]L^l0ol00009ojfLa@;o00007OmeXWl2o`0001_oW:>[0ol0000Mooooo`;o0000T?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1nooooo`;o00006_ooool4o`0001co
k_:f1Ol0000:oig3P`Ko00006_oWjmD2o`00013ob?Vg0_l0000KojG6Z1Oo00006OnD/kl2o`0000go
ai>B1?l00007ojFJ/@;o00006Oo1h]h2o`0001co]L^l0ol00008ojfLa@;o00007?meXWl3o`0001_o
W:>[0_l0000Nooooo`;o0000T?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`1nooooo`;o00007?ooool3o`0001Wok_:f1Ol0000;oig3P`?o00000_nVKWl4o`0001Soin_E
0_l0000@olSi]`;o00006_nUaZP3o`0001?o[ibl0ol0000GoiBc_`?o00003_o7Ti85o`0000CoYIZa
0ol0000Eol7RgPKo00007Onebk`3o`0000Ko[Ic50ol0000LogFRO`;o00007?nLXj/2o`0001kooooo
0_l0002@ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07kooooo0_l0
000Mooooo`?o00005_o^l[H5o`0000goWL>30_l00004ojI^O`Go00005OoWjmD3o`00013ob?Vg0ol0
000IojG6Z0;o00005On_W;`2o`0001OoU;>o0_l0000AolNCTPGo00000_nUV[42o`0000oo`N;N3?l0
000OokG;_0?o00001On]W<D2o`0001coMJ9o0ol0000LoibSZ`;o00007_ooool2o`00093ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2o`0001kooooo0ol0000C
onkb]PGo00003onM`h<2o`0000KoYVio1?l0000DonO[e@;o00004_o8nKL2o`0001WoYLJX0_l0000E
ojnL_0;o00005_nD/kl3o`0001?oai>B2ol00004ol7RgPoo00000_o1VlH3o`0001oo]L^l0ol00004
ojfLa@;o00007?meXWl2o`0001goW:>[0_l0000Nooooo`;o0000T?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1mooooo`?o00007oooool4o`0000ook_:f1Ol0000@oig3
P`?o00002?nVKWl5o`00013oin_E0ol0000BolSi]`;o00006?nUaZP3o`0001Go[ibl0ol0000EoiBc
_`;o00005_o7Ti8Eo`0000[o`I_60_l0000PokG;_0?o00000_n]W<D3o`0001_oMJ9o0ol0000MoibS
Z`;o00007_ooool2o`00093ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0OOooool2o`00027ooooo1?l0000<onkb]PGo00004_nM`h<2o`0000[oYVio2Ol0000;onO[e@;o
00004oo8nKL2o`0001SoYLJX0_l0000GojnL_0;o00005?nD/kl3o`0001Soai>B0_l00004ok>]bPKo
00004Oo1VlH3o`00023o]L^l2?l0000JogFRO`;o00007_nLXj/2o`0001kooooo0ol0002?ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0_l0000Sooooo`?o0000
2Oo^l[H5o`0001CoWL>30_l0000:ojI^O`;o000000?okkO4o`000?l000002?l00006onO[e@?o0000
4oo8nKL2o`0001OoYLJX0ol0000GojnL_0?o00004_nD/kl3o`0001Soai>B0ol00006ok>]bP?o0000
4oo1VlH3o`00023o]L^l2ol0000EogFRO`?o00007_nLXj/2o`0001oooooo0_l0002?ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07gooooo0_l0000Tooooo`?o00001_o^
l[H5o`0001KoWL>30_l0000:ojI^O`?o00001Oo_]l@:o`000003onO[eOl0003o000001Cob?Vg0_l0
000GojG6Z0;o00006On_W;`2o`0001;oU;>o0_l0000IolNCTP;o00002?nc[LX2o`0001Co`I_60_l0
000QokG;_0;o00000onIYGP8o`0001;oMJ9o0_l0000NoibSZ`?o00007oooool2o`0008oooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0OOooool2o`0002Gooooo0ol00003
onkb]PGo00005onM`h<3o`0000_oYVio0_l00009onnga0Wo00005?o8nKL2o`0001OoYLJX0_l0000I
ojnL_0;o00004OnD/kl3o`0001Woai>B0_l00008ok>]bP?o00004oo1VlH5o`0001go]L^l0ol00007
oiVUN0So00003OmeXWl3o`0001koW:>[0_l0000Pooooo`;o0000Soooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`1looooo`?o00009_ooool8o`0001WoWL>30_l0000<ojI^
O`;o00003_o_]l@3o`0001Gob?Vg0ol0000DojG6Z0Co00006On_W;`3o`00013oU;>o0_l0000IolNC
TP?o00002Onc[LX2o`0001Co`I_62Ol0000GokG;_0?o00002onIYGP9o`0000WoMJ9o0_l0000OoibS
Z`;o00008?ooool2o`0008oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0O?ooool2o`0002Sooooo1Ol0000Koig3P`;o00003?nVKWl3o`0000kokkO40ol0000EolSi]`;o
00004OnUaZP6o`0001_o[ibl0_l0000?oiBc_`?o00006Oo7Ti82o`0000[o/jg:0ol0000Col6KaP;o
000000?o[IjMo`000?l000002Ol0000BokG;_0;o00004?nIYGP8o`0000GoMJ9o0ol0000OoibSZ`;o
00008?ooool2o`0008oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
O?ooool2o`0002Wooooo0_l0000Loig3P`?o00003OnVKWl2o`0000ookkO40ol0000DolSi]`;o0000
3_nUaZP:o`0001[o[ibl0ol0000>oiBc_`;o00006Oo7Ti83o`0000_o/jg:0_l0000Col6KaP;o0000
1_n]WYd;o`0000co]L^l0ol0000DoiVUN0So000000?oMJ9oo`000?l000008?nLXj/2o`00023ooooo
0_l0002?ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07cooooo0_l0
000Yooooo`;o00007?nM`h<2o`0000koYVio0_l0000@onnga0?o00004oo8nKL2o`0000_oYLJX1ol0
0004omWge0;o00006on_W;`2o`0000goU;>o0ol0000IolNCTP;o00003?nc[LX3o`00017o`I_60ol0
000;ojfNW@_o00001onebk`2o`0001SoVJEh2?l0000PoibSZ`;o00008?ooool3o`0008kooooo00?o
0000ooooooooool02?ooool000Oooooo0ol00004ooooo`;o00002_ooool00ol0003oooooooooo`1l
ooooo`;o0000:Oooool3o`0001_oWL>30_l0000>ojI^O`?o00004?o_]l@2o`0001?ob?Vg0_l00009
ojG6Z0Ko00001ooImm@3o`0001[o[ibl0_l0000=oiBc_`;o00006_o7Ti82o`0000go/jg:0_l0000A
ol6KaP;o00004On]WYd;o`000004okG;_?l0003o0000o`0001coVJEh0ol0000QoibSZ`;o00008Ooo
ool2o`0008kooooo00?o0000ooooooooool02?ooool000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0Noooool3o`0002[ooooo
0_l0000Joig3P`?o00003onVKWl2o`00013okkO40ol0000BolSi]`;o00001_nUaZP6o`0000_ofOOD
0ol0000IojnL_0Co00002_nD/kl3o`0001Woai>B0ol0000=ok>]bP?o00004?o1VlH2o`0001Ko[IjM
2Ol0000NoiVUN0?o00007onLXj/3o`00027ooooo0_l0002>ooooo`03o`000?oooooooooo00Sooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo07_ooooo0_l0000[ooooo`;o00006_nM`h<2o`00013oYVio0_l0000Aonnga0Co
00004?o8nKL3o`0000;oYLJX1ol0000>omWge0;o00006?n_W;`8o`0000OoU;>o0_l0000JolNCTP;o
00003onc[LX2o`00013o`I_60_l0000KojfNW@?o00008?nIYGP2o`0001ooW:>[0_l0000Rooooo`;o
0000S_ooool00ol0003oooooooooo`08ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo
00002Oooool5o`0007Wooooo0_l0000[ooooo`?o00006OnM`h<2o`00013oYVio0ol0000@onnga0Oo
00003_o8nKL8o`00017ofOOD0ol0000FojnL_0?o00000_o<aM87o`0000?oU;>o0ol0000IolNCTP?o
00003onc[LX3o`0000oo`I_60_l0000LojfNW@;o00008?nIYGP3o`0001koW:>[0_l0000Rooooo`;o
0000R_ooool5o`0000[ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo07_ooooo0_l0000/ooooo`;o00006OnM`h<2o`00
017oYVio0_l0000?onnga0?o000000?o^]SNo`000?l000001Ol0000;olSi]`Go00005OoImm@2o`00
01Go[ibl0ol00006olc5dPWo00006_o7Ti82o`00017o/jg:0_l0000?ol6KaP;o00007?n]WYd2o`00
027oVJEh0_l0000NoibSZ`;o00008Oooool3o`0008kooooo00?o0000ooooooooool02?ooool000Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool0Noooool3o`0002_ooooo0_l0000Hoig3P`?o00004OnVKWl2o`0000kokkO40ol00005
ok[HgPOo00002?o8nKL2o`0001SofOOD0ol0000CojnL_0?o00002_o<aM86o`0001[oai>B0_l0000A
ok>]bP?o00003Oo1VlH3o`0001co[IjM0_l0000QoiVUN0;o00007_nLXj/2o`00023ooooo0ol0002?
ooooo`03o`000?oooooooooo00Sooooo0007ooooo`?o00001?ooool2o`0000[ooooo00?o0000oooo
ooooool0O?ooool2o`0002_ooooo0ol0000Goig3P`;o00004_nVKWl2o`0000gokkO40ol00009ok[H
gPOo00001?o8nKL3o`0001WofOOD0_l0000AojnL_0Co00003_o<aM82o`0001Woai>B1?l0000Bok>]
bP;o00003Oo1VlH2o`0001co[IjM0ol0000QoiVUN0?o00007OnLXj/2o`0001oooooo0ol0002@oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07cooooo0_l0000/ooooo`;o
00005onM`h<2o`0001;oYVio0ol0000;onnga0?o00003Onjf=h7o`000003olSi]ol0003o000001[o
fOOD0ol0000?ojnL_0Co00003oo<aM83o`0001Ooai>B1_l0000Aok>]bP?o00003?o1VlH2o`0001co
[IjM0_l0000SoiVUN0;o00007OnLXj/2o`0001oooooo0_l0002Aooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo07cooooo0_l0000/ooooo`;o00005_nM`h<3o`0001?oYVio
0_l0000:onnga0?o00004Onjf=h7o`0001_ofOOD0ol0000=ojnL_0?o00004_o<aM83o`0001Coai>B
1?l00002oij][P?o00004Onc[LX3o`0000_o`I_60_l0000LojfNW@;o00008onIYGP3o`0001coW:>[
0_l0000Nooooo`?o0000TOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`1looooo`?o0000:oooool3o`0001;oWL>31Ol0000DojI^O`;o00002Oo_]l@3o`0001Co^]SN1?l0
000MomWge0;o00003?n_W;`3o`0001Coc<GB0ol0000BolNCTPCo00001?nN[Jh4o`00013o/jg:0_l0
000;ol6KaP;o00007?n]WYd2o`0002CoVJEh0_l0000KoibSZ`?o00007Oooool3o`0009;ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0OOooool2o`0002cooooo0_l0000=
oig3P`[o00005?nVKWl3o`0000OokkO40ol0000Dok[HgPKo00007?oImm@3o`0000[o[ibl0ol0000F
olc5dP?o00004?o7Ti83o`0000OoWZf^1?l0000?ok>]bP?o00002_o1VlH2o`0001co[IjM0_l0000T
oiVUN0?o00006_nLXj/2o`0001gooooo0ol0002Cooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo07gooooo0_l0000/ooooo`;o00001onM`h<<o`0000;o]XS40ol0000DojI^
O`;o00001_o_]l@3o`0001Co^]SN0ol00002oj>dT@;o00007OoImm@2o`0000Wo[ibl0ol0000Holc5
dP?o00003Oo7Ti84o`0000[oWZf^1?l0000>ok>]bP;o00002_o1VlH2o`0001co[IjM0_l0000UoiVU
N0;o00006_nLXj/2o`0001gooooo0_l0002Dooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo07gooooo0_l0000/ooooo`?o000000?oWL>3o`000?l000002_l00008okJ8a0?o
00004onVKWl2o`0000GokkO40ol0000Dok[HgP?o00000onS]943o`0001cofOOD0ol00006ojnL_0Co
00006_o<aM83o`0000_oai>B1?l0000<oij][PCo00003Onc[LX3o`0000So`I_60ol0000LojfNW@;o
00009OnIYGP2o`0001[oW:>[0_l0000Looooo`?o0000U?ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`1mooooo`?o0000;?ooool9o`0000oo]XS40_l0000CojI^O`?o0000
0oo_]l@3o`0001Co^]SN0ol00005oj>dT@;o00007OoImm@2o`0000Go[ibl1?l0000Lolc5dP;o0000
2Oo7Ti84o`00013oWZf^0ol0000=ok>]bP;o00002?o1VlH2o`0001go[IjM0_l0000UoiVUN0?o0000
6OnLXj/2o`0001_ooooo0ol0002Eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo07kooooo0_l0000/ooooo`Co00005?nfR<@3o`0001?oYVio0_l00002onnga0?o00005?nj
f=h3o`0000KoXkBA0ol0000LomWge0?o00000on_W;`3o`0001koc<GB0ol00007olNCTPCo00004_nN
[Jh4o`0000_o/jg:0ol00007ol6KaP;o00007?n]WYd3o`0002KoVJEh0_l0000IoibSZ`;o00006_oo
ool3o`0009Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_ooool2
o`0002_ooooo0ol0000GokJ8a0?o00004_nVKWl2o`000004onnga?l0003o0000o`0001Co^]SN0ol0
0008oj>dT@?o00007?oImm@3o`000004ojnL_?l0003o0000o`00023oc<GB0ol00005olNCTP?o0000
5OnN[Jh4o`0000_o/jg:0_l00007ol6KaP;o00007?n]WYd2o`0002OoVJEh1?l0000GoibSZ`;o0000
6Oooool3o`0009Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0O_oo
ool2o`0002_ooooo0_l0000IokJ8a0;o00004_nVKWl5o`0001Co^]SN0ol0000:oj>dT@;o00007OoI
mm@5o`0002;oc<GB0ol00002olNCTPCo00006?nN[Jh3o`0000[o/jg:0ol00006ol6KaP;o00007?n]
WYd2o`0002GoVJEh2?l0000EoibSZ`;o00006Oooool2o`0009Sooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0O_ooool3o`0002Wooooo0ol0000IokJ8a0?o00004_nVKWl3
o`0001Co^]SN0ol0000;oj>dT@?o00007?oImm@4o`0002Coc<GB1ol0000Joij][PCo00002Onc[LX2
o`0000Ko`I_60_l0000JojfNW@Co00009?nIYGP4o`0000;ooooo1Ol0000BoibSZ`?o00006?ooool3
o`0009Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`00
02Wooooo0_l0000KokJ8a0?o00004OnVKWl2o`0001Co^]SN0ol0000=oj>dT@;o00007OoImm@2o`00
02Koc<GB1?l0000Moij][PCo00002?nc[LX3o`0000Co`I_60ol0000FojfNW@So00008_nIYGP4o`00
00Kooooo1?l0000AoibSZ`;o00006?ooool3o`0009Wooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Ooooool2o`0002Sooooo0ol0000LokJ8a0;o00004?nVKWl3o`0001?o
^]SN0ol0000>oj>dT@?o00007?oImm@2o`0002Ooc<GB0_l0000Poij][P?o00002?nc[LX2o`0000Co
`I_60_l0000CojfNW@Wo000000Co_M;Bo`000?l0003o00007onIYGP5o`0000Wooooo1?l0000?oibS
Z`;o00005oooool3o`0009[ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Ooooool2o`0002Oooooo0ol0000MokJ8a0?o00003onVKWl2o`0001?o^]SN0ol0000@oj>dT@;o
00006ooImm@3o`0002Ooc<GB0_l0000Qoij][PCo00001_nc[LX3o`0000;o`I_61_l0000<ojfNW@Wo
00001_nmd]83o`0001goVJEh1?l0000<ooooo`Go00003OnLXj/2o`0001Oooooo0_l0002Kooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo07oooooo0ol0000Vooooo`;o0000
7onfR<@3o`0000koYVio0_l0000Bok[HgP?o00004OnS]943o`0001SofOOD1?l0000Xolc5dP;o0000
8_nN[Jh4o`0000Ko/jg:3ol00003ojfNW@Wo00002onmd]83o`0001[oVJEh1?l0000@ooooo`Go0000
2onLXj/2o`0001Kooooo0ol0002Kooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo083ooooo0_l0000Uooooo`?o00008?nfR<@2o`0000goYVio0ol0000Aok[HgP?o00004onS
]942o`0001GofOOD1ol0000Xolc5dP?o00008onN[Jh4o`0000Co/jg:1Ol00004ojBdY0ko00004?nm
d]83o`0001OoVJEh1Ol0000Cooooo`Go00002OnLXj/2o`0001Gooooo0ol0002Looooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000Uooooo`;o00008OnfR<@3
o`0000coYVio0_l0000Aok[HgP?o00005?nS]943o`00013ofOOD2?l000001?n__L;o0000o`000?l0
000Volc5dPGo00008onN[Jh4o`0000;o/jg:1?l0000;ojBdY0Go00005Onmd]83o`0001CoVJEh1Ol0
000Gooooo`Go00001onLXj/2o`0001Cooooo0ol0002Mooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo083ooooo0_l0000Tooooo`?o00008_nfR<@9o`0000GoYVio0_l0000@
ok[HgP?o00005_nS]943o`0000cofOOD2?l00005ojnm`P?o00009?o<aM83o`000004om6V/?l0003o
0000o`0002CoWZf^1_l0000?ojBdY0;o00005onmd]83o`0001;oVJEh1?l0000Kooooo`Go00001OnL
Xj/2o`0001Cooooo0_l0002Nooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo083ooooo0ol0000Sooooo`;o00008onfR<@@o`0000oo^]SN0ol0000Hoj>dT@;o00002OoImm@7
o`0000[o[kg20ol0000Rolc5dP?o00000ooAY[03o`0002CoWZf^1?l0000@ojBdY0?o00005onmd]83
o`0000ooVJEh1?l0000Oooooo`Co00000onLXj/3o`0001?ooooo0ol0002Nooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo9ol0000RokJ8a0?o00001_nLQX<8o`00
00ko^]SN0ol0000Ioj>dT@?o00001?oImm@8o`0000ko[kg20_l0000Qolc5dP?o00001OoAY[03o`00
02CoWZf^0_l0000BojBdY0;o00006?nmd]82o`0000goVJEh1Ol0000Rooooo`Co000000?oW:>[o`00
0?l000004oooool3o`0009oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0POoooolVo`0002;o]XS40ol0000=oib6P`?o00003?njf=h3o`0001_oXkBA0_l000000ooImmCo
0000o`000006o`00017o[kg20ol0000Oolc5dP?o00001ooAY[03o`0002;oWZf^0ol0000BojBdY0;o
00006?nmd]83o`0000_oVJEh1?l0000Uooooo`Ko00004Oooool4o`000:3ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002;ooooo0ol0000PokJ8a0?o0000
3onLQX<3o`0000[o^]SN0ol0000Loj>dT@Oo00005_n__L83o`0001goc<GB0ol00009om6V/0?o0000
7onN[Jh4o`0001?oY;BT0_l0000IokgBdP?o00002?nIYGP4o`0002Wooooo1?l0000>ooooo`Ko0000
XOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`?o00008ooo
ool3o`0001ko]XS40ol0000Aoib6P`?o00002?njf=h3o`0001koXkBA0ol0000Jojnm`P;o00007?o<
aM83o`0000_odJJ`0ol0000Loij][PGo00005?nT]:@3o`0001Wo_M;B0ol00005oiVUN0Go0000;?oo
ool2o`0000_ooooo1ol0002Sooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo083ooooo0_l0000Uooooo`?o00007?nfR<@3o`0001?oW8J30ol00006ok[HgP?o00007onS]942
o`0001_o[kg20ol0000Jolc5dP?o00003OoAY[04o`0001SoWZf^2?l0000DojBdY0;o00006_nmd]83
o`0000?oVJEh1?l0000^ooooo`?o00001oooool7o`000:Kooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0P?ooool2o`0002Kooooo0ol0000JokJ8a0?o00005OnLQX<3o`00
00Co^]SN0ol0000Ooj>dT@?o00007?n__L83o`0001Soc<GB0ol0000?om6V/0Co00005OnN[Jh5o`00
00?o`YbX0_l0000DojBdY0;o00006onmd]87o`00037ooooo0ol00003ooooo`Oo0000ZOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`1oooooo`?o00009oooool2o`0001Wo
]XS40ol0000Goib6P`?o00000_njf=h3o`00023oXkBA0_l0000Nojnm`P?o00005_o<aM83o`0001;o
dJJ`0ol0000Boij][PGo00001Oo2W:P2o`0001CoY;BT0_l0000LokgBdPGo0000<oooool9o`000:co
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002Sooooo
0ol0000GokJ8a0?o00006OnLQX<6o`00027oXkBA0_l0000Oojnm`P;o00005Oo<aM83o`0001CodJJ`
0ol0000?oij][PGo00001oo2W:P3o`0001?oY;BT0ol0000LokgBdP;o0000=Oooool6o`000:oooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002Wooooo0ol0
000EokJ8a0?o00006onLQX<4o`00027oXkBA0ol0000Oojnm`P?o00004oo<aM83o`0001KodJJ`0ol0
000<oij][PGo00002_o2W:P2o`0001CoY;BT0_l0000LokgBdP;o0000=_ooool2o`000;;ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Ooooool2o`0002[ooooo0ol0000C
okJ8a0?o00007OnLQX<2o`0002;oXkBA0_l0000Qojnm`P?o00004Oo<aM83o`0001SodJJ`0ol00009
oij][PGo00003?o2W:P2o`0001CoY;BT0_l0000LokgBdP;o0000=_ooool2o`000;;ooooo00?o0000
ooooooooool02?ooool001[ooooo0ol0001oooooo`;o0000:oooool2o`0001;o]XS40ol0000Noib6
P`?o00008OnS]942o`0002;o[kg20_l0000@olc5dP?o00006_oAY[03o`0000KoWZf^1Ol0000>ol:L
Z0?o00004onT]:@3o`0001[o_M;B0ol0000fooooo`;o0000/?ooool3o`0000[ooooo000Jooooo`03
o`000?oooooooooo07oooooo0ol0000Zooooo`?o00004?nfR<@3o`00023oW8J30ol0000Ooj>dT@?o
00008_n__L83o`0000koc<GB0ol0000Lom6V/0?o00000onN[Jh5o`00017o`YbX0_l0000DojBdY0;o
00006_nmd]82o`0003Oooooo0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo083ooooo0_l0000[ooooo`?o00003_nfR<@3o`00027oW8J31_l0000Loj>dT@;o0000
9?n__L83o`0000coc<GB0ol0000Nom6V/0So00004oo2W:P2o`0001CoY;BT0_l0000JokgBdP;o0000
=_ooool3o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?oo
ool2o`0002cooooo0ol0000<okJ8a0?o00008OnLQX<:o`0001WoXkBA0_l0000Uojnm`POo00001?o<
aM85o`00023odJJ`1Ol0000Eol:LZ0?o00004onT]:@2o`0001[o_M;B0_l0000fooooo`;o0000/ooo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o0000;Oooool6
o`0000Oo]XS40ol0000Qoib6P`?o00001?na[/D6o`0001KoXkBA0ol0000Uojnm`Poo00008_oAY[02
o`0001So`YbX0_l0000CojBdY0?o00006Onmd]82o`0003Kooooo0_l0002cooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000^ooooo`[o000000Co]XS4o`00
0?l0003o00008_nLQX<2o`0000So/Jk51_l0000Boj>dT@Co00009?n__L83o`0000Coa>Wj1_l00000
1?oOYJ_o0000o`000?l0000Qom6V/0;o00006?o2W:P2o`0001CoY;BT0_l0000HokgBdP?o0000=_oo
ool2o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P?ooool2
o`0002gooooo0ol00002omW2a@Wo00008_nLQX<3o`0000[o/Jk51_l0000?oj>dT@So00008?n__L83
o`0000Soa>Wj0_l00003omnUZ`?o00008?oAY[02o`0001So`YbX0ol0000CojBdY0;o00006?nmd]82
o`0003Kooooo0ol0002cooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
083ooooo0ol0000[ooooo`?o00002?oI`/D3o`0002?oW8J30_l0000>ok6^a@Ko00002onS]943o`00
00;om/:[1_l0000Mojnm`P?o00002Oo4jOX2o`0000CogjF[0ol0000Oom6V/0;o00006Oo2W:P2o`00
01?oY;BT0_l0000HokgBdP?o0000<_ooool6o`000;?ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0POooool2o`0002_ooooo0_l0000:omW2a@?o00008OnLQX<3o`00013o
/Jk51ol00007oj>dT@?o00001_of`Z/6o`0001Wo[kg20ol0000:olCYnP;o00001OoOYJ/3o`0001ko
dJJ`0_l0000Iol:LZ0;o00004onT]:@3o`0001Ko_M;B1_l0000]ooooo`Wo0000/oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o0000:_ooool3o`0000_ofL;5
9Ol0000Dok6^a@Ko00001?nS]943o`0000Wom/:[1_l0000Fojnm`P?o00002oo4jOX2o`0000KogjF[
0_l0000Nom6V/0;o00006Oo2W:P3o`0001;oY;BT6ol000000ooYm<oo0000o`000003o`0002Wooooo
1_l00003ooooo`?o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`21ooooo`;o0000:Oooool3o`0000gofL;58ol0000Hok6^a@Wo00003Oof`Z/6o`0001;o[kg20ol0
000<olCYnP;o00001_oOYJ/3o`0001godJJ`0_l0000Jol:LZ0;o00004OnT]:@Ko`0000CojOC?1?l0
000Uooooo`Ko00001oooool2o`000;;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0POooool2o`0002Wooooo0_l0000>omW2a@?o00007_moQZD2o`0001[o/Jk51_l0000@
ooK2Z`Oo00003_n__L83o`0000goa>Wj0_l00007omnUZ`?o00007?oAY[02o`0001[o`YbX0_l0000@
ojBdY0?o00005onDNhL2o`0000KojOC?1?l0000Pooooo`Oo00002Oooool2o`000;;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002Sooooo0ol0000?omW2
a@;o00007OmoQZD3o`0001go/Jk50_l0000DooK2Z`Ko00002on__L83o`0000koa>Wj0_l00008omnU
Z`?o00006ooAY[02o`0001[o`YbX0ol0000>ojBdY0?o00005onDNhL3o`0000OojOC?1Ol0000Koooo
o`Oo00003?ooool3o`000;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0POooool3o`0002Kooooo0ol0000@omW2a@?o00007?moQZD2o`0001ko/Jk50_l0000GooK2Z`Ko
00001on__L83o`0000ooa>Wj0_l00009omnUZ`?o00006_oAY[02o`0001_o`YbX0_l0000=ojBdY0?o
00006?nDNhL2o`0000[ojOC?1Ol0000Gooooo`Ko00004?ooool2o`000;7ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0P_ooool2o`0002Kooooo0_l0000BomW2a@;o0000
7?moQZD2o`0001ko/Jk50_l0000IooK2Z`Ko00001?n__L83o`00013oa>Wj0_l0000:omnUZ`;o0000
6_oAY[02o`0001_o`YbX0_l0000<ojBdY0?o00006OnDNhL2o`0000cojOC?1Ol0000Booooo`Ko0000
4oooool2o`000;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_oo
ool2o`0002Gooooo0ol0000AomW2a@Co00006omoQZD2o`0001ko/Jk50_l0000LooK2Z`Wo00004Oo4
jOX2o`0000[ogjF[0ol0000Iom6V/23o00002OnT]:@4o`0001WoU7^70ol0000>onWdc`Go00003Ooo
ool7o`0001Gooooo0_l0002aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08;ooooo0_l0000Tooooo`?o00004_oI`/D5o`0001WoOhJU0ol0000Mok6^a@?o00007_of`Z/6
o`0001;oa>Wj0_l0000;omnUZ`?o00006?oAY[0Po`0000SoY;BT1?l0000JoiAkQ`;o00004OoYm<l4
o`0000[ooooo1_l0000Hooooo`?o0000/?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`22ooooo`;o00009?ooool2o`0001;ofL;50ol000001?oLa[;o0000o`000?l0000H
ogn6Y@;o00007Ona[/D4o`00027om/:[0_l0000ColCYnP;o00003?oOYJ/3o`0001KodJJ`0ol0000L
okVgj`?o00001_nT]:@3o`0001coU7^70_l0000ConWdc`Co00001Oooool6o`0001cooooo0_l0002`
ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000Soooo
o`?o00004_oI`/D2o`0000?og<Jb0ol0000Gogn6Y@;o00006ona[/D7o`00023om/:[0_l0000ColCY
nP;o00003OoOYJ/2o`0001KodJJ`0_l0000NokVgj`?o00001?nT]:@3o`0001coU7^70ol0000DonWd
c`co00007_ooool2o`000;3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0P_ooool3o`00027ooooo0ol0000BomW2a@?o00001?oLa[82o`0001OoOhJU0_l0000Jok6^a@Co
00000_naW<L2o`00023om/:[0_l0000ColCYnP;o00003OoOYJ/3o`0001GodJJ`0_l0000OokVgj`?o
00000_nT]:@3o`0001goU7^70_l0000GonWdc`Oo00008Oooool2o`000;3ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0Poooool2o`00023ooooo0ol0000ComW2a@;o0000
1OoLa[83o`0001GoOhJU0ol0000Hok6^a@Co00001?naW<L2o`00023om/:[0_l0000ColCYnP;o0000
3_oOYJ/3o`0001?odJJ`0ol0000PokVgj`Ko00007_nDNhL2o`0001WojOC?0_l0000Tooooo`;o0000
/?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`23ooooo`;o00008?oo
ool2o`0001?ofL;50ol00006omc6/P?o00005?moQZD2o`0001So/Jk51?l00005ok6La`?o00007oof
`Z/2o`0001?oa>Wj0_l0000?omnUZ`?o00004_oAY[02o`0002;o^KO[1?l0000NoiAkQ`?o00006OoY
m<l2o`0002?ooooo0ol0002`ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo08?ooooo0_l0000Oooooo`?o00004ooI`/D2o`0000Sog<Jb0ol0000Cogn6Y@;o00005_na[/D4
o`0000So/Ic70_l0000NooK2Z`?o00004oo4jOX2o`00013ogjF[0ol0000@om6V/0?o00008oni]n/2
o`0001ooU7^70_l0000JonWdc`;o00008oooool2o`000;7ooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0Poooool2o`0001kooooo0ol0000ComW2a@?o00002OoLa[83o`00
01;oOhJU0_l0000Eok6^a@Co00002OnaW<L2o`0001kom/:[0_l0000DolCYnP;o00004OoOYJ/2o`00
013odJJ`0_l0000TokVgj`;o00007onDNhL2o`0001WojOC?0ol0000Sooooo`;o0000/Oooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`23ooooo`;o00007_ooool2o`0001Co
fL;50_l0000;omc6/P;o00004OmoQZD3o`0001?o/Jk51?l0000;ok6La`?o00007Oof`Z/2o`0001Co
a>Wj0_l0000AomnUZ`?o00003ooAY[02o`0002Co^KO[0_l0000NoiAkQ`?o00006OoYm<l2o`0002Co
oooo0_l0002aooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08?ooooo
0ol0000Looooo`?o00004ooI`/D3o`0000_og<Jb0ol0000@ogn6Y@;o00004ona[/D4o`0000go/Ic7
0_l0000MooK2Z`;o00005?o4jOX2o`0001;ogjF[0ol0000=om6V/0?o00009?ni]n/Ro`0001[ojOC?
0_l0000Tooooo`;o0000/Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`24ooooo`;o00006oooool3o`0001CofL;50_l0000=omc6/P?o00003omoQZD2o`0001;o/Jk50ol0
000?ok6La`;o00007?of`Z/3o`0001Coa>Wj0_l0000ComnUZ`?o00003?oAY[02o`0002Go^KO[8_l0
000JonWdc`;o00008oooool3o`000;7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0Q?ooool5o`0001Sooooo0_l0000DomW2a@?o00003_oLa[83o`0000koOhJU0_l0000@
ok6^a@Co00004?naW<L3o`0001Som/:[1_l0000DolCYnP;o00005?oOYJ/9o`0000GodJJ`0_l0000T
okVgj`?o00007_oWg9d2o`0001[ojOC?0_l0000Sooooo`;o0000/_ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`23ooooo`_o00004_ooool3o`0001CofL;50_l0000@omc6
/P;o00003OmoQZD3o`0000oo/Jk51?l0000Bok6La`;o00005_of`Z/9o`0001?oa>Wj0_l0000ComnU
Za7o00008oni]n/3o`0001ooimbM0_l0000JonWdc`;o00008oooool2o`000;;ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool3o`0000?ooooo2ol0000<ooooo`?o
00005?oI`/D3o`00013og<Jb0ol0000:ogn6Y@Go00003Ona[/D4o`0001Co/Ic70_l0000CooK2Z`Ko
00001?n:YJH3o`0001;oa>Wj0_l0000BomnUZ`?o00001onRh//7o`0002?o^KO[1Ol0000NonOLW@;o
00006OoYm<l3o`0002?ooooo0_l0002booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo08;ooooo0_l00009ooooo`_o00001oooool2o`0001CofL;50ol0000Bomc6/P?o0000
1OmoQZD:o`0000_o/Jk51?l0000Eok6La`?o00004?of`Z/6o`0000OoRZFV0_l0000BolCYnP;o0000
4OoOYJ/3o`0000goX^;;0ol0000PokVgj`Co000000CoMiIao`000?l0003o00007OoWg9d2o`0001Wo
jOC?0_l0000Tooooo`;o0000/_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`22ooooo`;o00003_ooool;o`000004ooooool0003o0000o`0001CofL;50_l0000Domc6/P?o
000000?oOhJUo`000?l000001_l00003ojcFfP?o00002?na[/D4o`0001So/Ic70_l0000=ooK2Z`Ko
00002_n:YJH3o`00017oa>Wj0_l0000?omnUZ`Co00003onRh//3o`0001ko^KO[1?l00003ogNFL@?o
00007?oWg9d2o`0001WojOC?0_l0000Sooooo`?o0000/_ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`22ooooo`;o00004oooool9o`0001CofL;50ol0000Eomc6/POo0000
2?n/e]X4o`0000Go/Jk51?l0000Iok6La`;o00002oof`Z/6o`0000goRZFV0ol0000@olCYnP;o0000
3_oOYJ/4o`00017oX^;;0ol0000KokVgj`Co00001_mgUW43o`0001_oimbM0_l0000IonWdc`;o0000
8oooool2o`000;?ooooo00?o0000ooooooooool02?ooool001[ooooo0ol00022ooooo`;o00006?oo
ool3o`0001GofL;50_l0000Gomc6/P?o00003?n/e]X4o`0000;o/Jk51?l0000Kok6La`?o00002?of
`Z/5o`00017oRZFV0_l0000@olCYnP;o00003OoOYJ/3o`0001CoX^;;0_l0000JokVgj`Co00002?mg
UW43o`0001[oimbM0_l0000IonWdc`;o00008oooool2o`000;7ooooo0ol0000:ooooo`006_ooool0
0ol0003oooooooooo`22ooooo`;o00006Oooool3o`0001?ofL;50ol0000Fomc6/P?o00003on/e]X7
o`0001go/Ic70_l00005ooK2Z`Ko00004on:YJH3o`0000ooa>Wj0_l0000;omnUZ`Co00005OnRh//3
o`0001So^KO[0ol0000;ogNFL@?o00006OoWg9d2o`0001WojOC?0_l0000Sooooo`;o0000/oooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`;o00006_ooool3o`00
01;ofL;50_l0000Fomc6/P?o00004On/e]X4o`0001oo/Ic70_l00003ooK2Z`Ko00005_n:YJH3o`00
00koa>Wj0_l0000:omnUZ`Co00005onRh//8o`00013o^KO[1?l0000=ogNFL@?o00006?oWg9d2o`00
01SojOC?0ol0000Sooooo`;o0000/oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`22ooooo`;o00006oooool3o`00013ofL;50ol0000Eomc6/P?o00004on/e]X2o`00023o
/Ic72?l0000JohZUYP;o00003_o4jOX2o`0000WogjF[0ol0000Joj;Rba;o00001?ni]n/4o`0000oo
MiIa0ol0000GonOLW@;o00006?oYm<l2o`0002?ooooo0ol0002cooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo08;ooooo0_l0000Looooo`?o00003ooI`/D2o`0001Kog<Jb
0_l0000DojcFfP?o00008?naW<L5o`0001coRZFV0ol0000=olCYnP;o00002?oOYJ/3o`0001_oX^;;
0_l00004olOZ`a;o00004_mgUW43o`0001KoimbM0_l0000GonWdc`Co00008_ooool2o`000;Cooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool3o`0001gooooo0ol0
000=omW2a@?o00005OoLa[83o`0001Go[=KJ0_l0000Pok6La`;o00008?n:YJH3o`0000coa>Wj0_l0
0006omnUZ`Co00006onRh//3o`0000ooan[31_l0000DogNFL@?o00005OoWg9d2o`0001KojOC?1ol0
000Pooooo`;o0000]?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21
ooooo`;o00007oooool3o`0000cofL;50_l0000Eomc6/P?o00005_n/e]X3o`0001oo/Ic70_l0000Q
ohZUYP;o00003?o4jOX2o`0000GogjF[1?l0000Loj;Rb`;o00005?o7j/<2o`0001GoMiIa0ol0000D
onOLW@;o00005?oYm<l4o`0000;ooooo1?l0000Oooooo`;o0000]?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o00008?ooool3o`0000[ofL;50ol0000Domc6
/P?o00006?n/e]X3o`0001ko/Ic70_l0000QohZUYP?o00002oo4jOX2o`0000CogjF[0ol0000Noj;R
b`;o00005?o7j/<2o`0001KoMiIa6?l0000ConWdc`Co00001Oooool4o`0001gooooo0_l0002doooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000Qooooo`?o
00002OoI`/D2o`0001Gog<Jb0_l0000JojcFfP;o00007OnaW<L3o`0002;oRZFV1?l00009olCYnP;o
00000_oOYJ/4o`0001koX^;;0ol0000DolOZ``?o00005_mgUW4Go`00017ojOC?1?l00008ooooo`Go
00006_ooool3o`000;Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
POooool2o`0002;ooooo0ol00007omW2a@?o00005?oLa[83o`0001[o[=KJ0ol0000Iok6La`Ko0000
8?n:YJH8o`0000Ooa>Wj0_l000000ooOYJ_o0000o`000002o`0001ooX^;;0_l0000FolOZ``;o0000
5_mgUW42o`0001?o`Xjc0ol0000?onWdc`Co00002oooool4o`0001Wooooo0_l0002eooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000Sooooo`?o00001_oI
`/D2o`0001Cog<Jb0ol0000LojcFfP;o00005onaW<L9o`0001goRZFV1Ol00002olNde0Ko00001?o4
jOX5o`00027oX^;;0_l0000FolOZ``;o00005OmgUW43o`0001Co`Xjc0ol0000<onWdc`Co00003ooo
ool4o`0001Oooooo0_l0002eooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo087ooooo0_l0000Tooooo`_o00004_oLa[83o`0001go[=KJ0ol0000Dok6La`Go00001?oYclH3
o`0001[oRZFV1Ol00006olNde0Ko00000_o4jOX4o`0002;oX^;;0_l0000FolOZ``;o00005OmgUW42
o`0001Ko`Xjc0ol0000:onWdc`Co00004Oooool5o`0001Gooooo0_l0002eooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000Uooooo`oo00003OoLa[82o`00
01oo[=KJ0_l0000Aok6La`Ko00001ooYclH3o`0001OoRZFV1Ol0000;olNde0So00008_nRh//3o`00
01Koan[30_l0000EogNFL@;o00005oo2S[<5o`0000GojOC?1?l0000Eooooo`Go00004oooool2o`00
0;Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002Co
oooo0ol00007oh^`P0_o00001ooLa[83o`0001oo[=KJ0ol0000>ok6La`Ko00002_oYclH2o`0001Go
RZFV1Ol0000?olNde0Go00008onRh//2o`0001Ooan[30_l0000EogNFL@;o00006?o2S[<7o`000003
onWdcol0003o000000;o00006?ooool4o`00017ooooo0ol0002eooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo087ooooo0_l0000Tooooo`;o00003On;/80;o`000004omc6
/_l0003o0000o`00027o[=KJ0_l0000;ok6La`Ko00003OoYclH3o`0001;oRZFV1Ol0000ColNde0;o
00009?nRh//2o`0001Ooan[30ol0000DogNFL@;o00005oo2S[<3o`000003olBgSol0003o000000Go
00007?ooool4o`0000oooooo0_l0002fooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo087ooooo0_l0000Tooooo`;o00004_n;/809o`0002;o[=KJ0ol00008ok6La`Ko0000
4?oYclH3o`00013oRZFV1?l0000EolNde0;o00008onRh//3o`0001Soan[30_l0000CogNFL@?o0000
5_o2S[<3o`0000Goa;N?0ol0000Nooooo`Go00003Oooool2o`000;Kooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0POooool2o`0002?ooooo0ol0000Goh^`P0?o00009?n/
e]X3o`0000Go/Ic71Ol0000DonW?aP;o00003_n:YJH4o`0001OoakCD0ol0000Roj;Rb`;o00006Oo7
j/<2o`0001?oMiIa0_l0000Fol:>/`?o00001oo4]hl3o`0001oooooo1?l0000;ooooo`?o0000]_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`21ooooo`;o00008oooool2
o`0001WoRk200ol0000TojcFfP;o00000_naW<L6o`0001KojLo60ol0000;ohZUYPGo00006Oo7]=@2
o`0002;oX^;;0_l0000IolOZ``;o00004omgUW42o`0001Ko`Xjc0_l00009olBgS`;o00008Oooool4
o`0000Sooooo0ol0002gooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
087ooooo0_l0000Sooooo`;o00006_n;/802o`0002Co[=KJ2?l0000IonW?aP?o00002?n:YJH5o`00
01_oakCD0_l0000Roj;Rb`;o00006Oo7j/<2o`0001?oMiIa0_l0000Eol:>/`?o00002Oo4]hl3o`00
027ooooo1Ol00005ooooo`?o0000^?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`21ooooo`;o00008_ooool3o`0001[oRk200ol0000TojcFfPGo00007?oYclH3o`0000Go
RZFV1Ol0000MolNde0?o00008?nRh//3o`0001Woan[30ol0000BogNFL@;o00005?o2S[<3o`0000_o
a;N?0_l0000Sooooo`Co00000oooool3o`000;Wooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0POooool2o`0002;ooooo0_l0000Loh^`P0;o00008on/e]X3o`000004omfo
a_l0003o0000o`0001cojLo60_l00003ohZUYPGo00008?o7]=@2o`00023oX^;;0_l0000KolOZ``;o
00004OmgUW43o`0001?o`Xjc0ol0000<olBgS`?o00009?ooool7o`000;[ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0P?ooool3o`0002;ooooo0_l0000Loh^`P0;o0000
8_n/e]X3o`0000?ogKo60ol0000KonW?aPSo00008_o7]=@2o`00023oX^;;0_l0000KolOZ``;o0000
4OmgUW42o`0001Co`Xjc0_l0000>olBgS`;o00009Oooool5o`000;_ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0P?ooool2o`0002;ooooo0ol0000Loh^`P0?o00008On/
e]X2o`0000GogKo60ol0000KonW?aPGo00009?o7]=@2o`0001ooX^;;0ol0000KolOZ``;o00004Omg
UW42o`0001?o`Xjc0ol0000>olBgS`?o00009_ooool2o`000;cooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0P?ooool2o`0002;ooooo0_l0000Noh^`P0;o00008?n/e]X3
o`0000KogKo60ol0000KonW?aP;o00009_o7]=@3o`0001[oX^;;1_l0000LolOZ``;o00004OmgUW42
o`0001;o`Xjc0ol0000@olBgS`;o00009Oooool3o`000;cooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0P?ooool2o`0002;ooooo0_l0000Noh^`P0?o00007_n/e]X3o`00
00SogKo60ol0000JonW?aP;o00009oo7]=@2o`0001;oX^;;3_l0000LolOZ``;o00004OmgUW42o`00
017o`Xjc0ol0000AolBgS`;o00009Oooool2o`000;gooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0P?ooool2o`00027ooooo0ol0000Ooh^`P0;o00007_n/e]X2o`0000[o
gKo60ol0000IonW?aP;o00009oo7]=@2o`0000_oX^;;4?l00003onc7j0?o00006oo7j/<3o`0000oo
MiIa0ol0000@ol:>/`?o00004_o4]hl3o`0002?ooooo0ol0002mooooo`03o`000?oooooooooo00So
oooo000Jooooo`03o`000?oooooooooo083ooooo0_l0000Qooooo`;o00008?n;/803o`0001co[=KJ
0ol0000;omfoaP?o00006?oYclH2o`0002OoakCD0ol00002oj;Rba3o00003?o/anP3o`0001_oan[3
0_l0000?ogNFL@;o00004Oo2S[<2o`0001Coa;N?0_l0000Sooooo`;o0000__ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o00008Oooool2o`00027oRk200_l0
000LojcFfP;o00003OoM_lH3o`0001OojLo60ol0000WolNde0go00005?o/anP3o`0001[oan[30_l0
000?ogNFL@;o00004?o2S[<3o`0001Coa;N?0ol0000Rooooo`;o0000__ooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o00008?ooool3o`00027oRk200_l0000K
ojcFfP?o00003_oM_lH3o`0001OojLo60_l0000WolNde0Go00007Oo/anP3o`0001Woan[30_l0000?
ogNFL@;o00003oo2S[<3o`0001Koa;N?0_l0000Qooooo`?o0000__ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`20ooooo`;o00008?ooool2o`0002;oRk201ol0000EojcF
fP?o00004?oM_lH3o`0001KojLo60_l0000VolNde0?o00008Oo/anP2o`0001Woan[30_l0000?ogNF
L@;o00003_o2S[<3o`0001Ooa;N?0ol0000Pooooo`;o0000_oooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`20ooooo`?o00007oooool2o`0002?oRk203ol0000<ojcFfP;o
00004_oM_lH3o`0001GojLo60_l0000VolNde0;o00008_o/anP3o`0001Soan[30_l0000>ogNFL@?o
00003_o2S[<2o`0001Woa;N?0_l0000Oooooo`?o0000_oooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`21ooooo`?o00007Oooool3o`0002;oRk200ol00003og2K[a;o0000
0on/e]X3o`0001?ogKo60ol0000DonW?aP;o00009_o7]=@2o`0002?ok<OX0ol0000GolOZ``?o0000
3OmgUW42o`0000ko`Xjc0ol0000IolBgS`Oo00006_ooool2o`000<3ooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0P_ooool3o`0001cooooo0_l0000Soh^`P0;o00003Om`
Vjl>o`0001GogKo60ol0000ConW?aP;o00009Oo7]=@3o`0002Cok<OX0ol0000GolOZ``;o00001_mg
UW4:o`0000co`Xjc0ol0000KolBgS`go00004_ooool3o`000<3ooooo00?o0000ooooooooool02?oo
ool001[ooooo0ol00023ooooo`?o00006oooool2o`0002;oRk200ol0000Eog2K[`Go00005ooM_lH3
o`0001;ojLo60_l0000UolNde0;o00009_o/anP7o`0001;oan[35?l00009ol:>/`?o00006oo4]hl3
o`0000?ooooo4?l0000:ooooo`;o0000_oooool3o`0000[ooooo000Jooooo`03o`000?oooooooooo
08Cooooo0_l0000Iooooo`Co00008_n;/802o`0001WoL9^_1?l0000FomfoaP?o00004OoYclH2o`00
02GoakCD0_l0000Wonc7j0go00002_o7j/<:o`0000SoUHC61_l00006ol:>/`;o00006oo4]hl3o`00
00_ooooo4?l00003ooooo`;o0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`24ooooo`?o00005oooool8o`0001koRk200ol0000Jog2K[`Ko00005?oM_lH3o`00013o
jLo60_l0000TolNde0?o00009_o/anP3o`0000?o_>Fm3ol00002olOZ``?o00004_nEQ<H6o`0000?o
`Xjc0ol0000KolBgS`;o00005?ooool=o`000<7ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0QOooool3o`0001Cooooo1?l00002ohf/U@Ko00007?n;/802o`0001_oL9^_
2Ol0000BomfoaP?o00003ooYclH3o`0001koakCD1ol0000Wonc7j0;o00002onliKd<o`0001KoUHC6
2?l0000KolBgS`?o00006oooool5o`000<;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0Q_ooool3o`0001;ooooo1?l00006ohf/U@Ko00006?n;/803o`0001_oL9^_0_l0
0003on30i`Oo00004?oM_lH3o`0000oojLo60_l0000EolNde13o00009_o/anP3o`0001;o_>Fm1?l0
000IoiF4aPGo00006oo4]hl3o`0001oooooo0_l00032ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo08Oooooo0ol0000?ooooo`Co00002_n=[9D6o`0001GoRk200ol0000L
og2K[`;o00001_oP`>L7o`0000kogKo60ol0000>onW?aP;o00003?o7]=@Co`0000Co]:c30ol0000U
onc7j0;o00005OnliKd2o`0001_oUHC60_l0000LolBgS`;o00008?ooool2o`000<;ooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0R?ooool3o`0000gooooo1?l0000>ohf/
U@Ko00004_n;/802o`0001goL9^_0_l00009on30i`Oo00003?oM_lH3o`0000gojLo60_l00003olNd
e1?o00003_nd[<<2o`0002Cok<OX0ol0000EokcU_@;o00006onEQ<H3o`0001[oa;N?0ol0000Poooo
o`;o0000`_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`29ooooo`;o
00002oooool4o`0001;oSJbE1_l0000?oh^`P0?o00007Om`Vjl2o`0000coh<3W1ol0000:omfoaP?o
00002_oYclHAo`0001Oo]:c30_l0000Sonc7j0?o00005_nliKd2o`0001coUHC60ol0000HolBgS`?o
00008Oooool3o`000<7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
ROooool3o`0000Wooooo1?l0000Fohf/U@Ko00003?n;/802o`0001koL9^_0_l0000?on30i`Oo0000
2?oM_lH3o`0000GojLo63?l0000PokB/``?o00008_o/anP2o`0001Oo_>Fm0_l0000MoiF4aP;o0000
6?o4]hl2o`0002?ooooo0_l00031ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oo
oooooooo08[ooooo0ol00005ooooo`Go00006_n=[9D6o`0000WoRk200ol0000Nog2K[`;o00004_oP
`>L7o`0000KogKo60ol000000ooYclKo0000o`000006o`000003om2JXol0003o000002Go]:c30_l0
000Qonc7j0?o00005onliKd2o`0001goUHC60ol0000FolBgS`?o00008oooool2o`000<7ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Roooool3o`000003ooooool0003o
000000Ko00007On=[9D6o`0000KoRk200_l0000Oog2K[`;o00005OoP`>L7o`0000CogKo61ol00005
om2JX`?o00008ond[<<4o`00023ok<OX0_l0000HokcU_@;o00007_nEQ<H3o`0001Goa;N?0_l0000T
ooooo`;o0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<oooo
o`Oo00000_ooool3o`0001koSJbE1_l00003oh^`P0?o00007om`Vjl2o`0001Soh<3W3?l00009om2J
X`;o00008_nd[<<6o`0001kok<OX0ol0000HokcU_@;o00007onEQ<H2o`0001Coa;N?0ol0000Toooo
o`;o0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2=ooooo`?o
00001_ooool3o`00023oSJbE2?l0000Pog2K[`;o00006ooP`>L6o`0000cod9ZS0_l0000QokB/``?o
00000_nZ_ll2o`0001kok<OX0_l0000IokcU_@;o00007onEQ<H3o`0001;oa;N?0ol0000Tooooo`?o
0000`Oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<ooooo`?o0000
2?ooool3o`00027oSJbE1_l0000Pog2K[`;o00007_oP`>L2o`0000god9ZS0_l0000PokB/``?o0000
0onZ_ll3o`0001cok<OX0ol0000IokcU_@;o00008?nEQ<H5o`0000ooa;N?0_l0000Uooooo`;o0000
`_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2<ooooo`;o00002_oo
ool3o`0002?oSJbE0_l0000Qog2K[`;o00007OoP`>L3o`0000god9ZS0_l0000OokB/``?o00001OnZ
_ll2o`0001cok<OX0_l0000JokcU_@;o00008OnEQ<H7o`0000_oa;N?0ol0000Tooooo`?o0000`_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`?o00002oooool3
o`0002;oSJbE0_l0000Qog2K[`;o00007?oP`>L3o`0000kod9ZS0ol0000MokB/``?o00001_nZ_ll3
o`0001[ok<OX0ol0000JokcU_@;o00008?nEQ<H3o`000003oi^HW?l0003o000000Go00001oo4]hl3
o`0002Gooooo0_l00033ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08_ooooo0_l0000=ooooo`?o00008On=[9D2o`00027oL9^_0_l0000Kon30i`?o00004?o@VZ<2o`00
01co]:c30ol00008ojZoc`Co00006?o/anP2o`0001_o_>Fm0_l0000OoiF4aP?o00001OnKV9`7o`00
00Coa;N?0_l0000Uooooo`?o0000`oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2:ooooo`?o00003_ooool3o`00023oSJbE0_l0000Qog2K[`;o00006_oP`>L3o`00017o
d9ZS0_l0000KokB/``?o00002_nZ_ll6o`0001Cok<OX0ol0000KokcU_@;o00007_nEQ<H3o`0000Wo
ViRL2_l0000Uooooo`;o0000a?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2:ooooo`;o00004?ooool3o`0001ooSJbE0ol0000Pog2K[`;o00006OoP`>L3o`0001;od9ZS
0_l0000JokB/``?o00002_nZ_ll:o`00017ok<OX0_l0000LokcU_@;o00007OnEQ<H3o`0000goViRL
1_l0000Uooooo`?o0000a?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`29ooooo`?o00004Oooool3o`0001ooSJbE0_l0000Pog2K[`;o00006?oP`>L3o`0001?od9ZS0ol0
000HokB/``?o00002onZ_ll2o`0000CoZJn^1ol0000=onc7j0?o00007?nliKd2o`0001coUHC60ol0
000Aoi^HW0;o00009_ooool2o`000<Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0ROooool2o`0001?ooooo0ol0000Nohf/U@;o00008?m`Vjl2o`0001Soh<3W0_l0000E
om2JX`;o00005ond[<<3o`0000coZ[o?0_l00007ojV_[PKo00002_o/anP3o`0001go_>Fm0_l0000L
oiF4aP;o00004_nKV9`3o`0002Cooooo0ol00035ooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo08Wooooo0_l0000Dooooo`?o00007On=[9D2o`00023oL9^_0_l0000Gon30
i`?o00005Oo@VZ<2o`0001Ko]:c30ol0000<ojZoc`?o00002_nY[jh6o`0000Ook<OX0_l0000NokcU
_@;o00006onEQ<H3o`0001?oViRL0_l0000Tooooo`;o0000a_ooool00ol0003oooooooooo`08oooo
o`006_ooool00ol0003oooooooooo`28ooooo`?o00005Oooool3o`0001coSJbE1?l0000Nog2K[`Ko
00004_oP`>L3o`0001Kod9ZS0_l0000EokB/``?o00003OnZ_ll2o`0000goZJn^1ol00003onc7j0?o
00007_nliKd2o`0001[oUHC60ol0000Doi^HW0?o00008oooool2o`000<Kooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0R?ooool2o`0001Oooooo0ol0000Kohf/U@Oo0000
6om`Vjl=o`0000[oh<3W0ol0000Gom2JX`?o00004ond[<<3o`0000koZ[o?0_l0000@ojV_[PWo0000
7onliKd2o`0001WoUHC60ol0000Foi^HW0;o00008_ooool3o`000<Kooooo00?o0000ooooooooool0
2?ooool001[ooooo00?o0000ooooooooool0Qoooool3o`0001Sooooo0ol0000Iohf/U@?o000000?o
XiO<o`000?l000001Ol0000Gog2K[`?o00000on0P:P?o`0000;oh<3W0ol0000Iom2JX`;o00004_nd
[<<3o`0000koZ[o?0ol0000CojV_[PKo00007onliKd2o`0001SoUHC60ol0000Goi^HW0Ko00007_oo
ool2o`000<Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Qoooool2
o`0001[ooooo0ol0000Gohf/U@?o00001OnSUl`8o`0001;oL9^_0ol0000;oh20Z0co00006_o@VZ<2
o`00017o]:c30ol0000?ojZoc`;o00005onY[jh2o`00023o_>Fm0_l0000GoiF4aP?o00006OnKV9`<
o`0001Kooooo0ol00037ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
08Kooooo0ol0000Kooooo`?o00005On=[9D3o`0000WoXiO<2?l0000>og2K[`?o00004on0P:P4o`00
01_od9ZS0_l0000@okB/``?o00004?nZ_ll2o`0001OoZJn^0ol0000OokcU_@;o00005_nEQ<H3o`00
01[oViRL0_l00002ooooo`ko00004?ooool2o`000<Sooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0Q_ooool2o`0001gooooo0ol0000Dohf/U@;o00003_nSUl`8o`0000Wo
L9^_0ol0000Foh20Z0;o00006oo@VZ<2o`0000oo]:c30ol0000@ojZoc`?o00006?nY[jh2o`0001go
_>Fm1Ol0000EoiF4aP;o00006_nKV9`3o`0000Wooooo3Ol00009ooooo`?o0000b?ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`26ooooo`?o00007Oooool3o`0001;oSJbE
0ol0000Aoj>Gc0So00001Om`Vjl3o`0001OoP82X0ol0000Jom2JX`?o00003Ond[<<3o`00017oZ[o?
0_l0000IojV_[P?o00006OnliKd9o`0001?oUHC60ol0000Joi^HW0;o00004?ooool>o`0000;ooooo
0_l00039ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08Oooooo0_l0
000Nooooo`?o00004?n=[9D3o`0001KoXiO<1ol000001?m`Vjoo0000o`000?l0000Ioh20Z0;o0000
6oo@VZ<2o`0000co]:c30ol0000BojZoc`;o00006_nY[jh2o`0001Go_>Fm2?l00003oiYoS`?o0000
4OnEQ<H3o`0001_oViRL0_l0000Fooooo`co0000bOooool00ol0003oooooooooo`08ooooo`006_oo
ool00ol0003oooooooooo`27ooooo`;o00007oooool3o`0000koSJbE0ol0000Joj>Gc0Oo00006_n0
P:P2o`0001_od9ZS0_l0000;okB/``?o00004_nZ_ll3o`0001[oZJn^0ol0000AokcU_@So00001onJ
Ohl3o`0000ooUHC60ol0000Loi^HW0;o00007Oooool4o`000<[ooooo00?o0000ooooooooool02?oo
ool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00002_ooool00ol0003ooooooooo
o`27ooooo`?o00007oooool3o`0000goSJbE0_l0000Noj>Gc0?o00006on0P:P3o`0001[od9ZS0_l0
000:okB/``?o00004onZ_ll2o`0001coZJn^0ol0000<okcU_@So00003?nJOhl3o`0000goUHC60ol0
000Loi^HW0?o00007oooool2o`000<[ooooo00?o0000ooooooooool02?ooool000;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool0R?ooool2o`00023ooooo0ol0000;ohf/U@?o00007onSUl`2o`0001coP82X
0_l0000Jom2JX`?o00002?nd[<<3o`0001CoZ[o?0_l0000MojV_[P;o00002OnliKd8o`00013oVWn?
4Ol0000Moi^HW0;o00008?ooool2o`000<[ooooo00?o0000ooooooooool02?ooool000;ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool0R?ooool3o`00023ooooo0ol00009ohf/U@?o00008?nSUl`2o`0001co
P82X0_l0000Kom2JX`;o00001ond[<<3o`0001CoZ[o?0ol0000MojV_[P?o00001?nliKd8o`0001Go
VWn?3ol0000Noi^HW0;o00008?ooool3o`000<Wooooo00?o0000ooooooooool02?ooool000;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Wooooo1Ol00027ooooo`;o00008Oooool3o`0000KoSJbE1?l0000Qoj>Gc0?o00006on0P:P3o`00
01[od9ZS0_l00006okB/``?o00005OnZ_ll2o`0001ooZJn^0_l000000onliKgo0000o`000006o`00
01SoVWn?0_l0000;omCY/`?o00007OnKV9`2o`00027ooooo0_l00035ooooo`Go00002_ooool000;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool0ROooool2o`0002;ooooo0ol00004ohf/U@Oo00008?nSUl`2
o`0001coP82X0_l0000Jom2JX`;o00001Ond[<<3o`0001KoZ[o?0_l0000OojV_[POo00007?nJOhl2
o`0000coe>Vc0ol0000Koi^HW0?o00008Oooool2o`000<Wooooo00?o0000ooooooooool02?ooool0
0003ooooool0003o000000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo08Wooooo0ol0000Rooooo`?o00000_n=[9D3o`0000;oQKna1Ol0
000Noj>Gc0;o00007?n0P:P2o`0001[od9ZS0_l00004okB/``?o00005_nZ_ll3o`00023oZJn^0ol0
000NoiYoS`?o00003OoDjK<3o`0001[oViRL0_l0000Rooooo`;o0000bOooool00ol0003ooooooooo
o`08ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000[ooooo00?o0000
ooooooooool0R_ooool2o`0002?ooooo1_l00005ohFo/@Go00007?nSUl`2o`0001coP82X0ol0000I
om2JX`?o00000_nd[<<3o`0001OoZ[o?0_l0000QojV_[P;o00007onJOhl2o`0000ooe>Vc0ol0000I
oi^HW0;o00008_ooool2o`000<Wooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0R_ooool3o`0002?ooooo1?l00008ohFo/@Go00006_nSUl`2o`0001goP82X0_l0000Jom2J
X`Oo00005onZ_ll2o`00023oZJn^0ol0000OoiYoS`;o00004?oDjK<2o`0001WoViRL0_l0000Roooo
o`?o0000b?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2;ooooo`;o
00009?ooool2o`0000_oQKna1Ol0000Hoj>Gc0;o00007On0P:P2o`0001[od9ZS2_l0000CojZoc`?o
00008?nY[jh2o`00023oVWn?0_l0000@omCY/`?o00005onKV9`3o`0002?ooooo0_l00038ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08_ooooo0ol0000Rooooo`?o0000
3On5_k45o`0001KoXiO<0_l0000Moh20Z0?o00006?o@VZ<3o`0000CoZhR62?l0000?ojZoc`;o0000
8OnY[jh2o`00023oVWn?0_l0000AomCY/`?o00005_nKV9`2o`0002Cooooo0_l00038ooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0_l0000Qooooo`Co00003on5
_k45o`0001CoXiO<0ol0000Moh20Z0;o00005oo@VZ<3o`0000SoZhR62?l0000<ojZoc`;o00008OnY
[jh2o`00023oVWn?0_l0000BomCY/`?o00005OnKV9`2o`0002Cooooo0_l00038ooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0_l0000Pooooo`Ko00004?n5_k44
o`0001CoXiO<0_l0000Moh20Z0;o00005_o@VZ<3o`0000goZhR61ol00008ojZoc`?o00008OnY[jh2
o`00023oVWn?0_l0000ComCY/`;o00005OnKV9`2o`0002?ooooo0ol00038ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo08cooooo0ol0000Mooooo`Co00000_ooool3o`00
017oQKna1?l0000Boj>Gc0;o00007On0P:P3o`0001Cod9ZS0ol0000Aoj^8QPSo00001?nZ_ll2o`00
027oZJn^0ol0000OoiYoS`?o00004ooDjK<3o`0001?oViRL0ol0000Rooooo`?o0000bOooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2=ooooo`;o00007?ooool4o`0000Co
oooo0ol0000AohFo/@Go00003onSUl`4o`0001goP82X0_l0000Com2JX`?o00005On[R8H8o`000003
ojZocol0003o0000027oZJn^0_l0000PoiYoS`;o00005OoDjK<3o`0001;oViRL0_l0000Sooooo`;o
0000b_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2=ooooo`?o0000
6_ooool3o`0000Oooooo0_l0000CohFo/@Go00003?nSUl`7o`0001_oP82X0_l0000Bom2JX`?o0000
6_n[R8H7o`00027oZJn^0ol0000OoiYoS`;o00005_oDjK<3o`00017oViRL0_l0000Rooooo`?o0000
b_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2>ooooo`;o00006?oo
ool4o`0000Sooooo0ol0000DohFo/@Go00002OnSUl`3o`0000;o[jnZ1?l0000Joh20Z0?o00004?o@
VZ<3o`0001koZhR60ol0000QojV_[PGo00007_nJOhl2o`0001Ooe>Vc0ol0000@oi^HW0;o00008Ooo
ool3o`000<_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0S_ooool2
o`0001Oooooo1?l0000:ooooo`?o00005On5_k45o`0000KoXiO<0ol00005ojn_ZPCo00006On0P:P2
o`0000kod9ZS1?l0000Poj^8QP?o00007onY[jh3o`000003oiZBO_l0003o000000;o00007?nJOhl2
o`0001Soe>Vc0_l0000?oi^HW0?o00008Oooool2o`000<cooooo00?o0000ooooooooool02?ooool0
01[ooooo00?o0000ooooooooool0S_ooool4o`0001Cooooo0ol0000=ooooo`?o00005_n5_k45o`00
00?oXiO<0ol00007ojn_ZPGo00005on0P:P2o`0000cod9ZS1ol0000Poj^8QP?o00007OnY[jh3o`00
00?oVY9n1?l0000KoiYoS`;o00006?oDjK<3o`0000_oViRL1Ol0000Qooooo`?o0000c?ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2?ooooo`Co00004_ooool3o`0000oo
oooo0_l0000HohFo/@So00002_n_[jX5o`0001GoP82X0ol00009om2JX`Go00000_n9Xl<3o`00023o
ZhR68Ol00006oiZBOPCo00006?nJOhl3o`0001Woe>Vc0ol00003oi^HW0go00007oooool3o`000<go
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0TOooool4o`0000kooooo
1?l0000@ooooo`?o00006On5_k45o`0000go[jnZ1Ol0000Doh20Z0;o00001oo@VZ<5o`0000GoRJ?3
0ol0000Poj^8QQoo00002?nJTWh4o`0001OoVWn?0_l0000KomCY/`go00000oooool3o`0001kooooo
0_l0003>ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09;ooooo1Ol0
000;ooooo`Co00004_ooool3o`0001[oQKna0_l0000@ojn_ZPCo00004on0P:P2o`0000God9ZS1Ol0
0008ohVS``?o00007on[R8H2o`0001_odoOh0_l0000:oiZBOPCo00005OnJOhl2o`0001coe>Vc1Ol0
000;ooooo`?o00007?ooool3o`000<kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0U?ooool4o`0000Wooooo0ol0000Eooooo`?o00006?n5_k43o`0001;o[jnZ1?l0000A
oh20Z0?o00000_o@VZ<5o`0000_oRJ?30ol0000Moj^8QP?o00006ooCmoP2o`0000_oVY9n1?l0000D
oiYoS`;o00006ooDjK<3o`0000oooooo0ol0000Kooooo`;o0000coooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2Fooooo`Co00001Oooool4o`0001Oooooo0_l0000GohFo
/@?o00005?n_[jX8o`0000coP82X2?l0000>ohVS``?o00007?n[R8H2o`0001_odoOh0ol0000=oiZB
OPCo00004_nJOhl2o`0001[oe>Vc0ol0000Aooooo`?o00006Oooool3o`000<oooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0Uoooool5o`0000;ooooo1?l0000Hooooo`?o
00005_n5_k42o`0001Oo[jnZ3Ol00003oh20Z0So00004On9Xl<3o`0001_oZhR60_l0000Kom?gn0;o
00003onJTWh5o`00013oVWn?0_l0000IomCY/`?o00004oooool3o`0001Oooooo0ol0003@ooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo09Wooooo1ol0000Kooooo`?o0000
5?n5_k43o`0001Ko[jnZ0ol00003olW3Y0ko00000on^gj@3o`00017oRJ?30ol0000Joj^8QP;o0000
6ooCmoP2o`00017oVY9n1?l0000>oiYoS`?o00006?oDjK<3o`0001Gooooo0ol0000Fooooo`;o0000
dOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Kooooo`Co00007Ooo
ool2o`0001?oQKna0ol0000Fojn_ZP?o00002oo9`j@5o`0000Ko[]nT0_l0000BohVS``?o00006On[
R8H2o`0001_odoOh0_l0000CoiZBOPCo00003?nJOhl2o`0001Soe>Vc0ol0000Gooooo`?o00005?oo
ool3o`000=7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0W?ooool2
o`0001kooooo0ol0000AohFo/@?o00005on_[jX2o`0000kobL>T0ol00006ojkOY0?o00004_n9Xl<3
o`0001OoZhR60ol0000Kom?gn0;o00005?nJTWh4o`0000_oVWn?0_l0000HomCY/`;o00006Oooool3
o`00017ooooo1?l0003Booooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo
09cooooo0_l0000Oooooo`?o00004?n5_k42o`0001Oo[jnZ0ol0000>olW3Y0;o00002?n^gj@2o`00
01?oRJ?30ol0000Foj^8QP;o00007?oCmoP2o`0001KoVY9n1?l00009oiYoS`;o00005ooDjK<3o`00
01[ooooo0ol0000=ooooo`Ko0000doooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2Looooo`;o00008?ooool3o`0000koQKna0ol0000Fojn_ZP?o00003oo9`j@2o`0000So
[]nT0ol0000CohVS``?o00005On[R8H2o`0001codoOh0_l0000GoiZBOPCo00002?nJOhl2o`0001Ko
e>Vc0ol0000Looooo`?o00002Oooool7o`000=Gooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0W?ooool2o`00027ooooo0_l0000=ohFo/@?o00005on_[jX2o`0000oobL>T
0ol00009ojkOY0;o00005?n9Xl<3o`0001CoZhR60_l0000Kom?gn0?o00006OnJTWh4o`0000KoVWn?
0_l0000EomCY/`?o00007_ooool3o`0000Gooooo1ol0003Hooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo09cooooo0ol0000Pooooo`?o00003?n5_k42o`0001Oo[jnZ0ol0
000?olW3Y0;o00002_n^gj@3o`0001CoRJ?30ol0000Boj^8QP?o00006ooCmoP2o`0001_oVY9n1?l0
0005oiYoS`;o00005?oDjK<3o`00023ooooo0ol000000ooooooo0000o`000005o`000=_ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0WOooool2o`00027ooooo0ol0000:
ohFo/@?o00005_n_[jX3o`00013obL>T0_l0000;ojkOY0;o00005On9Xl<3o`00017oZhR60_l0000L
om?gn0;o00007OnJTWh4o`0000;oVWn?0ol0000DomCY/`;o00008_ooool7o`000=kooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0WOooool2o`0002;ooooo3_l0000Gojn_
ZP;o00004?o9`j@3o`0000_o[]nT0ol0000EohVS``?o00004?n[R8H2o`0001codoOh0_l0000KoiZB
OP[o00005?oDjK<3o`0002?ooooo0ol0003Qooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo09gooooo0_l0000Sooooo`co00005on_[jX3o`00013obL>T0_l0000=ojkOY0;o
00005_n9Xl<3o`0000ooZhR60_l0000Lom?gn0;o00006OnJTWh5o`0000;o_K>a1Ol0000ComCY/`?o
00009?ooool2o`000>;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
WOooool2o`0002;ooooo0ol00008ojR//@?o00005On_[jX3o`00017obL>T0_l0000=ojkOY0?o0000
5_n9Xl<3o`0000goZhR60ol0000Lom?gn0;o00005onJTWh5o`0000Oo_K>a0_l0000BomCY/`?o0000
9Oooool2o`000>;ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0WOoo
ool2o`00027ooooo0ol0000:ojR//@?o00005?n_[jX2o`00017obL>T0ol0000>ojkOY0;o00005on9
Xl<3o`0000coZhR60_l0000Mom?gn0;o00005OnJTWh5o`0000Wo_K>a0ol0000@omCY/`?o00009Ooo
ool3o`000>;ooooo00?o0000ooooooooool02?ooool001[ooooo0ol0002Mooooo`;o00008?ooool3
o`0000coZ:ba0ol0000Bojn_ZP?o00004Oo9`j@2o`0000oo[]nT0ol0000GohVS``?o00002on[R8H2
o`0001codoOh0ol0000CoiZBOPGo00003?nm/k4Do`0002Kooooo0_l0003Qooooo`?o00002_ooool0
01[ooooo00?o0000ooooooooool0WOooool3o`0001kooooo0ol0000>ojR//@;o00004On_[jX3o`00
01;obL>T0_l0000@ojkOY0;o00006?n9Xl<3o`0000[oZhR60_l0000Lom?gn0;o00004_nJTWh5o`00
00oo_K>a4_l0000Wooooo`;o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2Nooooo`;o00007_ooool2o`0000ooZ:ba0ol0000?ojn_ZP?o00004_o9`j@3o`00013o
[]nT0ol0000HohVS``?o00002On[R8H2o`0001codoOh0_l0000@oiZBOPGo00004?nm/k43o`0000ko
oooo0ol0000Vooooo`;o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2Nooooo`;o00007Oooool3o`00013oZ:ba0ol0000>ojn_ZP;o00004oo9`j@2o`0001;o[]nT
0_l0000IohVS``?o00001on[R8H3o`0001codoOh0_l0000=oiZBOPKo00004_nm/k42o`00013ooooo
0ol0000Uooooo`;o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`2Nooooo`;o00007?ooool3o`0001;oZ:ba0_l0000=ojn_ZP?o00004_o9`j@3o`0001;o[]nT0ol0
000IohVS``?o00001_n[R8H5o`0001[odoOh0_l0000;oiZBOPKo00005?nm/k42o`00017ooooo0ol0
000Sooooo`?o0000hoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2N
ooooo`;o00006oooool3o`0001?oZ:ba0ol0000;ojn_ZP?o00004oo9`j@2o`0001Co[]nT0_l0000J
ohVS``?o00001?n[R8H;o`0001GodoOh0_l00009oiZBOPGo00005_nm/k43o`0001;ooooo0ol0000R
ooooo`;o0000i?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Noooo
o`?o00006Oooool3o`0001GoZ:ba0ol0000:ojn_ZP;o00005?o9`j@2o`0001Co[]nT1?l0000IohVS
``?o00000_n[R8H3o`0000?oPgg52ol0000@om?gn0;o00001onJTWh5o`0001So_K>a0_l0000Doooo
o`?o00008?ooool3o`000>Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooooooo
ool0Woooool3o`0001Oooooo0ol0000GojR//@?o00002?n_[jX3o`0001?obL>T0ol0000EojkOY0Ko
00005on9Xl<6o`0000WoPgg52ol0000:om?gn0?o00001OnJTWh5o`0001[o_K>a0_l0000Eooooo`?o
00007_ooool4o`000>Cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
X?ooool3o`0001Kooooo0_l0000IojR//@;o00001on_[jX3o`0001CobL>T0_l0000EojkOY0Wo0000
5_n9Xl<4o`0000ooPgg52ol00005om?gn0;o00001?nJTWh5o`0001_o_K>a0ol0000Fooooo`?o0000
7?ooool3o`000>Kooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0XOoo
ool3o`0001Cooooo0ol0000IojR//@?o00001_n_[jX2o`0001GobL>T0_l0000EojkOY0;o00001?n;
blh5o`0001GoRJ?30_l0000Eoh=ma@go00000_nJTWh5o`0001go_K>a0_l0000Hooooo`;o00006ooo
ool3o`000>Oooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0X_ooool3
o`0001;ooooo0ol0000KojR//@?o00001?n_[jX3o`0001CobL>T0ol0000DojkOY0?o00001_n;blh6
o`00017oRJ?30ol0000Joh=ma@go00007_nm/k43o`0001Sooooo0ol0000Iooooo`?o0000j?ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Sooooo`?o00004?ooool3o`00
01goZ:ba0_l00003ojn_ZP?o00005Oo9`j@2o`0001Go[]nT0_l00009oh_;cPKo00003on9Xl<2o`00
023oPgg51_l0000Pokfc/@;o00006_ooool3o`0001Oooooo0ol0003Yooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0:Cooooo0ol0000=ooooo`Co00007_nX[;43o`0000;o
[jnZ0_l0000FolW3Y0;o00005?n^gj@3o`0000coRl_>1Ol0000<ohVS``?o00008_n3OLD2o`0002;o
_K>a0_l0000Kooooo`?o00005?ooool4o`000>[ooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0YOooool3o`0000[ooooo2?l0000MojR//@Ko00005Oo9`j@3o`0001Co[]nT
0_l0000?oh_;cPKo00002?n9Xl<3o`0002?oPgg50_l0000Qokfc/@?o00007?ooool3o`0001;ooooo
1?l0003[ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:Kooooo0ol0
0006ooooo`Ko00000_ooool5o`0001coZ:ba1?l0000FolW3Y0;o00005?n^gj@3o`00017oRl_>1_l0
0006ohVS``;o00009?n3OLD3o`00023o_K>a0_l0000Nooooo`?o00004?ooool3o`000>gooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Yoooool3o`0000?ooooo1_l00006
ooooo`Go00006onX[;42o`0001OobL>T0_l0000DojkOY0;o00005On;blh5o`0000?oRJ?30ol0000U
oh=ma@;o00008?nm/k42o`0001oooooo0ol0000>ooooo`?o0000k_ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2Xooooo`So00002oooool5o`0001WoZ:ba0_l0000BolW3
Y0Oo00004on^gj@3o`0001OoRl_>2?l0000Voh=ma@;o00007_nm/k44o`00023ooooo0_l0000=oooo
o`?o0000koooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2Yooooo`Go
00003oooool5o`0001OoZ:ba0ol00009olW3Y13o00004_n^gj@2o`0001[oRl_>1_l0000Voh=ma@?o
00006onm/k45o`00027ooooo0ol0000:ooooo`Co0000l?ooool00ol0003oooooooooo`08ooooo`00
6_ooool00ol0003oooooooooo`2Zooooo`;o00004oooool5o`0001KoZ:ba0_l00002olW3Y13o0000
1Oo6Z<X3o`00013o[]nT0ol0000Moh_;cP;o0000:?n3OLD2o`0001So_K>a2Ol0000Qooooo`?o0000
2?ooool4o`000?7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Z_oo
ool2o`0001Gooooo1Ol0000DojR//@co00003_o6Z<X3o`0000oo[]nT0_l0000Noh_;cP;o0000:?n3
OLD2o`0001Ko_K>a1_l00003ooooo`?o00008Oooool3o`0000Kooooo0ol0003cooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:[ooooo0_l0000Gooooo`Co00004onX[;45
o`0001KoaZS:0ol0000=ojkOY0?o00007_n;blh2o`0002SoPgg50_l0000Dokfc/@Go00001oooool2
o`0002;ooooo0ol00004ooooo`?o0000m?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0
003oooooooooo`2Zooooo`;o00006Oooool4o`00013oZ:ba0ol0000JolJXbP?o00003?n^gj@2o`00
01ooRl_>0_l0000Xoh=ma@?o00004Onm/k45o`0000Wooooo0ol0000Rooooo`?o00000_ooool3o`00
0?Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0Z_ooool2o`0001[o
oooo1Ol0000>ojR//@;o00007?o6Z<X3o`0000[o[]nT0ol0000Ooh_;cP;o0000:On3OLD2o`0000ko
_K>a1_l0000<ooooo`?o00008_ooool6o`000?Kooooo00?o0000ooooooooool02?ooool001[ooooo
00?o0000ooooooooool0ZOooool3o`0001cooooo1Ol0000;ojR//@?o00007Oo6Z<X3o`0000Wo[]nT
0_l0000Poh_;cP;o0000:On3OLD2o`0000co_K>a1_l0000?ooooo`;o00008oooool4o`000?Oooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0ZOooool2o`0001oooooo1Ol0
0009ojR//@;o00007oo6Z<X3o`0000Oo[]nT0ol0000Poh_;cP;o0000:On3OLD3o`0000Wo_K>a1Ol0
000Booooo`?o00008_ooool3o`000?Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000
ooooooooool0ZOooool2o`00027ooooo1Ol00005ojR//@Co00008?o6Z<X3o`0000Ko[]nT0_l0000Q
oh_;cRko00001onm/k45o`0001Gooooo0ol0000Pooooo`Co0000n?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2Yooooo`;o00008oooool;o`0002;oaZS:0ol00004ojkO
Y0?o00008On;blh_o`0000?o_K>a1_l0000Hooooo`;o00007oooool3o`000?[ooooo00?o0000oooo
ooooool02?ooool001[ooooo00?o0000ooooooooool0ZOooool2o`0002Gooooo2_l0000RolJXbP?o
00000on^gj@2o`0002;oRl_>0_l0000[ol?1c@Wo00006_ooool3o`0001cooooo1?l0003kooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0:Wooooo0_l0000Uooooo`Co0000
1?ooool2o`0002?oaZS:0ol000001?n^gjCo0000o`000?l0000Qoh_;cP?o0000;?o3`Ld5o`0001ko
oooo0ol0000Jooooo`Co0000o?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooo
ooooo`2Yooooo`;o00009?ooool3o`0000Kooooo0ol0000SolJXbPGo00008_n;blh2o`0002ko`l7=
0_l0000Qooooo`?o00006?ooool3o`000?kooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0ZOooool3o`0002;ooooo0ol00008ooooo`?o00008oo6Z<X4o`0002;oRl_>0_l0
000^ol?1c@;o00008_ooool2o`0001Kooooo1?l0003oooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0:[ooooo0ol0000Pooooo`?o00002_ooool2o`0002CoaZS:0_l0000R
oh_;cP?o0000;Oo3`Ld3o`0002;ooooo0ol0000Dooooo`Co0000ooooool1ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0:_ooooo0ol0000Nooooo`?o00002oooool3o`00
02?oaZS:0ol0000Moh_;cPKo0000;Oo3`Ld3o`0002Cooooo0ol0000Booooo`?o0000ooooool3oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`?o0000[?ooool2o`0001gooooo0ol0000=ooooo`;o
00009?o6Z<X2o`0001CoRl_>3ol0000/ol?1c@Co00009Oooool2o`00013ooooo1?l0003oooooo`;o
oooo0ol0000:ooooo`006_ooool00ol0003oooooooooo`2/ooooo`?o00006oooool3o`0000kooooo
0ol0000SolJXbP;o00003?n;blhBo`0000?ooooo0ol0000Yol?1c@Oo00009?ooool3o`0000kooooo
1?l0003oooooo`Gooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0[Ooo
ool3o`0001Wooooo0ol0000@ooooo`;o00008oo6Z<X3o`0000;oRl_>4_l0000=ooooo`;o0000:?o3
`Ld4o`0000;ooooo0ol0000Tooooo`?o00003?ooool3o`000?oooooo1oooool00ol0003ooooooooo
o`08ooooo`006_ooool00ol0003oooooooooo`2^ooooo`?o00005oooool3o`00017ooooo0ol0000S
olJXbPko00005Oooool3o`0002Go`l7=1?l00005ooooo`;o00009Oooool2o`0000[ooooo1?l0003o
ooooo`Sooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0[oooool2o`00
01Kooooo0ol0000Cooooo`?o00008_o6Z<X5o`0001oooooo0_l0000Tol?1c@Co00001_ooool3o`00
02Cooooo0ol00008ooooo`Co0000ooooool9ooooo`03o`000?oooooooooo00Sooooo000Jooooo`03
o`000?oooooooooo0:oooooo0ol0000Dooooo`?o00005Oooool2o`00027oaZS:0ol0000Rooooo`?o
00008Oo3`Ld4o`0000Wooooo0ol0000Tooooo`?o00001_ooool3o`000?oooooo2oooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`2`ooooo`?o00004_ooool3o`0001Kooooo
0ol0000PolJXbP;o00009?ooool2o`00023o`l7=1?l0000;ooooo`;o00009Oooool2o`0000Cooooo
1?l0003oooooo`cooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0/Ooo
ool2o`00017ooooo0ol0000Hooooo`;o00007oo6Z<X3o`0002Cooooo0ol0000Mol?1c@Co00003Ooo
ool3o`0002Cooooo0ol00002ooooo`Co0000ooooool=ooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0;7ooooo0ol0000?ooooo`?o00006Oooool3o`0001koaZS:0_l0000V
ooooo`;o00007?o3`Ld4o`0000oooooo0ol0000Tooooo`Ko0000ooooool?ooooo`03o`000?oooooo
oooo00Sooooo000Jooooo`03o`000?oooooooooo0;;ooooo0ol0000=ooooo`?o00006oooool2o`00
01goaZS:0ol0000Vooooo`?o00006Oo3`Ld4o`0001;ooooo0_l0000Sooooo`Ko0000ooooool@oooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;?ooooo1?l0000:ooooo`?o
00007?ooool3o`0001coaZS:0_l0000Xooooo`;o00006?o3`Ld4o`0001?ooooo0ol0000Pooooo`Co
000000?oooooo`000?l00000oooooolAooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0;Cooooo1Ol00007ooooo`?o00007_ooool3o`0001[oaZS:0ol0000Xooooo`?o0000
5_o3`Ld3o`0001Kooooo0ol0000Nooooo`Co0000oooooolEooooo`03o`000?oooooooooo00Sooooo
000Jooooo`03o`000?oooooooooo0;Kooooo1_l00003ooooo`?o00008?ooool2o`0001[oaZS:0_l0
000Zooooo`;o00005?o3`Ld4o`0001Sooooo0_l0000Looooo`Co0000oooooolGooooo`03o`000?oo
oooooooo00Sooooo000Jooooo`03o`000?oooooooooo0;Sooooo2Ol0000Qoooooako0000:_ooool4
o`00017o`l7=1?l0000Iooooo`?o00006_ooool4o`000?oooooo6?ooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`2kooooo`Go00008ooooolLo`0002[ooooo1_l0000>ol?1
c@Co00007?ooool2o`0001Sooooo1?l0003ooooooa[ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0_Oooool2o`0002?ooooo0ol0000Hooooo`;o0000:Oooool3o`0000;o
oooo1?l0000;ol?1c@Co00007Oooool3o`0001Gooooo1Ol0003ooooooa_ooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0_Oooool3o`0002;ooooo0_l0000Iooooo`?o0000
9oooool3o`0000Cooooo1?l00008ol?1c@Co00008?ooool3o`0001?ooooo1?l0003ooooooagooooo
00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool2o`00027ooooo0ol0
000Jooooo`;o00009Oooool4o`0000Oooooo0ol00006ol?1c@Co00008_ooool2o`00017ooooo1?l0
003ooooooaoooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0__ooool3
o`00023ooooo0_l0000Kooooo`;o00009?ooool4o`0000Wooooo1?l00002ol?1c@Co00009?ooool3
o`0000oooooo1?l0003oooooob3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0_oooool2o`0001oooooo0ol0000Kooooo`?o00008_ooool3o`0000cooooo2?l0000Voooo
o`?o00003?ooool4o`000?oooooo8_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`2oooooo`;o00007_ooool3o`0001gooooo0_l0000Qooooo`?o00003oooool4o`0002Wo
oooo0_l0000;ooooo`Co0000oooooolSooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`00
0?oooooooooo0;oooooo0ol0000Mooooo`;o00007_ooool2o`0001oooooo1?l0000Aooooo`;o0000
:_ooool3o`0000Cooooo2?l0003oooooobGooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0`?ooool2o`0001cooooo0ol0000Nooooo`;o00007_ooool4o`0001;ooooo0ol0
000Zooooo`go0000oooooolVooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooo
oooo0<3ooooo1?l0000Jooooo`;o00007oooool3o`0001cooooo0ol0000Eooooo`;o0000:oooool6
o`000?oooooo;?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`31oooo
o`Co00006?ooool3o`00023ooooo0_l0000Kooooo`?o00005_ooool2o`0002[ooooo0ol0003ooooo
oc3ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0`oooool3o`0001Oo
oooo0_l0000Qooooo`;o00006Oooool4o`0001Oooooo0ol0000Xooooo`?o0000oooooolaooooo`03
o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<Cooooo1?l0000Dooooo`?o0000
8Oooool3o`0001Oooooo1?l0000Iooooo`;o0000:?ooool2o`000?oooooo<_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`35ooooo`Co00004oooool2o`0002?ooooo0_l0
000Fooooo`?o00006oooool2o`0002Oooooo0ol0003ooooooc;ooooo00?o0000ooooooooool02?oo
ool001[ooooo00?o0000ooooooooool0aoooool3o`00017ooooo0ol0000Sooooo`;o00005Oooool3
o`0001cooooo0ol0000Uooooo`?o0000oooooolcooooo`03o`000?oooooooooo00Sooooo000Joooo
o`03o`000?oooooooooo0<Sooooo1?l0000>ooooo`?o00009?ooool2o`0001Cooooo0ol0000Noooo
o`;o00009Oooool2o`000?oooooo=?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003o
ooooooooo`39ooooo`Co00003Oooool2o`0002Gooooo0ol0000Aooooo`Co00007oooool2o`0002Co
oooo0ol0003oooooocCooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
boooool3o`0000_ooooo0ol0000Vooooo`;o00004?ooool4o`00023ooooo0ol0000Sooooo`;o0000
ooooooleooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0<cooooo2Ol0
0004ooooo`;o00009oooool2o`0000oooooo0ol0000Sooooo`;o00008_ooool3o`000?oooooo=Ooo
ool00ol0003oooooooooo`08ooooo`006_ooool3o`000<gooooo3_l0000Wooooo`?o00003Oooool3
o`0002Cooooo0_l0000Pooooo`Co0000ooooooldooooo`?o00002_ooool001[ooooo00?o0000oooo
ooooool0e?ooool6o`0002Wooooo0_l0000;ooooo`Co00009Oooool3o`0001gooooo1Ol0003ooooo
ocOooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0f?ooool3o`0002So
oooo0_l0000:ooooo`Co00009oooool2o`0001_ooooo1Ol0003oooooocWooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0fOooool3o`0002Oooooo0_l00009ooooo`?o0000
:Oooool2o`0001Wooooo1Ol0003ooooooc_ooooo00?o0000ooooooooool02?ooool001[ooooo00?o
0000ooooooooool0f_ooool3o`0002Kooooo0ol00007ooooo`?o0000:_ooool3o`0001Kooooo1Ol0
003oooooocgooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0foooool3
o`0002Kooooo0_l00005ooooo`Co0000;?ooool7o`0000oooooo1Ol0003oooooocoooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0g?ooool2o`0002Kooooo0_l00004oooo
o`Co0000;Oooool@o`0000Cooooo1Ol0003ooooood7ooooo00?o0000ooooooooool02?ooool001[o
oooo00?o0000ooooooooool0g?ooool3o`0002Gooooo0ol00002ooooo`?o0000;_ooool3o`0000Co
oooo4Ol0003ooooood?ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0
gOooool3o`0002?ooooo2?l0000^ooooo`?o00003_ooool6o`000?ooooooAOooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`3Nooooo`?o00007oooool:o`0002kooooo1?l0
003ooooooeWooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0goooool5
o`0001Wooooo1ol00003ooooo`Go0000:oooool3o`000?ooooooFoooool00ol0003oooooooooo`08
ooooo`006_ooool00ol0003oooooooooo`3Pooooo`Oo00004oooool7o`0000Sooooo1Ol0000Woooo
o`Co0000oooooomLooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0>?o
oooo1ol0000=ooooo`Oo00003Oooool4o`0002Gooooo1?l0003ooooooegooooo00?o0000oooooooo
ool02?ooool001[ooooo00?o0000ooooooooool0i_ooool7o`0000Oooooo1ol0000Booooo`Co0000
8_ooool3o`000?ooooooGoooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`3Yooooo`Oo000000?oooooo`000?l000001Ol0000Fooooo`Go00007_ooool4o`000?ooooooH?oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3/ooooo`Wo00006oooool5
o`0001_ooooo1?l0003oooooof7ooooo00?o0000ooooooooool02?ooool001[ooooo00?o0000oooo
ooooool0koooool3o`00023ooooo1Ol0000Hooooo`?o0000oooooomSooooo`03o`000?oooooooooo
00Sooooo000Jooooo`03o`000?oooooooooo0?oooooo5Oooool5o`0001Cooooo1?l0003oooooofCo
oooo00?o0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooolGooooo`Co0000
4_ooool4o`000?ooooooIOooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`3ooooooaWooooo1?l0000?ooooo`?o0000oooooomWooooo`03o`000?oooooooooo00Sooooo000J
ooooo`03o`000?oooooooooo0?oooooo6_ooool5o`0000Kooooo2Ol0003oooooofSooooo00?o0000
ooooooooool02?ooool001[ooooo00?o0000ooooooooool0oooooolLoooooa7o0000oooooomYoooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo0?oooooo7_ooool8o`000?oo
ooooL?ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo
U_ooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_oo
ool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool0
0ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0
003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0003o
ooooooooo`08ooooo`006_ooool00ol0003oooooooooo`3oooooooooooooU_ooool00ol0003ooooo
ooooo`08ooooo`006_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool02?ooool001[ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo00Sooooo00001?oooooo0000o`000?l00002ooooo`Go00000oooool2
o`0000[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Sooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`08ooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00002Oooooooo`000?oo0000V_l0000:ooooo`000_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`3oooooooooooooZoooool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool0oooooooooooooj_ooooo00000ooooooo0000o`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0003ooooooooo
oooo[Oooool000;ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0003ooooooooooooo
[_ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oo
oooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooooonn
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 699}, {699, 0}} -> {16.0374, 16.3764, 0.150671, \
0.150671}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Define the SBML Model using MathSBML", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ncells = Length[xymeristem]\)], "Input"],

Cell[BoxData[
    \(253\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(rn := Random[Real, {0,  .7}];\)\), "\[IndentingNewLine]", 
    \(rc := CMYKColor[rn, rn, rn,  .1]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sigma[x]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((1 + x\/\@\(1 + x\^2\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sigma[\((hw + Twy\ Y[i]\  + Twa\ A[i])\)]/tauw\)], "Input"],

Cell[BoxData[
    \(\(1 + \(hw + Twa\ A[i] + Twy\ Y[i]\)\/\@\(1 + \((hw + Twa\ A[i] + Twy\ \
Y[i])\)\^2\)\)\/\(2\ tauw\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(interpret[{{Y[i] \[RightTeeArrow] W[i], 
          GRN[1/tauw, Twy, 1, hw, 
            sigma]}, \[IndentingNewLine]{A[i] \[RightTeeArrow] W[i], \ 
          GRN[1/tauw, Twa, 1, hw, sigma]}}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox[\(W[i]\), "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], 
            "\[Equal]", \(\(1 + \(hw + Twa\ \(A[i]\)[t] + Twy\ \
\(Y[i]\)[t]\)\/\@\(1 + \((hw + Twa\ \(A[i]\)[t] + Twy\ \
\(Y[i]\)[t])\)\^2\)\)\/\(2\ tauw\)\)}], "}"}], ",", \({W[i]}\)}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(SIDify[x_[y_]] := \ 
        Symbol[ToString[x] <> "\<\[UnderBracket]\>" <> 
            ToString[y]];\)\), "\[IndentingNewLine]", 
    \(\(SIDify[x_, n_?IntegerQ] := \(SIDify[x[#]] &\) /@ 
          Range[n];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(rates = {ky \[Rule] \ 0.2, \ dy \[Rule] \ 0.1, \ Dy \[Rule] \ 0.1, \ 
          kD \[Rule] \ 3.0, \ tauw \[Rule] \ 10, \ dw \[Rule] \ 0.1, \ 
          hw \[Rule] \ 0, \ Twy \[Rule] \ \(-20\), \ Twa \[Rule] \ 0.5, \ 
          a \[Rule] \ 0.1, \ b \[Rule] \ 0.2, \ beta \[Rule] \ 0.1, \ 
          c \[Rule] \ 0.1, \ d \[Rule] \ 0.01, \ Da \[Rule] \ 0.1, \ 
          Db \[Rule] \ 1.5};\)\)], "Input"],

Cell[BoxData[
    \(radius[j_] := \ 
      Sqrt[\((xyz[\([j, 1]\)])\)^2 + \((xyz[\([j, 2]\)])\)^2]\)], "Input"],

Cell[BoxData[{
    \(\(cells = SIDify[cell, ncells];\)\), "\[IndentingNewLine]", 
    \(\(cellNames = \("\<Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(As = SIDify[A, ncells];\)\), "\[IndentingNewLine]", 
    \(\(ANames = \("\<Brusselator Variable A in Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(Bs = SIDify[B, ncells];\)\), "\[IndentingNewLine]", 
    \(\(BNames = \("\<Brusselator Variable B in Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(Ws = SIDify[Wus, \ ncells];\)\), "\[IndentingNewLine]", 
    \(\(WNames = \("\<Wuschel in Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(Ys = SIDify[Y, ncells];\)\), "\[IndentingNewLine]", 
    \(\(YNames = \("\<Diffusible Wuschel Inhibitor in Cell \>" <> 
              ToString[#] &\) /@ Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(L1s = SIDify[L1SP, ncells];\)\), "\[IndentingNewLine]", 
    \(\(L1Names = \("\<Layer 1 Specifc Protein in Cell \>" <> 
              ToString[#] &\) /@ Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(xs = SIDify[x, ncells];\)\), "\[IndentingNewLine]", 
    \(\(ys = SIDify[y, ncells];\)\), "\[IndentingNewLine]", 
    \(\(xnames = \("\<x coordinate of nuclues of Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\(ynames = \("\<y coordinate of nuclues of Cell \>" <> ToString[#] &\) /@ 
          Range[ncells];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ynames[\([42]\)]\)], "Input"],

Cell[BoxData[
    \("y coordinate of nuclues of Cell 42"\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(polygonalArea[vertices_] := \ 
        Module[{n, x, y, area}, \[IndentingNewLine]n = 
            Length[vertices]; \[IndentingNewLine]{x, y} = 
            Transpose[
              Append[vertices, 
                vertices[\([1]\)]]]; \[IndentingNewLine]area = \[Sum]\+\(i = \
1\)\%n\((x[\([i]\)] y[\([i + 1]\)] - 
                  x[\([i + 1]\)] y[\([i]\)])\); \[IndentingNewLine]area = 
            area/2; \[IndentingNewLine]Return[
            area];\[IndentingNewLine]];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(areas = 
      Abs /@ \(polygonalArea /@ boundedCellVoronoi[xymeristem]\)\)], "Input"],

Cell[BoxData[
    \({23.550573333914144`, 20.31926329714713`, 20.320294072212732`, 
      22.603812667747434`, 14.557191736694904`, 25.452158988108977`, 
      13.677408195307294`, 20.915460079738523`, 19.877941960784256`, 
      40.20060287800584`, 15.434360736640429`, 24.697314143519634`, 
      21.575883092135314`, 17.201167703482724`, 32.464147816230934`, 
      21.026913211250076`, 21.357338798447927`, 15.702350817790148`, 
      41.139092966734324`, 35.129079881709686`, 25.711911043300006`, 
      13.529736161616256`, 18.841817438260932`, 8.513322857142839`, 
      12.656967549019441`, 12.634514441842384`, 13.023991578947289`, 
      22.728339673544497`, 18.695229855016805`, 22.28467805941`, 
      13.931100173819004`, 16.184244047618904`, 13.513468102652041`, 
      15.573360062813663`, 20.447455129031823`, 22.90341871232522`, 
      22.549631710791914`, 14.116575854360008`, 29.51495153435917`, 
      18.82803741087423`, 12.805101581605186`, 18.162224631339086`, 
      23.960318466103104`, 17.74556832586609`, 20.341156213575005`, 
      17.910804891701446`, 11.781502102271588`, 15.05618733516485`, 
      14.0184456711645`, 21.8847448854425`, 13.76640438375307`, 
      11.007483635792141`, 26.867547142856893`, 29.454799804251707`, 
      14.995993281740766`, 14.12717807142758`, 20.973317545210648`, 
      21.568309641885662`, 25.007628783572954`, 22.303501764005432`, 
      17.25239546225464`, 6.960640259740558`, 13.412011546610756`, 
      20.414269891792742`, 27.0750486228701`, 12.258395540890433`, 
      9.626417563079713`, 9.986875000000282`, 11.540695105225268`, 
      23.414915750528735`, 11.731950000000325`, 15.93688707063393`, 
      14.348145695971198`, 20.528717582417812`, 22.281889867109157`, 
      19.19890124992571`, 20.878287087912213`, 26.27136445676024`, 
      12.351145984491268`, 15.465162585712278`, 11.245337332301915`, 
      25.62604900879046`, 26.39148262389824`, 18.39987170128461`, 
      9.628779093672165`, 12.447857213953284`, 22.321996753246594`, 
      15.589180624795063`, 15.234851194332009`, 20.285130740093336`, 
      10.289082208984837`, 15.200047462405564`, 16.58651958041969`, 
      14.444670538720402`, 21.964092010272452`, 23.845265689274925`, 
      23.27844180590614`, 10.664287978179345`, 14.36290292397689`, 
      22.577415639476612`, 16.012844503443375`, 16.15741247303822`, 
      17.439559274193925`, 15.333141125541488`, 13.334364983973956`, 
      11.955502139427153`, 26.749036931839782`, 12.240372727272643`, 
      18.183872553642686`, 13.346027703089021`, 16.322408333333442`, 
      21.489470530705148`, 26.73310556143963`, 23.342086617175028`, 
      19.104704887955222`, 20.336192329545838`, 23.02932670033647`, 
      16.252444378832024`, 14.410191137033962`, 16.890454148223853`, 
      17.448879079710878`, 27.34786253823313`, 28.21011486417501`, 
      20.63342148617494`, 28.707541528834554`, 12.940999227052998`, 
      12.369063322075135`, 9.662038749999965`, 15.103465156072161`, 
      14.995221630575315`, 23.14514465803495`, 30.334741394306548`, 
      12.115836767677138`, 20.383551196522944`, 17.778626987681037`, 
      15.993283029900795`, 20.16811424694879`, 20.85870658674594`, 
      16.862160363787098`, 19.94476553571417`, 26.45371516693217`, 
      12.517542941176316`, 17.122759999999744`, 21.251135853623055`, 
      42.67777053674263`, 12.260681257631404`, 16.738508779512813`, 
      20.88998976767698`, 21.860071118339874`, 26.929532911461592`, 
      14.110430552423168`, 25.174979608659214`, 23.394016488466832`, 
      25.957460128144703`, 22.086017474358414`, 15.724890155677485`, 
      12.634988569632696`, 17.09541416915272`, 16.06493224400856`, 
      24.50983598901098`, 26.87193173784999`, 27.01548918453318`, 
      19.2763373441785`, 43.08721543356705`, 18.75520570266781`, 
      15.802060234565943`, 10.915907776771746`, 11.25638452380963`, 
      16.072230082527767`, 19.08945558196592`, 23.43483575305936`, 
      19.25200752149476`, 17.87688149612586`, 10.657392361054463`, 
      23.225796756140426`, 27.031015518108916`, 15.44244091553719`, 
      25.207609544700176`, 14.085815252164139`, 19.844002660343904`, 
      17.837222985194785`, 23.613081199755015`, 16.253304385965293`, 
      18.489838913043968`, 21.825733216305707`, 20.419743876517487`, 
      15.02607929021542`, 49.744675317831025`, 15.356953264820277`, 
      30.013580901292244`, 15.972419422011626`, 10.438311785714177`, 
      9.95183333333307`, 12.592063636363946`, 19.068742840923733`, 
      18.823394078701767`, 23.62448469525293`, 26.919420387235277`, 
      23.520352671007913`, 23.92073083475634`, 42.80062039075506`, 
      16.73340892607348`, 25.581363142302735`, 17.1305807965241`, 
      24.69808409134521`, 18.417459150671675`, 19.512964051620656`, 
      25.720875347222545`, 25.267417519518176`, 20.255096192696328`, 
      23.879601541368174`, 21.741708399311847`, 22.091459764539195`, 
      22.06541235539271`, 43.92118266596617`, 33.43051121022063`, 
      19.103741410136536`, 35.82115969149527`, 30.530300904425303`, 
      20.592813926162307`, 28.56940792352634`, 12.118365459632969`, 
      17.89415618421117`, 14.400507692307656`, 33.202294165880176`, 
      26.81394345918784`, 23.210200379779735`, 32.75229924246128`, 
      24.026710739823102`, 24.437029825366608`, 23.355208452786883`, 
      16.711406523195365`, 15.753004004328886`, 36.98266651766471`, 
      17.56944764976015`, 15.380134065934271`, 29.5599267042021`, 
      17.10788778503229`, 26.111092007419074`, 17.425498455394518`, 
      17.333262981463122`, 28.821384712719237`, 11.29114788752986`, 
      28.57255672530573`, 28.520634766082367`, 20.219113069412288`, 
      19.637723333221857`, 23.967360931936582`, 25.420754677543982`, 
      28.172970228247323`, 27.056682868878397`, 28.747340636602985`, 
      24.25305396843214`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(totalArea = Plus @@ areas\)], "Input"],

Cell[BoxData[
    \(5129.864353404313`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt[totalArea]\)], "Input"],

Cell[BoxData[
    \(71.62307137650768`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[areas]\)], "Input"],

Cell[BoxData[
    \(253\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dt = prunedDelaunayTriangulation[xymeristem]\)], "Input"],

Cell[BoxData[
    \({edges \[Rule] {{1, 2}, {1, 3}, {1, 8}, {2, 4}, {2, 5}, {2, 8}, {3, 
            6}, {3, 7}, {3, 8}, {4, 5}, {4, 9}, {4, 10}, {5, 8}, {5, 9}, {5, 
            14}, {6, 7}, {6, 11}, {6, 12}, {6, 22}, {7, 8}, {7, 11}, {7, 
            13}, {8, 13}, {8, 14}, {8, 17}, {9, 10}, {9, 14}, {9, 18}, {9, 
            27}, {10, 18}, {10, 19}, {10, 28}, {11, 13}, {11, 22}, {11, 
            24}, {11, 25}, {11, 26}, {12, 16}, {12, 22}, {12, 30}, {13, 
            17}, {13, 26}, {13, 39}, {14, 17}, {14, 23}, {14, 27}, {14, 
            33}, {15, 20}, {15, 21}, {15, 29}, {15, 34}, {15, 35}, {16, 
            30}, {17, 23}, {17, 39}, {17, 53}, {17, 54}, {18, 27}, {18, 
            28}, {18, 31}, {19, 20}, {19, 28}, {19, 32}, {19, 38}, {19, 
            40}, {20, 34}, {20, 40}, {21, 29}, {21, 36}, {21, 47}, {22, 
            24}, {22, 37}, {22, 43}, {23, 33}, {23, 45}, {23, 54}, {24, 
            25}, {24, 37}, {25, 26}, {25, 37}, {25, 39}, {26, 39}, {27, 
            31}, {27, 33}, {28, 31}, {28, 32}, {28, 44}, {29, 35}, {29, 
            47}, {29, 49}, {29, 57}, {30, 43}, {30, 50}, {31, 33}, {31, 
            44}, {31, 46}, {32, 38}, {32, 44}, {33, 45}, {33, 46}, {34, 
            35}, {34, 40}, {34, 41}, {34, 51}, {34, 52}, {35, 41}, {35, 
            57}, {35, 60}, {36, 42}, {36, 47}, {36, 48}, {37, 39}, {37, 
            43}, {37, 59}, {38, 40}, {38, 44}, {38, 56}, {38, 67}, {39, 
            53}, {39, 59}, {39, 65}, {40, 51}, {40, 56}, {41, 52}, {41, 
            60}, {42, 48}, {42, 58}, {43, 50}, {43, 59}, {43, 61}, {43, 
            64}, {44, 46}, {44, 55}, {44, 66}, {44, 67}, {45, 46}, {45, 
            54}, {45, 75}, {46, 55}, {46, 68}, {46, 69}, {47, 48}, {47, 
            49}, {47, 63}, {48, 58}, {48, 63}, {48, 73}, {48, 77}, {49, 
            57}, {49, 63}, {49, 76}, {50, 61}, {50, 82}, {51, 52}, {51, 
            56}, {51, 71}, {51, 72}, {51, 84}, {52, 60}, {52, 72}, {53, 
            54}, {53, 65}, {53, 70}, {53, 74}, {54, 74}, {54, 75}, {55, 
            66}, {55, 69}, {55, 86}, {56, 62}, {56, 67}, {56, 71}, {57, 
            60}, {57, 76}, {57, 81}, {57, 85}, {58, 77}, {58, 78}, {59, 
            64}, {59, 65}, {59, 83}, {59, 87}, {60, 72}, {60, 80}, {60, 
            85}, {61, 64}, {61, 82}, {61, 89}, {61, 96}, {62, 67}, {62, 
            71}, {62, 79}, {63, 73}, {63, 76}, {64, 83}, {64, 96}, {65, 
            70}, {65, 87}, {65, 97}, {65, 100}, {66, 67}, {66, 79}, {66, 
            86}, {66, 91}, {67, 79}, {68, 69}, {68, 75}, {68, 94}, {69, 
            86}, {69, 94}, {69, 98}, {70, 74}, {70, 93}, {70, 97}, {71, 
            79}, {71, 84}, {72, 80}, {72, 84}, {72, 102}, {73, 76}, {73, 
            77}, {73, 92}, {74, 75}, {74, 90}, {74, 93}, {75, 90}, {75, 
            94}, {76, 81}, {76, 92}, {76, 95}, {77, 78}, {77, 92}, {77, 
            103}, {77, 107}, {78, 107}, {79, 84}, {79, 91}, {79, 99}, {79, 
            101}, {80, 85}, {80, 88}, {80, 102}, {80, 110}, {81, 85}, {81, 
            95}, {82, 89}, {82, 113}, {83, 87}, {83, 96}, {83, 100}, {83, 
            123}, {84, 101}, {84, 102}, {84, 109}, {85, 88}, {85, 95}, {86, 
            91}, {86, 98}, {86, 106}, {87, 100}, {88, 95}, {88, 110}, {88, 
            112}, {88, 120}, {89, 96}, {89, 113}, {90, 93}, {90, 105}, {90, 
            108}, {90, 116}, {91, 99}, {91, 106}, {91, 118}, {92, 95}, {92, 
            103}, {92, 111}, {93, 97}, {93, 104}, {93, 105}, {93, 115}, {94, 
            98}, {94, 108}, {94, 117}, {95, 111}, {95, 120}, {95, 121}, {96, 
            113}, {96, 123}, {96, 127}, {97, 100}, {97, 104}, {97, 124}, {98, 
            106}, {98, 117}, {98, 125}, {99, 101}, {99, 118}, {99, 
            119}, {100, 114}, {100, 123}, {100, 124}, {100, 132}, {101, 
            109}, {101, 119}, {101, 131}, {102, 109}, {102, 110}, {102, 
            129}, {103, 107}, {103, 111}, {103, 136}, {103, 137}, {104, 
            115}, {104, 124}, {104, 128}, {104, 130}, {105, 115}, {105, 
            116}, {106, 118}, {106, 125}, {107, 122}, {107, 137}, {108, 
            116}, {108, 117}, {109, 129}, {109, 131}, {110, 112}, {110, 
            129}, {111, 121}, {111, 136}, {112, 120}, {112, 129}, {112, 
            144}, {112, 149}, {113, 127}, {113, 134}, {114, 124}, {114, 
            132}, {114, 145}, {115, 116}, {115, 130}, {115, 142}, {116, 
            117}, {116, 143}, {117, 125}, {117, 143}, {117, 154}, {118, 
            119}, {118, 125}, {118, 135}, {119, 131}, {119, 135}, {120, 
            121}, {120, 126}, {120, 149}, {121, 126}, {121, 136}, {121, 
            138}, {121, 139}, {122, 137}, {122, 150}, {123, 127}, {123, 
            132}, {123, 141}, {124, 128}, {124, 140}, {124, 145}, {125, 
            135}, {125, 154}, {125, 155}, {125, 162}, {126, 138}, {126, 
            149}, {127, 134}, {127, 141}, {128, 130}, {128, 140}, {129, 
            131}, {129, 133}, {129, 144}, {130, 140}, {130, 142}, {130, 
            146}, {130, 156}, {131, 133}, {131, 135}, {131, 147}, {131, 
            148}, {131, 158}, {132, 141}, {132, 145}, {132, 164}, {133, 
            144}, {133, 148}, {134, 141}, {134, 152}, {134, 153}, {135, 
            147}, {135, 155}, {136, 137}, {136, 139}, {136, 157}, {136, 
            159}, {137, 150}, {137, 159}, {137, 171}, {138, 139}, {138, 
            149}, {138, 157}, {138, 163}, {138, 170}, {139, 157}, {140, 
            145}, {140, 156}, {141, 153}, {141, 164}, {142, 143}, {142, 
            146}, {142, 151}, {143, 151}, {143, 154}, {144, 148}, {144, 
            149}, {144, 165}, {144, 169}, {145, 156}, {145, 160}, {145, 
            164}, {145, 188}, {146, 151}, {146, 156}, {146, 161}, {147, 
            155}, {147, 158}, {147, 167}, {148, 158}, {148, 168}, {148, 
            169}, {149, 163}, {149, 165}, {150, 171}, {151, 154}, {151, 
            161}, {151, 166}, {151, 175}, {152, 153}, {152, 172}, {152, 
            178}, {153, 164}, {153, 172}, {153, 176}, {154, 162}, {154, 
            166}, {155, 162}, {155, 167}, {155, 173}, {156, 160}, {156, 
            161}, {157, 159}, {157, 170}, {158, 167}, {158, 168}, {158, 
            179}, {159, 170}, {159, 171}, {159, 181}, {159, 182}, {160, 
            161}, {160, 186}, {160, 188}, {161, 175}, {161, 186}, {161, 
            190}, {162, 166}, {162, 173}, {162, 183}, {162, 184}, {163, 
            165}, {163, 170}, {163, 180}, {164, 176}, {164, 188}, {164, 
            201}, {165, 169}, {165, 177}, {165, 180}, {166, 175}, {166, 
            183}, {167, 173}, {167, 174}, {167, 179}, {168, 169}, {168, 
            179}, {169, 177}, {169, 179}, {169, 192}, {169, 193}, {170, 
            180}, {170, 181}, {171, 182}, {172, 176}, {172, 178}, {172, 
            185}, {173, 174}, {173, 184}, {173, 189}, {174, 179}, {174, 
            187}, {174, 189}, {175, 183}, {175, 190}, {175, 199}, {176, 
            185}, {176, 197}, {176, 201}, {177, 180}, {177, 193}, {177, 
            194}, {178, 185}, {178, 203}, {179, 187}, {179, 191}, {179, 
            192}, {180, 181}, {180, 194}, {180, 196}, {180, 204}, {181, 
            182}, {181, 196}, {181, 200}, {182, 200}, {183, 184}, {183, 
            195}, {183, 199}, {184, 189}, {184, 195}, {184, 202}, {185, 
            197}, {185, 203}, {185, 208}, {186, 188}, {186, 190}, {186, 
            198}, {187, 189}, {187, 191}, {187, 205}, {188, 198}, {188, 
            201}, {188, 218}, {189, 202}, {189, 205}, {190, 198}, {190, 
            199}, {190, 207}, {190, 215}, {191, 192}, {191, 205}, {191, 
            206}, {191, 216}, {192, 193}, {192, 206}, {193, 194}, {193, 
            206}, {194, 204}, {194, 206}, {195, 199}, {195, 202}, {195, 
            213}, {195, 222}, {196, 200}, {196, 204}, {196, 211}, {196, 
            214}, {197, 201}, {197, 208}, {197, 209}, {198, 215}, {198, 
            218}, {199, 207}, {199, 212}, {199, 222}, {200, 211}, {201, 
            209}, {201, 218}, {201, 220}, {202, 205}, {202, 210}, {202, 
            213}, {203, 208}, {203, 219}, {204, 206}, {204, 214}, {204, 
            217}, {205, 210}, {205, 216}, {205, 225}, {206, 216}, {206, 
            217}, {206, 221}, {207, 212}, {207, 215}, {208, 209}, {208, 
            219}, {208, 226}, {209, 220}, {209, 226}, {209, 227}, {210, 
            213}, {210, 224}, {210, 225}, {211, 214}, {212, 215}, {212, 
            222}, {212, 223}, {212, 230}, {213, 222}, {213, 224}, {214, 
            217}, {215, 218}, {215, 228}, {215, 230}, {215, 232}, {215, 
            233}, {215, 235}, {216, 221}, {216, 225}, {216, 234}, {217, 
            221}, {218, 220}, {218, 228}, {218, 229}, {219, 226}, {219, 
            237}, {220, 227}, {220, 229}, {222, 223}, {222, 224}, {222, 
            231}, {223, 230}, {223, 231}, {223, 236}, {223, 238}, {224, 
            225}, {224, 231}, {225, 231}, {225, 234}, {226, 227}, {226, 
            237}, {226, 239}, {227, 229}, {227, 239}, {228, 229}, {228, 
            235}, {228, 240}, {229, 239}, {229, 240}, {229, 242}, {230, 
            232}, {230, 236}, {230, 245}, {231, 234}, {231, 238}, {231, 
            244}, {232, 233}, {232, 245}, {233, 235}, {233, 241}, {233, 
            245}, {234, 244}, {235, 240}, {235, 241}, {235, 243}, {236, 
            238}, {236, 245}, {236, 248}, {237, 239}, {237, 249}, {238, 
            244}, {238, 246}, {238, 248}, {239, 242}, {239, 249}, {239, 
            250}, {240, 242}, {240, 243}, {240, 247}, {241, 243}, {241, 
            245}, {241, 247}, {241, 251}, {241, 253}, {242, 247}, {242, 
            250}, {242, 252}, {243, 247}, {244, 246}, {245, 248}, {245, 
            251}, {246, 248}, {247, 252}, {247, 253}, {249, 250}, {250, 
            252}, {251, 253}, {252, 253}}, 
      statistics \[Rule] {4.980874120493021`, 4.955522172284169`, 
          1.589759648983314`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cm = edges /. dt\)], "Input"],

Cell[BoxData[
    \({{1, 2}, {1, 3}, {1, 8}, {2, 4}, {2, 5}, {2, 8}, {3, 6}, {3, 7}, {3, 
        8}, {4, 5}, {4, 9}, {4, 10}, {5, 8}, {5, 9}, {5, 14}, {6, 7}, {6, 
        11}, {6, 12}, {6, 22}, {7, 8}, {7, 11}, {7, 13}, {8, 13}, {8, 
        14}, {8, 17}, {9, 10}, {9, 14}, {9, 18}, {9, 27}, {10, 18}, {10, 
        19}, {10, 28}, {11, 13}, {11, 22}, {11, 24}, {11, 25}, {11, 26}, {12, 
        16}, {12, 22}, {12, 30}, {13, 17}, {13, 26}, {13, 39}, {14, 17}, {14, 
        23}, {14, 27}, {14, 33}, {15, 20}, {15, 21}, {15, 29}, {15, 34}, {15, 
        35}, {16, 30}, {17, 23}, {17, 39}, {17, 53}, {17, 54}, {18, 27}, {18, 
        28}, {18, 31}, {19, 20}, {19, 28}, {19, 32}, {19, 38}, {19, 40}, {20, 
        34}, {20, 40}, {21, 29}, {21, 36}, {21, 47}, {22, 24}, {22, 37}, {22, 
        43}, {23, 33}, {23, 45}, {23, 54}, {24, 25}, {24, 37}, {25, 26}, {25, 
        37}, {25, 39}, {26, 39}, {27, 31}, {27, 33}, {28, 31}, {28, 32}, {28, 
        44}, {29, 35}, {29, 47}, {29, 49}, {29, 57}, {30, 43}, {30, 50}, {31, 
        33}, {31, 44}, {31, 46}, {32, 38}, {32, 44}, {33, 45}, {33, 46}, {34, 
        35}, {34, 40}, {34, 41}, {34, 51}, {34, 52}, {35, 41}, {35, 57}, {35, 
        60}, {36, 42}, {36, 47}, {36, 48}, {37, 39}, {37, 43}, {37, 59}, {38, 
        40}, {38, 44}, {38, 56}, {38, 67}, {39, 53}, {39, 59}, {39, 65}, {40, 
        51}, {40, 56}, {41, 52}, {41, 60}, {42, 48}, {42, 58}, {43, 50}, {43, 
        59}, {43, 61}, {43, 64}, {44, 46}, {44, 55}, {44, 66}, {44, 67}, {45, 
        46}, {45, 54}, {45, 75}, {46, 55}, {46, 68}, {46, 69}, {47, 48}, {47, 
        49}, {47, 63}, {48, 58}, {48, 63}, {48, 73}, {48, 77}, {49, 57}, {49, 
        63}, {49, 76}, {50, 61}, {50, 82}, {51, 52}, {51, 56}, {51, 71}, {51, 
        72}, {51, 84}, {52, 60}, {52, 72}, {53, 54}, {53, 65}, {53, 70}, {53, 
        74}, {54, 74}, {54, 75}, {55, 66}, {55, 69}, {55, 86}, {56, 62}, {56, 
        67}, {56, 71}, {57, 60}, {57, 76}, {57, 81}, {57, 85}, {58, 77}, {58, 
        78}, {59, 64}, {59, 65}, {59, 83}, {59, 87}, {60, 72}, {60, 80}, {60, 
        85}, {61, 64}, {61, 82}, {61, 89}, {61, 96}, {62, 67}, {62, 71}, {62, 
        79}, {63, 73}, {63, 76}, {64, 83}, {64, 96}, {65, 70}, {65, 87}, {65, 
        97}, {65, 100}, {66, 67}, {66, 79}, {66, 86}, {66, 91}, {67, 
        79}, {68, 69}, {68, 75}, {68, 94}, {69, 86}, {69, 94}, {69, 98}, {70, 
        74}, {70, 93}, {70, 97}, {71, 79}, {71, 84}, {72, 80}, {72, 84}, {72, 
        102}, {73, 76}, {73, 77}, {73, 92}, {74, 75}, {74, 90}, {74, 
        93}, {75, 90}, {75, 94}, {76, 81}, {76, 92}, {76, 95}, {77, 78}, {77, 
        92}, {77, 103}, {77, 107}, {78, 107}, {79, 84}, {79, 91}, {79, 
        99}, {79, 101}, {80, 85}, {80, 88}, {80, 102}, {80, 110}, {81, 
        85}, {81, 95}, {82, 89}, {82, 113}, {83, 87}, {83, 96}, {83, 
        100}, {83, 123}, {84, 101}, {84, 102}, {84, 109}, {85, 88}, {85, 
        95}, {86, 91}, {86, 98}, {86, 106}, {87, 100}, {88, 95}, {88, 
        110}, {88, 112}, {88, 120}, {89, 96}, {89, 113}, {90, 93}, {90, 
        105}, {90, 108}, {90, 116}, {91, 99}, {91, 106}, {91, 118}, {92, 
        95}, {92, 103}, {92, 111}, {93, 97}, {93, 104}, {93, 105}, {93, 
        115}, {94, 98}, {94, 108}, {94, 117}, {95, 111}, {95, 120}, {95, 
        121}, {96, 113}, {96, 123}, {96, 127}, {97, 100}, {97, 104}, {97, 
        124}, {98, 106}, {98, 117}, {98, 125}, {99, 101}, {99, 118}, {99, 
        119}, {100, 114}, {100, 123}, {100, 124}, {100, 132}, {101, 
        109}, {101, 119}, {101, 131}, {102, 109}, {102, 110}, {102, 
        129}, {103, 107}, {103, 111}, {103, 136}, {103, 137}, {104, 
        115}, {104, 124}, {104, 128}, {104, 130}, {105, 115}, {105, 
        116}, {106, 118}, {106, 125}, {107, 122}, {107, 137}, {108, 
        116}, {108, 117}, {109, 129}, {109, 131}, {110, 112}, {110, 
        129}, {111, 121}, {111, 136}, {112, 120}, {112, 129}, {112, 
        144}, {112, 149}, {113, 127}, {113, 134}, {114, 124}, {114, 
        132}, {114, 145}, {115, 116}, {115, 130}, {115, 142}, {116, 
        117}, {116, 143}, {117, 125}, {117, 143}, {117, 154}, {118, 
        119}, {118, 125}, {118, 135}, {119, 131}, {119, 135}, {120, 
        121}, {120, 126}, {120, 149}, {121, 126}, {121, 136}, {121, 
        138}, {121, 139}, {122, 137}, {122, 150}, {123, 127}, {123, 
        132}, {123, 141}, {124, 128}, {124, 140}, {124, 145}, {125, 
        135}, {125, 154}, {125, 155}, {125, 162}, {126, 138}, {126, 
        149}, {127, 134}, {127, 141}, {128, 130}, {128, 140}, {129, 
        131}, {129, 133}, {129, 144}, {130, 140}, {130, 142}, {130, 
        146}, {130, 156}, {131, 133}, {131, 135}, {131, 147}, {131, 
        148}, {131, 158}, {132, 141}, {132, 145}, {132, 164}, {133, 
        144}, {133, 148}, {134, 141}, {134, 152}, {134, 153}, {135, 
        147}, {135, 155}, {136, 137}, {136, 139}, {136, 157}, {136, 
        159}, {137, 150}, {137, 159}, {137, 171}, {138, 139}, {138, 
        149}, {138, 157}, {138, 163}, {138, 170}, {139, 157}, {140, 
        145}, {140, 156}, {141, 153}, {141, 164}, {142, 143}, {142, 
        146}, {142, 151}, {143, 151}, {143, 154}, {144, 148}, {144, 
        149}, {144, 165}, {144, 169}, {145, 156}, {145, 160}, {145, 
        164}, {145, 188}, {146, 151}, {146, 156}, {146, 161}, {147, 
        155}, {147, 158}, {147, 167}, {148, 158}, {148, 168}, {148, 
        169}, {149, 163}, {149, 165}, {150, 171}, {151, 154}, {151, 
        161}, {151, 166}, {151, 175}, {152, 153}, {152, 172}, {152, 
        178}, {153, 164}, {153, 172}, {153, 176}, {154, 162}, {154, 
        166}, {155, 162}, {155, 167}, {155, 173}, {156, 160}, {156, 
        161}, {157, 159}, {157, 170}, {158, 167}, {158, 168}, {158, 
        179}, {159, 170}, {159, 171}, {159, 181}, {159, 182}, {160, 
        161}, {160, 186}, {160, 188}, {161, 175}, {161, 186}, {161, 
        190}, {162, 166}, {162, 173}, {162, 183}, {162, 184}, {163, 
        165}, {163, 170}, {163, 180}, {164, 176}, {164, 188}, {164, 
        201}, {165, 169}, {165, 177}, {165, 180}, {166, 175}, {166, 
        183}, {167, 173}, {167, 174}, {167, 179}, {168, 169}, {168, 
        179}, {169, 177}, {169, 179}, {169, 192}, {169, 193}, {170, 
        180}, {170, 181}, {171, 182}, {172, 176}, {172, 178}, {172, 
        185}, {173, 174}, {173, 184}, {173, 189}, {174, 179}, {174, 
        187}, {174, 189}, {175, 183}, {175, 190}, {175, 199}, {176, 
        185}, {176, 197}, {176, 201}, {177, 180}, {177, 193}, {177, 
        194}, {178, 185}, {178, 203}, {179, 187}, {179, 191}, {179, 
        192}, {180, 181}, {180, 194}, {180, 196}, {180, 204}, {181, 
        182}, {181, 196}, {181, 200}, {182, 200}, {183, 184}, {183, 
        195}, {183, 199}, {184, 189}, {184, 195}, {184, 202}, {185, 
        197}, {185, 203}, {185, 208}, {186, 188}, {186, 190}, {186, 
        198}, {187, 189}, {187, 191}, {187, 205}, {188, 198}, {188, 
        201}, {188, 218}, {189, 202}, {189, 205}, {190, 198}, {190, 
        199}, {190, 207}, {190, 215}, {191, 192}, {191, 205}, {191, 
        206}, {191, 216}, {192, 193}, {192, 206}, {193, 194}, {193, 
        206}, {194, 204}, {194, 206}, {195, 199}, {195, 202}, {195, 
        213}, {195, 222}, {196, 200}, {196, 204}, {196, 211}, {196, 
        214}, {197, 201}, {197, 208}, {197, 209}, {198, 215}, {198, 
        218}, {199, 207}, {199, 212}, {199, 222}, {200, 211}, {201, 
        209}, {201, 218}, {201, 220}, {202, 205}, {202, 210}, {202, 
        213}, {203, 208}, {203, 219}, {204, 206}, {204, 214}, {204, 
        217}, {205, 210}, {205, 216}, {205, 225}, {206, 216}, {206, 
        217}, {206, 221}, {207, 212}, {207, 215}, {208, 209}, {208, 
        219}, {208, 226}, {209, 220}, {209, 226}, {209, 227}, {210, 
        213}, {210, 224}, {210, 225}, {211, 214}, {212, 215}, {212, 
        222}, {212, 223}, {212, 230}, {213, 222}, {213, 224}, {214, 
        217}, {215, 218}, {215, 228}, {215, 230}, {215, 232}, {215, 
        233}, {215, 235}, {216, 221}, {216, 225}, {216, 234}, {217, 
        221}, {218, 220}, {218, 228}, {218, 229}, {219, 226}, {219, 
        237}, {220, 227}, {220, 229}, {222, 223}, {222, 224}, {222, 
        231}, {223, 230}, {223, 231}, {223, 236}, {223, 238}, {224, 
        225}, {224, 231}, {225, 231}, {225, 234}, {226, 227}, {226, 
        237}, {226, 239}, {227, 229}, {227, 239}, {228, 229}, {228, 
        235}, {228, 240}, {229, 239}, {229, 240}, {229, 242}, {230, 
        232}, {230, 236}, {230, 245}, {231, 234}, {231, 238}, {231, 
        244}, {232, 233}, {232, 245}, {233, 235}, {233, 241}, {233, 
        245}, {234, 244}, {235, 240}, {235, 241}, {235, 243}, {236, 
        238}, {236, 245}, {236, 248}, {237, 239}, {237, 249}, {238, 
        244}, {238, 246}, {238, 248}, {239, 242}, {239, 249}, {239, 
        250}, {240, 242}, {240, 243}, {240, 247}, {241, 243}, {241, 
        245}, {241, 247}, {241, 251}, {241, 253}, {242, 247}, {242, 
        250}, {242, 252}, {243, 247}, {244, 246}, {245, 248}, {245, 
        251}, {246, 248}, {247, 252}, {247, 253}, {249, 250}, {250, 
        252}, {251, 253}, {252, 253}}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\ \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[cm]\)], "Input"],

Cell[BoxData[
    \(705\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(diffusionReaction[x_, {i_, j_}, DC_] := \ 
      Module[{LHS, RHS}, \[IndentingNewLine]LHS = 
          SIDify[x[i]]; \[IndentingNewLine]RHS = 
          SIDify[x[j]]; \[IndentingNewLine]addReaction[LHS \[Rule] \ RHS, \ 
          reversible \[Rule] \ False, \ 
          kineticLaw \[Rule] \ DC*\((LHS - RHS)\), 
          name \[Rule] \ "\<Diffusion of \>" <> 
              ToString[x] <> "\< from Cell \>" <> 
              ToString[i] <> "\< to Cell \>" <> 
              ToString[j]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(L1IC = 
        Table[If[MemberQ[sc, i], 1, 0], \ {i, 1, ncells}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", "\[IndentingNewLine]", 
      RowBox[{\(newModel["\<activator\>", echo \[Rule] \ False]\), ";", 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(addFunction[id \[Rule] \ Sigma, \ 
          arguments \[Rule] \ {x}, math \[Rule] sigma[x]\ ]\), ";", 
        "\[IndentingNewLine]", \(addUnit[id \[Rule] \ "\<length\>", 
          name \[Rule] \ "\<micron\>", 
          unit \[Rule] \ {"\<metre\>" \[Rule] \ {scale \[Rule] \ \(-6\)}}]\), 
        ";", " ", 
        "\[IndentingNewLine]", \(addUnit[id \[Rule] \ "\<area\>", 
          name \[Rule] \ "\<square microns\>", \ 
          unit \[Rule] \ {"\<metre\>" \[Rule] \ {scale \[Rule] \ \(-12\), \ 
                  exponent \[Rule] \ 2}}]\), ";", " ", 
        "\[IndentingNewLine]", \(addCompartment["\<meristem\>", \ 
          constant \[Rule] \ True, spatialDimensions \[Rule] \ 2, \ 
          size \[Rule] \ totalArea]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addCompartment[id \[Rule] \ #1, name \[Rule] \ #2, \ 
              outside \[Rule] meristem, size \[Rule] \ #3, 
              constant \[Rule] \ True] &, \[IndentingNewLine]{cells, \ 
            cellNames, \ areas}\[IndentingNewLine]]\), ";", 
        "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(MapThread[
          addSpecies[#1, compartment \[Rule] \ #2, \ name \[Rule] \ #3, 
              initialAmount \[Rule] \ 0] &, {As, cells, \ ANames}]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addSpecies[#1, compartment \[Rule] \ #2, \ name \[Rule] \ #3, \ 
              initialAmount \[Rule] \ 0] &, {Bs, cells, \ BNames}]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addSpecies[#1, compartment \[Rule] \ #2, \ name \[Rule] \ #3, 
              initialAmount \[Rule] \ 0] &, {Ws, cells, WNames}]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addSpecies[#1, compartment \[Rule] \ #2, name \[Rule] \ #3, \ 
              initialAmount \[Rule] \ 0] &, {Ys, cells, YNames}]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addSpecies[#1, compartment \[Rule] \ #2, \ 
              initialAmount \[Rule] \ #3, name \[Rule] \ #4, 
              constant \[Rule] \ True, \ 
              boundaryCondition \[Rule] \ True] &, {L1s, cells, \ L1IC, 
            L1Names}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(MapThread[
          addParameter[#1, \ value \[Rule] \ \ #2, \ 
              constant \[Rule] \ true] &, \ {First /@ rates, \ 
            Last /@ rates}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(MapThread[
          addParameter[#1, \ value \[Rule] \ \ #2, \ 
              units \[Rule] \ dimensionless, name \[Rule] \ #3, 
              constant \[Rule] \ true] &, \ {xs, \ First /@ xymeristem, \ 
            xnames}]\), ";", 
        "\[IndentingNewLine]", \(MapThread[
          addParameter[#1, \ value \[Rule] \ \ #2, \ 
              units \[Rule] \ dimensionless, name \[Rule] \ #3, 
              constant \[Rule] \ true] &, \ {ys, \ Last /@ xymeristem, \ 
            ynames}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \( (*\ intracellular\ reactions\ *) \), 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ \({Y[i] \[RightTeeArrow] W[i], 
                GRN[1/tauw, Twy, 1, hw, sigma]}\ {A[i] \[RightTeeArrow] 
                  W[i], \ GRN[1/tauw, Twa, 1, hw, sigma]}\)\(,\)*) \),
          Background->RGBColor[1, 1, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(MapThread[
          addReaction[products \[Rule] \ #1, \ 
              modifiers \[Rule] \ {#2, #3}, \ \ reversible \[Rule] \ False, 
              name \[Rule] \ "\<Activation/Inhibition of Wuschel by A and Y \
in Cell \>" <> ToString[#4], \[IndentingNewLine]kineticLaw \[Rule] \ 
                Sigma[hw + Twa*#2 + Twy*#3]/tauw] &, {Ws, As, Ys, 
            Range[ncells]}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ {W[i] \[ShortRightArrow] \[EmptySet], \ dw}\ *) \),
          Background->RGBColor[1, 1, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(MapThread[
          addReaction[reactants \[Rule] \ #1, reversible \[Rule] \ False, 
              name \[Rule] \ "\<Removal of Wus in Cell \>" <> 
                  ToString[#2], \[IndentingNewLine]kineticLaw \[Rule] \ 
                dw*#1] &, {Ws, Range[ncells]}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ {\[EmptySet] \[Rule] Y[i], \ 
                ky*L1[i]}\ \ uses\ fact\ that\ L1\ is\ a\ boundary\ condition\
\ *) \),
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], \(MapThread[
          addReaction[reactants \[Rule] \ #1, 
              products \[Rule] \ #2, \ \[IndentingNewLine]name \[Rule] \ \
"\<Production of Y in Cell \>" <> 
                  ToString[#3], \[IndentingNewLine]reversible \[Rule] \ 
                False, kineticLaw \[Rule] \ ky*#1] &, {L1s, \ Ys, 
            Range[ncells]}]\), ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
          StyleBox[\(Y[i] \[Rule] \ \[EmptySet], \ dy\),
            Background->RGBColor[1, 1, 0]], 
          StyleBox[" ",
            Background->RGBColor[1, 1, 0]], "*)"}], 
        "\[IndentingNewLine]", \(MapThread[
          addReaction[reactants \[Rule] \ #1, \ 
              reversible \[Rule] \ 
                False, \[IndentingNewLine]name \[Rule] \ "\<Removal of Y in \
Cell \>" <> ToString[#2], \[IndentingNewLine]kineticLaw \[Rule] \ 
                dy*#1] &, {Ys, Range[ncells]}]\), ";", 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], "\[IndentingNewLine]", 
        StyleBox[\( (*\ {\[EmptySet] \[Rule] \ A[i], a}\ *) \),
          Background->RGBColor[1, 1, 0]], 
        "\[IndentingNewLine]", \(MapThread[
          addReaction[products \[Rule] \ #1, \ 
              reversible \[Rule] \ 
                False, \[IndentingNewLine]name \[Rule] \ "\<Production of A \
in Cell \>" <> ToString[#2], \[IndentingNewLine]kineticLaw \[Rule] \ 
                a] &, {As, Range[ncells]}]\), ";", "\[IndentingNewLine]", 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], 
        StyleBox[\( (*\(\ \)\(A[i] \[Rule] \ {}, \ 
              beta + d*\(Y[i]\)[t]\)\(}\)*) \),
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], \(MapThread[
          addReaction[reactants \[Rule] \ #1, 
              modifiers \[Rule] \ #2, \ \[IndentingNewLine]name \[Rule] \ \
"\<Removal of A in Cell \>" <> ToString[#3], \[IndentingNewLine]\ 
              reversible \[Rule] \ False, 
              kineticLaw \[Rule] \ #1*\((beta + d*#2)\)] &, {As, Ys, 
            Range[ncells]}]\), ";", 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], 
        StyleBox[\( (*\ \({2  A[i] + B[i] \[ShortRightArrow] 3  A[i], 
              c}\)\(,\)\ *) \),
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], \(MapThread[
          addReaction[
              2  #1\  + #2\  \[Rule] \ 3\ #1, \ \ reversible \[Rule] \ 
                False, \[IndentingNewLine]name \[Rule] \ "\<Brusselator \
Conversion of B to A in Cell \>" <> 
                  ToString[#3], \[IndentingNewLine]kineticLaw \[Rule] \ 
                c*\((#1)\)\^2*\((#2)\)] &, {As, Bs, Range[ncells]}]\), ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        StyleBox[\( (*\ {A[i] \[ShortRightArrow] B[i], \ b}*) \),
          Background->RGBColor[1, 1, 0]], 
        "\[IndentingNewLine]", \(MapThread[
          addReaction[#1\  \[Rule] \ #2, \ \ reversible \[Rule] \ 
                False, \[IndentingNewLine]name \[Rule] \ "\<Brusselator \
Conversion of A to B in Cell \>" <> ToString[#3], \ 
              kineticLaw \[Rule] \ b*#1] &, {As, Bs, \ Range[ncells]}]\), ";",
         
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
          StyleBox[\(diffusion\ reactions\),
            Background->RGBColor[0, 1, 0]], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
          
          StyleBox[\({\ {Y[i] \[ShortRightArrow] Y[j], \ 
                Dy}, {A[i] \[ShortRightArrow] A[j], \ 
                Da}, {B[i] \[ShortRightArrow] B[j], \ Db}}\),
            Background->RGBColor[1, 1, 0]], 
          StyleBox[" ",
            Background->RGBColor[1, 1, 0]], "*)"}], "\[IndentingNewLine]", 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 0]], 
        StyleBox["\[IndentingNewLine]",
          Background->RGBColor[1, 1, 
          0]], \(\(diffusionReaction[Y, #, Dy] &\) /@ cm\), ";", 
        "\[IndentingNewLine]", \(\(diffusionReaction[A, #, Da] &\) /@ cm\), 
        ";", "\[IndentingNewLine]", \(\(diffusionReaction[B, #, Db] &\) /@ 
          cm\), ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Built-in unit: \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"length\"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1], FontWeight -> 
            "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\" redefined. \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Built-in unit: ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"], 
        StyleForm[ 
        "length", FontColor -> RGBColor[ 0, 0, 1], FontWeight -> "Bold"], 
        StyleForm[ 
        " redefined. ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Built-in unit: \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"area\"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1], FontWeight -> 
            "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\" redefined. \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Built-in unit: ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"], 
        StyleForm[ 
        "area", FontColor -> RGBColor[ 0, 0, 1], FontWeight -> "Bold"], 
        StyleForm[ 
        " redefined. ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({458.7560759999999`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Timing[
      createModel["\<desktop/WusActivator/activator.xml\>"]]\)\(\
\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    \({42.59409100000016`\ Second, 
      "desktop/WusActivator/activator.xml"}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Timing[
        m = SBMLRead["\<desktop/WusActivator/activator.xml\>", 
            stats \[Rule] \ True, 
            return \[Rule] \ {SBMLStoichiometryMatrix \[Rule] \ 
                  False}]];\)\)], "Input"],

Cell[BoxData[
    \("File Statistics"\)], "Output",
  TextAlignment->Left,
  FontFamily->"Times",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.502007],
  Background->GrayLevel[0.929686]],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              StyleBox["\<\"Description\"\>",
                FontFamily->"Times",
                FontSize->14,
                FontWeight->"Bold",
                FontColor->RGBColor[0.415686, 0.352895, 0.803906],
                FontVariations->{"Underline"->True}],
              (
              StyleForm[ #, FontWeight -> "Bold", FontVariations -> {
                "Underline" -> True}, FontFamily -> "Times", FontColor -> 
                RGBColor[ 
                0.41569299999999998, 0.35290100000000002, 
                  0.80390300000000003], FontSize -> 14]&)], 
            TagBox[
              StyleBox["\<\"Value\"\>",
                FontFamily->"Times",
                FontSize->14,
                FontWeight->"Bold",
                FontColor->RGBColor[0.415686, 0.352895, 0.803906],
                FontVariations->{"Underline"->True}],
              (
              StyleForm[ #, FontWeight -> "Bold", FontVariations -> {
                "Underline" -> True}, FontFamily -> "Times", FontColor -> 
                RGBColor[ 
                0.41569299999999998, 0.35290100000000002, 
                  0.80390300000000003], FontSize -> 14]&)]},
          {"\<\"Compartments\"\>", "254"},
          {"\<\"Species\"\>", "1265"},
          {"\<\"ODES\"\>", "1265"},
          {"\<\"Global Parameters\"\>", "522"},
          {"\<\"Local Parameters\"\>", "0"},
          {"\<\"Rules\"\>", "0"},
          {"\<\"Reactions\"\>", "4139"},
          {"\<\"Events\"\>", "0"},
          {"\<\"CPU Used\"\>", "1395.453454`"},
          {"\<\"Warnings\"\>", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Top,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableAlignments -> {Left, Top}]]]], "Output",
  TextAlignment->Left]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run a simulation using MathSBML", "Section"],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(m = loadSimulator[context \[Rule] \ "\<None\>"];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Built-in unit: \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"length\"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1], FontWeight -> 
            "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\" redefined. \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Built-in unit: ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"], 
        StyleForm[ 
        "length", FontColor -> RGBColor[ 0, 0, 1], FontWeight -> "Bold"], 
        StyleForm[ 
        " redefined. ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Built-in unit: \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"area\"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0, 1]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1], FontWeight -> 
            "Bold"]&)], "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\" redefined. \"\>",
            FontWeight->"Bold",
            FontColor->RGBColor[0.2, 0.900008, 0.6]],
          (
          StyleForm[ #, FontColor -> RGBColor[ 
            0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
            FontWeight -> "Bold"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Built-in unit: ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"], 
        StyleForm[ 
        "area", FontColor -> RGBColor[ 0, 0, 1], FontWeight -> "Bold"], 
        StyleForm[ 
        " redefined. ", FontColor -> RGBColor[ 
          0.20000000000000001, 0.90000000000000002, 0.59999999999999998], 
          FontWeight -> "Bold"]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cpu = TimeUsed[];\)\), "\[IndentingNewLine]", 
    \(\(sim = SBMLNDSolve[m, 1000];\)\), "\[IndentingNewLine]", 
    \(\(Print[TimeUsed[] - cpu, "\< seconds.\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\(98.73782200000005`\[InvisibleSpace]" seconds."\),
      SequenceForm[ 98.737822000000051, " seconds."],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WusVars = SIDify[Wus, ncells]\)], "Input"],

Cell[BoxData[
    \({Wus\[UnderBracket]1, Wus\[UnderBracket]2, Wus\[UnderBracket]3, 
      Wus\[UnderBracket]4, Wus\[UnderBracket]5, Wus\[UnderBracket]6, 
      Wus\[UnderBracket]7, Wus\[UnderBracket]8, Wus\[UnderBracket]9, 
      Wus\[UnderBracket]10, Wus\[UnderBracket]11, Wus\[UnderBracket]12, 
      Wus\[UnderBracket]13, Wus\[UnderBracket]14, Wus\[UnderBracket]15, 
      Wus\[UnderBracket]16, Wus\[UnderBracket]17, Wus\[UnderBracket]18, 
      Wus\[UnderBracket]19, Wus\[UnderBracket]20, Wus\[UnderBracket]21, 
      Wus\[UnderBracket]22, Wus\[UnderBracket]23, Wus\[UnderBracket]24, 
      Wus\[UnderBracket]25, Wus\[UnderBracket]26, Wus\[UnderBracket]27, 
      Wus\[UnderBracket]28, Wus\[UnderBracket]29, Wus\[UnderBracket]30, 
      Wus\[UnderBracket]31, Wus\[UnderBracket]32, Wus\[UnderBracket]33, 
      Wus\[UnderBracket]34, Wus\[UnderBracket]35, Wus\[UnderBracket]36, 
      Wus\[UnderBracket]37, Wus\[UnderBracket]38, Wus\[UnderBracket]39, 
      Wus\[UnderBracket]40, Wus\[UnderBracket]41, Wus\[UnderBracket]42, 
      Wus\[UnderBracket]43, Wus\[UnderBracket]44, Wus\[UnderBracket]45, 
      Wus\[UnderBracket]46, Wus\[UnderBracket]47, Wus\[UnderBracket]48, 
      Wus\[UnderBracket]49, Wus\[UnderBracket]50, Wus\[UnderBracket]51, 
      Wus\[UnderBracket]52, Wus\[UnderBracket]53, Wus\[UnderBracket]54, 
      Wus\[UnderBracket]55, Wus\[UnderBracket]56, Wus\[UnderBracket]57, 
      Wus\[UnderBracket]58, Wus\[UnderBracket]59, Wus\[UnderBracket]60, 
      Wus\[UnderBracket]61, Wus\[UnderBracket]62, Wus\[UnderBracket]63, 
      Wus\[UnderBracket]64, Wus\[UnderBracket]65, Wus\[UnderBracket]66, 
      Wus\[UnderBracket]67, Wus\[UnderBracket]68, Wus\[UnderBracket]69, 
      Wus\[UnderBracket]70, Wus\[UnderBracket]71, Wus\[UnderBracket]72, 
      Wus\[UnderBracket]73, Wus\[UnderBracket]74, Wus\[UnderBracket]75, 
      Wus\[UnderBracket]76, Wus\[UnderBracket]77, Wus\[UnderBracket]78, 
      Wus\[UnderBracket]79, Wus\[UnderBracket]80, Wus\[UnderBracket]81, 
      Wus\[UnderBracket]82, Wus\[UnderBracket]83, Wus\[UnderBracket]84, 
      Wus\[UnderBracket]85, Wus\[UnderBracket]86, Wus\[UnderBracket]87, 
      Wus\[UnderBracket]88, Wus\[UnderBracket]89, Wus\[UnderBracket]90, 
      Wus\[UnderBracket]91, Wus\[UnderBracket]92, Wus\[UnderBracket]93, 
      Wus\[UnderBracket]94, Wus\[UnderBracket]95, Wus\[UnderBracket]96, 
      Wus\[UnderBracket]97, Wus\[UnderBracket]98, Wus\[UnderBracket]99, 
      Wus\[UnderBracket]100, Wus\[UnderBracket]101, Wus\[UnderBracket]102, 
      Wus\[UnderBracket]103, Wus\[UnderBracket]104, Wus\[UnderBracket]105, 
      Wus\[UnderBracket]106, Wus\[UnderBracket]107, Wus\[UnderBracket]108, 
      Wus\[UnderBracket]109, Wus\[UnderBracket]110, Wus\[UnderBracket]111, 
      Wus\[UnderBracket]112, Wus\[UnderBracket]113, Wus\[UnderBracket]114, 
      Wus\[UnderBracket]115, Wus\[UnderBracket]116, Wus\[UnderBracket]117, 
      Wus\[UnderBracket]118, Wus\[UnderBracket]119, Wus\[UnderBracket]120, 
      Wus\[UnderBracket]121, Wus\[UnderBracket]122, Wus\[UnderBracket]123, 
      Wus\[UnderBracket]124, Wus\[UnderBracket]125, Wus\[UnderBracket]126, 
      Wus\[UnderBracket]127, Wus\[UnderBracket]128, Wus\[UnderBracket]129, 
      Wus\[UnderBracket]130, Wus\[UnderBracket]131, Wus\[UnderBracket]132, 
      Wus\[UnderBracket]133, Wus\[UnderBracket]134, Wus\[UnderBracket]135, 
      Wus\[UnderBracket]136, Wus\[UnderBracket]137, Wus\[UnderBracket]138, 
      Wus\[UnderBracket]139, Wus\[UnderBracket]140, Wus\[UnderBracket]141, 
      Wus\[UnderBracket]142, Wus\[UnderBracket]143, Wus\[UnderBracket]144, 
      Wus\[UnderBracket]145, Wus\[UnderBracket]146, Wus\[UnderBracket]147, 
      Wus\[UnderBracket]148, Wus\[UnderBracket]149, Wus\[UnderBracket]150, 
      Wus\[UnderBracket]151, Wus\[UnderBracket]152, Wus\[UnderBracket]153, 
      Wus\[UnderBracket]154, Wus\[UnderBracket]155, Wus\[UnderBracket]156, 
      Wus\[UnderBracket]157, Wus\[UnderBracket]158, Wus\[UnderBracket]159, 
      Wus\[UnderBracket]160, Wus\[UnderBracket]161, Wus\[UnderBracket]162, 
      Wus\[UnderBracket]163, Wus\[UnderBracket]164, Wus\[UnderBracket]165, 
      Wus\[UnderBracket]166, Wus\[UnderBracket]167, Wus\[UnderBracket]168, 
      Wus\[UnderBracket]169, Wus\[UnderBracket]170, Wus\[UnderBracket]171, 
      Wus\[UnderBracket]172, Wus\[UnderBracket]173, Wus\[UnderBracket]174, 
      Wus\[UnderBracket]175, Wus\[UnderBracket]176, Wus\[UnderBracket]177, 
      Wus\[UnderBracket]178, Wus\[UnderBracket]179, Wus\[UnderBracket]180, 
      Wus\[UnderBracket]181, Wus\[UnderBracket]182, Wus\[UnderBracket]183, 
      Wus\[UnderBracket]184, Wus\[UnderBracket]185, Wus\[UnderBracket]186, 
      Wus\[UnderBracket]187, Wus\[UnderBracket]188, Wus\[UnderBracket]189, 
      Wus\[UnderBracket]190, Wus\[UnderBracket]191, Wus\[UnderBracket]192, 
      Wus\[UnderBracket]193, Wus\[UnderBracket]194, Wus\[UnderBracket]195, 
      Wus\[UnderBracket]196, Wus\[UnderBracket]197, Wus\[UnderBracket]198, 
      Wus\[UnderBracket]199, Wus\[UnderBracket]200, Wus\[UnderBracket]201, 
      Wus\[UnderBracket]202, Wus\[UnderBracket]203, Wus\[UnderBracket]204, 
      Wus\[UnderBracket]205, Wus\[UnderBracket]206, Wus\[UnderBracket]207, 
      Wus\[UnderBracket]208, Wus\[UnderBracket]209, Wus\[UnderBracket]210, 
      Wus\[UnderBracket]211, Wus\[UnderBracket]212, Wus\[UnderBracket]213, 
      Wus\[UnderBracket]214, Wus\[UnderBracket]215, Wus\[UnderBracket]216, 
      Wus\[UnderBracket]217, Wus\[UnderBracket]218, Wus\[UnderBracket]219, 
      Wus\[UnderBracket]220, Wus\[UnderBracket]221, Wus\[UnderBracket]222, 
      Wus\[UnderBracket]223, Wus\[UnderBracket]224, Wus\[UnderBracket]225, 
      Wus\[UnderBracket]226, Wus\[UnderBracket]227, Wus\[UnderBracket]228, 
      Wus\[UnderBracket]229, Wus\[UnderBracket]230, Wus\[UnderBracket]231, 
      Wus\[UnderBracket]232, Wus\[UnderBracket]233, Wus\[UnderBracket]234, 
      Wus\[UnderBracket]235, Wus\[UnderBracket]236, Wus\[UnderBracket]237, 
      Wus\[UnderBracket]238, Wus\[UnderBracket]239, Wus\[UnderBracket]240, 
      Wus\[UnderBracket]241, Wus\[UnderBracket]242, Wus\[UnderBracket]243, 
      Wus\[UnderBracket]244, Wus\[UnderBracket]245, Wus\[UnderBracket]246, 
      Wus\[UnderBracket]247, Wus\[UnderBracket]248, Wus\[UnderBracket]249, 
      Wus\[UnderBracket]250, Wus\[UnderBracket]251, Wus\[UnderBracket]252, 
      Wus\[UnderBracket]253}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SBMLPlot[sim, WusVars, \ {0, 1000}, \ 
      holdLegend \[Rule] \ True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 1.0804 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[.01131 .12275 -18 -4.5 ]
[.01131 .12275 0 4.5 ]
[.01131 .23079 -18 -4.5 ]
[.01131 .23079 0 4.5 ]
[.01131 .33883 -18 -4.5 ]
[.01131 .33883 0 4.5 ]
[.01131 .44687 -18 -4.5 ]
[.01131 .44687 0 4.5 ]
[.01131 .55491 -18 -4.5 ]
[.01131 .55491 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(200)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(400)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(600)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(800)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12275 m
.03006 .12275 L
s
[(0.1)] .01131 .12275 1 0 Mshowa
.02381 .23079 m
.03006 .23079 L
s
[(0.2)] .01131 .23079 1 0 Mshowa
.02381 .33883 m
.03006 .33883 L
s
[(0.3)] .01131 .33883 1 0 Mshowa
.02381 .44687 m
.03006 .44687 L
s
[(0.4)] .01131 .44687 1 0 Mshowa
.02381 .55491 m
.03006 .55491 L
s
[(0.5)] .01131 .55491 1 0 Mshowa
.125 Mabswid
.02381 .03632 m
.02756 .03632 L
s
.02381 .05793 m
.02756 .05793 L
s
.02381 .07954 m
.02756 .07954 L
s
.02381 .10115 m
.02756 .10115 L
s
.02381 .14436 m
.02756 .14436 L
s
.02381 .16597 m
.02756 .16597 L
s
.02381 .18758 m
.02756 .18758 L
s
.02381 .20919 m
.02756 .20919 L
s
.02381 .2524 m
.02756 .2524 L
s
.02381 .27401 m
.02756 .27401 L
s
.02381 .29562 m
.02756 .29562 L
s
.02381 .31723 m
.02756 .31723 L
s
.02381 .36044 m
.02756 .36044 L
s
.02381 .38205 m
.02756 .38205 L
s
.02381 .40366 m
.02756 .40366 L
s
.02381 .42527 m
.02756 .42527 L
s
.02381 .46848 m
.02756 .46848 L
s
.02381 .49009 m
.02756 .49009 L
s
.02381 .5117 m
.02756 .5117 L
s
.02381 .53331 m
.02756 .53331 L
s
.02381 .57652 m
.02756 .57652 L
s
.02381 .59813 m
.02756 .59813 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01725 L
.02605 .01907 L
.02729 .0207 L
.02846 .02186 L
.02954 .02269 L
.03053 .0233 L
.03279 .02429 L
.03396 .02466 L
.03506 .02494 L
.03636 .02521 L
.03756 .02541 L
.04 .02572 L
.04134 .02584 L
.04262 .02594 L
.045 .02607 L
.04633 .02612 L
.04753 .02616 L
.04866 .02619 L
.04988 .02621 L
.05104 .02623 L
.0521 .02623 L
.05334 .02624 L
.0545 .02624 L
.05577 .02624 L
.05648 .02623 L
.05713 .02623 L
.05844 .02622 L
.05986 .0262 L
.06244 .02616 L
.06749 .02606 L
.07306 .02592 L
.08433 .02558 L
.10458 .0249 L
.14478 .02353 L
.18347 .02232 L
.22461 .02121 L
.26423 .02028 L
.30234 .01952 L
.3429 .01884 L
.38195 .01828 L
.42345 .01777 L
.46343 .01737 L
.5019 .01704 L
.54281 .01674 L
.58222 .0165 L
.6201 .0163 L
.66044 .01613 L
.69927 .01598 L
.74054 .01586 L
Mistroke
.78031 .01575 L
.81855 .01567 L
.85925 .0156 L
.89843 .01554 L
.94006 .01548 L
.97619 .01544 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.02499 .0176 L
.02605 .0196 L
.02729 .02131 L
.02846 .02249 L
.02954 .02331 L
.03053 .02391 L
.03162 .02442 L
.03279 .02486 L
.03396 .0252 L
.03506 .02547 L
.03756 .0259 L
.03891 .02607 L
.0402 .0262 L
.04147 .0263 L
.04262 .02637 L
.04376 .02643 L
.045 .02648 L
.0463 .02653 L
.04753 .02655 L
.04869 .02657 L
.04991 .02659 L
.05095 .02659 L
.0521 .0266 L
.05279 .02659 L
.05345 .02659 L
.05468 .02659 L
.05537 .02658 L
.05601 .02657 L
.05745 .02655 L
.05987 .02651 L
.06244 .02646 L
.07277 .02617 L
.08247 .02583 L
.10458 .02497 L
.14327 .02349 L
.18441 .02208 L
.22403 .02092 L
.26214 .01999 L
.3027 .01915 L
.34175 .01849 L
.38324 .01791 L
.42323 .01745 L
.46169 .01708 L
.50261 .01676 L
.54201 .0165 L
.5799 .0163 L
.62024 .01613 L
.65906 .01599 L
.70034 .01586 L
Mistroke
.7401 .01577 L
.77835 .01569 L
.81905 .01563 L
.85823 .01557 L
.89986 .01553 L
.93998 .01549 L
.97619 .01547 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.02499 .0176 L
.02605 .0196 L
.02729 .02131 L
.02846 .02249 L
.02954 .02332 L
.03053 .02391 L
.03162 .02443 L
.03279 .02487 L
.03396 .02521 L
.03506 .02548 L
.03756 .02592 L
.03891 .02609 L
.0402 .02621 L
.04147 .02632 L
.04262 .02639 L
.04376 .02645 L
.045 .0265 L
.0463 .02655 L
.04753 .02658 L
.04869 .0266 L
.04991 .02661 L
.05095 .02662 L
.0521 .02662 L
.05279 .02662 L
.05345 .02662 L
.05468 .02661 L
.05537 .02661 L
.05601 .0266 L
.05745 .02658 L
.05987 .02654 L
.06244 .02649 L
.07277 .0262 L
.08247 .02587 L
.10458 .02502 L
.14327 .02353 L
.18441 .02212 L
.22403 .02096 L
.26214 .02002 L
.3027 .01919 L
.34175 .01852 L
.38324 .01793 L
.42323 .01747 L
.46169 .0171 L
.50261 .01678 L
.54201 .01652 L
.5799 .01632 L
.62024 .01614 L
.65906 .016 L
.70034 .01588 L
Mistroke
.7401 .01578 L
.77835 .0157 L
.81905 .01564 L
.85823 .01558 L
.89986 .01554 L
.93998 .0155 L
.97619 .01547 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.02499 .01734 L
.02605 .01922 L
.02729 .02088 L
.02846 .02206 L
.02954 .0229 L
.03053 .02352 L
.03279 .02453 L
.03396 .02491 L
.03506 .0252 L
.03636 .02549 L
.03756 .0257 L
.04 .02602 L
.04134 .02616 L
.04262 .02626 L
.045 .02641 L
.04633 .02647 L
.04753 .02651 L
.04866 .02655 L
.04988 .02658 L
.05104 .0266 L
.0521 .02661 L
.05334 .02662 L
.0545 .02663 L
.05577 .02663 L
.05648 .02663 L
.05713 .02663 L
.05844 .02662 L
.05918 .02661 L
.05986 .02661 L
.06244 .02658 L
.06486 .02654 L
.06745 .02649 L
.07216 .02638 L
.08288 .02608 L
.10458 .02536 L
.14572 .02394 L
.18534 .02267 L
.22345 .02161 L
.26401 .02062 L
.30306 .01982 L
.34456 .01909 L
.38454 .0185 L
.423 .01802 L
.46392 .01759 L
.50333 .01725 L
.54121 .01697 L
.58155 .01671 L
.62038 .01651 L
.66165 .01633 L
Mistroke
.70141 .01618 L
.73966 .01607 L
.78036 .01596 L
.81954 .01588 L
.86117 .0158 L
.90129 .01574 L
.9399 .01569 L
.97619 .01565 L
Mfstroke
1 .119 0 r
.02381 .01472 m
.03279 .04791 L
.03793 .06396 L
.04262 .07587 L
.04758 .08553 L
.0503 .0896 L
.05288 .09272 L
.05511 .09491 L
.05747 .09676 L
.06006 .09831 L
.06244 .09937 L
.06378 .09982 L
.06505 .10016 L
.06619 .10041 L
.06743 .10061 L
.06814 .1007 L
.06878 .10077 L
.06952 .10082 L
.07021 .10086 L
.07145 .10088 L
.07215 .10088 L
.0728 .10086 L
.07396 .1008 L
.07505 .10071 L
.07624 .10059 L
.07751 .10042 L
.08012 .09998 L
.0825 .09948 L
.09384 .09624 L
.10458 .09242 L
.14291 .07774 L
.18369 .06397 L
.22296 .05331 L
.26071 .04524 L
.30091 .03855 L
.3396 .03358 L
.38074 .02954 L
.42036 .02658 L
.45847 .02438 L
.49903 .0226 L
.53808 .02129 L
.57958 .02023 L
.61956 .01945 L
.65802 .01888 L
.69894 .01842 L
.73835 .01808 L
.77623 .01782 L
.81657 .01762 L
.8554 .01747 L
.89667 .01735 L
Mistroke
.93643 .01726 L
.97468 .01719 L
.97619 .01719 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.02499 .01708 L
.02605 .01882 L
.02721 .02031 L
.02846 .02158 L
.02961 .02249 L
.03068 .02317 L
.03279 .02416 L
.03396 .02458 L
.03506 .0249 L
.03636 .02522 L
.03756 .02546 L
.04 .02584 L
.04262 .02613 L
.04514 .02633 L
.04748 .02647 L
.05004 .02657 L
.05148 .02661 L
.05278 .02664 L
.05394 .02667 L
.05517 .02668 L
.05581 .02669 L
.05652 .0267 L
.05776 .02671 L
.05893 .02671 L
.06018 .02671 L
.06137 .02671 L
.06244 .02671 L
.06369 .0267 L
.06505 .02669 L
.06783 .02666 L
.07281 .02659 L
.08408 .02634 L
.10458 .02577 L
.14478 .02452 L
.18347 .02337 L
.22461 .02226 L
.26423 .02131 L
.30234 .02052 L
.3429 .01978 L
.38195 .01917 L
.42345 .01861 L
.46343 .01815 L
.5019 .01777 L
.54281 .01742 L
.58222 .01714 L
.6201 .0169 L
.66044 .01669 L
.69927 .01651 L
.74054 .01635 L
Mistroke
.78031 .01622 L
.81855 .01611 L
.85925 .01601 L
.89843 .01593 L
.94006 .01586 L
.97619 .01581 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.03279 .05 L
.03793 .06702 L
.04262 .07967 L
.04758 .08992 L
.0503 .09426 L
.05288 .09758 L
.05511 .09991 L
.05747 .10189 L
.06006 .10355 L
.06244 .10467 L
.06378 .10515 L
.06505 .10552 L
.06619 .10578 L
.06743 .10599 L
.06814 .10608 L
.06878 .10615 L
.06952 .10621 L
.07021 .10624 L
.07145 .10626 L
.07215 .10625 L
.0728 .10623 L
.07396 .10616 L
.07505 .10606 L
.07624 .10592 L
.07751 .10572 L
.0825 .10468 L
.08843 .10295 L
.09405 .10099 L
.10458 .09682 L
.14291 .0806 L
.18369 .06554 L
.22296 .05405 L
.26071 .04544 L
.30091 .03842 L
.3396 .03328 L
.38074 .02916 L
.42036 .02619 L
.45847 .02402 L
.49903 .02228 L
.53808 .02102 L
.57958 .02001 L
.61956 .01929 L
.65802 .01876 L
.69894 .01834 L
.73835 .01803 L
.77623 .01781 L
.81657 .01763 L
.8554 .0175 L
.89667 .0174 L
Mistroke
.93643 .01732 L
.97468 .01727 L
.97619 .01727 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.03279 .03792 L
.03793 .04921 L
.04262 .05764 L
.04758 .06456 L
.05012 .06734 L
.05288 .06984 L
.05544 .07172 L
.0578 .07313 L
.06022 .0743 L
.06244 .07515 L
.06487 .07588 L
.06747 .07646 L
.06862 .07665 L
.06988 .07683 L
.07106 .07697 L
.07218 .07707 L
.07286 .07712 L
.07359 .07717 L
.07487 .07723 L
.07559 .07725 L
.07636 .07726 L
.07702 .07727 L
.07774 .07727 L
.07902 .07725 L
.07975 .07723 L
.08041 .07721 L
.08169 .07715 L
.0829 .07708 L
.08551 .07688 L
.08829 .07661 L
.09328 .076 L
.10458 .07421 L
.14233 .06673 L
.18253 .05881 L
.22122 .05205 L
.26236 .04592 L
.30199 .04096 L
.34009 .03696 L
.38065 .03341 L
.4197 .03057 L
.4612 .02807 L
.50118 .02609 L
.53965 .02452 L
.58056 .02313 L
.61997 .02203 L
.65785 .02115 L
.69819 .02038 L
.73702 .01976 L
.7783 .01923 L
Mistroke
.81806 .0188 L
.8563 .01846 L
.897 .01817 L
.93618 .01793 L
.97619 .01774 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.03279 .03954 L
.04262 .06302 L
.04758 .07271 L
.05288 .0813 L
.05785 .08771 L
.06244 .09231 L
.06788 .09634 L
.07075 .09792 L
.07379 .09926 L
.07642 .10016 L
.07889 .10082 L
.08159 .10135 L
.08312 .10157 L
.08451 .10173 L
.08574 .10184 L
.08706 .10193 L
.0883 .10198 L
.08943 .102 L
.09012 .102 L
.09076 .102 L
.09145 .10199 L
.09219 .10197 L
.09343 .10192 L
.09414 .10189 L
.0948 .10185 L
.09727 .10165 L
.09952 .10142 L
.10458 .10072 L
.11449 .09884 L
.12366 .09669 L
.14443 .09112 L
.18369 .0801 L
.22144 .07032 L
.26165 .06128 L
.30033 .05391 L
.34147 .04737 L
.3811 .04216 L
.41921 .038 L
.45977 .03435 L
.49881 .03145 L
.54031 .02893 L
.58029 .02695 L
.61876 .02538 L
.65968 .02401 L
.69908 .02293 L
.73697 .02208 L
.77731 .02134 L
.81613 .02075 L
.85741 .02025 L
Mistroke
.89717 .01985 L
.93541 .01954 L
.97611 .01926 L
.97619 .01926 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.02605 .01751 L
.02846 .01976 L
.03072 .02133 L
.03279 .02239 L
.03521 .02334 L
.03784 .0241 L
.04032 .02464 L
.04262 .02503 L
.0472 .02559 L
.0498 .02582 L
.05224 .026 L
.05716 .02625 L
.05992 .02635 L
.06244 .02643 L
.06504 .02649 L
.0678 .02654 L
.07041 .02657 L
.07277 .02659 L
.07422 .0266 L
.07556 .02661 L
.07632 .02661 L
.07703 .02662 L
.07777 .02662 L
.07858 .02662 L
.07929 .02662 L
.07996 .02662 L
.08122 .02662 L
.08192 .02662 L
.08257 .02662 L
.08329 .02662 L
.08405 .02661 L
.08647 .02661 L
.08908 .02659 L
.09381 .02656 L
.09943 .0265 L
.10458 .02644 L
.1442 .0258 L
.18231 .02506 L
.22287 .02428 L
.26192 .02355 L
.30342 .02282 L
.3434 .02218 L
.38186 .0216 L
.42278 .02104 L
.46219 .02055 L
.50007 .02012 L
.54041 .0197 L
.57924 .01933 L
.62051 .01898 L
Mistroke
.66027 .01867 L
.69852 .0184 L
.73922 .01814 L
.7784 .01791 L
.82003 .0177 L
.86015 .01751 L
.89876 .01735 L
.93981 .01719 L
.97619 .01706 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.03279 .04673 L
.04262 .07774 L
.05288 .10343 L
.06244 .12046 L
.06792 .12736 L
.0731 .13219 L
.07775 .1353 L
.08038 .13661 L
.0828 .13757 L
.0854 .13834 L
.08783 .13885 L
.08923 .13906 L
.0905 .13921 L
.09121 .13926 L
.09197 .13931 L
.0927 .13934 L
.09337 .13936 L
.09408 .13936 L
.09484 .13936 L
.09556 .13934 L
.09622 .13931 L
.09747 .13923 L
.0981 .13918 L
.0988 .13911 L
.10179 .13871 L
.10458 .13821 L
.10959 .13701 L
.11503 .13536 L
.12493 .1317 L
.14349 .12354 L
.18427 .10438 L
.22354 .08769 L
.26129 .0742 L
.30149 .0625 L
.34018 .0535 L
.38132 .04592 L
.42094 .0402 L
.45905 .03585 L
.49961 .03222 L
.53866 .02949 L
.58015 .02723 L
.62014 .02554 L
.6586 .02426 L
.69952 .02321 L
.73892 .02241 L
.77681 .02182 L
.81715 .02132 L
.85598 .02094 L
.89725 .02064 L
Mistroke
.93701 .02041 L
.97526 .02024 L
.97619 .02023 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.02499 .01715 L
.02605 .01892 L
.02729 .02051 L
.02846 .02167 L
.03053 .02312 L
.0317 .02371 L
.03279 .02414 L
.03506 .02482 L
.03635 .0251 L
.03756 .02532 L
.04 .02564 L
.04136 .02578 L
.04262 .02588 L
.04384 .02596 L
.04514 .02604 L
.04748 .02613 L
.04891 .02617 L
.05026 .0262 L
.05147 .02622 L
.05278 .02623 L
.05395 .02624 L
.05523 .02625 L
.05587 .02625 L
.05657 .02624 L
.05781 .02624 L
.05906 .02623 L
.06024 .02622 L
.06244 .02619 L
.06753 .02611 L
.07293 .02598 L
.08263 .02572 L
.10458 .02502 L
.14233 .02378 L
.18253 .02254 L
.22122 .0215 L
.26236 .02053 L
.30199 .01973 L
.34009 .01907 L
.38065 .01847 L
.4197 .01798 L
.4612 .01753 L
.50118 .01717 L
.53965 .01687 L
.58056 .0166 L
.61997 .01638 L
.65785 .0162 L
.69819 .01604 L
.73702 .0159 L
.7783 .01579 L
Mistroke
.81806 .01569 L
.8563 .01561 L
.897 .01554 L
.93618 .01548 L
.97619 .01543 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.04262 .06266 L
.06244 .10672 L
.07216 .1242 L
.08255 .13921 L
.08852 .14603 L
.09396 .15112 L
.09911 .15502 L
.10458 .15824 L
.10932 .16033 L
.11183 .1612 L
.11454 .16197 L
.11701 .16252 L
.11928 .16291 L
.12037 .16306 L
.12156 .1632 L
.1226 .1633 L
.12373 .16339 L
.12446 .16343 L
.12514 .16346 L
.12578 .16349 L
.12646 .1635 L
.12764 .16352 L
.12894 .1635 L
.12967 .16349 L
.13033 .16346 L
.1311 .16343 L
.13182 .16339 L
.1345 .16318 L
.13699 .1629 L
.1393 .16258 L
.14451 .16164 L
.15414 .1593 L
.16317 .15654 L
.18378 .14904 L
.22246 .13321 L
.2636 .11676 L
.30323 .10247 L
.34134 .09042 L
.3819 .07938 L
.42094 .07033 L
.46244 .06221 L
.50242 .05565 L
.54089 .05033 L
.58181 .04559 L
.62121 .04177 L
.6591 .03869 L
.69944 .03594 L
.73826 .03374 L
.77954 .03179 L
Mistroke
.8193 .03023 L
.85754 .02897 L
.89824 .02787 L
.93742 .02698 L
.97619 .02626 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.04262 .0743 L
.06244 .12688 L
.07286 .14774 L
.08255 .16232 L
.08813 .1686 L
.0932 .17307 L
.096 .17507 L
.09905 .17688 L
.10171 .17817 L
.10458 .17928 L
.10712 .18003 L
.10945 .18055 L
.11057 .18074 L
.11179 .18091 L
.11295 .18103 L
.11402 .18112 L
.11467 .18115 L
.11538 .18118 L
.11666 .1812 L
.11791 .18118 L
.11905 .18113 L
.1203 .18105 L
.12166 .18092 L
.12309 .18075 L
.12442 .18056 L
.12973 .17948 L
.13457 .17813 L
.14545 .17413 L
.18529 .15378 L
.22362 .13278 L
.2644 .11259 L
.30367 .09603 L
.34142 .08272 L
.38162 .07104 L
.42031 .06189 L
.46145 .05402 L
.50107 .04793 L
.53918 .0432 L
.57974 .03914 L
.61879 .036 L
.66029 .03334 L
.70027 .0313 L
.73874 .02973 L
.77965 .02839 L
.81906 .02736 L
.85694 .02657 L
.89728 .02589 L
.93611 .02538 L
.97619 .02496 L
Mistroke
Mfstroke
1 .356 0 r
.02381 .01472 m
.02499 .01661 L
.02605 .01808 L
.02721 .01941 L
.02846 .02059 L
.03068 .02219 L
.03279 .02326 L
.03527 .02417 L
.0379 .02485 L
.04014 .02528 L
.04262 .02564 L
.04519 .02593 L
.04755 .02613 L
.05027 .02631 L
.05285 .02644 L
.05523 .02653 L
.05744 .0266 L
.05986 .02666 L
.06244 .0267 L
.06383 .02671 L
.06529 .02673 L
.06654 .02674 L
.06725 .02674 L
.06791 .02674 L
.06868 .02675 L
.0694 .02675 L
.07006 .02675 L
.07076 .02675 L
.07153 .02675 L
.07235 .02675 L
.07305 .02674 L
.07382 .02674 L
.07521 .02673 L
.07648 .02673 L
.07935 .02671 L
.08454 .02665 L
.0943 .02651 L
.10458 .02632 L
.14269 .02546 L
.18325 .02448 L
.22229 .02358 L
.26379 .02269 L
.30377 .02192 L
.34224 .02124 L
.38316 .0206 L
.42256 .02004 L
.46045 .01957 L
.50079 .01912 L
.53961 .01873 L
.58089 .01837 L
Mistroke
.62065 .01806 L
.6589 .01779 L
.69959 .01754 L
.73878 .01733 L
.78041 .01713 L
.82053 .01697 L
.85913 .01682 L
.90019 .01669 L
.93973 .01658 L
.97619 .01648 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.02499 .01752 L
.02605 .01947 L
.02729 .02114 L
.02846 .0223 L
.02954 .0231 L
.03053 .02368 L
.03163 .02418 L
.03279 .02459 L
.03395 .02492 L
.0352 .0252 L
.03746 .02556 L
.03884 .02571 L
.04016 .02583 L
.04133 .02591 L
.04262 .02598 L
.04396 .02603 L
.04523 .02607 L
.04636 .02609 L
.04759 .02611 L
.04823 .02612 L
.04894 .02612 L
.04967 .02612 L
.05036 .02612 L
.05158 .02612 L
.0529 .02611 L
.05413 .0261 L
.05546 .02608 L
.05789 .02603 L
.06244 .02592 L
.07306 .02559 L
.08433 .02517 L
.10458 .02437 L
.14233 .02293 L
.18253 .02159 L
.22122 .02049 L
.26236 .01951 L
.30199 .01873 L
.34009 .01811 L
.38065 .01755 L
.4197 .01711 L
.4612 .01673 L
.50118 .01643 L
.53965 .01618 L
.58056 .01597 L
.61997 .0158 L
.65785 .01567 L
.69819 .01555 L
.73702 .01546 L
.7783 .01538 L
Mistroke
.81806 .01531 L
.8563 .01526 L
.897 .01522 L
.93618 .01518 L
.97619 .01515 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.04262 .06328 L
.06244 .10977 L
.08426 .15173 L
.0949 .1678 L
.10458 .17973 L
.11403 .18893 L
.12297 .19551 L
.12755 .19814 L
.1324 .20042 L
.13772 .20236 L
.14264 .20366 L
.14516 .20416 L
.14755 .20454 L
.1497 .2048 L
.15091 .20491 L
.15205 .205 L
.15269 .20504 L
.15338 .20508 L
.15459 .20512 L
.15527 .20514 L
.156 .20515 L
.1573 .20516 L
.1585 .20514 L
.15962 .20511 L
.16085 .20506 L
.16217 .20498 L
.16453 .2048 L
.16709 .20452 L
.17174 .20384 L
.17628 .20298 L
.18047 .20203 L
.19914 .19635 L
.21974 .18822 L
.25994 .16995 L
.29863 .15208 L
.33977 .13437 L
.37939 .11913 L
.4175 .10625 L
.45806 .09438 L
.49711 .08459 L
.5386 .07574 L
.57859 .06854 L
.61705 .06267 L
.65797 .0574 L
.69737 .05315 L
.73526 .04969 L
.7756 .0466 L
.81443 .04411 L
.8557 .0419 L
Mistroke
.89546 .04013 L
.93371 .03871 L
.97441 .03746 L
.97619 .03741 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.04262 .0779 L
.0522 .10407 L
.06244 .12608 L
.0679 .13515 L
.07286 .14188 L
.0779 .1473 L
.08255 .15115 L
.08798 .1544 L
.09084 .15562 L
.09388 .15659 L
.09514 .15691 L
.09651 .15719 L
.09768 .15739 L
.09897 .15755 L
.09975 .15763 L
.10047 .15769 L
.10116 .15774 L
.1019 .15777 L
.10262 .15779 L
.10331 .15779 L
.10458 .15777 L
.10574 .15772 L
.10699 .15764 L
.10816 .15753 L
.10923 .1574 L
.11186 .157 L
.11434 .15651 L
.11928 .15526 L
.12466 .15354 L
.14313 .14575 L
.18391 .12476 L
.22318 .1053 L
.26093 .08916 L
.30113 .07495 L
.33982 .06389 L
.38096 .0545 L
.42058 .04735 L
.45869 .04189 L
.49925 .03729 L
.5383 .03381 L
.5798 .03092 L
.61978 .02874 L
.65824 .02709 L
.69916 .02571 L
.73857 .02467 L
.77645 .02389 L
.81679 .02323 L
.85562 .02274 L
.89689 .02233 L
Mistroke
.93666 .02202 L
.9749 .02179 L
.97619 .02178 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.02605 .01746 L
.02846 .01969 L
.03072 .02125 L
.03279 .02234 L
.03521 .02331 L
.03784 .0241 L
.04032 .02468 L
.04262 .0251 L
.0472 .02571 L
.0498 .02597 L
.05224 .02617 L
.05716 .02647 L
.05992 .0266 L
.06244 .02669 L
.06504 .02677 L
.0678 .02684 L
.07019 .02688 L
.07277 .02692 L
.07436 .02694 L
.07582 .02696 L
.07718 .02697 L
.07869 .02698 L
.07994 .02699 L
.08129 .027 L
.08204 .027 L
.08272 .027 L
.08335 .027 L
.08405 .02701 L
.08532 .02701 L
.08601 .02701 L
.08667 .02701 L
.08784 .02701 L
.0891 .02701 L
.08976 .027 L
.09049 .027 L
.09196 .027 L
.09459 .02699 L
.09709 .02697 L
.09977 .02695 L
.10458 .02691 L
.11482 .0268 L
.12593 .02666 L
.14608 .02634 L
.187 .02561 L
.2264 .02487 L
.26429 .02418 L
.30463 .02349 L
.34345 .02286 L
.38473 .02224 L
Mistroke
.42449 .02168 L
.46273 .0212 L
.50343 .02072 L
.54261 .0203 L
.58425 .0199 L
.62437 .01954 L
.66297 .01923 L
.70402 .01893 L
.74356 .01867 L
.78159 .01844 L
.82206 .01821 L
.86102 .01802 L
.90244 .01783 L
.94234 .01767 L
.97619 .01755 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.02605 .01786 L
.02729 .01921 L
.02846 .02028 L
.03072 .02187 L
.03279 .02293 L
.03524 .02384 L
.0375 .02446 L
.03998 .02497 L
.04262 .02537 L
.04496 .02564 L
.04749 .02588 L
.04967 .02603 L
.05205 .02617 L
.05483 .02629 L
.05748 .02638 L
.06005 .02645 L
.06244 .02649 L
.06509 .02653 L
.06658 .02654 L
.06795 .02655 L
.06916 .02656 L
.07048 .02656 L
.07114 .02656 L
.07185 .02657 L
.07314 .02657 L
.07439 .02656 L
.07509 .02656 L
.07575 .02656 L
.07694 .02656 L
.07821 .02655 L
.08041 .02653 L
.08284 .02651 L
.08824 .02646 L
.09405 .02638 L
.10458 .02621 L
.14572 .02535 L
.18534 .02447 L
.22345 .02364 L
.26401 .02282 L
.30306 .02209 L
.34456 .02139 L
.38454 .02078 L
.423 .02025 L
.46392 .01975 L
.50333 .01931 L
.54121 .01893 L
.58155 .01857 L
.62038 .01827 L
.66165 .01797 L
Mistroke
.70141 .01772 L
.73966 .0175 L
.78036 .0173 L
.81954 .01712 L
.86117 .01696 L
.90129 .01681 L
.9399 .01669 L
.97619 .01659 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.02499 .01706 L
.02605 .01879 L
.02721 .02027 L
.02846 .02153 L
.02961 .02243 L
.03068 .0231 L
.03279 .02409 L
.03396 .0245 L
.03506 .02482 L
.03636 .02513 L
.03756 .02537 L
.04 .02574 L
.04262 .02602 L
.04514 .02621 L
.04748 .02634 L
.04882 .0264 L
.05004 .02644 L
.05147 .02648 L
.05278 .02651 L
.05394 .02652 L
.05517 .02654 L
.0564 .02655 L
.0571 .02656 L
.05776 .02656 L
.05894 .02656 L
.06002 .02656 L
.06127 .02656 L
.06244 .02655 L
.06369 .02654 L
.06486 .02653 L
.06753 .0265 L
.07293 .02641 L
.08263 .0262 L
.10458 .02559 L
.14327 .02439 L
.18441 .02317 L
.22403 .02212 L
.26214 .02122 L
.3027 .02039 L
.34175 .0197 L
.38324 .01906 L
.42323 .01853 L
.46169 .0181 L
.50261 .0177 L
.54201 .01737 L
.5799 .0171 L
.62024 .01685 L
.65906 .01665 L
.70034 .01646 L
Mistroke
.7401 .01631 L
.77835 .01619 L
.81905 .01607 L
.85823 .01598 L
.89986 .01589 L
.93998 .01582 L
.97619 .01577 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.03279 .05051 L
.04262 .08139 L
.04758 .09258 L
.0503 .09748 L
.05288 .10135 L
.05528 .10435 L
.05789 .10699 L
.06008 .10878 L
.06244 .1103 L
.06381 .11101 L
.06506 .11156 L
.06751 .1124 L
.06887 .11273 L
.06959 .11287 L
.07036 .113 L
.0711 .1131 L
.07177 .11317 L
.07308 .11326 L
.07379 .11328 L
.07453 .11329 L
.07517 .11328 L
.07587 .11326 L
.07662 .11322 L
.07743 .11316 L
.07888 .11301 L
.08035 .1128 L
.08175 .11256 L
.08435 .11201 L
.08939 .11063 L
.09404 .10908 L
.10458 .10492 L
.14385 .0873 L
.1816 .07196 L
.2218 .05878 L
.26049 .04892 L
.30163 .04091 L
.34125 .03509 L
.37936 .03083 L
.41992 .02741 L
.45897 .02493 L
.50046 .02296 L
.54045 .02154 L
.57891 .02051 L
.61983 .01969 L
.65923 .01909 L
.69712 .01866 L
.73746 .01831 L
.77628 .01805 L
.81756 .01785 L
Mistroke
.85732 .0177 L
.89557 .0176 L
.93627 .01751 L
.97545 .01745 L
.97619 .01745 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.06244 .1237 L
.08255 .17289 L
.10458 .21862 L
.12507 .25221 L
.14415 .27515 L
.15465 .28435 L
.16457 .29091 L
.17348 .29514 L
.1785 .29687 L
.18314 .29807 L
.18558 .29856 L
.1878 .29892 L
.18903 .29908 L
.19037 .29923 L
.19165 .29935 L
.19281 .29944 L
.19398 .29951 L
.19509 .29956 L
.19625 .29958 L
.19751 .29959 L
.19861 .29958 L
.19978 .29955 L
.20078 .29951 L
.20187 .29946 L
.20325 .29936 L
.20456 .29924 L
.20702 .29897 L
.20966 .29859 L
.21254 .29809 L
.2225 .29566 L
.23189 .29249 L
.24227 .28818 L
.26328 .27749 L
.30348 .25288 L
.34217 .22779 L
.38331 .20225 L
.42293 .1799 L
.46104 .16086 L
.5016 .14326 L
.54065 .12876 L
.58214 .1157 L
.62213 .10513 L
.66059 .09658 L
.70151 .08898 L
.74091 .08289 L
.7788 .07802 L
.81914 .07371 L
.85797 .07029 L
.89924 .06732 L
Mistroke
.939 .06499 L
.97619 .06322 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.04262 .13039 L
.0522 .17921 L
.06244 .22171 L
.0679 .23986 L
.07286 .25362 L
.0779 .26495 L
.08255 .27307 L
.08514 .27666 L
.08798 .27987 L
.09084 .28236 L
.09243 .28343 L
.09388 .28422 L
.09524 .28482 L
.09654 .28525 L
.09725 .28543 L
.09791 .28556 L
.09863 .28567 L
.0994 .28574 L
.10007 .28577 L
.1008 .28577 L
.10212 .28568 L
.1034 .28547 L
.10458 .28519 L
.10584 .2848 L
.10704 .28435 L
.10928 .28327 L
.11432 .27993 L
.11867 .27615 L
.1234 .27126 L
.14407 .24394 L
.18485 .18402 L
.22412 .13625 L
.26187 .10242 L
.28121 .08906 L
.30207 .07715 L
.32172 .06793 L
.34321 .05968 L
.38283 .04837 L
.40244 .04422 L
.42339 .04059 L
.44331 .03777 L
.46489 .03527 L
.50487 .03182 L
.52475 .03054 L
.54579 .02942 L
.58368 .02787 L
.60313 .02726 L
.62402 .02672 L
.6653 .02589 L
Mistroke
.70506 .02532 L
.7433 .02493 L
.784 .02462 L
.82318 .02441 L
.86482 .02424 L
.90494 .02413 L
.94354 .02405 L
.97619 .024 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.04262 .09516 L
.06244 .16875 L
.08255 .22711 L
.09396 .25163 L
.09905 .26047 L
.10458 .26859 L
.11004 .27513 L
.11508 .2799 L
.11989 .28337 L
.12232 .28473 L
.125 .28595 L
.12741 .28679 L
.12962 .28736 L
.13084 .28759 L
.13148 .2877 L
.13217 .28779 L
.13342 .28791 L
.13459 .28798 L
.13575 .28799 L
.13701 .28796 L
.1382 .28788 L
.1393 .28776 L
.14029 .28763 L
.14138 .28744 L
.14357 .28696 L
.14608 .28624 L
.14881 .28527 L
.15378 .28301 L
.16308 .27736 L
.184 .25987 L
.22478 .21818 L
.26405 .17934 L
.3018 .14739 L
.342 .11982 L
.38069 .09896 L
.42183 .08181 L
.46145 .06921 L
.49956 .05992 L
.54012 .05237 L
.57917 .04687 L
.62066 .04244 L
.66065 .03923 L
.69911 .03688 L
.74003 .03499 L
.77943 .03361 L
.81732 .03259 L
.85766 .03177 L
.89648 .03117 L
.93776 .0307 L
Mistroke
.97619 .03037 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.04262 .09527 L
.06244 .16903 L
.08255 .22799 L
.09396 .2531 L
.09905 .26226 L
.10458 .27076 L
.11004 .2777 L
.11508 .28285 L
.11989 .28669 L
.12235 .28826 L
.125 .28965 L
.12738 .29067 L
.12956 .2914 L
.13061 .29168 L
.13175 .29194 L
.13283 .29214 L
.13384 .29229 L
.13512 .29243 L
.13628 .29251 L
.13753 .29254 L
.13824 .29253 L
.13889 .29251 L
.13997 .29244 L
.14116 .29233 L
.14241 .29216 L
.14357 .29196 L
.14617 .29136 L
.14858 .29064 L
.15402 .28845 L
.15882 .28593 L
.16392 .28274 L
.18248 .26774 L
.22023 .22938 L
.26044 .1885 L
.29912 .15444 L
.34026 .12504 L
.37989 .10281 L
.418 .08615 L
.45856 .07248 L
.4976 .06244 L
.5391 .05435 L
.57908 .04847 L
.61755 .04416 L
.65847 .04068 L
.69787 .03814 L
.73576 .03628 L
.7761 .03477 L
.81492 .03366 L
.8562 .03277 L
Mistroke
.89596 .03213 L
.9342 .03166 L
.9749 .03129 L
.97619 .03128 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.04262 .09286 L
.06244 .1632 L
.07216 .19129 L
.08255 .21585 L
.08852 .22725 L
.09396 .23588 L
.09911 .24257 L
.10458 .24811 L
.10932 .2517 L
.11201 .25325 L
.11454 .25441 L
.11685 .25523 L
.11896 .25579 L
.12013 .25602 L
.12141 .2562 L
.12261 .25633 L
.12373 .25639 L
.12503 .25641 L
.12577 .2564 L
.12644 .25637 L
.12769 .25627 L
.129 .25611 L
.13018 .25593 L
.13128 .25571 L
.13379 .2551 L
.13649 .25424 L
.13896 .25329 L
.14451 .25064 L
.15442 .24445 L
.16359 .23748 L
.18435 .21921 L
.22362 .18256 L
.26137 .15068 L
.30158 .12255 L
.34026 .10101 L
.3814 .08317 L
.42103 .06999 L
.45913 .06024 L
.4997 .05229 L
.53874 .04647 L
.58024 .04179 L
.62022 .03838 L
.65869 .03589 L
.69961 .03387 L
.73901 .0324 L
.7769 .03131 L
.81724 .03043 L
.85606 .02979 L
.89734 .02928 L
Mistroke
.9371 .02891 L
.97534 .02865 L
.97619 .02865 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.04262 .0584 L
.0522 .07625 L
.06244 .09103 L
.0679 .09707 L
.07286 .10155 L
.0779 .10521 L
.08255 .10786 L
.08798 .1102 L
.09084 .11115 L
.09388 .11196 L
.09633 .11249 L
.09897 .11294 L
.10048 .11314 L
.10187 .1133 L
.10326 .11343 L
.10458 .11352 L
.10578 .11359 L
.10708 .11365 L
.10826 .11368 L
.10935 .11369 L
.11052 .11369 L
.11182 .11368 L
.11247 .11366 L
.11316 .11364 L
.11442 .11359 L
.1156 .11353 L
.11688 .11346 L
.11921 .11328 L
.12357 .11284 L
.12878 .11215 L
.13433 .11126 L
.14429 .10934 L
.18204 .10012 L
.22224 .08956 L
.26093 .08 L
.30207 .07092 L
.34169 .06329 L
.3798 .05695 L
.42036 .05116 L
.45941 .04642 L
.50091 .04214 L
.54089 .03867 L
.57935 .03584 L
.62027 .0333 L
.65968 .03124 L
.69756 .02957 L
.7379 .02807 L
.77673 .02685 L
.818 .02576 L
Mistroke
.85776 .02489 L
.89601 .02419 L
.93671 .02356 L
.97589 .02305 L
.97619 .02305 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.03279 .04105 L
.04262 .06569 L
.04758 .07572 L
.05288 .08448 L
.05789 .09095 L
.06244 .09545 L
.06507 .09751 L
.06785 .09931 L
.07025 .10059 L
.07283 .10171 L
.0756 .10264 L
.0782 .10329 L
.07978 .10359 L
.08128 .10382 L
.08263 .10398 L
.08334 .10405 L
.0841 .10411 L
.08483 .10415 L
.08549 .10419 L
.0868 .10423 L
.08799 .10424 L
.08924 .10422 L
.0899 .1042 L
.09059 .10418 L
.09186 .10411 L
.09336 .104 L
.09472 .10388 L
.09978 .10324 L
.10458 .10242 L
.12449 .09759 L
.14291 .09217 L
.18218 .08034 L
.21993 .06999 L
.26013 .06054 L
.29882 .05292 L
.33996 .04624 L
.37958 .04098 L
.41769 .03683 L
.45825 .03322 L
.4973 .03039 L
.53879 .02796 L
.57878 .02607 L
.61724 .0246 L
.65816 .02333 L
.69756 .02234 L
.73545 .02156 L
.77579 .02089 L
.81461 .02037 L
.85589 .01993 L
Mistroke
.89565 .01958 L
.9339 .01932 L
.97459 .01909 L
.97619 .01908 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.02499 .01738 L
.02605 .01927 L
.02729 .02092 L
.02846 .02209 L
.02954 .02291 L
.03053 .02351 L
.03279 .02449 L
.03396 .02484 L
.03506 .02511 L
.03636 .02537 L
.03756 .02556 L
.04 .02585 L
.04134 .02597 L
.04262 .02606 L
.04384 .02612 L
.045 .02617 L
.04633 .02622 L
.04753 .02625 L
.04868 .02628 L
.04973 .02629 L
.05088 .0263 L
.0521 .02631 L
.05333 .02631 L
.05465 .0263 L
.05589 .02629 L
.05703 .02628 L
.05981 .02624 L
.06244 .0262 L
.07293 .02593 L
.08263 .02561 L
.10458 .02482 L
.14385 .02341 L
.1816 .02218 L
.2218 .02104 L
.26049 .02011 L
.30163 .01927 L
.34125 .01859 L
.37936 .01804 L
.41992 .01755 L
.45897 .01716 L
.50046 .01681 L
.54045 .01653 L
.57891 .0163 L
.61983 .0161 L
.65923 .01594 L
.69712 .01581 L
.73746 .0157 L
.77628 .01561 L
.81756 .01553 L
Mistroke
.85732 .01546 L
.89557 .01541 L
.93627 .01536 L
.97545 .01532 L
.97619 .01532 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.04262 .0881 L
.06244 .15593 L
.08255 .21073 L
.09396 .23443 L
.10458 .25146 L
.10961 .25785 L
.11508 .2636 L
.11989 .26768 L
.125 .27105 L
.12959 .27327 L
.13221 .27422 L
.13466 .2749 L
.13581 .27516 L
.1369 .27536 L
.13789 .27552 L
.13895 .27565 L
.1401 .27576 L
.14116 .27583 L
.14243 .27587 L
.14357 .27587 L
.14477 .27583 L
.1459 .27576 L
.14713 .27564 L
.14845 .27548 L
.15114 .27501 L
.1536 .27444 L
.15833 .27298 L
.16282 .27121 L
.17279 .26608 L
.18364 .25904 L
.22442 .22563 L
.26369 .19177 L
.30144 .16238 L
.34164 .13588 L
.38033 .11502 L
.42147 .09724 L
.46109 .08372 L
.4992 .07342 L
.53976 .0648 L
.57881 .05832 L
.62031 .05297 L
.66029 .04898 L
.69875 .04598 L
.73967 .0435 L
.77908 .04166 L
.81696 .04028 L
.8573 .03914 L
.89613 .0383 L
.9374 .03762 L
Mistroke
.97619 .03715 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.04262 .07624 L
.0522 .10211 L
.06244 .12439 L
.0679 .13386 L
.07286 .14108 L
.0779 .14712 L
.08255 .15161 L
.08798 .15565 L
.09079 .15728 L
.09388 .15875 L
.09638 .1597 L
.09907 .16051 L
.10056 .16086 L
.10192 .16113 L
.10329 .16135 L
.10458 .16152 L
.10578 .16164 L
.10708 .16173 L
.10826 .16178 L
.10935 .1618 L
.11052 .16179 L
.11182 .16175 L
.11247 .16172 L
.11316 .16168 L
.11442 .16158 L
.11688 .1613 L
.11921 .16095 L
.12357 .16008 L
.12872 .15874 L
.13349 .15725 L
.14429 .15321 L
.18355 .13472 L
.22131 .11632 L
.26151 .09877 L
.3002 .08446 L
.34134 .07192 L
.38096 .06213 L
.41907 .0545 L
.45963 .04797 L
.49867 .04295 L
.54017 .0387 L
.58015 .03547 L
.61862 .03299 L
.65954 .03089 L
.69894 .02929 L
.73683 .02807 L
.77717 .02703 L
.81599 .02624 L
.85727 .02558 L
Mistroke
.89703 .02508 L
.93528 .0247 L
.97597 .02439 L
.97619 .02439 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.06244 .16184 L
.08255 .22322 L
.0932 .25047 L
.10458 .27525 L
.11531 .29434 L
.12507 .30809 L
.12977 .31351 L
.13488 .31852 L
.13935 .32218 L
.14415 .32539 L
.14903 .3279 L
.15359 .3296 L
.15638 .33034 L
.15775 .33063 L
.15902 .33085 L
.16027 .33102 L
.1614 .33114 L
.16265 .33124 L
.16334 .33128 L
.16399 .3313 L
.16521 .33131 L
.1659 .3313 L
.16655 .33129 L
.16785 .33122 L
.16858 .33116 L
.16925 .3311 L
.17174 .33078 L
.17409 .33035 L
.17681 .32971 L
.17932 .32898 L
.18502 .32689 L
.19465 .3221 L
.20368 .3164 L
.22428 .30028 L
.26297 .26419 L
.30411 .22534 L
.34374 .19173 L
.38184 .16416 L
.42241 .13992 L
.46145 .12103 L
.50295 .10502 L
.54293 .09285 L
.5814 .08358 L
.62232 .07581 L
.66172 .06995 L
.69961 .06551 L
.73995 .0618 L
.77877 .05901 L
.82005 .05672 L
Mistroke
.85981 .05502 L
.89805 .05376 L
.93875 .05275 L
.97619 .05206 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.03279 .04625 L
.04262 .07575 L
.04758 .08789 L
.05288 .09869 L
.05785 .10682 L
.06244 .11273 L
.06788 .11801 L
.07075 .12013 L
.07379 .12194 L
.07624 .1231 L
.07889 .12409 L
.0804 .12455 L
.08179 .1249 L
.0831 .12517 L
.08451 .12541 L
.08585 .12559 L
.08706 .12571 L
.08828 .12579 L
.08943 .12584 L
.09008 .12585 L
.09077 .12586 L
.09201 .12584 L
.09269 .12581 L
.09334 .12578 L
.0948 .12569 L
.09607 .12557 L
.09727 .12544 L
.09952 .12514 L
.10458 .12419 L
.11423 .12166 L
.12449 .11825 L
.14291 .11118 L
.18066 .09591 L
.22086 .08111 L
.25955 .06911 L
.30069 .0587 L
.34031 .05067 L
.37842 .04448 L
.41898 .03926 L
.45803 .03528 L
.49953 .03196 L
.53951 .02946 L
.57798 .02756 L
.61889 .02598 L
.6583 .02478 L
.69618 .02387 L
.73652 .02311 L
.77535 .02254 L
.81662 .02206 L
Mistroke
.85639 .0217 L
.89463 .02143 L
.93533 .02121 L
.97451 .02105 L
.97619 .02104 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.04262 .06378 L
.0522 .08469 L
.06244 .10287 L
.0679 .11068 L
.07286 .11668 L
.08255 .12559 L
.08798 .12913 L
.09084 .13063 L
.09388 .13196 L
.09652 .13293 L
.09944 .1338 L
.10211 .13443 L
.10458 .13489 L
.10706 .13523 L
.10838 .13537 L
.10978 .13548 L
.11042 .13553 L
.11111 .13556 L
.11237 .13561 L
.11359 .13564 L
.11472 .13565 L
.11583 .13563 L
.11687 .13561 L
.118 .13557 L
.11922 .1355 L
.12172 .13532 L
.12399 .1351 L
.12912 .13441 L
.13471 .13342 L
.14487 .1311 L
.18565 .11841 L
.22492 .105 L
.26267 .09291 L
.30287 .08149 L
.34156 .072 L
.3827 .06341 L
.42232 .05645 L
.46043 .05082 L
.50099 .0458 L
.54004 .04178 L
.58153 .03823 L
.62152 .0354 L
.65998 .03315 L
.7009 .03116 L
.7403 .02958 L
.77819 .02832 L
.81853 .0272 L
.85735 .02632 L
.89863 .02555 L
Mistroke
.93839 .02495 L
.97619 .02447 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.02499 .01731 L
.02605 .01917 L
.02729 .02082 L
.02846 .02199 L
.02954 .02283 L
.03053 .02345 L
.03279 .02446 L
.03396 .02483 L
.03506 .02512 L
.03636 .0254 L
.03756 .02561 L
.04 .02592 L
.04134 .02605 L
.04262 .02615 L
.045 .02629 L
.04633 .02635 L
.04753 .02639 L
.04866 .02642 L
.04988 .02645 L
.05104 .02647 L
.0521 .02648 L
.05334 .02649 L
.0545 .02649 L
.05577 .02649 L
.05648 .02649 L
.05713 .02648 L
.05844 .02647 L
.05986 .02646 L
.06244 .02642 L
.06749 .02633 L
.07306 .02619 L
.08433 .02586 L
.10458 .02516 L
.14478 .02376 L
.18347 .02252 L
.22461 .02137 L
.26423 .02042 L
.30234 .01964 L
.3429 .01893 L
.38195 .01836 L
.42345 .01785 L
.46343 .01743 L
.5019 .0171 L
.54281 .0168 L
.58222 .01656 L
.6201 .01636 L
.66044 .01619 L
.69927 .01604 L
.74054 .01592 L
Mistroke
.78031 .01582 L
.81855 .01573 L
.85925 .01566 L
.89843 .0156 L
.94006 .01555 L
.97619 .01551 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.04262 .06078 L
.06244 .1046 L
.08255 .14016 L
.09396 .1552 L
.09905 .16064 L
.10458 .16567 L
.11004 .16978 L
.11508 .17285 L
.11989 .17518 L
.125 .17705 L
.1272 .17769 L
.12956 .17826 L
.13161 .17866 L
.13384 .17901 L
.13519 .17918 L
.13644 .17932 L
.13764 .17942 L
.13892 .1795 L
.14018 .17955 L
.14136 .17958 L
.14242 .17959 L
.14357 .17958 L
.14481 .17955 L
.14595 .1795 L
.14725 .17943 L
.14849 .17934 L
.15069 .17913 L
.15308 .17885 L
.1585 .17798 L
.16351 .17693 L
.17373 .1742 L
.18458 .17065 L
.22233 .15553 L
.26253 .13827 L
.30122 .12257 L
.34236 .10759 L
.38198 .09497 L
.42009 .08446 L
.46065 .07485 L
.4997 .06697 L
.54119 .05986 L
.58118 .0541 L
.61964 .04939 L
.66056 .04517 L
.69996 .04176 L
.73785 .03898 L
.77819 .03648 L
.81701 .03447 L
.85829 .03267 L
Mistroke
.89805 .03123 L
.9363 .03006 L
.97619 .02904 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.04262 .0847 L
.0522 .11372 L
.06244 .13856 L
.0679 .14912 L
.07286 .15718 L
.0779 .16395 L
.08255 .16901 L
.08798 .17359 L
.09079 .17544 L
.09388 .17712 L
.09638 .17822 L
.09907 .17916 L
.10056 .17957 L
.10192 .17989 L
.10329 .18015 L
.10458 .18035 L
.10578 .18049 L
.10708 .18061 L
.10826 .18067 L
.10935 .1807 L
.11052 .1807 L
.11182 .18066 L
.11247 .18062 L
.11316 .18058 L
.11442 .18047 L
.1156 .18033 L
.11688 .18016 L
.11921 .17976 L
.12357 .17877 L
.12878 .17721 L
.13433 .17518 L
.14429 .17078 L
.18204 .14983 L
.22224 .12666 L
.26093 .10692 L
.30207 .08946 L
.34169 .0759 L
.3798 .06547 L
.42036 .05669 L
.45941 .05007 L
.50091 .04459 L
.54089 .04049 L
.57935 .03742 L
.62027 .03487 L
.65968 .03297 L
.69756 .03155 L
.7379 .03036 L
.77673 .02948 L
.818 .02876 L
Mistroke
.85776 .02822 L
.89601 .02782 L
.93671 .0275 L
.97589 .02727 L
.97619 .02727 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.06244 .0862 L
.08255 .12015 L
.10458 .15288 L
.1253 .17798 L
.14415 .19522 L
.15421 .20217 L
.16372 .20735 L
.17376 .21143 L
.17943 .21315 L
.18466 .21439 L
.18932 .21524 L
.19189 .2156 L
.19433 .21588 L
.19659 .21609 L
.19778 .21618 L
.19906 .21626 L
.20024 .21633 L
.2013 .21637 L
.20238 .21641 L
.20339 .21643 L
.20458 .21645 L
.2059 .21645 L
.20656 .21645 L
.20727 .21644 L
.20855 .21642 L
.20982 .21638 L
.21103 .21633 L
.21329 .21621 L
.21596 .21603 L
.21843 .21581 L
.22401 .21517 L
.23364 .21364 L
.24268 .21177 L
.26328 .20635 L
.30197 .1935 L
.34311 .17836 L
.38273 .16381 L
.42084 .1505 L
.4614 .13737 L
.50044 .12585 L
.54194 .11482 L
.58192 .10533 L
.62039 .09719 L
.66131 .0895 L
.70071 .08296 L
.7386 .07738 L
.77894 .07215 L
.81776 .06772 L
.85904 .06359 L
Mistroke
.8988 .06012 L
.93705 .05719 L
.97619 .05456 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.03279 .041 L
.04262 .06644 L
.05288 .08742 L
.06244 .1013 L
.06792 .10697 L
.0731 .11101 L
.07775 .11369 L
.0828 .11576 L
.08542 .11653 L
.0883 .11717 L
.08975 .11742 L
.09131 .11763 L
.09278 .11779 L
.09343 .11785 L
.09413 .1179 L
.09482 .11794 L
.09545 .11797 L
.09669 .11801 L
.09738 .11803 L
.09813 .11803 L
.09884 .11803 L
.09949 .11802 L
.10067 .11798 L
.10196 .11792 L
.10332 .11784 L
.10458 .11774 L
.10718 .11748 L
.10959 .11717 L
.11503 .11628 L
.12493 .11413 L
.14349 .10896 L
.18275 .09639 L
.22051 .08466 L
.26071 .07358 L
.2994 .06447 L
.34054 .05635 L
.38016 .04987 L
.41827 .04471 L
.45883 .04018 L
.49787 .0366 L
.53937 .0335 L
.57935 .03107 L
.61782 .02916 L
.65874 .0275 L
.69814 .02621 L
.73603 .02518 L
.77637 .0243 L
.81519 .0236 L
.85647 .02301 L
Mistroke
.89623 .02254 L
.93448 .02218 L
.97517 .02187 L
.97619 .02187 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.04262 .09414 L
.06244 .16578 L
.08255 .22071 L
.09396 .24288 L
.09905 .25067 L
.10458 .25769 L
.11004 .26322 L
.11508 .26714 L
.11989 .26991 L
.12232 .27095 L
.125 .27185 L
.12623 .27218 L
.12741 .27244 L
.12848 .27264 L
.12962 .27281 L
.13085 .27294 L
.13199 .27302 L
.13269 .27305 L
.13335 .27307 L
.13459 .27306 L
.13568 .27301 L
.13684 .27292 L
.13782 .27282 L
.1389 .27267 L
.14132 .27224 L
.14357 .2717 L
.14858 .27007 L
.15402 .2677 L
.16392 .26206 L
.18248 .24821 L
.22326 .21156 L
.26253 .17692 L
.30028 .14798 L
.34048 .1226 L
.37917 .10311 L
.42031 .08686 L
.45994 .07474 L
.49804 .0657 L
.5386 .05826 L
.57765 .05276 L
.61915 .0483 L
.65913 .04502 L
.6976 .0426 L
.73851 .04062 L
.77792 .03918 L
.8158 .03811 L
.85614 .03724 L
.89497 .03662 L
.93625 .03612 L
Mistroke
.97601 .03579 L
.97619 .03578 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.02499 .01789 L
.02605 .02001 L
.02729 .02175 L
.02846 .02291 L
.02954 .02369 L
.03053 .02424 L
.03163 .02471 L
.03279 .02509 L
.03395 .02539 L
.0352 .02564 L
.03628 .02581 L
.03746 .02596 L
.03884 .02609 L
.04016 .02619 L
.04143 .02626 L
.04262 .02631 L
.04386 .02634 L
.04456 .02636 L
.04521 .02637 L
.0464 .02638 L
.04765 .02639 L
.04878 .02639 L
.04983 .02638 L
.05098 .02637 L
.05221 .02635 L
.05496 .0263 L
.05757 .02623 L
.06244 .02608 L
.10458 .02428 L
.14291 .02267 L
.18369 .02122 L
.22296 .02006 L
.26071 .01915 L
.30091 .01837 L
.3396 .01775 L
.38074 .01723 L
.42036 .01682 L
.45847 .01651 L
.49903 .01624 L
.53808 .01603 L
.57958 .01585 L
.61956 .01571 L
.65802 .01561 L
.69894 .01552 L
.73835 .01545 L
.77623 .0154 L
.81657 .01535 L
.8554 .01532 L
.89667 .01529 L
Mistroke
.93643 .01526 L
.97468 .01524 L
.97619 .01524 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.03279 .03532 L
.04262 .05468 L
.04758 .06256 L
.05288 .06945 L
.05789 .07454 L
.06244 .07809 L
.06507 .07973 L
.06785 .08117 L
.07283 .08313 L
.0756 .08391 L
.0782 .08449 L
.08104 .08495 L
.08264 .08515 L
.0841 .0853 L
.08536 .08539 L
.08671 .08547 L
.08797 .08553 L
.08912 .08556 L
.08983 .08557 L
.09048 .08558 L
.09119 .08558 L
.09194 .08557 L
.09321 .08555 L
.09393 .08553 L
.0946 .08551 L
.09712 .08539 L
.09942 .08524 L
.10458 .08478 L
.11449 .08351 L
.12366 .08204 L
.14443 .07819 L
.18369 .07038 L
.22144 .06327 L
.26165 .05648 L
.30033 .05078 L
.34147 .04556 L
.3811 .04126 L
.41921 .03772 L
.45977 .03451 L
.49881 .03188 L
.54031 .02952 L
.58029 .02759 L
.61876 .02602 L
.65968 .02461 L
.69908 .02346 L
.73697 .02252 L
.77731 .02168 L
.81613 .02099 L
.85741 .02037 L
Mistroke
.89717 .01988 L
.93541 .01947 L
.97611 .0191 L
.97619 .0191 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.04262 .07294 L
.06244 .12842 L
.08426 .17886 L
.0949 .19861 L
.10458 .21366 L
.1134 .22494 L
.12297 .23466 L
.12822 .23893 L
.13308 .24224 L
.13807 .24505 L
.14264 .24711 L
.14729 .24874 L
.14969 .2494 L
.1523 .24999 L
.15471 .25043 L
.15695 .25073 L
.15908 .25094 L
.16028 .25103 L
.16136 .25108 L
.16265 .25112 L
.1633 .25113 L
.16402 .25114 L
.16528 .25112 L
.16646 .25109 L
.16718 .25106 L
.16786 .25102 L
.16913 .25094 L
.17049 .25082 L
.17198 .25067 L
.17718 .24989 L
.18199 .24888 L
.19161 .24613 L
.20065 .2428 L
.22125 .23324 L
.25994 .21137 L
.30108 .18698 L
.3407 .16493 L
.37881 .14599 L
.41937 .12849 L
.45842 .11415 L
.49992 .10136 L
.5399 .09112 L
.57837 .08292 L
.61928 .07571 L
.65869 .07001 L
.69657 .06548 L
.73691 .06153 L
.77574 .05842 L
.81701 .05574 L
Mistroke
.85678 .05366 L
.89502 .05205 L
.93572 .05068 L
.9749 .04964 L
.97619 .04961 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.06244 .11656 L
.10458 .21173 L
.14415 .2822 L
.16408 .30976 L
.18221 .33003 L
.20178 .34683 L
.21254 .35389 L
.22272 .35921 L
.23241 .36311 L
.23772 .36479 L
.24269 .36607 L
.24727 .36702 L
.25147 .3677 L
.25369 .36799 L
.25612 .36825 L
.25869 .36846 L
.25988 .36853 L
.26113 .3686 L
.26246 .36866 L
.26368 .36869 L
.265 .36872 L
.26575 .36872 L
.26644 .36872 L
.26771 .36872 L
.26886 .3687 L
.2695 .36868 L
.27019 .36866 L
.27145 .36861 L
.2738 .36848 L
.27631 .3683 L
.2808 .36784 L
.28595 .36713 L
.29077 .36629 L
.30178 .36378 L
.32196 .35737 L
.34046 .34985 L
.38009 .33024 L
.4182 .30909 L
.45876 .28617 L
.4978 .26491 L
.5393 .2439 L
.57928 .22558 L
.61775 .20982 L
.65867 .19504 L
.69807 .18264 L
.73596 .17228 L
.7763 .16279 L
.81512 .15499 L
.8564 .14799 L
Mistroke
.89616 .14236 L
.9344 .13784 L
.9751 .13391 L
.97619 .13382 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.06244 .12951 L
.10458 .23219 L
.12507 .27127 L
.14415 .30067 L
.16254 .32257 L
.17277 .33209 L
.18221 .33927 L
.19242 .34537 L
.1977 .34787 L
.20351 .35015 L
.20822 .35164 L
.21329 .35289 L
.21608 .35344 L
.21864 .35385 L
.22127 .35419 L
.22365 .35442 L
.22483 .35451 L
.22611 .35458 L
.22731 .35464 L
.22842 .35468 L
.2296 .3547 L
.23089 .35471 L
.23154 .35471 L
.23224 .3547 L
.2335 .35467 L
.23467 .35463 L
.23595 .35457 L
.23828 .35441 L
.24054 .3542 L
.24264 .35397 L
.24742 .35327 L
.25269 .35226 L
.26336 .34951 L
.28271 .34248 L
.30357 .33266 L
.34471 .30924 L
.38433 .2847 L
.42244 .26143 L
.463 .23826 L
.50204 .21809 L
.54354 .19918 L
.58352 .18338 L
.62199 .17028 L
.66291 .15841 L
.70231 .14876 L
.7402 .14094 L
.78054 .13397 L
.81936 .12843 L
.86064 .12361 L
Mistroke
.9004 .11986 L
.93865 .11699 L
.97619 .11478 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.03279 .05544 L
.03793 .07478 L
.04262 .08889 L
.04758 .10008 L
.0503 .10469 L
.05288 .10815 L
.05527 .11066 L
.05747 .11246 L
.05988 .11394 L
.0611 .1145 L
.06244 .115 L
.06379 .11538 L
.06455 .11555 L
.06525 .11567 L
.06654 .11583 L
.06726 .11589 L
.06792 .11591 L
.06916 .11591 L
.06985 .11588 L
.0705 .11584 L
.07168 .11572 L
.07293 .11554 L
.07427 .11529 L
.07571 .11497 L
.0783 .11426 L
.0842 .11214 L
.10458 .10215 L
.14594 .08058 L
.18579 .06368 L
.22412 .05135 L
.2649 .04169 L
.30416 .03493 L
.34191 .03018 L
.38212 .02651 L
.42081 .02395 L
.46195 .02199 L
.50157 .02063 L
.53968 .01968 L
.58024 .01895 L
.61928 .01844 L
.66078 .01805 L
.70076 .01778 L
.73923 .01759 L
.78015 .01744 L
.81955 .01733 L
.85744 .01726 L
.89778 .0172 L
.9366 .01716 L
.97619 .01713 L
Mistroke
Mfstroke
.862 1 0 r
.02381 .01472 m
.02846 .03183 L
.03279 .04631 L
.03793 .06061 L
.04262 .07039 L
.04498 .07417 L
.04754 .07748 L
.04996 .07993 L
.0522 .0817 L
.05456 .08313 L
.05717 .08426 L
.05848 .08468 L
.05989 .08504 L
.06123 .08529 L
.06244 .08546 L
.06314 .08553 L
.0638 .08559 L
.06504 .08565 L
.06573 .08566 L
.06636 .08566 L
.06706 .08565 L
.0678 .08562 L
.06903 .08555 L
.07017 .08546 L
.07143 .08533 L
.07277 .08515 L
.07867 .08409 L
.08405 .08281 L
.10458 .07669 L
.14443 .06425 L
.18275 .05401 L
.22354 .04528 L
.2628 .03871 L
.30055 .03377 L
.34076 .02968 L
.37944 .02664 L
.42058 .02416 L
.46021 .02233 L
.49832 .02097 L
.53888 .01985 L
.57792 .01903 L
.61942 .01836 L
.6594 .01786 L
.69787 .0175 L
.73879 .0172 L
.77819 .01698 L
.81608 .01682 L
.85642 .01668 L
.89524 .01658 L
.93652 .0165 L
Mistroke
.97619 .01644 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.04262 .08733 L
.06244 .15097 L
.07286 .1763 L
.08255 .19402 L
.08813 .20162 L
.0932 .20697 L
.096 .20931 L
.09905 .2114 L
.10192 .21294 L
.10458 .21403 L
.10583 .21443 L
.10701 .21475 L
.10809 .21499 L
.10924 .2152 L
.11048 .21536 L
.11163 .21547 L
.11234 .2155 L
.113 .21552 L
.11425 .21552 L
.11535 .21547 L
.11651 .21538 L
.11751 .21527 L
.1186 .21511 L
.12103 .21463 L
.12331 .21404 L
.12851 .21222 L
.13326 .21008 L
.14393 .20394 L
.18378 .17376 L
.22211 .14422 L
.26289 .11725 L
.30215 .09624 L
.3399 .08017 L
.38011 .06676 L
.4188 .05675 L
.45994 .04857 L
.49956 .04253 L
.53767 .03806 L
.57823 .0344 L
.61727 .03171 L
.65877 .02952 L
.69875 .02793 L
.73722 .02675 L
.77814 .02578 L
.81754 .02508 L
.85543 .02456 L
.89577 .02414 L
.93459 .02383 L
.97587 .02358 L
Mistroke
.97619 .02358 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.02499 .01742 L
.02605 .01933 L
.02729 .02101 L
.02846 .02219 L
.02954 .02302 L
.03053 .02363 L
.03279 .02463 L
.03396 .02499 L
.03506 .02527 L
.03636 .02554 L
.03756 .02574 L
.04 .02605 L
.04134 .02618 L
.04262 .02627 L
.045 .02641 L
.04633 .02646 L
.04753 .0265 L
.04866 .02653 L
.04988 .02655 L
.05104 .02657 L
.0521 .02658 L
.05334 .02658 L
.0545 .02658 L
.05577 .02658 L
.05648 .02657 L
.05713 .02657 L
.05844 .02656 L
.05986 .02654 L
.06244 .0265 L
.06749 .0264 L
.07306 .02625 L
.08433 .0259 L
.10458 .02519 L
.14478 .02374 L
.18347 .02247 L
.22461 .02129 L
.26423 .02033 L
.30234 .01954 L
.3429 .01883 L
.38195 .01825 L
.42345 .01775 L
.46343 .01734 L
.5019 .01701 L
.54281 .01672 L
.58222 .01648 L
.6201 .01629 L
.66044 .01612 L
.69927 .01599 L
.74054 .01587 L
Mistroke
.78031 .01578 L
.81855 .0157 L
.85925 .01563 L
.89843 .01558 L
.94006 .01553 L
.97619 .0155 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.04262 .08885 L
.06244 .15644 L
.08255 .20957 L
.09396 .232 L
.10458 .24794 L
.10961 .2539 L
.11508 .25926 L
.11989 .2631 L
.125 .2663 L
.12959 .26847 L
.13221 .26943 L
.13466 .27014 L
.1369 .27065 L
.13895 .271 L
.14008 .27115 L
.14132 .27128 L
.14249 .27136 L
.14357 .27141 L
.14486 .27144 L
.14551 .27143 L
.14622 .27142 L
.14747 .27137 L
.14865 .27129 L
.15004 .27116 L
.1513 .27101 L
.15414 .27055 L
.15659 .27004 L
.15925 .26936 L
.1641 .26782 L
.17376 .26376 L
.1827 .25903 L
.22197 .23192 L
.25972 .20288 L
.29992 .17385 L
.33861 .14952 L
.37975 .12788 L
.41937 .11089 L
.45748 .09764 L
.49804 .08632 L
.53709 .07766 L
.57859 .0704 L
.61857 .0649 L
.65703 .06072 L
.69795 .05723 L
.73736 .0546 L
.77524 .05262 L
.81558 .05097 L
.85441 .04974 L
.89568 .04875 L
Mistroke
.93545 .04804 L
.97369 .04755 L
.97619 .04752 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.04262 .10636 L
.06244 .18789 L
.08255 .25068 L
.09396 .27676 L
.09905 .2862 L
.10458 .29494 L
.11004 .30209 L
.11508 .30744 L
.11989 .31148 L
.12235 .31315 L
.125 .31468 L
.12738 .31581 L
.12956 .31665 L
.13175 .31731 L
.13384 .31778 L
.135 .31798 L
.13625 .31814 L
.13743 .31824 L
.13849 .31829 L
.13975 .31831 L
.14046 .31829 L
.14111 .31826 L
.14231 .31818 L
.14357 .31804 L
.14479 .31787 L
.14612 .31763 L
.14853 .31707 L
.15305 .3156 L
.15833 .31326 L
.16321 .31057 L
.18154 .29685 L
.22081 .25731 L
.25856 .21738 L
.29876 .17951 L
.33745 .1494 L
.37859 .12402 L
.41822 .10512 L
.45632 .09109 L
.49689 .07968 L
.53593 .07135 L
.57743 .06467 L
.61741 .05984 L
.65588 .05631 L
.6968 .05346 L
.7362 .05139 L
.77409 .04988 L
.81443 .04867 L
.85325 .04781 L
.873 .04746 L
Mistroke
.89453 .04714 L
.93429 .04668 L
.954 .04652 L
.97498 .04638 L
.97619 .04638 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.06244 .09295 L
.10458 .16883 L
.14415 .22769 L
.18221 .27021 L
.20178 .2863 L
.22272 .2992 L
.23293 .30395 L
.24402 .30803 L
.24911 .30954 L
.25449 .3109 L
.25954 .31196 L
.26416 .31275 L
.26899 .31341 L
.27357 .31387 L
.27608 .31406 L
.27841 .3142 L
.27973 .31427 L
.28097 .31431 L
.28166 .31434 L
.2824 .31436 L
.2837 .31438 L
.28484 .3144 L
.28591 .31441 L
.28708 .3144 L
.28833 .31439 L
.28965 .31437 L
.29089 .31434 L
.29201 .31431 L
.29323 .31426 L
.29544 .31415 L
.29778 .31401 L
.302 .31367 L
.30689 .31316 L
.31137 .31258 L
.32147 .31093 L
.33975 .30686 L
.37937 .29441 L
.41748 .27959 L
.45804 .26247 L
.49709 .2458 L
.53858 .22862 L
.57857 .21302 L
.61703 .1991 L
.65795 .18557 L
.69735 .17379 L
.73524 .1636 L
.77558 .15389 L
.81441 .14561 L
.85568 .13784 L
Mistroke
.89544 .1313 L
.93369 .12578 L
.97439 .12069 L
.97619 .12048 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.06244 .08646 L
.10458 .15718 L
.14415 .21328 L
.18221 .25527 L
.20178 .27188 L
.22272 .28589 L
.23293 .29137 L
.24402 .29634 L
.25361 .29987 L
.26416 .30296 L
.2744 .30522 L
.284 .30672 L
.28929 .3073 L
.29413 .30769 L
.2968 .30785 L
.29821 .30792 L
.29972 .30798 L
.30116 .30802 L
.30247 .30806 L
.30379 .30808 L
.30503 .3081 L
.30619 .3081 L
.30744 .3081 L
.30861 .3081 L
.30968 .30808 L
.31094 .30806 L
.31231 .30803 L
.31479 .30795 L
.31739 .30783 L
.32015 .30767 L
.32511 .30731 L
.33389 .30641 L
.34358 .30508 L
.36293 .3015 L
.38378 .2965 L
.42492 .28426 L
.46455 .27073 L
.50266 .25712 L
.54322 .24266 L
.58226 .22921 L
.62376 .2157 L
.66374 .20361 L
.70221 .19291 L
.74313 .18252 L
.78253 .17349 L
.82042 .16566 L
.86076 .15821 L
.89958 .15184 L
.94086 .14588 L
Mistroke
.97619 .14138 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.06244 .14972 L
.10458 .26698 L
.12507 .31142 L
.14415 .34534 L
.16254 .37141 L
.18221 .3925 L
.19242 .40085 L
.20351 .40805 L
.21399 .41317 L
.22365 .41656 L
.22831 .41775 L
.23332 .41874 L
.23575 .41911 L
.23805 .4194 L
.24012 .41961 L
.24238 .41979 L
.24378 .41987 L
.24509 .41992 L
.24628 .41996 L
.24756 .41998 L
.24822 .41998 L
.24895 .41998 L
.24972 .41997 L
.25043 .41996 L
.25171 .41993 L
.25242 .4199 L
.25307 .41988 L
.25552 .41973 L
.2569 .41963 L
.25817 .41952 L
.263 .41896 L
.26764 .41822 L
.27263 .41724 L
.28167 .41496 L
.30227 .40774 L
.34341 .3873 L
.38303 .36359 L
.42114 .33979 L
.4617 .31525 L
.50075 .29338 L
.54225 .27258 L
.58223 .25507 L
.6207 .24052 L
.66161 .22737 L
.70102 .21676 L
.7389 .20825 L
.77924 .20081 L
.81807 .19502 L
.85934 .19018 L
Mistroke
.89911 .18663 L
.93735 .18415 L
.95616 .18323 L
.97619 .18248 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.04262 .08723 L
.06244 .15456 L
.08255 .20927 L
.09396 .23331 L
.10458 .25103 L
.11508 .26426 L
.12023 .26929 L
.125 .27312 L
.12924 .2759 L
.1339 .27833 L
.1386 .28012 L
.14117 .28085 L
.14357 .28137 L
.14482 .28159 L
.14615 .28177 L
.1474 .28191 L
.14854 .282 L
.14923 .28204 L
.14988 .28207 L
.15058 .28209 L
.15133 .2821 L
.15258 .28209 L
.15329 .28207 L
.15395 .28204 L
.15523 .28196 L
.15644 .28185 L
.15871 .28157 L
.16116 .28116 L
.16382 .28059 L
.16849 .27931 L
.17344 .27758 L
.18234 .27366 L
.20182 .26231 L
.2201 .24946 L
.25878 .21977 L
.29992 .18915 L
.33955 .16304 L
.37766 .14166 L
.41822 .12279 L
.45726 .108 L
.49876 .09535 L
.53874 .08563 L
.57721 .07816 L
.61813 .07185 L
.65753 .06704 L
.69542 .06337 L
.73576 .06028 L
.77458 .05794 L
.81586 .05601 L
Mistroke
.85562 .05458 L
.89386 .05352 L
.93456 .05269 L
.97374 .05211 L
.97619 .05208 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.04262 .06425 L
.06244 .11213 L
.08426 .1563 L
.0949 .17363 L
.10458 .18675 L
.1134 .19644 L
.12297 .20459 L
.12822 .20807 L
.13308 .21069 L
.13772 .21269 L
.14024 .21358 L
.14264 .21431 L
.14499 .21491 L
.14755 .21545 L
.14988 .21583 L
.15205 .2161 L
.15337 .21623 L
.15462 .21632 L
.15574 .21638 L
.15695 .21642 L
.15758 .21644 L
.15827 .21645 L
.15899 .21645 L
.15967 .21644 L
.16088 .21642 L
.16217 .21637 L
.16339 .2163 L
.16453 .21621 L
.16709 .21597 L
.16934 .21568 L
.17174 .21531 L
.18047 .21346 L
.18984 .21071 L
.19994 .20706 L
.21822 .19919 L
.25936 .17867 L
.29899 .15857 L
.33709 .14059 L
.37766 .12354 L
.4167 .10924 L
.4582 .09621 L
.49818 .08556 L
.53665 .07686 L
.57757 .06906 L
.61697 .06276 L
.65486 .05765 L
.6952 .05309 L
.73402 .04943 L
.7753 .04618 L
Mistroke
.81506 .04359 L
.8533 .04152 L
.894 .03969 L
.93318 .03824 L
.97482 .03697 L
.97619 .03693 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.02499 .01746 L
.02605 .01938 L
.02729 .02106 L
.02846 .02224 L
.02954 .02307 L
.03053 .02368 L
.03279 .02466 L
.03396 .02502 L
.03506 .02529 L
.03636 .02555 L
.03756 .02575 L
.04 .02604 L
.04134 .02616 L
.04262 .02625 L
.045 .02638 L
.04633 .02643 L
.04753 .02646 L
.04866 .02649 L
.04988 .0265 L
.05104 .02652 L
.0521 .02652 L
.05334 .02652 L
.0545 .02652 L
.05577 .02651 L
.05648 .02651 L
.05713 .0265 L
.05986 .02647 L
.06244 .02642 L
.06753 .0263 L
.07293 .02615 L
.08263 .02584 L
.10458 .02503 L
.14233 .02363 L
.18253 .02229 L
.22122 .02117 L
.26236 .02015 L
.30199 .01933 L
.34009 .01867 L
.38065 .01808 L
.4197 .0176 L
.4612 .01718 L
.50118 .01685 L
.53965 .01658 L
.58056 .01634 L
.61997 .01615 L
.65785 .016 L
.69819 .01587 L
.73702 .01576 L
.7783 .01567 L
Mistroke
.81806 .01559 L
.8563 .01553 L
.897 .01548 L
.93618 .01543 L
.97619 .0154 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.06244 .09749 L
.08255 .13425 L
.10458 .16671 L
.11448 .17821 L
.12507 .18829 L
.13506 .19573 L
.14415 .20084 L
.14898 .20294 L
.15411 .20475 L
.15848 .20596 L
.1633 .20697 L
.166 .20739 L
.16847 .20769 L
.16983 .20782 L
.17132 .20794 L
.17272 .20803 L
.17403 .20809 L
.17534 .20813 L
.17658 .20815 L
.17769 .20815 L
.17889 .20814 L
.18021 .20811 L
.18087 .20809 L
.1816 .20806 L
.18408 .20792 L
.18539 .20782 L
.18659 .20772 L
.18932 .20744 L
.19429 .20676 L
.20359 .20498 L
.21373 .20243 L
.22451 .19916 L
.26226 .18491 L
.30246 .16791 L
.34115 .15176 L
.38229 .13576 L
.42191 .12184 L
.46002 .10989 L
.50058 .09868 L
.53963 .08924 L
.58112 .08054 L
.62111 .07329 L
.65957 .06726 L
.70049 .06173 L
.73989 .05715 L
.77778 .05335 L
.81812 .04987 L
.85694 .047 L
.89822 .0444 L
Mistroke
.93798 .04226 L
.97619 .0405 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.06244 .10783 L
.08255 .1503 L
.10458 .18968 L
.12507 .21833 L
.14415 .23767 L
.15465 .24535 L
.16457 .25081 L
.17348 .25432 L
.1785 .25577 L
.18314 .25679 L
.18553 .25719 L
.1878 .25751 L
.19042 .25779 L
.19158 .25789 L
.19281 .25798 L
.19399 .25805 L
.19506 .25809 L
.19613 .25813 L
.19714 .25815 L
.19833 .25816 L
.19941 .25815 L
.20061 .25813 L
.20187 .25809 L
.20315 .25803 L
.20432 .25797 L
.20696 .25777 L
.20939 .25753 L
.2117 .25725 L
.21687 .25645 L
.2225 .25534 L
.23189 .25297 L
.24227 .24973 L
.26328 .24164 L
.30348 .2229 L
.34217 .20355 L
.38331 .18353 L
.42293 .16567 L
.46104 .15014 L
.5016 .13548 L
.54065 .12313 L
.58214 .11175 L
.62213 .10232 L
.66059 .09452 L
.70151 .08742 L
.74091 .08161 L
.7788 .07685 L
.81914 .07254 L
.85797 .06905 L
.89924 .06593 L
Mistroke
.939 .06344 L
.97619 .0615 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.03279 .04303 L
.04262 .06836 L
.04758 .07798 L
.05288 .08582 L
.05546 .08878 L
.05789 .09113 L
.06244 .09447 L
.06487 .09577 L
.06754 .09688 L
.06889 .09732 L
.07034 .09771 L
.07159 .09799 L
.07295 .09824 L
.0743 .09843 L
.07555 .09855 L
.07674 .09864 L
.07801 .09869 L
.07927 .09871 L
.08045 .09869 L
.0815 .09865 L
.08265 .09859 L
.08402 .09849 L
.0853 .09836 L
.0882 .09799 L
.09407 .09695 L
.10458 .0944 L
.14349 .08231 L
.18485 .06975 L
.22469 .05944 L
.26302 .05125 L
.30381 .04418 L
.34307 .03872 L
.38082 .03448 L
.42103 .03086 L
.45971 .02808 L
.50085 .02573 L
.54048 .02393 L
.57859 .02255 L
.61915 .02137 L
.65819 .02048 L
.69969 .01972 L
.73967 .01915 L
.77814 .01871 L
.81906 .01834 L
.85846 .01806 L
.89635 .01784 L
.93669 .01765 L
.97551 .01751 L
.97619 .01751 L
Mistroke
Mfstroke
.53 1 0 r
.02381 .01472 m
.04262 .15495 L
.06244 .27212 L
.08255 .3607 L
.09396 .39877 L
.10458 .42706 L
.11508 .44878 L
.125 .4641 L
.1339 .47392 L
.13893 .47795 L
.14357 .48077 L
.14596 .48189 L
.14823 .48276 L
.15085 .48354 L
.15201 .48381 L
.15324 .48404 L
.15442 .48421 L
.15549 .48433 L
.15656 .48441 L
.15757 .48446 L
.15875 .48447 L
.15984 .48444 L
.16104 .48436 L
.1623 .48423 L
.16358 .48406 L
.16475 .48385 L
.16738 .48325 L
.16982 .48253 L
.17213 .48169 L
.1773 .47934 L
.18292 .47608 L
.2027 .45976 L
.22371 .43652 L
.26146 .38779 L
.30166 .33586 L
.34035 .2917 L
.38149 .25301 L
.42111 .22357 L
.45922 .20147 L
.49978 .18335 L
.53883 .17005 L
.58032 .15931 L
.62031 .15151 L
.65877 .14579 L
.69969 .14121 L
.73909 .13794 L
.77698 .13564 L
.79643 .13473 L
.81732 .13393 L
.8385 .1333 L
Mistroke
.84823 .13306 L
.8586 .13285 L
.86901 .13267 L
.87844 .13254 L
.88792 .13244 L
.89684 .13237 L
.90151 .13234 L
.90663 .13232 L
.90921 .13231 L
.91063 .13231 L
.91198 .13231 L
.91323 .13231 L
.91389 .13231 L
.91458 .13231 L
.91582 .1323 L
.91696 .1323 L
.9181 .1323 L
.91915 .1323 L
.92029 .13231 L
.9215 .13231 L
.92255 .13231 L
.92353 .13231 L
.92575 .13232 L
.92821 .13232 L
.93044 .13233 L
.93545 .13236 L
.94031 .13239 L
.94545 .13243 L
.95467 .13252 L
.96459 .13266 L
.97548 .13284 L
.97619 .13285 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.04262 .09017 L
.0522 .12344 L
.06244 .15297 L
.0679 .16568 L
.07286 .17531 L
.0779 .18323 L
.08255 .1889 L
.08798 .19368 L
.09084 .19546 L
.0923 .19618 L
.09388 .19684 L
.09525 .1973 L
.09651 .19764 L
.09777 .19791 L
.09897 .1981 L
.09964 .19817 L
.10036 .19823 L
.10165 .19828 L
.10244 .19828 L
.10319 .19826 L
.10386 .19822 L
.10458 .19816 L
.10582 .19801 L
.10695 .19782 L
.1095 .19726 L
.11185 .19657 L
.11409 .19577 L
.12452 .19061 L
.14558 .17588 L
.18391 .14558 L
.22469 .11674 L
.26396 .09429 L
.30171 .07731 L
.34191 .06334 L
.3806 .05309 L
.42174 .04483 L
.46137 .03884 L
.49947 .03448 L
.54004 .03096 L
.57908 .02841 L
.62058 .02638 L
.66056 .02491 L
.69903 .02385 L
.73995 .02299 L
.77935 .02237 L
.81724 .02192 L
.85758 .02156 L
.8964 .02129 L
.93768 .02108 L
Mistroke
.97619 .02094 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.04262 .06536 L
.06244 .11248 L
.07216 .13169 L
.08255 .14866 L
.08852 .15662 L
.09396 .1627 L
.09911 .16747 L
.10458 .17153 L
.10932 .17425 L
.11183 .17542 L
.11454 .17648 L
.11701 .17727 L
.11928 .17786 L
.12156 .17832 L
.12373 .17865 L
.12503 .1788 L
.12622 .17891 L
.12688 .17895 L
.12759 .17899 L
.12888 .17904 L
.13009 .17905 L
.13137 .17904 L
.13246 .17901 L
.13366 .17895 L
.13439 .1789 L
.13508 .17885 L
.13637 .17872 L
.13927 .17836 L
.14178 .17796 L
.14451 .17742 L
.15391 .17497 L
.16428 .17139 L
.18529 .16247 L
.22549 .1432 L
.26418 .12519 L
.30532 .10808 L
.34495 .09386 L
.38305 .0822 L
.42362 .07173 L
.46266 .06329 L
.50416 .05583 L
.54414 .04989 L
.58261 .04513 L
.62353 .04093 L
.66293 .0376 L
.70082 .03493 L
.74116 .03258 L
.77998 .03071 L
.82126 .02907 L
Mistroke
.86102 .02777 L
.89926 .02674 L
.93996 .02584 L
.97619 .02518 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.06244 .09241 L
.10458 .16815 L
.14415 .22751 L
.18221 .27086 L
.20178 .28735 L
.22272 .30058 L
.23293 .30544 L
.24402 .30958 L
.24911 .3111 L
.25449 .31246 L
.25954 .31351 L
.26416 .31428 L
.26899 .31491 L
.27357 .31534 L
.27608 .31551 L
.27841 .31563 L
.27975 .31568 L
.28097 .31571 L
.28165 .31573 L
.28237 .31574 L
.2837 .31575 L
.28484 .31575 L
.28591 .31575 L
.28708 .31573 L
.28833 .3157 L
.28965 .31566 L
.29089 .31561 L
.29323 .3155 L
.29743 .3152 L
.302 .31476 L
.3114 .31349 L
.32177 .31157 L
.34278 .30626 L
.38298 .29223 L
.42167 .27596 L
.46281 .25753 L
.50243 .2398 L
.54054 .22339 L
.5811 .207 L
.62015 .19245 L
.66165 .17838 L
.70163 .16617 L
.74009 .15564 L
.78101 .14565 L
.82042 .13715 L
.8583 .1299 L
.89864 .12312 L
.93747 .1174 L
.97619 .11242 L
Mistroke
Mfstroke
.435 1 0 r
.02381 .01472 m
.06244 .17621 L
.08255 .24475 L
.10458 .30682 L
.12507 .35256 L
.14415 .38529 L
.15465 .3995 L
.16457 .4106 L
.17341 .4187 L
.18314 .42578 L
.19284 .43105 L
.19815 .43323 L
.20312 .43484 L
.20776 .43598 L
.212 .43674 L
.21434 .43705 L
.21558 .43718 L
.2169 .43729 L
.21817 .43738 L
.21932 .43744 L
.22047 .43748 L
.22156 .4375 L
.22272 .43751 L
.22397 .4375 L
.22514 .43747 L
.22621 .43743 L
.22747 .43736 L
.22884 .43726 L
.23132 .43703 L
.23392 .43671 L
.23668 .43628 L
.24164 .4353 L
.25042 .43295 L
.26011 .42952 L
.27946 .42053 L
.30031 .40838 L
.34145 .38011 L
.38108 .35113 L
.41919 .32415 L
.45975 .29787 L
.49879 .27556 L
.54029 .2552 L
.58027 .23871 L
.61874 .22547 L
.65966 .2139 L
.69906 .20487 L
.73695 .19786 L
.77729 .19194 L
.81611 .18753 L
.83586 .18571 L
Mistroke
.85739 .18403 L
.89715 .18167 L
.91686 .18083 L
.92695 .18048 L
.93785 .18016 L
.94814 .17992 L
.9576 .17975 L
.96665 .17962 L
.9712 .17958 L
.97619 .17954 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.04262 .11884 L
.06244 .21112 L
.08255 .28412 L
.09396 .31619 L
.10458 .34018 L
.11508 .35857 L
.12023 .36577 L
.125 .3714 L
.1339 .37943 L
.1386 .38243 L
.14115 .38373 L
.14357 .38475 L
.14592 .38554 L
.14716 .38589 L
.14849 .38621 L
.14971 .38645 L
.15082 .38662 L
.15193 .38676 L
.15298 .38686 L
.15422 .38694 L
.15552 .38696 L
.15663 .38695 L
.15785 .38689 L
.15916 .38679 L
.1599 .38671 L
.16057 .38662 L
.16311 .38618 L
.16545 .38564 L
.16761 .38501 L
.17251 .38319 L
.18141 .37859 L
.19103 .37199 L
.20007 .36455 L
.22067 .34441 L
.25936 .30109 L
.3005 .25586 L
.34013 .21787 L
.37823 .18764 L
.4188 .16194 L
.45784 .14262 L
.49934 .1268 L
.53932 .11519 L
.57779 .10662 L
.61871 .09966 L
.65811 .09457 L
.696 .09082 L
.73634 .08779 L
.77516 .0856 L
.81644 .08388 L
Mistroke
.83707 .08322 L
.8562 .0827 L
.8759 .08227 L
.89444 .08193 L
.915 .08164 L
.93362 .08145 L
.94341 .08138 L
.95374 .08132 L
.96256 .08128 L
.96756 .08126 L
.97 .08126 L
.97223 .08125 L
.97619 .08125 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.06244 .20711 L
.08255 .28515 L
.10458 .35514 L
.1253 .40798 L
.14415 .44645 L
.16372 .47788 L
.18466 .50306 L
.20381 .51943 L
.21461 .52619 L
.22459 .53098 L
.22925 .53278 L
.23426 .53441 L
.23859 .53559 L
.24332 .53662 L
.24618 .53713 L
.24884 .53752 L
.25159 .53785 L
.25409 .53809 L
.25527 .53818 L
.25654 .53826 L
.25765 .53831 L
.25886 .53836 L
.26014 .5384 L
.26085 .53841 L
.2615 .53842 L
.26268 .53842 L
.26394 .53842 L
.26516 .53839 L
.26585 .53837 L
.2665 .53835 L
.26781 .5383 L
.26923 .53822 L
.27178 .53805 L
.27411 .53783 L
.27951 .53718 L
.28518 .53625 L
.29479 .53414 L
.3053 .53116 L
.32491 .52396 L
.34586 .5144 L
.38736 .49181 L
.42734 .46795 L
.46581 .44499 L
.50673 .42192 L
.54613 .40174 L
.58402 .38455 L
.62436 .36871 L
.66318 .35579 L
.70446 .34439 L
Mistroke
.74422 .3355 L
.78246 .32869 L
.82316 .32312 L
.86234 .31924 L
.8838 .31769 L
.89362 .3171 L
.90398 .31658 L
.91358 .31616 L
.9241 .3158 L
.93366 .31554 L
.94258 .31537 L
.94691 .31531 L
.9492 .31528 L
.95162 .31526 L
.95373 .31524 L
.95607 .31522 L
.95709 .31522 L
.95819 .31522 L
.95922 .31521 L
.96017 .31521 L
.96111 .31521 L
.96211 .31521 L
.96305 .31521 L
.9639 .31521 L
.96491 .31521 L
.966 .31521 L
.96703 .31521 L
.96798 .31522 L
.96988 .31523 L
.97197 .31524 L
.97619 .31528 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.06244 .18499 L
.08255 .25705 L
.10458 .32353 L
.14415 .41367 L
.16372 .446 L
.18466 .47277 L
.19488 .48318 L
.20597 .49267 L
.21555 .49945 L
.22611 .5055 L
.23635 .51006 L
.24594 .51324 L
.25123 .51457 L
.25607 .51553 L
.25875 .51597 L
.26166 .51637 L
.26443 .51668 L
.26697 .5169 L
.26952 .51706 L
.27087 .51712 L
.27155 .51715 L
.27229 .51718 L
.27352 .51721 L
.27467 .51722 L
.27537 .51723 L
.27604 .51723 L
.27729 .51722 L
.27842 .5172 L
.27962 .51717 L
.28064 .51714 L
.28177 .51709 L
.28429 .51695 L
.28665 .51678 L
.29191 .51625 L
.29674 .51559 L
.30762 .51357 L
.31742 .51116 L
.32654 .50847 L
.34724 .50104 L
.38629 .48341 L
.42779 .46195 L
.46777 .44072 L
.50623 .42102 L
.54715 .40167 L
.58656 .38501 L
.62444 .37095 L
.66478 .35811 L
.70361 .34772 L
.74488 .33865 L
Mistroke
.78464 .33169 L
.82289 .32649 L
.84425 .32417 L
.86359 .32242 L
.88401 .32092 L
.90277 .31984 L
.92205 .31903 L
.93219 .31872 L
.93779 .31858 L
.94289 .31848 L
.94688 .31842 L
.95121 .31836 L
.95359 .31834 L
.95579 .31832 L
.95789 .3183 L
.95906 .31829 L
.96012 .31829 L
.96103 .31829 L
.96202 .31828 L
.96302 .31828 L
.96407 .31828 L
.96499 .31828 L
.96598 .31828 L
.96692 .31828 L
.96776 .31828 L
.96885 .31828 L
.96985 .31829 L
.97094 .31829 L
.9721 .31829 L
.97405 .31831 L
.97619 .31832 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.06244 .10391 L
.10458 .19004 L
.14415 .25932 L
.18221 .3147 L
.22272 .36114 L
.26171 .39367 L
.28302 .40659 L
.30316 .41583 L
.31285 .4193 L
.32313 .42231 L
.3319 .42437 L
.34157 .42611 L
.34677 .42683 L
.35171 .42737 L
.35614 .42775 L
.35863 .42792 L
.36098 .42805 L
.3623 .42811 L
.36373 .42816 L
.36491 .4282 L
.36622 .42823 L
.36763 .42826 L
.36841 .42827 L
.36913 .42828 L
.37042 .42828 L
.37114 .42828 L
.37181 .42828 L
.37309 .42827 L
.37428 .42826 L
.37558 .42823 L
.37697 .4282 L
.37929 .42812 L
.38186 .42801 L
.38677 .42771 L
.39195 .42728 L
.4012 .42625 L
.41116 .42478 L
.42206 .42277 L
.46262 .41225 L
.50167 .39883 L
.54316 .38252 L
.58315 .36591 L
.62161 .34987 L
.66253 .3333 L
.70193 .3182 L
.73982 .30467 L
.78016 .29146 L
.81899 .27998 L
.86026 .26909 L
Mistroke
.90002 .25986 L
.93827 .2521 L
.97619 .24546 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.06244 .18234 L
.08255 .25184 L
.10458 .31255 L
.11448 .33455 L
.12507 .35454 L
.13499 .37006 L
.14415 .38175 L
.15437 .39196 L
.15964 .39613 L
.16546 .3999 L
.17017 .40235 L
.17523 .4044 L
.17803 .40529 L
.18058 .40595 L
.18315 .40648 L
.1856 .40686 L
.18684 .40701 L
.18819 .40713 L
.18946 .40722 L
.19062 .40727 L
.19168 .40729 L
.19284 .4073 L
.19405 .40728 L
.19518 .40723 L
.19582 .4072 L
.19651 .40715 L
.19776 .40705 L
.20012 .40678 L
.20286 .40635 L
.2054 .40585 L
.20964 .40479 L
.21432 .40332 L
.22379 .39948 L
.24314 .38858 L
.26399 .37353 L
.30513 .33866 L
.34476 .30386 L
.38287 .27252 L
.42343 .24303 L
.46247 .21882 L
.50397 .19742 L
.54395 .1806 L
.58242 .16744 L
.62334 .15618 L
.66274 .14756 L
.70063 .14095 L
.74097 .13541 L
.77979 .13127 L
.82107 .12793 L
Mistroke
.86083 .12556 L
.89907 .12395 L
.91879 .12334 L
.92887 .12309 L
.93977 .12286 L
.94955 .12268 L
.95854 .12255 L
.96713 .12245 L
.97619 .12237 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.06244 .14215 L
.08255 .19883 L
.10458 .25172 L
.1253 .292 L
.14415 .3205 L
.16372 .34211 L
.17449 .35072 L
.18466 .35686 L
.19436 .36103 L
.19925 .36255 L
.20206 .36325 L
.20463 .36379 L
.20683 .36417 L
.20922 .3645 L
.21053 .36465 L
.21175 .36477 L
.21299 .36487 L
.21416 .36494 L
.21524 .365 L
.21642 .36504 L
.21749 .36506 L
.21847 .36506 L
.21954 .36505 L
.22071 .36503 L
.22193 .36498 L
.22307 .36492 L
.22434 .36484 L
.22567 .36473 L
.22808 .36448 L
.23067 .36413 L
.23353 .36367 L
.24343 .3614 L
.253 .35834 L
.26198 .35478 L
.30067 .33394 L
.34181 .30642 L
.38143 .27876 L
.41954 .25324 L
.4601 .22843 L
.49915 .20729 L
.54065 .18786 L
.58063 .17195 L
.6191 .15901 L
.66001 .14749 L
.69942 .13831 L
.7373 .131 L
.77764 .12462 L
.81647 .11963 L
.85774 .1154 L
Mistroke
.89751 .1122 L
.93575 .10981 L
.97619 .10794 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.04262 .08553 L
.0522 .11714 L
.06244 .14563 L
.0679 .15812 L
.07286 .16773 L
.0779 .17577 L
.08255 .18168 L
.08798 .18683 L
.09084 .18884 L
.09388 .19047 L
.09514 .19102 L
.09651 .19152 L
.09768 .19188 L
.09897 .1922 L
.09975 .19235 L
.10047 .19248 L
.10122 .19258 L
.1019 .19266 L
.1032 .19275 L
.10391 .19278 L
.10458 .19278 L
.10574 .19276 L
.10699 .19267 L
.10816 .19255 L
.10923 .1924 L
.11186 .19188 L
.11434 .19122 L
.11928 .18946 L
.12466 .18699 L
.14313 .1757 L
.18391 .14593 L
.22318 .11943 L
.26093 .09825 L
.30113 .08021 L
.33982 .06661 L
.38096 .05542 L
.42058 .04714 L
.45869 .041 L
.49925 .03596 L
.5383 .03226 L
.5798 .02925 L
.61978 .02705 L
.65824 .02543 L
.69916 .0241 L
.73857 .02313 L
.77645 .02241 L
.81679 .02183 L
.85562 .02139 L
.89689 .02104 L
Mistroke
.93666 .02079 L
.9749 .0206 L
.97619 .0206 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.06244 .11559 L
.10458 .21078 L
.14415 .28538 L
.18221 .34349 L
.22272 .39091 L
.26171 .42317 L
.28302 .43564 L
.29279 .44023 L
.30316 .44435 L
.31266 .44748 L
.32313 .45025 L
.33265 .45218 L
.34157 .4535 L
.34653 .45404 L
.34915 .45427 L
.35195 .45447 L
.35463 .45463 L
.35707 .45474 L
.35824 .45479 L
.35951 .45482 L
.3607 .45485 L
.36182 .45487 L
.3629 .45489 L
.36405 .4549 L
.36534 .4549 L
.36651 .45489 L
.36773 .45488 L
.36842 .45487 L
.36905 .45486 L
.37146 .4548 L
.37351 .45473 L
.37577 .45463 L
.38034 .45435 L
.38526 .45395 L
.39043 .45343 L
.39969 .45222 L
.42054 .44837 L
.44029 .44348 L
.45865 .43805 L
.4977 .42438 L
.5392 .40789 L
.57918 .39123 L
.61764 .37525 L
.65856 .35886 L
.69797 .34406 L
.73585 .33093 L
.77619 .31825 L
.81502 .30738 L
.85629 .29724 L
Mistroke
.89605 .28882 L
.9343 .28192 L
.975 .27582 L
.97619 .27566 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.06244 .10836 L
.10458 .19841 L
.14415 .27018 L
.18221 .32697 L
.22272 .3742 L
.26171 .40729 L
.28302 .42059 L
.30316 .43031 L
.31285 .43406 L
.32313 .43741 L
.33276 .44001 L
.34157 .44194 L
.35098 .44355 L
.35582 .44421 L
.3611 .4448 L
.36597 .44523 L
.37049 .44553 L
.37271 .44565 L
.3748 .44574 L
.37722 .44582 L
.3794 .44588 L
.38057 .4459 L
.38181 .44591 L
.38299 .44592 L
.38406 .44592 L
.38532 .44592 L
.38603 .44592 L
.38668 .44591 L
.38789 .4459 L
.38917 .44588 L
.39038 .44585 L
.3917 .44582 L
.39407 .44574 L
.39689 .44562 L
.39948 .44549 L
.40848 .44484 L
.41796 .44387 L
.4377 .44101 L
.45606 .43746 L
.49511 .42773 L
.53661 .41521 L
.57659 .40205 L
.61505 .38909 L
.65597 .37554 L
.69538 .36309 L
.73326 .35191 L
.7736 .341 L
.81243 .33156 L
.8537 .3227 L
Mistroke
.89347 .31533 L
.93171 .30931 L
.97241 .30403 L
.97619 .3036 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.06244 .12155 L
.08255 .16781 L
.0932 .18821 L
.10458 .20631 L
.11531 .21961 L
.12507 .22851 L
.12977 .23176 L
.13488 .23455 L
.1397 .23652 L
.14415 .23781 L
.14658 .23831 L
.14881 .23864 L
.15004 .23878 L
.15069 .23884 L
.15138 .23889 L
.15264 .23896 L
.15382 .239 L
.15499 .239 L
.15627 .23898 L
.15747 .23893 L
.15857 .23886 L
.15957 .23878 L
.16066 .23867 L
.16288 .23839 L
.16557 .23793 L
.16803 .23742 L
.17354 .23594 L
.1835 .23235 L
.20259 .22301 L
.22335 .21072 L
.26413 .18466 L
.3034 .16062 L
.34115 .13992 L
.38135 .12083 L
.42004 .10523 L
.46118 .09133 L
.5008 .08021 L
.53891 .07131 L
.57947 .06346 L
.61852 .05725 L
.66001 .05182 L
.7 .04756 L
.73846 .04418 L
.77938 .04125 L
.81878 .03894 L
.85667 .03713 L
.89701 .03555 L
.93584 .03431 L
.97619 .03327 L
Mistroke
Mfstroke
.174 1 0 r
.02381 .01472 m
.03279 .03806 L
.04262 .05842 L
.04758 .06581 L
.0503 .06904 L
.05288 .0716 L
.05528 .07359 L
.05789 .07536 L
.06008 .07657 L
.06244 .07763 L
.06506 .07854 L
.06751 .07918 L
.069 .07949 L
.07042 .07972 L
.07181 .0799 L
.07308 .08003 L
.07443 .08013 L
.07517 .08018 L
.07587 .08021 L
.07712 .08024 L
.07782 .08025 L
.07847 .08025 L
.07917 .08024 L
.07983 .08023 L
.08056 .08021 L
.08133 .08018 L
.08291 .0801 L
.08435 .08001 L
.08694 .07979 L
.08933 .07953 L
.09474 .07881 L
.10458 .07715 L
.14385 .06885 L
.1816 .0609 L
.2218 .05341 L
.26049 .04726 L
.30163 .04177 L
.34125 .03737 L
.37936 .03383 L
.41992 .03071 L
.45897 .02823 L
.50046 .02605 L
.54045 .02432 L
.57891 .02295 L
.61983 .02175 L
.65923 .02079 L
.69712 .02003 L
.73746 .01937 L
.77628 .01884 L
.81756 .01837 L
Mistroke
.85732 .01801 L
.89557 .01772 L
.93627 .01746 L
.97545 .01726 L
.97619 .01726 L
Mfstroke
.15 1 0 r
.02381 .01472 m
.02499 .01701 L
.02605 .01871 L
.02721 .02018 L
.02846 .02142 L
.02961 .02231 L
.03068 .02297 L
.03279 .02394 L
.03396 .02434 L
.03506 .02465 L
.03636 .02495 L
.03756 .02518 L
.04 .02554 L
.04134 .02568 L
.04262 .0258 L
.045 .02597 L
.04633 .02604 L
.04753 .02609 L
.04866 .02614 L
.04988 .02617 L
.05103 .0262 L
.0521 .02622 L
.05335 .02624 L
.05401 .02625 L
.05472 .02625 L
.05546 .02626 L
.05617 .02626 L
.05749 .02626 L
.05872 .02626 L
.05986 .02626 L
.06111 .02625 L
.06244 .02624 L
.06504 .02621 L
.06742 .02618 L
.07277 .02608 L
.08247 .02585 L
.10458 .02522 L
.1442 .02399 L
.18231 .02287 L
.22287 .02181 L
.26192 .0209 L
.30342 .02007 L
.3434 .01938 L
.38186 .0188 L
.42278 .01827 L
.46219 .01783 L
.50007 .01747 L
.54041 .01713 L
.57924 .01686 L
.62051 .01661 L
Mistroke
.66027 .0164 L
.69852 .01623 L
.73922 .01607 L
.7784 .01595 L
.82003 .01583 L
.86015 .01573 L
.89876 .01565 L
.93981 .01558 L
.97619 .01553 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.06244 .17537 L
.08255 .24408 L
.10458 .3071 L
.1253 .35503 L
.14415 .3896 L
.16372 .41708 L
.17461 .42895 L
.18466 .43791 L
.19377 .44448 L
.20381 .45014 L
.2139 .45427 L
.21942 .45592 L
.22459 .45709 L
.22955 .4579 L
.23236 .45822 L
.23371 .45834 L
.23497 .45844 L
.23617 .45851 L
.23748 .45857 L
.23866 .45861 L
.23975 .45863 L
.24093 .45864 L
.24222 .45863 L
.24287 .45862 L
.24357 .45861 L
.24484 .45857 L
.24608 .45851 L
.24722 .45844 L
.24981 .45824 L
.2521 .45801 L
.25453 .45772 L
.26336 .45618 L
.26825 .45505 L
.27273 .45384 L
.28283 .4506 L
.30111 .44313 L
.34074 .42198 L
.37885 .39831 L
.41941 .37242 L
.45845 .34855 L
.49995 .32537 L
.53993 .30565 L
.5784 .2892 L
.61932 .27431 L
.65872 .26233 L
.69661 .25279 L
.73695 .24451 L
.77577 .23816 L
.81705 .23293 L
Mistroke
.83768 .23085 L
.85681 .22921 L
.87651 .2278 L
.89505 .22672 L
.91562 .22579 L
.93423 .22519 L
.94402 .22496 L
.94937 .22486 L
.95435 .22478 L
.95897 .22472 L
.96317 .22468 L
.96541 .22467 L
.96784 .22465 L
.96917 .22465 L
.97041 .22464 L
.97166 .22464 L
.97284 .22463 L
.97361 .22463 L
.97443 .22463 L
.97535 .22463 L
.97619 .22463 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.06244 .14594 L
.10458 .26154 L
.12507 .30643 L
.14415 .3414 L
.16371 .37042 L
.18221 .39167 L
.192 .40056 L
.20263 .40845 L
.21228 .41409 L
.2212 .41806 L
.22586 .41969 L
.23087 .4211 L
.2356 .42213 L
.23993 .42282 L
.24255 .42312 L
.24498 .42333 L
.24638 .42342 L
.24765 .42347 L
.24836 .4235 L
.24912 .42352 L
.24984 .42353 L
.2505 .42354 L
.25171 .42354 L
.25283 .42352 L
.25406 .42348 L
.25476 .42346 L
.25539 .42343 L
.25666 .42336 L
.25804 .42326 L
.26055 .42303 L
.2654 .4224 L
.26995 .4216 L
.28033 .41905 L
.29044 .41569 L
.30133 .41121 L
.34247 .38828 L
.3821 .36094 L
.42021 .33318 L
.46077 .30438 L
.49981 .27869 L
.54131 .25424 L
.58129 .23369 L
.61976 .21664 L
.66068 .20124 L
.70008 .18881 L
.73797 .17882 L
.77831 .17004 L
.81713 .16316 L
.85841 .15729 L
Mistroke
.89817 .15286 L
.93641 .14958 L
.97619 .14708 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.04262 .10484 L
.06244 .18822 L
.08426 .26493 L
.10458 .32137 L
.12297 .35934 L
.13327 .37507 L
.14264 .38597 L
.14747 .39033 L
.15259 .39406 L
.15697 .39651 L
.15943 .39762 L
.16178 .39847 L
.16448 .39924 L
.16568 .39951 L
.16695 .39974 L
.16833 .39993 L
.16961 .40006 L
.17039 .40011 L
.17113 .40015 L
.1718 .40016 L
.17251 .40017 L
.17373 .40014 L
.17442 .4001 L
.17506 .40005 L
.17636 .39993 L
.17775 .39973 L
.18027 .39925 L
.18257 .39866 L
.18737 .39698 L
.19248 .39458 L
.20165 .38883 L
.21152 .38083 L
.22241 .37026 L
.26261 .32203 L
.3013 .27251 L
.34244 .22483 L
.38207 .18644 L
.42017 .15661 L
.46074 .13161 L
.49978 .11299 L
.54128 .09785 L
.58126 .08679 L
.61973 .07867 L
.66065 .0721 L
.70005 .06732 L
.73794 .06381 L
.77828 .06097 L
.8171 .05892 L
.85838 .05729 L
Mistroke
.89814 .05614 L
.93638 .05534 L
.95566 .05504 L
.97619 .05477 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.02499 .01707 L
.02605 .0188 L
.02721 .02028 L
.02846 .02154 L
.02961 .02244 L
.03068 .02311 L
.03279 .02409 L
.03396 .02449 L
.03506 .02481 L
.03636 .02512 L
.03756 .02535 L
.04 .02572 L
.04134 .02587 L
.04262 .026 L
.045 .02618 L
.0463 .02625 L
.04753 .02631 L
.04868 .02636 L
.04993 .0264 L
.0521 .02645 L
.05335 .02647 L
.05472 .02649 L
.05541 .0265 L
.05615 .02651 L
.05685 .02651 L
.05749 .02651 L
.05871 .02651 L
.0594 .02651 L
.06003 .02651 L
.0612 .02651 L
.06244 .0265 L
.06371 .02649 L
.06504 .02648 L
.06742 .02645 L
.07277 .02636 L
.08247 .02614 L
.10458 .02551 L
.14269 .02433 L
.18325 .02312 L
.22229 .02208 L
.26379 .02111 L
.30377 .02029 L
.34224 .01961 L
.38316 .01899 L
.42256 .01847 L
.46045 .01804 L
.50079 .01765 L
.53961 .01733 L
.58089 .01703 L
Mistroke
.62065 .01679 L
.6589 .01659 L
.69959 .01641 L
.73878 .01626 L
.78041 .01612 L
.82053 .01601 L
.85913 .01592 L
.90019 .01584 L
.93973 .01577 L
.97619 .01572 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.06244 .0938 L
.08255 .13013 L
.10458 .16384 L
.11448 .17646 L
.12507 .18806 L
.13499 .1971 L
.14415 .20389 L
.15437 .20976 L
.15975 .21217 L
.16546 .21424 L
.17041 .21565 L
.17504 .21668 L
.17765 .21713 L
.18013 .21748 L
.18298 .2178 L
.18424 .21791 L
.1856 .21801 L
.18695 .21808 L
.18819 .21814 L
.18937 .21818 L
.19062 .2182 L
.19175 .21821 L
.1928 .2182 L
.19395 .21818 L
.19518 .21815 L
.1965 .2181 L
.19793 .21803 L
.20053 .21785 L
.20306 .21762 L
.2054 .21737 L
.21432 .21601 L
.22379 .21401 L
.24326 .20851 L
.26154 .20215 L
.30023 .18676 L
.34137 .16966 L
.38099 .15379 L
.4191 .13962 L
.45966 .12593 L
.49871 .11414 L
.5402 .10306 L
.58019 .09368 L
.61865 .08575 L
.65957 .07838 L
.69897 .0722 L
.73686 .06701 L
.7772 .06221 L
.81603 .0582 L
.8573 .05451 L
Mistroke
.89706 .05146 L
.93531 .04891 L
.97601 .04657 L
.97619 .04656 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.06244 .12673 L
.10458 .22875 L
.12507 .26917 L
.14415 .30112 L
.16371 .3282 L
.18221 .34873 L
.20263 .36601 L
.2212 .37725 L
.2309 .38156 L
.24117 .38507 L
.24995 .38725 L
.25494 .38818 L
.25962 .38885 L
.26202 .38912 L
.26458 .38936 L
.26739 .38957 L
.27 .3897 L
.27128 .38975 L
.27195 .38977 L
.27266 .38979 L
.27397 .38981 L
.27517 .38982 L
.27633 .38982 L
.27741 .38981 L
.27859 .38979 L
.27986 .38976 L
.2811 .38971 L
.28225 .38967 L
.28484 .38952 L
.28712 .38936 L
.28955 .38915 L
.29839 .38809 L
.30328 .38731 L
.30776 .38648 L
.31786 .38424 L
.33614 .37905 L
.37576 .36408 L
.41387 .34685 L
.45443 .32737 L
.49348 .30876 L
.53497 .28997 L
.57496 .27331 L
.61342 .25884 L
.65434 .24518 L
.69374 .23371 L
.73163 .22415 L
.77197 .21545 L
.8108 .20841 L
.85207 .20222 L
Mistroke
.89183 .19742 L
.93008 .19379 L
.97078 .1909 L
.97619 .19059 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.04262 .11874 L
.06244 .2121 L
.08426 .29544 L
.10458 .35539 L
.12297 .39543 L
.13327 .41217 L
.14264 .42398 L
.14747 .42884 L
.15259 .43311 L
.15702 .43608 L
.16178 .43855 L
.16445 .43962 L
.16689 .44041 L
.16934 .44101 L
.17056 .44124 L
.17167 .44142 L
.17298 .44158 L
.1737 .44164 L
.17437 .44169 L
.17558 .44174 L
.17688 .44175 L
.17757 .44174 L
.17832 .44171 L
.17911 .44166 L
.17984 .4416 L
.18116 .44146 L
.18257 .44126 L
.18513 .44075 L
.18785 .44003 L
.19274 .43827 L
.198 .43576 L
.20381 .4323 L
.22393 .41549 L
.24327 .39409 L
.26413 .36761 L
.30527 .31242 L
.34489 .26277 L
.383 .22186 L
.42356 .18642 L
.46261 .15954 L
.50411 .1375 L
.54409 .12134 L
.58255 .10948 L
.62347 .0999 L
.66288 .09294 L
.70076 .08784 L
.7411 .08372 L
.77993 .08074 L
.8212 .07838 L
Mistroke
.86097 .07673 L
.89921 .07558 L
.91892 .07514 L
.93991 .07476 L
.9586 .0745 L
.97619 .07431 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.06244 .17438 L
.10458 .3079 L
.12507 .35827 L
.14415 .39749 L
.16371 .43063 L
.18221 .45598 L
.20263 .47792 L
.2212 .49296 L
.2309 .49914 L
.24117 .50454 L
.2508 .5086 L
.25962 .51153 L
.26903 .51389 L
.27422 .51487 L
.27915 .51561 L
.28369 .51612 L
.2879 .51646 L
.29032 .5166 L
.29252 .5167 L
.29374 .51673 L
.29506 .51676 L
.2963 .51678 L
.29745 .51679 L
.29871 .51678 L
.29991 .51677 L
.30098 .51675 L
.30215 .51673 L
.30342 .51669 L
.30477 .51663 L
.30719 .51651 L
.31151 .51621 L
.31627 .51576 L
.32693 .51433 L
.33694 .51249 L
.35712 .50757 L
.37563 .5019 L
.41525 .4872 L
.45336 .4713 L
.49392 .45395 L
.53296 .43782 L
.57446 .42192 L
.61444 .40818 L
.65291 .39658 L
.69383 .38602 L
.73323 .37753 L
.77112 .37085 L
.81146 .36527 L
.85028 .36128 L
.87146 .35965 L
Mistroke
.89156 .35845 L
.90117 .358 L
.9114 .3576 L
.92106 .3573 L
.9298 .3571 L
.93469 .35701 L
.93985 .35694 L
.94198 .35692 L
.94426 .3569 L
.94557 .35689 L
.94676 .35688 L
.94787 .35688 L
.94909 .35687 L
.95038 .35687 L
.95109 .35687 L
.95176 .35686 L
.95294 .35686 L
.95422 .35686 L
.9549 .35686 L
.95564 .35686 L
.95641 .35687 L
.95713 .35687 L
.95842 .35687 L
.95979 .35688 L
.96253 .3569 L
.9651 .35692 L
.96992 .35697 L
.97619 .35708 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.06244 .10788 L
.10458 .19545 L
.12507 .23129 L
.14415 .25999 L
.16371 .28429 L
.18221 .30226 L
.192 .30979 L
.20263 .31642 L
.21228 .32109 L
.2212 .32431 L
.22586 .32559 L
.23087 .32667 L
.23329 .32709 L
.2356 .32742 L
.23787 .32768 L
.23993 .32787 L
.24112 .32796 L
.2424 .32804 L
.24311 .32808 L
.24376 .32811 L
.24504 .32815 L
.24614 .32817 L
.24735 .32818 L
.24861 .32818 L
.24979 .32816 L
.25046 .32814 L
.25118 .32812 L
.25251 .32806 L
.25379 .32799 L
.25498 .32791 L
.25768 .32767 L
.26055 .32735 L
.26544 .32664 L
.26992 .3258 L
.28002 .32334 L
.2983 .31712 L
.33793 .29816 L
.37604 .27616 L
.4166 .25168 L
.45564 .22876 L
.49714 .20609 L
.53712 .1863 L
.57559 .16928 L
.61651 .15331 L
.65591 .13987 L
.6938 .12861 L
.73414 .11821 L
.77296 .10959 L
.81424 .10173 L
Mistroke
.854 .09529 L
.89224 .08999 L
.93294 .0852 L
.97212 .0813 L
.97619 .08093 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.06244 .14497 L
.10458 .26061 L
.12507 .30632 L
.14415 .3426 L
.16371 .37344 L
.18221 .39672 L
.192 .40678 L
.20263 .41597 L
.21222 .42275 L
.2212 .42784 L
.23064 .43193 L
.23565 .4336 L
.24104 .43501 L
.24373 .43557 L
.24667 .43608 L
.24944 .43646 L
.25077 .4366 L
.25202 .43672 L
.25325 .43682 L
.25457 .4369 L
.25578 .43696 L
.25688 .437 L
.25809 .43703 L
.2594 .43704 L
.26007 .43703 L
.26078 .43703 L
.26207 .43699 L
.26329 .43695 L
.26463 .43688 L
.26603 .43678 L
.26735 .43667 L
.27224 .43611 L
.27502 .43568 L
.27757 .43521 L
.28331 .43393 L
.29311 .43104 L
.30343 .42712 L
.34154 .40655 L
.3821 .37801 L
.42114 .34806 L
.46264 .31654 L
.50262 .28818 L
.54109 .26354 L
.58201 .2405 L
.62141 .22136 L
.6593 .20564 L
.69964 .1915 L
.73846 .18015 L
.77974 .17021 L
Mistroke
.8195 .16242 L
.85774 .15635 L
.89844 .15121 L
.93762 .14738 L
.97619 .14455 L
Mfstroke
0 1 .111 r
.02381 .01472 m
.03279 .04669 L
.04262 .07489 L
.04758 .08532 L
.0503 .08993 L
.05288 .09359 L
.05528 .09643 L
.05789 .09895 L
.06008 .10066 L
.06244 .10212 L
.06506 .10335 L
.06751 .10417 L
.069 .10453 L
.07042 .10479 L
.07169 .10496 L
.07241 .10503 L
.07308 .10507 L
.07379 .10511 L
.07455 .10513 L
.07528 .10514 L
.07594 .10513 L
.0772 .10508 L
.07784 .10504 L
.07854 .10498 L
.07999 .10484 L
.08154 .10463 L
.08435 .10415 L
.08979 .10289 L
.09493 .1014 L
.10458 .09812 L
.14291 .08333 L
.18369 .06895 L
.22296 .05763 L
.26071 .04893 L
.30091 .04164 L
.3396 .03616 L
.38074 .03164 L
.42036 .02829 L
.45847 .02578 L
.49903 .02372 L
.53808 .02218 L
.57958 .02092 L
.61956 .02 L
.65802 .0193 L
.69894 .01874 L
.73835 .01831 L
.77623 .018 L
.81657 .01774 L
.8554 .01754 L
.89667 .01738 L
Mistroke
.93643 .01727 L
.97468 .01718 L
.97619 .01717 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.06244 .11696 L
.10458 .2138 L
.14415 .29032 L
.18221 .3515 L
.22272 .40444 L
.26171 .4447 L
.30316 .47726 L
.32392 .49002 L
.34309 .49989 L
.36292 .50832 L
.3815 .51471 L
.40022 .51978 L
.4108 .52209 L
.42085 .52393 L
.43053 .5254 L
.4411 .52669 L
.4507 .52758 L
.45962 .52819 L
.4647 .52845 L
.46737 .52856 L
.47019 .52865 L
.47266 .52872 L
.47537 .52878 L
.47656 .5288 L
.47784 .52882 L
.47896 .52883 L
.48014 .52885 L
.48139 .52885 L
.48254 .52886 L
.48378 .52886 L
.48448 .52886 L
.48514 .52886 L
.48633 .52885 L
.48742 .52885 L
.48862 .52884 L
.48988 .52882 L
.49207 .52879 L
.49412 .52875 L
.49875 .52863 L
.5038 .52846 L
.50927 .52821 L
.51921 .52763 L
.5378 .52612 L
.55767 .52398 L
.57872 .52121 L
.6166 .51526 L
.65694 .50804 L
.69577 .50071 L
.73704 .49289 L
Mistroke
.7768 .48566 L
.81505 .4792 L
.85575 .47301 L
.89493 .46786 L
.93656 .46336 L
.97619 .46008 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.06244 .20253 L
.08255 .27954 L
.10458 .34903 L
.14415 .44047 L
.16372 .47239 L
.18466 .49845 L
.19488 .50849 L
.20597 .51762 L
.21555 .52413 L
.22611 .52996 L
.23635 .53437 L
.24594 .53749 L
.25114 .5388 L
.25607 .53981 L
.26177 .54072 L
.26445 .54105 L
.26697 .54131 L
.26939 .54151 L
.27066 .54159 L
.272 .54167 L
.27313 .54173 L
.27437 .54178 L
.2755 .54181 L
.27656 .54184 L
.27719 .54185 L
.27788 .54186 L
.27914 .54186 L
.28036 .54186 L
.28149 .54185 L
.28271 .54183 L
.2834 .54181 L
.28405 .54179 L
.28678 .54168 L
.28903 .54155 L
.29139 .54138 L
.29563 .541 L
.30018 .54046 L
.30517 .53975 L
.32478 .53577 L
.34573 .52979 L
.38722 .51443 L
.42721 .49729 L
.46567 .48027 L
.50659 .46274 L
.54599 .44712 L
.58388 .43361 L
.62422 .42103 L
.66305 .41071 L
.70432 .4016 L
Mistroke
.74408 .39456 L
.78233 .38928 L
.80369 .38694 L
.82303 .38518 L
.84345 .38367 L
.86221 .38261 L
.87141 .3822 L
.88149 .38183 L
.89163 .38154 L
.89717 .38142 L
.90233 .38133 L
.90735 .38126 L
.91018 .38124 L
.9128 .38122 L
.91509 .3812 L
.91639 .3812 L
.91761 .3812 L
.9189 .38119 L
.92007 .38119 L
.92136 .38119 L
.92201 .38119 L
.92272 .3812 L
.92397 .3812 L
.92516 .3812 L
.92738 .38121 L
.92976 .38123 L
.93234 .38125 L
.937 .38131 L
.94129 .38138 L
.94989 .38156 L
.95792 .38179 L
.97619 .38253 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.04262 .08204 L
.06244 .14297 L
.07216 .16711 L
.08255 .18789 L
.08852 .19733 L
.09396 .20433 L
.09942 .2099 L
.10458 .21387 L
.10919 .21643 L
.11182 .21749 L
.11428 .21825 L
.1156 .21857 L
.11686 .21881 L
.11799 .21898 L
.11923 .21912 L
.11993 .21918 L
.12056 .21922 L
.1213 .21925 L
.12199 .21926 L
.12322 .21924 L
.12392 .21922 L
.12455 .21918 L
.12562 .21909 L
.12676 .21896 L
.12883 .21864 L
.13128 .21813 L
.13352 .21754 L
.13839 .2159 L
.14299 .21394 L
.1629 .20238 L
.18132 .1892 L
.22059 .1597 L
.25834 .13382 L
.29854 .11055 L
.33723 .09231 L
.37837 .07682 L
.418 .06505 L
.4561 .05609 L
.49666 .04859 L
.53571 .04294 L
.57721 .03826 L
.61719 .03477 L
.65566 .03214 L
.69657 .02996 L
.73598 .02833 L
.77386 .0271 L
.8142 .02608 L
.85303 .02532 L
.89431 .02469 L
Mistroke
.93407 .02422 L
.97231 .02388 L
.97619 .02385 L
Mfstroke
0 1 .206 r
.02381 .01472 m
.06244 .1376 L
.10458 .2488 L
.14415 .33254 L
.18221 .39632 L
.22272 .44843 L
.26171 .48516 L
.28302 .5003 L
.30316 .51173 L
.32313 .52053 L
.34157 .5266 L
.35124 .52905 L
.36029 .53092 L
.37023 .53252 L
.37577 .53322 L
.38092 .53374 L
.38581 .53413 L
.39102 .53445 L
.394 .53458 L
.39546 .53463 L
.39681 .53467 L
.39801 .53469 L
.39933 .53472 L
.40065 .53474 L
.40138 .53475 L
.40205 .53475 L
.4033 .53476 L
.40401 .53476 L
.40466 .53476 L
.40586 .53475 L
.40713 .53474 L
.40826 .53472 L
.40932 .5347 L
.41175 .53464 L
.41436 .53456 L
.41675 .53446 L
.42214 .53417 L
.42688 .53383 L
.43195 .53339 L
.44107 .53242 L
.46177 .52936 L
.48311 .52515 L
.50327 .52037 L
.54173 .50962 L
.58265 .49669 L
.62205 .48361 L
.65994 .47104 L
.70028 .45811 L
.73911 .44644 L
.78038 .43511 L
Mistroke
.82014 .42539 L
.85839 .41722 L
.89909 .40984 L
.93827 .40403 L
.97619 .39962 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.06244 .15441 L
.10458 .2768 L
.14415 .36507 L
.18221 .42913 L
.20342 .45717 L
.22272 .47848 L
.26171 .51082 L
.28086 .52211 L
.30164 .53143 L
.32148 .5378 L
.33148 .54018 L
.34251 .54221 L
.3477 .54297 L
.35264 .54357 L
.35713 .54402 L
.36192 .54441 L
.36463 .54459 L
.36709 .54473 L
.36959 .54485 L
.3719 .54493 L
.37459 .54501 L
.37601 .54504 L
.37673 .54505 L
.37751 .54506 L
.37881 .54507 L
.38003 .54508 L
.38077 .54508 L
.38147 .54508 L
.38279 .54508 L
.38393 .54507 L
.38516 .54505 L
.38632 .54503 L
.38738 .54501 L
.38985 .54495 L
.39245 .54486 L
.39735 .54463 L
.4027 .54431 L
.41225 .54352 L
.42112 .54257 L
.44158 .53969 L
.46017 .53637 L
.50015 .52757 L
.53862 .51777 L
.57954 .50678 L
.61894 .49627 L
.65683 .48663 L
.69717 .47716 L
.73599 .46902 L
.77727 .46153 L
Mistroke
.81703 .45552 L
.85527 .45089 L
.87663 .44881 L
.89597 .44722 L
.91639 .44587 L
.93515 .44493 L
.94454 .44456 L
.95444 .44425 L
.96438 .44402 L
.97001 .44393 L
.97527 .44387 L
.97619 .44386 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.06244 .10968 L
.08255 .15416 L
.10458 .19716 L
.1253 .23075 L
.14415 .25466 L
.15354 .26406 L
.16372 .27238 L
.17449 .2791 L
.17974 .28164 L
.18466 .28359 L
.18959 .28514 L
.1941 .28624 L
.1965 .28669 L
.19911 .28709 L
.20054 .28727 L
.20187 .28741 L
.20324 .28753 L
.2045 .28762 L
.20582 .28769 L
.20651 .28772 L
.20725 .28774 L
.20848 .28776 L
.20918 .28776 L
.20984 .28776 L
.21106 .28774 L
.21217 .28771 L
.21346 .28765 L
.21468 .28758 L
.21738 .28736 L
.21987 .28709 L
.22553 .28622 L
.23016 .28527 L
.23515 .28403 L
.24419 .28127 L
.26479 .27296 L
.30593 .25125 L
.34556 .22798 L
.38367 .20592 L
.42423 .18403 L
.46327 .16502 L
.50477 .14718 L
.54475 .13222 L
.58322 .11974 L
.62414 .10833 L
.66354 .09894 L
.70143 .09121 L
.74177 .08421 L
.78059 .0785 L
.82187 .07338 L
Mistroke
.86163 .06925 L
.89987 .06591 L
.94057 .06294 L
.97619 .06077 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.04262 .05678 L
.0522 .07439 L
.06244 .08914 L
.0679 .09518 L
.07286 .09964 L
.0779 .10324 L
.08255 .10583 L
.08798 .10806 L
.09084 .10895 L
.09388 .10969 L
.09651 .11018 L
.09897 .11054 L
.10036 .11069 L
.10167 .11081 L
.10319 .11092 L
.10391 .11096 L
.10458 .11099 L
.10582 .11103 L
.10648 .11104 L
.10717 .11105 L
.10833 .11106 L
.10961 .11104 L
.11075 .11102 L
.11197 .11097 L
.11312 .11092 L
.11417 .11086 L
.11668 .11067 L
.11941 .11042 L
.12439 .10982 L
.13394 .10828 L
.14277 .10653 L
.18204 .097 L
.21979 .08735 L
.25999 .07777 L
.29868 .06954 L
.33982 .06189 L
.37944 .05554 L
.41755 .05027 L
.45811 .04546 L
.49716 .04152 L
.53866 .03795 L
.57864 .03504 L
.6171 .03266 L
.65802 .03051 L
.69743 .02876 L
.73531 .02732 L
.77565 .02603 L
.81448 .02497 L
.85575 .02402 L
Mistroke
.89552 .02325 L
.93376 .02262 L
.97446 .02206 L
.97619 .02204 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.06244 .10447 L
.10458 .19114 L
.14415 .26069 L
.18221 .31613 L
.22272 .36257 L
.26171 .39524 L
.28302 .40834 L
.30316 .41783 L
.31285 .42144 L
.32313 .42464 L
.33276 .42705 L
.34157 .4288 L
.35098 .43019 L
.35617 .43076 L
.3611 .43118 L
.3633 .43132 L
.36564 .43145 L
.36766 .43154 L
.36985 .43162 L
.3712 .43165 L
.37243 .43168 L
.37361 .4317 L
.37486 .43171 L
.37598 .43171 L
.37703 .43171 L
.37817 .4317 L
.3794 .43169 L
.38062 .43167 L
.38197 .43164 L
.38469 .43156 L
.38721 .43145 L
.38958 .43133 L
.3949 .43097 L
.40064 .43045 L
.41114 .4292 L
.42077 .4277 L
.43969 .42392 L
.46039 .41868 L
.50095 .40584 L
.54 .39137 L
.58149 .37484 L
.62148 .35864 L
.65994 .34335 L
.70086 .3278 L
.74026 .31378 L
.77815 .30133 L
.81849 .28926 L
.85731 .27882 L
.89859 .26898 L
Mistroke
.93835 .26069 L
.97619 .25386 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.06244 .1965 L
.08255 .27173 L
.10458 .34054 L
.14415 .43425 L
.16372 .46886 L
.18466 .49881 L
.20597 .52282 L
.22611 .54038 L
.24608 .55357 L
.26452 .56253 L
.27419 .56615 L
.28325 .56893 L
.29318 .57135 L
.29872 .57243 L
.30387 .57328 L
.30917 .57399 L
.31398 .57451 L
.31931 .57496 L
.32224 .57514 L
.32501 .57528 L
.32745 .57537 L
.32868 .5754 L
.33003 .57544 L
.33119 .57546 L
.33242 .57547 L
.33359 .57548 L
.33466 .57548 L
.3353 .57548 L
.33599 .57548 L
.33722 .57547 L
.33791 .57546 L
.33855 .57546 L
.34002 .57543 L
.34129 .5754 L
.34246 .57537 L
.3451 .57527 L
.34984 .57504 L
.3549 .5747 L
.36402 .57387 L
.37486 .57256 L
.38472 .57109 L
.4247 .56297 L
.46317 .55301 L
.50409 .54132 L
.54349 .52987 L
.58138 .51923 L
.62172 .5087 L
.66054 .4996 L
.70182 .49118 L
Mistroke
.74158 .48437 L
.77982 .47905 L
.80118 .4766 L
.82052 .47471 L
.84094 .47304 L
.8597 .4718 L
.87899 .47083 L
.88913 .47044 L
.89982 .47012 L
.90932 .46991 L
.91465 .46982 L
.91717 .46979 L
.9195 .46977 L
.92165 .46975 L
.92402 .46973 L
.92516 .46973 L
.9264 .46972 L
.9277 .46972 L
.92893 .46972 L
.93001 .46972 L
.9312 .46972 L
.93243 .46972 L
.93358 .46972 L
.93466 .46972 L
.93564 .46973 L
.93785 .46974 L
.94007 .46975 L
.9425 .46977 L
.94743 .46983 L
.95199 .4699 L
.95626 .46999 L
.96587 .47024 L
.97619 .4706 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.06244 .15518 L
.10458 .27815 L
.14415 .3661 L
.18221 .42874 L
.20178 .45369 L
.22272 .47558 L
.24259 .49223 L
.26416 .50626 L
.28492 .51627 L
.29482 .51996 L
.30409 .52285 L
.31387 .52533 L
.32282 .52712 L
.33275 .52862 L
.33823 .52924 L
.34344 .5297 L
.34603 .52988 L
.34847 .53003 L
.35069 .53014 L
.35303 .53023 L
.35425 .53027 L
.35559 .53031 L
.35682 .53034 L
.35794 .53035 L
.35857 .53036 L
.35926 .53037 L
.35999 .53038 L
.36068 .53038 L
.36133 .53039 L
.36202 .53039 L
.36325 .53038 L
.36438 .53037 L
.36542 .53036 L
.36656 .53035 L
.36776 .53032 L
.36978 .53027 L
.37199 .5302 L
.37699 .52998 L
.38164 .52969 L
.39216 .5288 L
.40209 .52767 L
.42068 .5249 L
.45915 .51706 L
.50007 .50671 L
.53947 .49584 L
.57736 .48526 L
.6177 .47441 L
.65652 .46473 L
.6978 .4555 L
Mistroke
.73756 .4478 L
.7758 .44156 L
.8165 .4362 L
.85568 .43232 L
.87713 .43071 L
.89732 .42955 L
.90711 .4291 L
.91743 .42872 L
.92625 .42846 L
.93592 .42825 L
.94115 .42817 L
.94372 .42814 L
.9461 .42811 L
.94821 .4281 L
.95054 .42808 L
.95175 .42808 L
.95288 .42807 L
.95408 .42807 L
.95537 .42807 L
.95668 .42807 L
.9579 .42807 L
.9586 .42807 L
.95924 .42807 L
.95997 .42807 L
.96067 .42807 L
.96206 .42808 L
.96334 .42809 L
.96624 .42811 L
.96854 .42813 L
.97108 .42816 L
.97619 .42824 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.06244 .10682 L
.10458 .19301 L
.12507 .22805 L
.14415 .25608 L
.16371 .27991 L
.18221 .2978 L
.192 .30547 L
.20263 .31242 L
.21222 .31751 L
.2212 .32128 L
.23064 .32428 L
.23565 .32548 L
.24104 .32649 L
.24373 .32689 L
.24667 .32724 L
.24944 .3275 L
.25077 .3276 L
.25202 .32768 L
.25325 .32775 L
.25457 .3278 L
.25578 .32784 L
.25688 .32786 L
.25809 .32787 L
.2594 .32787 L
.26007 .32786 L
.26078 .32785 L
.26207 .32782 L
.26329 .32778 L
.26463 .32772 L
.26735 .32756 L
.26987 .32736 L
.27224 .32712 L
.27757 .32645 L
.28331 .32551 L
.2938 .32323 L
.30343 .3206 L
.34305 .30548 L
.38116 .28689 L
.42172 .26537 L
.46077 .24458 L
.50227 .22345 L
.54225 .20459 L
.58071 .18806 L
.62163 .17227 L
.66104 .15879 L
.69892 .14732 L
.73926 .13661 L
.77809 .12762 L
.81936 .11934 L
Mistroke
.85912 .11247 L
.89737 .10677 L
.93807 .10157 L
.97619 .09741 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.06244 .14187 L
.10458 .25615 L
.14415 .34016 L
.18221 .40124 L
.20342 .42771 L
.22272 .44753 L
.24299 .46435 L
.26171 .47656 L
.28086 .48608 L
.29159 .49022 L
.30164 .49338 L
.31142 .49583 L
.32037 .49757 L
.3303 .49896 L
.33578 .49951 L
.33846 .49972 L
.34099 .49989 L
.34341 .50002 L
.34602 .50013 L
.34717 .50017 L
.34839 .5002 L
.34953 .50023 L
.35058 .50025 L
.35179 .50026 L
.3531 .50027 L
.3543 .50027 L
.35545 .50027 L
.35609 .50026 L
.35678 .50025 L
.35801 .50024 L
.35933 .50021 L
.3608 .50017 L
.36318 .50009 L
.36536 .5 L
.37028 .49972 L
.37462 .4994 L
.37918 .49899 L
.38873 .49789 L
.39892 .49641 L
.41729 .493 L
.45879 .48262 L
.49877 .47039 L
.53724 .45768 L
.57816 .44401 L
.61756 .43131 L
.65545 .41992 L
.69579 .40891 L
.73461 .39955 L
.77589 .39101 L
Mistroke
.81565 .38417 L
.85389 .37887 L
.87525 .37645 L
.89459 .37459 L
.91501 .37296 L
.93377 .37177 L
.95306 .37085 L
.9632 .37049 L
.97389 .37021 L
.97619 .37016 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.06244 .14081 L
.10458 .25405 L
.14415 .33636 L
.18221 .39427 L
.20178 .41644 L
.22272 .43486 L
.23293 .44197 L
.24402 .44839 L
.25361 .45289 L
.26416 .45679 L
.2691 .45825 L
.2744 .45957 L
.27899 .46052 L
.284 .46134 L
.28692 .46172 L
.28963 .46202 L
.29244 .46226 L
.29498 .46243 L
.29618 .46249 L
.29749 .46254 L
.29871 .46258 L
.29984 .46261 L
.30105 .46263 L
.30237 .46264 L
.30303 .46264 L
.30374 .46263 L
.30503 .46261 L
.30625 .46259 L
.30759 .46254 L
.309 .46249 L
.31031 .46242 L
.3152 .46207 L
.31798 .46181 L
.32053 .46152 L
.32627 .46073 L
.33607 .45893 L
.34639 .45648 L
.36613 .45043 L
.3845 .44344 L
.42354 .42554 L
.46504 .40396 L
.50502 .38251 L
.54349 .36241 L
.58441 .34238 L
.62381 .32483 L
.6617 .30975 L
.70204 .29568 L
.74086 .28402 L
.78214 .27355 L
Mistroke
.8219 .26521 L
.86015 .25866 L
.90084 .25316 L
.94002 .24919 L
.97619 .2466 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.03279 .04315 L
.04262 .07102 L
.05288 .09445 L
.06244 .11015 L
.06792 .11651 L
.0731 .12096 L
.07775 .12381 L
.08038 .125 L
.0828 .12587 L
.08405 .12623 L
.0854 .12656 L
.08656 .12681 L
.08783 .12702 L
.08932 .12722 L
.09 .12729 L
.09073 .12735 L
.09145 .1274 L
.0921 .12743 L
.09337 .12746 L
.09408 .12746 L
.09482 .12746 L
.09545 .12744 L
.09615 .12741 L
.09689 .12737 L
.0977 .12732 L
.09914 .12719 L
.10199 .12683 L
.10458 .1264 L
.10939 .12537 L
.11449 .12401 L
.12366 .12107 L
.14443 .11312 L
.18218 .09772 L
.22238 .08278 L
.26107 .07058 L
.30221 .0599 L
.34183 .05157 L
.37994 .04506 L
.4205 .03948 L
.45954 .03517 L
.50104 .03152 L
.54102 .02872 L
.57949 .02656 L
.62041 .02473 L
.65981 .02332 L
.6977 .02224 L
.73804 .02132 L
.77686 .02061 L
.81814 .02001 L
Mistroke
.8579 .01955 L
.89615 .0192 L
.93684 .01891 L
.97603 .01868 L
.97619 .01868 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.06244 .14685 L
.10458 .26425 L
.14415 .35074 L
.18221 .41534 L
.22272 .46721 L
.26171 .50326 L
.28302 .518 L
.30316 .52906 L
.32313 .53754 L
.34157 .54336 L
.35124 .5457 L
.36029 .54748 L
.37023 .54899 L
.37581 .54965 L
.38092 .55013 L
.38569 .55049 L
.3883 .55065 L
.39077 .55077 L
.39307 .55086 L
.39556 .55094 L
.39666 .55097 L
.39782 .55099 L
.39889 .55101 L
.39991 .55102 L
.4012 .55103 L
.40237 .55104 L
.40364 .55104 L
.40435 .55103 L
.40501 .55103 L
.40611 .55102 L
.40733 .551 L
.40859 .55098 L
.40978 .55095 L
.41251 .55087 L
.415 .55078 L
.42063 .55049 L
.42537 .55017 L
.43043 .54975 L
.43955 .54881 L
.46025 .54584 L
.4816 .54174 L
.50175 .53706 L
.54022 .52647 L
.58114 .51366 L
.62054 .50061 L
.65843 .48799 L
.69877 .47494 L
.73759 .46311 L
.77887 .45156 L
Mistroke
.81863 .4416 L
.85687 .4332 L
.89757 .42557 L
.93675 .41955 L
.97619 .4148 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.06244 .16433 L
.10458 .2922 L
.14415 .38296 L
.18221 .4488 L
.22272 .5007 L
.26171 .53673 L
.28302 .55169 L
.30316 .56322 L
.32144 .57171 L
.34157 .57914 L
.36141 .58468 L
.37239 .58707 L
.38244 .58887 L
.39172 .59021 L
.40184 .59136 L
.4074 .59186 L
.41255 .59224 L
.41785 .59255 L
.42272 .59277 L
.42514 .59285 L
.4278 .59293 L
.43047 .59299 L
.43193 .59301 L
.43329 .59303 L
.43458 .59304 L
.4358 .59305 L
.4369 .59306 L
.4381 .59306 L
.43939 .59306 L
.44005 .59305 L
.44077 .59305 L
.44205 .59304 L
.44325 .59303 L
.44552 .59299 L
.44792 .59295 L
.4522 .59283 L
.45681 .59266 L
.46185 .59243 L
.47213 .5918 L
.48146 .59107 L
.50241 .58891 L
.5424 .58325 L
.58086 .57648 L
.62178 .56852 L
.66118 .56062 L
.69907 .55319 L
.73941 .54574 L
.77824 .53925 L
.81951 .53324 L
Mistroke
.85927 .52845 L
.89752 .52484 L
.91723 .52338 L
.93822 .52214 L
.94762 .52169 L
.95778 .52128 L
.97619 .52074 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.06244 .17978 L
.10458 .31625 L
.14415 .40882 L
.18221 .47208 L
.20178 .49661 L
.22272 .51778 L
.24402 .53463 L
.26416 .54679 L
.28414 .55573 L
.30258 .5616 L
.31224 .56387 L
.3213 .56554 L
.33124 .5669 L
.33682 .56747 L
.34193 .56787 L
.34669 .56814 L
.34936 .56826 L
.35177 .56834 L
.35403 .56839 L
.35531 .56841 L
.35648 .56843 L
.35751 .56844 L
.35863 .56844 L
.35981 .56844 L
.36091 .56844 L
.3622 .56843 L
.36293 .56842 L
.3636 .56841 L
.36481 .56839 L
.36614 .56837 L
.36846 .5683 L
.37091 .56822 L
.37644 .56796 L
.38164 .56763 L
.39147 .56681 L
.40182 .56568 L
.42032 .56306 L
.45843 .55586 L
.49899 .54652 L
.53804 .53682 L
.57954 .5265 L
.61952 .51703 L
.65798 .50869 L
.6989 .50084 L
.73831 .4944 L
.77619 .48931 L
.81653 .4851 L
.83511 .48359 L
.85536 .48225 L
Mistroke
.86634 .48165 L
.87653 .48119 L
.88619 .48082 L
.89663 .48051 L
.90215 .48038 L
.90723 .48028 L
.91208 .48021 L
.91455 .48018 L
.9172 .48015 L
.9196 .48013 L
.92179 .48012 L
.92285 .48011 L
.92399 .48011 L
.92508 .48011 L
.92608 .4801 L
.92724 .4801 L
.92833 .4801 L
.92952 .4801 L
.9308 .48011 L
.93208 .48011 L
.93342 .48011 L
.93582 .48013 L
.9384 .48015 L
.94083 .48017 L
.94539 .48023 L
.95029 .48031 L
.9556 .48042 L
.96517 .48068 L
.97398 .481 L
.97619 .48109 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.02499 .01698 L
.02605 .01866 L
.02721 .02012 L
.02846 .02138 L
.02961 .02229 L
.03068 .02298 L
.03279 .024 L
.03396 .02443 L
.03506 .02476 L
.03756 .02535 L
.04 .02576 L
.04262 .02608 L
.04516 .0263 L
.04793 .02647 L
.04919 .02653 L
.05054 .02658 L
.05297 .02666 L
.0542 .02669 L
.05553 .02671 L
.05679 .02673 L
.05794 .02674 L
.05898 .02675 L
.06013 .02676 L
.06133 .02676 L
.06244 .02676 L
.0631 .02676 L
.0638 .02676 L
.06506 .02675 L
.06576 .02675 L
.06641 .02675 L
.06791 .02673 L
.0704 .02671 L
.07308 .02667 L
.08278 .02649 L
.10458 .02593 L
.14572 .0247 L
.18534 .02354 L
.22345 .02251 L
.26401 .02154 L
.30306 .02071 L
.34456 .01995 L
.38454 .01931 L
.423 .01877 L
.46392 .01828 L
.50333 .01787 L
.54121 .01753 L
.58155 .01721 L
.62038 .01695 L
.66165 .01671 L
Mistroke
.70141 .01652 L
.73966 .01635 L
.78036 .0162 L
.81954 .01608 L
.86117 .01597 L
.90129 .01587 L
.9399 .0158 L
.97619 .01573 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.06244 .17604 L
.10458 .31025 L
.14415 .40284 L
.18221 .46812 L
.20342 .49644 L
.22272 .51801 L
.26171 .55138 L
.28086 .56355 L
.30164 .57412 L
.32148 .58198 L
.34251 .58822 L
.35192 .5904 L
.36204 .59235 L
.37153 .59385 L
.38034 .59496 L
.39045 .59593 L
.39578 .59632 L
.40148 .59664 L
.40408 .59676 L
.4069 .59687 L
.40939 .59695 L
.41201 .59702 L
.41438 .59707 L
.41573 .59709 L
.41699 .5971 L
.41814 .59711 L
.4192 .59712 L
.42041 .59712 L
.42157 .59712 L
.4227 .59712 L
.42393 .59711 L
.42509 .59711 L
.42615 .5971 L
.42862 .59706 L
.43122 .59701 L
.43612 .59688 L
.44148 .59668 L
.45102 .59619 L
.4599 .59558 L
.48035 .59372 L
.49894 .59155 L
.53892 .58574 L
.57739 .57921 L
.61831 .57185 L
.65771 .5648 L
.6956 .55836 L
.73594 .55211 L
.77476 .54684 L
.81604 .54219 L
Mistroke
.83667 .54026 L
.8558 .53872 L
.8755 .53739 L
.89404 .53638 L
.90393 .53594 L
.91461 .53554 L
.92424 .53526 L
.93323 .53505 L
.93783 .53497 L
.94276 .5349 L
.94557 .53487 L
.94822 .53484 L
.95061 .53482 L
.95195 .53481 L
.9532 .53481 L
.95452 .5348 L
.95573 .5348 L
.95639 .5348 L
.95707 .5348 L
.95776 .5348 L
.95852 .5348 L
.95926 .5348 L
.95993 .5348 L
.96071 .5348 L
.96144 .5348 L
.96275 .5348 L
.96348 .5348 L
.96416 .53481 L
.9665 .53482 L
.96908 .53483 L
.97177 .53486 L
.97428 .53489 L
.97619 .53491 L
Mfstroke
0 1 .585 r
.02381 .01472 m
.06244 .12784 L
.10458 .23257 L
.14415 .31254 L
.18221 .37319 L
.20342 .40048 L
.22272 .4215 L
.26171 .45376 L
.28086 .46504 L
.29075 .4698 L
.30164 .47426 L
.3112 .47752 L
.32148 .48038 L
.33233 .48273 L
.33761 .48363 L
.34251 .48433 L
.34781 .48495 L
.35261 .48539 L
.35795 .48575 L
.36088 .48589 L
.3622 .48594 L
.36364 .48598 L
.36482 .48601 L
.36608 .48604 L
.36678 .48605 L
.36742 .48606 L
.36867 .48607 L
.3698 .48607 L
.37104 .48607 L
.37221 .48606 L
.37329 .48605 L
.37453 .48603 L
.3757 .486 L
.37835 .48593 L
.38094 .48583 L
.38373 .48569 L
.38869 .48536 L
.3933 .48498 L
.40377 .48384 L
.41397 .48239 L
.42487 .4805 L
.46637 .47073 L
.50635 .45864 L
.54482 .44569 L
.58574 .43148 L
.62514 .41803 L
.66303 .40575 L
.70337 .3937 L
.74219 .38327 L
.78347 .37355 L
Mistroke
.82323 .36555 L
.86147 .35914 L
.90217 .35367 L
.92236 .35148 L
.94135 .34972 L
.97619 .34728 L
Mfstroke
0 1 .609 r
.02381 .01472 m
.06244 .16433 L
.10458 .29214 L
.14415 .38128 L
.18221 .44207 L
.20178 .46474 L
.22272 .48305 L
.23293 .48991 L
.24402 .49589 L
.25449 .50021 L
.26416 .50311 L
.26882 .50415 L
.27383 .50503 L
.27626 .50536 L
.27856 .50562 L
.28083 .50583 L
.28289 .50598 L
.28416 .50605 L
.28536 .5061 L
.28663 .50615 L
.28734 .50616 L
.288 .50617 L
.2891 .50618 L
.29031 .50618 L
.29157 .50617 L
.29275 .50614 L
.29342 .50612 L
.29414 .5061 L
.29547 .50604 L
.29794 .50588 L
.30084 .50564 L
.30351 .50535 L
.30815 .50472 L
.31314 .50386 L
.32218 .50182 L
.33293 .49868 L
.34278 .49518 L
.3824 .47624 L
.42051 .45313 L
.46107 .42618 L
.50012 .40005 L
.54162 .37362 L
.5816 .35034 L
.62006 .33039 L
.66098 .31191 L
.70039 .29673 L
.73827 .28442 L
.77861 .27356 L
.81744 .26508 L
.85871 .25797 L
Mistroke
.89847 .25278 L
.93672 .24917 L
.95584 .24784 L
.97619 .24675 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.04262 .07784 L
.06244 .13785 L
.08426 .19224 L
.0949 .21315 L
.10458 .22861 L
.11403 .24033 L
.12297 .24842 L
.12787 .25168 L
.1324 .25398 L
.13496 .255 L
.13737 .25577 L
.13987 .2564 L
.14121 .25666 L
.14264 .25689 L
.14399 .25705 L
.14521 .25716 L
.14644 .25723 L
.1476 .25726 L
.14826 .25726 L
.14895 .25725 L
.1502 .25721 L
.1509 .25717 L
.15154 .25712 L
.15302 .25698 L
.1543 .25682 L
.15551 .25663 L
.15778 .25621 L
.16288 .25488 L
.16749 .25329 L
.17176 .25153 L
.18141 .24666 L
.22067 .21947 L
.25842 .19016 L
.29863 .16102 L
.33732 .13667 L
.37846 .11498 L
.41808 .09785 L
.45619 .08439 L
.49675 .07278 L
.53579 .06381 L
.57729 .05618 L
.61727 .05034 L
.65574 .04585 L
.69666 .04204 L
.73606 .03912 L
.77395 .03688 L
.81429 .03498 L
.85311 .03353 L
.89439 .03232 L
Mistroke
.93415 .0314 L
.9724 .03071 L
.97619 .03065 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.06244 .11163 L
.10458 .20438 L
.14415 .27769 L
.18221 .33462 L
.20342 .36034 L
.22272 .37994 L
.24299 .39669 L
.26171 .40875 L
.28086 .41783 L
.29094 .42137 L
.30164 .42423 L
.31105 .42602 L
.31634 .42674 L
.31885 .42701 L
.32117 .42722 L
.32353 .4274 L
.32566 .42753 L
.32803 .42764 L
.32933 .42768 L
.33056 .42771 L
.33164 .42773 L
.33279 .42774 L
.33377 .42775 L
.33484 .42775 L
.336 .42774 L
.33724 .42771 L
.33841 .42769 L
.33947 .42765 L
.34176 .42756 L
.34428 .42742 L
.34939 .42703 L
.35412 .42653 L
.35856 .42595 L
.36855 .42429 L
.37932 .42197 L
.39936 .41637 L
.42046 .409 L
.45857 .39292 L
.49913 .37354 L
.53817 .35413 L
.57967 .33379 L
.61965 .31517 L
.65812 .29855 L
.69904 .28247 L
.73844 .26863 L
.77633 .25684 L
.81667 .24587 L
.85549 .23676 L
.89677 .22856 L
Mistroke
.93653 .222 L
.97478 .21684 L
.97619 .21667 L
Mfstroke
0 1 .68 r
.02381 .01472 m
.02499 .01698 L
.02605 .01866 L
.02721 .02012 L
.02846 .02137 L
.02961 .02229 L
.03068 .02297 L
.03279 .02398 L
.03396 .02441 L
.03506 .02474 L
.03756 .02533 L
.04 .02573 L
.04262 .02604 L
.04516 .02626 L
.04793 .02643 L
.04919 .02649 L
.05054 .02654 L
.05297 .02661 L
.0542 .02664 L
.05553 .02667 L
.05679 .02668 L
.05794 .0267 L
.05898 .0267 L
.06013 .02671 L
.06133 .02671 L
.06244 .02671 L
.0631 .02671 L
.0638 .02671 L
.06506 .02671 L
.06576 .0267 L
.06641 .0267 L
.06791 .02669 L
.0704 .02666 L
.07308 .02663 L
.08278 .02645 L
.10458 .02591 L
.14572 .02472 L
.18534 .0236 L
.22345 .02261 L
.26401 .02167 L
.30306 .02087 L
.34456 .02013 L
.38454 .01951 L
.423 .01899 L
.46392 .01851 L
.50333 .01811 L
.54121 .01778 L
.58155 .01747 L
.62038 .01722 L
.66165 .01698 L
Mistroke
.70141 .01679 L
.73966 .01663 L
.78036 .01648 L
.81954 .01636 L
.86117 .01625 L
.90129 .01616 L
.9399 .01608 L
.97619 .01602 L
Mfstroke
0 1 .704 r
.02381 .01472 m
.06244 .10406 L
.10458 .18963 L
.14415 .25704 L
.18221 .30888 L
.20342 .33203 L
.22272 .34951 L
.24299 .36427 L
.26171 .37475 L
.28086 .38249 L
.29094 .38543 L
.29653 .38674 L
.30164 .38774 L
.30614 .38847 L
.31105 .38912 L
.31374 .3894 L
.31624 .38963 L
.31878 .38981 L
.32117 .38995 L
.32341 .39005 L
.32466 .39009 L
.32582 .39012 L
.3268 .39014 L
.32787 .39016 L
.32899 .39016 L
.33003 .39016 L
.33126 .39016 L
.33242 .39014 L
.33346 .39012 L
.33459 .39009 L
.33713 .39 L
.33947 .38989 L
.34411 .38958 L
.3491 .38911 L
.35814 .38796 L
.36889 .38609 L
.37874 .38394 L
.41837 .37185 L
.45647 .35647 L
.49703 .33781 L
.53608 .31891 L
.57758 .29884 L
.61756 .28018 L
.65603 .26322 L
.69694 .24649 L
.73635 .23177 L
.77423 .21893 L
.81457 .20664 L
.8534 .1961 L
.89468 .18621 L
Mistroke
.93444 .17787 L
.97268 .17087 L
.97619 .17027 L
Mfstroke
0 1 .727 r
.02381 .01472 m
.06244 .12293 L
.10458 .2244 L
.14415 .30361 L
.18221 .3664 L
.22272 .42069 L
.26171 .46238 L
.30316 .49692 L
.34309 .522 L
.3815 .53963 L
.40134 .54654 L
.42237 .55243 L
.4419 .55669 L
.4602 .55971 L
.47058 .56105 L
.48045 .56208 L
.4893 .56282 L
.49897 .56344 L
.50429 .56369 L
.50929 .56389 L
.51378 .56402 L
.5163 .56408 L
.51865 .56412 L
.52118 .56416 L
.52252 .56417 L
.52396 .56419 L
.52468 .56419 L
.52546 .5642 L
.52621 .5642 L
.52689 .5642 L
.52819 .5642 L
.52885 .5642 L
.52957 .5642 L
.53087 .5642 L
.53206 .56419 L
.53337 .56418 L
.53475 .56417 L
.53708 .56414 L
.53962 .5641 L
.5449 .56398 L
.54989 .56384 L
.55923 .56347 L
.56928 .56294 L
.58018 .56223 L
.6211 .55849 L
.6605 .5537 L
.69839 .54844 L
.73873 .54253 L
.77755 .53684 L
.81883 .53107 L
Mistroke
.85859 .526 L
.89683 .52174 L
.93753 .51799 L
.97619 .51529 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.06244 .11674 L
.10458 .21353 L
.14415 .29022 L
.18221 .35194 L
.22272 .40619 L
.26171 .44867 L
.30316 .48478 L
.34309 .51192 L
.3815 .53195 L
.40095 .54009 L
.42237 .54766 L
.46172 .5582 L
.48113 .56197 L
.502 .56513 L
.51211 .56634 L
.52314 .56746 L
.53368 .56833 L
.54323 .56896 L
.55336 .56949 L
.5629 .56985 L
.56815 .57 L
.57298 .5701 L
.57572 .57015 L
.57828 .57019 L
.58094 .57021 L
.58236 .57023 L
.58387 .57024 L
.58509 .57024 L
.58644 .57025 L
.58711 .57025 L
.58784 .57025 L
.58916 .57025 L
.5904 .57025 L
.59171 .57025 L
.59283 .57025 L
.59405 .57024 L
.5955 .57023 L
.59682 .57022 L
.59978 .5702 L
.60252 .57016 L
.60511 .57012 L
.61477 .56993 L
.62021 .56978 L
.62523 .56962 L
.644 .56886 L
.66464 .56775 L
.70498 .565 L
.7438 .5619 L
.78508 .55844 L
Mistroke
.82484 .5552 L
.86308 .55236 L
.90378 .54981 L
.92397 .54877 L
.94296 .54795 L
.97619 .54694 L
Mfstroke
0 1 .775 r
.02381 .01472 m
.06244 .10558 L
.10458 .19372 L
.14415 .26525 L
.18221 .32407 L
.22272 .37677 L
.26171 .41876 L
.30316 .45502 L
.34309 .48276 L
.3815 .50362 L
.42237 .52041 L
.44268 .52696 L
.46172 .53212 L
.49955 .53994 L
.5198 .54294 L
.53832 .54507 L
.55731 .54671 L
.56806 .54741 L
.57803 .54793 L
.5886 .54835 L
.59378 .54851 L
.59855 .54864 L
.60282 .54873 L
.60749 .5488 L
.61219 .54886 L
.61476 .54888 L
.61716 .5489 L
.61842 .54891 L
.61976 .54891 L
.62091 .54892 L
.62217 .54892 L
.62287 .54892 L
.62352 .54892 L
.62423 .54892 L
.62498 .54892 L
.62624 .54892 L
.62695 .54891 L
.62761 .54891 L
.6289 .54891 L
.63012 .5489 L
.6324 .54889 L
.63485 .54887 L
.63751 .54884 L
.6422 .54878 L
.64717 .5487 L
.65607 .54852 L
.67564 .54795 L
.69396 .54723 L
.73278 .54531 L
.77406 .54292 L
Mistroke
.81382 .54053 L
.85206 .53835 L
.89276 .53635 L
.93194 .53487 L
.94226 .53458 L
.9534 .53431 L
.97358 .53395 L
.97619 .53392 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.06244 .14025 L
.10458 .25377 L
.14415 .3387 L
.18221 .40285 L
.22272 .45495 L
.26171 .4918 L
.28302 .50722 L
.30316 .51914 L
.32144 .52793 L
.34157 .53561 L
.36141 .54137 L
.37239 .54385 L
.38244 .54573 L
.39172 .54714 L
.40184 .54836 L
.4074 .5489 L
.41255 .54931 L
.41785 .54966 L
.42272 .54992 L
.4278 .55011 L
.43047 .55019 L
.43329 .55025 L
.43448 .55027 L
.43575 .55029 L
.43684 .55031 L
.43804 .55032 L
.43876 .55032 L
.43944 .55033 L
.44008 .55033 L
.44076 .55033 L
.44194 .55033 L
.44325 .55033 L
.44442 .55032 L
.44566 .55031 L
.44671 .5503 L
.44786 .55029 L
.45044 .55024 L
.45284 .55019 L
.4572 .55007 L
.46185 .54989 L
.4721 .54937 L
.4832 .5486 L
.50335 .54674 L
.54427 .54156 L
.58367 .53541 L
.62156 .52901 L
.6619 .52212 L
.70072 .51576 L
.742 .50957 L
Mistroke
.78176 .50435 L
.82001 .50014 L
.84136 .49817 L
.8607 .49664 L
.88112 .49528 L
.89989 .49428 L
.91917 .49351 L
.92931 .49321 L
.93491 .49308 L
.94 .49298 L
.94434 .49291 L
.94905 .49285 L
.95163 .49282 L
.95402 .49281 L
.95631 .49279 L
.95757 .49278 L
.95873 .49278 L
.95974 .49278 L
.96079 .49277 L
.96186 .49277 L
.96302 .49277 L
.96402 .49277 L
.9651 .49277 L
.96611 .49277 L
.96704 .49278 L
.96821 .49278 L
.9693 .49279 L
.97175 .4928 L
.97391 .49282 L
.97619 .49284 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.06244 .15445 L
.10458 .27679 L
.14415 .36541 L
.18221 .43022 L
.20342 .45888 L
.22272 .48088 L
.26171 .51492 L
.28086 .52718 L
.30164 .53763 L
.32148 .54513 L
.33161 .54813 L
.34251 .55077 L
.35271 .55274 L
.36204 .55413 L
.36653 .55468 L
.37142 .55518 L
.37571 .55555 L
.38034 .55587 L
.38311 .55602 L
.38565 .55614 L
.38804 .55623 L
.39066 .5563 L
.39179 .55633 L
.39301 .55635 L
.39406 .55637 L
.39521 .55639 L
.3965 .5564 L
.39772 .5564 L
.39891 .5564 L
.40001 .5564 L
.40121 .55639 L
.40251 .55638 L
.40373 .55636 L
.40485 .55634 L
.40745 .55629 L
.41018 .5562 L
.41534 .55599 L
.42099 .55568 L
.43126 .55491 L
.4406 .55401 L
.46155 .55133 L
.50153 .54436 L
.54 .53615 L
.58091 .52667 L
.62032 .51745 L
.6582 .50892 L
.69854 .50053 L
.73737 .49333 L
.77865 .48679 L
Mistroke
.81841 .48164 L
.85665 .47782 L
.87636 .47629 L
.89735 .475 L
.90766 .47449 L
.9188 .47404 L
.92932 .47371 L
.93399 .47359 L
.93898 .47348 L
.94379 .4734 L
.94817 .47334 L
.95028 .47332 L
.95257 .4733 L
.95473 .47328 L
.95673 .47327 L
.95785 .47327 L
.95905 .47327 L
.96019 .47326 L
.96122 .47326 L
.96238 .47326 L
.96364 .47326 L
.96495 .47327 L
.96617 .47327 L
.96748 .47328 L
.96871 .47328 L
.97102 .4733 L
.9735 .47332 L
.97619 .47335 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.06244 .13568 L
.10458 .24497 L
.12507 .28875 L
.14415 .32366 L
.16371 .35339 L
.18221 .37574 L
.192 .38532 L
.20263 .39398 L
.21222 .40026 L
.2212 .40488 L
.23064 .40844 L
.23565 .40982 L
.24104 .41091 L
.24373 .41131 L
.24515 .41149 L
.24667 .41165 L
.24812 .41177 L
.24944 .41186 L
.25008 .41189 L
.25077 .41192 L
.25202 .41196 L
.25323 .41199 L
.25392 .41199 L
.25456 .41199 L
.25586 .41198 L
.25659 .41196 L
.25725 .41194 L
.25844 .41188 L
.25973 .41181 L
.26207 .41162 L
.2644 .41137 L
.26692 .41104 L
.27147 .41026 L
.27688 .40905 L
.28184 .40769 L
.30285 .39953 L
.32177 .38943 L
.34247 .37619 L
.38303 .34633 L
.42208 .3159 L
.46358 .2845 L
.50356 .25663 L
.54203 .23263 L
.58294 .21029 L
.62235 .1918 L
.66024 .17661 L
.70057 .16294 L
.7394 .15193 L
.78068 .14223 L
Mistroke
.82044 .13457 L
.85868 .12853 L
.89938 .12332 L
.93856 .11934 L
.97619 .11633 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.06244 .13188 L
.08255 .18443 L
.10458 .23322 L
.12507 .26902 L
.14415 .29339 L
.15465 .30307 L
.15981 .30688 L
.16457 .30986 L
.16881 .31209 L
.17348 .3141 L
.17817 .31566 L
.18075 .31633 L
.18314 .31683 L
.18563 .31724 L
.18705 .31742 L
.18834 .31756 L
.18957 .31765 L
.19073 .31772 L
.19196 .31777 L
.19265 .31778 L
.19328 .31779 L
.19439 .31778 L
.19543 .31776 L
.19657 .31771 L
.19779 .31764 L
.19907 .31754 L
.20028 .31741 L
.20255 .31713 L
.20507 .31671 L
.20775 .31618 L
.21255 .31496 L
.22343 .31115 L
.2328 .30684 L
.2429 .30133 L
.26118 .28963 L
.30232 .25891 L
.34195 .2283 L
.38006 .20071 L
.42062 .17453 L
.45966 .15274 L
.50116 .13311 L
.54114 .11731 L
.57961 .10463 L
.62053 .09347 L
.65993 .08464 L
.69782 .07764 L
.73816 .07152 L
.77698 .06672 L
.81826 .06258 L
Mistroke
.85802 .05936 L
.89626 .05686 L
.93696 .05472 L
.97614 .05309 L
.97619 .05309 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.02499 .01693 L
.02605 .01859 L
.02721 .02003 L
.02846 .02126 L
.02961 .02216 L
.03068 .02282 L
.03279 .02381 L
.03396 .02422 L
.03506 .02454 L
.03636 .02486 L
.03756 .0251 L
.04 .02547 L
.04134 .02563 L
.04262 .02575 L
.045 .02593 L
.0463 .02601 L
.04753 .02607 L
.04868 .02612 L
.04993 .02616 L
.0521 .02622 L
.05335 .02624 L
.05472 .02626 L
.05541 .02627 L
.05615 .02628 L
.05685 .02628 L
.05749 .02628 L
.05871 .02629 L
.0594 .02629 L
.06003 .02629 L
.0612 .02628 L
.06244 .02628 L
.06371 .02627 L
.06504 .02626 L
.06742 .02623 L
.07277 .02614 L
.08247 .02594 L
.10458 .02533 L
.14269 .02419 L
.18325 .02302 L
.22229 .02201 L
.26379 .02106 L
.30377 .02025 L
.34224 .01958 L
.38316 .01896 L
.42256 .01844 L
.46045 .018 L
.50079 .0176 L
.53961 .01727 L
.58089 .01696 L
Mistroke
.62065 .01671 L
.6589 .01649 L
.69959 .0163 L
.73878 .01614 L
.78041 .01599 L
.82053 .01587 L
.85913 .01577 L
.90019 .01568 L
.93973 .0156 L
.97619 .01554 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.04262 .05172 L
.06244 .08767 L
.08426 .12069 L
.0949 .1336 L
.10458 .14336 L
.1134 .15063 L
.12297 .15685 L
.12822 .15958 L
.13308 .1617 L
.14264 .16484 L
.14729 .16593 L
.14986 .16641 L
.1523 .1668 L
.15457 .16711 L
.15703 .16737 L
.15928 .16757 L
.16136 .1677 L
.16266 .16776 L
.16334 .16779 L
.16406 .16782 L
.16469 .16783 L
.16538 .16785 L
.1666 .16787 L
.16778 .16787 L
.16905 .16787 L
.17025 .16785 L
.17134 .16782 L
.1727 .16778 L
.17396 .16773 L
.17681 .16756 L
.17932 .16738 L
.18199 .16714 L
.19136 .16598 L
.20146 .16427 L
.21974 .16027 L
.26088 .14892 L
.3005 .13695 L
.33861 .12561 L
.37917 .11426 L
.41822 .10425 L
.45971 .09464 L
.4997 .08638 L
.53816 .07931 L
.57908 .07265 L
.61848 .06699 L
.65637 .06219 L
.69671 .0577 L
.73554 .0539 L
.77681 .05038 L
Mistroke
.81657 .04741 L
.85482 .04492 L
.89552 .04261 L
.9347 .04067 L
.97619 .03888 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.06244 .11521 L
.10458 .21014 L
.14415 .28447 L
.18221 .34245 L
.22272 .39013 L
.26171 .42314 L
.28302 .43622 L
.30316 .44562 L
.31285 .44918 L
.32313 .4523 L
.33276 .45464 L
.34157 .4563 L
.35098 .4576 L
.35617 .45812 L
.35856 .45831 L
.3611 .45848 L
.36348 .45861 L
.36564 .45871 L
.36668 .45875 L
.36781 .45878 L
.36887 .45881 L
.36985 .45883 L
.37101 .45885 L
.37227 .45886 L
.37351 .45886 L
.37483 .45886 L
.37606 .45885 L
.37722 .45884 L
.37827 .45882 L
.3794 .45879 L
.38174 .45872 L
.38425 .45861 L
.3888 .45835 L
.39422 .45793 L
.39918 .45744 L
.40941 .45613 L
.42019 .45433 L
.43993 .45007 L
.45829 .44511 L
.49734 .43209 L
.53884 .41576 L
.57882 .39874 L
.61729 .38201 L
.6582 .36449 L
.69761 .34834 L
.7355 .33374 L
.77584 .31939 L
.81466 .30683 L
.85594 .29486 L
Mistroke
.8957 .28468 L
.93394 .27611 L
.97464 .26826 L
.97619 .26798 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.06244 .08846 L
.10458 .16238 L
.14415 .22461 L
.18221 .2775 L
.22272 .32638 L
.26171 .36646 L
.30316 .40203 L
.34309 .42999 L
.3815 .45162 L
.42237 .46961 L
.46172 .4827 L
.49955 .49194 L
.51896 .49559 L
.53984 .49878 L
.56097 .50133 L
.58106 .50319 L
.59065 .5039 L
.60087 .50454 L
.61926 .50542 L
.62954 .50578 L
.63495 .50593 L
.64067 .50606 L
.64568 .50615 L
.65117 .50623 L
.65359 .50626 L
.65617 .50628 L
.65839 .5063 L
.66084 .50632 L
.6634 .50633 L
.6648 .50633 L
.66612 .50634 L
.66735 .50634 L
.66848 .50634 L
.66971 .50634 L
.67101 .50634 L
.67171 .50634 L
.67234 .50634 L
.67306 .50634 L
.67375 .50634 L
.67497 .50633 L
.6763 .50633 L
.67931 .50631 L
.68208 .5063 L
.68673 .50626 L
.69185 .5062 L
.7022 .50604 L
.71236 .50585 L
.72165 .50563 L
.74254 .50503 L
Mistroke
.7823 .50359 L
.82055 .50202 L
.86124 .50035 L
.90043 .49892 L
.92044 .4983 L
.94206 .49775 L
.95985 .4974 L
.97619 .49717 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.06244 .16829 L
.08255 .23472 L
.10458 .29678 L
.1253 .34501 L
.14415 .38035 L
.16372 .4085 L
.17449 .42033 L
.18466 .42918 L
.19436 .43558 L
.19925 .43807 L
.20463 .44026 L
.20922 .44167 L
.21175 .44228 L
.21416 .44275 L
.21638 .44309 L
.21756 .44323 L
.21881 .44335 L
.21997 .44344 L
.22102 .4435 L
.22208 .44354 L
.22307 .44356 L
.22424 .44356 L
.22548 .44354 L
.22666 .44349 L
.22773 .44342 L
.22899 .44333 L
.23035 .44319 L
.23284 .44286 L
.23544 .44241 L
.2382 .44182 L
.24315 .44046 L
.25193 .43719 L
.26163 .43239 L
.28097 .41967 L
.30183 .40232 L
.34297 .36179 L
.38259 .3206 L
.4207 .28296 L
.46126 .24713 L
.50031 .21747 L
.5418 .19109 L
.58179 .17024 L
.62025 .15387 L
.66117 .1398 L
.70057 .12897 L
.73846 .12063 L
.7788 .11357 L
.81763 .10822 L
.8589 .10381 L
Mistroke
.89866 .10056 L
.93691 .0982 L
.97619 .09643 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.03279 .05357 L
.03793 .07215 L
.04262 .0859 L
.04758 .09708 L
.05012 .10154 L
.05288 .10551 L
.05544 .10846 L
.0578 .11063 L
.06005 .11227 L
.06244 .1136 L
.06378 .11418 L
.06505 .11463 L
.0662 .11497 L
.06743 .11525 L
.06813 .11538 L
.06876 .11548 L
.07 .11562 L
.07069 .11567 L
.07144 .11571 L
.07215 .11572 L
.0728 .11572 L
.07396 .11569 L
.07505 .11561 L
.07624 .1155 L
.07751 .11533 L
.08012 .11486 L
.0825 .11431 L
.08793 .1127 L
.09384 .11054 L
.10458 .10592 L
.14536 .08666 L
.18463 .07039 L
.22238 .05795 L
.26258 .04779 L
.30127 .04042 L
.34241 .03458 L
.38203 .03041 L
.42014 .02742 L
.4607 .02505 L
.49975 .02336 L
.54125 .02203 L
.58123 .02108 L
.61969 .02039 L
.66061 .01985 L
.70002 .01945 L
.7379 .01916 L
.77824 .01893 L
.81707 .01876 L
.85834 .01862 L
Mistroke
.8981 .01852 L
.93635 .01845 L
.97619 .01839 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.04262 .11854 L
.06244 .21225 L
.08426 .29752 L
.10458 .36239 L
.14264 .45352 L
.16305 .48947 L
.18163 .51593 L
.20239 .53956 L
.22156 .55663 L
.24021 .56952 L
.24973 .57484 L
.25997 .57971 L
.27017 .58375 L
.27951 .58677 L
.28837 .5891 L
.29781 .59103 L
.30297 .59186 L
.30765 .59248 L
.31241 .59299 L
.31679 .59335 L
.31924 .59351 L
.32192 .59365 L
.32462 .59375 L
.32609 .5938 L
.32746 .59383 L
.32877 .59385 L
.33 .59386 L
.33111 .59386 L
.33232 .59386 L
.33363 .59385 L
.33429 .59384 L
.33502 .59383 L
.33631 .59381 L
.33752 .59378 L
.33995 .5937 L
.34221 .5936 L
.34735 .5933 L
.35235 .59291 L
.3577 .59238 L
.36739 .59115 L
.3762 .58976 L
.39539 .58588 L
.41619 .58057 L
.4571 .56755 L
.49651 .55284 L
.5344 .53768 L
.57473 .52127 L
.61356 .50583 L
.65484 .4903 L
Mistroke
.6946 .47653 L
.73284 .46459 L
.77354 .45341 L
.81272 .44416 L
.85436 .43599 L
.89447 .42969 L
.93308 .42507 L
.95305 .42323 L
.97413 .42169 L
.97619 .42157 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.06244 .14859 L
.10458 .26708 L
.14415 .35351 L
.18221 .41614 L
.20178 .44119 L
.22272 .46299 L
.24402 .48023 L
.2538 .48658 L
.26416 .49229 L
.27367 .49665 L
.28414 .50053 L
.29366 .50326 L
.30258 .50515 L
.30754 .50594 L
.31016 .50629 L
.31296 .5066 L
.31564 .50685 L
.31807 .50703 L
.32052 .50717 L
.32162 .50722 L
.32282 .50727 L
.32399 .5073 L
.32508 .50733 L
.32623 .50735 L
.32746 .50736 L
.3286 .50736 L
.32969 .50735 L
.33066 .50734 L
.33172 .50731 L
.33287 .50728 L
.33415 .50724 L
.33672 .50712 L
.33911 .50698 L
.34135 .50681 L
.34604 .50637 L
.35118 .50575 L
.36153 .50407 L
.37112 .50205 L
.38004 .49981 L
.41908 .48654 L
.46058 .4682 L
.50056 .44845 L
.53903 .42897 L
.57995 .40881 L
.61935 .39065 L
.65724 .37472 L
.69758 .35962 L
.7364 .34697 L
.77768 .33551 L
Mistroke
.81744 .32633 L
.85568 .31914 L
.89638 .31312 L
.93556 .30883 L
.9565 .30712 L
.97619 .30587 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.06244 .14972 L
.10458 .26914 L
.14415 .35663 L
.18221 .42191 L
.22272 .4748 L
.26171 .51248 L
.28158 .52746 L
.30316 .54088 L
.32216 .55048 L
.34309 .55889 L
.36292 .56495 L
.3739 .56758 L
.38395 .56955 L
.39323 .57104 L
.40336 .57231 L
.40891 .57286 L
.41406 .57328 L
.41899 .5736 L
.42424 .57385 L
.42684 .57395 L
.4296 .57403 L
.43195 .57408 L
.43328 .5741 L
.43452 .57412 L
.43522 .57413 L
.43597 .57413 L
.43668 .57414 L
.43733 .57414 L
.43858 .57414 L
.43989 .57414 L
.44057 .57414 L
.44131 .57413 L
.442 .57413 L
.44263 .57412 L
.4441 .5741 L
.44565 .57408 L
.44806 .57402 L
.45064 .57395 L
.45528 .57377 L
.4608 .5735 L
.46582 .57318 L
.4758 .57239 L
.48501 .57147 L
.5058 .5688 L
.54521 .56187 L
.58309 .55354 L
.62343 .54356 L
.66226 .53345 L
.70353 .52268 L
Mistroke
.7433 .51265 L
.78154 .50361 L
.82224 .49485 L
.86142 .48739 L
.90305 .48066 L
.94317 .47539 L
.97619 .47201 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.06244 .10525 L
.10458 .19324 L
.14415 .26423 L
.18221 .3215 L
.22272 .37087 L
.26171 .40771 L
.28158 .42274 L
.30316 .4364 L
.32216 .4463 L
.34309 .45507 L
.36292 .46149 L
.3739 .46431 L
.38395 .46647 L
.39323 .46813 L
.40336 .46958 L
.40891 .47023 L
.41406 .47074 L
.41936 .47118 L
.42424 .47151 L
.42932 .47178 L
.43193 .47189 L
.43481 .47199 L
.43731 .47206 L
.43965 .47211 L
.44094 .47213 L
.44212 .47214 L
.44277 .47215 L
.44347 .47215 L
.44476 .47216 L
.44591 .47216 L
.44699 .47216 L
.44817 .47216 L
.44945 .47215 L
.45071 .47214 L
.45205 .47212 L
.45443 .47208 L
.45664 .47203 L
.4587 .47198 L
.46337 .47181 L
.46842 .47158 L
.47389 .47127 L
.48383 .47056 L
.50241 .46874 L
.52229 .4662 L
.54333 .46297 L
.58122 .4561 L
.62156 .44787 L
.66038 .43958 L
.70166 .4308 L
Mistroke
.74142 .42271 L
.77967 .41548 L
.82036 .40853 L
.85955 .40267 L
.90118 .39745 L
.9413 .39344 L
.97619 .39083 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.06244 .084 L
.10458 .14861 L
.12507 .17388 L
.14415 .19319 L
.16254 .20783 L
.18221 .21932 L
.19242 .22371 L
.20351 .22736 L
.2086 .22866 L
.21399 .22981 L
.21903 .23068 L
.22365 .23131 L
.22596 .23157 L
.22848 .23181 L
.23088 .23199 L
.23306 .23213 L
.23561 .23225 L
.237 .2323 L
.23831 .23233 L
.23953 .23236 L
.24066 .23237 L
.24189 .23238 L
.24319 .23238 L
.24433 .23236 L
.24537 .23235 L
.24656 .23232 L
.2477 .23229 L
.24972 .23222 L
.25191 .23212 L
.25689 .23179 L
.26149 .23139 L
.27112 .23025 L
.28015 .22884 L
.30075 .22466 L
.33944 .21423 L
.38058 .20116 L
.42021 .18795 L
.45831 .17536 L
.49888 .1625 L
.53792 .15088 L
.57942 .13946 L
.6194 .1294 L
.65787 .12059 L
.69879 .11211 L
.73819 .10477 L
.77608 .09841 L
.81642 .09235 L
.85524 .08715 L
.89652 .08223 L
Mistroke
.93628 .07804 L
.97452 .07446 L
.97619 .07431 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.06244 .17744 L
.10458 .31216 L
.12507 .36338 L
.14415 .40376 L
.18221 .46559 L
.20263 .4897 L
.2212 .50679 L
.24035 .52003 L
.25115 .5257 L
.26113 .52987 L
.2708 .53298 L
.27986 .53513 L
.28505 .53605 L
.28979 .53668 L
.29241 .53696 L
.29527 .5372 L
.29658 .53729 L
.29797 .53737 L
.29927 .53743 L
.30048 .53747 L
.30172 .53751 L
.30238 .53752 L
.30309 .53753 L
.30383 .53754 L
.30453 .53755 L
.30584 .53754 L
.30706 .53753 L
.3082 .53751 L
.30944 .53748 L
.31077 .53743 L
.31349 .5373 L
.31606 .53713 L
.32189 .53658 L
.32696 .53593 L
.3316 .5352 L
.34206 .53312 L
.36099 .52795 L
.38169 .52058 L
.42225 .50235 L
.46129 .48205 L
.50279 .4595 L
.54277 .43823 L
.58124 .41902 L
.62216 .40048 L
.66156 .38472 L
.69945 .37159 L
.73979 .35973 L
.77861 .3503 L
.81989 .34226 L
Mistroke
.85965 .3363 L
.8979 .3321 L
.91761 .33049 L
.9277 .3298 L
.93859 .32917 L
.94869 .32868 L
.95797 .32832 L
.96683 .32804 L
.97619 .32783 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.02499 .01759 L
.02605 .01959 L
.02729 .02131 L
.02846 .02251 L
.02954 .02335 L
.03053 .02396 L
.03279 .02495 L
.03396 .02531 L
.03506 .02559 L
.03636 .02587 L
.03756 .02607 L
.04 .02638 L
.04134 .0265 L
.04262 .0266 L
.045 .02674 L
.04633 .0268 L
.04753 .02684 L
.04866 .02687 L
.04988 .02689 L
.05104 .02691 L
.0521 .02692 L
.05334 .02693 L
.0545 .02693 L
.05577 .02693 L
.05648 .02692 L
.05713 .02692 L
.05844 .02691 L
.05986 .02689 L
.06244 .02686 L
.06749 .02676 L
.07306 .02661 L
.08433 .02626 L
.10458 .02554 L
.14478 .02406 L
.18347 .02277 L
.22461 .02157 L
.26423 .02059 L
.30234 .01979 L
.3429 .01908 L
.38195 .01851 L
.42345 .018 L
.46343 .0176 L
.5019 .01728 L
.54281 .01699 L
.58222 .01677 L
.6201 .01658 L
.66044 .01642 L
.69927 .0163 L
.74054 .01618 L
Mistroke
.78031 .01609 L
.81855 .01602 L
.85925 .01596 L
.89843 .01591 L
.94006 .01587 L
.97619 .01583 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.06244 .1301 L
.10458 .2364 L
.14415 .31802 L
.18221 .38142 L
.22272 .43452 L
.26171 .47342 L
.28158 .48919 L
.30316 .50352 L
.34309 .5233 L
.36292 .53026 L
.38395 .53584 L
.39336 .53779 L
.40349 .53955 L
.41298 .54088 L
.42179 .54187 L
.43189 .54273 L
.43723 .54307 L
.44292 .54335 L
.44553 .54345 L
.44835 .54354 L
.45101 .54361 L
.45346 .54365 L
.45567 .54368 L
.45693 .5437 L
.4581 .5437 L
.45934 .54371 L
.46047 .54371 L
.46178 .54371 L
.46301 .5437 L
.46415 .5437 L
.46538 .54369 L
.4676 .54366 L
.47024 .54361 L
.47266 .54356 L
.47766 .54341 L
.48292 .5432 L
.49172 .54274 L
.50134 .54208 L
.52095 .54032 L
.5419 .5379 L
.5834 .5319 L
.62338 .52519 L
.66185 .5184 L
.70277 .51124 L
.74217 .50471 L
.78006 .49899 L
.8204 .49366 L
.85922 .48939 L
.87897 .48756 L
Mistroke
.9005 .48586 L
.91976 .4846 L
.94026 .48354 L
.94997 .48314 L
.95912 .48283 L
.97619 .48241 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.04262 .07864 L
.06244 .13484 L
.07286 .15715 L
.08255 .17276 L
.08813 .17948 L
.0932 .18426 L
.096 .18638 L
.09905 .1883 L
.10171 .18965 L
.10458 .19081 L
.10712 .19158 L
.10945 .19209 L
.11057 .19227 L
.11179 .19243 L
.11295 .19253 L
.11402 .1926 L
.11467 .19262 L
.11538 .19263 L
.11666 .19262 L
.11791 .19256 L
.11905 .19248 L
.1203 .19235 L
.12166 .19218 L
.12442 .19169 L
.12716 .19106 L
.12967 .19036 L
.13529 .18843 L
.14545 .18394 L
.18529 .16024 L
.22362 .13625 L
.2644 .11358 L
.30367 .09531 L
.34142 .08086 L
.38162 .06841 L
.42031 .05882 L
.46145 .05071 L
.50107 .04453 L
.53918 .03981 L
.57974 .03583 L
.61879 .03281 L
.66029 .03029 L
.70027 .02838 L
.73874 .02694 L
.77965 .02572 L
.81906 .02481 L
.85694 .02411 L
.89728 .02353 L
.93611 .02309 L
.97619 .02273 L
Mistroke
Mfstroke
0 .751 1 r
.02381 .01472 m
.03279 .03864 L
.03793 .05 L
.04262 .05822 L
.04758 .06466 L
.0503 .06729 L
.05288 .06928 L
.05511 .07065 L
.05747 .0718 L
.06006 .07277 L
.06244 .07342 L
.06378 .0737 L
.06505 .07392 L
.0662 .07408 L
.06743 .07422 L
.06813 .07428 L
.06876 .07433 L
.07 .07439 L
.07069 .07442 L
.07144 .07444 L
.07215 .07444 L
.0728 .07444 L
.07396 .07443 L
.07505 .0744 L
.07624 .07434 L
.07751 .07427 L
.08012 .07407 L
.0825 .07382 L
.08793 .07312 L
.09384 .07218 L
.10458 .07019 L
.14536 .06171 L
.18463 .05408 L
.22238 .04773 L
.26258 .04203 L
.30127 .03747 L
.34241 .03347 L
.38203 .0303 L
.42014 .02779 L
.4607 .02559 L
.49975 .02385 L
.54125 .02235 L
.58123 .02116 L
.61969 .02023 L
.66061 .01941 L
.70002 .01877 L
.7379 .01827 L
.77824 .01783 L
.81707 .01748 L
.85834 .01718 L
Mistroke
.8981 .01694 L
.93635 .01675 L
.97619 .0166 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.06244 .11415 L
.08255 .16015 L
.10458 .20409 L
.1253 .23791 L
.14415 .26155 L
.15421 .27127 L
.16372 .27863 L
.17376 .28453 L
.17943 .28704 L
.18466 .28887 L
.18932 .29012 L
.19189 .29065 L
.19433 .29107 L
.19659 .29138 L
.19778 .29151 L
.19906 .29162 L
.20024 .29171 L
.2013 .29177 L
.20238 .29182 L
.20339 .29185 L
.20458 .29186 L
.2059 .29186 L
.20656 .29185 L
.20727 .29183 L
.20855 .29178 L
.20982 .29171 L
.21103 .29163 L
.21329 .29142 L
.21596 .2911 L
.21843 .29074 L
.22401 .28966 L
.23364 .28708 L
.24268 .28394 L
.26328 .27474 L
.30197 .25281 L
.34311 .22716 L
.38273 .20302 L
.42084 .18155 L
.4614 .16107 L
.50044 .14376 L
.54194 .12786 L
.58192 .11475 L
.62039 .10397 L
.66131 .09423 L
.70071 .08632 L
.7386 .07987 L
.77894 .07409 L
.81776 .06943 L
.85904 .0653 L
Mistroke
.8988 .062 L
.93705 .05936 L
.97619 .05712 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.06244 .1355 L
.08255 .18887 L
.10458 .23705 L
.11448 .25465 L
.12507 .27052 L
.13499 .28254 L
.14415 .2912 L
.15437 .29819 L
.15975 .30079 L
.1625 .30184 L
.16546 .30278 L
.16804 .30342 L
.17041 .30389 L
.17154 .30407 L
.17278 .30423 L
.17395 .30435 L
.17504 .30444 L
.17571 .30448 L
.17643 .30452 L
.17769 .30456 L
.17841 .30456 L
.17916 .30456 L
.17981 .30455 L
.18052 .30452 L
.18178 .30446 L
.18249 .30441 L
.18314 .30436 L
.1856 .30409 L
.18788 .30374 L
.1904 .30325 L
.19551 .30195 L
.20468 .29865 L
.21539 .29348 L
.22544 .28759 L
.26413 .25926 L
.30527 .22595 L
.34489 .19546 L
.383 .16931 L
.42356 .14536 L
.46261 .12596 L
.50411 .10887 L
.54409 .09538 L
.58255 .08472 L
.62347 .07548 L
.66288 .06827 L
.70076 .06262 L
.7411 .05774 L
.77993 .05396 L
.8212 .05072 L
Mistroke
.86097 .04823 L
.89921 .04632 L
.93991 .04469 L
.97619 .04354 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.06244 .11854 L
.10458 .21632 L
.14415 .29299 L
.18221 .35371 L
.22272 .40552 L
.26171 .44408 L
.28158 .45983 L
.30316 .47416 L
.32216 .48455 L
.34309 .49374 L
.36292 .50041 L
.3739 .50331 L
.38395 .5055 L
.39323 .50714 L
.40336 .50853 L
.40891 .50912 L
.41406 .50956 L
.41899 .5099 L
.42424 .51016 L
.42684 .51025 L
.42827 .5103 L
.4296 .51033 L
.43083 .51035 L
.43195 .51037 L
.43319 .51039 L
.43388 .51039 L
.43452 .5104 L
.43516 .5104 L
.43587 .5104 L
.4366 .51041 L
.43729 .5104 L
.43853 .5104 L
.43922 .51039 L
.43985 .51039 L
.4412 .51037 L
.44268 .51034 L
.44565 .51027 L
.4483 .51018 L
.4507 .51008 L
.4561 .5098 L
.46582 .50908 L
.4758 .50808 L
.48501 .50693 L
.5058 .50361 L
.54521 .49505 L
.58309 .48472 L
.62343 .47228 L
.66226 .45956 L
.70353 .44582 L
Mistroke
.7433 .43284 L
.78154 .42088 L
.82224 .40896 L
.86142 .39845 L
.90305 .38842 L
.94317 .37995 L
.97619 .37388 L
Mfstroke
0 .656 1 r
.02381 .01472 m
.04262 .05259 L
.0522 .06849 L
.06244 .08207 L
.0679 .08782 L
.07286 .09221 L
.08255 .09871 L
.08798 .10132 L
.09388 .10346 L
.09658 .10423 L
.09944 .10491 L
.10208 .10544 L
.10458 .10585 L
.10693 .10617 L
.10949 .10644 L
.11183 .10663 L
.11399 .10676 L
.11531 .10681 L
.11656 .10685 L
.11768 .10688 L
.11889 .10689 L
.11952 .1069 L
.12021 .1069 L
.12094 .10689 L
.12161 .10689 L
.12282 .10687 L
.12411 .10683 L
.12534 .10679 L
.12647 .10675 L
.12903 .10661 L
.13369 .10628 L
.13792 .10589 L
.14241 .1054 L
.16189 .10255 L
.18017 .09923 L
.21885 .09141 L
.25999 .08304 L
.29962 .07549 L
.33773 .06887 L
.37829 .06257 L
.41733 .05721 L
.45883 .05221 L
.49881 .048 L
.53728 .04447 L
.5782 .0412 L
.6176 .03846 L
.65549 .03617 L
.69583 .03405 L
.73465 .03228 L
.77593 .03066 L
Mistroke
.81569 .02932 L
.85393 .02819 L
.89463 .02716 L
.93381 .02631 L
.97545 .02553 L
.97619 .02551 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.06244 .17311 L
.10458 .30596 L
.14415 .39818 L
.18221 .46374 L
.22272 .51455 L
.26171 .54935 L
.28302 .5637 L
.30316 .57472 L
.32144 .58283 L
.34157 .58991 L
.36141 .59521 L
.37239 .5975 L
.38244 .59922 L
.39172 .60052 L
.40184 .60164 L
.4074 .60212 L
.41255 .60249 L
.41785 .6028 L
.42272 .60301 L
.4278 .60318 L
.43047 .60324 L
.43183 .60326 L
.43329 .60328 L
.43457 .6033 L
.43575 .60331 L
.43692 .60331 L
.43804 .60332 L
.43933 .60332 L
.44053 .60332 L
.44185 .60331 L
.44251 .6033 L
.44325 .6033 L
.44566 .60327 L
.44786 .60323 L
.45029 .60318 L
.45284 .60311 L
.45715 .60296 L
.46185 .60276 L
.47213 .60217 L
.48146 .60148 L
.50241 .59943 L
.5424 .59398 L
.58086 .58737 L
.62178 .5795 L
.66118 .5716 L
.69907 .56407 L
.73941 .55643 L
.77824 .54967 L
.81951 .54332 L
Mistroke
.85927 .53816 L
.89752 .53417 L
.91888 .53239 L
.93822 .53106 L
.95778 .53001 L
.97619 .52929 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.06244 .13418 L
.10458 .24329 L
.14415 .32641 L
.18221 .39094 L
.22272 .44565 L
.26171 .48696 L
.30316 .52072 L
.34309 .54502 L
.3815 .56204 L
.40134 .56874 L
.42237 .57448 L
.4419 .57868 L
.4602 .58172 L
.47058 .5831 L
.48045 .58419 L
.49016 .58506 L
.49897 .5857 L
.50856 .58623 L
.51382 .58645 L
.51878 .58662 L
.52338 .58674 L
.52761 .58682 L
.52983 .58685 L
.53226 .58688 L
.53348 .58689 L
.5348 .5869 L
.53604 .5869 L
.53717 .58691 L
.53834 .58691 L
.53945 .58691 L
.54066 .58691 L
.54197 .5869 L
.54327 .5869 L
.54464 .58689 L
.54708 .58686 L
.54935 .58683 L
.55146 .5868 L
.55625 .58671 L
.56151 .58657 L
.56629 .58642 L
.57701 .58599 L
.5962 .58493 L
.61699 .58343 L
.65791 .57967 L
.69731 .57541 L
.7352 .57106 L
.77554 .56646 L
.81437 .56228 L
.85564 .55831 L
Mistroke
.8954 .55513 L
.93365 .55278 L
.95336 .55187 L
.97435 .55116 L
.97619 .55111 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.06244 .11263 L
.10458 .20561 L
.14415 .27712 L
.18221 .32978 L
.20178 .35055 L
.22272 .36813 L
.23293 .37503 L
.24402 .38131 L
.25361 .38578 L
.26416 .38972 L
.2744 .39259 L
.27932 .39366 L
.284 .39449 L
.28929 .39522 L
.29413 .39571 L
.29683 .39591 L
.29934 .39604 L
.30079 .3961 L
.30209 .39614 L
.30282 .39616 L
.30361 .39618 L
.30435 .39619 L
.30503 .39619 L
.30629 .39619 L
.30749 .39619 L
.30856 .39617 L
.30973 .39615 L
.311 .39611 L
.31234 .39606 L
.31476 .39594 L
.31699 .3958 L
.31908 .39564 L
.32385 .39518 L
.32904 .39453 L
.3338 .3938 L
.34452 .39175 L
.36344 .38684 L
.38414 .37995 L
.4247 .36318 L
.46375 .34472 L
.50524 .32429 L
.54523 .30493 L
.58369 .28725 L
.62461 .26985 L
.66401 .25465 L
.7019 .24154 L
.74224 .22919 L
.78107 .2188 L
.82234 .20927 L
Mistroke
.8621 .20146 L
.90035 .1951 L
.94105 .1895 L
.97619 .18554 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.06244 .0649 L
.10458 .11655 L
.14415 .16088 L
.18221 .19844 L
.22272 .23196 L
.26171 .25743 L
.28158 .26783 L
.30316 .27719 L
.32216 .28386 L
.34309 .28959 L
.36292 .29357 L
.37378 .29519 L
.38395 .29638 L
.38891 .29685 L
.39433 .29728 L
.39911 .2976 L
.4042 .29786 L
.40679 .29797 L
.40924 .29806 L
.41162 .29813 L
.41381 .29819 L
.41589 .29823 L
.41809 .29826 L
.41923 .29827 L
.4203 .29827 L
.42147 .29828 L
.42272 .29828 L
.42394 .29828 L
.42463 .29828 L
.42529 .29828 L
.4266 .29827 L
.42733 .29826 L
.42801 .29825 L
.43039 .29822 L
.4329 .29817 L
.43563 .2981 L
.43818 .29802 L
.44396 .2978 L
.45369 .29727 L
.46408 .29651 L
.48543 .29439 L
.50558 .29179 L
.54405 .28556 L
.58497 .27762 L
.62437 .26917 L
.66226 .26065 L
.7026 .25142 L
.74142 .24258 L
.7827 .23339 L
Mistroke
.82246 .22485 L
.8607 .217 L
.9014 .20908 L
.94058 .20191 L
.97619 .1958 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.06244 .1759 L
.10458 .30994 L
.14415 .40222 L
.18221 .46723 L
.20342 .49541 L
.22272 .51687 L
.26171 .54997 L
.28086 .56196 L
.30164 .57226 L
.32148 .57976 L
.33161 .58279 L
.34251 .5855 L
.35271 .58755 L
.36204 .58904 L
.37142 .59018 L
.38034 .59095 L
.38537 .59126 L
.38993 .59147 L
.39246 .59155 L
.39378 .59159 L
.39519 .59162 L
.39642 .59164 L
.39707 .59165 L
.39777 .59166 L
.399 .59167 L
.40015 .59168 L
.40138 .59168 L
.40251 .59168 L
.40376 .59167 L
.40439 .59167 L
.40509 .59166 L
.40625 .59164 L
.4075 .59162 L
.40976 .59157 L
.41199 .59151 L
.41434 .59142 L
.41853 .59124 L
.42808 .59063 L
.43828 .58972 L
.45664 .58746 L
.47799 .58395 L
.49814 .57992 L
.53661 .5707 L
.57753 .55941 L
.61693 .5478 L
.65482 .53649 L
.69516 .52474 L
.73398 .51404 L
.77526 .50359 L
Mistroke
.81502 .49461 L
.85326 .48709 L
.89396 .48037 L
.93314 .47521 L
.97478 .47117 L
.97619 .47106 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.06244 .13673 L
.10458 .2475 L
.14415 .33052 L
.18221 .39279 L
.22272 .44234 L
.26171 .47598 L
.28302 .48932 L
.30316 .49907 L
.32313 .50628 L
.34157 .51097 L
.35124 .51276 L
.36029 .51404 L
.36539 .51461 L
.37023 .51504 L
.3729 .51524 L
.37581 .51543 L
.37847 .51557 L
.38092 .51567 L
.38347 .51576 L
.38479 .51579 L
.38623 .51583 L
.38749 .51585 L
.38867 .51586 L
.38991 .51587 L
.3906 .51588 L
.39124 .51588 L
.39243 .51588 L
.39354 .51587 L
.39475 .51586 L
.39604 .51585 L
.39716 .51583 L
.39821 .51581 L
.40059 .51575 L
.40316 .51566 L
.40586 .51555 L
.41069 .51529 L
.41588 .51494 L
.42157 .51447 L
.44118 .51221 L
.46213 .50886 L
.50362 .50008 L
.54361 .48988 L
.58207 .47932 L
.62299 .46794 L
.66239 .45734 L
.70028 .44779 L
.74062 .43855 L
.77945 .43069 L
.82072 .42354 L
Mistroke
.86048 .41788 L
.89873 .41359 L
.92009 .4117 L
.93943 .41029 L
.95837 .40921 L
.97619 .40846 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.06244 .11428 L
.10458 .20876 L
.14415 .28176 L
.18221 .33657 L
.20342 .36061 L
.22272 .3786 L
.24299 .39371 L
.26171 .40444 L
.28086 .41248 L
.29094 .41561 L
.30164 .41815 L
.31105 .41978 L
.31634 .42045 L
.32117 .42092 L
.32566 .42123 L
.3282 .42136 L
.32941 .42141 L
.33056 .42145 L
.33164 .42148 L
.33282 .42151 L
.33389 .42153 L
.33487 .42154 L
.33594 .42155 L
.33711 .42155 L
.33833 .42154 L
.33947 .42153 L
.34074 .42151 L
.34207 .42147 L
.34448 .4214 L
.34707 .42128 L
.34993 .42112 L
.35503 .42073 L
.35983 .42027 L
.36876 .41915 L
.37838 .41761 L
.39842 .4134 L
.41952 .40776 L
.45763 .39527 L
.49819 .38002 L
.53724 .36457 L
.57874 .34822 L
.61872 .33311 L
.65718 .31952 L
.6981 .3063 L
.73751 .29486 L
.77539 .28511 L
.81573 .27604 L
.85456 .26855 L
.89583 .26188 L
Mistroke
.93559 .25666 L
.97384 .2527 L
.97619 .25249 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.06244 .11002 L
.10458 .20065 L
.14415 .26941 L
.16408 .29692 L
.18221 .31747 L
.20178 .33477 L
.21254 .34215 L
.22272 .34778 L
.23241 .35195 L
.23772 .35377 L
.24269 .35518 L
.24727 .35623 L
.25147 .357 L
.25612 .35764 L
.25869 .3579 L
.26113 .35808 L
.26237 .35815 L
.26372 .35821 L
.26499 .35826 L
.26616 .35828 L
.26722 .35829 L
.26838 .35829 L
.26959 .35828 L
.27072 .35826 L
.27135 .35824 L
.27204 .35822 L
.2733 .35816 L
.27565 .35802 L
.2784 .3578 L
.28094 .35754 L
.28517 .35699 L
.28985 .35622 L
.29932 .35418 L
.30942 .35136 L
.31867 .34825 L
.33953 .33972 L
.37915 .31954 L
.41726 .29765 L
.45782 .2739 L
.49687 .25186 L
.53836 .23009 L
.57835 .21109 L
.61681 .19473 L
.65773 .17936 L
.69713 .16644 L
.73502 .15562 L
.77536 .14566 L
.81418 .13744 L
.85546 .13001 L
Mistroke
.89522 .12398 L
.93347 .1191 L
.97416 .11479 L
.97619 .11459 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.02499 .01696 L
.02605 .01864 L
.02721 .02008 L
.02846 .02132 L
.02961 .02222 L
.03068 .02288 L
.03279 .02386 L
.03396 .02427 L
.03506 .02458 L
.03636 .02489 L
.03756 .02512 L
.04 .02549 L
.04134 .02564 L
.04262 .02576 L
.045 .02594 L
.04633 .02602 L
.04753 .02607 L
.04866 .02612 L
.04988 .02616 L
.05103 .02619 L
.0521 .02621 L
.05335 .02623 L
.05406 .02624 L
.05472 .02625 L
.05536 .02625 L
.05605 .02626 L
.05679 .02626 L
.05749 .02626 L
.05874 .02626 L
.05937 .02626 L
.06006 .02626 L
.06129 .02626 L
.06244 .02625 L
.06372 .02624 L
.06491 .02623 L
.0676 .02619 L
.07302 .0261 L
.08272 .02588 L
.10458 .02526 L
.14363 .02407 L
.18512 .02287 L
.2251 .02183 L
.26357 .02095 L
.30449 .02013 L
.34389 .01945 L
.38178 .01887 L
.42212 .01834 L
.46094 .0179 L
.50222 .0175 L
Mistroke
.54198 .01717 L
.58023 .01689 L
.62092 .01663 L
.66011 .01642 L
.70174 .01623 L
.74186 .01607 L
.78046 .01594 L
.82152 .01582 L
.86106 .01572 L
.89908 .01564 L
.93956 .01557 L
.97619 .01551 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.06244 .15686 L
.10458 .2801 L
.14415 .36899 L
.18221 .43436 L
.22272 .48641 L
.26171 .52265 L
.28302 .53764 L
.30316 .54911 L
.32144 .55746 L
.34157 .56462 L
.36141 .56979 L
.37226 .57191 L
.38244 .57346 L
.3874 .57407 L
.39282 .57464 L
.39759 .57506 L
.40268 .57542 L
.40772 .57569 L
.41229 .57587 L
.4145 .57593 L
.41566 .57595 L
.41688 .57598 L
.41796 .57599 L
.41913 .57601 L
.42021 .57602 L
.42121 .57602 L
.42247 .57603 L
.42311 .57603 L
.42381 .57602 L
.42505 .57602 L
.42621 .57601 L
.42688 .576 L
.42758 .57599 L
.42883 .57597 L
.43166 .57591 L
.43411 .57584 L
.43639 .57576 L
.44156 .57553 L
.45053 .57497 L
.46012 .57417 L
.48146 .57166 L
.50161 .56852 L
.54008 .56089 L
.581 .55112 L
.6204 .54083 L
.65829 .53065 L
.69863 .51995 L
.73745 .51012 L
.77873 .50045 L
Mistroke
.81849 .49209 L
.85674 .48506 L
.89743 .47875 L
.93662 .47388 L
.97619 .4702 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.02499 .0171 L
.02605 .01885 L
.02729 .02044 L
.02846 .02161 L
.03053 .02309 L
.0317 .02369 L
.03279 .02414 L
.03506 .02485 L
.03635 .02516 L
.03756 .02539 L
.04 .02575 L
.04136 .0259 L
.04262 .02602 L
.04514 .0262 L
.04748 .02631 L
.04882 .02637 L
.05004 .0264 L
.05145 .02644 L
.05278 .02646 L
.05396 .02648 L
.0552 .02649 L
.05626 .0265 L
.05742 .0265 L
.05868 .0265 L
.05938 .0265 L
.06002 .0265 L
.06127 .02649 L
.06244 .02649 L
.06486 .02646 L
.06753 .02643 L
.07293 .02633 L
.08263 .02611 L
.10458 .02547 L
.14478 .02422 L
.18347 .02307 L
.22461 .02198 L
.26423 .02106 L
.30234 .02028 L
.3429 .01957 L
.38195 .01898 L
.42345 .01845 L
.46343 .018 L
.5019 .01764 L
.54281 .01731 L
.58222 .01704 L
.6201 .01681 L
.66044 .0166 L
.69927 .01644 L
.74054 .01628 L
Mistroke
.78031 .01616 L
.81855 .01605 L
.85925 .01596 L
.89843 .01588 L
.94006 .01581 L
.97619 .01576 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.03279 .03581 L
.04262 .05568 L
.04758 .06383 L
.05288 .07103 L
.05785 .0764 L
.06244 .08028 L
.06788 .08373 L
.07075 .08511 L
.07379 .08631 L
.07624 .08709 L
.07889 .08777 L
.08179 .08834 L
.08451 .08874 L
.08708 .08901 L
.08853 .08912 L
.08923 .08916 L
.08988 .08919 L
.09118 .08924 L
.09235 .08927 L
.09362 .08928 L
.09433 .08928 L
.09499 .08928 L
.09614 .08926 L
.09721 .08923 L
.09839 .08919 L
.09965 .08913 L
.10223 .08898 L
.10458 .0888 L
.10939 .08832 L
.11449 .08769 L
.12366 .08631 L
.14443 .08251 L
.18218 .07483 L
.22238 .0669 L
.26107 .06002 L
.30221 .05361 L
.34183 .04827 L
.37994 .04386 L
.4205 .03983 L
.45954 .03653 L
.50104 .03356 L
.54102 .03114 L
.57949 .02916 L
.62041 .02737 L
.65981 .02592 L
.6977 .02473 L
.73804 .02366 L
.77686 .02279 L
.81814 .02201 L
Mistroke
.8579 .02137 L
.89615 .02085 L
.93684 .02039 L
.97603 .02001 L
.97619 .02001 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.06244 .09574 L
.10458 .17562 L
.14415 .24187 L
.18221 .29756 L
.22272 .34859 L
.26171 .3902 L
.30316 .42698 L
.34309 .45579 L
.3815 .47801 L
.42237 .49636 L
.46172 .50956 L
.49955 .51868 L
.51896 .52219 L
.53984 .52517 L
.56097 .52745 L
.5707 .52827 L
.58106 .52899 L
.59145 .52958 L
.60087 .52999 L
.60542 .53015 L
.61034 .5303 L
.61464 .53041 L
.61926 .5305 L
.62183 .53055 L
.62417 .53058 L
.62656 .53061 L
.62876 .53063 L
.63133 .53065 L
.63268 .53065 L
.63337 .53066 L
.63412 .53066 L
.63536 .53066 L
.63653 .53067 L
.63721 .53067 L
.63792 .53067 L
.6392 .53067 L
.64052 .53066 L
.64171 .53066 L
.6431 .53066 L
.64441 .53065 L
.64673 .53063 L
.64926 .53061 L
.65498 .53054 L
.66026 .53046 L
.66995 .53024 L
.67902 .52999 L
.69966 .52921 L
.73849 .52719 L
.77976 .52451 L
Mistroke
.81952 .52169 L
.85777 .51897 L
.89847 .51626 L
.93765 .51399 L
.97619 .51222 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.06244 .10911 L
.10458 .19979 L
.14415 .27234 L
.18221 .3306 L
.22272 .38084 L
.26171 .41862 L
.28158 .43423 L
.30316 .44861 L
.34309 .46888 L
.36292 .47621 L
.38395 .48222 L
.40349 .48635 L
.42179 .48908 L
.43217 .49018 L
.43728 .49061 L
.44203 .49095 L
.44668 .49122 L
.45089 .49143 L
.45557 .4916 L
.45814 .49167 L
.46056 .49173 L
.46172 .49175 L
.46297 .49177 L
.46404 .49178 L
.46521 .49179 L
.46593 .4918 L
.46659 .49181 L
.46789 .49181 L
.46907 .49181 L
.47032 .49181 L
.47154 .49181 L
.47285 .4918 L
.47409 .49179 L
.47522 .49178 L
.47786 .49174 L
.48064 .49169 L
.48521 .49156 L
.48946 .49141 L
.49911 .49094 L
.50963 .49026 L
.51957 .48945 L
.53815 .48758 L
.57662 .48248 L
.61754 .47581 L
.65694 .46872 L
.69483 .4617 L
.73517 .45433 L
.77399 .44759 L
.81527 .441 L
Mistroke
.85503 .43536 L
.89328 .4307 L
.93397 .42665 L
.97316 .4237 L
.97619 .42351 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.06244 .14358 L
.10458 .25831 L
.14415 .34331 L
.18221 .40714 L
.22272 .45864 L
.26171 .49451 L
.28302 .50915 L
.30316 .52009 L
.32313 .5284 L
.34157 .53399 L
.35124 .53618 L
.36029 .5378 L
.37023 .53912 L
.37581 .53965 L
.37849 .53986 L
.38092 .54002 L
.38321 .54014 L
.38569 .54025 L
.38705 .5403 L
.3883 .54034 L
.38958 .54037 L
.39077 .5404 L
.39179 .54041 L
.39288 .54043 L
.3941 .54044 L
.39521 .54044 L
.39636 .54043 L
.39762 .54042 L
.39881 .54041 L
.39991 .54039 L
.40237 .54033 L
.40468 .54025 L
.40722 .54015 L
.40995 .54 L
.41552 .53962 L
.42063 .53918 L
.43043 .53807 L
.43955 .53675 L
.46025 .53285 L
.4993 .52255 L
.5408 .50851 L
.58078 .49308 L
.61924 .47734 L
.66016 .46039 L
.69957 .44443 L
.73745 .42981 L
.77779 .41531 L
.81662 .40257 L
.85789 .39046 L
Mistroke
.89765 .38025 L
.9359 .37179 L
.97619 .36432 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.04262 .09509 L
.06244 .16709 L
.07216 .19585 L
.08255 .22113 L
.08852 .23298 L
.09396 .24205 L
.09911 .24917 L
.10458 .25519 L
.10932 .25919 L
.11183 .26088 L
.11454 .26236 L
.11701 .26344 L
.11928 .2642 L
.12037 .26449 L
.12156 .26476 L
.1226 .26494 L
.12373 .2651 L
.12446 .26517 L
.12514 .26522 L
.12578 .26525 L
.12646 .26527 L
.12764 .26527 L
.12894 .26521 L
.12967 .26515 L
.13033 .26508 L
.13182 .26487 L
.1332 .26462 L
.1345 .26433 L
.1393 .26285 L
.14451 .26057 L
.15391 .25502 L
.16428 .24725 L
.18529 .22836 L
.22549 .18915 L
.26418 .15474 L
.30532 .12449 L
.34495 .10146 L
.38305 .08416 L
.42362 .06997 L
.46266 .05957 L
.50416 .0512 L
.54414 .04513 L
.58261 .0407 L
.62353 .03713 L
.66293 .03453 L
.70082 .03263 L
.74116 .03109 L
.77998 .02997 L
.82126 .02907 L
Mistroke
.86102 .02842 L
.89926 .02794 L
.93996 .02756 L
.97619 .02731 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.06244 .13452 L
.10458 .24307 L
.14415 .32213 L
.18221 .37783 L
.20178 .39929 L
.22272 .41734 L
.23293 .42443 L
.24402 .43094 L
.25361 .43564 L
.26416 .43986 L
.2744 .44306 L
.284 .44531 L
.28929 .44626 L
.29413 .44696 L
.2968 .44728 L
.29972 .44757 L
.30248 .4478 L
.30503 .44796 L
.30758 .44809 L
.30892 .44814 L
.31034 .44818 L
.31158 .4482 L
.31273 .44822 L
.31399 .44823 L
.3147 .44823 L
.31535 .44822 L
.31654 .44821 L
.31765 .4482 L
.31886 .44817 L
.32015 .44814 L
.32231 .44805 L
.3247 .44794 L
.32991 .44757 L
.33552 .44703 L
.34567 .44567 L
.35525 .44398 L
.36571 .44172 L
.38681 .43606 L
.42738 .42204 L
.46642 .40621 L
.50792 .38839 L
.5479 .37132 L
.58637 .35563 L
.62729 .34015 L
.66669 .32666 L
.70458 .31509 L
.74492 .30432 L
.78374 .29542 L
.82502 .28746 L
Mistroke
.86478 .28119 L
.90302 .27637 L
.94372 .27248 L
.97619 .27026 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.03279 .04504 L
.04262 .07189 L
.04758 .08196 L
.05288 .09012 L
.05546 .09319 L
.05789 .0956 L
.06244 .09902 L
.06487 .10034 L
.06754 .10145 L
.06889 .10188 L
.07034 .10227 L
.07159 .10254 L
.07295 .10277 L
.0736 .10287 L
.0743 .10295 L
.07555 .10306 L
.07684 .10313 L
.07801 .10316 L
.07916 .10315 L
.0804 .10311 L
.08157 .10305 L
.08265 .10296 L
.08528 .10267 L
.08773 .10231 L
.09331 .1012 L
.10458 .09814 L
.14349 .08472 L
.18485 .07097 L
.22469 .05984 L
.26302 .05111 L
.30381 .04368 L
.34307 .03802 L
.38082 .0337 L
.42103 .03005 L
.45971 .02729 L
.50085 .02499 L
.54048 .02326 L
.57859 .02195 L
.61915 .02086 L
.65819 .02003 L
.69969 .01935 L
.73967 .01883 L
.77814 .01845 L
.81906 .01812 L
.85846 .01788 L
.89635 .0177 L
.93669 .01754 L
.97551 .01743 L
.97619 .01743 L
Mistroke
Mfstroke
0 .206 1 r
.02381 .01472 m
.06244 .10006 L
.10458 .18285 L
.14415 .25031 L
.18221 .30574 L
.22272 .35464 L
.26171 .39199 L
.28158 .40745 L
.30316 .42156 L
.32216 .43176 L
.34309 .44068 L
.36292 .44699 L
.37378 .4496 L
.38395 .45153 L
.38891 .4523 L
.39433 .453 L
.39911 .45352 L
.4042 .45396 L
.40679 .45414 L
.40924 .45429 L
.41162 .45441 L
.41381 .45449 L
.41589 .45456 L
.41695 .45459 L
.41809 .45461 L
.41923 .45463 L
.4203 .45464 L
.42157 .45465 L
.42272 .45465 L
.4239 .45465 L
.42501 .45464 L
.42622 .45463 L
.42753 .4546 L
.42883 .45458 L
.43019 .45454 L
.43264 .45446 L
.43702 .45426 L
.44181 .45396 L
.44701 .45354 L
.45256 .45299 L
.46257 .45175 L
.48391 .44808 L
.50407 .4435 L
.54253 .43229 L
.58345 .4178 L
.62285 .4023 L
.66074 .3867 L
.70108 .36996 L
.73991 .35417 L
.78118 .33808 L
Mistroke
.82094 .32351 L
.85919 .31047 L
.89989 .29776 L
.93907 .28667 L
.97619 .27722 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.06244 .09315 L
.10458 .17074 L
.14415 .23512 L
.18221 .28902 L
.22272 .3378 L
.26171 .37655 L
.30316 .40926 L
.34309 .43294 L
.3815 .44905 L
.40134 .45501 L
.41147 .45748 L
.42237 .45972 L
.43257 .46144 L
.4419 .46272 L
.45128 .46372 L
.4602 .46442 L
.46523 .46471 L
.46979 .46491 L
.47231 .465 L
.47505 .46507 L
.4763 .4651 L
.47763 .46513 L
.47887 .46514 L
.48001 .46516 L
.48113 .46517 L
.48219 .46517 L
.48332 .46518 L
.48454 .46518 L
.48561 .46517 L
.48674 .46517 L
.4877 .46516 L
.48877 .46515 L
.49116 .46511 L
.49373 .46505 L
.49839 .46491 L
.50335 .4647 L
.50796 .46445 L
.51843 .46372 L
.52864 .46278 L
.53953 .46155 L
.58103 .45501 L
.62101 .44653 L
.65948 .43701 L
.7004 .426 L
.7398 .41499 L
.77769 .40438 L
.81803 .39335 L
.85685 .38319 L
.89813 .37307 L
Mistroke
.93789 .3641 L
.97614 .35627 L
.97619 .35626 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.06244 .09274 L
.10458 .17006 L
.14415 .23425 L
.18221 .28775 L
.22272 .3357 L
.26171 .37334 L
.30316 .4047 L
.34309 .42724 L
.3815 .44265 L
.40134 .44847 L
.42237 .45323 L
.43178 .45493 L
.4419 .45648 L
.45139 .45768 L
.4602 .45858 L
.47031 .4594 L
.47564 .45973 L
.48134 .46002 L
.48676 .46023 L
.48942 .46031 L
.49187 .46037 L
.49406 .46041 L
.49646 .46045 L
.49763 .46047 L
.49887 .46048 L
.50019 .46049 L
.50143 .4605 L
.50264 .4605 L
.50334 .4605 L
.50399 .4605 L
.5053 .4605 L
.50603 .4605 L
.50671 .46049 L
.50785 .46048 L
.50909 .46047 L
.5116 .46044 L
.51437 .4604 L
.51733 .46034 L
.52267 .46019 L
.52809 .45999 L
.53321 .45976 L
.54279 .45923 L
.5628 .45772 L
.58125 .45592 L
.62066 .45102 L
.65854 .44535 L
.69888 .43873 L
.73771 .43211 L
.77898 .4251 L
Mistroke
.81874 .41862 L
.85699 .41278 L
.89769 .40713 L
.93687 .40234 L
.97619 .39826 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.06244 .1214 L
.08255 .16959 L
.10458 .21414 L
.11448 .23085 L
.12507 .24623 L
.13499 .25824 L
.14415 .26725 L
.15437 .27498 L
.15975 .27812 L
.16546 .28076 L
.17041 .2825 L
.17504 .28371 L
.1777 .28421 L
.18013 .28457 L
.18147 .28472 L
.18293 .28484 L
.1836 .28489 L
.18431 .28493 L
.1856 .28499 L
.18684 .28501 L
.18754 .28502 L
.1882 .28501 L
.1889 .285 L
.18953 .28499 L
.19026 .28496 L
.19095 .28493 L
.19218 .28485 L
.19331 .28476 L
.19588 .28449 L
.19845 .28413 L
.20128 .28363 L
.20701 .28231 L
.21741 .27897 L
.22718 .27492 L
.26587 .25319 L
.30701 .22588 L
.34663 .19979 L
.38474 .17663 L
.4253 .15475 L
.46435 .13649 L
.50584 .11994 L
.54583 .10649 L
.58429 .09558 L
.62521 .08586 L
.66461 .07807 L
.7025 .07182 L
.74284 .06628 L
.78166 .06187 L
.82294 .05801 L
Mistroke
.8627 .05497 L
.90095 .05256 L
.94164 .05047 L
.97619 .04902 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.06244 .06387 L
.08255 .08698 L
.10458 .109 L
.1253 .12583 L
.14415 .13761 L
.16372 .14642 L
.17449 .14992 L
.18466 .15245 L
.19436 .15424 L
.19925 .15494 L
.20463 .15555 L
.20922 .15597 L
.21175 .15615 L
.21416 .1563 L
.21638 .15641 L
.21881 .15652 L
.22102 .15659 L
.22307 .15664 L
.22436 .15666 L
.22506 .15667 L
.22572 .15668 L
.22688 .15669 L
.22815 .1567 L
.22886 .1567 L
.22954 .1567 L
.2308 .15669 L
.23151 .15668 L
.23216 .15668 L
.23364 .15666 L
.23483 .15663 L
.23594 .15661 L
.23847 .15654 L
.2436 .15634 L
.24827 .1561 L
.25255 .15583 L
.2622 .15506 L
.28113 .15305 L
.30183 .15026 L
.34239 .14369 L
.38143 .13668 L
.42293 .12903 L
.46291 .12176 L
.50138 .115 L
.5423 .10817 L
.5817 .10197 L
.61959 .09639 L
.65993 .09085 L
.69875 .08589 L
.74003 .08103 L
Mistroke
.77979 .07671 L
.81804 .07288 L
.85873 .06914 L
.89792 .06583 L
.93955 .06261 L
.97619 .06002 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.06244 .12432 L
.08255 .17414 L
.10458 .22099 L
.1253 .25633 L
.14415 .28044 L
.15421 .29012 L
.16372 .29729 L
.17376 .30285 L
.17943 .30513 L
.18466 .30671 L
.18932 .30772 L
.19193 .30813 L
.19318 .30828 L
.19433 .30841 L
.19549 .30851 L
.19655 .30858 L
.19772 .30865 L
.19897 .30869 L
.20006 .30871 L
.20124 .30871 L
.20236 .3087 L
.20339 .30867 L
.20458 .30861 L
.20586 .30853 L
.20817 .30834 L
.21091 .30801 L
.21342 .30763 L
.21886 .30654 L
.22401 .30521 L
.23366 .30201 L
.24392 .29774 L
.26234 .28832 L
.30009 .26481 L
.34029 .2377 L
.37898 .2124 L
.42012 .18777 L
.45975 .1668 L
.49785 .14924 L
.53842 .13319 L
.57746 .12007 L
.61896 .10835 L
.65894 .09892 L
.69741 .09133 L
.73833 .08462 L
.77773 .07927 L
.81562 .07501 L
.85596 .07127 L
.89478 .06832 L
.93606 .06578 L
Mistroke
.97582 .06383 L
.97619 .06381 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.06244 .14307 L
.10458 .25769 L
.14415 .34292 L
.18221 .40713 L
.22272 .45909 L
.26171 .49546 L
.28302 .51042 L
.30316 .52174 L
.32313 .5305 L
.34157 .53661 L
.36029 .54106 L
.37094 .54287 L
.38092 .54413 L
.38588 .5446 L
.3913 .54501 L
.39378 .54516 L
.39642 .54529 L
.39889 .54539 L
.40117 .54547 L
.40357 .54553 L
.40483 .54555 L
.40548 .54556 L
.40617 .54557 L
.40733 .54558 L
.40842 .54559 L
.40971 .54559 L
.41088 .54559 L
.41201 .54558 L
.41305 .54557 L
.41419 .54556 L
.41541 .54554 L
.41744 .54549 L
.41969 .54543 L
.42461 .54523 L
.42978 .54495 L
.43904 .54425 L
.449 .54324 L
.4599 .54186 L
.50046 .53457 L
.5395 .52515 L
.581 .51358 L
.62098 .50171 L
.65945 .49017 L
.70037 .47825 L
.73977 .46745 L
.77766 .45788 L
.818 .44875 L
.85682 .44107 L
.8981 .43418 L
Mistroke
.93786 .4288 L
.9761 .42482 L
.97619 .42481 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.06244 .19271 L
.08255 .26627 L
.10458 .33269 L
.1253 .38279 L
.14415 .41895 L
.16372 .448 L
.17461 .46078 L
.18466 .47062 L
.19377 .47803 L
.20381 .48464 L
.2139 .48977 L
.21938 .49197 L
.22459 .49369 L
.22944 .49498 L
.23473 .49607 L
.23705 .49645 L
.23953 .49679 L
.24186 .49704 L
.244 .49723 L
.24529 .49732 L
.24671 .49739 L
.24813 .49745 L
.24891 .49747 L
.24964 .49748 L
.25033 .49749 L
.25098 .4975 L
.2522 .4975 L
.25352 .49748 L
.25426 .49746 L
.25495 .49744 L
.25613 .49739 L
.25724 .49734 L
.25976 .49717 L
.26222 .49695 L
.26488 .49665 L
.26984 .49595 L
.27445 .49511 L
.28492 .49263 L
.29512 .4895 L
.30602 .48549 L
.34752 .46543 L
.3875 .44184 L
.42596 .41786 L
.46688 .39284 L
.50629 .37035 L
.54417 .35077 L
.58451 .33237 L
.62334 .31707 L
.66461 .30329 L
Mistroke
.70437 .29225 L
.74262 .2835 L
.78332 .27599 L
.8225 .27032 L
.84251 .26796 L
.86413 .26579 L
.90425 .26275 L
.92423 .26168 L
.93441 .26124 L
.94531 .26086 L
.95367 .26062 L
.96129 .26044 L
.96895 .2603 L
.97619 .26021 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.06244 .18828 L
.08255 .26057 L
.10458 .32571 L
.1253 .37422 L
.14415 .4083 L
.16372 .43434 L
.17449 .44494 L
.18466 .45273 L
.19436 .45827 L
.19925 .46041 L
.20463 .46228 L
.20922 .46349 L
.21175 .46402 L
.21416 .46442 L
.21638 .46472 L
.21756 .46485 L
.21881 .46496 L
.21997 .46505 L
.22102 .4651 L
.22208 .46515 L
.22307 .46518 L
.22424 .46519 L
.22548 .46518 L
.22666 .46516 L
.22773 .46512 L
.22899 .46505 L
.23035 .46496 L
.23284 .46472 L
.23544 .4644 L
.2382 .46396 L
.24315 .46294 L
.25193 .46048 L
.26163 .45686 L
.28097 .44727 L
.30183 .4342 L
.34297 .40343 L
.38259 .37152 L
.4207 .34161 L
.46126 .31233 L
.50031 .28739 L
.5418 .26462 L
.58179 .24616 L
.62025 .23136 L
.66117 .21842 L
.70057 .20831 L
.73846 .20047 L
.7788 .19382 L
.81763 .18885 L
.8589 .18486 L
Mistroke
.87953 .18331 L
.89866 .18211 L
.91837 .1811 L
.93691 .18035 L
.94679 .18003 L
.95747 .17974 L
.97609 .17938 L
.97619 .17938 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.06244 .1411 L
.08255 .19667 L
.10458 .24707 L
.12507 .28313 L
.14415 .30716 L
.15465 .3166 L
.15981 .32031 L
.16457 .32322 L
.17348 .32739 L
.17817 .32895 L
.18072 .32962 L
.18314 .33015 L
.18549 .33057 L
.18674 .33075 L
.18806 .33091 L
.18928 .33104 L
.19039 .33113 L
.19151 .3312 L
.19256 .33125 L
.19379 .33129 L
.19509 .3313 L
.1962 .33129 L
.19742 .33126 L
.19873 .3312 L
.19947 .33116 L
.20014 .33111 L
.20268 .33088 L
.20502 .33058 L
.20718 .33024 L
.21208 .32925 L
.22098 .32674 L
.23061 .3231 L
.23964 .31894 L
.26025 .30741 L
.29893 .2812 L
.34007 .25144 L
.3797 .22401 L
.41781 .20008 L
.45837 .17774 L
.49741 .1593 L
.53891 .14277 L
.57889 .1295 L
.61736 .11889 L
.65828 .10956 L
.69768 .10221 L
.73557 .0964 L
.77591 .09136 L
.81473 .08744 L
.85601 .0841 L
Mistroke
.89577 .08156 L
.93401 .07964 L
.97471 .07808 L
.97619 .07803 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.04262 .0688 L
.06244 .11901 L
.07216 .13949 L
.08255 .15764 L
.08852 .1662 L
.09396 .17277 L
.09911 .17797 L
.10458 .18242 L
.10932 .18544 L
.11183 .18675 L
.11454 .18795 L
.11701 .18885 L
.11928 .18953 L
.12143 .19005 L
.12373 .19048 L
.12511 .19068 L
.12637 .19082 L
.12763 .19093 L
.12882 .191 L
.1295 .19102 L
.13021 .19104 L
.13149 .19105 L
.1322 .19104 L
.13287 .19102 L
.1336 .19099 L
.13438 .19095 L
.13568 .19085 L
.1371 .19072 L
.13968 .19038 L
.14219 .18996 L
.14451 .18949 L
.15414 .18685 L
.16317 .18354 L
.18378 .17415 L
.22246 .15379 L
.2636 .13256 L
.30323 .11432 L
.34134 .09918 L
.3819 .08556 L
.42094 .07461 L
.46244 .06498 L
.50242 .05735 L
.54089 .0513 L
.58181 .04602 L
.62121 .04185 L
.6591 .03856 L
.69944 .03568 L
.73826 .03342 L
.77954 .03146 L
Mistroke
.8193 .02992 L
.85754 .02872 L
.89824 .02768 L
.93742 .02686 L
.97619 .02621 L
Mfstroke
.055 0 1 r
.02381 .01472 m
.02499 .01726 L
.02605 .0191 L
.02729 .02073 L
.02846 .02191 L
.02954 .02275 L
.03053 .02338 L
.03279 .0244 L
.03396 .02479 L
.03506 .02508 L
.03636 .02537 L
.03756 .02559 L
.04 .02592 L
.04134 .02606 L
.04262 .02617 L
.045 .02632 L
.04633 .02639 L
.04753 .02643 L
.04866 .02647 L
.04988 .0265 L
.05104 .02652 L
.0521 .02654 L
.05334 .02655 L
.0545 .02656 L
.05577 .02656 L
.05648 .02656 L
.05713 .02656 L
.05844 .02656 L
.05918 .02655 L
.05986 .02655 L
.06244 .02652 L
.06486 .02648 L
.06745 .02643 L
.07216 .02633 L
.08288 .02604 L
.10458 .02533 L
.14572 .02393 L
.18534 .02267 L
.22345 .02161 L
.26401 .02062 L
.30306 .01981 L
.34456 .01907 L
.38454 .01847 L
.423 .01798 L
.46392 .01754 L
.50333 .01718 L
.54121 .01689 L
.58155 .01663 L
.62038 .01641 L
.66165 .01622 L
Mistroke
.70141 .01606 L
.73966 .01594 L
.78036 .01583 L
.81954 .01573 L
.86117 .01565 L
.90129 .01559 L
.9399 .01553 L
.97619 .01549 L
Mfstroke
.079 0 1 r
.02381 .01472 m
.03279 .04023 L
.04262 .06369 L
.04758 .07294 L
.05288 .08077 L
.05789 .08629 L
.06244 .08995 L
.06507 .09155 L
.06785 .0929 L
.07022 .0938 L
.07283 .09456 L
.07564 .09513 L
.07721 .09537 L
.07865 .09552 L
.07999 .09563 L
.08074 .09567 L
.08145 .0957 L
.08273 .09573 L
.08345 .09573 L
.0841 .09573 L
.08539 .0957 L
.08603 .09567 L
.08674 .09564 L
.088 .09556 L
.08917 .09547 L
.09181 .09521 L
.09465 .09484 L
.10458 .09305 L
.12582 .08778 L
.14594 .08218 L
.18427 .07174 L
.22505 .06195 L
.26432 .05397 L
.30207 .04756 L
.34227 .0419 L
.38096 .03743 L
.4221 .03353 L
.46172 .03048 L
.49983 .02807 L
.54039 .02598 L
.57944 .02433 L
.62094 .02291 L
.66092 .02181 L
.69938 .02094 L
.7403 .02018 L
.77971 .01959 L
.81759 .01913 L
.85793 .01872 L
.89676 .01841 L
.93803 .01813 L
Mistroke
.97619 .01793 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.06244 .12965 L
.10458 .23487 L
.14415 .31285 L
.18221 .36904 L
.20178 .39118 L
.22272 .41016 L
.24402 .42488 L
.2538 .43019 L
.26416 .4349 L
.27367 .43844 L
.28414 .44151 L
.29366 .44359 L
.30258 .44498 L
.30754 .44552 L
.31035 .44576 L
.31296 .44594 L
.31546 .44607 L
.31773 .44616 L
.31899 .44619 L
.31965 .44621 L
.32035 .44622 L
.32164 .44624 L
.32282 .44625 L
.32398 .44625 L
.32503 .44624 L
.32624 .44623 L
.32739 .44621 L
.32845 .44618 L
.32943 .44615 L
.33165 .44606 L
.33389 .44595 L
.33635 .4458 L
.34135 .4454 L
.34626 .44489 L
.35144 .44423 L
.3607 .44277 L
.38155 .43827 L
.41966 .42669 L
.46022 .41123 L
.49927 .39481 L
.54076 .37693 L
.58075 .36011 L
.61921 .34481 L
.66013 .32981 L
.69953 .31677 L
.73742 .3056 L
.77776 .29517 L
.81658 .28653 L
.85786 .27877 L
Mistroke
.89762 .27261 L
.93587 .26784 L
.97619 .26397 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.04262 .10951 L
.06244 .19649 L
.08426 .27599 L
.10458 .33506 L
.12297 .37665 L
.14264 .40962 L
.15285 .42241 L
.16394 .43322 L
.16902 .43717 L
.17441 .4407 L
.17946 .44343 L
.18408 .44545 L
.18891 .4471 L
.19349 .44824 L
.196 .4487 L
.19833 .44903 L
.19967 .44917 L
.20089 .44928 L
.20156 .44932 L
.20229 .44936 L
.20362 .44941 L
.20476 .44944 L
.20583 .44944 L
.207 .44942 L
.20825 .44937 L
.20957 .44929 L
.21081 .4492 L
.21315 .44895 L
.21533 .44865 L
.21735 .44831 L
.22192 .44732 L
.22655 .44604 L
.23154 .44435 L
.24058 .44056 L
.26118 .42896 L
.30232 .39757 L
.34195 .36283 L
.38006 .32951 L
.42062 .29668 L
.45966 .26879 L
.50116 .24346 L
.54114 .2231 L
.57961 .20689 L
.62053 .1928 L
.65993 .18185 L
.69782 .17335 L
.73816 .16611 L
.77698 .16063 L
.81826 .1561 L
Mistroke
.85802 .15281 L
.89626 .15049 L
.91597 .14957 L
.93696 .14879 L
.95717 .14822 L
.97619 .14784 L
Mfstroke
.15 0 1 r
.02381 .01472 m
.06244 .10468 L
.10458 .19161 L
.14415 .26161 L
.18221 .318 L
.22272 .36637 L
.26171 .40202 L
.28158 .41629 L
.30316 .429 L
.32392 .43865 L
.34309 .44547 L
.36181 .45033 L
.37246 .45236 L
.38244 .4538 L
.3874 .45436 L
.39282 .45486 L
.39793 .45522 L
.40038 .45536 L
.40268 .45547 L
.40494 .45556 L
.40739 .45563 L
.40847 .45565 L
.40961 .45568 L
.41067 .45569 L
.41165 .4557 L
.41279 .45571 L
.41401 .45572 L
.41514 .45572 L
.41621 .45571 L
.41745 .4557 L
.4186 .45569 L
.41987 .45567 L
.42121 .45564 L
.42359 .45558 L
.4261 .45549 L
.43058 .45528 L
.4354 .45499 L
.44068 .45459 L
.45015 .45366 L
.45896 .45258 L
.47942 .44932 L
.498 .44557 L
.53799 .43549 L
.57645 .42395 L
.61737 .41055 L
.65677 .39719 L
.69466 .38438 L
.735 .37115 L
.77382 .35906 L
.8151 .34709 L
Mistroke
.85486 .33654 L
.89311 .32737 L
.9338 .3187 L
.97299 .31142 L
.97619 .31087 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.04262 .05326 L
.06244 .09013 L
.08255 .12017 L
.09396 .13291 L
.09905 .13753 L
.10458 .14182 L
.11004 .14534 L
.11508 .14799 L
.1198 .15001 L
.125 .15173 L
.12965 .15287 L
.13401 .15364 L
.13642 .15394 L
.13862 .15415 L
.13983 .15425 L
.14116 .15432 L
.14241 .15438 L
.14357 .15441 L
.14486 .15443 L
.14551 .15444 L
.14622 .15444 L
.14747 .15442 L
.14865 .1544 L
.14936 .15437 L
.15004 .15435 L
.1513 .15429 L
.15414 .1541 L
.15662 .15388 L
.15891 .15364 L
.1641 .15295 L
.17312 .15136 L
.1827 .14926 L
.22045 .13859 L
.26066 .12583 L
.29934 .11383 L
.34048 .10204 L
.38011 .09181 L
.41822 .08304 L
.45878 .07479 L
.49782 .06783 L
.53932 .06137 L
.5793 .05596 L
.61777 .05142 L
.65869 .04723 L
.69809 .04373 L
.73598 .0408 L
.77632 .0381 L
.81514 .03584 L
.85642 .03377 L
Mistroke
.89618 .03205 L
.93442 .03061 L
.97512 .02929 L
.97619 .02926 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.06244 .14526 L
.08255 .20045 L
.0932 .2247 L
.10458 .24632 L
.11531 .26239 L
.12507 .27338 L
.12977 .27746 L
.13488 .28104 L
.1397 .28363 L
.14415 .28539 L
.14658 .2861 L
.14881 .2866 L
.15004 .28681 L
.15138 .287 L
.15264 .28714 L
.15382 .28723 L
.155 .28729 L
.15612 .28731 L
.15712 .2873 L
.1582 .28726 L
.15939 .28719 L
.16064 .28708 L
.16171 .28696 L
.16288 .28679 L
.16557 .28631 L
.16803 .28574 L
.17354 .28404 L
.1835 .27969 L
.20259 .26795 L
.22335 .25206 L
.26413 .21787 L
.3034 .18639 L
.34115 .15971 L
.38135 .13565 L
.42004 .11652 L
.46118 .09997 L
.5008 .08715 L
.53891 .07721 L
.57947 .06872 L
.61852 .06222 L
.66001 .05674 L
.7 .05257 L
.73846 .04938 L
.77938 .0467 L
.81878 .04467 L
.85667 .04312 L
.89701 .04183 L
.93584 .04087 L
.97619 .0401 L
Mistroke
Mfstroke
.221 0 1 r
.02381 .01472 m
.02499 .0171 L
.02605 .01885 L
.02729 .02044 L
.02846 .02161 L
.03053 .02309 L
.0317 .0237 L
.03279 .02415 L
.03506 .02487 L
.03635 .02517 L
.03756 .02541 L
.04 .02577 L
.04136 .02593 L
.04262 .02605 L
.04514 .02623 L
.04748 .02635 L
.04882 .0264 L
.05004 .02644 L
.05147 .02648 L
.05278 .0265 L
.05394 .02652 L
.05517 .02653 L
.0564 .02654 L
.0571 .02655 L
.05776 .02655 L
.05894 .02655 L
.06002 .02655 L
.06127 .02654 L
.06244 .02653 L
.06369 .02652 L
.06486 .02651 L
.06753 .02648 L
.07293 .02638 L
.08263 .02616 L
.10458 .02553 L
.14327 .02431 L
.18441 .02308 L
.22403 .02202 L
.26214 .02112 L
.3027 .02028 L
.34175 .01959 L
.38324 .01896 L
.42323 .01843 L
.46169 .018 L
.50261 .01761 L
.54201 .01728 L
.5799 .01701 L
.62024 .01677 L
.65906 .01657 L
.70034 .01639 L
Mistroke
.7401 .01624 L
.77835 .01611 L
.81905 .016 L
.85823 .01591 L
.89986 .01583 L
.93998 .01576 L
.97619 .01571 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.06244 .15624 L
.08255 .21514 L
.10458 .26561 L
.11448 .28341 L
.12507 .29918 L
.13499 .31104 L
.14415 .31961 L
.15437 .32668 L
.15975 .32941 L
.16546 .33162 L
.16784 .33235 L
.17041 .333 L
.17262 .33346 L
.17504 .33386 L
.17651 .33404 L
.17787 .33418 L
.17917 .33429 L
.17983 .33433 L
.18055 .33437 L
.18126 .33439 L
.18192 .33441 L
.1832 .33443 L
.18437 .33442 L
.1856 .33438 L
.18682 .33432 L
.18814 .33423 L
.19055 .334 L
.1929 .33369 L
.19508 .33334 L
.2 .3323 L
.20524 .33086 L
.21395 .32778 L
.22357 .3235 L
.26377 .29892 L
.30246 .27052 L
.3436 .2402 L
.38322 .21327 L
.42133 .19037 L
.46189 .16944 L
.50094 .1525 L
.54244 .13758 L
.58242 .12581 L
.62088 .11654 L
.6618 .10852 L
.70121 .10229 L
.73909 .09745 L
.77943 .09331 L
.81826 .09015 L
.85953 .08751 L
Mistroke
.89929 .08556 L
.93754 .08415 L
.97619 .08311 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.04262 .06666 L
.06244 .11339 L
.07286 .13234 L
.08255 .14582 L
.08813 .15174 L
.0932 .15601 L
.096 .15796 L
.09905 .15974 L
.10171 .16105 L
.10458 .1622 L
.10712 .16302 L
.10945 .16361 L
.11179 .16406 L
.11402 .16436 L
.11527 .16448 L
.11595 .16454 L
.1166 .16458 L
.11785 .16463 L
.11899 .16465 L
.11965 .16465 L
.12035 .16464 L
.1216 .16461 L
.12229 .16457 L
.12294 .16453 L
.12442 .16442 L
.12572 .16429 L
.12714 .16412 L
.12973 .16374 L
.13457 .16279 L
.14545 .15976 L
.16522 .15226 L
.18623 .14296 L
.22398 .12575 L
.26418 .10877 L
.30287 .09448 L
.34401 .08154 L
.38363 .0711 L
.42174 .06269 L
.4623 .05525 L
.50135 .04932 L
.54285 .04413 L
.58283 .04003 L
.62129 .03678 L
.66221 .03394 L
.70162 .03169 L
.7395 .02991 L
.77984 .02835 L
.81867 .02712 L
.85994 .02606 L
Mistroke
.8997 .02522 L
.93795 .02456 L
.97619 .02402 L
Mfstroke
.292 0 1 r
.02381 .01472 m
.03279 .04214 L
.04262 .06683 L
.04758 .07625 L
.05288 .08398 L
.05546 .08691 L
.05789 .08923 L
.06244 .09255 L
.06487 .09385 L
.06754 .09495 L
.06889 .0954 L
.07034 .0958 L
.07159 .09608 L
.07295 .09634 L
.0743 .09653 L
.07555 .09667 L
.07674 .09676 L
.07801 .09682 L
.07927 .09684 L
.08045 .09684 L
.0815 .09681 L
.08265 .09676 L
.08331 .09672 L
.08402 .09666 L
.0853 .09655 L
.0882 .09621 L
.09127 .09574 L
.09407 .09523 L
.10458 .09282 L
.14443 .08096 L
.18275 .06972 L
.22354 .05944 L
.2628 .05125 L
.30055 .04479 L
.34076 .03919 L
.37944 .03484 L
.42058 .03112 L
.46021 .02826 L
.49832 .02604 L
.53888 .02415 L
.57792 .02269 L
.61942 .02146 L
.6594 .02051 L
.69787 .01978 L
.73879 .01916 L
.77819 .01868 L
.81608 .01831 L
.85642 .018 L
.89524 .01776 L
.93652 .01756 L
Mistroke
.97619 .0174 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.02499 .01725 L
.02605 .01907 L
.02729 .0207 L
.02846 .02187 L
.03053 .02334 L
.0317 .02393 L
.03279 .02437 L
.03506 .02505 L
.03635 .02534 L
.03756 .02556 L
.04 .0259 L
.04136 .02604 L
.04262 .02614 L
.04384 .02623 L
.04514 .02631 L
.04748 .02641 L
.04891 .02645 L
.05026 .02649 L
.05147 .02651 L
.05278 .02653 L
.05395 .02654 L
.05523 .02654 L
.05587 .02654 L
.05657 .02654 L
.05781 .02654 L
.05906 .02654 L
.06024 .02653 L
.06244 .0265 L
.06486 .02647 L
.06753 .02642 L
.07293 .02631 L
.08263 .02605 L
.10458 .02535 L
.14478 .02399 L
.18347 .02278 L
.22461 .02164 L
.26423 .02069 L
.30234 .0199 L
.3429 .01918 L
.38195 .01859 L
.42345 .01806 L
.46343 .01763 L
.5019 .01728 L
.54281 .01696 L
.58222 .0167 L
.6201 .01649 L
.66044 .0163 L
.69927 .01615 L
.74054 .01601 L
Mistroke
.78031 .0159 L
.81855 .01581 L
.85925 .01573 L
.89843 .01566 L
.94006 .0156 L
.97619 .01556 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.06244 .13978 L
.10458 .25189 L
.14415 .3344 L
.18221 .3941 L
.20178 .41779 L
.22272 .43821 L
.24402 .4541 L
.2538 .45985 L
.26416 .46495 L
.27367 .46877 L
.28414 .47207 L
.28872 .47323 L
.29366 .4743 L
.29797 .47507 L
.30258 .47574 L
.30532 .47607 L
.30782 .47632 L
.31035 .47652 L
.31268 .47668 L
.31541 .47681 L
.31684 .47686 L
.31758 .47688 L
.31836 .47689 L
.31968 .47691 L
.32091 .47692 L
.32166 .47692 L
.32238 .47692 L
.32301 .47691 L
.32371 .4769 L
.32495 .47688 L
.32612 .47685 L
.32739 .47681 L
.32877 .47675 L
.33157 .47659 L
.33415 .47641 L
.33885 .47598 L
.3438 .47539 L
.35335 .47388 L
.36354 .47178 L
.38191 .46683 L
.42341 .45135 L
.46339 .43272 L
.50186 .4131 L
.54277 .39179 L
.58218 .37179 L
.62006 .35361 L
.6604 .33576 L
.69923 .32023 L
.7405 .30557 L
Mistroke
.78027 .29323 L
.81851 .28295 L
.85921 .27362 L
.89839 .26609 L
.94002 .25956 L
.97619 .25501 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.06244 .12599 L
.10458 .22823 L
.14415 .30396 L
.18221 .35775 L
.20178 .37836 L
.22272 .39539 L
.23293 .40192 L
.24402 .40775 L
.25361 .4118 L
.26416 .41524 L
.2691 .4165 L
.2744 .41761 L
.27942 .41845 L
.284 .41904 L
.28667 .4193 L
.28915 .4195 L
.29188 .41966 L
.2934 .41972 L
.29407 .41975 L
.29478 .41977 L
.2961 .4198 L
.29732 .41981 L
.29862 .41982 L
.29936 .41982 L
.30006 .41981 L
.30131 .41979 L
.30246 .41977 L
.30378 .41973 L
.30503 .41967 L
.3074 .41955 L
.30962 .4194 L
.31468 .41894 L
.31962 .41834 L
.32494 .41753 L
.34336 .41356 L
.3634 .40745 L
.3845 .39943 L
.42261 .38206 L
.46317 .36133 L
.50221 .34076 L
.54371 .31939 L
.58369 .30001 L
.62216 .28284 L
.66308 .26635 L
.70248 .25225 L
.74037 .24031 L
.78071 .22924 L
.81953 .22008 L
.86081 .21182 L
Mistroke
.90057 .20517 L
.93881 .19989 L
.97619 .19568 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.03279 .03733 L
.04262 .05865 L
.04758 .0674 L
.05288 .0751 L
.05785 .08081 L
.06244 .08488 L
.06788 .08843 L
.07075 .08983 L
.07379 .091 L
.07642 .0918 L
.07889 .09238 L
.08159 .09286 L
.08312 .09306 L
.08451 .0932 L
.08574 .0933 L
.08706 .09338 L
.0883 .09343 L
.08943 .09346 L
.09012 .09347 L
.09076 .09347 L
.09145 .09346 L
.09219 .09345 L
.09343 .09342 L
.09414 .09339 L
.0948 .09336 L
.09727 .09321 L
.09952 .09302 L
.10458 .09246 L
.11449 .09091 L
.12366 .08913 L
.14443 .08448 L
.18369 .07514 L
.22144 .06675 L
.26165 .05886 L
.30033 .05232 L
.34147 .04642 L
.3811 .04163 L
.41921 .03775 L
.45977 .03427 L
.49881 .03147 L
.54031 .02899 L
.58029 .027 L
.61876 .0254 L
.65968 .02397 L
.69908 .02283 L
.73697 .02191 L
.77731 .02109 L
.81613 .02044 L
.85741 .01985 L
Mistroke
.89717 .01939 L
.93541 .01902 L
.97611 .01868 L
.97619 .01868 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.06244 .11589 L
.10458 .2108 L
.14415 .28521 L
.18221 .34374 L
.22272 .39241 L
.26171 .42642 L
.28302 .43991 L
.29279 .44494 L
.30316 .44951 L
.31266 .45302 L
.32313 .45616 L
.33265 .45837 L
.34157 .45991 L
.34653 .46055 L
.34915 .46082 L
.35195 .46107 L
.35463 .46126 L
.35707 .4614 L
.35824 .46145 L
.35951 .4615 L
.3607 .46154 L
.36182 .46157 L
.3629 .46159 L
.36405 .4616 L
.36534 .46161 L
.36651 .46161 L
.36773 .4616 L
.36842 .46159 L
.36905 .46158 L
.37022 .46156 L
.37146 .46152 L
.37364 .46144 L
.37568 .46134 L
.38034 .46103 L
.38504 .4606 L
.39017 .46 L
.40052 .45842 L
.41011 .45651 L
.41903 .45438 L
.45807 .44162 L
.49957 .42337 L
.53955 .40298 L
.57802 .38211 L
.61894 .35965 L
.65834 .33856 L
.69623 .31926 L
.73657 .3001 L
.77539 .28318 L
.81667 .26692 L
Mistroke
.85643 .25293 L
.89468 .24098 L
.93537 .2298 L
.97455 .22045 L
.97619 .22009 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.04262 .08306 L
.06244 .14753 L
.08426 .20629 L
.0949 .22964 L
.10458 .24774 L
.1134 .26161 L
.12297 .27392 L
.13308 .28397 L
.13801 .28783 L
.14264 .29086 L
.14757 .2935 L
.15208 .29539 L
.15708 .29696 L
.15985 .29759 L
.16122 .29785 L
.16247 .29804 L
.16369 .29821 L
.165 .29835 L
.16572 .29842 L
.16638 .29847 L
.16769 .29854 L
.16881 .29859 L
.17004 .2986 L
.17133 .29859 L
.17253 .29856 L
.17321 .29853 L
.17395 .29849 L
.1753 .29839 L
.17661 .29826 L
.17782 .29812 L
.18058 .29772 L
.1835 .29716 L
.18839 .29597 L
.19287 .29461 L
.20297 .29069 L
.22125 .28125 L
.26088 .25476 L
.29899 .22687 L
.33955 .19847 L
.37859 .174 L
.42009 .1516 L
.46007 .13348 L
.49854 .11896 L
.53946 .10623 L
.57886 .09624 L
.61675 .08838 L
.65709 .08157 L
.69591 .07628 L
.73719 .07176 L
Mistroke
.77695 .06829 L
.81519 .06561 L
.85589 .06334 L
.89507 .06162 L
.93671 .06021 L
.97619 .0592 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.06244 .05789 L
.10458 .10271 L
.14415 .14169 L
.18221 .17509 L
.22272 .20493 L
.26171 .22717 L
.28302 .2365 L
.30316 .24352 L
.32313 .24882 L
.34157 .25235 L
.35124 .25372 L
.36029 .25471 L
.37023 .25551 L
.37581 .25583 L
.37849 .25595 L
.38092 .25604 L
.38321 .25611 L
.38569 .25617 L
.38705 .2562 L
.3883 .25622 L
.38958 .25624 L
.39077 .25625 L
.39179 .25626 L
.39288 .25626 L
.3941 .25626 L
.39521 .25626 L
.39636 .25626 L
.39762 .25625 L
.39881 .25624 L
.39991 .25622 L
.40237 .25618 L
.40468 .25613 L
.40995 .25596 L
.41509 .25575 L
.42063 .25545 L
.4302 .25479 L
.44067 .25389 L
.46177 .25152 L
.50233 .24539 L
.54137 .23813 L
.58287 .22955 L
.62285 .22085 L
.66132 .21235 L
.70224 .20336 L
.74164 .19491 L
.77953 .18704 L
.81987 .179 L
.85869 .17163 L
.89997 .16422 L
Mistroke
.93973 .1575 L
.97619 .1517 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.06244 .14591 L
.08255 .20287 L
.10458 .25482 L
.12507 .29297 L
.14415 .31983 L
.15465 .33119 L
.16457 .33983 L
.17348 .34593 L
.17847 .34871 L
.18314 .35091 L
.18807 .35281 L
.19258 .35421 L
.19759 .35538 L
.20036 .35586 L
.20298 .35621 L
.20551 .35646 L
.20692 .35656 L
.2082 .35663 L
.20939 .35667 L
.21069 .35669 L
.21191 .3567 L
.21304 .35668 L
.21435 .35664 L
.21558 .35659 L
.21693 .3565 L
.21837 .35639 L
.22132 .35608 L
.22401 .35571 L
.22882 .35485 L
.23392 .35367 L
.2431 .35091 L
.26386 .34212 L
.30161 .31998 L
.34181 .29221 L
.3805 .26493 L
.42164 .2375 L
.46126 .21366 L
.49937 .19347 L
.53993 .17492 L
.57898 .15976 L
.62047 .14623 L
.66046 .13541 L
.69892 .12677 L
.73984 .11919 L
.77924 .11323 L
.81713 .10854 L
.85747 .1045 L
.8963 .10139 L
.93757 .09879 L
Mistroke
.97619 .09693 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.06244 .08516 L
.10458 .15516 L
.14415 .21263 L
.18221 .25882 L
.22272 .29715 L
.24141 .31096 L
.26171 .32323 L
.28302 .33315 L
.2926 .33668 L
.30316 .33992 L
.31271 .34229 L
.32299 .34428 L
.32866 .34513 L
.33385 .34577 L
.33906 .34628 L
.34402 .34664 L
.34661 .34679 L
.34905 .34689 L
.35124 .34697 L
.35247 .347 L
.35361 .34702 L
.35483 .34704 L
.35598 .34705 L
.35723 .34706 L
.35794 .34706 L
.35858 .34706 L
.35987 .34705 L
.3606 .34704 L
.36127 .34703 L
.36251 .34701 L
.36383 .34698 L
.366 .34692 L
.36834 .34683 L
.37257 .34661 L
.3776 .34627 L
.38221 .34587 L
.39202 .34477 L
.40114 .34347 L
.42184 .33963 L
.46088 .32968 L
.50238 .31647 L
.54236 .3023 L
.58083 .28811 L
.62175 .273 L
.66115 .25883 L
.69904 .2458 L
.73938 .23273 L
.7782 .22101 L
.81948 .20953 L
Mistroke
.85924 .19943 L
.89749 .19059 L
.93818 .1821 L
.97619 .17497 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.04262 .07659 L
.0522 .10195 L
.06244 .12316 L
.0679 .13193 L
.07286 .13848 L
.0779 .14384 L
.08255 .14773 L
.08798 .15113 L
.09084 .15248 L
.09388 .15362 L
.09651 .15437 L
.09897 .15491 L
.10038 .15514 L
.10167 .15531 L
.10239 .15539 L
.10316 .15546 L
.10385 .15551 L
.10458 .15555 L
.10521 .15558 L
.10591 .1556 L
.10713 .15561 L
.10782 .15561 L
.10856 .15559 L
.10926 .15557 L
.10989 .15553 L
.11112 .15545 L
.11246 .15534 L
.1149 .15505 L
.11725 .15469 L
.11976 .15423 L
.12425 .15319 L
.13422 .15019 L
.14523 .14606 L
.18543 .12786 L
.22412 .11018 L
.26526 .09352 L
.30488 .08003 L
.34299 .06929 L
.38355 .05998 L
.42259 .05275 L
.46409 .0466 L
.50407 .04189 L
.54254 .03826 L
.58346 .03519 L
.62286 .03284 L
.66075 .03104 L
.70109 .0295 L
.73991 .02833 L
.78119 .02735 L
Mistroke
.82095 .0266 L
.8592 .02603 L
.89989 .02555 L
.93908 .02519 L
.97619 .02492 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.04262 .1107 L
.06244 .19185 L
.07286 .22363 L
.08255 .24603 L
.08813 .25581 L
.0932 .26285 L
.096 .26602 L
.09905 .26891 L
.10171 .27097 L
.10458 .27274 L
.10712 .27393 L
.10945 .27473 L
.11057 .27502 L
.11179 .27527 L
.11295 .27544 L
.11402 .27554 L
.11467 .27558 L
.11538 .2756 L
.11666 .27558 L
.11791 .2755 L
.11905 .27536 L
.1203 .27516 L
.12166 .27488 L
.12442 .2741 L
.12716 .27307 L
.12967 .27192 L
.13529 .26872 L
.14545 .26114 L
.18529 .22028 L
.22362 .1794 L
.2644 .14254 L
.30367 .11473 L
.34142 .09428 L
.38162 .07795 L
.42031 .06632 L
.46145 .05724 L
.50107 .05085 L
.53918 .0463 L
.57974 .04272 L
.61879 .04018 L
.66029 .03818 L
.70027 .03677 L
.73874 .03575 L
.77965 .03494 L
.81906 .03436 L
.85694 .03395 L
.89728 .03363 L
.93611 .03341 L
.95667 .03332 L
Mistroke
.97619 .03326 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.04262 .11518 L
.06244 .20021 L
.07286 .23375 L
.08255 .25753 L
.08813 .26795 L
.0932 .27544 L
.096 .27881 L
.09905 .28186 L
.10171 .28403 L
.10458 .28587 L
.10712 .28709 L
.10945 .28788 L
.11057 .28816 L
.11179 .28838 L
.11295 .28852 L
.11402 .28859 L
.11467 .28861 L
.11538 .2886 L
.11666 .28853 L
.11791 .28839 L
.11905 .2882 L
.1203 .28793 L
.12166 .28756 L
.12442 .28658 L
.12967 .28394 L
.13529 .28015 L
.14545 .27131 L
.18681 .2229 L
.22665 .17617 L
.26498 .13918 L
.30576 .10907 L
.34503 .08768 L
.38278 .07256 L
.42298 .06086 L
.46167 .05273 L
.50281 .04651 L
.54244 .04221 L
.58054 .0392 L
.62111 .03686 L
.66015 .03522 L
.70165 .03395 L
.74163 .03305 L
.7801 .03242 L
.82102 .03192 L
.86042 .03157 L
.89831 .03132 L
.91775 .03123 L
.93865 .03114 L
.97619 .03103 L
Mistroke
Mfstroke
.601 0 1 r
.02381 .01472 m
.04262 .09501 L
.06244 .16308 L
.07286 .18868 L
.07784 .19816 L
.08255 .20548 L
.08813 .21213 L
.0932 .21643 L
.09603 .21816 L
.09865 .21936 L
.10002 .21984 L
.10153 .22027 L
.10229 .22044 L
.10311 .22059 L
.10386 .22071 L
.10458 .22079 L
.10522 .22085 L
.10591 .22089 L
.10712 .22091 L
.1078 .2209 L
.10852 .22086 L
.10982 .22075 L
.11102 .22059 L
.11214 .22039 L
.11468 .21978 L
.11747 .21889 L
.12001 .21788 L
.12571 .21502 L
.13603 .20829 L
.1458 .20065 L
.18413 .16686 L
.22492 .13344 L
.26418 .10718 L
.30193 .08734 L
.34214 .07109 L
.38082 .05926 L
.42196 .04981 L
.46159 .04302 L
.4997 .03812 L
.54026 .0342 L
.5793 .03139 L
.6208 .02917 L
.66078 .02757 L
.69925 .02642 L
.74017 .02551 L
.77957 .02485 L
.81746 .02437 L
.8578 .02398 L
.89662 .02371 L
.9379 .02349 L
Mistroke
.97619 .02335 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.06244 .12283 L
.10458 .22174 L
.12507 .26115 L
.14415 .29226 L
.16371 .31836 L
.18221 .33764 L
.192 .34577 L
.20263 .35303 L
.21222 .35822 L
.2212 .36198 L
.23064 .36484 L
.23565 .36592 L
.24104 .36676 L
.24373 .36706 L
.24515 .36718 L
.24667 .36729 L
.24812 .36738 L
.24944 .36744 L
.25008 .36746 L
.25077 .36748 L
.25202 .3675 L
.25323 .3675 L
.25392 .3675 L
.25456 .36749 L
.25586 .36746 L
.25659 .36744 L
.25725 .36742 L
.25844 .36736 L
.25973 .36729 L
.26207 .36711 L
.2644 .36689 L
.26692 .36659 L
.27147 .36592 L
.28184 .36376 L
.2928 .36063 L
.30285 .35708 L
.34247 .33836 L
.38058 .31607 L
.42114 .29078 L
.46019 .26676 L
.50169 .24277 L
.54167 .22173 L
.58013 .20361 L
.62105 .18664 L
.66046 .17241 L
.69834 .16056 L
.73868 .1497 L
.77751 .14078 L
.81878 .13276 L
Mistroke
.85854 .12627 L
.89679 .12103 L
.93749 .11639 L
.97619 .11276 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.03279 .04043 L
.03793 .05279 L
.04262 .06188 L
.04758 .06911 L
.0503 .07212 L
.05288 .0744 L
.05511 .07598 L
.05747 .07731 L
.06006 .07843 L
.06244 .0792 L
.06378 .07952 L
.06505 .07978 L
.0662 .07996 L
.06743 .08012 L
.06813 .08019 L
.06876 .08024 L
.07 .08032 L
.07069 .08035 L
.07144 .08037 L
.07215 .08037 L
.0728 .08037 L
.07396 .08035 L
.07505 .08031 L
.07624 .08024 L
.07751 .08015 L
.08012 .0799 L
.0825 .07961 L
.09384 .07765 L
.10458 .07529 L
.14291 .06595 L
.18369 .05678 L
.22296 .0493 L
.26071 .04332 L
.30091 .03808 L
.3396 .03397 L
.38074 .03043 L
.42036 .02768 L
.45847 .02553 L
.49903 .02367 L
.53808 .02223 L
.57958 .021 L
.61956 .02004 L
.65802 .0193 L
.69894 .01866 L
.73835 .01817 L
.77623 .01779 L
.81657 .01746 L
.8554 .0172 L
.89667 .01698 L
Mistroke
.93643 .01681 L
.97468 .01668 L
.97619 .01667 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.04262 .05874 L
.06244 .1012 L
.08426 .13976 L
.0949 .15446 L
.10458 .16524 L
.11403 .17336 L
.12297 .17896 L
.12787 .18124 L
.1324 .18288 L
.13737 .18421 L
.13987 .1847 L
.14264 .18512 L
.14512 .18539 L
.14653 .1855 L
.14783 .18558 L
.14909 .18562 L
.15022 .18565 L
.15154 .18565 L
.15277 .18564 L
.1539 .1856 L
.15509 .18555 L
.15611 .18549 L
.15723 .18541 L
.15972 .18519 L
.16205 .18491 L
.16732 .18408 L
.17212 .18311 L
.18292 .18029 L
.20201 .17377 L
.22277 .16541 L
.26355 .14778 L
.30282 .13129 L
.34057 .11678 L
.38077 .10303 L
.41946 .09145 L
.4606 .0808 L
.50022 .07199 L
.53833 .0647 L
.57889 .05806 L
.61794 .05261 L
.65943 .04769 L
.69942 .04367 L
.73788 .04037 L
.7788 .0374 L
.81821 .03497 L
.85609 .03298 L
.89643 .03118 L
.93526 .02972 L
.97619 .02841 L
Mistroke
Mfstroke
.696 0 1 r
.02381 .01472 m
.06244 .09271 L
.10458 .16868 L
.14415 .22965 L
.18221 .27727 L
.20342 .29869 L
.22272 .31489 L
.24299 .3285 L
.26171 .33802 L
.271 .3417 L
.28086 .34486 L
.29075 .3473 L
.29637 .34838 L
.30164 .34918 L
.3066 .34976 L
.30922 .35001 L
.31202 .35022 L
.3147 .35037 L
.31714 .35047 L
.31831 .3505 L
.31958 .35053 L
.32078 .35055 L
.32189 .35056 L
.32296 .35056 L
.32411 .35055 L
.32519 .35054 L
.32618 .35052 L
.32734 .35049 L
.3286 .35045 L
.33089 .35036 L
.33329 .35022 L
.33584 .35005 L
.34041 .34965 L
.34978 .34848 L
.35988 .34675 L
.37816 .3425 L
.3982 .33644 L
.4193 .3288 L
.45741 .3127 L
.49797 .29375 L
.53702 .27495 L
.57851 .25526 L
.6185 .23713 L
.65696 .22076 L
.69788 .20467 L
.73728 .19051 L
.77517 .17814 L
.81551 .16626 L
.85434 .15602 L
.89561 .14632 L
Mistroke
.93537 .13806 L
.97362 .13103 L
.97619 .13059 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.06244 .10358 L
.10458 .18821 L
.14415 .25211 L
.18221 .29694 L
.20178 .31345 L
.22272 .32638 L
.23293 .33102 L
.24402 .33488 L
.24911 .33627 L
.25449 .33748 L
.25954 .33839 L
.26416 .33904 L
.26647 .3393 L
.26899 .33953 L
.27139 .33971 L
.27357 .33983 L
.27488 .33989 L
.27611 .33993 L
.27742 .33996 L
.27815 .33997 L
.27882 .33998 L
.27995 .33999 L
.28119 .33999 L
.28249 .33997 L
.2837 .33995 L
.28483 .33991 L
.28607 .33987 L
.28832 .33976 L
.2905 .33963 L
.29253 .33947 L
.29712 .33903 L
.302 .33842 L
.31137 .33688 L
.32147 .33472 L
.33975 .32965 L
.38089 .31426 L
.42051 .29633 L
.45862 .27796 L
.49918 .2584 L
.53823 .24029 L
.57972 .2223 L
.61971 .2064 L
.65817 .19253 L
.69909 .17928 L
.73849 .16795 L
.77638 .15828 L
.81672 .14922 L
.85555 .1416 L
.89682 .13456 L
Mistroke
.93658 .12872 L
.97483 .12389 L
.97619 .12373 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.02499 .01722 L
.02605 .01903 L
.02729 .02065 L
.02846 .02182 L
.03053 .02329 L
.0317 .02388 L
.03279 .02433 L
.03506 .02501 L
.03635 .0253 L
.03756 .02553 L
.04 .02587 L
.04136 .02601 L
.04262 .02612 L
.04384 .0262 L
.04514 .02628 L
.04748 .02639 L
.04891 .02643 L
.05026 .02647 L
.05147 .02649 L
.05278 .02651 L
.05395 .02652 L
.05523 .02652 L
.05587 .02653 L
.05657 .02653 L
.05781 .02652 L
.05906 .02652 L
.06024 .02651 L
.06129 .0265 L
.06244 .02649 L
.06749 .02641 L
.07306 .02629 L
.08433 .02599 L
.10458 .02534 L
.14478 .02399 L
.18347 .02277 L
.22461 .02163 L
.26423 .02068 L
.30234 .01989 L
.3429 .01917 L
.38195 .01858 L
.42345 .01805 L
.46343 .01761 L
.5019 .01726 L
.54281 .01694 L
.58222 .01668 L
.6201 .01647 L
.66044 .01628 L
.69927 .01612 L
.74054 .01598 L
Mistroke
.78031 .01587 L
.81855 .01578 L
.85925 .01569 L
.89843 .01563 L
.94006 .01557 L
.97619 .01552 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.06244 .06464 L
.10458 .11454 L
.12507 .13571 L
.14415 .15286 L
.16371 .16741 L
.18221 .17815 L
.192 .18264 L
.20263 .1866 L
.21228 .18943 L
.2212 .19143 L
.22586 .19226 L
.23087 .193 L
.2352 .19351 L
.23993 .19394 L
.24279 .19414 L
.24545 .19428 L
.24799 .19439 L
.24941 .19444 L
.2507 .19447 L
.25197 .19449 L
.25313 .19451 L
.25442 .19452 L
.25506 .19452 L
.25577 .19452 L
.25696 .19452 L
.25824 .1945 L
.25945 .19448 L
.26055 .19446 L
.26284 .1944 L
.26536 .19431 L
.27047 .19404 L
.2752 .19371 L
.27964 .19334 L
.28963 .19227 L
.3004 .19081 L
.34154 .18323 L
.38116 .17419 L
.41927 .16489 L
.45983 .1549 L
.49888 .14552 L
.54037 .136 L
.58036 .12736 L
.61882 .11956 L
.65974 .11184 L
.69914 .10496 L
.73703 .09884 L
.77737 .09283 L
.81619 .08751 L
.85747 .08232 L
Mistroke
.89723 .07774 L
.93548 .07371 L
.97617 .06978 L
.97619 .06978 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.06244 .13594 L
.08255 .18942 L
.10458 .23889 L
.1253 .27609 L
.14415 .3019 L
.15354 .31194 L
.16372 .32078 L
.17449 .32791 L
.17974 .3306 L
.18466 .33267 L
.18959 .33433 L
.1941 .33549 L
.1965 .33597 L
.19911 .3364 L
.20054 .33658 L
.20187 .33673 L
.20324 .33686 L
.2045 .33695 L
.20582 .33702 L
.20651 .33704 L
.20725 .33706 L
.20848 .33708 L
.20918 .33708 L
.20984 .33708 L
.21106 .33705 L
.21217 .33701 L
.21346 .33694 L
.21468 .33686 L
.21738 .3366 L
.21987 .33629 L
.22553 .33529 L
.23016 .33421 L
.23515 .33279 L
.24419 .32962 L
.26479 .31992 L
.30593 .29399 L
.34556 .26559 L
.38367 .23845 L
.42423 .21158 L
.46327 .18848 L
.50477 .16713 L
.54475 .14958 L
.58322 .13526 L
.62414 .12247 L
.66354 .11222 L
.70143 .10399 L
.74177 .09674 L
.78059 .09099 L
.82187 .08598 L
Mistroke
.86163 .08207 L
.89987 .079 L
.94057 .07638 L
.97619 .07453 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.02499 .01707 L
.02605 .0188 L
.02721 .02029 L
.02846 .02155 L
.02961 .02245 L
.03068 .02312 L
.03279 .02411 L
.03396 .02452 L
.03506 .02484 L
.03636 .02515 L
.03756 .02539 L
.04 .02576 L
.04262 .02604 L
.04514 .02623 L
.04748 .02636 L
.04882 .02642 L
.05004 .02646 L
.05147 .0265 L
.05278 .02653 L
.05394 .02655 L
.05517 .02656 L
.0564 .02657 L
.0571 .02658 L
.05776 .02658 L
.05894 .02658 L
.06002 .02658 L
.06127 .02658 L
.06244 .02657 L
.06369 .02657 L
.06486 .02656 L
.06753 .02652 L
.07293 .02644 L
.08263 .02623 L
.10458 .02562 L
.14327 .02442 L
.18441 .0232 L
.22403 .02215 L
.26214 .02125 L
.3027 .02041 L
.34175 .01971 L
.38324 .01907 L
.42323 .01854 L
.46169 .0181 L
.50261 .01769 L
.54201 .01736 L
.5799 .01708 L
.62024 .01683 L
.65906 .01662 L
.70034 .01643 L
Mistroke
.7401 .01628 L
.77835 .01615 L
.81905 .01603 L
.85823 .01594 L
.89986 .01585 L
.93998 .01578 L
.97619 .01572 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.03279 .04312 L
.04262 .06786 L
.04758 .07686 L
.0503 .0808 L
.05288 .08392 L
.05528 .08633 L
.05789 .08848 L
.06008 .08993 L
.06244 .09119 L
.06506 .09226 L
.06751 .09299 L
.069 .09332 L
.07042 .09356 L
.07169 .09373 L
.07236 .0938 L
.07308 .09386 L
.07384 .09391 L
.07456 .09394 L
.07526 .09396 L
.07591 .09397 L
.07661 .09397 L
.07738 .09396 L
.07818 .09394 L
.07893 .0939 L
.0803 .09381 L
.08155 .09371 L
.08435 .09338 L
.08933 .09257 L
.09474 .09144 L
.10458 .08892 L
.14536 .07658 L
.18463 .06537 L
.22238 .05621 L
.26258 .0482 L
.30127 .04197 L
.34241 .03666 L
.38203 .03259 L
.42014 .02946 L
.4607 .02681 L
.49975 .02478 L
.54125 .02307 L
.58123 .02177 L
.61969 .02078 L
.66061 .01995 L
.70002 .01931 L
.7379 .01882 L
.77824 .01841 L
.81707 .01809 L
.85834 .01783 L
Mistroke
.8981 .01763 L
.93635 .01748 L
.97619 .01735 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.04262 .0559 L
.06244 .09148 L
.07286 .10595 L
.08255 .11675 L
.0932 .12583 L
.09912 .12975 L
.10458 .13272 L
.10944 .13488 L
.1148 .1368 L
.12018 .13829 L
.12316 .13894 L
.12589 .13943 L
.12828 .13979 L
.13089 .14011 L
.13366 .14036 L
.13503 .14046 L
.13628 .14054 L
.13746 .14059 L
.13873 .14064 L
.13943 .14066 L
.14007 .14067 L
.14134 .14069 L
.14242 .1407 L
.14362 .14069 L
.14486 .14067 L
.14603 .14065 L
.14729 .1406 L
.14863 .14055 L
.15103 .14042 L
.15362 .14023 L
.15648 .13998 L
.16638 .13877 L
.17595 .13719 L
.18493 .13542 L
.22362 .12594 L
.26476 .11462 L
.30439 .10392 L
.34249 .09434 L
.38305 .08512 L
.4221 .07722 L
.4636 .06985 L
.50358 .06367 L
.54205 .05849 L
.58296 .05371 L
.62237 .04975 L
.66026 .04645 L
.70059 .04343 L
.73942 .04093 L
.7807 .03865 L
Mistroke
.82046 .03678 L
.8587 .03524 L
.8994 .03384 L
.93858 .03269 L
.97619 .03175 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.03279 .0411 L
.04262 .06394 L
.04758 .07225 L
.0503 .07592 L
.05288 .07885 L
.05528 .08115 L
.05789 .08321 L
.06244 .08592 L
.06506 .08704 L
.06751 .08784 L
.07019 .08849 L
.0717 .08877 L
.07308 .08896 L
.07451 .08912 L
.07584 .08923 L
.07661 .08927 L
.0773 .0893 L
.0781 .08933 L
.07886 .08934 L
.07953 .08934 L
.08023 .08934 L
.0815 .08931 L
.0822 .08928 L
.08286 .08925 L
.08435 .08916 L
.08698 .08894 L
.08946 .08867 L
.09412 .088 L
.10458 .08601 L
.14291 .07645 L
.18369 .06616 L
.22296 .05749 L
.26071 .05043 L
.30091 .04419 L
.3396 .03926 L
.38074 .03498 L
.42036 .03165 L
.45847 .02904 L
.49903 .02678 L
.53808 .02502 L
.57958 .02352 L
.61956 .02235 L
.65802 .02145 L
.69894 .02067 L
.73835 .02007 L
.77623 .0196 L
.81657 .01919 L
.8554 .01888 L
.89667 .01861 L
Mistroke
.93643 .0184 L
.97468 .01824 L
.97619 .01824 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.06244 .12028 L
.10458 .21709 L
.12507 .256 L
.14415 .28694 L
.16371 .31308 L
.18221 .33252 L
.192 .34075 L
.20263 .34812 L
.21222 .35341 L
.2212 .35723 L
.23064 .36012 L
.23565 .3612 L
.23844 .36168 L
.24104 .36204 L
.24373 .36234 L
.24527 .36247 L
.24667 .36257 L
.248 .36264 L
.24926 .36269 L
.24995 .36271 L
.25059 .36273 L
.25128 .36274 L
.25202 .36274 L
.25322 .36274 L
.2545 .36272 L
.25571 .36269 L
.25681 .36265 L
.2581 .36258 L
.25951 .3625 L
.26207 .36228 L
.26692 .36171 L
.27147 .36098 L
.28184 .35867 L
.29195 .35562 L
.30285 .35157 L
.34399 .3309 L
.38361 .30632 L
.42172 .28131 L
.46228 .2552 L
.50133 .23162 L
.54283 .20884 L
.58281 .18929 L
.62127 .17271 L
.66219 .15733 L
.7016 .14454 L
.73948 .13393 L
.77982 .12423 L
.81865 .11628 L
.85992 .10912 L
Mistroke
.89968 .10331 L
.93793 .0986 L
.97619 .09464 L
Mfstroke
.933 0 1 r
.02381 .01472 m
.03279 .03402 L
.04262 .0528 L
.04758 .06087 L
.05288 .06827 L
.06244 .07841 L
.06788 .08247 L
.07075 .08418 L
.07379 .08571 L
.07644 .08682 L
.07936 .08784 L
.08205 .0886 L
.08451 .08916 L
.08689 .0896 L
.0895 .08997 L
.09093 .09013 L
.09225 .09025 L
.0936 .09035 L
.09487 .09043 L
.09605 .09048 L
.09734 .09052 L
.0985 .09054 L
.09957 .09055 L
.10073 .09054 L
.10201 .09052 L
.10265 .09051 L
.10334 .09049 L
.10458 .09044 L
.10714 .09032 L
.10986 .09013 L
.11475 .08969 L
.12582 .0883 L
.14594 .08493 L
.18369 .07759 L
.22389 .06981 L
.26258 .06294 L
.30372 .05645 L
.34335 .05098 L
.38145 .04639 L
.42202 .04215 L
.46106 .03863 L
.50256 .03542 L
.54254 .03276 L
.58101 .03057 L
.62193 .02856 L
.66133 .02691 L
.69922 .02554 L
.73956 .02429 L
.77838 .02326 L
.81966 .02233 L
Mistroke
.85942 .02156 L
.89766 .02092 L
.93836 .02034 L
.97619 .01988 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.06244 .09627 L
.08255 .13143 L
.0932 .14693 L
.10458 .16075 L
.11531 .17104 L
.12507 .17814 L
.12977 .18082 L
.13488 .18322 L
.13935 .18491 L
.14415 .18632 L
.1467 .18691 L
.14903 .18736 L
.15139 .18772 L
.15359 .18799 L
.15493 .18812 L
.15614 .18821 L
.15749 .1883 L
.15823 .18833 L
.15892 .18836 L
.16019 .18839 L
.16136 .1884 L
.16264 .1884 L
.16328 .18839 L
.16399 .18837 L
.16466 .18835 L
.1654 .18832 L
.16673 .18825 L
.16924 .18807 L
.17216 .18778 L
.17486 .18744 L
.17979 .18666 L
.18502 .18562 L
.20449 .18028 L
.22277 .17386 L
.26146 .15833 L
.3026 .14145 L
.34222 .12618 L
.38033 .11286 L
.42089 .10025 L
.45994 .08959 L
.50143 .07973 L
.54141 .07152 L
.57988 .06467 L
.6208 .05839 L
.6602 .05318 L
.69809 .04886 L
.73843 .0449 L
.77725 .04162 L
.81853 .03864 L
Mistroke
.85829 .03619 L
.89654 .03416 L
.93723 .03231 L
.97619 .0308 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.06244 .11575 L
.08255 .15984 L
.10458 .19849 L
.11448 .21216 L
.12507 .22415 L
.13506 .23301 L
.14415 .23908 L
.14898 .24157 L
.15411 .2437 L
.15848 .2451 L
.1633 .24625 L
.166 .24671 L
.16847 .24703 L
.16983 .24716 L
.17055 .24722 L
.17132 .24727 L
.17206 .24731 L
.17272 .24734 L
.17403 .24739 L
.17532 .2474 L
.17652 .2474 L
.17782 .24737 L
.17848 .24734 L
.17921 .24731 L
.18042 .24724 L
.18173 .24714 L
.18408 .24691 L
.18664 .24658 L
.18937 .24614 L
.19426 .24515 L
.20532 .24204 L
.22544 .23403 L
.26319 .21431 L
.3034 .19121 L
.34208 .16969 L
.38322 .14884 L
.42285 .13114 L
.46096 .11635 L
.50152 .10283 L
.54056 .09177 L
.58206 .08185 L
.62204 .07385 L
.66051 .06737 L
.70143 .0616 L
.74083 .05697 L
.77872 .05324 L
.81906 .04993 L
.85788 .04728 L
.89916 .04494 L
Mistroke
.93892 .0431 L
.97619 .04166 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.02499 .01722 L
.02605 .01903 L
.02729 .02064 L
.02846 .02181 L
.02954 .02264 L
.03053 .02326 L
.03279 .02426 L
.03396 .02464 L
.03506 .02492 L
.03636 .0252 L
.03756 .02541 L
.04 .02573 L
.04134 .02585 L
.04262 .02595 L
.045 .02609 L
.04633 .02615 L
.04753 .02619 L
.04866 .02622 L
.04988 .02625 L
.05104 .02626 L
.0521 .02627 L
.05334 .02628 L
.0545 .02629 L
.05577 .02628 L
.05648 .02628 L
.05713 .02628 L
.05844 .02627 L
.05986 .02625 L
.06244 .02622 L
.06749 .02612 L
.07306 .02599 L
.08433 .02566 L
.10458 .02499 L
.14478 .02363 L
.18347 .02242 L
.22461 .0213 L
.26423 .02037 L
.30234 .0196 L
.3429 .0189 L
.38195 .01833 L
.42345 .01782 L
.46343 .0174 L
.5019 .01706 L
.54281 .01676 L
.58222 .01651 L
.6201 .01631 L
.66044 .01613 L
.69927 .01598 L
.74054 .01584 L
Mistroke
.78031 .01574 L
.81855 .01565 L
.85925 .01557 L
.89843 .01551 L
.94006 .01545 L
.97619 .01541 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.06244 .10966 L
.08255 .15226 L
.10458 .19096 L
.11448 .20518 L
.12507 .21809 L
.13499 .22799 L
.14415 .2353 L
.15437 .24145 L
.15975 .2439 L
.16546 .24594 L
.17041 .24726 L
.17504 .24815 L
.1777 .24852 L
.18013 .24876 L
.18147 .24887 L
.18218 .24891 L
.18293 .24895 L
.18366 .24898 L
.18431 .249 L
.1856 .24903 L
.1868 .24903 L
.18792 .24902 L
.18915 .24899 L
.19047 .24894 L
.19185 .24887 L
.19317 .24877 L
.19562 .24855 L
.20004 .24799 L
.20484 .24715 L
.21566 .24455 L
.22566 .24137 L
.26493 .2243 L
.30268 .20472 L
.34288 .18359 L
.38157 .16443 L
.42271 .14596 L
.46234 .13022 L
.50044 .11695 L
.541 .10468 L
.58005 .09452 L
.62155 .08528 L
.66153 .07772 L
.7 .07151 L
.74091 .0659 L
.78032 .06133 L
.81821 .05759 L
.85854 .05423 L
.89737 .05149 L
.93865 .04905 L
Mistroke
.97619 .04719 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.06244 .10895 L
.10458 .19591 L
.12507 .22961 L
.14415 .25493 L
.16254 .27345 L
.17284 .28131 L
.18221 .28695 L
.18704 .28931 L
.19216 .29142 L
.19659 .29293 L
.20135 .29424 L
.20402 .29484 L
.20646 .29531 L
.20894 .2957 L
.21124 .29599 L
.21391 .29625 L
.21533 .29635 L
.21605 .29639 L
.21683 .29643 L
.21758 .29646 L
.21826 .29648 L
.21892 .2965 L
.21961 .29651 L
.22082 .29652 L
.22214 .29651 L
.22344 .29648 L
.22465 .29644 L
.22597 .29637 L
.22738 .29628 L
.22974 .29609 L
.23234 .29581 L
.23714 .29512 L
.24165 .29428 L
.25171 .29182 L
.26256 .28834 L
.3037 .26983 L
.34333 .24791 L
.38143 .22604 L
.422 .20363 L
.46104 .18373 L
.50254 .16471 L
.54252 .14854 L
.58099 .13489 L
.62191 .12227 L
.66131 .1118 L
.6992 .1031 L
.73954 .09515 L
.77836 .08862 L
.81964 .08272 L
Mistroke
.8594 .07791 L
.89764 .07399 L
.93834 .07046 L
.97619 .06771 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.02499 .0174 L
.02605 .0193 L
.02729 .02097 L
.02846 .02215 L
.02954 .02298 L
.03053 .02359 L
.03279 .02458 L
.03396 .02495 L
.03506 .02523 L
.03636 .0255 L
.03756 .0257 L
.04 .026 L
.04134 .02612 L
.04262 .02622 L
.045 .02635 L
.04633 .0264 L
.04753 .02644 L
.04866 .02647 L
.04988 .02649 L
.05104 .0265 L
.0521 .02651 L
.05334 .02652 L
.0545 .02652 L
.05577 .02651 L
.05648 .02651 L
.05713 .02651 L
.05844 .02649 L
.05986 .02647 L
.06244 .02643 L
.06749 .02633 L
.07306 .02618 L
.08433 .02583 L
.10458 .02511 L
.14478 .02366 L
.18347 .02239 L
.22461 .02122 L
.26423 .02026 L
.30234 .01948 L
.3429 .01877 L
.38195 .0182 L
.42345 .0177 L
.46343 .01729 L
.5019 .01696 L
.54281 .01667 L
.58222 .01644 L
.6201 .01625 L
.66044 .01609 L
.69927 .01595 L
.74054 .01583 L
Mistroke
.78031 .01574 L
.81855 .01566 L
.85925 .01559 L
.89843 .01554 L
.94006 .01549 L
.97619 .01546 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.06244 .0631 L
.08255 .08608 L
.10458 .10823 L
.1253 .12544 L
.14415 .13773 L
.16372 .14716 L
.17449 .15102 L
.18466 .15387 L
.19436 .15596 L
.19966 .15686 L
.20463 .15756 L
.20922 .1581 L
.21341 .1585 L
.21807 .15884 L
.22069 .159 L
.22307 .15911 L
.22536 .1592 L
.22784 .15928 L
.2292 .15931 L
.23046 .15933 L
.23165 .15935 L
.23292 .15936 L
.23401 .15936 L
.23517 .15936 L
.23627 .15936 L
.23728 .15936 L
.23845 .15934 L
.23973 .15933 L
.24206 .15928 L
.24454 .15922 L
.24728 .15912 L
.25282 .15887 L
.25796 .15857 L
.26278 .15823 L
.28297 .1563 L
.30147 .15397 L
.34109 .14784 L
.3792 .14115 L
.41976 .13374 L
.45881 .12664 L
.50031 .11932 L
.54029 .11259 L
.57876 .10646 L
.61967 .10035 L
.65908 .09486 L
.69696 .08994 L
.7373 .08509 L
.77613 .08077 L
.8174 .07654 L
Mistroke
.85717 .0728 L
.89541 .06949 L
.93611 .06625 L
.97529 .0634 L
.97619 .06334 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.02605 .018 L
.02729 .01939 L
.02846 .02048 L
.03072 .02212 L
.03279 .02319 L
.03524 .02412 L
.0375 .02475 L
.03998 .02527 L
.04262 .0257 L
.04496 .02598 L
.04749 .02623 L
.05205 .02655 L
.05483 .02669 L
.05748 .02679 L
.05985 .02686 L
.06244 .02692 L
.06382 .02694 L
.0653 .02697 L
.06661 .02698 L
.06799 .027 L
.06924 .02701 L
.0699 .02701 L
.07061 .02701 L
.07186 .02702 L
.07302 .02702 L
.07377 .02702 L
.07447 .02702 L
.07524 .02702 L
.07605 .02702 L
.07675 .02702 L
.07741 .02702 L
.07814 .02702 L
.07892 .02702 L
.08172 .027 L
.08429 .02698 L
.08901 .02694 L
.09418 .02687 L
.10458 .02671 L
.14514 .02587 L
.18419 .02497 L
.22568 .02403 L
.26567 .02318 L
.30413 .02243 L
.34505 .0217 L
.38445 .02107 L
.42234 .02052 L
.46268 .01999 L
.5015 .01954 L
.54278 .01911 L
Mistroke
.58254 .01874 L
.62079 .01842 L
.66149 .01812 L
.70067 .01787 L
.7423 .01763 L
.78242 .01742 L
.82102 .01724 L
.86208 .01708 L
.90162 .01694 L
.93964 .01682 L
.97619 .01671 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.02499 .01776 L
.02605 .01983 L
.02729 .02156 L
.02846 .02274 L
.02954 .02356 L
.03053 .02414 L
.03163 .02464 L
.03279 .02506 L
.03395 .02539 L
.0352 .02567 L
.03746 .02604 L
.03884 .0262 L
.04016 .02632 L
.04145 .02641 L
.04262 .02648 L
.04384 .02654 L
.045 .02658 L
.04622 .02661 L
.04753 .02664 L
.04869 .02665 L
.04991 .02666 L
.05095 .02666 L
.0521 .02666 L
.05279 .02665 L
.05345 .02665 L
.05468 .02663 L
.05601 .02662 L
.05745 .02659 L
.06244 .02648 L
.07306 .02614 L
.08433 .02571 L
.10458 .02488 L
.14233 .02336 L
.18253 .02194 L
.22122 .02078 L
.26236 .01975 L
.30199 .01894 L
.34009 .0183 L
.38065 .01774 L
.4197 .0173 L
.4612 .01691 L
.50118 .01662 L
.53965 .01638 L
.58056 .01618 L
.61997 .01602 L
.65785 .0159 L
.69819 .01579 L
.73702 .01571 L
.7783 .01563 L
Mistroke
.81806 .01558 L
.8563 .01553 L
.897 .0155 L
.93618 .01547 L
.97619 .01544 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.06244 .07405 L
.10458 .13323 L
.14415 .18028 L
.18221 .21437 L
.20178 .22694 L
.22272 .23656 L
.23293 .23989 L
.23832 .2413 L
.24402 .24255 L
.24901 .24345 L
.25449 .24422 L
.2569 .2445 L
.25949 .24475 L
.26194 .24495 L
.26416 .2451 L
.2667 .24523 L
.26809 .24528 L
.2694 .24532 L
.27062 .24535 L
.27174 .24537 L
.27297 .24538 L
.27427 .24538 L
.27558 .24538 L
.27632 .24537 L
.27699 .24536 L
.27829 .24533 L
.27952 .2453 L
.28229 .2452 L
.2853 .24504 L
.29036 .24467 L
.29573 .24416 L
.30539 .24292 L
.32486 .23938 L
.34314 .23506 L
.38182 .22381 L
.42296 .21019 L
.46259 .1966 L
.5007 .18371 L
.54126 .17055 L
.5803 .1586 L
.6218 .1468 L
.66178 .13631 L
.70025 .12705 L
.74117 .11805 L
.78057 .11017 L
.81846 .10327 L
.8588 .09661 L
.89762 .09081 L
.9389 .08526 L
Mistroke
.97619 .08074 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.02499 .01672 L
.02605 .01825 L
.02721 .01962 L
.02846 .02083 L
.02961 .02173 L
.03068 .02241 L
.03279 .02345 L
.03506 .02425 L
.03756 .02488 L
.04017 .02534 L
.04262 .02566 L
.04517 .0259 L
.04761 .02608 L
.04979 .0262 L
.05217 .0263 L
.05475 .02638 L
.05619 .02641 L
.0575 .02643 L
.05872 .02645 L
.06005 .02647 L
.06129 .02648 L
.06244 .02649 L
.06372 .02649 L
.06488 .02649 L
.06553 .02649 L
.06622 .02649 L
.0675 .02649 L
.06868 .02649 L
.06995 .02648 L
.07221 .02646 L
.07484 .02644 L
.07731 .02641 L
.08293 .02632 L
.10458 .02587 L
.14327 .02488 L
.18441 .02382 L
.22403 .02286 L
.26214 .02202 L
.3027 .02121 L
.34175 .02052 L
.38324 .01987 L
.42323 .01931 L
.46169 .01884 L
.50261 .0184 L
.54201 .01803 L
.5799 .01771 L
.62024 .01741 L
.65906 .01716 L
.70034 .01693 L
Mistroke
.7401 .01673 L
.77835 .01656 L
.81905 .01641 L
.85823 .01628 L
.89986 .01615 L
.93998 .01605 L
.97619 .01597 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.06244 .11491 L
.08255 .16083 L
.10458 .20453 L
.1253 .23793 L
.14415 .2609 L
.15421 .27012 L
.16372 .27687 L
.1686 .27961 L
.17376 .282 L
.17943 .28402 L
.18211 .28477 L
.18466 .28535 L
.18701 .2858 L
.18958 .28617 L
.1907 .2863 L
.19191 .28641 L
.19303 .28649 L
.19407 .28655 L
.19538 .2866 L
.19608 .28662 L
.19681 .28663 L
.19803 .28662 L
.19873 .28661 L
.19938 .28659 L
.2006 .28654 L
.2017 .28647 L
.20298 .28637 L
.2042 .28626 L
.2064 .286 L
.20875 .28565 L
.21296 .28484 L
.21749 .28372 L
.2225 .28222 L
.24184 .27418 L
.2627 .26261 L
.30384 .23548 L
.34346 .20833 L
.38157 .18367 L
.42213 .16004 L
.46118 .14009 L
.50268 .12182 L
.54266 .10684 L
.58112 .09458 L
.62204 .08356 L
.66145 .07464 L
.69933 .0674 L
.73967 .06091 L
.7785 .05569 L
.81977 .05105 L
Mistroke
.85953 .04733 L
.89778 .04433 L
.93848 .04167 L
.97619 .03961 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.02499 .01685 L
.02605 .01845 L
.02721 .01986 L
.02846 .02108 L
.02961 .02197 L
.03068 .02265 L
.03279 .02364 L
.03396 .02406 L
.03506 .02439 L
.03636 .02471 L
.03756 .02496 L
.04 .02535 L
.04262 .02564 L
.04514 .02585 L
.04748 .02598 L
.05004 .02609 L
.05148 .02613 L
.05278 .02616 L
.05394 .02619 L
.05517 .02621 L
.05581 .02621 L
.05652 .02622 L
.05776 .02623 L
.05893 .02624 L
.06018 .02624 L
.06137 .02624 L
.06244 .02624 L
.06369 .02623 L
.06439 .02623 L
.06505 .02622 L
.06783 .0262 L
.07022 .02617 L
.07281 .02613 L
.08408 .02591 L
.10458 .02539 L
.14572 .02423 L
.18534 .02315 L
.22345 .02221 L
.26401 .02131 L
.30306 .02055 L
.34456 .01983 L
.38454 .01924 L
.423 .01873 L
.46392 .01827 L
.50333 .01788 L
.54121 .01755 L
.58155 .01725 L
.62038 .01699 L
.66165 .01676 L
Mistroke
.70141 .01656 L
.73966 .0164 L
.78036 .01625 L
.81954 .01612 L
.86117 .01601 L
.90129 .01591 L
.9399 .01583 L
.97619 .01577 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.04262 .09836 L
.06244 .17411 L
.08255 .23423 L
.09396 .25995 L
.10458 .27832 L
.10961 .28517 L
.11508 .2913 L
.11989 .29563 L
.125 .29915 L
.12959 .30143 L
.13221 .30238 L
.13346 .30274 L
.13466 .30304 L
.13573 .30326 L
.1369 .30346 L
.13796 .3036 L
.13895 .3037 L
.14012 .30377 L
.14119 .3038 L
.14242 .30379 L
.14357 .30373 L
.14473 .30364 L
.14598 .3035 L
.14716 .30332 L
.14823 .30313 L
.15085 .30252 L
.15334 .30178 L
.15828 .29986 L
.16365 .29717 L
.18212 .28412 L
.22291 .24446 L
.26217 .20432 L
.29992 .16991 L
.34013 .13945 L
.37881 .11598 L
.41995 .09645 L
.45958 .08194 L
.49769 .07114 L
.53825 .06231 L
.57729 .0558 L
.61879 .05053 L
.65877 .04667 L
.69724 .04382 L
.73816 .04149 L
.77756 .03977 L
.81545 .03849 L
.85579 .03743 L
.89461 .03666 L
.93589 .03602 L
Mistroke
.97565 .03557 L
.97619 .03556 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.04262 .07206 L
.06244 .12278 L
.07286 .14281 L
.08255 .15667 L
.08813 .16255 L
.0932 .16667 L
.096 .16848 L
.09905 .17009 L
.10171 .17123 L
.10458 .17217 L
.10588 .17251 L
.10712 .17279 L
.10833 .17301 L
.10945 .17319 L
.1106 .17333 L
.11164 .17342 L
.11279 .1735 L
.11402 .17354 L
.11467 .17355 L
.11536 .17355 L
.11659 .17352 L
.11728 .17349 L
.11792 .17345 L
.11937 .17333 L
.12065 .1732 L
.12181 .17304 L
.12442 .17262 L
.12959 .17145 L
.13522 .16977 L
.14545 .16589 L
.18623 .14554 L
.22549 .12509 L
.26325 .10744 L
.30345 .09138 L
.34214 .07849 L
.38328 .06723 L
.4229 .0584 L
.46101 .05147 L
.50157 .04547 L
.54061 .04079 L
.58211 .03679 L
.62209 .03369 L
.66056 .03128 L
.70148 .02921 L
.74088 .02761 L
.77877 .02636 L
.81911 .02529 L
.85793 .02446 L
.89921 .02374 L
Mistroke
.93897 .0232 L
.97619 .02278 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.04262 .08573 L
.06244 .15114 L
.08255 .20322 L
.09396 .22521 L
.09905 .23319 L
.10458 .24056 L
.11004 .24656 L
.11508 .251 L
.11989 .25432 L
.12235 .25567 L
.125 .25689 L
.12738 .25778 L
.12956 .25842 L
.13175 .25892 L
.13285 .25911 L
.13384 .25925 L
.135 .25938 L
.13625 .25947 L
.1374 .25952 L
.13849 .25953 L
.13976 .2595 L
.14093 .25943 L
.14222 .25932 L
.14357 .25916 L
.14612 .25873 L
.14853 .25818 L
.15305 .25683 L
.15792 .25493 L
.16321 .25241 L
.18154 .24087 L
.22233 .20774 L
.26159 .17516 L
.29934 .14729 L
.33955 .12235 L
.37823 .10281 L
.41937 .08618 L
.459 .07354 L
.49711 .06392 L
.53767 .05586 L
.57671 .04979 L
.61821 .04476 L
.65819 .04099 L
.69666 .03816 L
.73758 .03581 L
.77698 .03404 L
.81487 .03271 L
.85521 .0316 L
.89403 .03077 L
.93531 .03009 L
Mistroke
.97507 .02958 L
.97619 .02957 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.04262 .04512 L
.0522 .05812 L
.06244 .06943 L
.0679 .07428 L
.07286 .07803 L
.08255 .08366 L
.08798 .08596 L
.09388 .08787 L
.09944 .08921 L
.10458 .09011 L
.10924 .09068 L
.11185 .09092 L
.11425 .09108 L
.11647 .0912 L
.11772 .09125 L
.11889 .09129 L
.12001 .09131 L
.12103 .09133 L
.1222 .09134 L
.12331 .09135 L
.1245 .09135 L
.12581 .09134 L
.12648 .09133 L
.12719 .09132 L
.12847 .09129 L
.13095 .09121 L
.13321 .09112 L
.13872 .09082 L
.14393 .09044 L
.16384 .08841 L
.18226 .086 L
.22153 .08022 L
.25928 .07452 L
.29948 .06873 L
.33817 .06355 L
.37931 .05853 L
.41893 .05417 L
.45704 .05039 L
.4976 .04678 L
.53665 .04367 L
.57814 .04073 L
.61813 .03822 L
.65659 .03607 L
.69751 .03404 L
.73691 .0323 L
.7748 .03082 L
.81514 .02941 L
.85397 .02822 L
.89524 .02709 L
Mistroke
.935 .02613 L
.97325 .02532 L
.97619 .02526 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.03279 .03327 L
.04262 .05151 L
.05288 .06683 L
.06244 .07712 L
.06792 .08137 L
.0731 .08443 L
.07775 .0865 L
.0828 .08813 L
.08542 .08876 L
.0883 .08931 L
.09131 .08974 L
.09275 .0899 L
.09413 .09002 L
.09538 .09012 L
.09676 .0902 L
.098 .09025 L
.09916 .09029 L
.09987 .0903 L
.10054 .09031 L
.10178 .09032 L
.10248 .09032 L
.10313 .09031 L
.10383 .0903 L
.10458 .09029 L
.1058 .09025 L
.10713 .0902 L
.10954 .09008 L
.11406 .08975 L
.11934 .08923 L
.12422 .08864 L
.14255 .08585 L
.18182 .07854 L
.21957 .07138 L
.25977 .0643 L
.29846 .05819 L
.3396 .05245 L
.37922 .04763 L
.41733 .04358 L
.45789 .03983 L
.49694 .03671 L
.53844 .03384 L
.57842 .03147 L
.61688 .02949 L
.6578 .02767 L
.69721 .02617 L
.73509 .02492 L
.77543 .02377 L
.81426 .02282 L
.85553 .02195 L
Mistroke
.89529 .02123 L
.93354 .02064 L
.97424 .02009 L
.97619 .02007 L
Mfstroke
1 0 .617 r
.02381 .01472 m
.04262 .05951 L
.06244 .10262 L
.08255 .13889 L
.09409 .15521 L
.10458 .16688 L
.1094 .17122 L
.11464 .17523 L
.11917 .17812 L
.12415 .18071 L
.12944 .18283 L
.13213 .18368 L
.13504 .18443 L
.13775 .18498 L
.14023 .18537 L
.14142 .18551 L
.14272 .18565 L
.14387 .18574 L
.14509 .18582 L
.14572 .18585 L
.14642 .18587 L
.14764 .1859 L
.14833 .18591 L
.14907 .18591 L
.14977 .1859 L
.1504 .18589 L
.15163 .18585 L
.15233 .18581 L
.15297 .18578 L
.15541 .1856 L
.15756 .18537 L
.15994 .18507 L
.16476 .18426 L
.17558 .18169 L
.18573 .17853 L
.22442 .16292 L
.26556 .14453 L
.30519 .12763 L
.34329 .11292 L
.38385 .09912 L
.4229 .08759 L
.4644 .07706 L
.50438 .06841 L
.54285 .0613 L
.58376 .05486 L
.62317 .04961 L
.66106 .0453 L
.70139 .04141 L
.74022 .03824 L
.7815 .03539 L
Mistroke
.82126 .03308 L
.8595 .03119 L
.9002 .0295 L
.93938 .02812 L
.97619 .02703 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.06244 .07936 L
.10458 .14158 L
.12507 .16645 L
.14415 .18538 L
.16254 .19933 L
.17284 .20529 L
.18221 .20958 L
.18704 .21139 L
.19216 .21302 L
.20135 .21526 L
.20646 .21614 L
.21124 .21674 L
.21399 .217 L
.21649 .21717 L
.21788 .21725 L
.21939 .21732 L
.22008 .21734 L
.22081 .21736 L
.2215 .21738 L
.22214 .21739 L
.22338 .2174 L
.22404 .21741 L
.22474 .21741 L
.22548 .2174 L
.22618 .2174 L
.22749 .21737 L
.22872 .21734 L
.22986 .2173 L
.23242 .21718 L
.23499 .21701 L
.23782 .21679 L
.24355 .21618 L
.25395 .21465 L
.26372 .21276 L
.30241 .20238 L
.34355 .18865 L
.38317 .17469 L
.42128 .16148 L
.46184 .14814 L
.50089 .13619 L
.54238 .12455 L
.58237 .11437 L
.62083 .10549 L
.66175 .09698 L
.70115 .08964 L
.73904 .08329 L
.77938 .07723 L
.81821 .07203 L
.85948 .06711 L
Mistroke
.89924 .0629 L
.93749 .05929 L
.97619 .05604 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.04262 .05803 L
.06244 .09991 L
.08426 .13827 L
.0949 .15312 L
.10458 .16419 L
.11403 .17272 L
.12297 .17879 L
.12787 .18135 L
.1324 .18327 L
.13737 .1849 L
.14007 .18559 L
.14264 .18614 L
.14499 .18654 L
.14755 .18687 L
.14868 .18699 L
.14988 .18709 L
.15101 .18717 L
.15205 .18722 L
.15336 .18727 L
.15405 .18729 L
.15478 .1873 L
.15601 .1873 L
.15671 .18729 L
.15736 .18728 L
.15857 .18724 L
.15968 .18719 L
.16096 .18712 L
.16217 .18703 L
.16438 .18683 L
.16672 .18656 L
.17094 .18595 L
.18047 .184 L
.18984 .18148 L
.19994 .17824 L
.21822 .17147 L
.25936 .1543 L
.29899 .13767 L
.33709 .12277 L
.37766 .10853 L
.4167 .09645 L
.4582 .08527 L
.49818 .07599 L
.53665 .06829 L
.57757 .06125 L
.61697 .05546 L
.65486 .05067 L
.6952 .04631 L
.73402 .04273 L
.7753 .03949 L
Mistroke
.81506 .03684 L
.8533 .03467 L
.894 .0327 L
.93318 .03109 L
.97482 .02965 L
.97619 .0296 L
Mfstroke
1 0 .545 r
.02381 .01472 m
.04262 .05607 L
.06244 .09013 L
.07286 .10286 L
.08255 .11158 L
.08813 .11534 L
.0932 .11807 L
.09905 .1205 L
.10458 .12216 L
.10919 .12315 L
.11182 .12356 L
.11428 .12386 L
.1156 .12399 L
.11686 .12409 L
.11801 .12417 L
.11923 .12424 L
.12055 .12429 L
.12177 .12432 L
.12252 .12433 L
.12323 .12434 L
.12455 .12433 L
.12562 .12432 L
.1268 .12429 L
.12802 .12425 L
.12917 .1242 L
.13122 .12409 L
.13341 .12393 L
.13842 .12344 L
.14299 .12286 L
.16208 .11942 L
.18284 .11455 L
.22362 .10376 L
.26289 .09343 L
.30064 .08423 L
.34084 .07543 L
.37953 .06796 L
.42067 .06104 L
.46029 .05528 L
.4984 .05049 L
.53896 .04609 L
.57801 .04246 L
.61951 .03916 L
.65949 .03646 L
.69795 .03423 L
.73887 .0322 L
.77828 .03054 L
.81616 .02917 L
.8565 .02793 L
.89533 .02691 L
.9366 .02599 L
Mistroke
.97619 .02524 L
Mfstroke
1 0 .522 r
.02381 .01472 m
.03279 .03597 L
.04262 .05671 L
.05288 .07389 L
.06244 .08522 L
.06792 .0898 L
.0731 .09304 L
.07775 .09517 L
.08038 .09609 L
.0828 .09679 L
.08523 .09736 L
.08783 .09783 L
.08933 .09804 L
.09069 .0982 L
.09199 .09832 L
.09337 .09843 L
.09412 .09847 L
.0948 .0985 L
.09612 .09855 L
.09686 .09857 L
.09766 .09858 L
.09842 .09858 L
.09912 .09857 L
.10038 .09855 L
.1011 .09854 L
.10177 .09851 L
.10313 .09845 L
.10458 .09837 L
.10714 .09818 L
.10986 .09792 L
.11475 .09734 L
.12582 .09557 L
.14594 .09142 L
.18369 .08258 L
.22389 .07342 L
.26258 .06546 L
.30372 .05807 L
.34335 .05194 L
.38145 .04687 L
.42202 .04227 L
.46106 .03851 L
.50256 .03513 L
.54254 .03239 L
.58101 .03015 L
.62193 .02815 L
.66133 .02652 L
.69922 .02519 L
.73956 .02399 L
.77838 .02302 L
.81966 .02216 L
Mistroke
.85942 .02146 L
.89766 .02089 L
.93836 .02038 L
.97619 .01998 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.03279 .04439 L
.04262 .07367 L
.053 .09929 L
.06244 .11724 L
.0675 .12475 L
.07298 .13138 L
.07878 .13679 L
.08426 .1406 L
.08939 .14315 L
.09197 .14411 L
.09482 .14494 L
.09725 .14547 L
.09859 .1457 L
.09986 .14588 L
.10104 .14602 L
.10233 .14613 L
.10349 .1462 L
.10458 .14624 L
.10587 .14626 L
.10651 .14626 L
.10722 .14625 L
.10848 .14621 L
.10966 .14615 L
.11104 .14605 L
.11231 .14593 L
.11515 .14558 L
.12026 .14469 L
.1251 .14357 L
.14371 .13762 L
.18204 .12162 L
.22282 .10428 L
.26209 .08938 L
.29984 .07715 L
.34004 .0663 L
.37873 .05774 L
.41987 .05034 L
.45949 .0446 L
.4976 .04013 L
.53816 .0363 L
.57721 .03333 L
.61871 .03081 L
.65869 .02888 L
.69715 .02738 L
.73807 .0261 L
.77748 .02512 L
.81536 .02436 L
.8557 .02371 L
.89453 .0232 L
.9358 .02278 L
Mistroke
.97556 .02245 L
.97619 .02244 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.03279 .04614 L
.04262 .07686 L
.053 .10318 L
.06244 .12095 L
.06786 .12855 L
.07298 .13415 L
.07839 .13859 L
.08144 .14049 L
.08426 .14191 L
.08652 .14283 L
.08895 .14362 L
.09035 .14398 L
.09162 .14426 L
.09283 .14449 L
.09412 .14468 L
.09545 .14484 L
.09669 .14494 L
.09744 .14498 L
.09815 .14501 L
.09879 .14503 L
.09948 .14503 L
.10077 .14502 L
.10142 .145 L
.10214 .14497 L
.1034 .14489 L
.10458 .14479 L
.10718 .14448 L
.10959 .14409 L
.11503 .14292 L
.12493 .13996 L
.14349 .13262 L
.18275 .11456 L
.22051 .09792 L
.26071 .0826 L
.2994 .07037 L
.34054 .05981 L
.38016 .05167 L
.41827 .04539 L
.45883 .04006 L
.49787 .03599 L
.53937 .03258 L
.57935 .02999 L
.61782 .02802 L
.65874 .02636 L
.69814 .0251 L
.73603 .02413 L
.77637 .02331 L
.81519 .02269 L
.85647 .02217 L
Mistroke
.89623 .02177 L
.93448 .02147 L
.97517 .02121 L
.97619 .0212 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.02605 .01772 L
.02846 .02007 L
.03072 .02166 L
.03279 .02271 L
.03521 .02362 L
.03784 .02434 L
.04032 .02484 L
.04262 .02519 L
.04482 .02546 L
.0472 .02569 L
.0498 .02589 L
.05224 .02603 L
.05497 .02616 L
.05757 .02625 L
.0599 .02632 L
.06244 .02637 L
.06382 .02639 L
.0653 .02641 L
.06661 .02643 L
.06799 .02644 L
.06924 .02645 L
.0699 .02645 L
.07061 .02645 L
.07186 .02646 L
.07302 .02646 L
.07377 .02646 L
.07447 .02646 L
.07524 .02646 L
.07605 .02646 L
.07675 .02646 L
.07741 .02645 L
.07892 .02645 L
.08151 .02643 L
.08429 .02641 L
.08945 .02636 L
.09488 .02629 L
.10458 .02614 L
.14269 .0254 L
.18325 .02452 L
.22229 .0237 L
.26379 .02287 L
.30377 .02214 L
.34224 .02149 L
.38316 .02087 L
.42256 .02033 L
.46045 .01985 L
.50079 .0194 L
.53961 .019 L
.58089 .01862 L
Mistroke
.62065 .01829 L
.6589 .01801 L
.69959 .01774 L
.73878 .01751 L
.78041 .01729 L
.82053 .0171 L
.85913 .01693 L
.90019 .01677 L
.93973 .01664 L
.97619 .01653 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.04262 .07331 L
.06244 .12745 L
.08255 .16943 L
.09396 .18627 L
.09905 .19213 L
.10458 .19738 L
.11004 .20148 L
.11508 .20436 L
.11989 .20639 L
.12232 .20715 L
.125 .20781 L
.12623 .20805 L
.12741 .20824 L
.12848 .20839 L
.12962 .20851 L
.13085 .20861 L
.13199 .20868 L
.13269 .2087 L
.13335 .20872 L
.13459 .20872 L
.13568 .20869 L
.13684 .20864 L
.13782 .20858 L
.1389 .20848 L
.14132 .2082 L
.14357 .20784 L
.14858 .20677 L
.15402 .20519 L
.16392 .20147 L
.18248 .19239 L
.22326 .16838 L
.26253 .14521 L
.30028 .12515 L
.34048 .10674 L
.37917 .09185 L
.42031 .07875 L
.45994 .06841 L
.49804 .06025 L
.5386 .05315 L
.57765 .0476 L
.61915 .04282 L
.65913 .03911 L
.6976 .03621 L
.73851 .03371 L
.77792 .03177 L
.8158 .03025 L
.85614 .02894 L
.89497 .02792 L
.93625 .02704 L
Mistroke
.97601 .02637 L
.97619 .02636 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.03279 .04641 L
.04262 .07457 L
.04758 .08518 L
.05288 .09379 L
.05546 .09702 L
.05789 .09957 L
.06244 .10316 L
.06487 .10453 L
.06754 .10567 L
.06889 .10612 L
.07034 .10651 L
.07159 .10678 L
.07295 .10701 L
.0736 .10709 L
.0743 .10717 L
.07555 .10727 L
.07684 .10733 L
.07801 .10734 L
.07916 .10731 L
.0804 .10725 L
.08157 .10717 L
.08265 .10706 L
.08528 .10671 L
.08773 .10629 L
.09331 .10502 L
.10458 .10161 L
.14349 .08699 L
.18485 .07226 L
.22469 .06048 L
.26302 .05136 L
.30381 .04368 L
.34307 .03789 L
.38082 .03351 L
.42103 .02986 L
.45971 .02712 L
.50085 .02486 L
.54048 .02317 L
.57859 .02191 L
.61915 .02086 L
.65819 .02008 L
.69969 .01944 L
.73967 .01896 L
.77814 .0186 L
.81906 .0183 L
.85846 .01808 L
.89635 .01791 L
.93669 .01777 L
.97551 .01767 L
.97619 .01767 L
Mistroke
Mfstroke
1 0 .379 r
.02381 .01472 m
.02499 .01678 L
.02605 .01835 L
.02721 .01974 L
.02846 .02096 L
.02961 .02186 L
.03068 .02254 L
.03279 .02358 L
.03506 .02436 L
.03756 .02497 L
.04017 .02543 L
.04262 .02573 L
.04517 .02597 L
.04761 .02613 L
.04979 .02625 L
.05217 .02634 L
.05475 .02641 L
.05619 .02644 L
.0575 .02646 L
.05872 .02648 L
.05937 .02648 L
.06005 .02649 L
.06129 .0265 L
.06244 .0265 L
.06309 .0265 L
.06379 .0265 L
.06507 .0265 L
.06631 .0265 L
.06746 .02649 L
.0687 .02649 L
.07006 .02648 L
.07283 .02645 L
.07784 .02638 L
.08253 .0263 L
.10458 .02581 L
.14327 .02478 L
.18441 .02367 L
.22403 .02269 L
.26214 .02183 L
.3027 .02101 L
.34175 .02032 L
.38324 .01966 L
.42323 .01911 L
.46169 .01864 L
.50261 .01821 L
.54201 .01784 L
.5799 .01753 L
.62024 .01724 L
.65906 .01699 L
.70034 .01677 L
Mistroke
.7401 .01658 L
.77835 .01642 L
.81905 .01627 L
.85823 .01614 L
.89986 .01603 L
.93998 .01593 L
.97619 .01586 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.03279 .04289 L
.03793 .05629 L
.04262 .06602 L
.04758 .07366 L
.0503 .07679 L
.05288 .07915 L
.05511 .08077 L
.05747 .08212 L
.06006 .08324 L
.06244 .08398 L
.06378 .08429 L
.06505 .08453 L
.06619 .08469 L
.06743 .08483 L
.06814 .08488 L
.06878 .08492 L
.06952 .08495 L
.07021 .08497 L
.07145 .08498 L
.07215 .08497 L
.0728 .08495 L
.07396 .0849 L
.07505 .08482 L
.07751 .08459 L
.07992 .08429 L
.0825 .08389 L
.09405 .08147 L
.10458 .07875 L
.14443 .06766 L
.18275 .05799 L
.22354 .04944 L
.2628 .04276 L
.30055 .03757 L
.34076 .03314 L
.37944 .02974 L
.42058 .02687 L
.46021 .02468 L
.49832 .02301 L
.53888 .02159 L
.57792 .02051 L
.61942 .01961 L
.6594 .01892 L
.69787 .0184 L
.73879 .01795 L
.77819 .01762 L
.81608 .01736 L
.85642 .01714 L
.89524 .01698 L
.93652 .01684 L
Mistroke
.97619 .01673 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.03279 .0336 L
.04262 .05113 L
.04758 .05815 L
.05288 .06418 L
.05789 .06855 L
.06244 .07154 L
.06507 .0729 L
.06785 .07409 L
.07283 .07568 L
.0756 .07631 L
.0782 .07675 L
.08104 .07711 L
.08264 .07726 L
.0841 .07737 L
.08536 .07744 L
.08606 .07747 L
.08671 .07749 L
.08797 .07753 L
.08912 .07754 L
.08979 .07755 L
.09049 .07755 L
.09175 .07753 L
.09246 .07752 L
.09311 .07751 L
.0946 .07746 L
.0959 .07741 L
.09712 .07735 L
.09942 .07721 L
.10458 .07679 L
.11423 .07573 L
.12449 .07434 L
.14291 .07146 L
.18066 .06516 L
.22086 .05875 L
.25955 .05317 L
.30069 .04793 L
.34031 .04354 L
.37842 .03987 L
.41898 .03649 L
.45803 .03368 L
.49953 .03111 L
.53951 .02899 L
.57798 .02724 L
.61889 .02564 L
.6583 .02431 L
.69618 .02322 L
.73652 .02222 L
.77535 .02139 L
.81662 .02064 L
Mistroke
.85639 .02002 L
.89463 .01951 L
.93533 .01904 L
.97451 .01866 L
.97619 .01865 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.04262 .07382 L
.06244 .12877 L
.08255 .17174 L
.08806 .18072 L
.09396 .18893 L
.09948 .1953 L
.10458 .20008 L
.10954 .20376 L
.1148 .20668 L
.11752 .20782 L
.12007 .20867 L
.12287 .20938 L
.12445 .20967 L
.12589 .20988 L
.12712 .21002 L
.12845 .21012 L
.12969 .21018 L
.13082 .2102 L
.13152 .21019 L
.13215 .21018 L
.13286 .21015 L
.1336 .21011 L
.13484 .21002 L
.13621 .20988 L
.13866 .20953 L
.14129 .20903 L
.14603 .20783 L
.15131 .20608 L
.1562 .20414 L
.16727 .19885 L
.18739 .18721 L
.22665 .16205 L
.2644 .13898 L
.30461 .11745 L
.34329 .09997 L
.38443 .08459 L
.42406 .0725 L
.46217 .063 L
.50273 .05478 L
.54177 .04838 L
.58327 .04291 L
.62325 .03869 L
.66172 .03541 L
.70264 .0326 L
.74204 .03043 L
.77993 .02874 L
.82027 .02728 L
.85909 .02616 L
.90037 .0252 L
Mistroke
.94013 .02446 L
.97619 .02391 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.03279 .04268 L
.04262 .06661 L
.04758 .07515 L
.0503 .07886 L
.05288 .08178 L
.05528 .08404 L
.05789 .08605 L
.06008 .08742 L
.06244 .0886 L
.06506 .08961 L
.06751 .09031 L
.069 .09064 L
.07042 .09088 L
.07169 .09105 L
.07308 .09119 L
.07384 .09124 L
.07456 .09128 L
.07521 .09131 L
.07591 .09132 L
.07667 .09133 L
.07748 .09133 L
.07817 .09132 L
.07893 .09129 L
.07963 .09126 L
.08028 .09123 L
.08173 .09113 L
.08435 .09087 L
.08694 .09054 L
.08933 .09017 L
.09474 .08917 L
.10458 .0869 L
.14385 .07591 L
.1816 .06564 L
.2218 .05622 L
.26049 .04871 L
.30163 .04222 L
.34125 .03718 L
.37936 .03327 L
.41992 .02993 L
.45897 .02735 L
.50046 .02517 L
.54045 .0235 L
.57891 .02222 L
.61983 .02113 L
.65923 .02029 L
.69712 .01964 L
.73746 .01909 L
.77628 .01867 L
.81756 .01831 L
Mistroke
.85732 .01804 L
.89557 .01783 L
.93627 .01765 L
.97545 .01751 L
.97619 .01751 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.03279 .03199 L
.04262 .04903 L
.05288 .06338 L
.06244 .07307 L
.06792 .07708 L
.0731 .07997 L
.07775 .08193 L
.0828 .08349 L
.08542 .0841 L
.0883 .08463 L
.09131 .08506 L
.09275 .08522 L
.09413 .08534 L
.09538 .08544 L
.09676 .08553 L
.098 .08559 L
.09916 .08563 L
.09987 .08565 L
.10054 .08567 L
.10178 .08568 L
.10248 .08569 L
.10313 .08569 L
.10383 .08569 L
.10458 .08568 L
.1058 .08566 L
.10649 .08564 L
.10713 .08562 L
.10954 .08553 L
.11173 .08541 L
.11406 .08526 L
.12422 .08433 L
.13293 .08327 L
.14255 .08191 L
.18275 .0753 L
.22144 .06878 L
.26258 .06229 L
.30221 .05666 L
.34031 .05183 L
.38088 .04728 L
.41992 .04343 L
.46142 .03985 L
.5014 .03685 L
.53987 .03432 L
.58079 .03198 L
.62019 .03001 L
.65808 .02836 L
.69842 .02683 L
.73724 .02554 L
.77852 .02435 L
Mistroke
.81828 .02336 L
.85652 .02253 L
.89722 .02176 L
.9364 .02112 L
.97619 .02056 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.04262 .10369 L
.0522 .14274 L
.06244 .17779 L
.0679 .19317 L
.07286 .20506 L
.0779 .21508 L
.08255 .22248 L
.08798 .22898 L
.09084 .23152 L
.09388 .2336 L
.09514 .23429 L
.09651 .23492 L
.09768 .23537 L
.09897 .23576 L
.09975 .23596 L
.10047 .23611 L
.10122 .23623 L
.1019 .23632 L
.1032 .23641 L
.10391 .23643 L
.10458 .23642 L
.10574 .23636 L
.10699 .23621 L
.10816 .23602 L
.10923 .23578 L
.11186 .23502 L
.11434 .23404 L
.11928 .2315 L
.12466 .22794 L
.14313 .21164 L
.18391 .16903 L
.22318 .13239 L
.26093 .10442 L
.30113 .08183 L
.33982 .06574 L
.38096 .05323 L
.42058 .0445 L
.45869 .03836 L
.49925 .0336 L
.5383 .03027 L
.5798 .02769 L
.61978 .0259 L
.65824 .02462 L
.69916 .02362 L
.73857 .02291 L
.77645 .0224 L
.81679 .02199 L
.85562 .02169 L
.89689 .02145 L
Mistroke
.93666 .02128 L
.9749 .02116 L
.97619 .02115 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.02499 .01685 L
.02605 .01845 L
.02721 .01987 L
.02846 .02109 L
.02961 .022 L
.03068 .02268 L
.03279 .0237 L
.03396 .02413 L
.03506 .02447 L
.03756 .02506 L
.04 .02547 L
.04262 .02579 L
.04516 .02601 L
.04793 .02618 L
.05054 .0263 L
.05179 .02634 L
.05297 .02638 L
.05413 .0264 L
.05538 .02643 L
.05642 .02644 L
.05756 .02646 L
.05879 .02647 L
.0601 .02648 L
.06131 .02648 L
.06244 .02648 L
.0631 .02648 L
.0638 .02648 L
.06506 .02648 L
.06576 .02647 L
.06641 .02647 L
.06791 .02646 L
.0704 .02644 L
.07308 .0264 L
.08278 .02623 L
.10458 .02571 L
.14572 .02456 L
.18534 .02347 L
.22345 .0225 L
.26401 .02158 L
.30306 .0208 L
.34456 .02006 L
.38454 .01944 L
.423 .01892 L
.46392 .01844 L
.50333 .01803 L
.54121 .01769 L
.58155 .01738 L
.62038 .01711 L
.66165 .01687 L
Mistroke
.70141 .01666 L
.73966 .01649 L
.78036 .01633 L
.81954 .0162 L
.86117 .01608 L
.90129 .01598 L
.9399 .0159 L
.97619 .01583 L
Mfstroke
1 0 .19 r
.02381 .01472 m
.02499 .01685 L
.02605 .01846 L
.02721 .01989 L
.02846 .02114 L
.02961 .02207 L
.03068 .02277 L
.03279 .02385 L
.03506 .02468 L
.03756 .02534 L
.04017 .02585 L
.04262 .0262 L
.04517 .02647 L
.04761 .02668 L
.04979 .02682 L
.05217 .02695 L
.05475 .02705 L
.0575 .02713 L
.05883 .02717 L
.06009 .02719 L
.06244 .02723 L
.06371 .02724 L
.06489 .02725 L
.06618 .02726 L
.06691 .02726 L
.06757 .02726 L
.06826 .02727 L
.0689 .02727 L
.06961 .02727 L
.07035 .02727 L
.0716 .02727 L
.07232 .02726 L
.07299 .02726 L
.07417 .02725 L
.07542 .02725 L
.07765 .02723 L
.08269 .02717 L
.0881 .0271 L
.09314 .02701 L
.10458 .02677 L
.14363 .02579 L
.18512 .02468 L
.2251 .02366 L
.26357 .02276 L
.30449 .02189 L
.34389 .02115 L
.38178 .02051 L
.42212 .01991 L
.46094 .01941 L
.50222 .01893 L
Mistroke
.54198 .01854 L
.58023 .0182 L
.62092 .01789 L
.66011 .01763 L
.70174 .01738 L
.74186 .01718 L
.78046 .01701 L
.82152 .01686 L
.86106 .01672 L
.89908 .01661 L
.93956 .01651 L
.97619 .01643 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.02499 .01761 L
.02605 .01961 L
.02729 .02132 L
.02846 .02249 L
.02954 .0233 L
.03053 .02388 L
.03163 .02439 L
.03279 .02481 L
.03395 .02514 L
.0352 .02542 L
.03746 .02579 L
.03884 .02595 L
.04016 .02607 L
.04145 .02617 L
.04262 .02623 L
.04384 .02629 L
.045 .02633 L
.04622 .02636 L
.04753 .02639 L
.04869 .0264 L
.04991 .02641 L
.05095 .02641 L
.0521 .02641 L
.05279 .0264 L
.05345 .0264 L
.05468 .02638 L
.05601 .02637 L
.05745 .02634 L
.06244 .02623 L
.07306 .0259 L
.08433 .02548 L
.10458 .02468 L
.14233 .02321 L
.18253 .02184 L
.22122 .02071 L
.26236 .01971 L
.30199 .01892 L
.34009 .01828 L
.38065 .01772 L
.4197 .01728 L
.4612 .01689 L
.50118 .01658 L
.53965 .01634 L
.58056 .01613 L
.61997 .01597 L
.65785 .01583 L
.69819 .01572 L
.73702 .01563 L
.7783 .01555 L
Mistroke
.81806 .01549 L
.8563 .01544 L
.897 .01539 L
.93618 .01536 L
.97619 .01533 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.03279 .03978 L
.04262 .06312 L
.04758 .07253 L
.05288 .08066 L
.05789 .08657 L
.06244 .09061 L
.06507 .09243 L
.06785 .094 L
.07025 .0951 L
.07283 .09605 L
.0756 .09681 L
.0782 .09733 L
.07978 .09757 L
.08128 .09773 L
.08263 .09784 L
.0834 .09789 L
.0841 .09792 L
.08539 .09795 L
.08611 .09796 L
.08678 .09796 L
.08801 .09794 L
.0893 .09789 L
.09046 .09783 L
.09155 .09776 L
.09401 .09754 L
.09668 .09724 L
.09911 .0969 L
.10458 .09597 L
.12366 .09157 L
.14443 .0859 L
.18521 .07467 L
.22447 .06496 L
.26222 .05695 L
.30243 .04977 L
.34111 .04402 L
.38225 .03898 L
.42188 .03499 L
.45999 .03183 L
.50055 .02907 L
.53959 .02689 L
.58109 .025 L
.62107 .02352 L
.65954 .02236 L
.70046 .02134 L
.73986 .02054 L
.77775 .01991 L
.81809 .01936 L
.85691 .01893 L
.89819 .01856 L
Mistroke
.93795 .01826 L
.97619 .01803 L
Mfstroke
1 0 .119 r
.02381 .01472 m
.02499 .01721 L
.02605 .01902 L
.02729 .02064 L
.02846 .02181 L
.03053 .02328 L
.0317 .02388 L
.03279 .02432 L
.03506 .02501 L
.03635 .0253 L
.03756 .02552 L
.04 .02586 L
.04136 .02601 L
.04262 .02612 L
.04384 .02621 L
.04514 .02628 L
.04748 .02639 L
.04891 .02644 L
.05026 .02647 L
.05147 .0265 L
.05278 .02651 L
.05395 .02653 L
.05523 .02653 L
.05587 .02654 L
.05657 .02654 L
.05781 .02654 L
.05906 .02653 L
.06024 .02652 L
.06129 .02651 L
.06244 .0265 L
.06505 .02647 L
.06749 .02643 L
.07306 .02631 L
.08433 .02601 L
.10458 .02538 L
.14327 .02409 L
.18441 .02282 L
.22403 .02173 L
.26214 .02082 L
.3027 .01999 L
.34175 .0193 L
.38324 .01867 L
.42323 .01816 L
.46169 .01775 L
.50261 .01737 L
.54201 .01706 L
.5799 .01681 L
.62024 .01658 L
.65906 .0164 L
.70034 .01623 L
Mistroke
.7401 .0161 L
.77835 .01599 L
.81905 .01589 L
.85823 .01581 L
.89986 .01574 L
.93998 .01568 L
.97619 .01563 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.02499 .01708 L
.02605 .01882 L
.02729 .0204 L
.02846 .02156 L
.03053 .02303 L
.0317 .02363 L
.03279 .02408 L
.03506 .02478 L
.03635 .02508 L
.03756 .0253 L
.04 .02565 L
.04136 .0258 L
.04262 .02591 L
.04384 .02601 L
.04514 .02609 L
.04748 .0262 L
.04891 .02625 L
.05026 .02628 L
.05147 .02631 L
.05278 .02633 L
.05395 .02634 L
.05523 .02635 L
.05587 .02636 L
.05657 .02636 L
.05781 .02636 L
.05906 .02636 L
.06024 .02635 L
.06129 .02634 L
.06244 .02633 L
.06505 .0263 L
.06749 .02627 L
.07306 .02616 L
.08433 .02588 L
.10458 .02527 L
.14327 .02404 L
.18441 .02281 L
.22403 .02175 L
.26214 .02086 L
.3027 .02004 L
.34175 .01935 L
.38324 .01872 L
.42323 .01821 L
.46169 .01778 L
.50261 .01739 L
.54201 .01707 L
.5799 .01681 L
.62024 .01656 L
.65906 .01637 L
.70034 .01619 L
Mistroke
.7401 .01604 L
.77835 .01592 L
.81905 .01581 L
.85823 .01572 L
.89986 .01563 L
.93998 .01557 L
.97619 .01551 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.02499 .01687 L
.02605 .0185 L
.02721 .01992 L
.02846 .02115 L
.02961 .02206 L
.03068 .02274 L
.03279 .02375 L
.03396 .02418 L
.03506 .02452 L
.03756 .02511 L
.04 .02552 L
.04262 .02583 L
.04516 .02605 L
.04793 .02622 L
.04919 .02628 L
.05054 .02634 L
.05297 .02641 L
.0542 .02644 L
.05553 .02647 L
.05679 .02648 L
.05794 .0265 L
.05898 .02651 L
.06013 .02651 L
.06133 .02652 L
.06244 .02652 L
.0631 .02652 L
.0638 .02651 L
.06506 .02651 L
.06576 .02651 L
.06641 .0265 L
.06791 .02649 L
.0704 .02647 L
.07308 .02643 L
.08278 .02626 L
.10458 .02573 L
.14572 .02457 L
.18534 .02347 L
.22345 .02249 L
.26401 .02157 L
.30306 .02077 L
.34456 .02003 L
.38454 .01941 L
.423 .01888 L
.46392 .0184 L
.50333 .01799 L
.54121 .01764 L
.58155 .01733 L
.62038 .01706 L
.66165 .01682 L
Mistroke
.70141 .01661 L
.73966 .01644 L
.78036 .01628 L
.81954 .01615 L
.86117 .01603 L
.90129 .01593 L
.9399 .01584 L
.97619 .01577 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.02499 .01695 L
.02605 .01862 L
.02721 .02007 L
.02846 .0213 L
.02961 .0222 L
.03068 .02287 L
.03279 .02385 L
.03396 .02426 L
.03506 .02458 L
.03636 .02489 L
.03756 .02512 L
.04 .0255 L
.04134 .02565 L
.04262 .02578 L
.045 .02595 L
.0463 .02603 L
.04753 .02609 L
.04868 .02614 L
.04993 .02618 L
.0521 .02624 L
.05335 .02626 L
.05472 .02628 L
.05541 .02628 L
.05615 .02629 L
.05685 .0263 L
.05749 .0263 L
.05871 .0263 L
.0594 .0263 L
.06003 .0263 L
.0612 .0263 L
.06244 .02629 L
.06371 .02628 L
.06504 .02627 L
.06742 .02624 L
.07277 .02616 L
.08247 .02595 L
.10458 .02535 L
.14269 .02422 L
.18325 .02306 L
.22229 .02206 L
.26379 .02111 L
.30377 .02032 L
.34224 .01965 L
.38316 .01904 L
.42256 .01853 L
.46045 .0181 L
.50079 .0177 L
.53961 .01737 L
.58089 .01707 L
Mistroke
.62065 .01682 L
.6589 .01662 L
.69959 .01643 L
.73878 .01627 L
.78041 .01612 L
.82053 .01601 L
.85913 .01591 L
.90019 .01582 L
.93973 .01574 L
.97619 .01568 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.02499 .01684 L
.02605 .01843 L
.02721 .01984 L
.02846 .02107 L
.02961 .02197 L
.03068 .02265 L
.03279 .02368 L
.03396 .02411 L
.03506 .02445 L
.03756 .02505 L
.04 .02546 L
.04262 .02578 L
.04516 .02601 L
.04793 .02618 L
.05054 .0263 L
.05179 .02635 L
.05297 .02638 L
.05413 .02641 L
.05538 .02643 L
.05642 .02645 L
.05756 .02647 L
.05879 .02648 L
.0601 .02649 L
.06131 .02649 L
.06244 .0265 L
.0631 .0265 L
.0638 .0265 L
.06506 .02649 L
.06576 .02649 L
.06641 .02649 L
.06791 .02648 L
.0704 .02646 L
.07308 .02643 L
.08278 .02626 L
.10458 .02575 L
.14572 .02462 L
.18534 .02355 L
.22345 .02259 L
.26401 .02167 L
.30306 .02089 L
.34456 .02015 L
.38454 .01953 L
.423 .019 L
.46392 .01852 L
.50333 .0181 L
.54121 .01776 L
.58155 .01744 L
.62038 .01717 L
.66165 .01692 L
Mistroke
.70141 .01671 L
.73966 .01653 L
.78036 .01637 L
.81954 .01624 L
.86117 .01611 L
.90129 .01601 L
.9399 .01592 L
.97619 .01585 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .01719 L
.02605 .01898 L
.02729 .0206 L
.02846 .02177 L
.03053 .02325 L
.0317 .02385 L
.03279 .0243 L
.03506 .025 L
.03635 .0253 L
.03756 .02553 L
.04 .02588 L
.04136 .02603 L
.04262 .02614 L
.04384 .02623 L
.04514 .02632 L
.04748 .02643 L
.04891 .02648 L
.05026 .02652 L
.05147 .02654 L
.05278 .02657 L
.05395 .02658 L
.05523 .02659 L
.05587 .02659 L
.05657 .0266 L
.05781 .0266 L
.05906 .02659 L
.06024 .02659 L
.06129 .02658 L
.06244 .02657 L
.06505 .02654 L
.06749 .0265 L
.07306 .0264 L
.08433 .02611 L
.10458 .02549 L
.14327 .02422 L
.18441 .02294 L
.22403 .02186 L
.26214 .02094 L
.3027 .02009 L
.34175 .0194 L
.38324 .01876 L
.42323 .01824 L
.46169 .01782 L
.50261 .01743 L
.54201 .01711 L
.5799 .01685 L
.62024 .01662 L
.65906 .01643 L
.70034 .01625 L
Mistroke
.7401 .01611 L
.77835 .016 L
.81905 .01589 L
.85823 .01581 L
.89986 .01573 L
.93998 .01567 L
.97619 .01562 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{551.75, 341},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008W0001EB000`400?l00000o`00003ooooooooo
ooooobWooooo001fooooo`Go00000oooool2o`0000Cooooo0_l0001Iooooo`?o00000oooool2o`00
00Cooooo0_l0001Gooooo`?o00001?ooool2o`0000Cooooo0_l0001Gooooo`?o00001?ooool2o`00
00Cooooo0_l0001Eooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool007Oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0005Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool0Doooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0001Eooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool007Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0005Kooooo1Ol00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000EOooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0001Eooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool007Wooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0E?ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000EOooool4o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Fooooo`?o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool007Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000Eoooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000EOooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000EOooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Eoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000?ooooo001fooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005Sooooo0_l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000E_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000EOooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
001Dooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool007Oooooo0ol00004ooooo`;o00001?ooool2o`0005[o
oooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l0001Hooooo`;o00001?ooool2o`0000Co
oooo0_l0001Gooooo`?o00001?ooool2o`0000Cooooo0_l0001Fooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo000Iooooo`03o`000?oooooooooo0?oooooo
ooooool=ooooo`006Oooool00ol0003oooooooooo`3ooooooooooooo3Oooool001Wooooo00?o0000
ooooooooool0ooooooooooooo`gooooo000Iooooo`03o`000?oooooooooo0?ooooooooooool=oooo
o`006Oooool00ol0003oooooooooo`3ooooooooooooo3Oooool001Wooooo00?o0000ooooooooool0
ooooooooooooo`gooooo000Iooooo`03o`000?oooooooooo0?ooooooooooool=ooooo`006Oooool0
0ol0003oooooooooo`3ooooooooooooo3Oooool000cooooo3Ol000000ooo003o0000o`00003oo`00
0<So0000:oooH@0<ooon00go0000000Iooooo`03ool00?oo00Kooooo01Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool05OoooolEooon02coo`0Z5?oo01P00ooo00coo`00ool0003Nool000gooooo000Iooooo`03ool0
??oo003ooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03ooon
0?oo02[oo`0Z02Woo`0ZJooo000[ool01T7oo`0`:Ooo04Q;ool090gooooo000Iooooo`04oi<0oooo
003oo`00ool0Lecooooo5_oo02XEool07R_oo`00:ooo00HEool0<2[oo`1c:ooo05//ool0B3ooo`0T
?ooo05@<ool0@Pgooooo000Iooooo`03ohOo0?oo02Coo`0000;oo`0600?oog<0ooooooooool0;_oo
oolEooon01Goo`0Z00?oo`3/ool00?oo0000:?oo000Fool01QGoo`0`5_oo07<Doomc02[og?l05_oo
05/[ool0B003on80oooo02Coo`0T02Woo`0T4ooo05Agool0?0gooooo000Iooooo`03o`000?oo03co
o`0T00?oo`0000?oo`06ool0Looo07<05ooooolFooon02_oo`0000?oo`1Qool0<?oo0300:?oo0300
0ooo0>3oog<0oomc000Xoomc01Wooooo4?oLo`0EoolZ01Goo`1K00?oBP3oool0B?oo04P04ooo04PF
on80oaKoo`0T5?oo05@Zool0?003ool0NOoo04;oo`1202Soo`12;Ooo07lOool0CPgooooo000Ioooo
o`06o`000?oo03coo`0Tool0@_oo0=Coo`0Z1ooo0004ool01PSoo`0<7Ooo000Fool01QKoo`0`5Ooo
L`1>ooooo`_og?l04?oo:P0Eool0FaKoo`185OoR0?lFool092[oo`0l5Ooo07TFool0@QCoo`1o5ooo
0;H00om40?ooo`1>ool0CP0Yool0CQ?oo`2;3?oo06d=ooooo`006Oooool01ol0003oo`0lool09?oo
04;oo`2Gool0i_me0?l00_ooool2ool0fP;oo`0`3?oo0004ool01QWoo`0`1oooL`1hoooooa3og?l0
1Ooo:P0Fool0FaGoo`185OoR0?l00olD0?ooo`0Tool0900Cool090Goo`1D4Ooo03`Dool0NAKoo`25
5Ooo04800onI0?oo0<Koool0]P0Dool0]QGoQ`3o5_oo04hCool0Rb_oo`1]3?oo09d=ooooo`006Ooo
ool02?l0003oT`3oool0??oo02Coo`12ool0Uooo0>KoM@3oWOooool@omco00Goh_l04?oo05/6ojD0
oa3oo`185OoR0?lFool090ooo`1D2ooo03`@ool0N@03ool0QOoo04;oo`1202Soo`1200?o0?m6ool0
]_oo0;H05?oo0;HEohL0oaGoo`1>5?oo08/Eool0K@03o`P0ool0A_ooo`2M01Goo`2M4_oo0;0=ool0
T@gooooo000Iooooo`09o`000?n7o`3oo`0lool09?oo04;oo`2Gool0e?oo0>KoM@3o097ooooo2ooL
o`000oooooooh_l0on;o0007on;o00_oo`1K00?o0<3oojD0oonU0?l02?nU0?l;ool0B13ohP3o00?o
oooooa@0oolD0?l00_lD0?l@ool091Goo`1D4?oo03`;ool0N@03ool0QOoo04;oo`1200koo`125Ooo
07l00ol0a_ooo`2fool0]P0Cool0]P?o0?l^0oooiP0@od@0o`03o`16oooo04koo`1>01;oo`1>:Ooo
06d2ool0/1Goo`2M4ooo0;0Eool0T@;oT`3o2ood0?l=ooooo`006Oooool02_l0003oQol0ool0??oo
02Coo`25ool0@_oo09Ooa03oool0i_me0?n8ooooo`Sog?l00_ooool:on;o0003o`30oooo05_oo`1K
00Koo`1K00?o0<3oojD0oonU0?l02?nU0?l;ool0B0_ohP3o00?ooooooa@0oolD0?l02?lD0?l:ool0
913oo`1D1OmS0?l00ol0og7o05ooool0?00=ool0?003o`1Ooon1o`3oo`2500?oo`252_oo07T00ooo
08Goo`12ool0@P09ool0@Pooo`1o0ol0odH4ohL0oa3oo`2f3Ol0obh3oooV00KoA03o5_oo04h3ool0
Ra3oo`1]5?nC0?l3ool0/1Goo`2M4_n/0?lFool0T@03om`0oood0?oom03o01Com03o2on=0?l=oooo
o`006Oooool02ol0003oQol0ool0??oo04koo`0Tool0@_oo09Ooo`3Dool0i_ooooooM@3o083ooooo
1ooLo`02ooooo`Ooh_l01Ol0`?l7ool0F`WoY@3o2_oo04P3ool0I`SohP3o00?ooooooa@0oolD0?l0
2OlD0?l:ool090Woo`1D00?oolh0of<0oomS0?l02?mS0?l00ol0og7o05ooo`1Oo`03o`1Oo`Ooo`0l
2Ooo08D6ool0NA3oo`122Ooo07l01?oooooo0?m6o`3oA_l0odH9ohL0o`_oo`2f3_l0obh00oooiP3o
om@0oi<0o`05oi<0oa3oo`1>3_oo08/;ool0K@oooiL000?ooid0ool0/?oo0;001Ooo0;0@ool0WA;o
[03o5Ooo0942om`0oaGom03o5Olbo`0<ool0_0gooooo000Iooooo`;o000000[oo`0lool0Iooo02Co
o`25ool0@_oo09Ooo`3Dool0i_ooooooM@3oN?ooool7omco00Cooooo0ooRo`07o`30o`Ooo`1K1OnU
0?l2o`3lo`Woo`181_oo06L5on80o`;ooooo2OlD0?l;ool090Soo`1D00?oolh0of<0oomS0?l02OmS
0?l9o`1Oo`Ooo`0l1Ooo08D2ool0N@ooo`121?nI0?l:ool0O`04ooooool0odKo0?m6o`3oAP[oQ`3o
2_oo0;H5o`3o;Q7oT`3o2ooo04h>ool0Ra3oo`1]1On=0?lBool0/0_oo`2M3on/0?l00ol/0?oog03o
om`0o`0@ool0TD7oo`2l3?nUo`0=ooooo`006Oooool03?l0003ooooooi<0oooo03coo`0Tool0QOoo
04;oo`2Yool0Uoooooooo`3VogD0og7ooooo1ooLo`05ooooo`;oh_l01Ol0`?l9ool0F`03ojD0ool0
o?oo0?co00Co0?co1ooo04P00ooR0?ooo`1Wool0I`05ool0I`03on80oooooooooooo00Cooooo1olD
0?l9ool090Woo`1D2omS0?l;o`1Oo`03oooooooo08Goo`0l00Koo`0l00?oo`25ool0NOoo07T02ooo
0488oiT0o`_oo`1o0ol0odH:ohL0o`_oo`2f3_nC0?l6ool0Z@;oo`2;2_oo04h4ool0R`GoS@3o4?oo
06dEool0/0Gooooo0_l0oj4;ool0W@Go[03o3OoL0?l;ool0TA3oo`2l0_od0?lYoonl01GoYOl000?o
ok`0o`3oj_l0onX02_l0onX=ooooo`006Oooool03Ol0003oooooo`3foooo03coo`1>ool09?oo08Go
o`12ool0Uooo0=Coooooool0i_me0?l0Joooool5omco00Oooooo00?o0<3oool0Fooo05/02Ooo05/0
0onU0?ooobX0o`3lo`06o`3lo`Ooo`1800?ohP3oool0Iooo06L01Ooo06L7ooooo`Ko503o2?oo02@7
ool0E003oo[o0?mS0?ooH`3o00SoH`3o00?oolh0o`1Oool0Gol02?l0Gol00oooT@3oo`25ool0Q@03
ool0Q@Ooo`0l2_oo0489oiT0o`[oo`1o0ol0odH;ohL0o`03o`36oooo0;Koo`2f00Ooo`2f2OnC0?l;
ool0Z@;oo`2;2ooo04h8ohd0o`_oo`1]4?oo0;0?ooooo`;o0?nQ2ooo09d=om`0oa3oo`2A1_oo0;`7
oo@0o`oook`05?oooolFojGo0003o`3oj_lb0?oo<P3o01Co<P3o2ooo0<P=ooooo`006Oooool03_l0
003oooooohOo0?oo03coo`1Wool09?oo08Goo`1Dool0@_oo09Ooo`3Dol@0oooo0>KoM@3oIOooool5
omco00Gooooo2?oo05/5ojD0o`03oolZ0?oo<03ooc0000Co0?co2?oo04P00ooR0?ooo`1Wool0I`05
ool0I`Kooooo1olD0?l7ool090Coo`1D0_ojo`0:of<0o`_o05oo00?o0?maool0QOoo08D01_oo08D7
ool0?0Koo`1200?oA?l0oom]0?nI0?l01_nI0?l;ool0O`?o0?m62_n70?l5o`36o`Ooo`2f1onC0?l;
ool0Z@Coo`2;2Ooo04h4ohd0o`03oooooomko`3oNol000?oNol02Ooo06d;ool0/1Gooooo0_l0oj4:
ool0W@Cog03o1?oo0;`@ool0T@;oo`2l4?od0?l5oonl01Cooooo0_nUo`0Zoc80o`03oooooooo0<So
o`3801?oo`382ooj0?l=ooooo`006Oooool03ol0003oooooohOo0?oo03coo`2`ool0B?oo02Coo`25
ool0@_oo09Ooo`3Dooooooo40?ooo`3VogD0o`1Oooooo`Gog?l00oooool2o`30o`Goo`1K1_nU0?l0
0ooo:P3ooc00ool`0002ool`00;o0?co1ooo04P2on80o`Ooo`1W1_ooool5oa@0o`;oo`1D1ooo02@0
0ooo05Con_l0of<0o`0:of<0o`[o05oo00?o0?maool0QOoo08D02?oo08D3ool0@PKoo`0l0_oo0484
ool0N@?oA?l000?oofd0oiT0oonI0?l00_nI0?l8ool0O`?o0?m62on70?l8o`36o`Goo`2f4?oo0:T7
ool0R`Soo`1>1oooool00omko`3o203oo`P0o`02o`P0o`Ooo`1]2Ooo0;0Eooooo`;o0?nQ2ooo09d7
ool0_0_oo`2A0_oo_0000olbo`3om03ooo@0o`0=oo@0o`03oonl0?oooooooooo017ooooo0_nUo`0E
oc80o`Cooooo4?l0onX7oooooa3oo`388?l0]?l=ooooo`006Oooool04?l0003oooooohOo0?oo03co
o`2`ool0C_oo02Coo`25ool0E?oo04;oo`2Gool0e?ooooooo`3Voooooome0?mHooooo`Kog?l000?o
ooooo`30ool0`?l00_l0`?l5ool0F`CoY@3o1ooo<007ool0B0CohP3o1Ooo06L6ooooo`03oa@0oooo
05Coo`1D00Coo`1D1ooo02@9of<0o`[o05oo0_oocP000ol0og7oo`25ool0Q@06ool0Q@[oo`121?oo
03`5ool0N@GoA?l000?oofd0oiT0oonI0?l01ooo07l3o`3oAPSoQ`3o0ooFo`03oooV00;o0<Ko4?oo
0:T2o`2Wo`CoA03o2_oo08/7ool0CPKooooo00?oNol0o`P0ool80?l01?l80?l7ool0K@Koo`2`4?oo
ool4oooh0003o`3oXOoo0;coo`2M00[oo`2M1?oo0;`00ooL0?oo[03ooj`0o`02oj`0o`Woo`2A0_oo
_005oc;o00Oom03o4oooool2ojGo013o<P3o3_ooool;o`3ojPcooooo2ooo0<P@o`2doa[oa?l01_l8
o`0=ooooo`006Oooool03?l0003oooooohOo0?nC0?ooo`0lool0C_oo02Coo`2Mool0QOoo04;oo`2Y
ool0U`;ooooo00?oo`3Voooooome0?l0D_ooool5omco00Ko0<3o1Ooo05/2ojD0o`03on;o0?oo<03o
oc0000Cooc0000?o;?l0ool0B?oo04P01?oo04P5on80o`Koo`1W0oooool8ool0E0Ooo`0T1omS0?l0
0ooo=P3o05ooo`1Oo`06o`1Oo`;ooooo0ooocP000ol0og7oo`25ool0Q@03ool0Q@[oo`121OoolP05
ool0?0;oo`1i00?oooooodCo0?m4o`001?m4o`000oooK@3oo`1oool0O`05ool0O`Co0?m61_n70?l4
omKo0003oooV0?oo0:Woo`2Y00Woo`2Y0ooo0;H00onC0?oo0:Ooo`2Wo`04o`2Wo`03oomD0?oo08_o
o`2;00Woo`2;0_n=0?l00ol0A_ooo`1>ool0CP05ool0CP;ooooo00?oodh0og_o0?mko`000_mko`06
o`P0o`Ooo`1]1_oo0;08ooooo`SoooP000?o0?nQool0_?oo0;`02_oo09d00ol/0?oo[03ooj`0o`07
oj`0o`?ook`01ooo09400ooo_03o<_l0oc;o0006oc;o00Oom03o3oooool2ojGo00_o<P3o3Oooool2
olCo00oo0?oZ1oo4o`06ooX0o`[oo`381_l0]?lColCo0003ooooooo:o`3ob_l000kob_l01_l8o`0;
ool0n0gooooo000Iooooo`0Bo`000?ooooooQol0oi<0oooo03coo`1iool0B?oo02Coo`25ool0E?oo
04;oo`2Gool0e?ooooooa03oool0i_ooooooM@3oBoooool4omco00Oo0<3o1_oo05/4on;o00?ooc00
1?l/o`04ool0B0KohP3o1Ooo06L2ooooo`Ooo`1D00?o503ooooooooo02@01Ooo02@7of<0o`03oon`
0?l0Gooo05oo00Go05oo1Oooool00ooocP3o0?maool0Q@0;ool0@P03oooooooolP3ooo8000Gooo80
0ooo07T4ool0?003oh7o0?oooooooooo00CoA?l000?o0?m6ool0Oooo07l01Ooo07l6oonY00GoQ`3o
2ooo0:T7ool0]P?oT`3o00?o0:Ooo`3o;_ooE0002Ooo08/6ohd0o`;o04Ko00?oooooool0C_oo04h0
0ooo04h00oooCP3oNol0og_o0004og_o00Ko203o1ooo06d6ool0/0Sooooo1ooon003ool0_0Soo`2M
0ol/0?l8oj`0o`Gook`01ooo0947oc;o00Wom03o2oooool2ojGo00_o<P3o0oooool6olCo017o0?oZ
1_ooool;ooX0o`_oo`3800?o0;Cool[o0?o:o`008Oo:o`000ol8o`3oo`3hool0n00Cool0n0_o02;o
3Oooool001Wooooo01?o0000oooooooooooo0?Koool0??oo0;3oo`1>ool09?oo08Goo`2;ool0@_n1
0?ooo`2Gool0e?ooooooa03oool0i_ooooooM@3o04Gooooo0_oLo`07o`30o`;ooooo1Ooo05/3ool`
00?oh_l01_l/o`05ool0B0CohP3o00?oBP3oool0Iooo06L00ooo06L7ool0E004oa@0oooooooooooo
ooooo`Goo`0T1_mS0?l00ooo/03o05ooo`1Oo`05o`1Oo`Kooooo2Ooo0482oom200Gooooo1OoolP06
ool0N@Coo`0l00CoPOl0oooooom4o`3oA?l00ol0odH5ool0O`;oV@3o1OooZ@0;ool0Z@;oonH00_l0
Yol7ool0]PCoT`3o0_l0obh7ool0R`03od@0oon=0?ooS@3o00GoS@3o0_l0A_l3ooooo`Goo`1>1Omk
o`06o`P0o`Ooo`1]1_oo0;08ooooo`CoooP00_oL0?l4ool0_0Ooo`2M1?l/0?l7oj`0o`Cook`02Ooo
0944oc;o00[om03o2Oooool2ojGo00_o<P3o2Oo4o`0;o`3ojPcooooo2ooj0?l00ol0]?ooo`38ool0
b008ool0b003o`2dooo:o`3ob_l001Kooooo00?om?l0ool0n?oo0?P05?oo0?P7o`0Ro`com?l03On/
o`0=ooooo`006Oooool03_l0003ooooooooooon7o`3oo`0lool0/?oo04koo`18ool09?oo08Goo`1D
ool0@_oo09Ooo`2Y0_ooool01?o40?ooo`3Voooooome0?loooooo`Oo0<3o0oooool6ool0F`Cooc00
1ol/o`02ooooo`Coo`181?oR0?l2odX0o`;oo`1W1ooo05@00olD0?ooooooooooo`02ooooo`Koo`0T
1?mS0?l00ooo/03o05ooo`1Oo`05o`1Oo`Kooooo1ooo0482ool0Q@Cood801Oooool5ooob00Goo`1i
0_ooool4ool0?003ooooool0odKo0?m600;o0?m61_oo07l2oiT0o`;oojT02?oo0:T2ooo200?oe_l0
1Ol0Yol5ool0]PKoT`3o1ooo08/00om40?ooS@3oohd0o`05ohd0o`;o04Ko1Oooool5ool0CP?oNol0
1_l80?l7ool0K@Koo`2`2?ooool00ooon03og03oom`0o`03om`0o`Coo`2l1ooo09d2ob`0o`;ooooo
1on/0?l00ooo_03oo`2Aool0T@08ool0T@Co<_l000?ooooooo@0oood0?l01_od0?l9ooooo`;oYOl0
2_lb0?l5olCo00Cooooo2ol0onX6ooooo`Kob_l000?oVOl0ooX0oooj0?l02?oj0?l00ol0]?ooo`38
ool0b009ool0b0kooooo1oodo`0?ool0n0;o2?l04?l08_lGojco00;oolP02ol0omh=ooooo`006Ooo
ool03ol0003ooooooooooon7o`3oo`0lool0_?oo07Woo`1>ool09?oo08Goo`2;ool0E?oo04;oo`2G
ool0e002ooooo`04ool0i_ooooooooooogD0ocWooooo1Ol0`?l5ooooo`Goo`1K00?oY@3oool`0?oo
<0000_oo<005obco0003on;o0?oo:P3oobX000;ooooo1?oo04P3on80o`;oBP3o1ooo05@3oa@0o`Co
oooo1Ooo02@5of<0o`Ko05oo1_ooool7ool0@PCoo`2500Co0?maoom20?oo@P3ood801Oooool5ooob
00Goo`1i0oooool01?n1o`3oo`0lool0??oo03`4o`3oAPGoo`1o0onI0?l7ool0Z@;oQ`3o0ooo`P00
0ooFo`3o0:Ooo`2Wo`05o`2Wo`Goo`2f1?nC0?l7ool0R`03od@0oon=0?ooS@3o00GoS@3o1?l0A_l4
ooooo`Koo`1>00?oNol0o`P0ool80?l01Ol80?l00oooU`3oo`1]ool0K@03ool0K@Koo`2`2?ooool0
0ooon03og03oom`0o`03om`0o`?oo`2l2?oo09d4ooooo`Oo[03o2?oo0947oc;o0003oooooood0?oo
m03o00Gom03o1_ooool2ojGo00_o<P3o2Oooool:o`3ojPgob_l02ooj0?l2ooooo`Woo`380ooooolB
ojco00_oo`3h4Ol08_lCoaCo01Ko0?oN1OlDo`06ool0U`gooooo000Iooooo`?o000000goQol0oi<0
oooo03coo`2`ool0C_oo04Soo`0Tool0QOod0?ooo`1Dool0@_oo09Ooo`3D00;ooooo00Coo`3Voooo
ooooooooM@3o<oooool5o`30o`;og?l00oooool5ool0F`03ojD0oooo<03ooc0000;ooc001Ol/o`03
on;o00;oobX000?oooooool0B?oo04P00_oo04P2on80o`Ooo`1D00?oo`1Woa@0oolD0?l00olD0?l0
0ooooooon_l0oo[o0005ool090GoH`3o1Ol0Gol5ooooo`Ooo`121Ooo08D2o`3oL@Cood800oooool6
ooob00Goo`1i0oooool2oh7o0006o`3oA_oo03coo`0lool0??l0odKoA?l01Ooo07l00onI0?ooo`2Y
ool0Z@05ool0Z@CoQ`3o0_oo`P07o`2Wo`03oooV0?l0a_ooo`2f00Coo`2f0_nC0?l7ool0R`;oA03o
1_n=0?l5o`16o`03oonS0?oooooooooo00;ooooo1Ooo04h7o`P0o`03ooooooooU`3oo`1]00Goo`1]
1Ooo0;07ooooo`03oooh0?oL0?oog03o00Gog03o00?oo`2lool0WOoo09d01Ooo09d3o`3oX@;ooooo
1on/0?l7ool0T@03oooooolbo`3o<_l000Go<_l000?ooooooo@0oood0?l01Ood0?l4olCo00;oYOl0
2Olb0?l:ooooo`03ol[o0?l0on[o0?oZ00Oo0?oZ1_o:o`07ooooo`[onP3o1_ooool7ool0b0co[?l0
1_odo`000ooob03oo`3hool0n009ool0n0Oo02;o0ol8o`0@oaCo01Go0?oN1_ooool:ooo/00_oo`2G
1_l0^_l=ooooo`006Oooool04?l0003ooooooooooon7o`3oT`3oool0??oo0;3oo`1>ool0B?oo02Co
o`25ool0Roo^0?ooo`1Dool0@_oo0:T2ooooo`04ol@0oooo0>KoooooogD0obkooooo1Ol0`?l4omco
00;ooooo00GoY@3oool0Fooo05_oo`1KojD0o`04ool`00Go;?l00_ooool3on;o0003oolZ0?oF0?oo
o`1800?oo`181_oo05@4ool0I`Co503o0oojo`05ool090GoH`3o1Ol0Gol3ooooo`Ooo`121ooo08D3
o`3oL@?ood800oooool5ooob0003oooooooo07Woo`1i00?oo`1i00Gooi40oooooooooooooooooh7o
0003o`3oAP?oo`0l00?oA?l0ool0Oooo07l00_oo07l6ool0Z@03oooooon70?ooQ`3o00?oQ`3o1ol0
Yol2omKo0003oooD0?oo0;Koo`2f00Coo`2f1ooo08/4od@0o`GoS@3o00?oooooo`16ool0A_l00ol0
A_l2oonS00?ooooo1Ooo04h5o`P0o`Cooooo1Ooo06d2oonM00Coo`2`1Oooool00ooon03og03oom`0
o`05om`0o`03ob`0oooo09goo`2M00Goo`2M1?l0oj48oj`0o`Ooo`2A00?ooooooc;o0?lbo`001Olb
o`08oo@0o`Coa?l00_nUo`07oc80o`Sooooo1Oo:o`07o`3ojP_ooooo2ooj0?l2o`2do`Kooooo00?o
[?l0ool0b?oo0<P01Ooo0<P2ojco00com?l00_oob00:ool0n0?o02;o1ol8o`05oaCo00Kooooo4?l0
omh@ooooo`_oon`02_oo09L6o`2jo`_oK`3o3Oooool001Wooooo017o0000ooooooooooooQol0o`3f
oooo03coo`2`ool0NOoo04koo`0Tool0WOoo08Gom03oool0Xooo05Coo`12ool0Z@02ooooo`04ol@0
oooo0>KoooooogD0obSooooo1Ol0`?l2ooooo`?og?l00_ooool2ojD0o`?oo`1K0_oo<006obco00?o
oooo00Cooah0on;o0?oRo`3oeP3o1Ooo04P2ool0E0?oBP3o00?o03[oool0Iooo06L00_oo06L4oa@0
o`;on_l01Ooo02@4of<0o`Go05oo00?oocH0oooooooo04801_oo0487ool0Q@03ooo>0?oooooo0?ma
00?o0?ma0ooo@P000ooooooooo80ooob0004ooob00;ooooo1?oo07T3oonA00;ooooo0_l0odH3ool0
Z@?oo`0l1?oo07l00ooo0:Woooooooooo`03oiT0o`GoQ`3o1Ol0Yol5omKo00Coo`2f1ooo08/5od@0
o`;ooooo1?n=0?l3ooooo`?o04Ko0_ooX`03ooooo`Goo`1>1Ol80?l3ooooo`Koo`1]0oooW@04ool0
/0?ooooo1ooL0?l00ol/0?ooo`2Mool0W@05ool0W@04ool0_?l0oj7o0?nQo`3oX@Oo[03o00?ook`0
ool0TOoo09401Ooo09400ooooooo<_l0oc;o0005oc;o00Oom03o1Oooool2ojGo00Oo<P3o1?ooool9
ol[o00Oo0?oZ2Oooool00onIo`3onP3oooX0o`06ooX0o`Ko0;Co1on/o`07ool0b0Gom?l01_oob003
oaCo00Woo`3h1_l08_l3o`So00_ooooo2ol0omh?oooooa7oK`3o2ooo09L@ofl0o`_o01co3Oooool0
01Wooooo01;o0000ooooooooooooQol0oonA0?oo03coo`2lool0/?oo04koo`18ool09?oo097oo`25
onh0oooo0:?oo`1Dool0@_oo0:T2ooooo`04ol@0oooo0>KoooooogD0ob;ooooo1Ol0`?l4ooooo`?o
g?l000?oooooojD0oonU0?l01?oo05/5obco00Kooooo0ooo05@4ool0B003on80ool0oaco0?co00?o
BP3o00?o03[oool0Iooo06L00_oo06L4oa@0o`03oooooooo02Coo`0T00?oo`0T1?mS0?l4o`1Oo`So
o`121ooo08D3ooo>0003ooooool0og7o0?ma00?o0?ma0ooo@P05ooob00Gooooo0ooo07T2ooooo`Wo
o`2Y0ooo03`2ool0O`Gooooo0onI0?l3ohL0o`?o0:Oo0oooiP04omKo00Coo`2f1Ooo08/2oi<0o`Go
A03o00?o0?l^ooooooooool01?n=0?l3ooooo`Co04Ko00?ooj<0ooooooooCP001Ooo04h5o`P0o`?o
oooo1Ooo06d01?ooU`3ooid0oonM0?ooW@05ool0/0Oog03o00?oooP0ob`0ool/0?l01Ooo09d3ool0
_003o`3oXOn/0?oo[03o00Go[03o00?ook`0ooooooooool01Ooo0942ooooo`Ko<_l01ood0?l6oooo
o`03ojGo0?lb0?oo<P3o00Go<P3o00?ooooool[o0?o:o`002?o:o`09o`3ojPWooooo0onIo`05ooX0
o`Oo0;Co1?n/o`05ooCo00Goo`381ooob007oaCo00Ooo`3h2?l08_l;ooooo`[o0?oN2_ooool@ofl0
o`;oon`01Ol0^_l:ool0U`cooooo3ol07?l01?l0od3ooh/0oon;0?ooR`07ool0iPgooooo000Ioooo
o`0Co`000?ooooooooooohOo0?ooT@3oT`3oool0??oo0;3oo`1>ool0B?oo02Coo`2Mool0QOoo08_o
kP3oool0Xooo04;oo`3Dool0Z@02ooooo`04ool0i_ooooooooooogD0oagooooo1?l0`?l5ooooo`?o
g?l01?nU0?l3ool0F`Co;?l01Oooool5ool0E0Coo`1800?ohP3oo`3o7?l0oa`01?m:0?l01?l0>_oo
o`1Wool0Iooo06L4oa@0o`Goo`0T0omS0?l3o`1Oo`Ooo`120_oo0:<6ool0Q@;ooooo1?oocP05o`3o
L@03oooooooo@P3ood8000Gooo801_ooool4ool0N@Goo`2Y00Co0?m6oh7o0?n1o`3oPOl00_ooK@03
ool0?003ool0Oooooooooooo00;ooooo0_l0Yol3oiT0o`04ohL0ool0Yoooom@0oooD00CoonH00ooF
o`03ool0]PKoo`2;1?nC0?l3od@0o`;o0?l^00?oooooohd0oon=0?l00on=0?l3ooooo`05oonS0?l0
A_oo04Koo`16ooooX`000_ooCP04ool0CPGo203o0oooool5ool0K@;ooiL00oooW@04ool0/0Gog03o
0_oon003ob`0o`Goo`2M0ooo0;`6oj`0o`04oonl0?ooooooooooooooo`Koo`2A0_ooool4oc;o00Oo
m03o1_ooool00onUo`3o<P3ooc80o`05oc80o`Sob_l02_l0onX;ooooo`CoVOl01_oj0?l5o`2do`Co
oooo1_odo`06ool0b0co5?l01ooo0?P6o`0Ro`Wooooo2ol0omh9ooooo`_oK`3o0oook009o`2jo`_o
o`2G2oooool;o`0Lo`03o`3o@?ooR`3ooh/000Gooh/02ooo0>H7o`0Fo`gooooo000Iooooo`0Go`00
0?oooooooooooooooon7o`3oT`3oool0??oo0;3oo`1iool0C_oo04Soo`0Tool0TOoo08Go/P3oonh0
oooo0:?oo`12ool0e?oo0:Wooooool@0oooo0>H00_ooool00ome0?ooooooooooo`0Fooooo`Co0<3o
1_ooool2omco00CoY@3o00Cooc00ool0Fooo05_oo`1K0_l/o`05ooooo`Goo`1D00?oeP3oool0B?oo
04P00_oo04P00ooR0?oo0?lLo`3o7004odX0o`03o`0joooo06Ooo`1W00;oo`1W0_lD0?l00ooooooo
o`0Tool09002ool090?oH`3o00?o05ooool0@_oo04801Ooo0482onh0o`?oo`2S1?oo08D3ooooo`Go
olh01?l0og42ooooo`;ood801?oolP06ooooo`03ool0ZOoo07Woo`1i00;oo`1i0_oo0:T3o`3oAP03
oonY0?ooT@3oPOl000;oPOl000?oofd0ool0Oooo03`00_oo03`00ooooooo0:Ooo`2Wo`03o`2Wo`04
ohL0oonI0?ooV@3ooiT0o`Coom@00oooiP000oooooooe_l0ool0]P02ool0]PGoo`2;00?ooooooomD
0?ooE0000onC0?l3od@0o`;o0?l^00?oooooohd0oon=0?l00_n=0?l4ooooo`03oonS0?l0A_oo04Ko
00;o04Ko00?oodh0ool0C_oo04h00ooo04h4o`P0o`?ooooo1Ooo06d2oonG00?ooid000?og03oool0
/?oo0;000_oo0;02om`0o`CoooP00ol/0?l5ool0W@Coo`2l1?n/0?l00ooo_03oooooooooo`02oooo
o`Goo`2A1?ooool3oc;o00Gom03o1_ooool00onUo`3o<P3ooc80o`05oc80o`Kob_l02Ol0onX<oooo
o`;o[?l01_nIo`05ooX0o`Co0;Co0_ooool4ooCo00Ko5?l01Ooo0<P3oaCo00Kooooo00?o2?l0ool0
n?oo0?P01_oo0?P2o`0Ro`_ooooo2Ol0omh4oooooa3oK`3o1oook007o`2jo`Woo`2G1Oooool00onC
o`3o01coo`0Lo`0>o`0Lo`03o`3o@?ooR`3ooh/000Ko01Ko2_oo0>H6o`0FoaWooooo000Iooooo`0H
o`000?oooooooooooooooon7o`3oT`3oool0??nI0?ooo`1iool0C_oo04Soo`38ool09?oo097oo`25
o`1Ooooo0:?oo`2Gool0@_oo05Coo`2Yooooooo40?ooo`3V0_ooool00ome0?ooooooooooo`0@oooo
o`Go0<3o1_ooool00ooo<03og?l0ojD0o`03ojD0o`03obco0?oo05_oo`1K00;oo`1K1Oooool5ool0
E0;oeP3o1?oo04P01?oR0?ooobX0o`3o7?l0oa`3odX0o`03o`0joooo06Ooo`1W00;oo`1W0_lD0?l5
ool09003of<0oooo04;oo`1200Goo`120oo^0?l4ool0X`Goo`251?ooool3ooo>00Go0?ma0oooool5
ooob00;ooooo1_oo0:T3ool0N@?o0?m600?oojT0ooooooooool00_ooT@03oh7o00;oo`1o0ooo03`4
o`2Wo`?oQ`3o0onI0?l3oooD0006ooooooooiP3oonH0oooV0?ooooooo`2f1_oo08/01?oooooooe@0
oomD0?ooE004oi<0o`03od@0oooooooo0?l^00;o0?l^00Coooooohd0oon=0?ooS@3o1?ooool2oonS
00?o04Ko00?oodh0ool0C_oo04h00_oo04h4o`P0o`?ooooo1Ooo06d3oonG00Cog03o1?oo0;04oooh
00Co;03o1Ooo09d4ool0_0Co[03o00Cook`0oooooooooooooooo1_oo0944ooooo`03olCo0?lbo`3o
<_l000Gom03o1?ooool00oooI`3oYOl0oc80o`05oc80o`Kob_l01ol0onX>ooooo`Co[?l01OnIo`06
ooX0o`;o0;Co1_odo`07oaCo00Koo`381oooool00ol8o`3oo`3hool0n005ool0n0;o02;o3?ooool5
o`3ogPooK`3o1oooool9ooo/00Oo0;[o1ooo09L?o`0Lo`?o0?m02ol05_l;ool0iQ7ooooo2ooo0?8=
ooooo`006Oooool05Ol0003oooooooooooooooooQol0oi<0oooo03coo`2lool0/?oo04koo`2fool0
B?oo02Coo`2Aool0QOnb0?ooP@3oool0Xooo09Ooo`12ool0E002ool0Z@05ol@0oooo0>Kooooooooo
oome0?l03Oooool4o`30o`Kooooo0_oo<005ojD0o`03obco0?oo05_oo`1K00;oo`1K1?ooool5ool0
E0;ooooo1Ooo04P2on;o0003oolZ0?l0oacoBP3o00?oBP3o00Co03[oool0Iooo06Ooo`1W0_lD0?l4
ool09003of<0oooo04;oo`1200?oo`1200?ook00onh0ooo^0?l00_o^0?l5ool0X`Coo`251_ooool3
ooo>00?o0?ma1?ooool4ooob00Ooo`2Y00?oooooo`3oA_l0odH00ooo07T00ol0odKoojT0ooooo`04
ooooo`;ooi400_n1o`02ool0O`?oo`0l0oooool4ohL0o`?oV@3o0_ooe0000oooooooonH0oooV0002
oooV00Goo`2;0ol0a_l4oomD00?oT`3o00?oA03oooooooooool00ol0obh4ohd0o`?ooooo00?oodh0
oonS0?ooX`000ol0A_l4ool0CP?o203o1Oooool3ool0K@03oooooooL0?oog03o00Gog03o1?oo0;03
oooh00Go;03o1?oo09d00oooooooo`2lool0_002ool0_0?o[03o0_oo_002ooooo`Goo`2A1Oooool0
0oo4o`3o<_l0oc;o0005oo@0o`Cooooo00?oofL0ojGo0?lb0?l01?lb0?l5ol[o00Oo0?oZ3_ooool6
ojco00?oVOl01ooj0?l00ol0]?oom?l0ooCo0004ooCo00Oo5?l01ooo0<P6ooooo`03o`So0?oo0?So
o`3h00Goo`3h0_l08_l<ooooo`03o`3og_m_0?ooK`3o00WoK`3o2oooool;ooo/00Wo0;[o1ooo09L6
o`0Lo`03oon;0?l0od3o0?m000Go0?m01_l05_l@ool0iPcooooo4?oo0?85ooooo`Koa03o3Oooool0
01Wooooo01Go0000ooooooooooooooooohOo0?l0m_ooo`0lool0_?oo0;3oo`1iool0C_oX0?ooo`18
ool09?oo097oo`25o`1Ooon10?ooo`2Go`30oooo04800ooo05@01Ooo0>KoooooooooooooooooM@3o
00Oooooo1Ol0`?l5ooooo`?ooc001?nU0?l3obco00?oo`1K2?oo05@3ooooo`Coo`1800?ohP3ooooo
oooRo`000_oRo`001_l0oacoBP3oodX0oom:0?oo03[ooa@0o`?oo`1W00?oooooool09?oo02@00_oo
02@5ool0@P03ooooooo^0?ookP3o00;okP3o1Ooo0:<00oooooooo`25ool0Q@02ool0Q@Oooooo0ooo
cP03o`3oL@?ooooo00?ooo80ool0ZOoo0:T01Ooo0:T3ooooo`Co0?m60ooo07T7ooooo`;ooi4000?o
0:Ooool0Oooo07l00_oo07l2ool0?0;ooooo1?n70?l01?ooe03oV@3ooiT0oonI0?l3ooooo`;oonH0
1Ooo08/00ooo0;Koooooo`36o`02o`36o`?ooe@000CoA03ooi<0oonC0?ooT`3o0oooool3o`3o;P?o
S@3o0oooool2oom>00;ooj<00ol0A_l3ool0CP?o203o1Oooool4ool0K@Cog03o0oooW@04ool0/0;o
ooP01Ol/0?l5ool0W@03o`3oXOoo0;coo`2l00;oo`2l0_n/0?l3oonl0003oooooooo097oo`2A00?o
o`2A1?ooool2olCo0003oc;o0?od0?oom03o00Com03o1?ooool2oomW0003ojGo0?lb0?oo<P3o00;o
<P3o0oo:o`07o`3ojPgooooo2?n/o`000oooooooVOl0ooX0o`06ooX0o`?o0;Co0oodo`000ooob03o
5?l0oaCo0005oaCo00Ooo`381oooool7ool0n0;o02;o2Oooool;ofl0o`gooooo2Oook00;o`2jo`;o
oooo1ooo09L2o`0Lo`03oon;0?l0od3o0?m000Ko0?m000?o01Koool0i_oo0>H03Ooo0>HAooooo`_o
o`3b2_ooool;ol@0oa?ooooo000Iooooo`0Eo`000?oooooooooooooooon7o`3ooi40oi<0oooo03co
o`2`ool0NOoo04koW`3oool0B?oo02Coo`2Aoo@0oooo08GoP@3oo`3Noooo09Oooc0000;oo`1200?o
0<3oool0E?oo05@00_l0`?l00ome0?oo0<3oo`30o`05o`30o`Cooooo1Ooo<004ojD0o`;o;?l02?oo
05@7ooooo`Coo`1800CohP3ooolN0?oooooon_l00_oRo`001?l0oacoBP3oodX0oom:0?l2oa@0o`?o
o`1W1?oo02@4ool0@P03ooooooo^0?ookP3o00;okP3o1Ooo0:<2ooooo`Coo`252?ooool3ooo>00?o
0?ma1ooo0:T5ooooo`Go0?m600CoojT0ool0NOoo07Woo`1i1oooool2o`2Wo`Coo`1o00CoA?l0ool0
??oo03coo`0l1?n70?l2oooD00?oV@3o0oooool5ool0R`;oo`2f00?oe_l0ooooool0a_l00_l0a_l2
oomD00;oA03o0onC0?l3ooooo`;o0?l^1?n=0?l00oooooooodh0oom>0002oom>00;ooj<00ol0A_l3
ool0CP03o`P0oooooooooooo00Gooooo0ooo06d3om`0o`;ooiL00_ooW@04ool0/003oooh0?l/0?oo
;03o00?o;03o00?oooooool0WOoo09d00_oo09d2ooooo`Coo`2l00Go[03ooonl0?oo_03ook`0oooo
o`05ool0T@Cooooo0_o4o`000olbo`3om03ooo@0o`03oo@0o`Gooooo0oooI`000onUo`3o<P3ooc80
o`02oc80o`;ob_l01Ol0onX=ooooo`Oo[?l00oooool7ooX0o`Go0;Co00Com?l0ooo80?oob03ooooo
1OlDo`02ooooo`Goo`381oooool7ool0n0;o02;o1Oooool;ofl0o`;o0?oN3oooool7ooo/00Wo0;[o
1_ooool7ool0U`03oon;0?l0od3o0?m000Co0?m000?o01Koool0i_oo0>H02Ooo0>HFooooo`[oo`3b
2_ooool;ol@0o`Oo0?l42_o:0?l=ooooo`006Oooool06_l0003oooooooooooooooooQol0oonA0?nC
0?ooo`0loiT0oooo0;3oo`1>ool0]_oj0?ooo`18ool09?oo097oo`25ojD0oon10?oo05ooool0Uooo
0=Cooc00ool0@_ooooooo`2Y0ooo05@00ome0?ooooooooooo`02ooooo`Kooc0000?oooooojD0oonU
0?l00_nU0?l00ol/o`3oo`1Dool0E003ool0E003ool0Fooooooooooo00Sooooo1?oo04P00ooF0?oo
oah0oo[o0003oo[o0003on;o0?m:0?ooBP3o00;oBP3o0_lD0?l2ool0I`Coo`0T0ooo04800ooooooo
kP3oonh0o`02onh0o`Goo`2S0oooool4ool0Q@Wooooo0_oocP07ool0Z@;ooo800_oo@P03ooooo`Go
0?m60oooZ@03ool0N@Cooooo1Ol0Yol3ool0O`03oooooom4o`3oA?l000;oo`0l0on70?l3oooD00?o
V@3o00?oooooool0Rooo08/00ooo08/3ool0]P;oe_l000Coooooo`36ool0a_oo0<Ko1Om40?l2oi<0
o`?ooooo0_l0obh3ohd0o`03ooooooooCP3oodh000;oodh000?ooooooonS0?mko`000ol0A_l3ool0
CPKooooo00?og03oool0KOoo06d00_oo06d01OoooooooiL0oonG0?ooU`3ooooo00;ooid00ooo0;05
ob`0o`;ooooo1?oo09d00oooooooo`2lool0_003ool0_004oj`0oooo_03ook`0oonl00Goo`2A1?oo
ool2olCo0003oc;o0?od0?oom03o00?om03o1Oooool3oomW0003ojGo0?lb0?oo<P3o00?o<P3o1_l0
onX;ooooo`Oo[?l01Oooool5ooX0o`;om?l01Ol0]?l00ooob03oooooooooo`06oaCo00;ooooo1Ooo
0<P5ooooo`Ooo`3h0_l08_l3ooooo`WoK`3o1_l0omh?ooooo`Ooon`01ol0^_l8ooooo`Ooo`2G00?o
oh/0o`3o@?l0od000_l05_l:ool0iQKooooo2ooo0?89o`3o10_oa03o0_l0o`@00ooooooobP3oolX0
o`0=olX0o`?o0=ko5?ooool001Wooooo01;o0000ooooooooooooooooohOo0?ooT@3oT`3oool0??nI
0?ooo`2`ool0NOoo04koj03oool0B?oo05_oo`0Too@0oooo08D2ojD0o`04ool0Uooo0:?oo`2Soooo
o`;oo`120_oo0:T00ooo<03oo`1Dool0E00?ool0E0;oo`1K2oooool3ool0B003omH0ooojo`3on_l0
00?on_l000?oobX0on;o0?m:0?l00_m:0?l2oa@0o`?oo`120ooo02@00ooo04;oH`3oof<0o`04onh0
o`Goo`2S0oooool5ool0Q@Sooooo1ooo0:T00ol0og7oooooooob0003ooob00;ood8000?oooooo`3o
A_l0odH00ol0odH4oonY0004oooooooo07Woo`1iool0N@;ooooo1Ol0Yol00oooK@3oo`1oool0O`02
ool0O`03oooooom4o`3oA?l000?oo`0l00GoQ`3ooooD0?ooe03oom@0ooo20003oiT0o`Coo`2;00?o
onH0oooooooo0;H00_oo0;H2omKo0003ooooool0a_oo0<Ko00CoA03o0_ooool3oi<0o`;ooooo0_l0
obh3ohd0o`Coodh00_ooool3og_o0003o`16ool80?ooo`1>00;oo`1>0oooool4om`0o`?oo`1]00?o
oooooonG0?ooU`000_ooU`000ooooooooid0oonM0003ool0/0;o;03o0_ooh002ooooo`Coo`2M00?o
ooooool0_?oo0;`00_oo0;`01?n/0?oo0?nQoonl0?oo_005ool0T@Cooooo0_o4o`000olbo`3om03o
oo@0o`03oo@0o`Gooooo0oooI`02ojGo00Co<P3o1Ol0onX;ooooo`Ko[?l01_ooool00onIo`3onP3o
ooX0o`03ooX0o`;om?l01Ol0]?l3ooooo`Go5?l01?ooool4ool0b0?ooooo00?o2?l0ool0n?oo0?P0
1?oo0?P2o`0Ro`?ooooo1om_0?l2ooooo`Ko0?oN3oooool7ooo/00Oo0;[o1_ooool00ol07?ooo`2G
ool0U`06ool0U`Go01Ko1ooo0>H00ooooooo0?l4o`3o100Eo`3o10Soo`3b1_l0o`@6ooooo`Soa03o
0oooool;olX0o`Oo0=ko1Oooool=o`80o`gooooo000Iooooo`?o00000_ooool04on7o`3oT`3oool0
??oo0;coo`2`ool0NOoo04koW`3oool0b?oo04Soo`0Tool0Fooo08_oo`25oh40ool0Yoooo`2Gonh0
oooo0:<00_nU0?l3ool0@P03ool0ZOnU0?ooY@3o00?oY@3o1_l/o`04ool0F`[ooooo1?oo04P01?oF
0?oon_l0oo[o0?oo7P02ooooo`;oobX000?oBP3oool0@_oo04801?oo0484ool09004of<0ooo^0?oo
kP3oonh0o`Koo`2S1?ooool4ool0Q@Oooooo1_oo0:T2ooo>00?o0?ma00Coooooooob0?oolP3ooo80
0_oo@P05o`3oAPCoojT00oooool3ool0N@Go0:Oo00?ooooooom]0?ooK@000ooo07l2oh7o00;oA?l0
0ooo03`3oooD00?ool801Ooo08/2oooV0004oooooooo0;Koo`2fool0]P;oe_l000?oooooo`36oom4
0?l00om40?l01?ooE03oooooooooooooool2oi<0o`;ooooo0_l0obh3ohd0o`?oodh000?oooooog_o
0?mko`000omko`000ol0A_oo203oool0CP02ool0CP03oooooooL0?oog03o00?og03o1?oo06d01Ooo
oooooiL0oonG0?ooU`3ooooo00?o;03o0ooo0;001?oon03oon00ooooooooool5ool0W@03oooooooo
0;coo`2l00;oo`2l00Co[03oo`3oXOl0oj7ook`01?oo0944ooooo`;oa?l000?o<_l0oo@0oood0?l0
0ood0?l5ooooo`?oofL00onUo`04oc80o`Co0?oZ2oooool5ojco00Oooooo00?oVOl0ooX0oooj0?l0
0ooj0?l3ooCo00Co0;Co0oooool5oaCo00Gooooo1?oo0<P2ooooo`03o`So0?oo0?Soo`3h00?oo`3h
00Co02;ooooooooooooooooo1om_0?l4ooooo`Go0?oN3_ooool7ooo/0003ooooool0^_oo0;[o00Co
0;[o0_ooool5o`0Lo`Ooo`2G1_l05_l7ool0iPSo0?l44?ooool7ool0lPgooooo0_o40?l@olX0o`;o
oooo5Ol20?lJooooo`006Oooool00ol0003oooooooooo`02ooooo`0<ohOo0?l0m_ooo`0lool0_?oo
0;3oK`3oool0C_oo06Ooj03oool0b?oo0?;oo`0T0_oo05/01_oo08GoP@3oool0Uoooooooo`3Dool0
X`;oY@3o00?oooooool0i_oo04800_oo04800ome0?ooooooomco0006ool0F`_ooooo0ooo04P2omH0
o`?ooah00_ooool6ool0@P;o03[o1?oo02@00oo^0?ooo`2Sool0X`05ool0X`;ook001?ooool4ool0
Q@Kooooo1Ooo0:T2ooooo`?oolh00ol0og44ooob0003oom20?l0odKo0?m600;o0?m600?ooooooonY
0?ooZ@000_ooZ@04ooooo`?oo`1i0ol0Yol3ooooo`;oofd00ooo07l3oh7o0004odCo0?n70?ooo`0l
ool0?0;oom@000?oooooooo20?oo`P001?oo08/01OooooooonH0oooV0?ooiP3ooooo00?oo`2f0_oF
o`000oooooooA03ood@0o`02od@0o`;ooe@00oooool3oi<0o`04ooooool0obko0?l^o`3o;P;oS@3o
0_ooCP02ooooo`?oNol00_ooX`02o`P0o`?oo`1>1?oL0?l2ooooo`?oo`1]0_ooool2oonG00Go;03o
0ooo0;000ooon03oooooool0W@04ool0W@?ooooo0ooo0;`01?n/0?oo0?nQo`3oXOl0oj44ool0T@Co
oooo0_o4o`05oo@0o`Kooooo0_ooI`03ojGo00Go<P3o0ol0onX;ooooo`Go[?l01_ooool2oiWo00Go
nP3o0oodo`000ooob03o0;Coo`2do`02o`2do`;ooooo1OlDo`05ooooo`Goo`3800?o2?l0ool0n?oo
0?P01?oo0?P00ol08_ooooooofl0o`06ofl0o`Kooooo1Ol0omh<ooooo`Ooon`00oooool3o`2jo`So
01co1ooo09L4o`0Fo`Woo`3V1?l0o`@Dooooo`Ooo`3b2?ooool>olX0o`;ooooo00?oJOl0o`80ool2
0?l03Ol20?l00ol0g_ooJOl0ofWo000GofWo00;o0?l@1_oo0=@=ooooo`006Oooool00ol0003ooooo
ooooo`02ooooo`0>ohOo0?ooT@3oT`3oool0??l0ROooo`2`ool0NOoo04koj03oool0b?oo0?;oo`0T
ool0B?oo08/3ool0F`04ool0Uoooooooo`3Dool0X`;on_l000Go08ooool0i_ooooooo`1Kool0@P02
ool0F`_ooooo0_ojo`04ool0B0;oeP3o00?ooooooolN0?oo7P001Ooo04800om:0?oo503oo`1Oo`02
o`0jo`?oo`0T00?oo`1Wool0Xooo0:<00_oo0:<2ooooo`04oolf0?oo/03ook00oon`00?ooooo1?oo
08D5ooooo`Goo`2Y1?ooool3ooo>0003ooooool0og7o0?ma00?ooo8000?oooooo`3oA_l0odH00_l0
odH00oooooooojT0oonY0002oonY00?ooooo0_l0Yol3ool0N@03o`2Woooooooooooo00?ooooo00?o
ofd0ool0Oooo07l00_oo07l01?ooooooPOl0oh7o0?m4o`02ohL0o`;oo`0l0_ooool00ooo`P3oo`2;
ool0R`02ool0R`03oiT0ooooooooonH000;oonH000Coooooool0]_oo0;Koo`2f0_oFo`001?oooooo
A03ood@0oom40?l3oomD00Cooooo0_nC0?l01Ooooooo0?l^o`3o;_l0obkoodh000;oS@3o00?oodh0
ooooooooool00omko`02oonS00;o203o0ooo04h2om`0o`Cooooo0ooo06d2ooooo`Go;03o0_ooh003
ool0/003oooh0?oo09goo`2M00;oo`2M0oooool2oj`0o`?oo`2l00?oooooo`3oXOoo09401?oo0945
ooooo`Gom03o00?o<_l0ooooooooool00oooool2oomW00CoYOl01?lb0?l3o`3ojP_ooooo1On/o`06
ooooo`?oVOl01?oj0?l3ooCo0003ooo80?l0]?oo0;Co00?o0;Co00?ooooooaCo0?lDo`000olDo`06
ooooo`Coo`3800?o2?l0ool0n?oo0?P00ooo0?P2o`0Ro`03oooooom_0?ooK`3o00?oK`3o2?ooool5
o`3ogP_ooooo1_ook002ooooo`_o01co00?oTol0ool0Uooo09L01Ooo09L;ool0iQ3ooooo2OmYo`08
ool0lPSoJOl01oo:0?l5ol@0o`03ofWo0?l20?oo0P3o00Wo0P3o2Ol0g_lEooooo`?o0?l@2_oo0=@6
och0o`gooooo000Iooooo`03o`000?oooooooooo00;ooooo013oQol0oonA0?nC0?ooo`0loiT0oooo
0;3oN`3oool0C_oo06OonP3oool0b?oo09goo`0Too@0oooo08_o0?of2_oo05/2oo[o01Soo`120_m:
0?l00olD0?oo05ooo`1Oo`02ool0X`?oo`0T00?oo`1Wonh0ooooool01?ooool01Ooo=P3ook00oon`
0?oo/03ooooo00Goo`251?ooool5ool0Z@Kooooo0ooocP001Ooooooo0?mao`3oLOl0og7ooo8000Go
0?m600?ooooooonY0?ooZ@000_ooZ@02ooooo`Co0:Oo0ooo07T6ooooo`04oom]0?oo07ooo`1oool0
O`?ooooo0_n1o`000om4o`3oQ`3oohL0o`02ool0?003oooooooo08_oo`2;00;oo`2;0_nI0?l01Ooo
ooooonH0oooV0?ooiP3ooooo00?oo`2f00?oooooomKo0?oFo`000om40?l3oomD00Cooooo0onC0?l0
1?oooooo0?l^o`3o;_ooCP03ohd0o`;ooooo0omko`02oonS00;og03o0ooo04h6ooooo`?oo`1]00?o
ooooob`0ool/0?l00_l/0?l01?ooooooon00oooP0?ooh002ool0/0Goo`2M0oooool3oj`0o`?oo`2l
00?oooooool0TOoo09400_oo0946ooooo`Com03o0_lbo`05ooooo`03oomW0?nUo`3oYOl000?oYOl0
1?lb0?l2o`3ojP_ooooo1On/o`05ooooo`KoVOl00ooj0?l01?odo`3oolP0ooo80?oob004o`2do`03
oooooolDo`3o5?l000?o5?l01oooool4ool0b0Goo`3h0_l08_l00oooooooK`3oofl0o`03ofl0o`So
oooo1Ol0omh9ooooo`Koon`02Ol07?l3o`2jo`;oTol01ooo09L7ool0iP;o0?m01?oooolEofWo0003
oooooooo0?;oo`3b00Koo`3b2?ooool00oo40?oobP3oolX0o`05olX0o`?oa03o2_l20?l7o`3Noaco
?P3o2Ooo0=@5och0oaSooooo000Iooooo`03o`000?oooooooooo00;ooooo00goQol0oonA0?nC0?oo
o`0lool0_?oo0;3oN`3oool0C_oo06Ooj03oool0b?oo0?;oo`2A00;oo`0T00Woo`18oh40oooo08Go
o`2Goooooooo0=Coooooo`1Oooo^0?l00ooo0:<00ooo0>Koooooool0Z@02ool0Z@Cooooo1?oo04P3
omH0o`Co05oo1?m:0?l00olD0?ooo`2Sool0X`02ool0X`?oo`0T00?oo`1Wo`3looooool00oooool2
oolf00;ook001Ooo08D00oooooooo`2Yool0Z@06ool0Z@Sooooo0ooocP001?oooooo0?mao`3oLOl0
og44o`3oAP;ood801?ooZ@06o`2Wo`04oooooooo07Woo`1iool0N@Kooooo00Coofd0ool0Oooo07oo
o`1o1?ooool2oh7o00?oQ`3o00?oooooool0??oo08/00_oo08/01?ooooooV@3ooiT0ooooool3oooV
0005oooooooo0;Koo`2fool0]_ooool00_oFo`03od@0o`?ooe@01Oooool2oi<0o`05ooooool0obko
0?l^o`3o;_ooCP000_n=0?l2ooooo`?oNol01?oL0?l3ool0CPKooooo0ooo06d4ob`0o`03oonG0?oo
h03oon0000;oon000_oo0;03ool0W@Cooooo1?n/0?l00oooooooo`2lool0_004ool0T@Gooooo1Ood
0?l3oc;o00Cooooo00?oofL0ojGo0?nUo`000_nUo`02o`3ojP?o<P3o00?o0?oZooooooooool02_oo
ool4ojco00Gooooo1OnIo`02ooCo00ConP3o0ooob0001?oooooo0;Coo`2dool0]?l5oaCo00Wooooo
0ooo0<P4ool0n0;o02;o00?oooooofl0oom_0?l00om_0?l9ooooo`Co0?oN1oooool6ooo/00Oo01co
00?oooooo`2jool0^_l01?l0^_l7ool0U`Koo`3V0_l0od0<ofWo00oooooo1ooo0?84ooooo`?o0P3o
00?oa03oolX0ooo:0?l01oo:0?l3o`80o`Sooooo4?ln0?lBooooo`?o0?l@1ooo0=@Vooooo`006Ooo
ool00ol0003oooooooooo`02ooooo`0@ohOo0?ooT@3oT`3oool0??oo0;coo`2`ofl0oooo07Woo`1>
ool0Iooo0<Soo`3bool0WOoo097om03oool090;oo`1800Coo`25ool0UooR0?ooo`3D0ooR0?l2onh0
o`Coo`2S00?ohP3oool0B?oo04P00_oo04P2ool0Z@;oeP3o0ol0Gol2odX0o`Ooo`2S00CokP3oool0
9?oo02Coo`0T0_oo06L01?l0o?ooooooooooooooool2oolf00Goo`251_oo0:T>ooooo`;oolh000Co
ooooo`3oLOl0og7o0?ma0ol0odH2oom200?oojT01Ol0Yol5ooooo`;oo`1i1_ooool01?ooK@3oo`1o
ool0Oooo07l3ooooo`;oom@00_n1o`001?n70?ooo`2;ool0Rooo08/2ool0?003ooo20?oooooooooo
00;oV@3o0oooiP001?ooooooo`2fool0]_oo0;H2ooooo`05omKo0?m40?ooA03ood@0ool0a_l00_oo
E006ooooo`;oT`3o0ol0obh01OooCP3oooooohd0oon=0?oooooo00;oNol01?oL0?l01?l80?ooo`1>
ool0C_oo04h6ooooo`?oo`1]0_l/0?l00oooooooon00oooP0003oooP0003oooooooo0;3oo`2`00?o
o`2M0_ooool5oj`0o`;ooooo0_oo0;`3ool0T@03o`3oXOoooooooooo00;ooooo1?od0?l01?o4o`3o
<_l0oc;o0?lbo`03ooooo`?oofL00_nUo`04o`3ojP?o<P3o3Oooool3ojco00Cooooo1OnIo`03ooCo
00ConP3o0_oob003ooooo`?o0;Co0olDo`0:ooooo`Coo`380_oo0?P2o`0Ro`KoK`3o2Oooool5o`3o
gPGooooo1Oook007o`0Lo`?ooooo1Ol0^_l6ool0U`Koo`3V0_l0od03ofWo01Sooooo1ooo0?84o`80
o`_obP3o2Oooool;och0oa_ooooo0ol0oa07ool0e2gooooo000Iooooo`03o`000?oooooooooo00;o
oooo01;oQol0ooooool0m_ooo`0lool0_?l0ROooo`2`og/0oooo04koo`1oool0Iooo0<Soo`3bool0
TOod0?ooeP3oool09?n10?l>ool0B0goo`2S1Ooo0:T3ool090;oo`1W1?oo0:T5ool0Q@03ool0ZOoo
oooooooo01?ooooo0ooocP000ooolP3o0?mao`3oL@02o`3oAP;ooooo0_ooZ@05o`2Wo`Oooooo0ooo
07T6ooooo`?oo`1o0oooool2oooD00;oPOl01?oo08/00ooo`P3oo`0lool0?003ooooo`;oV@3o0_oo
iP001?ooooooo`2fool0]_oo0;H3ooooo`?oA03o00?o0<KooomD0?ooE0001oooool2oi<0o`;o0?l^
00?oodh0oooooon=0?l00_n=0?l00omko`3og03oom`0o`02om`0o`03oonS0?l80?ooo`1>00;oo`1>
1_ooool3ool0K@03ob`0ooooooooon0000?oon0000GooiL0ooooooooooooooooool0/003ool0W@;o
oooo0on/0?l5ooooo`Coo`2A00?o0?nQoonl0?ooool00_ooool3oo@0o`;oa?l00olbo`02ooooo`?o
ofL01_l0onX01?o:o`3o<P3ooc80oolb0?l<ooooo`Co[?l00oooool4oiWo00Gom?l00ooj0?l2ooo8
00?ooooo1?l0]?l2oaCo00[ooooo1?oo0<P2ool0n003o`0Room_0?ooK`3o00?oK`3o2oooool4o`3o
gPGooooo0_ook008o`0Lo`;ooooo0ol0o`@5o`2jo`Goo`2G1Ooo0>H2o`3o@1_ooooo1ooo0?82o`80
o`WobP3o0oo40?l00ooooooo?P3ooch0o`0>och0o`Co0=ko6oooool3o`3o40Ooo`3D=?ooool001Wo
oooo00?o0000ooooooooool00_ooool04On7o`3oooooo`3foonC0?ooo`0loiT0oooo0;3oN`3oool0
C_oo06goo`1Wool0b?oo0?;oo`2Mool0TOod0?ooo`2;00;oo`0T00?oeP3oool0Uooo08D00_oo08D3
of<0o`?oeP3o00?oo`3VomH0oome0?l02?mS0?l2ohgo00;oobX000?o0?lLool09?oo02@00_oo02@2
ool0I`;o0?co00?oocH0ool0QOoo08D00_oo08D2oon`01Kooooo0_oocP000ooolP3o0?m6o`3oL@02
o`3oL@?ooooo00?oojT0o`2Wool0Yol00_l0Yol:ooooo`;oo`1i1_ooool3ool0O`?ooooo0oooe004
ool0R`03odCo0?oo`P3ool8000;oo`0l1?ooool00onI0?ooonH0oooV0003ool0]P?ooooo0om40?l2
o`36o`03oomD0?oooooooooo00Kooooo00?oodh0oi<0ool0obh00oooool00on=0?oog03oom`0o`03
om`0o`;ooooo0_l80?l2ool0CP03o`16oooooooooooo00;ooooo00Go;03oool0KOoo06goo`1]oooo
o`04oooP00?ooiL00_ooool01?oo0;3oo`2Mool0WOoo09d2ooooo`?o[03o1?ooool4ool0T@;o0?nQ
00?ook`0ooooooooool01?od0?l2olCo00?o<_l000?ooooooomW0?ooI`001Ol0onX4ol[o00?o<P3o
2oooool4ojco00;ooooo1OnIo`001Ooooooom?l0ooCo0?odo`3ooooo00ConP3o00?oolP0oooooooo
ool00_ooool3o`2do`?o5?l02_ooool3ool0b0;oo`3h1Om_0?l<ooooo`Co0?oN1?ooool7o`0Lo`;o
oooo1_l0o`@5ool0iPGoo`2G00?oo`3Vo`0Fool05_l00ol0od0Jooooo`Ooo`3b0_l20?l7olX0o`Go
a03o2?ln0?l5ooooo`So0=ko6oooool3o`3o40Ooo`3D>oooool001Wooooo00?o0000ooooooooool0
0oooool04_n7o`3ooi40oi<0oooo03coV@3oool0/?m_0?ooQ`3oool0C_oo07ooo`1Wool0b?oo0?;o
o`2Aoo@0oonb0?ooo`2;odX0o`;oo`0T00Coo`2GomH0oooo0=Coo`250_oF0?l01ooooooo08oool@0
oomS0?ooo`3Vof<0oome0?l00_m:0?l4ohgo0003oolZ0?oo02Coo`0T00?oo`0T00Coh_l0ool0Iooo
06Ooo`1W0_l0o?l3ool0Q@;ook005oooool2ooo>00;o0?m60ol0og42ooooo`Go0:Oo2oooool3ool0
N@Kooooo0_oo07l3ooooo`;oom@01?oo08/00on70?ooA?l0ooo20002ooo200;oo`0l1?ooool2oiT0
o`03oooooooo0;Koo`2f00?ooooo0om40?l2o`36o`03oomD0?oooooooooo00Gooooo0oooCP02oi<0
o`;ooooo1?oL0?l00omko`3oooooooooo`02ooooo`04o`P0oooo04koo`1>ool0CP?ooooo0_l/0?l3
ool0K@04ooooooooh03oon00oooP00;ooooo0_ooU`03ooooo`?oo`2M0_ooool3oj`0o`Cooooo0ooo
09400ooo0;co0?nQo`3oX@02oonl0005oooooood0?oom03ooo@0ooooool00_o4o`03oc;o0003oomW
0?l0on[o0?oZ00?o0?oZ00?oYOl0ol[o0?o:o`000_o:o`001?oooooo<P3ooc80oolb0?l;ooooo`?o
[?l00_ooool4oiWo00;ooooo1?odo`001OoooooonP3oooX0oooj0?ooolP000Gooooo0ol0]?l2oaCo
00[ooooo00Coo`3hool0b?oo0<Soo`381Om_0?l=ooooo`Co0?oN00?oooooo`0Lool07?l01Ol07?l0
1?ook03oooooooooooooool3o`3o10Soo`3V1Ooo09L3o`0Fo`?o0?m06_ooool5ool0lP;o0P3o1oo:
0?l4ol@0o`03och0oooooooooooo00_ooooo1ol0g_lLooooo`?o0?l@1ooo0=@_ooooo`Koj03o3Ooo
ool001Wooooo00?o0000ooooooooool00oooool05?n7o`3ooi40oi<0oooo03coo`2lo`29oooo0;3o
N`3oool0C_oo07ooj03oool0Iooo0?;oo`2Mool0TOod0?oo/P3oool0Ron10?ooBP3o0ooo02@01_oo
0=Coo`25ool0QOoo08GoBP3ool@0o`;oBP3o00?oo`3Vohgo0?me0?l01_oo02@2o`0jo`;oh_l00_oo
06L5ool0Q@;ook006?ooool3o`3oAP?o0?ma00?oooooo`2Wool0Yol00_l0Yol2oom200_ooooo0ooo
07T6ooooo`?oo`1o0_ooool00oooe03oo`2;ool0R`02ool0R`?oQ`3o00CoA?l0ooo20?oo`P3ooi40
0_oo03`4ooooo`;oV@3o00?oooooool0]_oo0;H00_ooool3od@0o`;o0<Ko00?ooe@0ooooooooool0
1Oooool3oom>0003oooooonC0?ooT`3o00Cog03o00?oS@3oog_o0?ooool00oooool01Ol80?ooo`1>
ool0C_oo04ko04Ko00Co;03o0ooo06d01?ooooooon00oooP0?ooh002ooooo`?ooiL00_ooool3ool0
W@03oooh0?oooooo[03o00;o[03o1?ooool3ool0T@03ool0_?l0oj7o0?nQ00;ook`01?od0?l00ooo
ooooa?l0olCo0002oc;o00Go0?oZ0onUo`03ol[o00;ooooo0olb0?l:ooooo`Co[?l000?ooooooiWo
0?nIo`000_nIo`03ooooo`?om?l000?oooooooX0oooj0?l00_oj0?l00ooob03oooooooooo`02oooo
o`Co0;Co00?o5?l0ooooooooool01oooool2o`So0004ool0n?oo0<Soo`38ool0b0?oK`3o0_l08_l<
ooooo`;o0?oN1ol07?l4ooo/00;ooooo00?o0?l4ool0i_oo0>H01Ooo0>H3o`2jo`Goo`2G0ol05_l3
o`3o@1[ooooo1Ooo0?87olX0o`Coa03o00?o?P3oooooooooool02oooool7o`3Noacooooo0ol0oa07
ool0e2_ooooo2ooX0?l6og/0o`gooooo000Iooooo`03o`000?oooooooooo00?ooooo01OoQol0oonA
0?nC0?ooo`0lool0_?l0ROooo`2`og/0ooo:0?ooo`1>ool0]_oo06Ooo`3bokP0oooo097om03ook80
oooL0?ooo`2;oh40ool0g_ooo`2Gohgo000;ool090Ooo`250ooo06L2ool0Q@04o`3loooo/03ook00
oon`01Sooooo0ol0odH00ooolP3o0?mao`3oL@04o`2Wo`;ooooo0_oo@P0;ooooo`;oo`1i1oooool2
ool0O`03oom]0?oo08_oo`2;00?oo`2;0_ooool2ohL0o`;oA?l000Gool80ooooooooT@3ooi40ool0
?004ooooo`;oV@3o0ooo0;H01?ooooooA03ood@0oom40?l3o`36o`Kooooo1?ooCP02ooooo`Cog03o
00?oNol0ohd0oon=0?l01?ooool01?l80?ooo`1>ool0C_oo04h4ob`0o`;ooooo0_oo06d01?oooooo
on00oooP0?ooh003ooooo`;ooiL00_ooool3ool0W@03ool0/?oon03o[03o00;o[03o1?ooool3ool0
T@;oo`2l00?o0?nQoonl0?oo_0000ood0?l3ooooo`;oa?l01?l0onX01OooooooYOl0ojGo0?nUo`3o
oooo00?ob_l00_ooool3oc80o`Wooooo1?n/o`000oooooooVOl0oiWo0002oiWo00?ooooo1?odo`00
1?oooooonP3oooX0oooj0?l2ooo800Cooooo0ol0]?l2oaCo00Sooooo0_l8o`02ool0n0?oo`3800Co
K`3oo`0Rool08_oo02;o2oooool7o`0Lo`03ooooooook03oon`000?oon`000?oooooool0i_oo0>H0
1Ooo0>H00onCo`3o0;[oo`2jo`02o`2jo`Goo`2G0ol05_l3o`3o@1Wooooo0_l20?l4ool0lPGobP3o
1?o40?l00oln0?ooooooooooo`0<ooooo`Ko0=ko7?ooool5o`3o40Goo`3D8oooool5o`3oo0;oN`3o
2?oX0?l6og/0o`Gooooo1_l0oel=ooooo`006Oooool00ol0003oooooooooo`03ooooo`0<ohOo0?oo
T@3oT`3oool0??oo0;coV@3oool0/?mk0?ooQ`3oool0C_oo07oonP3o0_oo06L02ooo09goo`2Aoo@0
oonb0?ooo`2;oh40ool0g_oo0?m6ool0Uooo=P3oo`3D00;ooah000Wo0:Ooooooooooooooa03ooooo
ool07?ooo`3Vo`0joome0?l00_oo=P03ool0I`04oon`0?l0o?oo0?coo`3loaWooooo0ol0odH7o`2W
o`03oonY0?oooooooooo00?ood802_ooool3ool0N@Kooooo0ooo07l3ool0R`04oooD0?oooooooooo
ooooo`?oQ`3o0_m4o`001?oo`P3oooooooooooooT@02ool0?0?ooooo0_nI0?l2ool0]P;ooooo0_m4
0?l00ooooooo0<Koo`36o`06ooooo`?oodh00_ooool4om`0o`03oooooomko`3oNol000;oS@3o1?oo
ool00ol80?ooo`1>ool0CP03ob`0o`?ooooo0ooo06d3oooP00Cooooo0_ooU`001_ooooooo`2Mool0
WOoo09goo`2`oooh00?o[03o1?ooool3ool0T@05oooooooo0;coo`2lo`3oXOoo_0000ood0?l3oooo
o`03olCo0?l0on[o0?oZ00;o0?oZ00?oofL0oooooonUo`000_nUo`001?oooooob_l0ol[o0?o:o`02
ooooo`?o<P3o2Oooool3ojco0003oooooonIo`3oVOl000;oVOl01?ooool3ooCo0003oooooooj0?oo
nP3o00;onP3o0_oob004ooooo`?o0;Co0_lDo`07ooooo`?o2?l00_oo0?P3ool0b0Co02;o1oooool7
o`0Lo`;o0?oN00?oooooooo/0?ook0000_ook007ool0iP04o`3o1?nCo`3oTol0oi?o00Co0;[o1?oo
09L3o`0Fo`?o0?m05oooool4o`80o`03och0oooo0?;oo`3b00;oo`3b1?o:0?l3ol@0oa3ooooo1Ol0
g_lKooooo`Ko0?l@1_oo0=@Hooooo`[o0?ol1_mk0?l7onP0o`Sooooo2ol0oelCooooo`006Oooool3
o`0000?ooooo01_oQol0ooooool0m_ooT`3oool0??nI0?oo0?olool0/?mk0?ooo`1>ool0KOoX0?oo
o`38ool0l_oo06Ooo`2Aoo@0oonb0?oog03oool0Ron10?oo0=koo`3oA_oo09Ooooooool0e?oo=P00
1?l0>_l01Oo40?oo03[oo`0Loooo0>KoocH000;oo`1W0_oo/002o`3loaSooooo1ol0Yol2o`3oL@;o
ojT01?ooool2oom200_ooooo0_oo07T6ooooo`?oo`1o0_oo08/2oooD00Cooooo0_n70?l01?n1o`3o
A?l0odCo0?oo`P02ooooo`03oonA0?oo03coo`0l00;ooooo0_ooiP001?nI0?ooo`2fool0]_ooool3
od@0o`03ooooool0a_oo0<Ko00Gooooo0oooCP000ooooooog03oom`0o`02om`0o`;oT`3o0omko`02
ohd0o`?ooooo00Ko203oool0C_oo04koo`1>ob`0ool0A_l4ooooo`;oo`1]0oooh006ooooo`04oonG
0?oo09goo`2Mool0W@;oo`2`0on/0?l4ooooo`?oo`2A0_ooool2ool0_004oonl0?od0?oom03ooo@0
o`;ooooo1Ol0onX00olbo`3oooooooooo`03ojGo0004ooooooo:o`3ob_l0ol[o00;ooooo0olb0?l8
ooooo`Co[?l000CooooooiWo0?nIo`3oVOl01?ooool4ooCo0004oooooooj0?oonP3oooX0o`?oolP0
1?ooool3o`2do`;o5?l01Oooool4o`So00?oo`3h0ooo0<P3o`0Ro`Gooooo1_l07?l00ooooooo0?oN
o`3ogP02o`3ogPCoon`01Ooo0>H3o`3o10?oTol01Ol0^_l4ool0U`Co01Ko0ol0od0Dooooo`;o0P3o
1?ln0?l5ool0lP;obP3o1?o40?l@ooooo`Go0=ko6Oooool7o`3o4003oooooooo0=Coo`3D00?oo`3D
4oooool5o`3oo0ooN`3o1ooX0?l6ooooo`Wo0?mO7_ooool001Wooooo00?o0000ooooooooool00ooo
ool03on7o`3oooooo`3foonC0?ooo`0lool0_?l0XOooo`2`og/0ooo:0?ooo`1>ool0Oooo0<SoA03o
ool0lP02ool0I`03oo@0oonb0?oog03o00;oo`2;00Go03[oool0Uol0>_oo03[oool0e004o`3o7003
o`2?ooo40?ooo`1W00;oo`1W00CoooooogD0oome0?oo0?co5Oooool5o`2Wo`04o`3oA_oolP3ooo80
oonY00?o0?ma1_ooool2oom200_ooooo0_oo07T5ooooo`04ool0Rooo07ooo`1oool0R`?oom@01Ooo
ool2ohL0o`;oPOl000?oA?l0ooooooooool00_ooool2ool0?0;ooooo0_ooiP03ool0]P04oooooom4
0?ooA03oooooo`?o0<Ko1?ooool3oom>00Cog03o0_ooool01Ol0obkoT`3oog_o0?mko`3ooooo00;o
S@3o0_ooool2ob`0o`;oo`1>00?ooj<0o`16ool0A_l00oooool3ool0K@;oon001oooool3ool0W@;o
o`2`0on/0?l4ooooo`?oo`2A0oooool2ool0_0?om03o00?oooooo`3oj_l0onX00_l0onX3oc;o00;o
oooo0onUo`001?oooooob_l0ol[o0?o:o`03ooooo`;o<P3o1oooool4ojco0003oooooonIo`3oVOl0
00;oVOl01?ooool3ooCo0003oooooooj0?oonP3o00;onP3o0ooob004ooooo`?o0;Co0_lDo`04oooo
o`Co2?l000CoK`3oool0n?oo0?Soo`3h0ooo0<P3o`0Ro`03ooooool07?oo01co00Go01co1?ooool3
o`3ogP;oon`01_oo0>H3o`3o10CoTol01?l0^_l5ool0U`04ooooool05_oo01Koo`0Fo`?o0?m04ooo
ool2o`80o`Go?P3o1?oo0?82olX0o`Coa03o4?ooool5o`3NoaWooooo1Ol0oa03ooooo`Goo`3D3_oo
ool?og/0o`Sooooo1ooX0?l6ooooo`Oo0?mO9oooool001Wooooo00?o0000ooooooooool00oooool0
4On7o`3ooooooonA0?nC0?ooo`0lool0_?nI0?ooo`2`og/0oomG0?ooo`1>ool0OooX0?ooo`38ool0
l_nh0?ooo`2A00;oo`1W00Wo0?lLom`0oon10?ooo`2;o`3o7?oo09Oo0?m6ool0e?l0odH01Ooo06L0
1?o40?ooooooo`0Loooo0>H2o`2Wo`03ogD0oooooooooooo00[ooooo2Ol0Yol2o`3oAP?ooo8000Co
olh0oonY0?l0og7o0?ma1oooool2oom200[ooooo0ooo07T3ooooo`?oo`2;0_oo07l00oooK@3oom@0
oooD0005ooooo`?oQ`3o00Cooooooh7o0?m4o`3oA?l01?ooool00ooo03coooooooooo`02oooV00;o
o`2f00Gooooood@0oom40?ooA03oooooo`02o`36o`04omKo0?ooooooooooooooo`;oodh01?oL0?l4
ooooo`03o`3o;_nC0?ooT`3o00?ooooo00?oS@3oooooool/0?l00_l/0?l2ool0CP03oonS0?oooooo
04Ko00;ooooo0ooo06d2oooP00Oooooo0ooo09d01?ooooooo`2`ool0/?n/0?l5ooooo`?oo`2A0ooo
ool00ol0oj7oo`2lool0_002oo@0o`06ooooool0on[o0?oZo`3oj_ooI`3oa?l00_lbo`02ooooo`?o
YOl000Cooooool[o0?o:o`3ob_l00oooool3oc80o`Kooooo0on/o`000oooooooVOl0oiWo0002oiWo
00Gooooo0oodo`001OoooooonP3oooX0oooj0?oooooo00?oolP01?ooool3o`2do`;o5?l00oooool4
o`So0003ofl0oooo0?Soo`3h00;oo`3h0ooo0<P7o`0Lo`Oooooo1?l0omh5ool0iP03ooooool0o`Co
0?l400;o0?l41?nCo`001?oooooo0;[oo`2jool0^_l4ool0U`;ooooo1?l05_l3o`3o@17ooooo0_l2
0?l5och0o`Goo`3b00?obP3ool@0ooo40?l00_o40?l?ooooo`Ko0=ko6?ooool6o`3o40?ooooo1Ooo
0=@8ooooo`Co0?ol1omk0?l@ooooo`Ooj03o1_ooool7o`3oGbkooooo000Iooooo`03o`000?oooooo
oooo00Cooooo01;oQol0oonA0?nC0?ooo`0lool0_?nI0?oo0?olool0/?mk0?ooo`1>ool0KOoo07oo
o`38ool0l_lV0?ooo`2Mool0TOod0?l9ool0I`;o0?m600Coooooon;o0?ooooooa03o0_l0o?l01Ol0
7?ooo`3Vool0i_ooooooM@3o00_o0:Oo1?ooool4o`3oAP?ooo8000?oolh0oonY0?l0og400_l0og47
ooooo`;ood802_ooool2ool0N@?ooooo0ooo08/3ool0O`?oom@01Oooool2ohL0o`;ooooo00?oPOl0
odCo0?m4o`001Oooool01?oo03cooooooooV0?ooiP02ool0]P?oA03o0_ooool2o`36o`05omKo0?oo
ooooooooooooooooCP000ooL0?l5ooooo`04og_o0?l0obkoT`3ooi<0o`?ooooo0_n=0?l2ob`0o`?o
o`1>00Gooj<0ooooool0A_oo04Koooooo`02ool0K@;oon001oooool3ool0W@05oonG0?n/0?ooo`2`
ool0/?oon0001?ooool3ool0T@Cooooo00Co0?nQool0_?oo0;com03o1?l0onX2oomW00?o<_l000Go
ooooojGo0?nUo`3oYOl0ooooo`03ol[o00Cooooo0_lb0?l6ooooo`?o[?l000CooooooiWo0?nIo`3o
VOl01Oooool4ooCo0005oooooooj0?oonP3oooX0ooooool00ooob004ooooo`?o0;Co0olDo`02oooo
o`?o2?l000?oooooool0n?oo0?P00_oo0?P2o`0Lo`;oo`380ol07?l:ooooo`03ooo/0?l0omkoo`3V
00Goo`3V00?oooooo`3o1?l0o`@00ol0o`@3oi?o00;ooooo0ol0^_l4ool0U`?ooooo0ol05_l3o`3o
@13ooooo0_l20?l5och0o`Goo`3b0_o:0?l2ol@0oa3ooooo1Ol0g_lIooooo`Go0?l@1?ooool5ool0
e0Cooooo1_l0oo`7og/0oa3ooooo1ooX0?l6ooooo`Oo0?mO7?ooool<od[o00gooooo000Iooooo`03
o`000?oooooooooo00Cooooo01goQol0oonA0?nC0?ooS@3oool0??nI0?oo0?olool0/?mk0?oobP3o
ool0C_oo0;Koo`1oool0b?oo0?;o^03oool0TOod0?oo02Sook80oooL0?ooP@3oo`3Noooo08_oo`2G
ooooooooZ@3oo`3Don;o0003o`3oAP04o`2?ooo40?ooooooooooo`;o01co00?oo`3Voooooome0?l0
1Oooool9o`3oAPCooo800_oocP000ooooooo0?mao`3oL@08ooooo`;ood802_ooool2ool0N@03oooo
oooo08_oo`2;00;oo`2;00?oooooool0Oooo07l00oooe005ooooo`?oQ`3o0_ooool00on1o`3oA?l0
odCo0005ooooo`;oo`0l0_ooiP02ool0]P;oA03o0_ooool3o`36o`;oe_l000?oooooom`0oooL0?l0
0_oL0?l6ooooo`05og_o0?l0obkoT`3ooi<0ooooool00_l/0?l2ohd0o`;o203o0_oo04h2oonS0004
ooooool0A_oo04Koooooo`;oo`1]00?oon00ooooooooool01Oooool3ool0W@03oooooon/0?oo[03o
00;oo`2`00?oooP0oonM0?ooool01?oo0945ooooo`03oo@0oooo0;coo`2l00?o0?oZ00?ooooooomW
0?ooI`000olbo`001OooooooYOl0ojGo0?nUo`3ooooo00?ob_l01Oooool2oc80o`Gooooo0on/o`00
1?ooooooVOl0oiWo0?nIo`05ooooo`?om?l00_ooool3ooX0o`04oooooooob03oolP0ooo800Cooooo
0ol0]?l3oaCo0003ooooool8o`3o2?l000;o2?l000Coooooool0n?oo0?Soo`3h0ol07?l3ool0b003
o`0Roooooooooooo00Oooooo1ooo0>H4ooooo`?o0?l41?nCo`03ooooo`03o`2joooo09Ooo`2G00?o
o`2G0oooool4o`0Fo`?o0?m03_ooool00ol20?oo?P3ooch0o`04och0o`Goo`3b0oo:0?lAooooo`Go
0=ko6Oooool5o`3o40Cooooo1Ooo0=@2ooooo`Co0?ol2Omk0?l@ooooo`Ooj03o1_ooool7o`3oGa?o
oooo4?m:o`0Iooooo`006Oooool00ol0003oooooooooo`04ooooo`0HohOo0?ooT@3o0?Kooi<0oooo
03coo`2loiT0oooo0;3oN`3ooeL0oooo04koo`1iool0Oooo0<Soo`3bobH0oooo09goo`2Aoo@0oonb
0?oo0?ofom`0oon10?oo0=ko0_oo08/00ooRo`3oo`3DoonY0003o`3lo`03o`3oA_l0Soooa03o00?o
0?m600Co01coool0i_l0odKoM@3o1?l0odH5ooooo`05oonY0?oolP3ooo80ooob0?ooool00_oocP00
1?oooooo0?mao`3oLOl0og48ooooo`;ood802Oooool3ool0N@?oo`2;0oooool2ool0O`;oom@000?o
ofd0ooooooooool00oooool2ohL0o`;ooooo00Cool80oh7o0?m4o`3oA?l01_ooool00ooo03coonH0
oooV0002ool0]P04oiT0oom40?ooooooooooo`;o0<Ko00?oooooomKo0?oL0?l00ooL0?l7ooooo`;o
Nol00_l0obh01?nC0?oo;03oob`0ool/0?l2ohd0o`;o203o0_oo04h2oonS0003ooooool0A_oo04Ko
00?oo`1]1oooool3ool0W@04oooooon/0?oo[03ooj`0o`;oo`2`00?oooP0oonM0?oo09400_oo0946
ooooo`;om03o0_oo0;`2o`3ojP04ooooooooI`3oofL0oomW00;o<_l000Goa?l0ojGo0?nUo`3oYOl0
ooooo`03ol[o00Gooooo0olb0?l4ooooo`?o[?l000CooooooiWo0?nIo`3oVOl01Oooool3ooCo00;o
oooo0ooj0?l01?ooooooolP0ooo80?oob004ooooo`?o0;Co0olDo`04o`So0003oooooooo0?Soo`3h
00;oo`3h0_l07?l01Oooooooo`38ool0b?oo0<So02;o00Gooooo1ooo0>H2o`3ogPKooooo0ol0o`@3
oi?o00?ooooo00?o0;[oool0Uooo09L00_oo09L4ooooo`Co01Ko0ol0od0=ooooo`03o`80ooln0?oo
?P3o00?o?P3o00?oa03oool0l_oo0?800ooo0?84olX0oa3ooooo1Ol0g_lJooooo`Co0?l@0oooool6
ool0e003o`3oo?mk0?ooN`3o00SoN`3o5?ooool5onP0o`Kooooo1ol0oel?ooooo`_oB_l0:Oooool0
01Wooooo00?o0000ooooooooool01?ooool07On7o`3ooi40o`3foonC0?ooo`0lool0_?nI0?ooo`2`
ofl0oomk0?oobP3oool0C_oo07Woo`1ood@0oooo0?;o^03oool0TOod0?oo2?l0ok80ool/0?oog03o
ooob0?l0g_ooh_l0ool0Rol0o?ooo`3D00?ooooo0_ooZ@000ol0Soooa03ooonY0002oonY0004o`0L
oooo0>KoojT0ogD0o`KoojT00ooolP001Oooooooolh0ooo>0?oocP3ooooo00;o0?ma2Oooool2oom2
00Wooooo0_oo07T2ool0R`Gooooo0_oo07l00oooe03oofd0oom]0004ooooo`?oQ`3o0_ooool2ooo2
0003oh7o0?m4o`3ooooo00Kooooo00Goo`0loooV0?oo0;Koo`2foiT0o`03ooooo`;o0<Ko00Cooooo
om`0oooL0?oog03o0_ooCP07ooooo`;oNol00_l0obh01?l/0?ooT`3oob`0ooooool2ohd0o`06o`P0
oooo04koo`1>ool0C_oooooooj<00_ooool00ol0A_ooo`1]ool0K@07ooooo`?oo`2M00Gooooooj`0
oon/0?oo[03ooonG0002ool0/004oooh0?oo097oo`2Aool0T@Kooooo0ood0?l2ool0_0;ooooo0ooo
I`03oc;o00?oYOl000Cooooool[o0?o:o`3ob_l01_ooool2oc80o`Gooooo0_n/o`001?ooooooVOl0
oiWo0?nIo`05ooooo`?om?l00_ooool3ooX0o`;ooooo0_oob005ooooo`;o0;Co00?ooooooaCo0?lD
o`000ol8o`000ol07?ooo`3hool0n002ool0n004ofl0ooooooooooooooooo`?oo`3800?o02;ooooo
oooo0>H01_oo0>H2ofWo00Co0?oN1_ooool3o`3o10;oTol01?ooool4ool0U`Cooooo1?l05_l3o`3o
@0cooooo1_ln0?l2ol@0o`Coo`3b00?oooooolX0ooo:0?l00_o:0?l>ooooo`Ko0=ko6_ooool5o`3o
40;ooooo1Ooo0=@7og/0oaSooooo1_oX0?l4ooooo`Oo0?mO1oooool?od[o027ooooo1_nO0?l=oooo
o`006Oooool00ol0003oooooooooo`04ooooo`0KohOo0?oooooooi40oi<0oooo03coo`2loiT0ool0
oocoo`2`og/0ooo:0?ooo`1>ool0NOoo07ooo`38ool0l_lV0?ooo`2Mool0TOod0?oo/P3oo`3lool/
0?oog03oo`3Nool0o?ooo`2G00;oo`2;00?oo`3Dooooooooool00oooool00ol0Soooa03oooooo`02
ooooo`05o`0Loooo0>KoooooogD0ooooool01?oolP02ooooo`;oolh000Coooooo`3oLOl0og7o0?ma
2Oooool2oom200Oooooo0_oo08/2ool0N@03ool0Rooooooooooo00?ooooo00?oom@0ool0Oooo07l0
0oooK@04ooooo`;oQ`3o0oooool2ooo20003oh7o0?m4o`3oA?l000Kooooo0_oo03`2ool0]P;oV@3o
0_ooool00ol0a_oog03oom`0o`02om`0o`;oodh02?ooool2og_o0003o`3o;_l/0?oo;03o00;oT`3o
00Coooooohd0oon=0?oooooo0_oo04h2ooooo`;ooj<000Coooooo`16oooo06goo`1]1_ooool3ool0
W@04oooooon/0?oo[03ooj`0o`;ooiL00_oo0;03ool0T@Kooooo0ood0?l01?l0on[oo`2lool0_?oo
ool3oomW0004oooooolbo`3o<_l0olCo00;oYOl00_ooool2ol[o00Kooooo0olb0?l4ooooo`?o[?l0
0onIo`05ooooo`?om?l00_ooool3ooX0o`;ooooo0ooob004ooooo`?o0;Co00?oooooo`So0?l07?l0
0ol07?l3ool0n0;oK`3o1?ooool2ool0b0Goo`3V00?oooooofWo0?mYo`000omYo`03o`3ogPOooooo
0ol0o`@00onCo`3oooooooooo`02ooooo`Coo`2G1Oooool3o`0Fo`Co0?m02_ooool5och0o`03o`80
ooooooooa03o00;oa03o0ooo0?800ooooooobP3oolX0o`02olX0o`gooooo1Ol0g_lLooooo`Co0?l@
00?oooooool0e?oo0=@01?oo0=@4og/0oa_ooooo1OoX0?l3ooooo`Oo0?mO3_m:o`0Uooooo`_oW`3o
1_l0Mol=ooooo`006Oooool00ol0003oooooooooo`04ooooo`0HohOo0?oooooooi40oi<0oon=0?oo
o`0lool0_?l0oocoo`2`og/0oomG0?ooo`1>ool0KOoo07Woo`1ood@0oooo0?;o^03oool0TOl0FOoo
m03ook80ool/0?oo0?oZ0_oL0?l01?oolP3oo`2Gooob0?oo08/6ooooo`03o`2?ooo40?oooo8000;o
oo8000Co01coool0i_oolP3oM@3o0oooool3ooo>00?o0?ma2_ooool2oom200Cooooo1Ooo08/2ool0
N@Gooooo00Coom@0ool0Oooo07ooo`1o0_ooK@05ooooo`;oQ`3o0oooool2ooo20003oh7o0?m4o`3o
A?l000Kooooo00OoonH0ool0??oo0;Koo`2foooooonI0?oooooo00Cog03o0_oFo`000oooCP3ooooo
ooooo`07ooooo`;oNol00ol/0?l01_ooooooT`3oooooool80?ooS@3oooooo`;oo`1>0_ooool2oonS
0004oooP0?l0A_ooo`1]ool0K@Gooooo0ooo09d01?oooooo[03ooj`0oon/0?l2ooooo`03oonG0?oo
0;3oo`2A00;oo`2A00?ooid0ooooooooool00oooool3oo@0o`04o`3oj_l0oj7oo`2lool0_0?oofL0
00Cooooooc;o0?lbo`3o<_l00onUo`02ooooo`;ob_l01_ooool2oc80o`Gooooo0_n/o`03oiWo00Go
oooo0oodo`02ooooo`?onP3o0_ooool3ooo800Gooooo0_l0]?l5o`0Lo`04oooooooo0?Soo`3hool0
n0;oK`3o1?oo0>H3ool0b0Cooooo1?mYo`000oook03oooooo`3ogP02o`3ogPOooooo0ol0o`@01?nC
o`3oooooooooooooool4ool0U`03oon;0?oooooooooo00;ooooo1?l05_l3o`3o@0Wooooo1Oln0?l2
o`80o`04ooooooo40?ooa03ool@0o`Coo`3b1?o:0?l;ooooo`Ko0=ko7Oooool4o`3o40Goo`3D0omk
0?l2o`3oo1[ooooo1_oX0?l00ooooooo0?mOo`3oG`05o`3oG`KoB_l0:_ooool:oil0o`[o07Oo1ol0
omP=ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Wooooo00?o0000
ooooooooool01?ooool07_n7o`3ooooooonA0?nC0?ooS@3oool0??oo0;coV@3oool0/?mk0?ooE`3o
olX0oooo04koo`1iool0Oooo0<Soo`3bobH0oooo09goo`2Aoo@0oonb0?ooooooob`0oon10?oooooo
om`0ooooooooo`2Gooob00?oo`2;0ooolP000ol0Sooooooool@0o`04ooooo`03ool0i_ooooooM@3o
00;oolh00ol0og4;ooooo`;ood8000?oooooool0Rooo08/00ooo08/3ooooo`;oo`1i0oooool3oooD
00;oo`1o00?ooooooom]0?ooK@001?ooool3ohL0o`?ooooo0_oo`P000oooooooA?l0odCo0006oooo
o`06oooV0?oo0;Koo`0lod@0ooooT@3oV@3o0ooL0?l2o`36o`03oom>0?oFo`3oodh000Wooooo00Go
Nol0ob`0ool/0?oo;03oo`3o;P02ooooo`04oi<0ool80?ooS@3oohd0o`;oo`1>0_ooool01?ooX`3o
on00oooP0?l0A_l2ool0K@Gooooo0_oo09d01?oooooo[03ooj`0oon/0?l3ooooo`04oonG0?oo097o
o`2Aool0T@;ooid01?ooool3oo@0o`03ooooool0oj7o0?nQ00;oo`2l0_ooI`001Ooooooo<_l0oc;o
0?lbo`3oa?l000;oYOl00_ooool3ol[o00Kooooo0_lb0?l4ooooo`;o[?l00onIo`05ooooo`?om?l0
0_ooool3ooX0o`;ooooo0ooob005ooooo`Go01co00Co2?l0oaCo0?ooooooo`3h1ooo0>H01?oooooo
o`38ool0b?oo0<P4ooooo`?oJOl000?oon`0ooooooooool00ol0omh6ooooo`04oi?o0?l0o`Co0?l4
o`3o10;ooooo1Ooo09L00ol0^_oooh/0ooooo`02ooooo`Co01Ko0ol0od09ooooo`Co?P3o0_l20?l0
0oooooooa03ool@0o`02ol@0o`Coo`3b0oo:0?l;ooooo`Go0=ko7oooool2o`3o4003og/0oooo0=Co
o`3D00?oo`3D00CoN`3oo`3oo?l0ooco0?ol6oooool5onP0o`03ooooool0oeoo0?mO00Co0?mO1_m:
o`0Vooooo`_oW`3o2Ol0Mol7o`3of1Sooooo00001Ooooooo0000oooooooooooo000000Wooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`0MohOo0?oooooooi40o`3foonC0?oo
o`0lool0_?nI0?oo06_oool0/?mk0?oobP3oool0C_oo0;Koo`1iool0Oooo0?Soo`3bokP0oooo09go
o`2Aoo@0oonb0?oo0?ofob`0oon10?oo0=koom`0oooo09L00_ooool00ooo0=Coooooool0R`02ool0
R`04ooooool0Sooooooool@0o`?ooooo00Goolh0ool0i_oocP3oM@3oo`3oL@0<ooooo`Goo`2;1_oo
ool2ool0N@;ooooo0oooe0001?ooooooo`1oool0Ooooool2oom]00Cooooo0_n70?l4ooooo`;ool80
0_ooool00om4o`3oooooooooo`04ooooo`04oooV0?oo0;Koo`0lool0?0Cog03o00Cooe@0o`36ool0
a_ooodh00_oFo`08ooooo`04og_o0?l/0?oo;03oob`0o`;o0?l^0_ooool2oi<0o`04o`P0oon=0?oo
o`1>ool0CP;ooooo0oooh003ool0K@Cooooo0ooo09d00ooooooo[03ooj`0o`04ooooo`?oo`2A00?o
oooooonM0?ooW@000_ooool01?l0on[om03ooo@0oood0?l2ooooo`;o0?nQ00Gook`0ool0_?ooI`3o
ofL0ooooo`02oc;o0004oooooonUo`3oYOl0ojGo00;ooooo0_o:o`07ooooo`;o<P3o0oooool2ojco
00?oVOl01Oooool3ooCo00;ooooo0ooj0?l3ooooo`;oolP00oooool5o`0Lo`04o`2dool8o`3ooooo
oaCo00Goo`3V00?oK`3oooooooooool00_ooool3ool0b0?ooooo1?mYo`001?ook03ooooooooooooo
ool2o`3ogPKooooo00GoTol0o`3o1?l0o`Co0?l4ooooo`04ool0U`?o0;[o00Cooh/0oooooooooooo
oooo0ol05_l4o`3o@0Oooooo1Oln0?l2o`80o`Goa03o00Coooooool0l_oo0?;oo`3b0oo:0?l:oooo
o`Go0=ko7oooool2o`3o4003og/0oooo0=Coo`3D00?oo`3D1?l0oo`Kooooo`Goj03o00?oooooo`3o
Gol0oel00ol0oel5od[o02Cooooo2OnO0?l4ogGo00Oo07Oo0ol0omPBooooo`Ko__l03Oooool00005
ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`08ooooo`Co00001?ooool07On7
o`3ooi40o`3foonC0?ooo`0lool0_?nI0?oo0?olool0/?mk0?ooE`3oool0C_oo06goo`1iool0Oom4
0?ooo`3bobH0oooo09goo`2Aoo@0oonb0?ooooooo`3om_n10?ooooooo`3NoooL0?ooo`2G00;ooooo
00Coo`3Doooooooooooooooo1?oo08/00oo40?ooolh0ooo>0002o`3oL@04ool0i_ooooooM@3oogD0
o`Oooooo1?oo08/9ooooo`;oo`1i00CooooooooD0?ooe03oom@00_ooool2ool0O`03ooooooooK@3o
ofd000Cooooo0_n70?l4ooooo`;ool800_ooool2odCo00Gooooo00CoonH0ool0]_oo0;Koo`0l0_oL
0?l2oiT0o`;ooe@000Co0<Kooom>0?ooCP3oe_l02?ooool3ob`0o`03ooooool0obko0?l^00?ooooo
00GoT`3oo`P0ooooooooS@3oool0CP02ooooo`;oon0000Coooooool0KOoo06go04Ko1?ooool2ool0
W@04oooooon/0?oo[03ooj`0o`?ooooo0ooo09401?oo0;3oooooooooooooW@02o`3ojP?om03o0ooo
ool2o`3oX@03oonl0?oo0;coo`2l00;ooooo0_lbo`03ojGo00?ooooo0_o:o`07ooooo`;o<P3o0ooo
ool2ojco00;oVOl01Oooool3ooCo00?ooooo0_oj0?l4ooooo`03ooo80?l07?oo01co00Co01co00?o
2?l0o`2dool0]?l01_oo0>H00ooo0?SoK`3oofl0o`04ooooo`03o`0Roooo0<Soo`3800;ooooo1?mY
o`000oook03oooooooooo`02ooooo`?o0?oN1Oooool2oi?o00;o0?l41?oo09L01Ooooooo0;[oo`2j
ool0^_oooh/000?ooooo0ol05_l3o`3o@0Oooooo1?ln0?l2o`80o`Goa03o0_ooool4ool0lP;obP3o
2_ooool4o`3Nob3ooooo0omk0?l4ool0e0Co0?ol6oooool5onP0o`;oB_l01?l0oel00om:o`3ooooo
ooooo`0Pooooo`Coj?l01onO0?l00oooooooMOl0ogGo0003ogGo00Oo07Oo0ol0omP2oooooagoD?l0
3Oooool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Gooooo023oQol0oonA0?ooooooT`3oohd0oooo03coo`2loiT0oooo0;3oN`3ooeL0
ooo:0?ooo`1>ool0]_oo07Woo`1oool0n?oo0?;o^03oool0WOoo097om03ook80ool0ooKo^?l0oh40
oooooooo0=koom`0oooo09Ooooooool0e0;ooooo1?oocP000ol0Soooo`2;ool0R`0>ool0R`;ood80
2?ooool3ool0N@?oom@00_ooool3ool0O`03ooooooooK@3oofd000?ooooo0on70?l4ooooo`;ool80
0oooool00om4o`3oooooooooo`03ooooo`05od@0oooo0;Koo`2fom`0oooo03`00_ooool00onI0?oo
oe@0oomD0002o`36o`03oooooooFo`3oe_l000Kooooo0ol/0?l2ooooo`;o0?l^0_ooool2o`P0o`03
oi<0ooooooooS@3o00;oo`1>0oooh0001?ooooooo`1]ool0KOl0A_l3ooooo`?oo`2M00?ooooooj`0
oon/0?l00oooool3ool0T@;oo`2`0_ooool2o`3ojP?om03o1?ooool2o`3oX@03oonl0?oo0;coo`2l
00;ooooo0_lbo`02ojGo0003olCo0?oooooooooo00?ob_l01oooool2oc80o`?ooooo00Co[?l0oiWo
0?nIo`3oVOl01?ooool3ooCo00?ooooo0ooj0?l2ooooo`Go01co0oooool00ol8o`3oo`3Vool0iP03
ool0iP04oaCo0?oo0?Soo`3hool0n0;oK`3o1Oooool01?l08_ooo`38ool0b?ooool3ofWo0003ooo/
0?oooooooooo00Cooooo0_l0omh5ooooo`;oTol000?o0?l4ool0Uooo09L00_oo09L2ooooo`?o0;[o
0_ooR`02ooooo`?o01Ko0ol0od06ooooo`Co?P3o00?ooooool@0ooo40?l00oo40?l4ooooo`?oo`3b
0_o:0?l9ooooo`Go0=ko7oooool4og/0o`Coo`3D1?l0oo`Hooooo`;oB_l01OoX0?l00om:o`3ooooo
ooooo`04o`3oGacooooo2?oXo`07oil0o`03oooooom@o`3oD?l000?oD?l01ol0Mol3o`3of0WoD?l0
2Oooool7okko00Kooooo1onh0?l=ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool08On7o`3ooooooonA0?nC0?ooS@3oool0
??oo0;coV@3ooch0oooo0;3oN`3oolX0oooo04koQ`3oool0]_oo07WoA03oool0l_lV0?ooo`2Mool0
TOod0?oo/P3ooooD0?l0ooKoP@3oob`0ool0g_ooolh0ool0UooL0?ooolh0ool0e006o`3oL@03o`2?
ooooooooa03o00Cooooo0_oo0>H01?ooooooM@3oooooooooool3oom200Sooooo0_oo07T3oooD00;o
oooo0ooo07l2ooooo`;oofd00oooool2ohL0o`Gooooo0_oo`P03ooooo`03oh7o0?m4o`3ooooo00;o
oooo0_oL0?l2ool0]P04oooooooo03coo`0looooo`;oV@3o00?ooe@0o`36ool0a_l00_ooool00ooF
o`3oooooooooo`03ooooo`?o;03o00?oNol0ooooooooool00_l0obh2ooooo`;o203o00?ooooooi<0
ooooool00_oo04h2oooP00;ooj<00_oo06d00ol0A_ooooooooooo`03ool0W@04oooooon/0?oo[03o
oj`0o`?ooooo0_oo0942ooooo`04ool0/?l0on[o0?oZo`3ojP?om03o1_ooool01?l0oj7ook`0ool0
_?oo0;`2ooooo`;o<_l00_nUo`000oo4o`3oooooooooo`02ol[o00Oooooo0olb0?l2ooooo`04ojco
0?nIo`3oVOl0oiWo00Cooooo0oodo`04ooooo`;onP3o1Ol07?l2ooo80003oooooooo0>Koo`3V00Co
o`3V0oooool3ool0n0?oK`3o1?ooool01?l08_ooo`38ool0b?oo0<P3ofWo0003ooo/0?oooooooooo
00Gooooo0_l0omh4ooooo`;oTol000Co0?l4ool0Uooo09Ooo`2G0oooool3o`2jo`;ooh/00_ooool3
o`0Fo`;o0?m01_ooool4och0o`Goa03o1_ooool3ool0lP;obP3o2?ooool4o`3Noaoooooo1?mk0?l5
ool0e0Co0?ol5oooool3od[o00Coj03o0oooool5o`3oGaGooooo1_oXo`07oe3o00KoW`3o0om@o`03
o`3of0Oo07Oo00?o0?oHooooooooool04_ooool7okko00;ooooo2onh0?lDooooo`0000Goooooo`00
0?ooooooooooo`000008ooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`0RohOo0?oooooo
oi40o`3foonC0?ooo`0lool0_?nI0?oo0?nKool0/?mk0?ooE`3oool0C_oo06goo`2fooX0oooo07Wo
o`3bo`3Toonh0?ooo`2Mool0TOod0?oo/P3oo`3om_nho`3oP@3oob`0ool0g_oo0?maool0UooL0?oo
0?maool0e0Kooooo00?o08ooooooooo40?l01Oooool2ool0iP03ogD0oooo@P3ooooo00Sooooo0_oo
07T2oooD00?ooooo0_oo07l3ooooo`;oofd00oooool2ohL0o`Gooooo0_oo`P04ooooo`;oA?l01?oL
0?l2ool0]P;ooooo00Ooo`0looooooooooooV@3ooonA0?ooCP3o0<Ko00;ooooo0_oFo`03ooooo`?o
;03o0_mko`03ooooo`03o`3o;_oooooooooo00;o203o00?ooooooi<0oonC0?l00_oo04h2oooP0007
ooooooooX`3oo`1]ool0KOoooooo04Koooooo`02ool0W@;ooooo0_n/0?l3ooooo`?oo`2A0_ooool2
ool0/004o`3oj_od0?oom03ooo@0o`Oooooo0_l0oj401?oo_03oo`2looooooooool2oc;o0005ojGo
0?ooooooa?l0olCo0?ooool00_o:o`07ooooo`;o<P3o0oooool3oiWo00Cooooo0oodo`03ooooo`05
o`0Loooj0?oonP3oooX0ool07?l01?ooool5ool0iP04o`So0?oooooo0;Coo`2do`;ooooo0ooo0?P0
0oooooooK`3oofl0o`05ooooo`03o`0Roooo0<Soo`3800?oJOl02?ooool3o`3ogP?ooooo0_nCo`00
1?l0o`Coo`2Gool0Uooo09L3ooooo`?o0;[o0_ooR`02ooooo`?o01Ko0_l0od06ooooo`03och0ooo4
0?ooa03o00Coa03o00?o0P3oooooooooool01Oooool3ool0lP;obP3o1oooool4o`3Noaoooooo1?mk
0?l4ool0e003ooooool0ooco0?ol00;o0?ol5Oooool4od[o00Goj03o0oooool4o`3oGa3ooooo4?m@
o`02ooooo`GoW`3o1Ol0omP7o`1goaGooooo1onno`000ooooooo^03ookP0o`06okP0oaoooooo0002
ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo01goQol0
ooooooooT@3o0?Kooi<0oooo03coo`2lo`16oonI0?ooo`2`og/0oomG0?oobP3oool0C_nO0?ooo`2f
ool0NOoo07ooo`3bobH0oooo09goo`2Aoo@0oonb0?ooooooo`3om_nho`3oP@3oob`0o`02ooooo`03
ool0UooL0?ooo`3D00Oooooo00?o08ooooooooo40?l00oooool3oom200;oo`3V1oooool2ool0N@04
oooD0?ooooooooooooooo`?oo`1o1?ooool01?ooK@3oooooooooooooool2ohL0o`Gooooo0_oo`P03
ooooo`Gog03o0_m40?l2ool0]P?ooooo00Goo`0loooooonI0?ooV@3ooonA0002o`36o`;ooooo00?o
e_l0ooooooooool00ol/0?l2og_o00Cooooo0_l0obh00ooooooo203oo`P0o`02ooooo`03oi<0oooo
04koo`1>00;oon000_ooool2ool0K@03ooooool0A_ooo`2M00;oo`2M00Cooooooj`0oon/0?oo[03o
0oooool2ool0T@;ooooo00?o0?oZool0/?oo0;000ood0?l00oooW@3oooooooooo`05ooooo`;o0?nQ
00Cook`0ool0_?oo0;cooooo0_lbo`001OnUo`3oooooolCo0?o4o`3ooooo00;ob_l01oooool2oc80
o`;ooooo0onIo`05ooooo`;om?l01?l07?l3ooX0o`?ooooo1Ooo0>H3o`So00;ooooo0_l0]?l2oooo
o`;oo`3h00Co5?l0ofl0oom_0?ooK`3o1Oooool00ol08_ooo`38ool0b002ofWo00Wooooo0_l0omh3
ooooo`;oTol01?oo09L3ooooo`?o0;[o0_ooR`02ooooo`?o01Ko00?o0?m0ooooooooool01?ooool5
ol@0o`04ooooool20?oo0P3oo`80o`Oooooo0ooo0?82olX0o`Kooooo1?l0g_lNooooo`GoN`3o1?oo
0=@00ooooooo0?olo`3oo002o`3oo1Cooooo1Om:o`04onP0o`Cooooo1?l0oel9ooooo`_oD?l000?o
j?l0ooooooooool02Oooool6oil0o`?o0?oH1ol0MolEooooo`Oo__l00oooool5okP0oaSooooo0_nb
0?l=ooooo`006Oooool00ol0003oooooooooo`05ooooo`0PohOo0?oooooooi40o`3foonC0?ooo`0l
o`04oooo0;coV@3oool0/?mk0?oo<P3oolX0oooo04koo`1]ool0]_oo0<Soo`1iool0OolV0?oo^03o
ool0WOoo097om03ook80ool0ooKooooooh40ooooe03o;03ooooD0?oo09L2ooooo`03ool0e?oooooo
oooo00Gooooo00?o08ooooooooo40?l00_oo@P05ooooo`03ool0i_ooooooom@000;oom@00_oo07T4
ooooo`;oo`1o1Oooool2oom]0004oooooon70?ooQ`3oohL0o`Gooooo0_oo`P000ooooooog03oom`0
o`02om`0o`;oA?l000?ooooood@0oom40?l00_oo0;H3ooooo`;oo`0l00?ooe@0oiT0ooooCP000_l0
a_l3ooooo`05omKo0?l/0?oo;03oob`0ooooool00_mko`04ooooo`;o0?l^00?oooooo`P0ool80?l0
0oooool2ool0CP04ohd0ooooooooooooooooo`;oo`1]0_ooool2ool0W@;ooooo0_n/0?l3ooooo`?o
o`2A1?l0onX01Ooo0;3om03ooo@0oooooooooid000Oooooo0_l0oj401?oo_03oo`2lool0_?ooool2
oc;o00?ooooo00Coa?l0ooooooo:o`3ob_l01oooool2oc80o`05oooooonIo`3oVOl0oiWo0?n/o`00
1?ooool5o`0Lo`;ooooo0_oj0?l00oooooooo`3Vool0iP03ool0iP;ooooo0ol8o`03ooooo`;o0;Co
00Coooooool0n?oo0?Soo`3h0om_0?l5ooooo`;o02;o0_oo0<P2ofWo00Sooooo0ol0omh2ooooo`;o
Tol00ooo09L00ol0o`Coooooooooo`02ooooo`;o0;[o0oooR`001Ooooooo01Koo`0Fool05_oo0?m0
00Cooooo1Oo40?l3ooooo`?o0P3o1oooool3ool0lP;obP3o1Oooool4o`3Noakooooo1?mk0?l00ol0
oa3oo`3Dool0e002ool0e0Go0?ol4oooool5od[o0003oooooooX0?ooj03o00;oj03o0oooool5o`3o
G`;ooooo2om@o`05onSo00gooooo1OnO0?l01?oooooo0?oHo`3of?l0omP5o`1go`;oMOl04?ooool?
ohOo00Go^03o4On7o`09ooooo`?o/P3o3oooool001Wooooo00?o0000ooooooooool01Oooool09?n7
o`3ooooooonA0?ooooooT`3oohd0oooo03coo`2loiT0ool0Joooo`2`og/0oomG0?oobP3oool0C_nO
0?ooo`2fool0b?oo07Woo`1oobH0oooo09goo`2Aoo@0ool0:?oo/P3oo`3om_nho`3oP@3oooooool/
0?ooom@0ool0Uoooe03oooooool0e0;og03o1?ooool01?oo@P3o08oooom20?o40?l4ooooo`?oom@0
0_oo0>H2ool0N@?ooooo0ooo07l5ooooo`;oofd000?oooooohL0oon70?l01_ooool00ooo`P3og03o
om`0o`02om`0o`?ooooo00CoA?l0oooooom40?ooA03o0_oo0;H4ooooo`06ool0??ooE03oV@3ooiT0
oooooooo0<Ko0oooool3ob`0o`04oooooomko`3oNol0og_o00Cooooo0_l0obh00ooooooo203oo`P0
o`03ooooo`04oi<0oooo04koS@3oohd0o`;ooooo0_oo06d2ooooo`;oo`2M00Cooooooj`0oon/0?oo
[03o0oooool2ool0T@?o0?oZ0_ooool2ool0/004oo@0oooooooooid0oonM00Kooooo0_l0oj401?oo
_03oo`2lool0_?ooool2oc;o00?ooooo0_o4o`000ooooooob_l0ooooo`06ooooo`;o<P3o0onIo`02
ojco00Ko01co00Com?l0oooooooooooooooo1_oo0>H4ooooo`?o2?l01?ooool2o`2do`04oooooooo
0?Soo`3hoaCo00;oK`3o1Oooool00oook03o02;oo`0Ro`02ool0b003ofWo0?oooooooooo00Oooooo
0_l0omh2ooooo`;oTol00ooo09L00ol0o`Coooooooooo`02ooooo`?o0;[o0_ooR`001Ooooooo01Ko
o`0Fool05_oo0?m000;ooooo1Oo40?l2och0o`?ooooo0ol20?l7ooooo`?oo`3b0_o:0?l3ooooo`Go
0=ko7_ooool4og/0o`03o`3o4?oo0=Coo`3D00;oo`3D1?l0oo`Cooooo`GoB_l00_ooool4onP0o`?o
oooo1?l0oel7oe3o00?ooooo1_oXo`0;ooooo`?oQol01_nO0?l00on7o`3o0?oHo`3of006o`1go`;o
MOl05On7o`03okko00Oooooo1Onh0?lFooooo`CoQol01Onb0?l5ohOo00gooooo000Iooooo`03o`00
0?oooooooooo00Gooooo02CoQol0ooooooooT@3oooooo`3foonC0?ooo`0lool0_?nI0?oo0?nKool0
/?mk0?ooE`3oolX0oooo04koo`1]ool0]_oo0<So07goool0NOoo07oo^03oool0WOoo097om03ook80
ool0ooKooooooh40oooooooo0=koob`0ooooooooo`2GoooD0?oo0=@2oooD00?og03o0oooe0001?l0
Soooom@0ol@0ooo40?l2oooD00;ooooo0ooo07T2ool0iP?oo`1o1_ooool2oom]0003oooooon70?oo
Q`3o00Gooooo1?oL0?l6ooooo`03odCo0?m40?ooA03o00;oo`2f1?ooool01OooCP3oo`0loomD0?nI
0?oooooo00;o0<Ko00Coooooob`0ool/0?oo;03o0_ooool2og_o00Kooooo00Co0?l^ooooool80?oo
203o0oooool01?ooh03oo`1>ool0C_n=0?l2ooooo`;oo`1]00Gooj<0ool0WOoo09goo`2Mooooo`02
oj`0o`?ooooo0ooo0942o`3ojP?ooooo0_oo0;001?oon03oooooooooooooW@06ooooo`;o0?nQ00Co
ok`0oooooooo0;coYOl00_lbo`03ooooo`;oa?l000?ooooool[o0?o:o`001_ooool2oc80o`;oVOl0
1Ol07?l3ooooo`;om?l01Ooo0>H7ooooo`?o2?l000CoolP0oooooooooooooooo0ol0]?l3ool0n003
oooooom_0?ooK`3o00Cooooo00?oon`0o`0Rool08_l00ooo0<P00omYo`3oooooooooo`07ooooo`;o
0?oN00?ooooooi?o0?nCo`000ooo09L00ol0o`Coooooooooo`03ooooo`;o0;[o0_ooR`001Ooooooo
01Koo`0Fool05_oo0?m000Goa03o0oln0?l4ooooo`?o0P3o1oooool3ool0lP;obP3o0_ooool4o`3N
oaoooooo1?mk0?l00oooooooo`3Dool0e002ool0e0Co0?ol4_ooool5od[o00Cooooo0ooX0?l3oe3o
00Co0?mO1OoooolHohOo00GoW`3o00Coooooo`3of?l0omSo0?oH1Ol0Mol3ogGo00oooooo1onno`07
ooooo`Oo^03o5oooool3onko00Go/P3o0oo^o`0Dooooo`006Oooool00ol0003oooooooooo`06oooo
o`0DohOo0?oooooooi40o`3foonC0?ooo`0lo`04oooo0;coV@3oool0/?mk0?oo<P3oolX0oolJ0?oo
o`1>ool0]_oX0?ooo`38ool0n?oo07T2ool0O`0;ool0TOl0FOoom03ook80ool0ooKo^?l0oh40oooo
oooo0=koob`0oooo09L00_ooool01Ooo0=Cood80oom20?oo@P3ooooo00?og03o00Koooooo`2?oooo
oooooooool@0ooooool2ool0N@;ooooo0ooo07l2ool0iPGooooo0_ooK@000oooooooQ`3oohL0o`03
ooooo`Cog03o00?ool80ooooooooool01Oooool01_m4o`3oA03ood@0ooooooooo`2foooV00;ooooo
0_ooCP001?ooE03oo`0loooooonI0?l2o`36o`?o;03o0_oFo`000oooooooNol0og_o0006ooooo`;o
0?l^0_l80?l3ooooo`03oooP0?oo04koo`1>00;oS@3o00Coooooool0KOoo06gooj<00_oo09d01?oo
oooo04Kooj`0oon/0?l3ooooo`;oo`2A0_l0onX3ooooo`;om03o00Coo`2`oooh0?ooU`3ooooo0_oo
W@04ooooo`05oomW0?l0oj7o0?nQoonl0?ooool00_oo0;`2oc;o00Cooooo00Coa?l0ooooooo:o`3o
b_l01_ooool2oc80o`Co01co1?ooool6ool0iP03oooooooj0?oonP3o00Kooooo0ol8o`02ooo800?o
oooo0_l0]?l00oooooooo`3hool0n002ooooo`;oK`3o0_ooool3ooo/00;o02;o0_oo0<P2ofWo00So
oooo0ol0omh00onCo`3oo`2Gool0U`02ool0U`03o`3o1?oooooooooo00Cooooo0_l0^_l00oooR`3o
ooooooooo`02o`0Fo`Coa03o0_ooool3och0o`Cooooo0ol20?l7ooooo`?oo`3b0_o:0?l00ooooooo
0=koo`3No`02o`3Nob3ooooo0omk0?l00oooooooo`3Dool0e002ool0e0Co0?ol4Oooool5od[o00Co
oooo00?oD?l0onP0oooX0?l00_oX0?l2oe3o00Co0?mO2On7o`04onSo00kooooo1_nO0?l01?oooooo
0?oHo`3of?l0omP5o`1go`?oMOl03_ooool6okko00Oooooo1onh0?lEooooo`Ook_l01Onb0?lLoooo
o`006Oooool00ol0003oooooooooo`06ooooo`0DohOo0?oooooooi40o`3foonC0?ooo`0lo`04oooo
0;coV@3ooch0oooo0;3oN`3ooeL0ooo:0?ooo`1>ool0KOoo0;Koo`38o`2Eoooo0?82ool0N@0<ool0
Oooo097o05Wooo@0oooo@P3o0?ofokSo0?n10?oood80o`3Nool/0?ooo`2G0_oo@P000ooo0=Cooooo
ooooo`04ooooo`?og03o0ooo07T01?ooooooo`1oool0Oooo07l2ooooo`03ogD0oooooooooooo00;o
o`3V00Gooooooom]0?ooK@3oooooohL0o`06om`0o`03oooooooo`P3ool8000Oooooo0om40?l00ooo
ooooo`2fool0]P02ooooo`;oodh000GooooooomD0?oo03cooooooiT0o`03ob`0o`03oonA0?oooooo
e_l000?oNol01oooool00ol0obko203oo`P0o`03ooooo`06oooP0?oo04koo`1>oi<0oon=0?oooooo
0_oo06d01?ooooooo`2Mool0WOooool3oj`0o`03ooooool0on[oo`2A00;oo`2A1?ooool3oo@0o`;o
o`2`00CoooP0oooooooooooooid01?ooool2oomW0003o`3oXOoo_03ook`000;oo`2l0_lbo`04oooo
o`;oa?l00_o:o`03ooooo`Co01co00?o<P3oooooooooool00_n/o`000oooooooo`3Vool0iP03ool0
iP04ooCo0?ooooooooooooooo`?onP3o1Oooool3o`So0003oooooooob03oolP000?ooooo0_l0]?l0
0oooooooo`3hool0n002ooooo`;oK`3o00Coooooooo/0?ook03oon`00ol08_l2ool0b003ofWo0?oo
oooooooo00Oooooo0_l0omh01OnCo`3oo`2Gool0Uooo09Oooooo00;o0?l41Oooool3o`2jo`?ooooo
1?o40?l3ooooo`?o?P3o1?ooool3o`80o`Oooooo0ooo0?82olX0o`Co0=ko8?ooool3og/0o`Goo`3D
0ol0oo`Aooooo`GoB_l00_ooool5oe3o00?oj03o0_n7o`04o`3oG`Kooooo1OoXo`0?ooooo`GoW`3o
0_ooool4o`3of0Co07Oo0omeo`0>ooooo`Go__l01_ooool7okP0oaGooooo1oo^o`000ooooooo/P3o
ok80o`04ok80ob7ooooo000Iooooo`03o`000?oooooooooo00Kooooo01OoQol0ooooooooT@3ooooo
oi<0oon=0?ooo`0lool0_?nI0?oo06_oool0/?mk0?ooE`3oolX0oooo04koo`1]ool0]_oo0<SoQ`3o
ool0n?oo0?;o9P3oool0N@03ool0O`09ok80ool0ooKooooooh40oooooooo0=koooooool/0?ooo`2G
00;ooooo00?oo`3Dooooooooool00oooool3ool0N@04oooooooo07ooo`1oool0O`[og03o0_oo0>H3
om`0o`Gooooo0_oo`P07ooooo`;oA03o00GoA?l0oooooooo0;Koo`2fooooo`03oom>0004oooooooo
E03ooe@0ool0?0;oV@3o0oooool01?ooT@3oe_l0og_o0?mko`09ooooo`;o203o0_ooool2oooP00;o
o`1>00?oT`3ooooooon=0?l00_oo06d3ool0W@04oooooon/0?oo[03oooooo`;o0?oZ0_oo0945oooo
o`;om03o00Goooooool0/?oo0;3oooP0oonG0002ooooo`03oonM0?oooooooooo00?oofL00_l0oj40
0ooo_03oYOl0ool0_002oc;o00Cooooo0_o4o`02ol[o00Go01co0_nIo`02oc80o`Koo`3V0_ooool2
ooCo00?ooooo0_oj0?l5ooooo`?o2?l00_ooool2ooo800?ooooo0_l0]?l3ool0n0;ooooo0_m_0?l3
ooo/0004ooooool08_oo02;oooooo`;oo`3800?oJOl0ooooooooool01oooool00ol0omkoo`2Gool0
U`02ool0U`;ooooo0_l0o`@4ooooo`03oon;0?l0^_oo0;[o00?ooooo0oo40?l4ooooo`?o?P3o1?oo
ool3o`80o`Oooooo0ooo0?82olX0o`?o0=ko8Oooool2og/0o`Coo`3D0_l0oa03o`3oo13ooooo1?m:
o`07oe3o0003oooooooX0?ooj03o00;oj03o1Ol0oel5ooooo`Goj?l03oooool5oil0o`;ooooo1?l0
omP5o`1go`?oMOl03_ooool4okko00Gooooo1_nh0?lEooooo`Ook_l00oooool5ok80oaKooooo1?nh
o`0=ooooo`006Oooool00ol0003oooooooooo`06ooooo`0GohOo0?oooooooi40oooooonC0?ooS@3o
ool0??oo0;co04KooiT0oooo0;3oN`3ooc80ooo:0?oo09_oool0C_nO0?ooo`2fool0b?n70?ooo`3b
obH0oonh0?l00ooo07T2ool0O`07o`3om_nho`3oP@3oooooool0g_ooooooool0U`02ob`0o`03oooo
oooo0=Coo`1i00?oo`1i00Coooooool0Oooo07ooo`1o0oooool2ol@0o`Kooooo00CoM@3oohL0oon7
0?oooooo0_oo0>H4ooooo`;ool801oooool2od@0o`05odCo0?ooooooo`2fool0]_ooiP000_ooCP02
ooooo`?o;03o00?oo`0loiT0ool0a_l00oooool00oooT@3oNol0og_o0009ooooo`;o203o0_ooool2
oooP0005oooooooo04kooooooi<0oon=0?l00_oo06d2ool0W@06oonS0?oooooo[03ooj`0ool0A_oo
0?oZ0ooo0944ooooo`?om03o0_ooool00ooo0;3oooP0oonG0002ooooo`;ooid000?ooooooomW0?oo
I`000_ooool01_l0oj7ook`0ojGo0?nUo`3oo`2loc;o00Gooooo1Ol07?l2ooooo`;oVOl01Ooo0>H0
0on/o`3oooooooooo`03ooooo`;om?l00oooool2ooX0o`Gooooo0_l8o`03ooooo`;oolP00oooool2
o`2do`;oo`3h0_ooool3ofl0o`04oaCo0?ook03oooooooooo`;o02;o00?oooooool0b?oo0<P02_oo
ool3ool0U`Gooooo00Go0?l4oooooooooooooooooon;0003o`2jo`03ooooooo40?ooa03o00;oa03o
1?ooool3och0o`Cooooo0ol20?l7ooooo`?oo`3b0oo:0?l00ol0g_ooooooooooo`0Oooooo`;oN`3o
1?oo0=@00ooooooo0?l@o`3o4003o`3oo0kooooo1Om:o`04oe3o00Gooooo0ooX0?l4o`3oG`Gooooo
1OoXo`0@ooooo`CoW`3o0_ooool5o`3of0Co07Oo0omeo`0?ooooo`Co__l01Oooool4okP0oaCooooo
1oo^o`04ooooo`Ko/P3o5?ooool7okSo017ooooo000Iooooo`?o00001_ooool06_n7o`3ooooooonA
0?oooooo0?Kooi<0oooo03co00Coool0_?nI0?oo?P3oool0/?mk0?ooE`3oolX0oooo04koo`1]ool0
]_oo0<So07goool0n?oo0?;o9P3ookP0oooo09goo`2A3Ooo07T00ooo0=Coooooooooo`02ool0O`?o
oooo00?o08ooooooooooool00_ooool01Oo40?ooooooooooooooooooofd000;oQ`3o00?oM@3ooooo
ooooool00_ooool2ool0iP;ool801oooool2od@0o`05oooooom4o`3oo`2fool0]_ooiP000_ooCP00
1?oooooo;03oob`0ool/0?l2ooooo`03ool0??nI0?oooooo00?ooooo0_mko`09ooooo`;o203o0_oo
ool2oooP0005oooooooo04koo`1>oooooonC0?l00_oo06d2ool0W@04oonS0?n/0?oo[03ooj`0o`;o
04Ko0_oo0945ooooo`;om03o0oooool2ool0/006oooh0?ooU`3oooooooooooooW@3ooooo0_ooI`02
ooooo`;o0?nQ0_nUo`02ool0_0Oo01co00Cob_l0oooooooooooooooo1Ooo0>H01?lb0?oooooooooo
oon/o`05ooooo`;om?l00_ooool3ooX0o`Cooooo0ol8o`04ooooo`05ooo80?ooooooooooooooool0
]?l00ooo0?P2ooooo`;oK`3o0_lDo`02ooooo`?o02;o00?oooooool0b?oo0<P02?ooool4ool0U`03
oi?o0?oooooooooo00?ooooo0_l0o`@2ooooo`03oon;0?l0^_oo0;[o00Coa03o0_l05_l3ooooo`?o
?P3o1?ooool3o`80o`Oooooo0ooo0?800ol0g_oobP3oolX0o`0Rooooo`Goo`3D0_ooool2o`3o40?o
0?ol2_ooool3ohOo00CoB_l01?m@o`07ooooo`?oj03o0ol0oel4ooooo`Goj?l04?ooool5oil0o`03
ooooool0omSo0?oH00?o0?oH00?oooooo`1gool0Mol00_l0Mol3ogGo00kooooo1Onno`04ooooo`Go
^03o4Oooool7onko00Kooooo1Onb0?lDooooo`Ko^?l01Oooool6o`3o5Pgooooo000Iooooo`03o`00
0?oooooooooo00Kooooo01ooQol0oooooooooooooi40o`3foonC0?ooo`0lo`04oooo0;coV@3ooch0
oooo0;3oN`3ooeL0ooo:0?oo6P3oool0C_nO0?ooo`2fool0b?oo0?Soo`3bod@0oonh0?oo03Coool0
WOoo097o/P3ooo@0ool0ooKo^?l000_oo`1o1_ooool00ol0Soooooooooooo`02ooooo`04ol@0oooo
K@3oQ`3oohL0o`?ooooo00?oM@3oooooooooool00_oo`P001?ooooooo`3Vool0i_oo0>H3ooooo`?o
A03o00KoooooodCo0?oo0;Koo`2foooV0?ooCP04ob`0o`06oomD0?oooooooooooooooooo03coV@3o
0oooool2og_o00Wooooo0_l80?l01Ol0obkoon00oooP0?ooh03ooooo00;oo`1>0_ooool01OnC0?oo
o`1]ool0WOoo09go0?oZ00;o[03o0_ooool00ol0A_ooo`2Aool0T@04ooooo`?om03o0oooool2ool0
/004oooh0?ooU`3oooooooooo`;ooid00_ooI`03ooooo`Co01co00?oo`2lo`0Lool07?l00oooool2
olCo0003ol[o0?oo0>Koo`3V00?oo`3V00?oVOl0ooooooooool00_lb0?l00ooooooo[?l0ojco0004
ooooo`;om?l00_ooool2ooX0o`Gooooo0_l8o`05ooooo`;oolP00_ooool00ol0]?ooo`3hool0n003
ooooo`;oK`3o00Coon`0oaCo0?oooooooooo0_l08_l2ooooo`;oo`381oooool3ool0U`;o0?oN1_oo
ool2o`3o1003ooooooooR`3o0;[o00Coa03o00Co0?m0o`0Fool05_oo01Ko0_ooool3och0o`Gooooo
0_l20?l7ooooo`?oo`3b00Co0=koolX0ooo:0?oobP3o8?ooool4ool0e0Gooooo0_l0oa02o`3oo0Ko
oooo1_n7o`04od[o00?oD?l02Oooool3onP0o`;o0?mO0oooool5onSo017ooooo1?nO0?l2ooooo`Co
0?oH0_ooool4o`1go`?oMOl03Oooool5okko00Gooooo1?nh0?l?ooooo`Ook_l02?ooool5ok80oa;o
oooo1onho`0;o`3o5PKo6_l03Oooool001Wooooo00?o0000ooooooooool01_ooool08on7o`3ooooo
ooooooooT@3o0?Kooi<0oon=0?ooo`0lool0_?nI0?oo0?nKool0/?mk0?oo<P3oolX0ool0Voooo`1>
ool0KOoX0?ooo`2fo`1moooo0?Soo`3bokP0ool0=?ooon00ool0TOl0:?oom03oo`3om_ooooooP@3o
ooo/0?oooooo0=ko00;ooooo00Goo`2Go`3oj_oooooo;03oool0e007ooooo`03o`2?ooooooooofd0
00;oQ`3o00?oa03oooooooooool01?ooool00ome0?oool80ooooo`05ooooo`?oo`3V0oooool2ool0
]P04oooV0?l/0?oo;03oob`0o`;ooooo00Oooe@0ooooooooooooooooo`36oooo03coV@3o00;ooooo
0_mko`000ooFo`3oooooooooo`06ooooo`;o203o00?o0?l^oooP0?ooh0000oooool01?oo04kooooo
ooooooooool2ool0K@04ool0WOl0on[o[03ooj`0o`;ooooo0ooo0944ooooo`;om03o1Oooool01?oo
0;3oooP0oooh0?ooU`02ooooo`03oonM0?l07?oo01co00Go01co00CoYOl0oooooolbo`3oo`2l0ooo
ool6ool0iP03oooooonIo`3oVOl000?ooooo0_lb0?l00ooooooo[?l0ojco0004ooooo`;om?l00_oo
ool2ooX0o`Cooooo0ol8o`05ooooo`;oolP00oooool2ool0n0;ooooo00Coon`0ofl0oom_0?oooooo
0_lDo`000ooooooo02;oo`0Ro`02ooooo`;oo`381_ooool3ool0U`;o0?oN1oooool2o`3o1003oooo
ooo40?ooa03o00;oa03o0_ooool00ol0od3o01Koo`0Fo`02ooooo`?o?P3o1Oooool3o`80o`Oooooo
0_oo0?801?l0g_oobP3oolX0ooo:0?lPooooo`?oo`3D1_ooool2o`3o40?o0?ol00?oooooohOo0?n7
o`001On7o`02ooooo`CoB_l00_m@o`0;ooooo`?oj03o0_l0oel00oooooooj?l0onSo0003onSo01;o
oooo1?nO0?l2ooooo`Co0?oH00?oooooo`1gool0Mol00ol0Mol3ogGo00cooooo1Onno`06ooooo`Co
^03o3?ooool7onko00[ooooo1Onb0?l@ooooo`?o^?l07?lP0?l=ooooo`006Oooool00ol0003ooooo
ooooo`07ooooo`0RohOo0?oooooooi40oooooonC0?ooS@3oool0??oo0;co04KooiT0ooln0?ooo`2`
og/0oomG0?oobP3ooaX0oooo04koW`3oool0]_oj0?ooo`3hool0l_lV0?oo^03oo`0doooo09goo`2A
ok80oood0?oo0?ofokSo0?n10?ooon`0o`3No`?ooooo00Coo`2Go`3oj_l0on[oo`3D0ol/0?l4oooo
o`?oQ`3o0oooool01?o40?ooooooooooooooool2ooo20003oooooome0?oooooo00Cooooo0_m40?l2
ooooo`?oo`2f0ol/0?l3ooooo`;ooe@00_ooool2o`36o`03ool0??nI0?oooooo00;oNol000?ooooo
omKo0?ooool01_ooool2o`P0o`;o0?l^00Coon00oooooooooooooooo0_oo04h01Ooooooo0?oZool0
KOoo06goS@3o00?o[03o00Cooj<0oooooooo097oo`2A1Oooool2oo@0o`Kooooo00?oo`2`o`0Lool0
7?l01Ol07?l3ooooo`;o0?nQ00GoYOl0oonl0?oo0>Koo`3Vool0_004ool0iP;oa?l000?ob_l0oooo
oonIo`000_nIo`04ooooo`04oc80ooooooooooooojco00Cooooo0_odo`02ooooo`;onP3o1?ooool2
o`So00Oooooo00?oolP0ooooooooool00ooo0?P00oooooooon`0ooo/0002ofl0o`03oooooolDo`3o
5?l000?o02;o00Coooooool0b?oo0<Soo`381Oooool3ool0U`03oi?o0?l0omko0?oN00Oooooo1Oo4
0?l00ol0^_ooooooooooo`02o`3o@0;o01Ko00Cooooooch0ooln0?oo?P3o1Oooool3o`80o`Oooooo
0ooo0?800ooooooobP3oolX0o`0Pooooo`?oo`3D1_ooool2o`3o40?o0?ol1?n7o`04ooooo`03oe3o
0?m:o`3oB_l000;oB_l03_ooool3onP0o`;o0?mO1?oXo`0Cooooo`CoW`3o00?oooooo`3of?l0omP0
0ol0omP00ooooooo07Ooo`1go`02o`1go`?oMOl03?ooool5okko00Kooooo1Onh0?l;ooooo`Gok_l0
3Oooool4ok80oaSo803o00?o0?lFoa[o0?lJo`002?lJo`0Nooooo`006Oooool00ol0003ooooooooo
o`07ooooo`0HohOo0?oooooooi40ooooool0m_ooT`3oool0??l0oh?oo`2loiT0ooln0?ooo`2`og/0
oomG0?oobP3ooaX0oooo04koo`1]onP0oooo0;Ko09Goool0n?oo0?;o^03o0_n70?l02Ooo09goo`2A
ok80oood0?oooooookSo0?n10?ooon`0o`3No`02ooooo`05ool0Uoooooooooooo`3oj_oo0=@00_oo
ool01ol/0?ooQ`3oohL0oon70?oo;03oooooool0Sol01?ooool2ol@0o`03ooo20?oooooooooo00;o
oooo00?oM@3oooooooooool00_m40?l01?oooooo;03oool0]_oo0;H2ob`0o`?oo`3V1?l07?l3oooo
o`04o`36ooooooooo`0looooo`;oNol000?oooooomKo0?oFo`001_ooool2o`P0o`03oooP0?l0obko
on0000?ooooo0_oo04h2o`3ojP03ool0WOoo06goT`3o00;o[03o00?ooooooonS0?oo09400_oo0940
1?l0A_ooooooooooooooool3oo@0o`Cooooo0_l07?l2ool0/005o`0LooooU`3oofL0oomW0?ooW@00
0oooool7ool0iP;oo`2l1?ooool00oo4o`3ob_l0ooooo`02oiWo00Gooooo0_lb0?l00ooooooo[?l0
ojco0003ooooo`;om?l00_ooool2ooX0o`?ooooo0ol8o`07ooooo`;oolP000Coooooool0n?oo0?So
0;Co0oook002ofl0o`;ooooo00?o5?l0o`0Rool08_l00_ooool2ool0b003ofWo0?oooooooooo00;o
oooo0ooo09L2oi?o00;o0?oN1Oooool4ol@0o`04ooooool0^_oo0;[oo`2jo`;ooooo00Go0?m0o`0F
ool05_oo01Koooooo`02och0o`Kooooo0_l20?l7ooooo`04o`3Noooo0?;oo`3booooo`?obP3o7_oo
ool01?mk0?ooo`3Dool0e?oo0=@5ooooo`03ohOo0?l0oa3o0?l@00?o0?ol1_ooool3oe3o00?oB_l0
3oooool3onP0o`;o0?mO0_oXo`0Dooooo`CoW`3o00?oooooo`3of?l0omP00_l0omP2ooooo`Co07Oo
0omeo`0;ooooo`Go__l01_ooool5okP0o`[ooooo1_o^o`04ooooo`[o803o1?nb0?l2ob00o`Kooooo
2_l0oaH5oa[o01gooooo1?me0?l=ooooo`006Oooool00ol0003oooooooooo`07ooooo`0TohOo0?oo
oooooi40ooooool0m_ooT`3oohd0oooo03coo`2loiT0ool0Joooo`2`og/0oolb0?oobP3oo`10oooo
04koo`1]onP0oooo0;Ko203oool0n?oo0?;o9P3ookP0ool0=?ooA03oool0WOoo097oQ`3ooo@0oooo
ooooP@3oooo/0?oooooo0=ko0_ooool01Ooo09OoooooohL0oon70?ooo`3D00;oQ`3o1?ooool8ob`0
o`03ol@0ool/0?oo;03o00;o;03o00?oA03oogD0oom40?l00_l/0?l2ool0]P03oooooom4o`3oonH0
00Cooooo1?oo0>H4o`0Lo`03ool0??ooooooNol000;ooooo00?oe_l0ooooooooT@001?ooool2o`P0
o`;oon0000Ko0?l^ooooooooooooooooo`3oj_oo04h2o`3ojP03ool0WOoo06goo`1]00;o[03o0_oo
ool2ool0T@03ooooool0A_oo04Ko00;ooooo0_od0?l7o`0Lo`03oooooooo0;3oooP000Woo`3V0_l0
oj401Ooooooo<_l0oc;o0?ooooooo`2l00Gooooo00Coa?l0ol[o0?nIo`3oVOl01Oooool2oc80o`03
oooooon/o`3o[?l000?ooooo0_odo`03ooooo`04ooX0ooooooooooooooooo`;o2?l02?ooool2ooo8
0004oooooooo0?Soo`3ho`2do`;oon`000?oooooofl0oom_0?l00_ooool00olDo`3o02;oo`0Ro`02
ooooo`;oo`381?ooool3ool0U`?oTol00_l0omh3ooooo`Coa03o00?oooooo`3o1?ooool00_l0^_l3
ooooo`04o`3o@?l05_oo01Koooooo`?o?P3o1Oooool3o`80o`Kooooo00Go0=koool0l_oo0?;oo`3b
ooooo`02olX0oakooooo00CoN`3oool0e?oo0=Coo`3D0oooool4ohOo00;o0?l@0_l0oo`4ooooo`Co
D?l01?m:o`0?ooooo`?oj03o0_l0oel00ooXo`3oooooooooo`0Cooooo`?oW`3o0_ooool3o`3of003
ooooool0Mooo07Oo00?o07Oo0omeo`0:ooooo`Go__l01Oooool6okP0o`[ooooo1?o^o`0;ob00o`Go
oooo1Onb0?l00ooooooo0?lFo`3o5P09o`3o5P03oa[o0?nho`3o^?l002;ooooo1ome0?lAooooo`00
6Oooool00ol0003oooooooooo`07ooooo`0OohOo0?oooooooooooonA0?l0m_ooT`3oohd0oooo03co
o`2lo`16oonI0?oo?P3oool0/?mk0?ooE`3oolX0oolJ0?ooo`1>ool0KOoX0?ooo`2fo`2Eoooo0?;o
0>CookP0ool0=?ooofd0od@0oooo097o/P3ooo@0o`08ohL0o`05ool0UoooK@3oofd0o`3oj_oo0=@0
1oooool00ooo`P3o08ooooo20004ooooo`04ol@0oom40?ooA03ood@0o`;ooooo00CoM@3oool0]_oo
0;Kooooo0_m4o`04ooooo`;ooe@00oooool01Ol0a_ooo`3Vool0i_oo0>Koo`0l00[o01co0_l80?l0
1?l07?ooon00o`3o;_l0obh3o`3ojP;oo`1>00Oo01coool0WOoo06goo`1]oj`0oonC0?ooS@3o00?o
o`2A1?l07?l3oo@0o`03o`0Looooooooo`3V00Koo`3V00Koo`2`ool0i_oo0>KooiL0ooooooooW@04
ooooo`05ojGo0?l0oj7ooooooonl0?lbo`000_ooool00ooo0;coooooooooo`02ooooo`04ol[o0?nI
o`3oVOl0oiWo00Kooooo00Co<P3ooooooooooooo[?l00_ooool3ooCo00?ooooo0_oj0?l01?oooooo
2?l0o`So0?l8o`09ooooo`04ooo80?ooooooo`3hool0n0;o0;Co0_ooool2ofl0o`;ooooo00?o5?l0
o`0Rool08_l00_ooool2ool0b0?ooooo0ooo09L00oooooooTol0oi?o0002ooooo`03o`3og_oooooo
a03o00?oa03o0oooool2o`3o10;o0;[o0oooool01?l0od3o01Koo`0Fooooool2och0o`Kooooo0_l2
0?l6ooooo`;o0=ko0_oo0?801?oooooobP3oolX0ooo:0?lMooooo`04og/0oooo0=Coo`3Dool0e0Ko
Qol000Coooooo`3o4?l0oa3o0?l@0_l0oo`00oooooooD?l0oe3o0003oe3o00CoB_l04?ooool3onP0
o`;o0?mO5Oooool4oil0o`03ooooool0omSo0?oH00;o0?oH1?l0Mol3ogGo00[ooooo1Onno`05oooo
o`Go^03o2_ooool00oo^o`3o803oob00o`07ob00o`cooooo1?nb0?l6o`3o5PGo6_l00_nho`0Roooo
o`OoM@3o6?ooool001Wooooo00?o0000ooooooooool01oooool09_n7o`3oooooooooooooT@3ooooo
oi<0oon=0?ooo`0lool0_?l0A_ooV@3ooch0oooo0;3oN`3ooeL0ooo:0?oo09_oool0C_oo06goj03o
ool0b?oo0;Koo`3hool0l_lV0?oo^03oo`0doooo`P3oo`2Mool0TOnb0?oom03ooom]0?n10?ooofd0
ooo/0?ooK@3o0=ko0_ooool01_oo09Ooooooooooool0on[oo`3Do`3ojP;ooooo0ooo`P02ooooo`03
o`2?oooooooooooo00?oA03o00Coa03oooooooooCP3oodh00_oo0;H2ogD0o`03odCo0?n1o`3ooooo
00;ooooo0_ooE004ooooo`06o`36oooooooooooooiT0oooo03coNol02_oo0>H2oooP0003ooooool0
7?oo01co00;o01co0_oo04h3ool0W@04ool0KOn/0?oooooooi<0o`;oo`2A0_ooX`02ooooo`03o`16
oooo0>Koo`3V00Goo`3V1Oooool2ool0/005oooh0?ooI`3ooiL0ooooooooW@000oooool01?nUo`3o
0?nQo`3oXOooool2oc;o0003oooooooo0;coo`2l00Cooooo0_nIo`07ooooo`;o<P3o00Coooooojco
0?n/o`3ooooo0_odo`04ooooo`;onP3o0ol8o`0:ooooo`;oolP00_oo0?P2o`2do`?ooooo00CoK`3o
oooooooooooooooo0_l08_l2ooooo`;oo`380_ooool3ool0U`05oooooonCo`3oTol0oi?o0?ooool0
1Oo40?l5ooooo`04o`3o1?l0^_oo0;[oo`2jo`?ooooo0ol05_l00ooooooo?P3ooch0o`05ooooo`?o
0P3o1Oooool3o`3No`;oo`3b00?oooooolX0ooo:0?l07Oooool01?mk0?ooo`3Dool0e?oo0=@3ohOo
00Cooooo0ol0oa03o`3oo0?oD?l00_ooool3od[o013ooooo00Coj?l0onP0oooX0?ooj03o0_l0oelD
ooooo`CoW`3o0_ooool3o`3of004ooooool0Mooo07Ooo`1go`?oMOl02_ooool4okko00Gooooo1Onh
0?l9ooooo`Oo803o4_ooool3ok80o`;o0?lF1_lJo`02okSo02?ooooo1_me0?lOooooo`006Oooool0
0ol0003oooooooooo`07ooooo`0VohOo0?oooooooooooonA0?oooooo0?Kooi<0oon=0?ooo`0lool0
_?nI0?oo?P3oool0/?mk0?oo<P3oolX0ool0@?oo6P3oool0C_oo06goo`38ooX0oooo0;Koo`3bo`3T
oonh0?oo03Coooooool0FOooo`2Mool0TOm40?oom03ookSo0?n10?ooooooooo/0?l0g_l2ooooo`03
ool0Uooooooooooo00;ool8000Coo`3Do`3oj_l0on[o0?oZ1Oooool2od@0o`;ooooo0_ooCP03ool0
]P;ooooo00?oonH0odCo0?me0?l00_ooool2oomD00Cooooo0_l0a_l2ooooo`03oiT0oooo03cooooo
00;ooooo0_oFo`000ooooooooi40ooooo`02o`P0o`03oooP0?l0on[oo`3V00Goo`3V00Coo`1>ool0
WOoo09goo`3V0_oo06d01?oo0>Koo`2Aool0TOoo0947ool0iP_ooooo00?oo`2`oooh0?oon0000_oo
U`001?oooooooid0ooooooooool2ojGo0004o`3oXOoooooo<_l0oc;o00;ooooo00?oo`2loooooooo
ool00_ooool2oiWo00Oooooo0_lb0?l01?oooooo[?l0ojco0?ooool2ooCo00Cooooo0_oj0?l2o`So
00_ooooo00KoolP0ool0n?oo0?Soo`3hooooool0]?l3ooooo`;oK`3o0oooool00ol08_oooooooooo
o`02ool0b004oooooooo09Ooo`2Gool0U`;ooooo0_nCo`04ol@0o`03o`3og_oooooooooo00Gooooo
00?o0?l4o`2jool0^_l00oooool01?l0od3o01Koo`0Fooooool3och0o`Gooooo0_l20?l5ooooo`?o
0=ko0ooo0?800ooooooobP3oolX0o`0Looooo`Coo`3D00?oQol0ooooooooool01?ooool3o`3o4003
ooooool0ooco0?ol00;oD?l00oooool3od[o013ooooo00Coj?l0onP0oooX0?ooj03o0_l0oelDoooo
o`?oW`3o0_ooool4o`3of004ooooool0Mooo07Ooo`1go`?oMOl02Oooool4okko00Kooooo0onh0?l7
ooooo`Oo803o00?ok_l0ooooooooool04Oooool00ol0oaKo/P3ook80o`02ok80o`?o6_l00onho`0U
ooooo`GoM@3o9Oooool001Wooooo00?o0000ooooooooool01oooool08On7o`3oooooooooooooT@3o
ooooo`3foonC0?ooS@3oool0??oo0;co04KooiT0ooln0?ooo`2`og/0oomG0?oobP3ooaX0oooo04ko
o`1]onP0oooo0<So203oool0]_oo0?;o9P3ookP0ool0=?ooooooo`1Ioooo09goo`2Aod@0o`02oo@0
o`04oh40oooo`P3oon`0o`3No`;ool8000?oo`2Gooo20?ooool00_ooool00ooo0=Coooooooooo`02
o`3ojP?oA03o00Coodh0o`2?ooooCP3oodh00_oo0;H2ooooo`04ol@0ooooiP3oA?l0odCo00;ooooo
00?oM@3ooomD0?ooool00oooool2o`36o`;ooooo00?oNol0oiT0oooo03`00oooool01?oFo`3ooooo
ooooooooT@02o`P0o`?o0?oZ00?oooooo`3o;_ooool00_ooool2ool0CP05ool0WOn/0?oo[03oool0
KOooool00_oo09401OnC0?ooS@3oooooooooX`3ooooo00;om03o00?o04Koooooooooool02Oooool0
1OooI`3oo`2`oooh0?oooooooiL000;ooooo00Cooid0oooooonUo`3oYOl00_l0oj42oc;o00?ooooo
00Coo`2loooooooooooooooo0_nIo`000oo4o`3oooooooooo`05ooooo`05oc80ooooooooooooojco
0?ooool00_odo`04ooooo`;onP3o0_l8o`0;ooooo`03ooo/0?oo0?Soo`3h00;ooooo0_l0]?l2oooo
o`;oK`3o0oooool2o`0Ro`03oooooooo0<Soo`3800?oo`2G0_ooool00onCo`3oa03ool@0o`02ol@0
o`03ooooool0omko0?oN00Sooooo0_l0^_l3ooooo`04o`3o@?l05_oo01Koooooo`;o?P3o1_ooool2
o`80o`Cooooo0ol0g_l01?ooooooo`3bool0l_ooool3olX0oa[ooooo00CoQol0ool0e?oo0=Coo`3D
2Oooool2o`3o4005oooooom@o`3o0?olo`3oo?m@o`000oooool3od[o013ooooo00Coj?l0onP0oooX
0?ooj03o0_l0oelCooooo`CoW`3o0_ooool3o`3of003ooooool0Mooo07Oo00;o07Oo0_meo`08oooo
o`Go__l01oooool3okP0o`?ooooo1olP0?l3onko01;ooooo00Co6_l0o`3o5_l0oaKo0?lF0onb0?l5
okSo02Gooooo1Ome0?lZooooo`006Oooool00ol0003oooooooooo`08ooooo`0GohOo0?oooooooi40
ooooool0m_ooT`3oohd0oooo03coo`2lo`16oonI0?oo?P3oool0/?mk0?oo0P3oolX0ool0@?oo6P3o
ool0C_nO0?ooo`38ooX0ool80?l00_oo0;H02_nh0?oo03Coog_o0?l0FOooooooool0WOoo097o0?of
oooooood0?l2od@0o`05ooooool0g_ooodh0oom>0?oo09L00oooCP000om40?ooo`3Dod@0o`02od@0
o`?o0?oZ0_ooool2ool0]P?ooooo0_ooiP000oo40?ooPOl0ooooo`02oomD0003oooooome0?oooooo
00;ooooo00?o0<Koooooooooool00_mko`000onI0?ooo`0looooo`02ooooo`03omKo0?ooooooon00
00;o203o0_l0onX3ooooo`06o`3o;_oooooooooooooooooo04koo`2M0_n/0?l2ool0K@;oo`2A00Go
oooooi<0oooooooooooooonS0002oo@0o`03ooooool0A_oooooo00Wooooo00KoofL0ool0/?oo0;3o
ooP0ooooooooU`02ooooo`?oYOl000Goooooo`3oXOoooooo<_l0oonl0003ooooo`03ool0_?oooooo
oooo00;oVOl000?oooooolCo0?ooool01Oooool2oc80o`03oooooon/o`3o[?l000;om?l01?ooool2
ooX0o`03o`So0?oooooooooo00[ooooo00?oon`0ool0n?oo0?P00_ooool2o`2do`;ooooo0_m_0?l3
ooooo`;o02;o00?o5?l0oooooooo09L00_oo09L00oooooooa03ool@0o`03ol@0o`Cooooo00?o0?oN
ooooooooool01_ooool2o`2jo`?ooooo0ol05_l00ooooooo?P3ooch0o`06ooooo`;o0P3o0_ooool4
o`3No`05oooooooo0?;oo`3bool0l_ooool00_o:0?lJooooo`Coo`3D2Oooool3o`3o40;oD?l00_l0
oo`3ooooo`?oB_l04?ooool01?oXo`3oj03oonP0oooX0?l2o`3oGa?ooooo0onO0?l2ooooo`Co0?oH
00Coooooo`1gool0Mooo07Oo0omeo`07ooooo`Co__l02?ooool4okP0o`Ko803o1Oo^o`0@ooooo`;o
6_l01Ol0oaH4ok80o`;o^?l09_ooool5ogD0oboooooo000Iooooo`03o`000?oooooooooo00Sooooo
023oQol0ooooooooT@3oooooo`3foonC0?ooS@3oo`04oooo03coo`2loiT0ooln0?ooo`2`og/0oolb
0?oobP3oo`10oolJ0?ooo`1>ool0KOoX0?ooo`38o`2Eool80?ooo`3bool0]_nh0?oo03Coog_o0?l0
FOoo02Soool0W@;oo`2A00?ooooooo@0ooooool01Om40?l00ooo09OoA03ood@0o`02ooooo`03ool0
e?oooooooooo00?ooooo0_oo0;H02_l0on[o08ooooooooooooooonH0oooooom4o`3oPOl0ol@0oooo
E004ooooo`03ogD0ool0a_oo0<Ko00?oNol000?ooooooiT0oooo03`00oooool01OoFo`3o0?oZo`3o
j_l80?oo0?oZ00Cooooo0_l0obh01_ooooooo`2Mool0C_oo04ko[03oooooo`;oo`1]0_oo0942oooo
o`03oi<0oooooooom03o00;om03o0_ooool00ol0A_ooooooooooo`07ooooo`;oofL000Koo`2`oooh
0?oon03ooooooonG0?ooool2ojGo00?ooooo00?o0?nQoc;o0?lbo`000oooool2ool0_0?oVOl000?o
b_l0olCo0?o4o`001_ooool01?lb0?oooooooooooon/o`02ooCo00Cooooo00?o2?l0ooX0ool8o`00
2oooool2ooo/00;oo`3h0oooool00ol0]?ooooooooooo`02ofl0o`?ooooo0_l08_l01?lDo`3oo`2G
ool0Uooo09L4ol@0o`03oi?o0?oooooooooo00Cooooo0_l0omh7ooooo`;o0;[o0oooool2o`0Fo`04
ooooooln0?oo?P3ooch0o`Kooooo0_l20?l01?oooooo0=koo`3Nool0g_l3ooooo`;oo`3b00Cooooo
olX0ooo:0?oobP3o6?ooool01On7o`3oo`3Dool0e?oo0=CoN`3o00Wooooo0ol0oa02oe3o0003oooo
ool0ooco0?ol00;ooooo0om:o`0@ooooo`;oj?l00_oX0?l2o`3oGa?ooooo0onO0?l2ooooo`?o0?oH
0_ooool3o`1go`;oMOl02?ooool3okko00Sooooo00Co803ookP0oonh0?oo^03o0olP0?l3ooooo`Co
k_l04?ooool2oa[o00Go0?lF00?ooooookSo0?nb0?l00_nb0?l00onho`3oooooooooo`0Sooooo`Ko
M@3o=?ooool001Wooooo0ol00008ooooo`0JohOo0?oooooooooooonA0?oooooo0?Kooi<0oon=0?oo
o`0lool0_?l0A_ooV@3ooch0oooo0;3oN`3ooeL0ooo:0?oo09_oool0C_oo06goj03oool0b?oj0?oo
09Goool0l_l0i?l2ool0]P04ooooool0FOoooooook80o`;oo`2M00Koo`2AokSo0?od0?ooooooooo/
0?l0g_l3ooooo`;oo`2G0_ooool01?oo0=Coooooooooooooool2ool0]PCooooo00?o08ooo`3oj_l0
onX01?l0onX2ol@0o`;ooooo0_l0a_l01?me0?oo0?oZo`3oj_l0onX2oiT0o`03ool0??l0on[o0?oZ
00?o0?oZ0_l80?l5ooooo`06o`3o;_oo09goo`2Mool0WOoo04ko[03o0_ooool00ooo06goo`2Aoooo
o`03ooooo`03oi<0oood0?oom03o00Cooooo00?o04Koooooooooool01_ooool2oomW0003oooooooo
0;3oooP000;ooooo00CooiL0ojGo0?nUo`3ooid00_ooool2o`3oX@03oc;o0?oo_03ooooo00;ooooo
00Ooo`2loiWo0?nIo`3ooooool[o0?ooooooa?l000Oooooo00Go<P3ooooooon/o`3o[?l0ooCo0003
ooooo`;o2?l00_oj0?l:ooooo`?oon`00_oo0?P3ooooo`;o0;Co00?oooooofl0oom_0?l00oooool2
o`0Ro`?oo`2G00Coo`38ol@0ooo40?oooooo0_nCo`06ooooo`;o0?oN1oooool2o`2jo`03o`3o1?oo
oooooooo00;o01Ko00?ooooooch0ooln0?l01oooool2o`80o`?o0=ko1?ooool2ool0lP03ooooooo:
0?oobP3o01Oooooo00?oQol0ool0e?oo0=@00_oo0=@2og/0o`Sooooo0ol0oa02oe3o0005ooooool0
ooco0?olo`3oo?ooool00om:o`0@ooooo`;oj?l00ooX0?l00ol0oeooooooooooo`0@ooooo`CoW`3o
0_ooool3o`3of0;ooooo0ol0Mol2ogGo00Sooooo0onno`03ooooo`Ko803o0onh0?l4ooooo`Gok_l0
3oooool00olJo`3o0?lFo`3o5P04o`3o5P;ooooo00?o^?l0ok80oonb0?l00_nb0?lTooooo`GoM@3o
>_ooool001Wooooo00?o0000ooooooooool02?ooool0:On7o`3oooooooooooooT@3oooooo`3foonC
0?ooS@3oool0??oo0;co04KooiT0ooln0?ooo`2`og/0ool20?oobP3oo`10oolJ0?ooo`1>ool0KOoX
0?ooo`38ooX0ool0D_ooo`3bobH0oonh0?ooo`2fooooool0FOoo02Sook80oonIo`3oo`2Mool0TOnh
o`3om03oooooooook03o0=ko00Cooooo00Koo`2Gooooooooooooo`3Doooooooo0;H4ooooo`;oonH0
00Coooooo`2?oon1o`3ooe@00oooool2o`3ojP;oa03o00So0?oZooooooooooooM@3ooooooonI0?oo
ooooool0?0;oon0000Goe_l0ooooool80?oo203ooonA0005ooooo`;oo`2M00Go[03oool0C_oo04ko
ooooool0T@02ool0K@Gooooo0_od0?l00oooX`3oooooooooo`02ooooo`03o`16oooooooooooo00Go
oooo0_ooI`001_ooooooo`2`ool0/?oon03ooooooonG00;oYOl000KooooooonM0?ooooooooooo`3o
XOlbo`02oonl00?ooooo00?oo`2loiWo0?ooool00_o:o`000oooooooa?l0ooooo`05ooooo`;o<P3o
0_n/o`001?odo`3oooooooooooooool2o`So00;onP3o2_ooool2ooo/0004oooooooo0?Soo`3hooo8
00;ooooo0_l0]?l2ooooo`05ofl0ooooooooooooooooool08_l00ooo09L00oo40?ooo`38ooooo`02
ooooo`;oTol01_ooool2o`3ogPOooooo0_l0^_l2o`3o1004ooooool05_oo01Koooooo`;o?P3o1_oo
ool3o`80o`;o0=ko1?ooool3ool0lP03ooooooo:0?oobP3o01Kooooo00GoQol0ool0e?oo0=Coo`3D
ooooo`02og/0o`Wooooo0_l0oa02oe3o00;ooooo0_l0oo`01?ooooooB_l0od[o0?m:o`0@ooooo`;o
j?l00ooX0?l00ol0oeooooooooooo`0@ooooo`?oW`3o0oooool3o`3of0;ooooo0ol0Mol00omeo`3o
ooooooooo`06ooooo`?o__l01olP0?l2ooooo`Co^03o0oooool4onko00oooooo00?o6_l0o`3o5_l0
oaH00ol0oaH4ooooo`;o^?l00onb0?lRooooo`KoM@3o?oooool001Wooooo00?o0000ooooooooool0
2?ooool07On7o`3oooooooooooooT@3oooooo`3foonC0?ooS@3oo`04oooo03co04KooiT0ooln0?oo
o`2`og/0oolb0?oobP3oo`10oolJ0?ooo`1>ool0KOoX0?ooo`38ooX0ool0ojOoo`3bo`P0oonh0?oo
03Co00?oo`2f00Ko/P3oooooool0ooKoo`2Mool0TOn10?l2oo@0o`03ooooool0g_oooooo00;ooooo
00?oo`2fool0Uooo0;H00_oo0;H3ooooo`;oonH000GoooooodCo0?m4o`3oPOl0o`2?o`03ooooo`;o
Nol00_l0a_l00oooooooa03oooooo`02ooooo`06oiT0ooooooooon00ool0??ooooooe_l00_l80?l2
ooooo`03oonA0?oooooooooo00?oo`2M0_n/0?l00ooo04koooooool0T@02ool0K@Cooooo0ood0?l0
0ooooooooj<0ooooo`02ooooo`;o04Ko1_ooool2oomW00;ooooo00Coo`2`oooh0?oon03ooooo0_nU
o`001?oooooooid0oonM0?ooool2o`3oX@05oc;o0?oo_03ooooooooooonIo`000_oo0;`00ooooooo
b_l0ol[o0002ooooo`03olCo0?oooooooooo00Cooooo00?o<P3ooooooon/o`000_odo`02ooooo`;o
2?l00_oj0?l9ooooo`?oon`000Coooooool0n?oo0?SoolP00oooool00ol0]?ooooooooooo`02ofl0
o`;ooooo0ooo09L01?o40?oo5?l0ool0b?oo0<P2ooooo`;oTol01oooool00ol0omkoooooooooo`04
ooooo`06oon;0?l0^_oo0;[oooooool0o`Cooooo0_l05_l00ooooooo?P3ooch0o`06ooooo`;o0P3o
0_l0g_l5ooooo`;oo`3b0_ooool2olX0oaGooooo1?oo0=@01?ooooooN`3oog/0oomk0?l9ooooo`;o
0?l@00CoD?l0oooooooooooooooo0_l0oo`3od[o013ooooo0_oXo`03onP0o`03o`3oGooooooooooo
013ooooo0onO0?l3ooooo`?o0?oH0_ooool3o`1go`03ogGo0?oooooooooo00Gooooo1olP0?l6oooo
o`?o^03o0oooool4onko00gooooo0_lJo`05o`3o5PGooooo0_nho`04ok80ob3ooooo1Ome0?lboooo
o`Ko0?nd3Oooool001Wooooo00?o0000ooooooooool02?ooool08?n7o`3oooooooooooooT@3ooooo
o`3foonC0?ooS@3oo`04oooo03coo`2lo`16oonI0?oo?P3oool0/?mk0?ooE`3oolX0ool0Vooo6P3o
ool0C_oo06goj03oool0b?oj0?oo05;oool0l_lV0?oo^03oo`0doooooooo05Wo1Ooo0;H2ool0T@03
oooP0?oo0;Koo`2f00?oo`2f0_ooool01?oo09Oooooooooooooo0=@2oooV00;ooooo00?oA?l0oh7o
0?ooool00_ooool00ol0SoooNol0og_o0002o`36o`Cooooo0_o40?l01OnI0?ooon00ogD0oooo03co
oooo00;o203o0oooool01OooT@3oooooool0WOoo09go0?l^00;o[03o0_oo04h2ool0T@03ool0KOoo
oooooooo00;ooooo0_od0?l01?ooooooT`3oooooooooX`03ooooo`03o`16oooooooooooo00?ooooo
0oooI`03ooooo`03ool0/?oon03oYOl000;oYOl00_ooool02?ooW@3oooooooooool0oj7o<_l0oooo
oooo_03ooooo0_nIo`001?oo0;coooooooooooo:o`02ooooo`;oa?l01Oooool2oc80o`;o[?l000?o
m?l0ooooool8o`000_l8o`02ooX0o`Wooooo0_ook002ooooo`;oo`3h00Coooooooo80?oooooooooo
0_l0]?l01?ooooooK`3oofl0ooo40?l3ool0U`03o`0Roooooooooooo00;oo`380_ooool2oi?o00Oo
oooo0_l0omh5ooooo`04oon;0?l0^_oo0;[oooooo`;o0?l40_l05_l2ooooo`03och0oooooooooooo
00Cooooo0_l20?l00ol0g_ooooooooooo`04ooooo`;oo`3b0oooool00oo:0?ooooooooooo`0Boooo
o`?oo`3D0_ooool3og/0o`Wooooo0ol0oa04ooooo`;o0?ol0_m:o`0@ooooo`?oj?l00_oX0?l00ol0
oeooooooooooo`0@ooooo`?oW`3o0oooool3o`3of0;ooooo0ol0Mol5ooooo`Ko803o00?o__l0oooo
ooooool01_ooool4okP0o`;ooooo1?o^o`0<ooooo`;o6_l01Ol0oaH6ooooo`?o^?l00onb0?lNoooo
o`KoM@3o<_ooool5o`3o]1?ooooo000Iooooo`03o`000?oooooooooo00Wooooo02?oQol0oooooooo
T@3oooooo`3foomSo`3oT`3oohd0oooo03coo`2lo`16oonI0?oo?P3oool0/?mk0?oo0P3oolX0ool0
@?oo6P3oool0C_nO0?ooo`1]ool0b?oj0?oo05;oool0l_oo0?So^03oo`0dooooI`3o05Woooooool0
:?oo/P3oog_o0002ool0]P05ool0WOoo097oo`2Aoo@0ooooh0000_l0g_l2ooooo`09oooV0?oo09Oo
onH0oooooooo0=CooooooomD0?m4o`3oPOl000;ooooo0_mko`000ooooooo08ooo`36o`04ooooo`?o
on0000CoV@3ool@0ooo40?ooo`0l0_me0?l4ooooo`?oo`2M0on/0?l01?ooooooo`1>ool0TOoo0942
ool0K@;ooooo0ood0?l2ooooo`03oi<0ooooX`3ooj<000?ooooo00?o04Koooooooooool00_ooool2
oomW00Cooooo0_oo0;02ojGo0005ooooooooU`3oooooooooooooW@000_ooool00ol0oj7ooooooonl
0003oiWo0003oooooooo0;cooooo00;ob_l00_ooool00oo4o`3oooooooooo`04ooooo`05oc80oooo
oooo[?l0ooCo0?ooool00_l8o`000ooooooonP3oooX0o`08ooooo`?oon`000Goooooool0n?oo0?So
o`3hooooo`02ooo800;ooooo00Co0;Coooooooo40?ooa03o0ooo09L2o`0Ro`?ooooo00?oo`38ofWo
0?nCo`000_nCo`07ooooo`;o0?oN1Oooool00oooR`3o0;[oo`2jo`02ooooo`03o`3o@?l05_oo01Ko
00;ooooo0_ln0?l4ooooo`03o`3Nool20?oo0P3o00Oooooo0_oo0?83ooooo`;obP3o4_ooool3ool0
e0?ooooo0_mk0?l9ooooo`03oe3o0?l0oa3o0?l@00Gooooo0_l0oo`00om:o`3oooooooooo`0>oooo
o`?oj?l00ooX0?lBooooo`?oW`3o0oooool3o`3of003oooooomeo`3o07Oo00;o07Oo1?ooool4ob00
o`Co__l02?ooool3okP0o`;ooooo1?o^o`0;ooooo`?o6_l01?l0oaH6ooooo`Co^?l01?nb0?lLoooo
o`GoM@3o<oooool5o`3o]0Oooooo1?n10?l=ooooo`006Oooool00ol0003oooooooooo`09ooooo`0^
ohOo0?oooooooooooonA0?oooooo0?Kooi<0oon=0?oo0?n3ool0??l0A_ooV@3ooch0oooo0;3oN`3o
oc80ooo:0?oo043ooaX0ool05_ooo`1>onP0oooo06goo`38ooX0ool0D_ooo`3bobH0oonh0?oo03Co
ooooool0FOoooooook80oooooooo0?ofog_o0?l8o`3oo`2Moooooooo097om03ooooP0?oooooo0=ko
oooV00;ooooo00Koo`2GoomD0?ooE03oo`3DodCo0?n1o`03og_o00;ooooo0_l0a_l00ol0Soooon00
oooP0002oooP00;ooooo00GoV@3oooooooooooooo`0lol@0o`02ooooo`04ogD0oooo09goo`2Mool0
W@?o[03o00Go0?l^oooooooo04koo`1>ooooo`02ool0K@04oooooood0?oom03ooo@0o`Cooooo00?o
T`3ooonS0?ooool00oooool00ol0A_ooooooooooo`03oomW00Gooooo00?oo`2`ojGo0?nUo`000_oo
ool01OooU`3oooooooooooooW@3ooooo00;o0?nQ00?ooooooiWo0?nIo`000oooool00ooo0;cooooo
ol[o0003ooooo`03olCo0?oooooooooo00?ooooo0_lb0?l2ojco0004ooooool8o`3o2?l0ooooo`;o
nP3o1oooool3ooo/00;ooooo0_oo0?P3ooooo`03ooo80?oooooooooo00?oa03o0ooo09L00ooooooo
02;oo`0Ro`03ooooo`;oo`380_nCo`09ooooo`03o`3og_oooooooooo00?ooooo00?ooh/0o`2jool0
^_l00_ooool00ol0od3o01Koo`0Fo`02ooooo`;o?P3o0_ooool3o`3No`;o0P3o1oooool2ool0lP?o
oooo0_o:0?lAooooo`?oo`3D1?ooool2og/0o`Sooooo0_m@o`02o`3o40Cooooo00?oB_l0o`3oo?l0
oo`04?ooool3onSo0003o`3oGooX0?ooj03o01;ooooo0onO0?l3ooooo`?o0?oH00?oooooogGo0?l0
Mol00_l0Mol3ooooo`Co803o00Cooooookko0?nno`3o__l02?ooool4okP0o`Gok_l02_ooool4oa[o
00Co0?lF1Oooool5okSo0004oooooonb0?oo/P3ook80oa_ooooo1Ome0?lcooooo`Go0?nd1oooool5
oh40oa7ooooo000Iooooo`03o`000?oooooooooo00Wooooo02OoQol0oooooooooooooi40ooooool0
m_ooT`3oohd0ool01?ooo`0lo`2Qool0A_ooV@3ooch0oooo0;3oN`3ooeL0ooo:0?oo043ooaX0oomM
0?ooo`1>onP0oooo06gonP3oo`1Boooo0?;oo`3hokP0ool80?ooofL0o`1Ioooooooo02Sook80oooo
oooo0?ofo`So0?mko`000_oo09d2ool0T@;om03o00Wo0=kooooP0?mko`3oNol0ool0Uom4o`3oNol0
ool0e?mko`000oooool2o`36o`?oon0000Co08oooooooooooooooooo0_nI0?l2o`P0o`04ool0??oF
o`3ooooool@0o`;oo`2M0_n/0?l2ooooo`;o0?l^00Goo`2Aool0C_ooooooooooool0K@03oo@0o`Ko
oooo00?oS@3ooi<0ooooool00oooool01?l0A_oooooooomW0?ooI`07ooooo`03ool0/?nUo`3ooooo
00;ooooo00OooiL0oooooooooooooid0ooooool0oj7ooooo00;oVOl01?ooool00ooo0;cob_l0ol[o
0003ooooo`03olCo0?oooooooooo00?ooooo00?o<P3ooooooon/o`000ol8o`000ooooooonP3oooX0
o`07ooooo`;oon`00oooool2ool0n0?ooooo1Oo40?l3ool0U`?ooooo00Co02;ooooooooooooooooo
0_oo0<P00olDo`3oTol0ooooo`08ooooo`;o0?oN1?ooool00oooR`3o0;[oo`2jo`02ooooo`;o0?m0
00?o01Koooooooooool00_ln0?l01Ooooooo0=koo`3Nool0g_oooooo00;o0P3o1_ooool3ool0lP?o
oooo0_o:0?l@ooooo`?oo`3D1?ooool3og/0o`Oooooo0om@o`02o`3o40Cooooo00?oB_l0o`3oo?l0
oo`03oooool3onSo00;o0?mO0_oX0?lBooooo`;oW`3o0oooool3o`3of003oooooomeo`3o07Oo00;o
07Oo0_ooool4ob00o`03oooooonno`3o__l000;o__l02?ooool3okP0o`Cok_l02_ooool4oa[o00Go
0?lF1?ooool5okSo00?ooooo0onb0?lIooooo`GoM@3o<_ooool6o`3o]0Oooooo1On10?lFooooo`00
6Oooool00ol0003oooooooooo`09ooooo`0]ohOo0?oooooooooooonA0?oooooo0?Kooi<0oon=0?oo
00Coool0??oo0;co04KooiT0ooln0?ooo`2`og/0ool20?oobP3oo`10oolJ0?ooG@3oo`3o^_oo04ko
o`1]ool0b?oj0?oo05;oool0l_lV0?oo^03oo`P0ooooiP3o05WooooV0?l0:?oo/P3ooooV0?l0ooKo
2?l0okSo0?n10?oooe@0ool0WOoo097oNol000;om03o00Coon00odCo0?ooh03oo`2G0_ooh002ool0
e003oooP0?l0a_oooooo00Gooooo00?o08oooooooonI0?l00_l80?l00oooooooo`0lomKo0003ool0
W@05oj`0ooo40?ooa03ool@0oome0?l00_oo0942ool0CP04oo@0oooo06goo`1]oo@0o`Sooooo00?o
S@3ooi<0ooooool00oooool00ol0A_ooofL0oomW0007ooooo`03ojGo0?oo0;3oooP000?ooooo00Ko
oiL0oooooooooooooid0oc;o0?l0oj42oiWo0003oonl0?oooooooooo00;ooooo00?oo`2lol[o0?oo
ool00_ooool2olCo00Gooooo00Co<P3oojco0?l8o`3o2?l00_ooool2ooX0o`Kooooo0oook003oooo
o`;oo`3h00?ooooool@0ooo40?l00_o40?l2ooooo`04o`2doooo09Ooo`2Gofl0o`?ooooo0_l08_l3
ooooo`03ool0b?lDo`3o5?l000Wooooo0_l0omh4ooooo`03oon;0?l0^_oo0;[o00;ooooo0_l0od02
o`0Fo`;ooooo00Co?P3oo`3Nool0g_oo0=ko0_ooool2o`80o`Kooooo0_oo0?84ooooo`;obP3o3ooo
ool3ool0e0Gooooo0_mk0?l7ooooo`?oD?l000?oooooo`3o4?l0oa000oooool2od[o00;o0?ol3_oo
ool3onSo0003ooooool0oeooj03o00;oj03o4Oooool3oil0o`?ooooo0_l0omP00oooooooMOl0o`1g
o`02o`1go`03oooooolP0?oo803o00;o803o0_ooool3okko00Sooooo1?nh0?l3onko00_ooooo0olJ
o`04o`3o5PCooooo1Onho`05ooooo`?o/P3o5_ooool6ogD0oc;ooooo1Ol0ok@8o`04o`GoP@3o3_l0
1?l=ooooo`006Oooool00ol0003oooooooooo`09ooooo`0OohOo0?oooooooooooonA0?oooooo0?Ko
oi<0oolP0?ooS@3oo`3Hoooo03co04KooiT0ooln0?oo0?oBool0/?lb0?oobP3oo`10ool0Vooo6P3o
oed0oooo04koj03oool0KOl0UOoonP3oool0l_oo0?So^03oo`0do`02o`P0o`09o`1Iool0;_oo/P3o
oomD0?l0ooKoVOl0o`So0?nho`3oP@3o00;ooooo0_oo09401_m4o`3om03ooh7o0?n1o`3oooooool0
U`;ooooo00?o0<Koool0e?ooool01oooool01OnI0?oo203ooooooooo09goo`0l00;oo`2M00Co[03o
oooooooooooooooo1?oo09400oo40?ooo`1>oo@0o`02ool0K@[ooooo00?ooj<0oi<0ooooool00_oo
ool00oooI`3o04KooomW0007ooooo`;oYOl000?oo`2`oooh0?ooool00_ooool01?ooU`3ooooooooo
oolbo`02o`3oX@03oooooooo_03ooooo00Cooooo00?oo`2lol[o0?ooool00_ooool00oo4o`3ooooo
ooooo`03ooooo`;o<P3o0_l8o`03ooooo`03ooX0oooooooooooo00?ooooo0oook004ooooo`;oo`3h
0oo40?l01?ooooooolP0ooo80?ooool3ool0U`04ofl0ooooooooooooooooo`;o02;o0oooool2ool0
b003oaCo0?oooooooooo00Sooooo00?o0?oNooooooooool00_ooool00oooR`3o0;[oo`2jo`02oooo
o`;o0?m00_l05_l01Ooooooo0=kooch0ooln0?oo0=ko00Cooooo00?o0P3oooooooooool01?ooool2
ool0lPCooooo0_o:0?l>ooooo`?oo`3D1_ooool2og/0o`Kooooo0om@o`001?oooooo0?l@o`3o4?l0
oa03ooooo`;oB_l00_l0oo`=ooooo`?oj?l000?oooooo`3oGol0oel00_oX0?lBooooo`;oW`3o0ooo
ool3o`3of004ogGo0?l0Mooo07Ooo`1go`Co803o0_ooool4okko00Sooooo0onh0?l3onko00_ooooo
1?lJo`03o`3o5P?ooooo1Onho`07ooooo`?o/P3o5?ooool5ogD0ob;ooooo1_m_o`0Eo`04o`?ooooo
1On10?l=ooooo`Ko/_l03Oooool001Wooooo00?o0000ooooooooool02_ooool00on7o`3ooooooonA
0002ooooo`0To`3foonC0?ooS@3oo`3oPooo03co0:7oo`16oonI0?oo?P3oool0/?mk0?ooE`3oolX0
ool0@?oo6P3ooed0oonO0?ooo`1>ofT0oooo06gonP3oool0l_oo0?So9P3ookP0ool0=?ooooooo`P0
oooooooo02Sook80oooooooo0?ofoiWo0?l8o`3oP@3o0_ooool00om4o`3oo`2Mool0T@02ool0T@05
oo@0ooooooooooooool0Uol0a_l00_ooool00ooo0=Coooooooooo`03ooooo`03o`P0oooo09goo`2M
00;oo`2M00?oo`0loj`0ooooool01Ooo09400ooooooo0?l^oo@0o`02ool0CP03ol@0oooo06gooooo
00[ooooo00Cooj<0oi<0oooooooooooo0_ooI`000ol0A_ooooooooooo`05ooooo`;oYOl000?ooooo
ool0/?oon0000oooool01OooU`3ooooooiWo0?lbo`3o0?nQ00;ooooo00?ook`0ooooooooool00ooo
ool00ooo0;cob_l0ooooo`02ooooo`03olCo0?oooooooooo00?ooooo00?o<P3oo`So0?l8o`000ooo
ool2ooX0o`?ooooo0oook003ooooo`;oa03o0_oo0?P00oo40?ooooooooooo`02ooooo`05ooo80?oo
ooooo`2Gool0Uol0]?l00_m_0?l3ooooo`04o`0Rooooooooooooooooo`;oo`3800?oJOl0oaCo0?oo
ool02?ooool2o`3ogPCooooo0_l0^_l2ooooo`;o0?m00_l05_l2o`3No`;o?P3o1Oooool2o`80o`Go
oooo0_oo0?85ooooo`03olX0oooooooooooo00_ooooo0ooo0=@7ooooo`;oN`3o1_ooool2oe3o00;o
oooo0_l0oa03ooooo`?oB_l00_l0oo`=ooooo`;oj?l000Coooooo`3oGol0oeoo0?mO0_oX0?lAoooo
o`?oW`3o0oooool2o`3of004ogGo0?l0Mooo07Ooo`1go`?o803o0oooool3okko00Wooooo0onh0?l3
onko00_ooooo0olJo`04o`3o5P;ooooo1?nho`09ooooo`?o/P3o4Oooool6ogD0oaKooooo3Om_o`0:
o`04o`Kooooo1Ol0ok@8ooooo`GoP@3o4_nbo`0Cooooo`006Oooool00ol0003oooooooooo`0:oooo
o`0OohOo0?oooooooooooonA0?oooooo0?Kooi<0oon=0?oo5?l0ool0??oo0;co04KooiT0ooln0?oo
o`2`og/0ool20?oobP3oo`10oolJ0?oo0?nEoed0oonO0?ooo`1>ofT0oooo06gonP3oool0l_oo0?So
^03oo`0do`02ooooo`0;o`P0oooooooo02Sook80oooooooo0?ofoiWo0?l8o`3oP@3oodCo0?ooool0
0_n1o`02ooo/00Coo`2A0_oo09L8ool0W@04oj`0ooooooooe_l0ool0?0?oo`2A1?ooool3oo@0o`05
ool0C_ooooooo`1]ool0KOooool00_o40?l8ooooo`03oonS0?nC0?ooofL000;oofL000?oooooo`16
ooooool01Oooool2ojGo0004oooooooo0;3oo`2`oooh00?ooooo00?ooiL0oiWo0?lbo`000_l0oj40
0ooooooook`0oonl0005ooooo`03ool0_?oooooooooo00;ooooo00?oa?l0ooooooooool00_ooool2
oc80o`04ojco0?ooooooooooooooo`;onP3o0_ooool3ooo/0003ooooooo40?ooa03o00?oa03o0_oo
0?P6ooooo`?oo`2G00?o0;Coofl0oom_0?l00oooool2o`0Ro`?ooooo00Coo`38ofWo0?oooooo5?l0
2Oooool00ol0omkoooooooooo`02ooooo`;o0;[o0_ooool2o`3o@0;o01Ko0_l0g_l2och0o`Gooooo
0_l20?l5ooooo`;oo`3b1Oooool2olX0o`_ooooo0ooo0=@8ooooo`;oN`3o1_ooool2oe3o00;ooooo
0_l0oa02ooooo`?oB_l000?oooooo`3oo?l0oo`03?ooool3onSo00?o0?mO0ooX0?l@ooooo`?oW`3o
0oooool3o`3of0;o07Oo1?lP0?l2ooooo`Co__l02Oooool3okP0o`?ok_l02_ooool4oa[o00?o0?lF
0oooool3okSo00[ooooo0onb0?l?ooooo`GoM@3o4Oooool;ofoo00;ooooo2ol01?l;ooooo`Go0?nd
1?ooool5ok;o00CoP@3o0_nbo`0Eooooo`Ko09Go3Oooool001Wooooo0ol0000:ooooo`0RohOo0?oo
oooooooooonA0?oooooo0?Kooi<0oon=0?oo00Coo`3Hoooo03co04KooiT0ooln0?oo0?oBool0/?lb
0?oobP3oo`10ool0Vooo6P3ooed0oonO0?ooj03oool0C_oo06gonP3oool0l_l0i?ooo`3hokP0ool0
=?ooooooo`1Io`;o203o00So/P3oogGo0?l0ooKoooooodCo0?l8o`3oP@3ooh7o00Cooooo00Co0<Ko
o`3Noooooooooooo3?oo09400ooo03com03ooo@0o`06oo@0o`03o`3o;_oo04koo`1>00;oo`1]1?oo
ool00ome0?ooa03ool@0o`02ol@0o`?ooooo00?ooj<0oi<0ooooI`000oooool00ol0A_oooooooooo
o`03ooooo`;oYOl00_ooool00ooo0;3ooooooooh0002ooooo`?oVOl000Go<_l0o`3oXOoooooooooo
oonl0005ooooo`;oo`2l1?ooool01oo4o`3ooooooooooooooooo2?l0oc80oon/o`000oooool2ooX0
o`03ooooooook03oa03o00Goa03o0oooool2ool0n0Gooooo0ooo09L01?oooooo0;Coo`2doom_0?l3
ooooo`;o02;o0oooool2ool0b003ofWo0?lDo`3o5?l000Sooooo0_l0omh3ooooo`04oon;0?l0^_oo
ooooooooo`;o0?m00_l05_l01?l0g_oo0?l4ooooooln0?l5ooooo`;o0P3o1Oooool2ool0lPGooooo
0_o:0?l:ooooo`?oo`3D00?oQol0ooooooooool01Oooool3og/0o`Gooooo0om@o`02ooooo`;o0?l@
0_ooool2od[o00;ooooo0_l0oo`;ooooo`?oj?l000Coooooo`3oGol0oeoooooo0_oX0?lAooooo`;o
W`3o1?ooool2o`3of003ogGo0?l0Mooo803o00;o803o0oooool3okko00[ooooo0onh0?l3onko00[o
oooo0olJo`04o`3o5P;ooooo1?nho`0:ooooo`?o/P3o3Oooool5ogD0o`cooooo2_m_o`02ooooo`_o
00Co4_ooool4o`3o]0Wo/_l000?ooooooh40oon10?l00_n10?lBooooo`Wo09Go4oooool001Wooooo
00?o0000ooooooooool02_ooool09_n7o`3oooooooooooooT@3oooooo`3foonC0?oo803oohd0ool0
oh?oo`0lo`2Qool0A_ooV@3oo`1[oooo0;3oN`3oo`80ooo:0?oo043ooaX0oomM0?oo01KoonP0ool0
[_ooo`1>ool0KOoj0?ooo`3bool0n?nh0?ooYOl0o`0doooooooo05WooomW0?l0:?oo/P3o0ol80?l0
0onIo`3oP@3oo`So0002ooooo`;o0<Ko00?oooooooo/0?l80?l01?l80?l01?oo09Oooooooooooooo
0=@4oo@0o`05ool0??ooooooooooooooool0Sol00oooool01Ol0obkoo`1>ool0C_ooooooo`1]00Oo
oooo0_me0?l2ooooo`Goa03o0oooool00ol0A_ooooooooooo`02ooooo`;oYOl00oooool00ooo0;3o
oooooooh0003oiWo0004oonG0?lbo`3o<_l0o`3oX@;ooooo00?ook`0ooooooooool00oooool00ooo
0;coooooooooo`03ooooo`03olCo0?oooooo2?l000;o2?l000Co<P3oojco0?oooooooooo0_oj0?l4
ol@0o`Oooooo0_oo0?P4ooooo`?oo`2G00CoolP0oooooooooooo0;Co0_m_0?l3ooooo`09o`0Roooo
oooooooooooooonCo`3oo`38ofWo0?oooooo5?l000Wooooo00Go0?oNoooooooooooooooooon;0002
o`2jo`;ooooo00Ko0=koo`0Fool05_ooooooo`3o1?ooool2och0o`Gooooo00?o0P3oooooooooool0
0oooool2ool0lPGooooo0_o:0?l9ooooo`?oo`3D00?oQol0ooooooooool01_ooool2og/0o`Kooooo
0_m@o`03ooooo`;o0?l@0_ooool2od[o00;ooooo0_l0oo`:ooooo`?oj?l00_ooool2o`3oG`03oooo
oooX0?ooj03o013ooooo0onO0?l3ooooo`?o0?oH1?lP0?l3ooooo`?o__l02_ooool3okP0o`?ok_l0
2Oooool4oa[o00?o0?lF0_ooool4okSo00_ooooo0onb0?l;ooooo`GoM@3o1_ooool;ofoo0003oooo
ool01?oo00Co00Wo00Co5Oooool5ok;o00?o0?nd0onbo`06ooooo`GoP@3o3Oooool9o`2Eoacooooo
000Iooooo`03o`000?oooooooooo00[ooooo02WoQol0oooooooooooooooooonA0?l0m_ooHol0oi<0
oon=0?ooD?l0ool0??oo0;co04KooiT0ooln0?ooo`2`og/0ool20?oobP3oo`10ool0omko6P3ooed0
oonO0?ooj03oofT0oooo04konP3oool0l_l0i?ooo`3hokP0ool0=?ooooooodCo0?l0FOooA?l0o`0X
oonb0?ooooooo`36o`02o`P0o`03oh40ool80?oo203o00Co203o00?oon`0o`3Nooooool00oooool2
ool0U`05oooooooo0=Coe_l0oooooooo03`01Oooool01Ol0Soooooooool0C_oo04kooooo00;oo`1]
2_ooool01Ome0?ooofL0oomW0?ooX`3oT`3o00;ooooo0oo40?l3ooooo`;oYOl01?ooool01?oo0;3o
VOl0oiWo0?nIo`02ooooo`;o<_l00_l0oj400ooooooook`0oonl0005ooooo`03ool0_?oooooooooo
00?ooooo00Goa?l0o`So0?l8o`3oooooooCo0003ol@0o`;onP3o00?oa03oooo/0?ooool02?ooool2
ool0n0?ooooo0ooo09L01?ooooooolP0ooo80?ooool2o`2do`04ofl0ooooooooooooooooo`;o02;o
0_ooool01_nCo`3oo`38ool0b?mYo`3ooooooaCo00Sooooo0_l0omh3ooooo`;o0;[o00Goooooo`3N
ool0g_oo0=koo`0Fo`02ooooo`03o`3o1?ln0?oo?P3o00Gooooo0_l20?l4ooooo`;oo`3b1Oooool2
olX0o`Sooooo0ooo0=@2ohOo00Sooooo0_mk0?l6ooooo`;oD?l00oooool2o`3o40;ooooo0_m:o`02
ooooo`;o0?ol2_ooool2onSo00;ooooo0ol0oel00oooooooj03oonP0o`0@ooooo`;oW`3o1?ooool2
o`3of0?o803o1?ooool3okko00[ooooo0onh0?l3onko00Wooooo0olJo`001?oooooo0?lFo`3o5_l0
oaH2ooooo`?o^?l03?ooool3ok80o`Wooooo1Ome0?l3ooooo`SoKol000?oooooo`04ool01?l02Ol0
1?lFooooo`[o/_l000?oooooo`3o]?l0ok@00_l0ok@8ooooo`CoP@3o2oooool7o`2Eo`Wooooo3ol2
o`0=ooooo`006Oooool00ol0003oooooooooo`0:ooooo`0YohOo0?ooooooooooooooooooT@3ooooo
o`3foonC0?ooS@3ooaCo0?l0f?ooo`0lo`16ool0oi_oV@3oo`3od_oo0;3o<P3ooeL0ooo:0?oo043o
oaX0oomM0?oo01KoonP0oomY0?oo07goool0C_oo06goo`3bool0n?l0okCo^03oo`0dool0a_oo05Wo
o`36ool0:?oo/P3oo`36ool0ooH00oooool00on10?oo2?l0ooooo`04ooooo`03ooo/0?l0g_oo0=ko
00;ooooo00KoV@3ooooooooo09Ooe_l0ool0e?oo03`6ooooo`03o`3o;_oo04kooi4000;oo`1]2ooo
ool2oomW0004ogD0ooooX`3oS@3ooi<0o`?ooooo00?o04Koooooooo40?l01oo40?l00ooo0;3oVOl0
oooh0003ooooo`06oc;o0?oooooo0?nQoonM0?oooooook`01Oooool00oo:o`3oo`2lol@0o`0:ol@0
o`04oooooooj0?oonP3oooo/00[ooooo0_oo0?P2ooooo`?oo`2G0oooool01?oob03oooooooooool0
]?l2ofl0o`?ooooo00?o02;oooooooooool00_nCo`001Ooo0<SoooooofWo0?oooooo5?l000Oooooo
0_l0omh3ooooo`;o0;[o0ol0g_l00ol0od3o01Koo`0Fo`02ooooo`;o?P3o1Oooool2o`80o`Cooooo
0_oo0?86ooooo`03olX0oooooooooooo00Gooooo0ooo0=@00oooooooQol0ohOo0008ooooo`;oN`3o
1Oooool3oe3o00?ooooo0_l0oa02ooooo`;oB_l00oooool00ol0oocoooooooooo`07ooooo`?oj?l0
0_ooool2o`3oG`;ooooo0_oX0?l?ooooo`?oW`3o1?ooool01?l0omSo803oob00oolP0?l4ooooo`?o
__l02_ooool3okP0o`?ok_l02?ooool4oa[o0005ooooool0oaKo0?lFo`3o5_ooool01?nho`0<oooo
o`?o/P3o1oooool5ogD0o`?ooooo1Om_o`000ooooooo00Coo`04o`06o`04oaKooooo2onbo`07oooo
o`Co0?nd1oooool5oh40o`Sooooo1ol0UOl@o`;o01cooooo000Iooooo`03o`000?oooooooooo00_o
oooo02WoQol0oooooooooooooi40ooooool0m_ooT`3oohd0ool01?oo0?n3ool0??l0XOoo04Kooch0
oonI0?ooo`2`og/0ool20?oobP3oo`10oolJ0?oo0?nEoed0oonO0?ooj03oofT0oooo0<Soo`1>ool0
KOl0i?ooo`3hokP0ool0=?ooYOl0ooooool0FOooPOl0o`0Xoonb0?ooofL0o`3omP02ooooo`03okSo
0?n10?oo2?l000Gooooo0_ook0000ol0g_ooV@3oooooo`02omKo0003ool0Uooo03coo`3D00Gooooo
0_oo04h2ool0K@_ooooo0_ooI`02ooooo`03oonS0?n=0?ooT`3o00?ooooo00Co04KooooooonUo`3o
YOl00oooool3oiWo0003ool0/?o40?ooa03o00ooa03o00Coo`2loooooooooooooooo0_l8o`002Oo4
o`3oooooooCo0?odo`3o<P3oojco0?ook03onP3oooo/000;ooooo`03ool0n?ooooooo`2G00;oo`2G
1Oooool00ooob03oooooo`2do`02ofl0o`?ooooo0_l08_l00oooooooTol0oi?o0002ool0b0;oJOl0
00?ooooooaCo0?ooool01_ooool01?l0omkoooooooooooooool2o`2jo`;o0=ko0_l0od02o`0Fo`?o
oooo00?o?P3oooooooooool00oooool2o`80o`Gooooo00?oo`3booooooooool01?ooool2olX0o`Go
oooo0ooo0=@2ooooo`;oQol02?ooool2og/0o`Gooooo0_m@o`04ooooo`;o0?l@0_ooool2od[o00?o
oooo0_l0oo`7ooooo`?oj?l00oooool2o`3oG`;ooooo0_oX0?l?ooooo`;oW`3o1?ooool01?l0omSo
803oob00oolP0?l4ooooo`?o__l02_ooool3okP0o`?ok_l02?ooool3oa[o00;ooooo0ol0oaH01?oo
oooo^?l0okSo0?nho`0=ooooo`?o/P3o1Oooool5ogD0o`;ooooo1_m_o`000ooooooo00Coo`04o`03
o`04oaGooooo2Onbo`0?ooooo`?o0?nd1_ooool5oh40o`Kooooo1ol0UOl7o`;o01_ooooo1?mM0?l=
ooooo`006Oooool00ol0003oooooooooo`0;ooooo`0ZohOo0?oooooooooooonA0?oooooo0?Kooi<0
oolP0?ooS@3ooe3o0?oo03coo`2lo`16oooon03oV@3oool0/?mk0?oo0P3ooeL0ooo:0?oo0?oNoaX0
oomM0?ooW`3oonP0oomY0?oo07goool0C_oj0?ooo`1]obH0oooo0?So^03oo`0doon1o`3oYOl0o`1I
ool0;_oo02Sook80oooooooo0?of0_ooool01?n10?ooooooo`So0?l8o`05ooooo`03oiT0ool0g_oo
e_l000;ooooo00Coo`0lool0Uoooooooo`3D0_ooool2ool0CP;oo`1]00?ooi40ooooool0Sol01ooo
ool3oomW00?ooooo00Oooj<0ohd0oonC0?ooooooogD0oooooooo04Ko00;oYOl00_ooool3oiWo0004
oooooooo0;3oo`2`oooh00?ooooo00Oo<_l0oonG0?l0oj7o0?nQoonM0?oooooook`000Cooooo0_o:
o`000ooo0;coooooo`So0002o`So0007ooooooo4o`3oooooooCo0?oooooo<P3oooo/0002ooX0o`_o
oooo00Coo`3hool0Uooo09Ooo`2G1oooool01?oob03oooooo`2doom_0?l3ooooo`;o02;o00?ooooo
oi?o0?nCo`000_oo0<P01OooooooJOl0oooooooooooo5?l000Kooooo0_l0omh2ooooo`04o`3Nool0
^_oo0=koooooo`;o0?m000?oooooo`0Fooooool00_ooool2och0o`Gooooo00?o0P3oooooooooool0
0oooool2ool0lPGooooo0_o:0?l4ooooo`?oo`3D0_ooool3ohOo00Sooooo0_mk0?l5ooooo`;oD?l0
1?ooool2o`3o4004oooooom:o`3oB_l0od[o00?ooooo0_l0oo`6ooooo`?oj?l01?ooool2o`3oG`;o
oooo0_oX0?l?ooooo`;oW`3o0oooool01Omeo`3o803oob00oolP0?oo07Oo00?ooooo0onno`0:oooo
o`?o^03o0oo^o`07ooooo`Co6_l00_ooool3o`3o5PCo^?l03Oooool3ok80o`Cooooo1?me0?l2oooo
o`GoKol000?oooooo`04ool01?l01?l01?lCooooo`Oo/_l05?ooool4o`3o]0Cooooo1On10?l6oooo
o`Go09Go0ol2o`0Oooooo`OoG@3o1?l0Sol=ooooo`006Oooool00ol0003oooooooooo`0;ooooo`0Z
ohOo0?ooooooooooooooooooT@3o0?Koo`3o:?nC0?ooS@3ooe3o0?l0f?ooo`0lo`16ool0oi_o?P3o
oiT0oooo0;3o<P3ooeL0ooo:0?oo043ooaX0oomM0?oo01Kooil0oooX0?ooJ@3oool0b?oo04koo`3b
ool0KOlV0?ooo`3hooooool0=?ooooooo`1Ioooooooo02Sook80oomeo`3o0?of0_ooI`001Ooooooo
P@3ooooooooooooo2?l000;oVOl000OooooooiT0oooFo`3oe_l0o`3Nooooooooo`0l00;ooooo0_oo
09L2ool0CP;oo`1]00?ooooooonA0?ooool00_ooool2o`2?o`;ooooo0oooI`05ooooo`03oonS0?n=
0?ooT`3o00?ooooo0_me0?l2ooooo`;oVOl00oooool00ooo0;3ooooooooh0002ooooo`;o<_l000Ko
oiL0o`3oXOoooooooid0oooooooo_004ooooo`03ol[o0?ooooooo`2l00;o2?l00_ooool2olCo00;o
m?l000Co[?l0oc80oooj0?oonP3o2oooool3ool0U`Wooooo00CoolP0oooooom_0?ooK`3o0oooool0
1_l08_oooooooi?o0?nCo`3oooooool0b0;ooooo00CoJOl0oooooooooooo5?l01_ooool01?l0omko
ooooo`3Nool0g_l2o`2jo`04ooooool0od3o0?m0ooooo`;o01Ko0_ooool2och0o`03o`3o1?oooooo
oooo00;ooooo0_l20?l4ooooo`;oo`3b1Oooool2olX0o`?ooooo0ooo0=@3ooooo`;oQol02_ooool0
0omk0?ooooooooooo`03ooooo`;oD?l01?ooool2o`3o4003oooooom:o`3oB_l000Gooooo00?o0?ol
ooooooooool01?ooool2onSo00Gooooo0_l0oel2ooooo`;oj03o3_ooool3oil0o`?ooooo0olP0?l0
1?l0Moooooooooooooooool3okko00[ooooo0onh0?l3onko00Oooooo0olJo`04ooooo`;o0?lF0onh
o`0>ooooo`?o/P3o0_ooool5ogD0o`KoKol000?oooooo`04ool01?l00ol01?lBooooo`Oo/_l05ooo
ool4o`3o]0?ooooo1On10?l4ooooo`;o0_l01Ol0UOlPooooo`OoG@3o1ol0SolAooooo`006Oooool0
0ol0003oooooooooo`0;ooooo`0MohOo0?ooooooooooooooooooT@3oooooo`3foonC0?ooS@3ooaCo
0?l0oh?oo`0lo`3oo?l0A_oo?P3ooiT0oooo0;3oN`3oo`80ooo:0?oo043ooaX0ool0oiGoG@3ooil0
oooX0?ooJ@3oo`1moooo0<P00_oo04h01?oo06goo`3hokP0ool0=?l2ooooo`07o`1Ioooooooo02So
ok80oooooooo0?ofooooo`02oomW0004oh40ooooooooooooo`So00;oV@3o00GoVOl0oooooooooooo
on`0ool0?003ooooo`;oo`1>0_oo06d2ooooo`03oonA0?oooooooooo00?ooooo00?oofL0o`2?oooo
I`001oooool00oooX`3oS@3ooi<0o`02ooooo`06ojGo0?l0A_oooooooiWo0?me0?ooVOl01?ooool0
0ooo0;3ooooooooh0002ooooo`08oc;o0?oooooooiL0o`3oXOoooooooid0oooooooo_004ooooo`04
ol[o0?l8o`3oo`2lo`So00?ooooo00Goa?l0ooCo0?odo`3oon`0oc80o`02ooX0o`[ooooo0ooo09L;
ooooo`03ooo80?ooooooK`3o00?ooooo0_l08_l2oi?o0003oooooooo0<Soo`3800;ooooo00CoJOl0
oooooooooooo5?l01Oooool4o`3No`;o0;[o0_ooool01?l0od3oooooo`0Fool05_l2ooooo`;o?P3o
00?o0?l4ooooooooool00_ooool2o`80o`Cooooo0_oo0?86ooooo`03olX0oooooooooooo00?oo`3D
1?ooool2ohOo00[ooooo0_mk0?l4ooooo`;oD?l01?ooool2o`3o4003oooooom:o`3oB_l000Gooooo
0_l0oo`5ooooo`;oj?l01?ooool3o`3oG`?ooooo00?oj03oooooooooool03?ooool2oil0o`?ooooo
00?oMOl0ob00oolP0?l00_l0Mol2ooooo`?o__l02_ooool3okP0o`?ok_l01oooool3oa[o00Cooooo
0ol0oaH2okSo00kooooo0onb0?l00oooooooM@3oogD0o`02ogD0o`GoKol00_ooool5o`04oa3ooooo
1onbo`0Iooooo`Go0?nd1?ooool3oh40o`;ooooo1?l2o`05o`2Eoaoooooo1_mM0?l00ooooooo08oo
o`2?o`04o`2?oaSooooo000Iooooo`03o`000?oooooooooo00_ooooo023oQol0oooooooooooooooo
oonA0?oooooo0?Kooi<0oolP0?ooS@3oo`3oPooo03coo`2lo`16oooon03o?P3oool0/?mk0?oo0P3o
oeL0ooo:0?oo09_ooaX0oomM0?oo01KoonP0ool08_ooJ@3oool0b?l0D_oonP3oool0CP?oo`1]00Wo
03Coooooool0FOooYOl0o`0^ool0:?oo/P3oooooool0ooH00_ooool01on10?ooofL0oomW0?nI0?oo
2?l0omKo0?ooool00_nIo`000ooo03coon`0o`3No`02ool0CP;oo`1]00Goooooool0Uooo09Oooooo
oonA0005oomW00;ooooo00?o08ooooooooooool01?ooool01oooX`3ooooooi<0ooooooooYOl0oiWo
0?l0A_l00_nIo`02ooooo`08ogD0oooooooooooooooooooo0;3ooooooooh0?ooool2oc;o0007oooo
ool0oj7o0?nQooooooooW@3ooooooonl0003ooooo`?o2?l000Ooo`2looooooooooooooooooo/0?o4
o`3om?l000;ooooo00?o<P3oooX0ooooool01oooool4ool0U`03ool0n?oooooooooo00Wooooo0_oo
b002ofl0o`?ooooo00?o02;ooi?o0?nCo`000_ooool00ooo0<Soooooooooo`02ofWo00;ooooo00Co
5?l0oooooooooooooooo0ol0g_l2ooooo`;o0;[o0_ooool2o`3o@003ooooool05_oooooo00;ooooo
00?o?P3oooooool0o`@01?ooool00ol20?ooooooooooo`02ooooo`;oo`3b1_ooool2olX0o`?oo`3D
1Oooool2ohOo00[ooooo0_mk0?l5ooooo`03oe3o0?oooooooooo00;ooooo0_l0oa000oooooooB_l0
od[o0006ooooo`03o`3oo?oooooooooo00?ooooo0_oXo`04ooooo`;o0?mO1?ooool2onP0o`cooooo
0onO0?l3ooooo`?o803o0_l0Mol01?oooooo__l0okko0?nno`0:ooooo`?o^03o00?oooooonko0?o^
o`001oooool3oa[o00Cooooo0ol0oaH00onho`3oooooooooo`0=ooooo`?o/P3o1?me0?l2ofoo00Co
oooo1Ol01?l@ooooo`Go/_l07?ooool4o`3o]0Gooooo1?n10?l3o`;o00Ko09Go7Oooool7oed0o`03
ooooool0Sooo08oo00Co08oo7_ooool001Wooooo00?o0000ooooooooool02oooool08?n7o`3ooooo
oooooooooooooi40ooooool0m_ooT`3oob00oon=0?ooD?l0o`29oooo03co04Koo`3oVoln0?ooV@3o
ool0/?lb0?ooE`3oolX0ool0@?oo6P3oo`3oUOmM0?ooW`3oonP0oomY0?oo09Goool0b?l0D_ooo`3b
0ooo04h3ool0K@06o`1IoonUo`3o02Sook80oomeo`3o0?of0oooool01?n10?ooV@3oomKo0?oFo`02
o`So0003oomW0?oo03coofL000;oo`1>0_oo06d5oomW0003ool0UoooI`3ooooo00Oooooo00?o08oo
ooooooooool00_ooool00oooX`3oVOl0oi<0o`03oiWo0003o`16oooooooooooo00Cooooo0_me0?l0
0ooo0;3ooooooooh0002oc;o00;ooooo00Oo0?nQoooooooooooooid0oooooooo_03ooooo00?o2?l0
0_ooool00ooo0;coooooooo/0002ooo/0004olCo0?odo`3oooooojco00;onP3o1_ooool3ool0U`03
oooooooo0?Soo`3h00cooooo00?oolP0oooooom_0?l00oooool2o`0Ro`03oi?o0?oooooooooo00;o
o`380_ooool01_mYo`3ooooooooooooooooo5?l0ooooo`?o0=ko00Goooooo`3og_ooooooooooo`2j
o`02ooooo`;o0?m000?oooooo`0Fool05_l00_ooool2och0o`03ooooool0o`Cooooo00;ooooo0_l2
0?l3ooooo`;oo`3b1_ooool01?o:0?ooo`3Dool0e?oo0=@6ooooo`;oQol02_ooool2og/0o`Gooooo
0_m@o`03ooooo`;o0?l@00?ooooood[o0?m:o`001_ooool2o`3oo0Cooooo0_oXo`04ooooo`;o0?mO
1?ooool2onP0o`cooooo0_nO0?l3ooooo`?o803o0_l0Mol2ooooo`;o__l02_ooool3okP0o`04oooo
ooo^o`3ok_l0onko00Oooooo0_lJo`04ooooo`?o0?lF00?o^?l0ooooooooool03Oooool3ok80o`?o
M@3o1Oooool5o`04o`oooooo1_nbo`0Mooooo`Co0?nd0oooool3o`;o00?oP@3o00?o0_l0ooooool0
UOl01?l0UOlLooooo`OoG@3o0oooool5o`2?obCooooo000Iooooo`03o`000?oooooooooo00cooooo
02coQol0oooooooooooooooooonA0?l0m_oo0?lXoi<0oon=0?ooD?l0o`3Hoooo03co0?olo`16ooln
0?oo06_oool0/?mk0?oo0P3ooeL0ooo:0?oo0?oNoaX0oomM0?ooW`3oonP0oomY0?oo07goool0b?l0
D_oo>?l0ool0l_lV0?oo0?ndool0C_l0=?ooooooool0KOl0FOooooooo`0Xoonb0?ooooooo`3omP;o
oooo00?oV@3ooh40ooooool00_ooool02Ooo06goo`0lool0C_oo04koo`1]o`3o;_nIo`3o0=kooiWo
0003ooooo`04oonA0?ooooooo`2Gool0U`Sooooo0_l0Sol3oiWo0005oi<0oonUo`3oYOl0ooooool0
A_l02?ooool01?oo0;3oM@3oogD0oolbo`03ooooo`05o`3oXOoooooooooooonM0?ooool00ol8o`00
2_oooooob_l0ooooooooooooon`0ool0_?ook03oooooooCo0?o4o`02ooooo`;onP3o1?ooool4ool0
U`;ooooo0_oo0?P=ooooo`03ooo80?m_0?ooK`3o00?ooooo00?o02;ooi?o0?ooool00_ooool01Ooo
0<SoooooooooooooooooJOl000?ooooo0ol0g_l2ooooo`;o0?oN00Coooooo`2jool0^_oooooo0_l0
od000ooooooo01Koo`0Fo`02ooooo`;o?P3o0_ooool00ol0o`Coooooooooo`02o`80o`?ooooo0_oo
0?86ooooo`?oo`3D1oooool2ohOo00[ooooo0_mk0?l5ooooo`;oD?l00oooool2o`3o4003oooooom:
o`3oB_l000Oooooo00?o0?olooooooooool00_ooool2onSo00Cooooo0_l0oel4ooooo`;oj03o2ooo
ool3oil0o`;ooooo0olP0?l01?l0omSo07Ooo`1gooooool3okko00Wooooo0onh0?l01?ooooook_l0
onko0?o^o`07ooooo`?o6_l00_ooool2okSo00;o0?lF3oooool01Ome0?oo/P3ook80oonb0?ooM@3o
00Gooooo1Ol01?l?ooooo`Go/_l07oooool4o`3o]0Ko0_l01?n10?l5o`2Eoa[ooooo1omM0?l5oooo
o`Go08oo:Oooool001Wooooo00?o0000ooooooooool03?ooool08on7o`3ooooooooooooooooooi40
o`3foomSo`3oT`3oohd0ool01?oo0?n3ool0??l0XOoo04Kooooh0?ln0?oo0>[oool0/?lb0?ooE`3o
olX0ool0@?oo6P3ooed0ool05_ooW`3oonP0oomY0?oo09Goool0b?l0D_ooo`3booX0oolV0?ooo`3h
00?oo`1>3?oo06d01Ooo04koo`0loooooooooooo0?l^00Cooooo0_l0g_l5oiWo0004ool0e?oo09Oo
o`2Gool0U`KoVOl000Goooooo`2?ooooooooT`3oojGo0002ooooo`03o`16oooooooooooo00Gooooo
0_oo0;001Ooooooo<_l0oc;o0?me0?oooooo00;o0?nQ00?oooooo`So0?l8o`000_l8o`02ooooo`;o
b_l00oook0001_oo0;coooooooooooodo`3oa?l0ooooo`;onP3o00?o<P3oooooooooool00ooo09L4
ooooo`;oo`3h3_ooool00ooob03oK`3oo`2do`02ooooo`;o02;o0oooool2ool0b0?ooooo00?oJOl0
ooooool0g_l00_l0g_l4ooooo`05o`3og_oooooo0;[oo`2jooooool00_l0od02ooooo`03o`0Foooo
oooooooo00;o?P3o0oooool01?l0o`Coooooooooool20?l3ooooo`;oo`3b1Oooool3ool0e0Sooooo
0_n7o`0;ooooo`03og/0oooooooooooo00?ooooo0_m@o`03ooooo`;o0?l@00?ooooood[o0?m:o`00
1oooool2o`3oo0?ooooo0_oXo`03ooooo`?o0?mO1?ooool2onP0o`_ooooo0_nO0?l3ooooo`;o803o
00Goooooo`1gool0Mooo07Ooooooo`02okko00Wooooo0onh0?l01?ooooook_l0onko0?o^o`08oooo
o`;o6_l00_ooool2okSo00?o0?lF2oooool5ogD0o`;o/P3o1?ooool5o`04o`oooooo1Onbo`0Qoooo
o`?o0?nd1?l2o`03ooooo`?oP@3o1?l0UOlHooooo`OoG@3o1oooool5o`2?obkooooo000Iooooo`?o
00003?ooool09_n7o`3ooooooooooooooooooi40ooooool0m_ooT`3oob00oon=0?ooD?l0o`29oooo
03cooid0o`16ooln0?oo0?oBo`3Zoooo0;3o0P3ooeL0ooo:0?oo6P3oo`3oUOmM0?ooW`3oonP0oomY
0?oo07goo`2Eoooo0<So05;oool0l_oj0?oo9P3oool0n?l0=?oooooo3?oo04h01Ooo03coooooo`3o
;_l0obkooooo00?o2?l00oooool2o`3No`;oon`00_ooool00ooo0=Coooooooooo`03ool0U`?ooooo
0_nUo`001On=0?ooT`3ooooooooooooo04Ko00Oooooo00Coo`2`oooooooooooo<_l00oooool2ogD0
o`;o2?l000Oooid0oonl0?ooooooooooooo/0?o:o`3oon`000?ooooo00Soo`2looooooodo`3om?l0
olCo0?oooooonP3ooc80o`Coo`2G1Oooool2ool0n0oooooo0_m_0?l01?l0]?oooooooi?o0?l08_l4
ooooo`05ool0b?oooooooooooooooomYo`000ol0g_l00ooooooo5?l0ooooo`03ooooo`03o`3og_oo
oooo0;[o00;ooooo00?o0?m0ooooooooool00_l05_l2ooooo`03och0oooooooooooo00;ooooo00Co
0?l4ooooool20?oo0P3o0oooool00ooo0?;oooooooooo`02ooooo`?oo`3D0_o:0?l7ooooo`;oQol0
2oooool2og/0o`Cooooo0_m@o`03ooooo`;o0?l@00?ooooood[o0?m:o`001oooool2o`3oo0?ooooo
0_oXo`03ooooo`;o0?mO1Oooool2onP0o`_ooooo0_nO0?l2ooooo`?o803o00Coooooo`1gool0Mooo
oooo0onno`09ooooo`;o^03o0_ooool2onko00Wooooo0_lJo`04okSo00;o0?lF2Oooool5ogD0o`03
ofoo0?oooooo/P3o00;o/P3o0_ooool4o`04oa3ooooo1?nbo`0Qooooo`;o0_l00ol0ok@6ooooo`Co
P@3o0_l0UOlFooooo`OoG@3o2?ooool6o`2?oc?ooooo000Iooooo`03o`000?oooooooooo00cooooo
00?oQol0ooooooooool00_ooool08OooT@3o0?Koo`3o:?nC0?ooS@3ooe3o0?l0f?ooo`2lool0??l0
A_oo?P3oo`1[ool0j_ooo`2`oiT0oomG0?oobP3oo`3og_lJ0?ooG@3oo`0FoonO0?ooj03oofT0ool0
UOooo`38o`1Boolho`3oo`3booX0ool0okCoo`3ho`0do`02ooooo`06o`1IoooFo`3oV@3ook80oonU
o`3o0?of0_ooool2ool0?0;o0?l^1_ooool3o`So0004oonA0?oooooo0=koo`3No`?oon`000Goo`3D
ooooooooooooooooojGo0002ool0U`07ojGo0?ooooooS@3ooi<0ool0Soooooooo`16o`07ooooo`05
ool0/?oooooo<_l0oc;o0?ooool00_l8o`000ol0oj7ooiL0ooooo`02ogD0o`Coon`000?ob_l0oooo
ooooool00_ooool01_oo0;com?l0ooCo0?ooooooa?l0ooX0o`?oo`2G1oooool2ool0n13ooooo00Co
K`3oo`2dooooooooTol00_l08_l3ooooo`;oo`380_ooool3o`3No`?ooooo00Co5?l0oooooooooooo
oooo0_l0omh2o`2jo`04ooooool0od3o0?m0ooooo`;o01Ko0_ooool2och0o`?ooooo0_l0o`@2o`80
o`?ooooo0_oo0?82ooooo`?oo`3D00?oooooolX0ooo:0?l01oooool2ohOo00_ooooo0_mk0?l4oooo
o`;oD?l01?ooool01?l0oa3ooooood[o0?m:o`08ooooo`04o`3oo?ooooooooooooooo`;oj?l00ooo
ool2o`3oG`Gooooo0_oX0?l:ooooo`?oW`3o00Coooooob00oolP0?oo803o0_ooool2o`1go`?o__l0
2_ooool2okP0o`04ooooooo^o`3ok_l0onko00Sooooo0olJo`02okSo0004ooooool0oaKo0?lFo`3o
5PKooooo1Ome0?l2ofoo00?ooooo0_nb0?l2ooooo`?o00Co4?ooool4ok;o023ooooo1?l2o`03o`3o
]0Gooooo1?n10?l00ol0UOooooooooooo`0Cooooo`KoG@3o2_ooool5o`2?ocWooooo000Iooooo`03
o`000?oooooooooo00cooooo00?oQol0ooooooooool00_ooool08OooT@3o0?Koo`3o:?nC0?ooS@3o
oaCo0?l0oh?oo`2lool0??l0A_ooooP0och0ool0om;oN`3oool0/?nI0?oo08?oolX0oolJ0?oo0?nE
oed0oonO0?ooj03oofT0ool0OOoo09Goool0b?l0D_ooo`3booX0oolV0?oo^03oool0n002omKo0008
o`1IoonI0?oo02koo`0Xoonb0?ooooooo`3om_oo03`2o`3o;P03oh40oooooooooooo00Sooooo0ol8
o`000ooooooo0=koooooo`02ojGo0003ool0e?nUo`3oYOl000;ooooo00?ooj<0ool0Uooo09L00_oo
09L00ooooooo04Koooooo`06ooooo`03ool0/?lbo`3o2?l000?o2?l00_l0oj45ooo/00;oM@3o0_o:
o`04ooooo`03ool0_?odo`3ooooo00Coo`2G00?o<P3oooooooooool01Oooool2ool0n13ooooo00?o
olP0ofl0ool0]?l00_nCo`000ol08_ooooooooooo`02ooooo`03ool0b?l0g_oo0=ko00;o0=ko00?o
JOl0ooooooooool00_ooool01OlDo`3ooooooooooooooooo0?oN00;o0;[o00?oooooo`3o@?l0od00
0_ooool00ol05_ooooooooooo`02och0o`Cooooo00?o0?l4ooooool20?l00oooool2ool0lP04oooo
oooo0=Coo`3Dool0e0?ooooo00?obP3oooooooooool01_ooool00on7o`3oooooooooo`09ooooo`;o
N`3o1Oooool00om@o`3oooooooooo`02ooooo`;o0?l@0_m:o`08ooooo`;o0?ol0_ooool2onSo00?o
oooo0_l0oel5ooooo`;oj03o2_ooool2oil0o`;ooooo0_lP0?l3ooooo`;o07Oo0_nno`0:ooooo`?o
^03o00?oooooonko0?o^o`002Oooool2oa[o0004okSo0?ooooooooooooooo`;o0?lF1Oooool4ogD0
o`?oKol01Oooool2ok80o`Co00Co3oooool4ok;o01oooooo1Ol2o`001?oooooo0?ndo`3o]?l0ok@4
ooooo`CoP@3o5Oooool5oed0o`[ooooo1_l0Solnooooo`006Oooool00ol0003oooooooooo`0=oooo
o`0VohOo0?ooooooooooooooooooT@3o0?Koof?o0?nC0?ooS@3oo`04oom@o`3o08Woool0_?oo03co
04Kooch0ool0om;o0>[oog/0oooo0;3oV@3oolX0ool0omko6P3ooed0ool05_ooj03oo`0RoomY0?oo
0?l^ool0b?l0D_oo>?l0ool0l_oj0?oo0?ndool0n?l0=?l2oiT0o`07o`1Ioooooooo02Sook80ool0
obkoo`0lo`3o;P02ooooo`03oh40oonUo`3oYOl000;oYOl01Oooool01?ooT@3oooooojGo0?nUo`02
o`So00;o0=ko0_ooool2ool0e0?oon`000CoS@3ooi<0ooook03oon`01ooo09L2ool0/0;o2?l00ooo
k0000ol0oj7oon`0oonG0002ooooo`06oonM0?oo_03oooooooooooo:o`3oM@3o0_ooool6ool0U`04
ooX0oon/o`3ooooooc80o`Oooooo00?oo`3hooooooooool03oooool2ofl0o`04o`2doooooooo02;o
o`0Ro`?ooooo0_oo0<P01Ol0g_ooooooooooooooooooJOl000Cooooo00Wo5?l0oooooooooooooooo
o`3og_l0^_oooh/0ooooool0od000_ooool2o`0Fo`;ooooo00?o?P3oooooooooool00oooool00ol0
o`Co0P3oo`80o`02ooooo`;oo`3b0ooo0=@4ooooo`;obP3o1oooool2ohOo00_ooooo00?oN`3ooooo
ooooool00oooool2oe3o00?ooooo0_l0oa02od[o00Wooooo00?o0?olooooooooool00_oXo`03oooo
o`;o0?mO1_ooool00ooX0?ooooooooooo`08ooooo`;oW`3o00Coooooob00oolP0?oo803o0_ooool3
o`1go`;o__l02_ooool2okP0o`;ooooo0_o^o`08ooooo`?o6_l00oooool3o`3o5P;ooooo1Ome0?l3
ofoo00Kooooo0onb0?l2o`04o`oooooo1?nbo`0Nooooo`Go0_l00oooool3o`3o]0?ooooo00Co09Go
oh40oon10?ooP@3o5Oooool4oed0o`[ooooo1Ol0Som4ooooo`006Oooool00ol0003oooooooooo`0=
ooooo`0WohOo0?ooooooooooooooooooT@3oooooo`3foonC0?oo803oohd0oom@o`3o0=Soool0_?oo
03co04Kooch0ool0Jooo0>[oog/0oooo0;3oE`3oolX0oonI0?oo6P3ooed0ool0ok[oW`3oonP0oomY
0?oo07goo`2Eoooo0<So05;oool0l_l0i?oonP3ooiT0oooo0?So03Co00;ooooo00Ko05Woo`0^ool0
:?ooo`0logGo0?l0ooH3ooooo`04oh40ooooooooooooooooo`OoYOl01?ooool2o`So00;o0=ko0_l8
o`02ool0e005ohd0oonC0?ooooooooooool0A_l01?l8o`000ol0Sooo2?l0ool0/00Dool0U`03ooCo
0?oo0;cooooo00;onP3o00Coa?l0ojco0?lb0?oo<P3o1_ooool2ool0n17ooooo00KoK`3ooi?o0?l0
]?ooooooo`0Rooooool3o`3No`03ool0b?oooooooooo00?ooooo00?oJOl0ooooooooool00_ooool0
1?lDo`3oooooooooool0omh2o`2jo`03ooooool0od3o0?m000;ooooo00?o01Koooooooooool00_ln
0?l5ooooo`04o`3o1?l20?ooooooooooo`;oo`3b0_oo0=@5ooooo`;obP3o1oooool2ohOo00_ooooo
0_mk0?l4ooooo`;oD?l00oooool2o`3o40;oB_l02Oooool2o`3oo003oooooooXo`3oj?l000;ooooo
0ol0oel6ooooo`;oj03o2?ooool3oil0o`03oooooolP0?oo803o00?ooooo0_l0Mol2o`3of0_ooooo
0_nh0?l01?ooooook_l0onko0?o^o`07ooooo`03okSo0?lJo`3o6_l000Cooooo0_l0oaH00ooooooo
M@3oogD0o`02ogD0o`04oooooom_o`3oKol0ofoo00Sooooo0_nb0?l00ol01?ooooooooooo`0=oooo
o`Co/_l07Oooool5o`;o00Gooooo0ol0ok@00ooooooo09Goo`2Eo`04oh40oaCooooo1?mM0?l8oooo
o`Ko08oo=oooool5o`3oY`gooooo000Iooooo`03o`000?oooooooooo00gooooo00?oQol0oooooooo
ool00_ooool04_ooT@3o0?Koo`3o:?nC0?ooS@3ooe3o0?l0oh?oo`2lo`3oo?oo03coooP0och0ool0
om;o0>[oog/0oooo0;3o08?oolX0o`?oV@3o00coW`3oonP0ool0ol3oJ@3oo`1mool0UOooo`38oiT0
oooo0?;o9P3oooX0oonh0?l2ool0n008o`3o;_l0FOoo0?l^ool0??l0:?oo/P3oooooool0ooH3oooo
o`03oh40oooooooooooo00Cooooo00?ooi40ooooooooool02?ooool2o`3No`07oooooon=0?ooo`3D
ool0e?l8o`3o04Koo`So0005ooooo`04ool0/?lbo`3ooooooooh00;ooooo0_l0oj401_oooooooiL0
oooooooooooooid0oonl00;ooooo00Cob_l0oooooooooooooooo0_odo`001?oo0;conP3oooX0oooo
ool2ojco0003oc80oooooooooooo00Cooooo0_oo0?PAooooo`;oK`3o0_l0]?l2o`0Ro`;o0=ko00?o
ooooool0b?oo0<P01Oooool00omYo`3oooooooooo`02ooooo`06oaCo0?ooooooooooo`3og_l0^_oo
oh/00_l0od02ooooo`;o01Ko0_ooool00oln0?ooooooooooo`04ooooo`;o0P3o00?oooooool0l_oo
0=@00_oo0=@6ooooo`03olX0oooooooooooo00Gooooo0_n7o`0;ooooo`;oN`3o1?ooool2oe3o00?o
oooo0_l0oa000oooooooB_l0ooooo`09ooooo`04o`3oo?ooooooj?l0onSo00;ooooo0_l0oel7oooo
o`;oj03o2?ooool2oil0o`04oooooolP0?oo803oob00o`?ooooo0_l0Mol2o`3of0[ooooo0onh0?l0
0oooooook_l0onko0007ooooo`;o^?l00_lJo`03ooooo`;o0?lF1?me0?l00oooooooKol0ofoo0002
ofoo00Oooooo00Co00Cook80oonb0?oo/P3o3oooool3ok;o01gooooo1?l2o`07ooooo`?o0?nd0_l0
UOl4oh40oa?ooooo1OmM0?l7ooooo`Go08oo=_ooool7o`3oYa;ooooo000Iooooo`03o`000?oooooo
oooo00gooooo00?oQol0ooooooooool00_ooool06?ooT@3o0?Koo`3o:?nC0?ooS@3ooaCo0?l0oh?o
08Woool0_?oo03co04Kooch0ool0om;o0>[oog/0oooo0;3oE`3oolX0ool0]?oo6P3ooed0oonI0?oo
W`3oonP0o`?oV@3o013oo`38o`1Bool0oa3oo`3booX0ool0okCo^03oo`0doooo0?Soooooool0??oo
oooo02Sook80oomeo`3o0?of1?ooool00on10?ooooooooooo`02ooooo`03oonA0?oooooooooo00So
oooo00Gooj<0ooooooooooooS@3ooi<0o`02ooooo`03ool0e?oooooooooo00?ooooo00Go<_l0ool0
/?oooooo08oooooh0002ooooo`04o`3oXOoooooooooooonG00;ooooo00?ooid0oonl0?ooool00_o:
o`02ooooo`;om?l000Coooooool0_?oj0?oooooo0_me0?l00oo4o`3o<P3oooooo`04ooooo`;oo`3h
4Oooool01onCo`3oK`3oooo80?l0]?oo0=koo`0Rool0g_l00oooool00ooo0<Soooooooooo`04oooo
o`03ofWo0?oooooooooo00;ooooo00?o5?l0ooooooooool00_l0^_l00ooooooo0?m0ooooo`02oooo
o`03o`0Foooooooooooo00;o?P3o1Oooool2o`80o`04oooooooo0=Coo`3Dool0e0Oooooo0_o:0?l6
ooooo`;oQol03?ooool00omk0?ooooooooooo`03ooooo`04oe3o0?ooooooooooooooo`;o0?l@00?o
oooood[o0?m:o`002_ooool00ol0oocoj?l0onSo0002ooooo`;o0?mO1oooool2onP0o`Sooooo0_nO
0?l3ob00o`Cooooo0_l0Mol2o`3of0[ooooo0_nh0?l2ooooo`;ok_l01_ooool2okSo00?o6_l00ooo
ool4ogD0o`03oooooom_o`3oKol000;oKol02?ooool2o`04o`;o/P3o3_ooool4ok;o01cooooo1?l2
o`08ooooo`;o0?nd0_l0UOl4oh40oa?ooooo1?mM0?l7ooooo`Go08oo=?ooool7o`3oY`Sooooo1?mY
0?l=ooooo`006Oooool00ol0003oooooooooo`0=ooooo`03ohOo0?oooooooooo00;ooooo02cooi40
o`3foomSo`3oT`3oo`0:oon=0?ooD?l0o`29oooo0;cooid0ool0??oooooo?P3oo`3Zool0l?ooN`3o
ool0/?l0PooobP3ooaX0ool0oj7oG@3ooil0oooX0?oo0?o0ofT0ool0OOoo09Goool0b?l0Moooo`3b
o`3Toooj0?oo0?ndokP0ool0=?ooo`0lo`1Ioooooooo02koo`0Xoonb0?ooMOl0o`3omPCooooo00Go
P@3ooooooooooooooooooonA0009ooooo`09oonS0?ooooooooooohd0oonC0?ooooooo`3Nool0A_oo
oooo00;oo`3D00Cooooooc;o0?lbo`3oo`2`0_ooool01?oon03o08ooo`2?ool0oj42ooooo`07oonG
0?oooooooooooonM0?oo_03ooooool[o0003ooooo`04ooCo0?oooooonP3oool0_0?ooooo00?o[?l0
olCo0?me0?l01?ooool2ool0n17ooooo00GoTol0ofl0oom_0?oo0=koo`2do`02o`0Ro`Cooooo00?o
o`38ooooooooool01?ooool00omYo`3oooooooooo`02ooooo`05oaCo0?oooooo0;[oo`2jooooool0
0_l0od02ooooo`;o01Ko0_ooool00oln0?ooooooooooo`04ooooo`05o`80oooo0=Coo`3Dool0e?oo
0?802?ooool00oo:0?ooooooooooo`04ooooo`;oQol03?ooool2og/0o`Cooooo0_m@o`03ooooo`04
o`3o4?ooooooB_l0od[o00[ooooo0_l0oo`00ooXo`3oooooooooo`02o`3oG`Oooooo0_oX0?l8oooo
o`;oW`3o0_lP0?l5ooooo`;o07Oo0_l0omP:ooooo`;o^03o00Coooooonko0?o^o`3ok_l01_ooool2
okSo00;o6_l000?oooooogD0oome0?l00ome0?l2ooooo`?oKol02Oooool3o`04o`;o/P3o3Oooool3
ok;o01_ooooo1Ol2o`09ooooo`Co09Go0on10?lCooooo`CoG@3o1_ooool5o`2?oc;ooooo1ol0ojL;
ooooo`CoJ@3o4Oooool001Wooooo00?o0000ooooooooool03Oooool00on7o`3oooooooooo`02oooo
o`0QoonA0?oooooo0?Kooi<0oolP0?ooS@3ooe3o0?l0f?ooo`2loonM0?l0oi_oo`0loch0ool0om;o
0>[oog/0oomG0?ooo`2`olX0oolJ0?oo0?oNoed0ool0ok[oW`3oonP0ool0ol3oJ@3oooCo0?oo0<So
05;oocSo0?oo0?;o9P3o00;onP3o00[oo`0loooooooo0?So05Woooooool0:?oooooook80oooooooo
0?of1?ooool00on10?oooooooonA0009ooooo`09oonS0?ooooooooooohd0ooooooooT`3oooooool0
A_oooooo00;o0=ko00Co<_l0ool0e?oo0;3oo`2`0_ooool01ooon03oooooo`3oXOoooooo08oooooo
ooooU`000_ooool01?ooW@3ook`0ooooooo:o`02ooooo`;om?l000?oooooooX0oooo0;`00_ooool2
ojco0003olCo0?lb0?oooooo00;oM@3o0_oo0?P@ooooo`?o0=ko00GoK`3oo`3Noooob03o0;Coo`0R
o`04ooooo`;oo`381_ooool00omYo`3oooooooooo`02ooooo`04oaCo0?oooooo0;[ooon;00;o0?m0
0oooool00ol05_ooooooooooo`02och0o`Gooooo0ooo0=@2ool0lPSooooo0_o:0?l6ooooo`03ohOo
0?oooooooooo00[ooooo0_mk0?l4ooooo`;oD?l00oooool2o`3o40;oB_l02oooool01?l0oocoj?l0
ooooooooool2o`3oG`Oooooo0_oX0?l9ooooo`03oil0oolP0?oo803o00Cooooo0ol0Mol2o`3of0Wo
oooo0onh0?l00oooooook_l0onko0006ooooo`?o^?l000?o6_l0ogD0oome0?l00_me0?l01?oooooo
0?lFo`3o5_ooool3ofoo00Wooooo0ol01?l3ok80o`_ooooo1?nbo`0Jooooo`Co0_l02_ooool4o`2E
o`04oooooon10?ooP@3ooh40oa7ooooo1OmM0?l5ooooo`Go08oo<?ooool7o`3oY`go8?l01OmY0?l8
ob3o00gooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Sooooo00?o0000
ooooooooool03_ooool00on7o`3oooooooooo`02ooooo`0/oonA0?l0m_oo0?lXoi<0oon=0?ooD?l0
o`3oPol0ROooo`2loonM0?l0A_ooo`0lo`3od_l0j_ooN`3oofl0oooo0;3o043oolX0oolJ0?ooG@3o
o`3o^_nO0?ooj03oo`3o`?mY0?oo07goo`2Eoooo0<So05;oool0l_l0i?oo9P3oool0??oj0?oo03Co
oooooooo0?So05Woooooool0:?oo/P3oogGo0?l0ooH4ooooo`03oh40oonho`3ooooo00Sooooo00So
oj<0ooooooooooooS@3ooooooonC0?ooooooo`16o`;ooooo0_lbo`000ol0g_ooo`2`o`3No`02ool0
e003oooh0?oooooo0?nQ00?ooooo00?o08ooooooooooool00_oo_002ol[o0004ooooooodo`3om?l0
ooooo`;onP3o00Soo`2loooooooooooo[?l0ooooooo4o`3o<P3oooooo`?oo`3h0_me0?l;ooooo`Go
0=ko00GoTol0ofl0oom_0?ooolP0o`2do`02o`0Ro`Cooooo00?oo`38ooooooooool01Oooool00omY
o`3oooooooooo`03ooooo`;o0;[o00?oooooo`3o@?ooool00_ooool2o`0Fo`;ooooo00?o?P3ooooo
ooooool00_ooool3ool0e003oooooooo0?;oo`3b00Wooooo00?obP3oooooooooool01Oooool00on7
o`3oooooooooo`0:ooooo`03og/0oooooooooooo00?ooooo00CoD?l0oooooooooooooooo0_l0oa02
od[o00_ooooo00Coj?l0o`3oo?oooooooooo0_l0oel8ooooo`03onP0oooooooooooo00Oooooo0_nO
0?l01OlP0?oooooooooooooooooo__l000;o07Oo0_ooool00ol0omSoooooooooo`07ooooo`;o^03o
0_ooool2onko00Gooooo0onho`04ogD0o`?ooooo0_l0oaH3ofoo00Wooooo0ol01?l00ooooooo/P3o
ok80o`0;ooooo`?o/_l06_ooool4o`;o00[ooooo1?l0UOl00ol0okCoP@3ooh40o`02oh40oa3ooooo
1?mM0?l6ooooo`Co08oo9?ooool:ob3o00Oo0?nW1?lPo`0<ooooo`CoJ@3o6_ooool00005ooooool0
003oooooooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00ko
oooo00?oQol0ooooooooool00_ooool07oooT@3o0?Koo`3o:?nC0?oo00Coohd0oom_o`3o08Woool0
_?ooW@3o0?nKo`16oooo03co0>[oo`3`oomk0?ooE`3oool0/?o:0?oo6P3oo`3oUOmM0?oo0?njoil0
oooX0?oo0?o0ofT0oooooooo09Goool0b?l0Mol00_oo03`00ol0odco0?ndooX0o`02ooooo`;oo`3h
00Go02koo`0Xoonb0?ooMOl0o`3omP04ooooo`03oh40oonho`3ooooo00Kooooo00Kooj<0oooooooo
ooooS@3ooooooonC0?l2o`16o`03oooooolbo`3o<_l000;ooooo00?oo`2`ooooooooool00_l0g_l2
ool0e0;o0=ko00SooooooonG0?oooooo08oooonl0?oooooob_l0ooooo`;om?l000GoooooooX0oooj
0?ooooooool0_002ooooo`04ojco0?oooooo<P3ooc80o`;oo`3h1Oooool2ogD0o`Cooooo1Ol0g_l2
ooooo`;oTol000Koooooofl0ooooooooolP0o`2dool08_l4ooooo`;oo`381oooool00omYo`3ooooo
ooooo`03ooooo`04o`2jool0omko0?m0o`3o@0?ooooo00?o01Koooooooooool00_ln0?l2ooooo`?o
o`3D0_l20?l2ool0lP03o`3o1?oooooooooo00Kooooo0_o:0?l6ooooo`;oQol02oooool2og/0o`Co
oooo0_m@o`02ooooo`;o0?l@0_m:o`0:ooooo`;oj?l00_l0oo`2ooooo`03o`3oGooooooooooo00Ko
oooo0_oX0?l8ooooo`;oW`3o00Go803ooooooooooooooooookko0002o`1go`;ooooo0_l0omP7oooo
o`?o^03o00Coooooonko0?o^o`3ok_l01?ooool00onho`3oM@3oogD0o`03ogD0o`03oa[o0?oooooo
oooo00;ooooo0_l0oaH2ofoo00Wooooo0ol01?l2ooooo`;o/P3o2Oooool4ok;o01Wooooo1?l2o`0:
ooooo`Co09Go0_l0ok@3oh40oa3ooooo1?mM0?l5ooooo`Go08oo7_ooool:ob3o00Cooooo1_l0ojLC
ooooo`CoJ@3o7_ooool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`08
ooooo`Co00003Oooool00on7o`3oooooooooo`02ooooo`0UoonA0?l0m_oo0?lXoi<0ool02_ooS@3o
oe3o0?l0f?ooo`2loonM0?l0oi_ooooooch0oooo03co0>[oog/0oom_0?ooo`2`o`10ooo:0?oo6P3o
oed0ool0ok[oW`3oonP0ooooooooJ@3oo`0Rool0UOooo`38ool0??l0oa3oo`3bobH0ool0okCo^03o
ooX0o`02ooooo`07o`1Ioooo0?So02Sooooooonb0?ooooooo`3omP02ooooo`03oonA0?ooooooP@3o
00Kooooo00Sooj<0ooooooooooooS@3ooooooonC0?oo04Koooooo`;o<_l00oooool00ooo0;3ooooo
ooooo`02oooh0003o`3oXOoooooooooo00?oo`3D0ol0g_l01Ol0Sooob_l0ooooooodo`3ooooo00;o
nP3o0_ooool01_oo0;coooooojco0?n/o`3ooooooc80o`;oo`3h2?ooool01Ol0g_ooM@3oogD0oome
0?oo0=ko00Gooooo0_nCo`001OooooooK`3oofl0ooooooooolP000;o02;o1?ooool00ooo0<Sooooo
ooooo`06ooooo`03ofWo0?oooooooooo00;ooooo0_l0^_l2o`3o@0?ooooo0_l05_l2ooooo`03och0
oooo0=Coo`3D00;oo`3D0_ooool01Ol20?ooooooool0l_oooooo0?l400Oooooo0_o:0?l7ooooo`03
ohOo0?oooooooooo00[ooooo00?oN`3oooooooooool00_ooool2oe3o00?ooooo00?o0?l@oooooom:
o`002_ooool2onSo0004ooooool0oocoooooooooo`;o0?mO1oooool2onP0o`Oooooo00CoMOl0oil0
oonO0?oo803o0_ooool2okko00;o07Oo0_ooool2o`3of0Kooooo0onh0?l2ooooo`;ok_l00oooool5
ogD0o`04oooooolJo`3o6_l0oa[o00Cooooo0_l0oaH00om_o`3oooooooooo`07ooooo`?o00Co0ooo
ool2ok80o`Sooooo0onbo`0Iooooo`Co0_l02oooool3o`2Eo`?o0?nd0on10?l?ooooo`CoG@3o1Ooo
ool4o`2?oa3ooooo4olPo`09ooooo`Go0?nW5Oooool4ofT0ob;ooooo00001Ooooooo0000oooooooo
oooo000000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03ohOo0?oo
oooooooo00?ooooo00gooi40o`3fool0obSoT`3oohd0oom@o`3o0?n3o`29oooo0;co0?nKooo80?l0
A_oo?P3o00;oo`0l00coN`3oool0/?l0PooobP3ooaX0ool0oiGoG@3oo`3o^_nO0?ooj03oo`3o`?mY
0?l2ool0?008ool0b?l0Moooo`3bobH0ool0odco0?ndokP0oooj0?l2ooooo`08o`1Ioooo0?So02So
ok80oomeo`3oooooo`3om_ooT@03ooooo`03oh40oooooooooooo00;ooooo00Oooj<0oooooooooooo
S@3ooooooonC0?oo04Ko00;o<_l00oooool2ool0/0;ooooo00?oooP0o`3oXOl0oj401?ooool01?oo
U`3oooooool0e?oo0=@2ol[o00;o08oo0_oj0?l3o`3No`04ool0_?l0g_oo0=koo`3No`?oo`3h2_l0
g_l4ooooo`;oM@3o00Cooooooi?o0?nCo`3oTol00_ooool00om_0?ooooooooooo`02o`0Ro`Cooooo
0_oo0<P8ooooo`04ofWo0?ooooooooooooooo`;o0;[o00?o0?oNo`3o@?ooool00oooool00ol05_oo
ooooooooo`03ool0e0Cooooo0_l20?l2ool0lP03ooooool0o`Cooooo00Kooooo00?obP3ooooooooo
ool01_ooool00on7o`3oooooooooo`09ooooo`;oN`3o1?ooool01?m@o`3oooooooooooooool2o`3o
40;oB_l02Oooool2onSo00;ooooo00Co0?olooooool0oeoo0?mO1oooool2onP0o`Oooooo0_meo`00
1?nO0?oo803oooooooooool2okko00;o07Oo0_ooool2o`3of0Kooooo0_nh0?l3ooooo`;ok_l01Ome
0?l2okSo00;ooooo0_lJo`05ooooo`03ofoo0?l0oaKoKol000Sooooo0ol01?l4ooooo`;o/P3o1ooo
ool3ok;o01Sooooo1?l2o`0<ooooo`?o09Go00?oooooo`3o]?n10?l00on10?l=ooooo`GoG@3o1Ooo
ool4o`2?o`oooooo1OlPo`0Hooooo`Co0?nW5_ooool4ofT0obKooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00kooooo
00?oQol0ooooooooool00oooool06OooT@3o0?Koo`3o:?nC0?oo00Coohd0oolPo`3o08Woool0_?oo
W@3o0?nKooooooln0?oo0>[oo`3`oooo03coK`3oool0/?o:0?oo6P3oo`3og_mM0?oo0?njoil0oooX
0?l00_oo03`02_l08_oo09Goool0b?l0D_oo0?l@ool0l_lV0?oo0?ndokP0ool0=?l2ooX0o`08o`1I
oonCo`3oo`3ho`0Xoonb0?ooMOl0o`3om_ooT@04ooooo`04oh40oooooooooooooonS00;ooooo00Go
S@3ooooooonC0?oo04Kooc;o0004ooooo`06ool0/?oooooooooooooooooon03o0?nQ1Oooool01Ooo
U`3ooooooonl0?oo_03ob_l000;oo`3D0_oj0?l01ol0Soooooooooooooooooooo`2loooooon/o`00
0_oo0?P00olb0?ooooooooooo`0?ooooo`03oi?o0?me0?ooM@3o00?ooooo00GoK`3ooooooooooooo
02;oo`2do`04ooooo`03ool0b?oooooooooo00Oooooo00GoJOl0ooooooooooooooooo`2jo`02o`3o
gP04o`3o@?ooooooooooooooo`;o01Ko0ooo0=@6ooooo`03o`80oooo0?;oo`3b00;ooooo00?o0?l4
ooooooooool01?ooool2olX0o`Oooooo0_n7o`0:ooooo`;oN`3o1?ooool2oe3o00;ooooo0_l0oa02
od[o00Wooooo0_oXo`03ooooo`03o`3oo?l0oeoo0?mO00Oooooo0_oX0?l7ooooo`;oMOl00_nO0?l0
1?oooooo__l0okko0?nno`02o`1go`?ooooo00?o0?oHooooooooool00oooool3okP0o`03oooooome
0?ooM@3o00CoM@3o00CooooookSo0?nho`3o^?l00oooool2oa[o00Gooooo00?oKol0o`3o5_l0oaH0
1oooool3o`04o`Cooooo0onb0?l6ooooo`?o/_l05oooool4o`;o00gooooo0ol0UOl00ooooooo0?nd
oh40o`02oh40o`gooooo1?mM0?l6ooooo`Co08oo2oooool8ob3o01Wooooo1?l0ojLGooooo`?oJ@3o
:_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool03_ooool00on7o`3oooooooooo`03ooooo`0@oonA0?l0m_oo0?lXoi<0
ool01?ooS@3ooe3o0?l0f?ooo`2looooool0oi_oolP0o`16ooln0?oo0>[oo`3oM`Woo`0l00koj03o
o`3o`?mY0?oo07goo`2Eoooo0<So07Ooo`3o4?oo0?;o9P3oo`3o]?nh0?oo03Coooooo`;onP3o00Ko
<_l0ool0n?oo0?So/P3oogGo0?l0ooH5ooooo`08oh40ooooX`3ooooooooooon=0?oo<_l0oi<0ool0
A_l5ooooo`06ool0/?oooooooooooooooooon03o0?nQ1Oooool00oooU`3ooooooonl0002ol[o00?o
nP3o0_oo0=@01Ooooooo08ooo`2?oooo0;cooooo00;oo`3h00?ooooooc80ooooool03oooool2oi?o
00?ooooo0_me0?l01?m_0?ooooooo`0Rool08_l4ooooo`;oo`382Oooool00omYo`3oooooooooo`02
o`2jo`03o`3og_l0od3ooooo00;ooooo1?oo0=@2och0o`Gooooo0_l20?l01Ooo0?;ooooooooooooo
oooo0?l400Kooooo00?obP3oooooooooool01_ooool00on7o`3oooooooooo`09ooooo`03og/0oooo
oooooooo00?ooooo00OoD?l0ooooooooooooooooo`3o4?ooooooB_l000Wooooo0_oXo`03ooooo`;o
0?ol00?o0?mOooooooooool01_ooool00ooX0?ooooooooooo`04ooooo`?oMOl00_nO0?l3okko00;o
oooo00Co07Oooooooooooooooooo0_l0omP4ooooo`;o^03o1?me0?l01?o^o`3oooooooooooooool3
okSo00Cooooo0_lJo`04ooooo`;oKol00_l0oaH7ooooo`;o00Co1Oooool2ok80o`Kooooo0onbo`0G
ooooo`?o0_l03_ooool3o`2Eo`03ooooool0okCoP@3o00;oP@3o3?ooool4oed0o`Gooooo1Ol0Sol4
ooooo`_o8?l07?ooool5o`3oYaOooooo1?mY0?l]ooooo`000_ooool2o`0000Wooooo0ol00009oooo
o`03o`000?oooooooooo00oooooo00?oQol0ooooooooool00oooool09Ol0m_oo0?lXo`3oD_nC0?oo
00Coohd0ool0oh?o08Woool0_?l0oi_oolP0o`1[ooln0?oo0>[oo`3oMomk0?ooK`3oool0/?o:0?oo
6P3oo`3og_mM0?oo0?njoil0ool05_ooj03oofT0ool08_ooooooo`2Eoooo0<So07Ooo`3oa_oo0?;o
0?m<o`3o]?nh0?l00_ooool01?l0FOoonP3oo`0^ool0:?l2ool0n003ogGo0?l0ooKooooo00;ooooo
00So<_l0oh40oolbo`3o<_l0ohd0oooooooo04Kooi<0o`Gooooo00Coo`2`oooooooooooooooo0_l0
oj45ooooo`03oonG0?oooooom?l000?onP3o1Oooool2ool0e003ool0_?oo0?Soo`3h00;ooooo00?o
<P3oooooooooool03Oooool2oi?o00Gooooo00?oK`3ooooooome0?l00_me0?l4ooooo`03ool0b?oo
oooooooo00Sooooo00KoJOl0ooooool0^_oo0;[oo`3o@?l0omh5ool0e004o`0Foooooooooooooch0
o`Kooooo00?o0P3oool0l_oo0?800oooool00ol0o`Coooooooooo`03ooooo`;obP3o2?ooool00on7
o`3oooooooooo`08ooooo`;oN`3o1?ooool2oe3o00;ooooo0_l0oa02od[o00Sooooo0_oXo`04oooo
o`03o`3oo?l0oeoooooo00Oooooo0_oX0?l5ooooo`;oMOl000?ooooooil0oonO0?l00_nno`03oooo
o`;o07Oo0oooool01?l0omSoooooogD0oome0?l3okP0o`03ogD0oooooooooooo00;ok_l00_ooool3
okSo00Gooooo0_lJo`03ooooo`?oKol00_l0oaH6ooooo`?o00Co1Oooool2ok80o`Gooooo0onbo`0F
ooooo`Co0_l03_ooool3o`2Eo`;ooooo0on10?l:ooooo`GoG@3o1Oooool4o`2?o`Wo8?l08_ooool5
o`3oYaSooooo1?mY0?laooooo`006Oooool00ol0003oooooooooo`0?ooooo`03ohOo0?oooooooooo
00?ooooo02Ko0?Koo`3o1?l0obSoT`3oo`04oon=0?oo0?n3o`29oooo0;coooooo`3oVooooooo06_o
och0ool0l?ooN`3ooeL0oom_0?ooo`2`olX0oolJ0?oo0?nEoed0ool0ok[oW`3oonP0ool0ol3oJ@3o
o`0Rool0UOooo`38o`1Booodo`3o0>Coool0l_l0okCo^03oo`0do`;ooooo00Oo05WoooX0oooj0?oo
02Sooc;o0?oo0?So0?of00?o<_l00_ooool01On10?ooS@3oooooool0A_ooT`3o00Gooooo00Goo`2`
ooooooooooooooooo`3oX@06ooooo`04oonG0?oj0?oonP3oooX0o`Sooooo00?oo`3hool0_?n/o`00
0ooo0=@00olb0?ooa?l0ooooo`0<ooooo`;oTol01Oooool2ofl0o`05ooooool08_oo02;oo`2doooo
ool00_me0?l2ool0b0[ooooo00?oJOl0ool0e?oo0=@01?oo0=@01?lDo`3oooooooooool05_l2oooo
o`;o?P3o1Oooool00ol20?ooo`3bool0lP04ooooo`03o`3o1?oooooooooo00?ooooo00?obP3ooooo
ooooool01oooool00on7o`3oooooooooo`08ooooo`03og/0oooooooooooo00;ooooo0_m@o`02oooo
o`;o0?l@0_m:o`08ooooo`;oj?l01Oooool00ol0oocoooooooooo`06ooooo`;oj03o1Oooool2ogGo
0003oooooolP0?ooW`3o00;o__l00oooool2o`1go`;ooooo1Ome0?l2okP0o`?ooooo0oo^o`001?oo
oooo^?l0okSo0?nho`06ooooo`;o6_l00oooool2ofoo0003ooooool0oaKo0?lF00Kooooo0_l01?l6
ooooo`;o/P3o1?ooool3ok;o01Kooooo0ol2o`0?ooooo`?o09Go0_ooool3oh40o`[ooooo0omM0?l6
ooooo`Co08oo1?lPo`0Vooooo`Go0?nW6_ooool3ofT0ocGooooo000Iooooo`03o`000?oooooooooo
00oooooo00?oQol0ooooooooool00oooool09oooT@3o0?Koo`3o:?nC0?oo00Cooe3o0?n=0?oo0=So
o`29oooo0;co0?nKooo80?l0Jooo?P3oo`16ool0ogOoN`3oofl0ool0@?ooo`2`oaX0ool0omkoG@3o
o`3o^_nO0?oo01KoonP0ool0ol3oJ@3oooooool0UOooo`38o`1gool0olKo9P3oool0l_l0okCo^03o
o`0do`02ooooo`03o`1IooooT@3onP3o00;onP3o0ooo0?P3ooooo`04ohd0oon10?oo04Kooi<0o`Co
oooo0_oo0;02ooooo`;o0?nQ1_ooool2ooX0o`;ob_l01oooool2ool0n004ool0_?n/o`3ooooooooo
o`;o<P3o0ooo0=@:ooooo`;oTol01_ooool01_m_0?ooooooooooool08_ooooooo`2do`;ooooo0_oo
0<P01?ooooooM@3oogD0oome0?l4ooooo`Goo`3D00?o0;[oo`3o@?l0omh00_ooool01?lDo`3ooooo
o`0Fool05_l2ooooo`03och0oooooooooooo00Cooooo00?o0P3oool0l_ooool01?ooool00ol0o`Co
ooooooooo`03ooooo`03olX0oooooooooooo00Kooooo0_n7o`09ooooo`;oN`3o1?ooool01om@o`3o
oooooooooooooooo0?l@oooooom:o`002Oooool00ooXo`3oooooooooo`03ooooo`;o0?ol1oooool2
onP0o`Gooooo0_meo`001?oooooo803ooil0oonO0?l4ooooo`03o`1goome0?ooM@3o00?oM@3o00?o
0?oHooooooooool00_nh0?l3ooooo`;ok_l000CooooookSo0?nho`3o^?l01oooool2oa[o00;ooooo
0om_o`000ooooooo0?lFo`3o5P05ooooo`?o00Co1Oooool3ok80o`?ooooo0onbo`0Eooooo`Co0_l0
3oooool3o`2Eo`;ooooo0on10?l:ooooo`?oG@3o1?ooool5o`2?o`?o8?l09_ooool5o`3oYa_ooooo
1?mY0?lhooooo`006Oooool00ol0003oooooooooo`0?ooooo`03ohOo0?oooooooooo00?ooooo02Oo
oi40o`3fool0obSo803ooi<0ool01?ooS@3oo`3oPol0ROooo`2lo`3oVooob03o06_ooch0ool0A_oo
0?mgog/0oomG0?ooK`3oo`10oooo0;3o6P3oo`3og_mM0?oo0?njoil0oooX0?oo0?o0ofT0ool08_oo
09Gooooooooo0<Soooooo`3ToolV0?ooo`3boooooonh0?l00_ooool01Ol0FOooooooo`0^ool0:?oo
Tol000;onP3o00Oo0?ofool0n?oo0?Soo`3hooooool0A_ooT`3o00?ooooo0_oo0;03ooooo`03o`3o
XOoon03ooooo00?ooooo0ooj0?l00ooo_03ob_l0oonM0005ooooo`?oo`3h00?oooooool0_?n/o`00
0_ooool01?lb0?ooooooolCo0?ooool2o`2?o`Koo`3D00Cooooooi?o0?nCo`3oTol01oooool01?m_
0?ooooooo`0Rool08_l2o`2do`;ooooo00?oo`38ooooooooool00oooool5ool0e0;ooooo0_l0^_l2
o`3o@006o`3og_oooooooooooaCo0?oooooo01Ko0oooool00oln0?ooooooooooo`03ooooo`03o`80
oooo0?;oo`3b00Gooooo00?o0?l4ooooooooool00_ooool2olX0o`Sooooo00?oQol0ooooooooool0
2?ooool00omk0?ooooooooooo`02ooooo`;oD?l00_ooool2o`3o40;oB_l02?ooool2onSo00Cooooo
00?o0?mOo`3oo?ooool01oooool00ooX0?ooooooooooo`03ooooo`;oMOl000Coooooob00oonO0?oo
W`3o0_ooool5ogD0o`?ooooo0_l0omP00ooooooo^03ookP0o`03ooooo`;ok_l00onho`08ooooo`;o
6_l000Coooooofoo0?m_o`3oKol00_ooool2o`3o5PGooooo0_l01?l6ooooo`;o/P3o0oooool3ok;o
01Gooooo0ol2o`0@ooooo`?o09Go0_ooool3oh40o`03o`3o]?oooooooooo00Oooooo0omM0?l2oooo
o`Go08oo0olPo`0Vooooo`Go0?nW7Oooool3ofT0occooooo000Iooooo`03o`000?oooooooooo00oo
oooo00?oQol0ooooooooool01?ooool0;ol0m_oo0?lXo`3oD_nC0?oo00Coohd0ool0oh?o08Woo`2Q
oooo0;co0?nKooo80?l0Jooo?P3oo`16ool04?ooN`3oofl0ool0@?oobP3oool0/?l0omko0_l0oed0
oonO0?oo01KoonP0ool0ol3oJ@3oooooool0UOoo05;oool0b?oooooo0>Coool0l_l0okCo^03oo`0d
oooooooooi40o`1Ioooooooo02koo`0XoonCo`3o/P3o00?onP3o00Ooooooool0n?oo0?Soo`3hoh40
ooooooooo`2`00Cooooo00?o0?nQoooh0?ooool00_ooool2ooX0o`05ooCo0?ooU`3ob_l0ol[o0?oo
W@000_ooool4ool0n0;ooooo0_oo0;`3ooooo`03oc80ooooooooa?l000Cooooo00?o08oooooooooo
ool00_ooool00onCo`3oo`3Dool0e00?ool0e0;oo`381_oo0=@4ooooo`CoM@3o00?o0?m0ooooool0
omh00_ooool00olDo`3o01Koo`0Fo`02ooooo`;o?P3o1Oooool2ool0lPKooooo00?o0?l4oooooooo
ool00_ooool00oo:0?ooooooooooo`07ooooo`03ohOo0?oooooooooo00Oooooo0_mk0?l4ooooo`07
oe3o0?ooooooooooooooool0oa3ooooood[o0008ooooo`;oj?l01?ooool2o`3oG`03o`3oo?oooooo
oooo00Gooooo0_oX0?l4ooooo`;oMOl000CoooooogD0oonO0?ooW`3o1?me0?l2o`1go`Cooooo0_l0
omP00ooooooo^03ookP0o`03ooooo`04onko0?nho`3o^?l0okSo00Wooooo0_lJo`03ofoo00?ooooo
0_l0oaH4ooooo`?o00Co1_ooool2ok80o`;ooooo0onbo`0Dooooo`Co0_l04?ooool3o`2Eo`;ooooo
0on10?l00ol0okCoooooooooo`07ooooo`?oG@3o1Ol0Sol3ob3o02Kooooo1Ol0ojLNooooo`CoJ@3o
;_ooool4oeOo00gooooo000Iooooo`03o`000?oooooooooo00oooooo00?oQol0ooooooooool01?oo
ool05Ol0m_oo0?l4o`3o:?lP0?ooT`3ooe3o0?n=0?oo08Woo`2Qoooo0;co0?nKooo80?l0Jooo?P3o
o`16ool0ogOoN`3ooeL0oom_0?oo043oolX0o`02ool0/00@oed0ool0ok[oW`3oonP0ool0ol3oJ@3o
o`0Rool0UOooooooo`1Boooo0<So0?o6obH0oooo0?;o0?ndokP0o`;om?l000Coooooo`1IooooX`3o
02So0_ooool00onb0?ooS@3oo`16o`04ooX0o`;oo`2`2_oj0?l2ooooo`03oonG0?o:o`3ooooo00Co
o`3h1Oooool00ooo0;co[?l0ooooo`02ooooo`03oc80ooooooooa?l000Kooooo0_l0Sol2oi?o00Wo
oooo00?oK`3oooooool08_l00_ooool01?l0]?oooooooooooooo0<P<ooooo`;o0;[o00?o0?m0oooo
oome0?l00_me0?l00ooooooo5?l0o`0Fo`03ooooo`03och0oooooooooooo00?ooooo00?o0P3oool0
l_ooool01_ooool00ol0o`Coooooooooo`02ooooo`03olX0oooooooooooo00Kooooo0_n7o`09oooo
o`03og/0oooooooooooo00?ooooo00?oD?l0ooooooooool00_l0oa02od[o00Sooooo00?oj?l0oooo
ooooool00_ooool2o`3oG`;o0?ol1_ooool2onP0o`;ooooo1ome0?l00onO0?ooooooooooo`03oooo
o`03o`1goooooooooooo00?ooooo00Co0?oHoooooonh0?oo^03o0oooool3okSo00[ooooo0_lJo`02
ofoo00Gooooo00?o0?lFooooooooool00_ooool2o`04o`Oooooo0_nb0?l01?oooooo/_l0ok;o0?nb
o`0Dooooo`?o0_l04Oooool3o`2Eo`;ooooo0on10?l00ol0okCoooooooooo`07ooooo`?oG@3o0ol0
Sol2ob3o02Sooooo1?l0ojLPooooo`?oJ@3o:oooool5o`3oJ`Ko0?nK3Oooool001Wooooo00?o0000
ooooooooool04?ooool00on7o`3oooooooooo`03ooooo`0doonA0?l0m_oo0?lXob00oonC0?oo5?l0
ohd0ool0f?oo08Woo`3oo?oo0;coolP0o`1[ool0om;o?P3oo`16ool04?ooN`3oofl0ool0@?oobP3o
oaX0ool0]?ooo`2`oed0oonO0?oo01KoonP0ool0ol3oJ@3oo`0Rool0UOoo05;oo`1goooo0<So0>Co
obH0oooo0?;o^03oo`0doooooooom?l0o`1Iooodo`3o02koo`0XooooooooS@3ook80ool0ooKoTol0
oi<0o`;oo`2`00?ooooooh40oooo0?P03_oo0?P8ooooo`03ool0_?n/o`3ooooo00;ooooo00?o<P3o
ooooooo4o`001_ooool3oi?o0003o`2?oooooooooooo00Kooooo0_m_0?l2o`0Ro`;ooooo00Co0;Co
oooooooo0<Soo`382oooool2o`2jo`;o0?m000?oooooo`3og_ooool00_ooool5ogD0o`03och0oooo
oooooooo00?ooooo0_oo0?87ooooo`04o`3o1?ooooooooooooooo`;obP3o2?ooool00on7o`3ooooo
ooooo`07ooooo`;oN`3o1?ooool2oe3o0003ooooool0oa3o0?l@00;oB_l02?ooool2onSo00?ooooo
0_l0oel00ooooooo0?olooooo`04ooooo`03ogD0oooX0?ooj03o00CoM@3o0_meo`02okko0003ob00
oonO0?ooW`3o00Cooooo0_l0Mol4ooooo`04o`3of?nh0?oo^03ookP0o`;ooooo0onho`0;ooooo`;o
6_l00_m_o`05ooooo`;o0?lF0oooool2o`04o`Oooooo0_nb0?l3ok;o01Cooooo0ol2o`0Aooooo`?o
09Go0_ooool3oh40o`;o0?nd1oooool01Ol0SoooG@3ooed0oomM0?oo08oo00;o8?l0:_ooool3o`3o
Yb3ooooo1?mY0?lNoooooaGo0?nK4oooool001Wooooo00?o0000ooooooooool04?ooool00on7o`3o
ooooooooo`03ooooo`0HoonA0?l0m_oo0?lXob00oonC0?oo00Cooe3o0?n=0?oo08Woo`2Qoooo0;co
0?nKooo80?l0Jooo?P3oo`3`ool04?ooN`3oo`3o=?m_0?oo043oolX0oolJ0?oo0?oN0_oo0;003onO
0?ooj03oo`3o`?mY0?oo07goo`0Rool0UOoo05;oo`1goooo0<So9P3oo`3oGooo0?;o^03oo`0do`02
ooooo`0:o`1Iooodo`3o02koohd0ool0A_oo/P3oooCo0?nC0?ooo`2`oi?o00;om?l000Co0?nQoh40
oonho`3om?l01oooool2ol[o0003ooooooooW@3ooooo00Oooooo00?oo`2looooooooool00_ooool0
0olb0?ooooooolCo0004ooooo`?oTol01?ooool2o`2?o`Gooooo00?oK`3oooooool08_l00_ooool2
o`2do`03oooooooo0<Sooooo00_ooooo00?o0;[oo`3o@?l0od000_ooool01_l0omkooooooooooooo
oooo01KooaCo00?ooooo00?o?P3oogD0oome0?l00_me0?l2ool0lPSooooo00Go0?l4oooooooooooo
ooooolX0o`09ooooo`03ohOo0?oooooooooo00Oooooo00?oN`3oooooooooool00oooool01_m@o`3o
ooooooooool0oa3ooooood[o00Sooooo0_oXo`03ooooo`;o0?mO0_ooool7ogD0o`04onP0oooooooo
ooooooooo`;oMOl000Cooooookko0?nno`3ooooo0_nO0?l4ooooo`;o07Oo1Oooool2okP0o`?ooooo
0_nho`02onko00[ooooo0_lJo`000om_o`3oooooooooo`04ooooo`;o0?lF0_ooool3o`04o`Kooooo
0onb0?l2ok;o01Cooooo0ol2o`0Aooooo`?o09Go0_ooool3oh40o`;o0?nd1Oooool3o`2?o`?oG@3o
00?o8?l0ooooooooool0:Oooool4o`3oYb3ooooo0omY0?lGooooo`_o0?nK00?o0?m[ooooooooool0
1Oooool5oeOo01_ooooo000Iooooo`?o00004?ooool00on7o`3oooooooooo`04ooooo`0Xo`3fool0
obSo0?mBob00oonC0?ooD?l0ofoo0?n=0?oo0:7ooooooooo0;coolP0o`1[ool0om;o?P3oo`3oMomk
0?ooE`3oo`80oom_0?oooj<0olX0oolJ0?oo0?oNoed0oooo0;3oooooonP0ool0ol3oJ@3oo`1mool0
8_ooooooo`1Boooo0<So0>CoobH0ool0okCoo`3bokP0o`?ooooo00Go05Woohd0ool0;_oo02Sooooo
o`02ool0/0Co0?nQ00Cooooooooh0?n10?oo^?l01_ooool01?o:o`3oooooooooooooW@08ooooo`04
ool0_?ooooooooooooooo`;o<P3o00?oooooolCo0?ooool01?nCo`09ooooo`05o`2?oooooooooooo
oooooom_0?l00_l08_l2ooooo`04o`2doooob03oo`38ool0b0_ooooo0_l0^_l00ol0od3oJOl0oooo
o`02o`3ogP?ooooo00Co01KooaCo0?oooooooooo0_ln0?l3ooooo`;oo`3b00?oooooogD0oome0?l0
0ome0?l3ooooo`05o`3o1?ooooooooooooooooo:0?l02?ooool2ohOo00Wooooo00?oN`3ooooooooo
ool00_ooool2oe3o0003ooooool0oa3o0?l@00;oB_l02?ooool01OoXo`3ooooooooooooooooo0?mO
00GoM@3o1Oooool2onP0o`;ooooo0_meo`03okko0003oooooonO0?ooW`3o00Cooooo0_l0Mol5oooo
o`;o^03o0_ooool3okSo00;ok_l02Oooool00om_o`3o6_l0oa[o0007ooooo`;o0?lF0_ooool2o`04
o`Oooooo0_nb0?l2ok;o01Cooooo0ol2o`0Aooooo`?o09Go0_ooool3oh40o`?o0?nd0_ooool5o`2?
o`?oG@3o:oooool4o`3oYb7ooooo0omY0?lBooooo`So0?nK00?o0?m[ooooooooool02oooool5oeOo
00cooooo1ol0OOl=ooooo`006Oooool00ol0003oooooooooo`0@ooooo`03ohOo0?oooooooooo00Co
oooo02Wo0?Koo`3o1?l0obSo803ooi<0oom@o`3oa?l0ohd0ool0ROoo0?olool0_?oooooo06_oo`3o
d_ln0?oo0?mgo`0@oomk0?oo0?ldofl0oolb0?oobP3ooaX0ool0]?ooG@3oo`3o^_oo0;3oj03ooon;
0?mY0?oo07goooooool08_oo05;oo`1goooo0<So9P3oo`3oC?l0okCoo`3bo`0do`02ooooo`03ohd0
ool0A_ooo`2`00;oo`2`00Co0?nQok80ool0ooKoMOl00_ooool3oi?o0003oh40oonho`3ooooo00;o
oooo0_o:o`02ooooo`03oonM0?oooooooooo00Gooooo00?o[?l0ool0_?ooool00_ooool00olb0?oo
ooooooooo`03oi?o00kooooo00Co08ooofl0oom_0?oo02;o0oooool00ol0]?ooo`38ool0b00;oooo
o`;o0;[o00Go0?m0oooooomYo`3oooooo`3ogP03ooooo`;o01Ko00Co5?l0oooooooooooo?P3o0ooo
ool2ool0lP03o`80oooooooooooo00Gooooo1Ome0?l2olX0o`?oM@3o1Oooool00on7o`3ooooooooo
o`07ooooo`;oN`3o1?ooool01_m@o`3oooooo`3o4?l0oa3ooooood[o00Cooooo2ome0?l3ooooo`03
o`3oo?oooooooooo00;ooooo0_oX0?l2ooooo`;oMOl00_nno`02ooooo`;oW`3o1?ooool2o`1go`Go
oooo0_nh0?l01Ooooooo^?l0okSo0?nho`3ooooo00;ok_l02Oooool00om_o`3o6_l0oa[o0007oooo
o`;o0?lF0_ooool2o`04o`Oooooo0_nb0?l00onbo`3oooooooooo`0Booooo`?o0_l04_ooool2o`2E
o`;ooooo0on10?l01?oooooo0?ndo`3o]?ooool4o`2?o`;o8?l00omM0?l[ooooo`?o0?nW8_ooool3
ofT0o`kooooo1ol0oi/Aooooo`GoEol01_ooool;o`1mo`?ooooo1?mG0?l=ooooo`006Oooool00ol0
003oooooooooo`0@ooooo`03ohOo0?oooooooooo00Cooooo01_ooi40o`3fool0obSo803ooi<0oolD
o`3oD?l0o`3oPon=0?oo0:7ooooooooo0;coolP0o`1[ool0j_oo?P3oo`0@oomk0?ooE`3oo`23oom_
0?oob_l0olX0oolJ0?oo0?oNoed0oonO0?l00ooo0;003?mY0?oo07goo`2Eool08_oo05;oo`1goooo
0<So9P3oo`3oXOoo0?;o^03oo`0do`?oo`2`00?o0?nQoi<0ool0:?l00_ooool01?nb0?oo0?ofogGo
0?oon003ooooo`06oi?o0?n10?ooTol0oi?o0?o:o`3ook`00_ooool00oooW@3oooooooooo`05oooo
o`06ojco0?oo0;cooooooooooonCo`3o<P3o0onCo`0Aooooo`03ofl0ool08_oo08oo00?ooooo00?o
0;Coool0b?ooool02oooool01ol0^_oo0?m0oon;0?ooooooJOl0ooooool0omh00oooool00ol05_oo
oooooaCo0002ooooo`03och0oooooooooooo00;oo`3b0_l20?l9ooooo`04o`3o1?ooooooooooolX0
o`Gooooo3_me0?l00omk0?ooM@3oogD0o`0>ogD0o`;ooooo0_oXo`03ooooo`03o`3oGooooooooooo
00?ooooo00?o0?olooooooooool00_ooool00ooX0?ooooooooooo`02ogGo00;o__l00oooool00onO
0?oo803oooooo`03ooooo`03o`1goooooooooooo00?ooooo0_nh0?l00ol0omSo^?l0okSo0002oooo
o`;ok_l02Oooool00om_o`3o6_l0oa[o0007ooooo`;o0?lF0_ooool2o`04o`Oooooo0_nb0?lDoooo
o`?o0_l04_ooool3o`2Eo`04oooooon10?ooP@3ooh40o`;ooooo00?o0?ndo`2?ool0Sol00_l0Sol2
ob3o0004oooooomM0?ooG@3ooed0ob_ooooo0ol0ojLRooooo`?oJ@3o2_ooool7o`3oVa?ooooo1OmG
o`03ooooo`So07go1oooool7oeL0oa7ooooo000Iooooo`03o`000?oooooooooo017ooooo00?oQol0
ooooooooool01?ooool07Ol0m_oo0?lXob00ool02_ooT`3ooe3o0?m_o`3oS@3oo`2Qooooooooo`2l
ooooool0Jooo0?oBoch0ool0ogOo013oog/0ool0A_ooK`3ooc80ooo:0?oo6P3oo`2doomM0?oo0?nj
oil0oooX0?oo0:ko00?oo`2`00Ko09Goo`0Rool0Mooo0?o6ool0b?lV0?l3ool0/0;o0?nQ00Gooooo
oi<0oooooooo02koo`0Xo`02ooooo`03ok80ool0ooKooooo00Gooooo0_n10?l<oi?o0003ool0_?nC
o`3oTol000;o<P3o0_ooool00oo4o`3oooooooooo`0>ooooo`;oK`3o00?o02;oooooooooool00_l0
Sol2ool0b0_ooooo0_l0^_l01?ooR`3oooooooooooooool2o`3ogP;ooooo0_l05_l00ooooooo5?l0
ooooo`02och0o`05oooooooo0?;oo`3booooool20?l02_ooool01?l0o`Coooooooooooo:0?l9oooo
o`03ohOo0?oooooooooo00Kooooo0_mk0?l4ooooo`;oD?l00_l0oa000oooooooB_l0ooooo`07oooo
o`04onSo0?ooooooooooooooo`;o0?mO1?ooool2o`3oo0?ooooo0_oX0?l00oooooooMOl0ogGo0002
okko00?ooooo0_nO0?l4ooooo`;o07Oo1?ooool2okP0o`03o`3of?nho`3ooooo00;ooooo0_o^o`09
ooooo`;oKol000?o6_l0ooooooooool01_ooool00ol0oaKoooooooooo`02o`04o`Oooooo0_nb0?lC
ooooo`?o0_l04_ooool3o`2Eo`05oooooon10?ooP@3ooh40ooooool01Ol0Sol01?lPo`3ooooooooo
ooooool3oed0ob_ooooo0ol0ojLSooooo`;oJ@3o1_ooool7o`3oVaGooooo1OmGo`000ooooooo07go
o`1mo`05o`1mo`Sooooo1omG0?lHooooo`006Oooool00ol0003oooooooooo`0Aooooo`03ohOo0?oo
oooooooo00Cooooo01oo0?Koo`3o:?l0oe;o803ooi<0oom@o`3oa?l0o`3Hoon=0?oo0?olo`3oVooo
0;co06_oo`3od_ln0?oo0?mgo`0@oomk0?ooE`3oo`16oom_0?oo<P3oolX0oolJ0?oo0?oNoed0oonO
0?ooooooonP0ool0ol3oJ@3o00Ooo`2`00Oo04Koohd0oooo0?;o^03ooooooonC0?oo05Wo00;ooooo
00Ko02Sooooooooon03o/P3oo`3om_meo`04ooooo`;ob_l000Cook`0oh40oonho`3ooid01oooool0
1On/o`3oo`2loooooooooooo<P3o00?ooooo00?oa?l0ooooooooool03_ooool00om_0?oo02;ooooo
o`03ooooo`04o`2doooo0<So08ooo`2?o`Wooooo0_l0^_l00oooR`3oooooooooo`02ooooo`05o`3o
g_ooooooooooooooool05_l00_ooool01?lDo`3ooooooch0ooooool2ool0lP03ooooool20?oo0P3o
00[ooooo00Co0?l4ooooooo:0?oobP3o2Oooool00on7o`3oooooooooo`06ooooo`03og/0oooooooo
oooo00?ooooo00CoD?l0o`3o4?l0oa3ooooo0_m:o`07ooooo`;oj?l00_ooool2o`3oG`Gooooo00?o
0?olooooooooool00_ooool01OoX0?ooooooogGo0?meo`3o__l000Cooooo0_nO0?l01?lP0?oooooo
ooooooooool2o`1go`Cooooo0_nh0?l2o`3of0Cooooo00?ok_l0ooooooooool01oooool2ofoo00;o
6_l01oooool2o`3o5P?o00Co1_ooool3ok80oa;ooooo0ol2o`0Cooooo`;o09Go00Cooooooh40oon1
0?ooP@3o1?l0Sol00ol0okCo8?l0ooooo`03ooooo`?oG@3o:oooool3o`3oYb?ooooo0omY0?l2oooo
o`Ko0?nK00?o0?m[ooooooooool05?ooool4oeOo00Oo07go2?ooool7oeL0o`?ooooo3ol02_l=oooo
o`006Oooool00ol0003oooooooooo`0Aooooo`03ohOo0?oooooooooo00Cooooo02Ko0?Koof?o0?l0
obSo803oo`04oonC0?ooD?l0o`3oPol0ROooS@3ooooooooo0;coooooo`1[ool0j_oo?P3oo`3o5_l0
4?ooN`3oo`3o=?l20?ooK`3oolX0oolJ0?oo0;Cooed0ool0ok[oW`3ooooooooX0?oo0?o0ofT0ool0
OOoo09Goo`1Bool08_oo04Koohd0o`;oo`3800Wo0?ndool0l_nh0?ooT`3oooooool0FOooooooo`0^
ool0:?l00_ooool00onb0?oo0?ofogGo0003ol[o0005oonl0?oooooooooooooooon10?l00_nho`04
ooooo`;o[?l000Coo`2loooooolb0?oo<P3o0oooool00oo4o`3oooooooooo`0=ooooo`;oK`3o1Ooo
ool2ool0b003ooo80?oooooooooo00;o08oo1_ooool00ol0^_oooh/0oon;0004ooooo`03o`3og_oo
oooooooo00;o01Ko0_ooool00olDo`3ooooooch0o`02ool0lP;ooooo00?o0P3oooooooooool02Ooo
ool00ol0o`CoooooolX0o`0:ooooo`03ohOo0?oooooooooo00Gooooo0_mk0?l5ooooo`05oe3o0?l0
oa3ooooooooooom:o`001oooool2onSo00;ooooo0_l0oel6ooooo`04o`3oo?ooooooooooooooo`;o
j03o0_meo`000onno`3oooooooooo`02ooooo`;oW`3o00Co803ooooooooooooooooo0_l0Mol4oooo
o`;o^03o00?o^?l0o`3of?ooool00oooool2onko00Sooooo0_m_o`02oa[o00Oooooo0_l0oaH2o`04
o`Oooooo0_nb0?l00onbo`3oooooooooo`0?ooooo`?o0_l04oooool3o`2Eo`?oP@3o0ol0Sol3o`3o
]0Cooooo0omM0?l[ooooo`?o0?nW9?ooool2ofT0o`Go0?nK0_l0of/Fooooo`;oEol01ol0OOl6oooo
o`;o00[o1omG0?l:o`0:oacooooo000Iooooo`03o`000?oooooooooo017ooooo00?oQol0oooooooo
ool01Oooool02Ol0m_oo0?lXob00ool02_oo00Cooi<0ool0oh?o08Woo`2Qo`02ohd0o`0Dool0_?l0
Jooo0?oBoch0ool0ogOo013oog/0oomG0?oo08?oofl0oolb0?oobP3ooaX0ool0A_ooG@3ooil0oooo
ooooj03oo`0FoomY0?l4o`16o`0>ohd0ool0olKo9P3oo`2joooo0<So0?ndool0l_nh0?oooooooooh
0?l0FOooooooo`0^ool0:?l2ooooo`05ok80ool0ooKoMOl0oonl0?ooU`000oooool01_ooW@3ooooo
oh40oooooooo^?l0ooooo`;o[?l000Coooooool0_?oooooo<P3o1?ooool00oo4o`3oooooooooo`0=
ooooo`03ofl0oooooooooooo00?ooooo00Co0;Coool0b?ooooooolP01Oooool2o`2?o`;ooooo0_l0
^_l00oooR`3oooooooooo`02ooooo`;o0?oN0_ooool00ol05_ooooooooooo`02ooooo`03oaCo0?oo
0?;oo`3b00?ooooo00?o0P3oooooooooool02Oooool00ol0o`CoooooolX0o`0:ooooo`03ohOo0?oo
oooooooo00Gooooo00?oN`3oooooooooool00oooool01?m@o`3o0?l@o`3o4?ooool2od[o00Kooooo
0_oXo`02ooooo`;o0?mO1oooool01_l0oocoooooooooooooooooj03oogGo00;o__l01Oooool00onO
0?oo803oooooo`03ooooo`05o`1goooooooooooooooooonho`000_nh0?l00ooooooo0?oHo`3of003
ooooo`;ok_l02?ooool2ofoo0003oooooolJo`3ooooo00Kooooo0_l0oaH2o`04o`Oooooo0_nb0?l0
0onbo`3oooooooooo`0?ooooo`;o0_l05?ooool2o`2Eo`03oooooon10?ooP@3o00;o08oo0_lPo`02
o`3o]0Cooooo0omM0?l[ooooo`?o0?nW8oooool01?l0oi_oJ@3oofT0oomY0?l2o`3oV`;o0?m[5ooo
ool3o`1mo`_o00[o1omG0?l4o`3oC1Kooooo1_lJ0?l=ooooo`006Oooool00ol0003oooooooooo`0A
ooooo`03ohOo0?oooooooooo00Gooooo02ko0?Koo`3o:?lP0?oo00[oo`04oonC0?ooooooo`3Hool0
ROoo0?olo`3oVooo0;co06_oo`3od_l0j_oo?P3oo`3o5_l04?ooN`3oo`3o=?l0PoooK`3oolX0oolJ
0?oo04Kooed0ool0A_ooW`3oo`16oooX0?oo01KoofT0ool0OOoo09Goohd0oolho`3o02;oo`3ToolV
0?oo0;[oool0b?ooooooo`3bo`3o@?oooooo05Wo0_ooool01ol0:?oob_l0ol[o0?oo_03o/P3ooooo
oomeo`000oooool01OooW@3oooooooooooooooooP@3o00;o[?l000Go^?l0oooooooo0;cooooooc80
o`04ooooo`03olCo0?oooooooooo00cooooo0_m_0?l5ooooo`;oo`3800?oooooooo80?ooool01ooo
ool2o`2?o`03oon;0?oooooooooo00?ooooo00?o0?oNofWo0?ooool00_l05_l4ooooo`;oo`3b0ooo
ool2o`80o`cooooo0_o:0?l:ooooo`03ohOo0?oooooooooo00Cooooo0_mk0?l5ooooo`;o0?l@0_oo
ool00om:o`3oooooooooo`05ooooo`03onSo0?oooooooooo00;o0?mO2?ooool00ol0oocooooooooo
o`02onP0o`;o__l01Oooool2oil0o`04ob00ooooooooooooooooo`;o07Oo00?ooooookSo0?nho`00
0_nh0?l2ooooo`04o`3of?ooooooooooooooo`;ok_l02?ooool2ofoo0003oooooolJo`3o6_l000Oo
oooo00?o0?lFo`04ool01?l01oooool2ok80oa7ooooo0ol2o`0Cooooo`;o09Go00Go08oooh40oon1
0?ooP@3oooooo`02ob3o00?o0?nd0oooool3oed0ob_ooooo0ol0ojLQooooo`?o0?nK0omY0?l2o`3o
J`kooooo4Ol02_l4ooooo`OoE`3o0_ooool4o`3oC13ooooo2olJ0?lCooooo`006Oooool00ol0003o
ooooooooo`0Aooooo`03ohOo0?oooooooooo00Gooooo02Go0?Koo`3o:?l0oe;o803oo`04oomMo`3o
T`3oo`3oPol0ROoo0?oloooooon=0?ooo`2lo`1[ool0j_oo?P3oo`3oMol04?ooN`3ooeL0ool0Pooo
0P3oofl0ooo:0?oo6P3oo`2doomM0?oo0?njoil0ool0[_ooj03oofT0ool0OOooS@3oo`2Eool0D_oo
07Oo00;o02;o017oT`3oo`2joooo0<SoooP0ool0l_l0od3oooooo`1Iooo:o`3o02koo`0Xoooo_03o
oooooonG0?nb0?ooooooogGo0002oonM00Cooooo00Go[?l0oh40ooooooooooooool0_002oc80o`Co
oooo00?oa?l0ooooooooool02oooool00ol08_ooK`3oooooo`04ooooo`;oo`380_ooool00ooob03o
ooooooooo`05ooooo`04o`3o@?l0^_oooh/0oon;00;o08oo0oooool01?l0omkoJOl0o`0Fool05_l4
ooooo`;oo`3b1?ooool00ol20?ooooooooooo`0;ooooo`03olX0oooooooooooo00Wooooo00?oQol0
ooooooooool01?ooool00omk0?ooooooooooo`03ooooo`04oe3o0?l0oa3oooooooooo`;oB_l01_oo
ool2onSo0003ooooool0oeoo0?mO00Wooooo00Go0?oloooooomeo`3oj03ookko0006ooooo`;oW`3o
00Co803ooooooooooooooooo0_l0Mol3okSo00;o^03o0_ooool2o`3of0;ooooo0_o^o`08ooooo`;o
Kol000?ooooooa[o0?lJo`001oooool00ol0oaKo00Coo`04o`07ooooo`;o/P3o4Oooool2o`;o01?o
oooo00Co09Goo`2?ool0Sooo08oo0_n10?l01?oooooo8?l0ob3o0?lPo`02o`3o]0?ooooo0omM0?l[
ooooo`?o0?nW7oooool5o`3oV`03o`3oJomY0?ooJ@3o00[ooooo2Ol02_l3ooooo`Ko07go00?oEol0
ooooooooool01?ooool5oeL0o`Gooooo1?l0od`;ooooo`Wo6P3o3Oooool4o`3ol0gooooo000Ioooo
o`03o`000?oooooooooo01;ooooo00?oQol0ooooooooool01?ooool07ol0m_oo0?lXoonA0?lP0?oo
00[oo`04oonC0?oo0?n3o`29ool0XOoo0?olo`3oVooo0;coS@3oo`3od_l0j_oo?P3oo`3o5_l04?oo
N`3oo`3o=?l0Pooo0P3oofl0ooo:0?oo0;Coo`3og_mM0?ooW`3ool[o0?oX0?l00_n=0?l02Ol0OOoo
09Goooooool0D_oo07Oooi<0oolV0?oo0?m<o`2jo`02ool0b00=ool0l_l0od3oooooo`1Ioooo_03o
02koo`0XooooU`3ooooook80ool0ooKooid0ogGo0003ooooo`;o[?l00_ooool01?n10?ooo`2loc80
oonho`04ooooo`03olCo0?oooooooooo00[ooooo00?o02;oofl0oom_0?l01Oooool01Ooo0<So0;Co
ooooooooooooolP000Kooooo00Co0?m0o`2jool0^_oooh/01?ooool3o`2?o`03ofWo0?l05_oooooo
00?ooooo0_oo0?800oln0?ooooooooooo`02ooooo`03o`80oooooooooooo00[ooooo0_o:0?l;oooo
o`03ohOo0?oooooooooo00?ooooo0_mk0?l5ooooo`;o0?l@0_ooool00om:o`3oooooooooo`04oooo
o`;oj?l000?oooooo`3oGol0oel02_ooool01?l0oocoMOl0ogGo0?oX0?l7ooooo`03oil0oolP0?oo
803o00;ooooo0_l0Mol2okSo00;ooooo00Go^03oooooooooooooooooo`3of002ooooo`;ok_l02?oo
ool2ofoo00;ooooo00?o6_l0ooooooooool01Oooool00ol0oaKo00Coo`04o`06ooooo`?o/P3o4?oo
ool3o`;o01;ooooo1?l0Sol3oh40o`?o8?l000?oooooo`3o]?l0ok@00oooool2oed0obcooooo0_l0
ojLMooooo`Go0?nK0_l0of/01?ooooooJ@3oofT0oomY0?l7ooooo`Go00[o1oooool5o`1mo`;oEol0
1_ooool5oeL0o`Kooooo1?l0od`8ooooo`Oo6P3o4Oooool5o`3ol17ooooo000Iooooo`03o`000?oo
oooooooo01;ooooo00?oQol0ooooooooool01Oooool0:Ol0m_oo0?lXob00ool02_oo00Cooego0?nC
0?oo08Woo`2Qool0ooco0?nKoooooooo0;coS@3oo`3Zool0l?oo?P3oo`0@oomk0?ooE`3oo`23ool2
0?ooK`3oolX0oolb0?oo0;Cooed0oon=0?ooW`3oohd0oooX0?ooJ@3oo`1mooo:o`3o09Goo`1BoonC
0?oob_l0o`3ToolV0?oo0?m<00;o0;[o00Coo`38ool0l_l0od3o05Wo0_ooool01ol0:?oooooooooo
oooooooo/P3oo`3om_ooool00_meo`000on/o`3oooooooooo`02ooooo`04ool0_?n10?oooooooooo
o`;o^?l000?oooooolCo0?ooool02oooool00ol08_ooK`3oooooo`04ooooo`;oo`380oooool00ooo
b03oooooooooo`03ooooo`03o`3o@?l0^_oo0;[o00;ooh/01Oooool01Ol0omkoooooo`0Fool05_oo
08oo00;ooooo0_oo0?82och0o`?ooooo0_l20?l<ooooo`03olX0ool0o`Cooooo00[ooooo00?oQol0
ooooooooool00oooool00omk0?ooooooooooo`03ooooo`;o0?l@0_ooool2od[o00Kooooo00Coj?l0
oooooooooooo0?mO2_ooool2o`3oo003ogGo0?oX0?ooj03o00Kooooo0_nO0?l01_lP0?oooooooooo
oonho`3o07OookSo00?ooooo0_nh0?l3ooooo`04o`3of?ooooook_l0onko00Sooooo0_m_o`02oooo
o`;o6_l01oooool00ol0oaKo00Coooooo`05ooooo`;o/P3o00?o/_l0ooooooooool03Oooool3o`;o
017ooooo1?l0Sol01?l0UOooP@3ooh40oon10?l3ob3o0004ooooool0okCo0?ndo`3o]0;ooooo0omM
0?l[ooooo`?o0?nW6_ooool5o`3oV`03o`3oJooooooooooo00?ooooo0_mY0?l4ooooo`Ko00[o1ooo
ool5o`1mo`?oEol01Oooool5oeL0o`Kooooo1Ol0od`5ooooo`Oo6P3o5?ooool3o`3ol0[o043o3Ooo
ool001Wooooo00?o0000ooooooooool04_ooool00on7o`3oooooooooo`05ooooo`0>o`3fool0obSo
803oo`0:ool01?ooGOl0oe3o0?nC0?oo08Woo`3oo?oooooo0?nKool0_?l0Jol2ohd0o`0Moch0ool0
oaKo013oog/0ool0ocCo08?oo`80oom_0?oobP3ooc80oon=0?ooG@3ooooh0?nO0?oo0:koonP0oomY
0?oo07goo`3oYonC0?oo05;oo`1gool0olKo0>CoobH0ool0oa3o0?ndo`2joooo0<P00_oo0?802?l0
FOoooiL0o`0^ool0:?oooooooonM0?oooooo/P3o0_n/o`000oooooooMOl0ooooo`02ooooo`04ool0
_?oooooooooooh40o`?ooooo00?o^?l0ooooooooool02Oooool00ol08_ooK`3oofl0o`05ooooo`03
ool0b?l0]?oooooo00;ooooo00?oolP0ooooooooool00_ooool2o`3o@003o`2jooooR`3ooh/000Go
oooo0_l0omh2o`0Fo`;ooooo0ooo0?800ooooooo?P3ooaCo0003ooooo`03o`80oooooooooooo00_o
oooo00?obP3oo`3o1?ooool02_ooool00on7o`3oooooooooo`02ooooo`;oN`3o1Oooool01Ol0oa3o
D?l0ooooooooooooB_l000Kooooo0_oXo`000ooooooo0?mOo`3oG`09ooooo`05ogGo0?l0ooco__l0
okko0?oX0?l01_ooool2oil0o`;o803o0_nho`02o`1go`?ooooo0_nh0?l3ooooo`;o0?oH0_o^o`08
ooooo`;oKol00_ooool2oa[o00Oooooo00?o0?lFo`04ool01?l01Oooool2ok80o`03ok;o0?oooooo
oooo00gooooo0_l2o`0?ooooo`Go08oo0ol0UOl2oh40o`?o8?l00_ooool2o`3o]0?ooooo0_mM0?l[
ooooo`?o0?nW6?ooool5o`3oV`03o`3oJooooooooooo00Gooooo0omY0?l6o`0:o`Sooooo1Ol0OOl0
1?ooooooEol0oeOo0?mGo`04ooooo`GoE`3o1oooool4o`3oC0?ooooo1olJ0?l@ooooo`ko043o5ooo
ool001Wooooo0ol0000Booooo`03ohOo0?oooooooooo00Gooooo013o0?Koo`3o:?l0oe;o803oo`0:
ool01?ooD?l0o`3oPonC0?oo0:7oo`3oo?l0oi_oooooool0_?l0om;o0>[o2?n=0?l04Oo:0?ooS@3o
o`3oUOmM0?oo0?njoil0ool0[_ooj03oofT0ool05_ooT`3oo`2Eool0D_oo>?l0o`1gool0olKo9P3o
00;o02;o00[o0?ndo`0doooo0<So^03oool0l_l0FOoo0?m0o`0^ool0:?oooooo0_n/o`001onb0?oo
ooooooooooooooooMOl0oooooooo0;`01?ooool01On10?ooooooolCo0?oooooo^?l000Sooooo0_l0
8_l00om_0?ooooooooooo`03ooooo`;oo`381?ooool00ooob03oooooooooo`03o`3o@0;o0;[o00?o
oh/0ooooooooool01?ooool01Ol0omkoooooo`0FoomYo`3ooooo00;oo`3b0_ooool2och0o`;o08oo
00?oooooo`80ool20?l03?ooool2olX0o`03ooooool0o`Cooooo00Wooooo00?oQol0ooooooooool0
0_ooool00omk0?ooooooooooo`03ooooo`;o0?l@0_ooool2od[o00Gooooo0_oXo`000ooooooo0?mO
o`3oG`09ooooo`;oMOl000Co0?olokko0?oX0?ooj03o1_ooool00onO0?ooooooob00o`02okSo00;o
07Oo0oooool2okP0o`Cooooo00?o0?oHonko0?o^o`002?ooool2ofoo00?ooooo00?o6_l0oooooooo
ool01Oooool00ol0oaKo00Coo`04o`05ooooo`;o/P3o00?o/_l0ooooooooool03?ooool3o`;o00go
oooo1?l0Sol3ooooo`;o09Go0on10?l2ob3o00?ooooo0_l0ok@3ooooo`;oG@3o:_ooool3o`3oYaOo
oooo1?l0oi/00ol0of_oooooooooo`05ooooo`?o00[o0_mY0?l2o`0:o`[ooooo1Ol0OOl2ooooo`Co
Eol00_ooool5oeL0o`Sooooo1?l0od`7oaX0o`cooooo2ol0@?l2ooooo`Go0?o`4?ooool00olno`3o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0Booooo`03ohOo0?oooooooooo00Gooooo
02ko0?Koo`3o:?oooooo803oo`0:ool01?ooGOl0oe3o0?l0ROooT`3oo`3oo?l0oi_oooooool0_?l0
om;oooooo`3Zooln0?oo0?lFo`0@oomk0?oo0?ldo`23ool20?ooooooolX0oom_0?oo0_l0oed0oolb
0?ooW`3oo`2^oooX0?ooT`3oo`0Fool0ojOo09Goo`1Bool0Moooooooo`3ToolV0?oo0?m<o`0Rool0
okCo03Co0_oo0<P01Ooo0?;ooid0o`3o@?l0;_oo02So00?ooooo00Ko/P3ooooooooooooo<P3oool0
_?nno`05ooooo`04oh40ooooooooooooooooo`;o^?l00oooool3o`0Ro`;oK`3o0oooool3ool0b003
o`2doooooooooooo00;ooooo00GoolP0o`3o@?l0od3o0?m0ooooo`02o`2jo`;ooh/01_ooool01?l0
omko01Koo`0FoomYo`02ool0lP?ooooo00Oo?P3ooooooooooooo5?l0ooooool20?oo08oo00cooooo
00CobP3ooooooooooooo0?l42_ooool01?n7o`3oooooooooooooool2og/0o`Cooooo0_l0oa001?m@
o`3ooooooooooom:o`06ooooo`04onSo0?oooooo0?mOo`3oG`Wooooo0_meo`001?nno`3o0?oloooo
oooX0?l6ooooo`;oW`3o00?o^?l0ob00ooooool00_l0Mol3ooooo`;o^03o1?ooool2o`3of003onko
0?oooooooooo00Kooooo0_m_o`03ooooo`;o6_l01oooool2o`04o`Gooooo0_nb0?l00onbo`3ooooo
ooooo`0<ooooo`;o0_l03?ooool4o`2?o`Gooooo00Co09Gooh40oon10?ooP@3o0_lPo`03ooooo`?o
0?nd0_ooool3oed0obWooooo0ol0ojLGooooo`?o0?nK00?o0?m[ooooooooool00_ooool7o`0:o`03
oooooomY0?ooJ@3o00Wooooo1Ol0OOl3ooooo`CoEol00_ooool4oeL0o`Sooooo0_l0od`7oaX0o`So
oooo2ol0@?l9ooooo`Co0?o`4?ooool3ocko00?o03Co3Oooool001Wooooo00?o0000ooooooooool0
4oooool00on7o`3oooooooooo`04ooooo`0/o`3fool0o`Co0?lXob00ool02_oo00Cooego0?m@o`3o
0=Soo`29oonC0?ooooooo`3oVoooooooo`2looo80?l0j_oo0?3ooch0ool04?oo0?o<og/0ool0Pooo
09_oo`80ooo:0?oo6P3oofl0oomM0?oo0;Cooc80oonO0?ooj03oo`3o`?mY0?oo01Koo`2Eoooooooo
05;oo`1gool0olKo0>CoobH0ool0oa03o`0Ro`03okP0oooo0<Soo`3b00;o[?l000Wo02Soo`3o@?oo
oooooooook80oooooooo<P3oool0_?ooool00_meo`03ooooo`03olCo0?ooooooP@3o00Cooooo00?o
^?l0o`0Rool08_l00_ooool01?m_0?ooooooooooooooool2ool0b003ooooool0]?oo0;Co00?ooooo
0ol0od001?oooooo0;[oo`2jool0^_l2oon;00Kooooo00Co0?oNo`0Fool05_oooooo0_oo0?84oooo
o`06och0oooooooooooooaCo0?oooooo0P3o0_ooool3o`2?o`Oooooo0_o:0?l2ooooo`03o`3o1?oo
oooooooo00Sooooo00GoQol0ooooooooooooooooog/0o`04ooooo`;o0?l@00?ooooooe3o0?ooool0
0_m:o`05ooooo`;oj?l00_l0oel8ooooo`?oMOl000?o__l0ooooool0oo`00_oX0?l5ooooo`;oW`3o
00?o^?l0ob00oolP0?l00_l0Mol3ooooo`;o^03o1Oooool00ol0omSok_l0onko0008ooooo`04ofoo
0?ooooooooooooooo`;o6_l01oooool2o`04o`Gooooo0_nb0?l00onbo`3oooooooooo`0<ooooo`;o
0_l02Oooool5o`2?o`Oooooo0on10?l2ob3o00Cooooo0_l0ok@3ooooo`;oG@3o:Oooool3o`3oYaKo
oooo1?l0oi/00ol0of_oooooooooo`05o`0:o`Gooooo0omY0?l6ooooo`Go07go1Oooool3oeOo00;o
oooo1?mG0?l7ooooo`Oo6P3o1Oooool:o`10o`oooooo1Ol0oo0=ooooo`Ko?_l01?l0=?l@ooooo`00
6Oooool00ol0003oooooooooo`0Cooooo`03ohOo0?oooooooooo00Gooooo01go0?Koo`3o:?l0oe;o
803oo`0:ool01?ooD?l0o`3oPol0ROooT`3oo`3oo?l0oi_oooooool0_?l0om;oooooo`3Zool0ogOo
?P3oo`0@oomk0?oo0?oHo`23ool20?ooooooolX0oolJ0?ooK`3ooed0o`02oi<0o`0Aoil0oooX0?oo
J@3oo`1mool05_oo09Goo`1Boolho`3o07Ooo`3ToolV0?oo0?m<o`3o4?l0okCo03Coo`0Roonh0?l0
0_oo0<P02?oooooo02koo`0Xool0od3ooooooc80oonb0?ooo`2l1?ooool00omeo`3o__l0olCo0003
ooooo`03oh40oooooooo02;o00;o02;o0_nho`02ofl0o`04oooooooo0<Soo`38ool0b0;ooooo00Co
0;Cooooooooooooooooo0_l0od001Ooob03oooooo`2jool0^_oooooo00;ooh/01oooool00ol0omko
01Koooooo`02ool0lPCooooo0_ln0?l2ooooo`03oaCo0?l20?oo0P3o00Kooooo0_l0Sol4ooooo`05
olX0ooooooooooooooooool0o`@02_ooool00on7o`3oooooooooo`02og/0o`Cooooo00Ko0?l@oooo
oom@o`3oD?l0oooooom:o`05ooooo`;oj?l00_l0oel7ooooo`?oMOl00_nno`02ooooo`03o`3oo?oX
0?oooooo00?ooooo0_nho`001_nO0?oooooooooooolP0?ooooooo`1go`?ooooo0_nh0?l5ooooo`;o
0?oH00?ok_l0ooooooooool01_ooool2ofoo00?ooooo00?o6_l0ooooooooool01Oooool2o`04o`Go
oooo0_nb0?l00onbo`3oooooooooo`0;ooooo`?o0_l01_ooool5o`2?o`[ooooo0_n10?l2ob3o00Go
oooo0_l0ok@2ooooo`?oG@3o:?ooool3o`3oYaGooooo1?l0oi/00ol0of_o00[oo`0:o`04o`0:o`So
oooo0_mY0?l5ooooo`Co07go1_ooool4oeOo00GoE`3o1_ooool5oaX0o`04o`3oC?oooooooooooooo
o`So043o5?ooool5o`3ol0_ooooo1olno`02ooooo`Co03Co5?ooool001Wooooo00?o0000oooooooo
ool04oooool00on7o`3oooooooooo`05ooooo`0:o`3fool0obSoooooob00ool02_oo00Cooego0?l0
oh?o08Woo`2Qo`;oT`3o02Koooooo`1[oooo0;coolP0o`3Zool0l?oo?P3oo`0@ool0olcoN`3oo`23
ool0Vooo0P3oo`3<ooo:0?oo0?nEoi<0ool0ok[o0;Cooil0ool0[_ooj03oofT0ool0OOoo01Koo`2E
ool0D_oo07Ooo`3oa_l0i?oo9P3oo`3oC?l0oa3o0?ndo`0dool0oeoo^03oo`0Ro`?oo`380_lb0?l0
0ol0od3oo`2lok80o`05ooooo`04ogGo0?nno`3oooooooooo`;o02;o00CoP@3ooooooooooooooooo
0_m_0?l00onho`3oo`38ool0b003ooooo`;o0;Co00Koooooo`3o@?l0od3o0?m0oooooooob002o`2j
o`03ooooooooR`3ooh/000Sooooo00Go01Koool0l_oo0?;oo`3bofWo0004ooooo`06och0oooooooo
oooooooooolDo`3o0P3o2_ooool3o`2?o`05olX0ooooooooooooooooool0o`@02_ooool01?n7o`3o
oooooooooomk0?l4ooooo`;o0?l@00?ooooooe3o0?ooool00_m:o`05ooooo`03onSo0?oooooo0?mO
00Oooooo0_meo`03okko00?ooooo0_oX0?l2ooooo`?o^?l00_nO0?l00ooooooo803oob00o`02o`1g
o`;ooooo0_nh0?l6ooooo`03o`3of?o^o`3ooooo00Oooooo0_m_o`03ooooo`;o6_l01oooool00ol0
1?oo0?lFooooo`03ooooo`;o/P3o00?o/_l0ooooooooool02oooool2o`;o00?ooooo1_l0Sol<oooo
o`?oP@3o00?o8?l0ooooooooool01?ooool2o`3o]0;ooooo0_mM0?lXooooo`?o0?nW5Oooool3o`3o
V`Go00[o2oooool3ofT0o`?ooooo1?l0OOl7ooooo`?oEol01?mG0?l5ooooo`Ko6P3o0ol0od`00ooo
oooo043oo`10o`03o`10oaOooooo1Ol0oo0:ooooo`Ko?_l01Oooool4o`0doaSooooo000Iooooo`03
o`000?oooooooooo01?ooooo00?oQol0ooooooooool01Oooool0<_l0m_oo0?lXoooooolP0?oo00[o
o`04oomMo`3oD?l0o`3Hool0ROoo0?oloooooonC0?ooooooo`1[oooo0;cooi40o`3Zool0ogOo?P3o
o`3oIOmk0?oo0?oHo`23ool20?oooooooi<0ooo:0?ooj?l0ofl0ool0omko0;Cooil0oooX0?ooJ@3o
o`1moooooooo01KooonG0?l0D_oo07Ooo`3oa_l0i?oo9P3ooeOo0?l0okCoooooo`0dool0oeoo^03o
0_lb0?l01?oo0?;oo`38ool0_?oo0;`2o`0Ro`03ok80ool08_oo02;o00Ko02;o0oooool00on10?oo
o`38ool0b003ool0b006okSo0?ooooooooooooooool0]?oooooo0_l0od03ooooo`;o0;[o00?ooooo
oon;0?ooR`002?ooool00ol05_ooo`3bool0lP02ooooo`04ofWo0?ooooooooooooooo`;o?P3o0ooo
ool2o`80o`cooooo0_o:0?l3o`2?o`03ooooool0o`Cooooo00Sooooo00CoQol0oooooomk0?ooN`3o
0oooool2o`3o40;ooooo00?oD?l0oooooom:o`001Oooool2onSo00;o0?mO1Oooool3ogGo00;o__l0
1Oooool00ooX0?oo0?olokSo0002okSo00;ooooo00CoW`3ooooooooooooo803o0_l0Mol2ooooo`;o
^03o1_ooool2o`3of0Sooooo0_m_o`04ooooo`03oa[o0?oooooooooo00Gooooo0_l01?l3ooooo`?o
/P3o3_ooool2o`;o00Go08oo3oooool3oh40o`;o8?l01_ooool2o`3o]0;ooooo0_mM0?lWooooo`?o
0?nW5Oooool00ol0oi_o00[oo`0:o`03o`0:o`kooooo0_mY0?l00ooooooo07goo`1mo`03o`1mo`Oo
oooo1?mGo`03oeL0o`Cooooo1OlJ0?l2ooooo`?o0?m<1Ol0@?lGooooo`Go0?o`2_ooool5ocko00Oo
oooo1?l0=?lLooooo`006Oooool00ol0003oooooooooo`0Cooooo`03ohOo0?oooooooooo00Gooooo
00go0?Koo`3o1?l0obSo0?mBob00ool02_oo00Coooooool0oh?o08WoolCo0?l0ooco0?nK00;oT`3o
00So0?oBool0_?l0j_oo0?3ooch0ool04?oo0?o<og/0o`?oT`3o00[o0<cooaX0ooo:0?ooG@3oofl0
ool0omko0;Cooil0oooX0?ooJ@3o0olb0?l01_l0D_oo>?l0o`1gool0i?oo9P3oo`3oC0Co<P3o00Oo
0?mOokP0ool0FOoo0;[oool0_?oo0?;ooooo00ooo`3800?oP@3oooooooooool00oooool2o`3o@003
o`2dool0od3o0?m000;ooooo0ol0^_l00ooooooooh/0oon;0009ooooo`;oo`3b0oooool01OmYo`3o
oooooooooooooooo?P3o00Cooooo00?o0P3ooaCo0?ooool02oooool00oo:0?ooooooooooo`03oooo
o`Co08oo1_ooool00on7o`3oooooog/0o`04ooooo`07o`3o4?oooooooooooooooom@o`3ooooood[o
0005ooooo`03onSo0?l0oeoo0?mO00Gooooo0_meo`03okko00Gooooo0_oX0?l00ol0oocooooooooo
o`02ooooo`;oW`3o0_ooool01?lP0?oo07Ooooooooooool2okP0o`Kooooo00?ok_l0o`3of?ooool0
2?ooool00om_o`3oooooooooo`02ooooo`;o6_l01_ooool2o`04o`?ooooo0_nb0?l00onbo`3ooooo
ooooo`0:ooooo`Ko08oo4Oooool3oh40o`03o`2EoolPo`3ooooo00Kooooo0_l0ok@2ooooo`;oG@3o
9oooool2o`3oYaCooooo1Ol02_l@ooooo`?oJ@3o0ol0OOl9ooooo`?oEol01?mG0?l2ooooo`Go6P3o
0oooool2o`3oC0Go043o6?ooool4o`3ol0[ooooo1Olno`08ooooo`Co03Co8?ooool001Wooooo00?o
0000ooooooooool05?ooool00on7o`3oooooooooo`05ooooo`0<o`3fool0obSoooooob00ool02_oo
00Cooego0?l0oh?o08Woo`2Qool0ooco0?nK0_ooool2oi<0o`03ool0_?nC0?ooT`3o00?oT`3o00So
0?oHo`23ool0@?oo0P3oo`3<ooo:0?oooiL0oed0o`;oK`3o00GoW`3oo`3o`?oX0?oo0?o`o`1mo`07
oc80o`06o`3oC?oooooo0?ndo`0doooooooo^03o0_oo0;`00ooooooo02koool0lP02ool0lP03oooo
ool0ooKo/P3o00?ooooo1?l0od02ofl0o`;o0?m000?oP@3oo`3o@?l0od000_l0od02o`2do`03okSo
0?l0^_oo0;[o00;o0;[o00Coooooooo80?ooR`3ooh/02Oooool2ool0lPCooooo00GoJOl0oooooooo
oooooooooch0o`04ooooo`03o`80oolDo`3ooooo00[ooooo0_o:0?l5ooooo`03o`3o1?oooooooooo
00;ooooo0ol0Sol2ooooo`03ohOo0?mk0?ooN`3o00?ooooo0_l0oa02ooooo`;oD?l00_m:o`04oooo
o`03onSo0?l0oeoo0?mO00Cooooo0omeo`02okko00Gooooo00Go^?l0onP0oooX0?ooooooo`3oo003
ooooo`;oW`3o0_ooool2ob00o`04oooooonh0?oo^03ookP0o`Kooooo0_o^o`000ol0omSooooooooo
o`06ooooo`;oKol01?ooool00olJo`3oooooooooo`04ooooo`;o00Co00?o0?lFooooooooool00_nb
0?l00onbo`3oooooooooo`05ooooo`Oo08oo00?o0_l0ooooooooool04_ooool2oh40o`;o09Go2?oo
ool2o`3o]0;ooooo0_mM0?lVooooo`?o0?nW4Oooool5o`0:o`03o`3oVooooooooooo013ooooo0_mY
0?l2o`1mo`Wooooo1?mGo`03oeL0o`;ooooo1?lJ0?l4ooooo`Ko043o6_ooool3o`3ol0Wooooo1Oln
o`0:ooooo`?o03Co9?ooool001Wooooo00?o0000ooooooooool05?ooool00on7o`3oooooooooo`05
ooooo`0Wo`3fool0obSoooooob00ool02_oo00CooaCo0?m@o`3o08Woo`2Qool0oocoooooo`3oVooo
oooo06_oo`3od_oob03oo`2lo`3`ool0oaKo?P3oo`3oc?mk0?oo08?oo`2Kool0@?oo0P3ooaX0ooo:
0?ooG@3oo`3o^_ooooooK`3ooil0oooX0?ooJ@3oo`1mooooW@3o09Go00;o01Ko00_o07Ooo`3oa_l0
i?oo9P3ooeOo0?oooooo0?ndo`0doooo0;co^03oo`1Io`02ooooo`03o`0Xool0^_oo0;[o00;oo`3b
00?o0?ofok80ooooool01?ooool01?m_0?ooMOl0okko0?nno`02ooooo`04oh40oooooooo0;Coo`2d
o`?o0;[o00KooooookSo0?ooooooooooooo80?ooR`08ooooo`?oo`3b00?o0?oNooooooooool00_oo
ool00omYo`3oooooooooo`02och0o`?ooooo0_l20?l00olDo`3oooooooooo`09ooooo`03olX0oooo
oooooooo00Cooooo00?o0?l4ooooooooool01_ooool2o`2?o`04og/0ool0Sooo08ooooooo`;o0?l@
0oooool00om@o`3ooooood[o0004ooooo`03onSo0?l0oeoo0?mO00?ooooo0omeo`03okko00Cooooo
0onho`001?oX0?ooooooooooool0oo`3ooooo`06oil0ooooooooooooo`1goolP0?oooooo0_nh0?l7
ooooo`;ok_l00_l0omP7ooooo`;oKol01?ooool2oa[o00Kooooo00Co00Coo`3o5_oooooooooo0_nb
0?l00onbo`3oooooooooo`07o`2?o`Cooooo0_l2o`0Cooooo`?oP@3o0_l0UOl7ooooo`?o0?nd0_oo
ool2oed0obKooooo0_l0ojL?ooooo`Go00[o0ol0oi/@ooooo`?o07go0_mY0?l:ooooo`?oEol01?mG
0?l5oaX0o`;ooooo1_l0@?l00ol0odcoooooooooo`0Iooooo`Co0?o`1_ooool6ocko00_ooooo1?l0
=?lWooooo`006Oooool00ol0003oooooooooo`0Dooooo`03ohOo0?oooooooooo00Gooooo00go0?Ko
of?o0?l0obSo0?mBob00ool02_oo00Coooooool0f?oo08Woooooool0ooco0?nK00;ooooo00?o06_o
ooooool0j_l00_oo0;`07Oln0?oo0?mUog/0ool0Pooo09_oo`10ooooW@3o0P3ooaX0ooo:0?ooG@3o
o`3o^_ooW@3oK`3ooil0oooX0?ooJ@3oo`1mool0ojOo09Goo`1Bool05_oo07Ooo`3ToolV0?oo0?m<
oon;0?l0okCoo`2l00;ooooo00So^03oo`1Ioooooooo02koo`0Xooooooooa?l0ooooo`?oo`3b0_l0
^_l2ofl0o`Oo0;[o00?oP@3oo`2jooooool01Oooool2okSo00Kooooo1?oo0?800ol05_oo0?oNoooo
o`04ooooo`04ofWo0?oooooooooooch0o`Cooooo00?o0P3ooooooolDo`002oooool00oo:0?oooooo
ooooo`04ooooo`03o`3o1?oooooooooo00Oooooo0_mk0?l3ooooo`Go08oo00?oD?l0od[o0?m:o`00
1?ooool2o`3oG`?ooooo0_meo`000ooooooo__l0okko0004ooooo`?o^?l000?oooooonP0oooX0?l0
0_ooool00ol0oocoooooooooo`02oil0o`;ooooo0_lP0?l2okP0o`Sooooo00?ok_l0ooooool0omP0
1oooool2ofoo00Gooooo00?o6_l0ooooooooool01?ooool2o`04o`04o`3o5_oooooo/P3ook80o`Go
08oo2Oooool2o`;o01?ooooo0_n10?l2o`2Eo`Sooooo0_l0ok@3ooooo`;oG@3o9_ooool2o`3oY`co
oooo1Ol02_l2o`3oJ`?o0?nK3oooool4o`1mo`?oJ@3o2Oooool3oeOo00?oE`3o1?lJ0?l2ooooo`Go
043o0ol0od`Kooooo`Co0?o`1Oooool5ocko00kooooo0ol0=?l[ooooo`006Oooool00ol0003ooooo
ooooo`0Dooooo`03ohOo0?oooooooooo00Gooooo00go0?Koo`3o1?l0obSoooooob00ool02_oo00Co
oego0?l0oh?o08Woo`2Qool0ooco0?nK00;ooooo017o06_oo`3od_oob03o0>[oo`3oMooo0;co?P3o
o`3oc?mk0?oo08?oo`2Kool0@?oo0<cooaX0ool0oiGobP3ooed0o`02ooooo`0<oil0oom_0?ooj03o
ofl0ool0OOoo0?nWo`2Eool0D_oo01Koo`3oa_l0i?oo9P3o0_oo0;`01Ol0okCo03Cooooooooooooo
^03o00;ooooo00?o02koo`0Xooooool00oooool00om_0?ooo`3bool0lP02ool0lPCooooo00GoMOl0
o`2dool0]?oooooooh40o`04ooooo`;ooh/000CoolP0oooooonho`3o^?l01?oo0?800ooooooo01Ko
o`0Fo`02o`3ogPGooooo00CoJOl0ooooooln0?oo?P3o0oooool2o`80o`;ooooo00?o5?l0oooooooo
ool01oooool2olX0o`Kooooo00?o0?l4ooooooooool01oooool01?mk0?ooQol0ooooooooool2o`3o
40Cooooo00?oD?l0o`2?ool0Sol01?l0Sol00ol0oeooooooooooo`03ogGo00?o__l00oooool3okSo
00;ooooo0_oX0?l3ooooo`04o`3oo?oooooooooooil0o`;ooooo00Co07Ooob00oonh0?oo^03o2?oo
ool2onko0003ooooool0omSooooo00Kooooo00?oKol0ooooooooool00oooool2oa[o00Gooooo0_l0
1?l2o`2?o`;o/P3o00?o/_l0ooooooooool02_ooool3o`;o01;ooooo0on10?l2o`2Eo`Sooooo0_l0
ok@3ooooo`;oG@3o9Oooool3o`3oY`[ooooo1?l02_l2ooooo`;o0?m[0ol0oi/>ooooo`Co07go0_oo
ool2ofT0o`Wooooo0omGo`03oeL0o`?o6P3o1_l0@?l01?oooooo0?m<o`3oC?l0od`Looooo`?o0?o`
0oooool6ocko00oooooo1?l0=?l^ooooo`006Oooool3o`0001Cooooo00?oQol0ooooooooool01_oo
ool09Ol0m_oo0?lXoooooolP0?oo00[oo`04oolDo`3oD?l0o`29ool0XOoo0?ololCo0?l0oi_ooooo
o`1[ool0om;oooooo`3Zool0l?oo0?mgool0_?l0ofGoN`3oo`23ool0Vooo043oooooool0c?oo6P3o
olX0oomM0?oo0?njooooool0[_ooW`3oo`3o`?oX0?l00om_0?l03ol0D_oo>?l0o`0Fool0olKoo`2l
obH0oomGo`3oooooo`3o]?l0=?oooh/0oooooonh0?ooooooolCo0005ofl0o`03ooooool0ooKo/P3o
00;ooooo1Ooo0?801OooooooMOl0okko0?nno`3oP@3o00?ooh/01_oo0?82okSo0005ooooool05_oo
01Koooooool0omh01_ooool00omYo`3ooooooch0o`04ooooo`05o`80oooooooooooooooooolDo`00
2Oooool00oo:0?ooooooooooo`06ooooo`03o`3o1?oooooooooo00Gooooo0_mk0?l01?n7o`3ooooo
o`3o4?l0oa05ooooo`03oe3o0?m:o`3ooooo00;ooooo0_l0oel00ooooooo08ooo`2?o`04o`2?o`?o
oooo0onho`04ooooo`03onP0oooooooooooo00;ooooo00Go0?oloooooonO0?ooW`3oooooo`02o`1g
o`;o^03o2?ooool2onko00;ooooo00?o0?oHooooooooool01?ooool2ofoo00Gooooo00?o6_l0o`2?
ool0Sol01?l0Sol00ol01?oo08ooo`3o5P02ok80o`03ok;o0?oooooooooo00[ooooo0_l2o`0Coooo
o`;oP@3o0ol0UOl8ooooo`;o0?nd0oooool2oed0obGooooo0_l0ojL:ooooo`?o00[o0oooool2o`3o
J`?o0?nK3Oooool4o`1mo`Cooooo0_mY0?l8ooooo`?oEol00omG0?l2oaX0o`Co043o0oooool4o`3o
C1_ooooo1?l0oo000ooooooo?_l0ocko0003ocko01;ooooo0ol0=?lbooooo`006Oooool00ol0003o
ooooooooo`0Eooooo`03ohOo0?oooooooooo00Gooooo00go0?Koof?o0?l0obSo0?mBob00ool02_oo
00Coooooool0f?oo08Woooooool0ooco0?nK00;ooooo017o06_oo`3od_oob03o0>[oo`3oMol0oaKo
o`2lo`3oc?mk0?oo08?oo`2Kool0@?oo0<cooaX0ool0oiGobP3ooed0o`02ooooo`06o`2^oonO0?oo
j03oofT0ool0OOoo0?nW0_m_0?l2ool0_009o`0FoolV0?oo0?m<ooooool0okCo03Coo`3o4?ooR`3o
K`3o00;o^03o00?oooooo`0^ool0:?l01?ooool01?l0ooKo/P3oooooooooool2o`2do`;ooooo2?oo
0?800ooob03oooooooooo`04ooooo`;o01Ko00?o^?l0o`3og_l0omh01_ooool00omYo`3ooooooch0
o`04ooooo`05o`80oooooooooooooooooolDo`002?ooool2olX0o`Sooooo00?o0?l4ooooooooool0
1Oooool01Omk0?ooooooohOo0?oooooo0?l@00Gooooo00CoD?l0od[o0?m:o`3ooooo0ol0oel3ogGo
00?o__l000?ooooookSo0?nho`002?l0Sol2onP0o`Go08oo0_nO0?l00ooooooo07Ooo`1go`02okP0
o`Sooooo5Ol0Sol4ooooo`;o00Co0onb0?l00onbo`3oooooooooo`0:ooooo`;o0_l04_ooool3oh40
o`;o09Go2Oooool2o`3o]0?ooooo0_mM0?lTooooo`?o0?nW2?ooool4o`0:o`?ooooo0ol0of/2o`3o
V`gooooo0ol0OOl5ooooo`?oJ@3o1oooool3oeOo00?oE`3o00Co6P3oo`10ool0@?oo043o1?ooool4
o`3oC1_ooooo1?l0oo05ocko01?ooooo1?l0=?leooooo`006Oooool00ol0003oooooooooo`0Eoooo
o`03ohOo0?oooooooooo00Gooooo01Ko0?Koo`3o1?l0obSoooooob00ool02_oo00Cooego0?l0oh?o
08Woo`2Qool0oocoa?l0o`3oVooooooo06_oo`3od_oooooo0>[oo`3`ool0ogOo013o0ooo0;`02?l0
Vooo043oooooool0c?oo6P3oooooooo:0?oo0?nj0_ooool01Ol0[_ooW`3oonP0ool0]?oo07go00;o
o`2l2_m_0?l01ooooooo05Wooon;0?nh0?oooh/0o`0^ool0:?l00oooR`001?l0ooKooh/0ok80oonb
0?l5oon;00?ooooo00CoMOl0okko0?nno`3oP@3o1Oooool2o`0Fo`;ooooo00?o0?oNooooooooool0
1?nho`001?ooooooJOl0och0ooln0?l3ooooo`;o0P3o0oooool00olDo`3oooooooooo`05ooooo`;o
bP3o2Oooool00ol0o`Coooooooooo`04ooooo`;oN`3o00CoooooohOo0?l0oa3o0?l@1Oooool00om@
o`3oB_l0ooooo`02o`3oG`03oooooomeo`3oMOl000;o__l01Onho`09ooooo`03onP0oooooooooooo
00?ooooo00Co0?oloil0ool0Sooo07Oo0onh0?l:o`2?o`?ooooo00?o0?oHooooooooool01?ooool0
0om_o`3oooooooooo`04ooooo`03oa[o0?oooooooooo00?ooooo0_l01?l2ok80o`03oooooonbo`3o
/_l000[ooooo0ol2o`0Booooo`;oP@3o00?o8?l0o`2Eool0UOl02Oooool2o`3o]0?ooooo0_mM0?lT
ooooo`;o0?nW1oooool4o`0:o`Cooooo0ol0of/3o`3oV`_ooooo1?l0OOl6ooooo`;oJ@3o1oooool3
oeOo00?oE`3o0ol0@?l5ooooo`?o0?m<7?ooool3o`3ol0Co?_l05Oooool3o`0docWooooo000Ioooo
o`03o`000?oooooooooo01Gooooo00?oQol0ooooooooool01Oooool03_l0m_oo0?l4o`3o:?mYo`3o
803oo`0:ool01?oo5?l0o`3oPol0ROoo0:7oooooool0ooco0?nK0_ooool0;Ol0Jooo0?oBooooool0
j_oo0?mgooooool04?oo?P3ooeL0oooo0;co09_oo`10ool0c?oooooooaX0oooooooobP3oo`;o0?oo
oooo0:kooil0ool0omkoj03oool0_?l0OOoo0;Coo`1Boolho`3o07Ooo`3oa_l0i?oo9P3ooeOo0?o4
o`3o0?ndo`0dool0oa3oooooo`1Ioooooooo^03oooooool0;_oo02Soooooo`03o`2do`;ooooo00?o
/P3oooooooooool01_ooool2ogGo0003okko0?n10?ooP@3o00;ooooo00?o01Koooooooooool00_l0
omh7ooooo`;o?P3o00Go^?l0ooooooooooooooooo`80o`04ooooo`03oaCo0?oooooooooo00Gooooo
00?obP3oooooooooool02?ooool00ol0o`Coooooooooo`04ooooo`03og/0oooooooooooo00;o0?l@
1_ooool2od[o00;o0?mO0omeo`04okSo00cooooo0_oX0?l5ooooo`;oW`3o00GooooookP0oonh0?oo
ooooob00o`07ooooo`;ok_l01?ooool00ol0omSoooooooooo`03ooooo`;oKol01Oooool2oa[o00Go
oooo00Co00Cook80oonb0?oo0?lF0_nbo`0:ooooo`;o0_l04_ooool3oh40o`?o09Go2Oooool2o`3o
]0?ooooo0_mM0?lSooooo`?o0?nW1_ooool3o`0:o`Kooooo0_l0of/3o`3oV`_ooooo0ol0OOl8oooo
o`;oJ@3o1_ooool2oeOo0005oaX0oomG0?ooE`3ooeL0ool0@?l01oooool3o`3oC1_ooooo1?l0oo03
ocko01Kooooo0ol0=?llooooo`006Oooool00ol0003oooooooooo`0Eooooo`03ohOo0?oooooooooo
00Kooooo01Wo0?Koof?o0?l0obSo0?mBob00ool02_oo00Coooooool0f?oo08Woooooool0ooco0?mm
o`3oVooooooo06_oo`3od_oooooo0>[oo`3`ool0ogOo013oo`3oc?mG0?oo08?o00Coo`2l00Co6P3o
o`80oomM0?oobP3o1Ooo0;`02Ol0oo3o07goo`3oYol0UOoo05;oo`2dool0Mooo0;CoobH0o`03o`0F
o`0:o`0doooooooo0?l@o`3o4?l0FOoooooookP0ool0]?oo02Soo`2do`?ooooo00Co0?ofoooooooo
oooo/P3o1_ooool01?oob03ooooooooooomeo`02o`0Fo`03oh40ool05_oooooo00;o0?oN2?ooool0
1Oln0?ooJOl0oooooooooooo^?l000;o0P3o00Go^?l0oooooooooooooooooaCo0006ooooo`;obP3o
2_ooool00ol0o`Coooooooooo`03ooooo`;oN`3o0ol0oa07ooooo`03od[o0?l0oeoo0?mO00;oMOl0
0_nho`0?ooooo`;oj03o1Oooool2oil0o`04oooooonh0?oo^03oooooo`;o803o1oooool00oo^o`3o
ooooooooo`02ooooo`;o0?oH1Oooool00om_o`3oooooooooo`04ooooo`03oa[o0?oooooooooo00?o
oooo00Co00Cook80oonb0?oo0?lF0_nbo`0:ooooo`;o0_l04Oooool3oh40o`03ob3o0?l0UOoo09Go
00[ooooo0_l0ok@3ooooo`;oG@3o8oooool2o`3oY`Kooooo0ol02_l6ooooo`;o0?m[0ol0oi/:oooo
o`Co07go2Oooool2ofT0o`Gooooo00?oEol0oaX0oolJ0?l00omG0?l8ooooo`?o0?m<6_ooool4o`3o
l0Co?_l05_ooool3o`0doc3ooooo0_lho`0=ooooo`006Oooool00ol0003oooooooooo`0Fooooo`03
ohOo0?oooooooooo00Gooooo01go0?Koo`3o1?l0obSoooooob00ool02_oo00CooaCo0?l0oh?o08Wo
o`2Qool0oocoooooo`3oVoo4o`3oooooo`1[ool0om;oooooo`3Zool0ogOoooooo`0@ool0olcoE`3o
og/0ool0Vooo043oo`3<o`04ool0_00?olX0oooooooo0:kooooooonO0?ooj03oo`3ol?l0OOoo0?nW
o`2Eool0D_oo>?l0o`1gool0]?oo9P3o00;o0;Co0ol05_l2o`2do`05o`1Ioooooooo^03ookP0ool0
:?l01?ooool01?l0ooKooooooooooonb0?l4ooooo`03ooo80?l05_oo01Ko00;o01Ko0_ooool00ome
o`3oP@3oo`3ogP08ooooo`;o?P3o00GoJOl0ooooooooooooooooo`80o`03ooooo`?o^?l000?o5?l0
okSo0?nho`000_ooool2olX0o`cooooo00?o0?l4ooooooooool00_ooool01Omk0?oo0?l@o`3o4?oo
ooooQol000Gooooo00Oo^?l0oe3o0?l0oeoo0?mOogGo0?ooooooj?l0017ooooo00?oj03ooooooooo
ool01?ooool01?nO0?oo^03ookP0oonh0?l2ooooo`03ob00oooooooooooo00Gooooo0_o^o`04oooo
o`03o`3of?oooooooooo00?ooooo0_m_o`05ooooo`;o6_l01Oooool2ok80o`03ooooool0oaKo/_l0
00Wooooo0ol2o`0@ooooo`?oP@3o00Coooooob3o0?l0UOoo09Go2_ooool2o`3o]0;ooooo0omM0?lS
ooooo`;o0?nW1Oooool3o`0:o`Oooooo0_l0of/2o`3oV`[ooooo0ol0OOl:ooooo`?oJ@3o1?ooool0
0omGo`3o6P3ooaX0o`03oeL0o`Sooooo0ol0od`Jooooo`?o0?o`1?lno`0Gooooo`?o03Co;_ooool5
ocSo00oooooo000Iooooo`03o`000?oooooooooo01Kooooo00?oQol0ooooooooool01Oooool0=Ol0
m_oo0?l4o`3o:?mYo`3o0?mBob00ool01?oo5?l0o`3oPol0ROoo0:7oooooool0ooco0?nKooooooo4
o`3o06_oo`3od_oooooo0>[oo`3`ool0ogOo013oo`3oc?mG0?oo?P3oog/0oooooooo043oo`3<oolJ
0?oooooooed0ool0ok[obP3oooooool0[_ooW`3ooooooooX0?oo0?oNo`1mool0ojOo05;oocSo0?o4
o`3o07Ooo`3ToolV0?ooEol0ooooool0okCo03Co00?o01Ko00Go05Wooooooooooooo^03oo`0Xo`04
ooooo`03o`3om_oooooooooo00;o/P3o00?oolP0o`0Fool05_l01Oooool2o`3ogP03oooooon10?oo
P@3o00;o__l00oooool2och0o`03oooooomYo`3ooooo00;ooooo00?o0P3oooooooooool01?ooool0
1_lDo`3ooooooooooooooooo^?l0olX0o`Co^?l02Oooool00ol0o`Coooooooooo`02ooooo`05og/0
ool0oa3o^?l0okSo0?n7o`001Onho`000omeo`3o0?mOo`3oG`02ooooo`;oj?l04?ooool2onP0o`Go
oooo00CoW`3ookP0oonh0?oo07Oo0oooool00olP0?ooooooooooo`04ooooo`;ok_l01Oooool00ol0
omSoooooooooo`03ooooo`03ofoo0?oooooooooo00Cooooo00?o6_l0ooooooooool00_ooool3ok80
o`04ooooool0oaKo0?lFok;o00Sooooo0_l2o`0@ooooo`?oP@3o0_ooool00olPo`3o09Goo`2Eo`0:
ooooo`;o0?nd0_ooool2oed0ob?ooooo0ol0ojL4ooooo`?o00[o1oooool2o`3oJ`?o0?nK2?ooool4
o`1mo`_ooooo0_mY0?l4ooooo`;o6P3o1?mG0?l8ooooo`?o0?m<6_ooool3o`3ol0?o?_l06?ooool3
o`0dobOooooo4Ol0l?l=ooooo`006Oooool00ol0003oooooooooo`0Fooooo`03ohOo0?oooooooooo
00Kooooo03Co0?Koof?o0?l0obSo0?mBob00ool02_oo00Coooooool0f?oo08Woooooool0oocooooo
o`3oVoooooooa?l0o`1[ool0om;oooooo`3Zool0ogOoooooo`0@ool0olcoE`3ooch0oomk0?oo043o
o`3<oooooooo6P3ooooooomM0?oo0_l0olX0oooooooo0:kooil0oomY0?ooj03oo`1mool0omko09Go
o`1Boolho`3oooooo`1goolV0?oo0?m<oeOo0?oooooo03Co0oooool4o`0Fo`03okP0ool05_oo01Ko
00Oo01Ko00?o/P3oooooooooool00oooool2o`3ogPGooooo00GoP@3oogGo0?nno`3o__l0och0o`02
ooooo`03ofWo0?oooooooooo00;o0P3o1_ooool01?lDo`3oooooooooooooool2olX0o`Gooooo2?nh
o`001?l0o`Co^?l0okSo0?nho`02og/0o`;o^?l00_ooool01?n7o`3o__l0ogGo0?meo`03o`3oG`?o
oooo00?oj?l0ooooooooool03oooool00ooX0?ooooooooooo`04ooooo`;o^03o0_l0Mol3ooooo`03
ob00oooooooooooo00?ooooo0_o^o`06ooooo`03o`3of?oooooooooo00;ooooo0_m_o`05ooooo`;o
6_l00oooool2ok80o`05o`04ooooooooooooo`3o5_nbo`002?ooool2o`;o00oooooo0on10?l3oooo
o`03ob3o0?l0UOoo09Go00Wooooo0ol0ok@2ooooo`;oG@3o8oooool2o`3oY`Cooooo0ol02_l7oooo
o`;o0?m[0ol0oi/8ooooo`?o07go3Oooool2ofT0o`?ooooo0_lJ0?l3oeL0o`Wooooo0ol0od`Joooo
o`?o0?o`0olno`0Hooooo`?o03Co8Oooool9o`3`o`?o>?l06oooool001Wooooo00?o0000oooooooo
ool05_ooool00on7o`3oooooooooo`06ooooo`0>o`3fool0o`Co0?lXofWo0?lP0?oo00[oo`04oolD
o`3o0?n3o`29ool0XOooooooo`3oo?l0oi/2ooooo`0?o`1[ool0om;oooooo`3Zool0l?oo0?lFo`0@
ool0olcoE`3oo`23ooln0?ooN`3oo`10ool0c?oo6P3o00;ooooo01CoG@3oo`;o0?o:0?oo0:koo`3o
`?nO0?ooj03oo`3ol?l0OOoo0?oNo`2Eool0D_oo>?l0o`3oa_l0Mooo9P3oo`3oC?oooooo0?ndo`0d
o`?ooooo00Ko05Woo`3o4?oooooooooookP0ool0:?l3ooooo`03o`3om_oob03oolP000;ooooo00Go
/P3oooooooooooooooooo`3ogP08ooooo`;oP@3o00Go?P3oogGo0?nno`3oJOl0okko0002o`80o`03
okko0?oooooooooo00Cooooo00?o5?l0ooooooooool00_o:0?l>ooooo`05o`3o1?ooooooooooo`3o
4?mk0?l01Onno`02ogGo00?o0?mO0_m:o`02ooooo`;oj?l04?ooool2onP0o`Cooooo0onh0?l2o`1g
o`?ooooo0_lP0?l4ooooo`;ok_l01_ooool2o`3of0Cooooo00?oKol0ooooooooool01?ooool01?lJ
o`3oooooooooooooool2ok80o`03o`04oooooooooooo00;o0?lF2?ooool2o`;o00kooooo0on10?l4
ooooo`03ob3o0?l0UOoo09Go00Wooooo0_l0ok@3ooooo`;oG@3o8oooool2o`3oY`Cooooo0_l02_l8
ooooo`04o`3oJol0oi_o0?nKo`3oV`Sooooo0ol0OOl>ooooo`;oJ@3o0_ooool2oaX0o`?oE`3o2Ooo
ool3o`3oC1[ooooo0ol0oo02ocko01Wooooo0ol0=?lMooooo`Oo0?3o1Olho`0Cooooo`;o9P3o3Ooo
ool001Wooooo00?o0000ooooooooool05_ooool00on7o`3oooooooooo`06ooooo`0?o`3fool0o`Co
0?lXofWo0?l0oe;o803oo`04oolDo`3o0?n3o`29ool0XOooooooo`3oo?oooooo0?nK00;ooooo02Go
06_oolCo0?oooooo0>[oo`3oMooob03o013oo`3oc?mG0?oo08?oog/0ool0@?oo0<cooooooolJ0?oo
oooooed0ool20?oo0_l0olX0ool0[_oo0?o0oil0oooX0?ook_l0o`1mool0ojOo05;oo`3og_oooooo
0>Coo`1goolV0?ooEol0ooooool0okCo03Co00?ooooo00[o05Woo`3o4?l0oa3ooooookP0ool0:?oo
0?mOoooooooob03o0?of1?ooool00onb0?oo0?oNo`3ogP08ooooo`;o?P3o00Cooooooh40oooooooo
JOl00_l20?l3ogGo00Go__l000Co5?l0oooooooooooobP3o3oooool00ol0o`Co0?l@o`3o4002og/0
o`03okko0?meo`3oMOl000?oMOl00_l0oel2ooooo`03od[o0?m@o`3ooooo00;oj?l04?ooool2onP0
o`Cooooo0_nh0?l01?nO0?ooooooo`1gool0oo`3ooooo`03ob00oooooooooooo00?ooooo00?ok_l0
ooooooooool01Oooool00ol0omSoooooooooo`03ooooo`03ofoo0?oooooooooo00?ooooo0_lJo`02
ooooo`;o/P3o0_l01?l2ooooo`03o`3o5_oooooooooo00Kooooo0_l2o`0=ooooo`?oP@3o1Oooool0
0olPo`3o09Goo`2Eo`09ooooo`;o0?nd0oooool2oed0ob;ooooo0ol0ojL3ooooo`?o00[o1oooool2
o`3oJ`;o0?nK2?ooool3o`1mo`oooooo0_mY0?l3oaX0o`?oE`3o2Oooool3o`3oC1Wooooo00Go?_l0
o`3ol?l0oo3o0?o`ocko000Jooooo`?o03Co6Oooool7o`3`o`Go>?l05_ooool4obH0o`oooooo000I
ooooo`03o`000?oooooooooo01Oooooo00?oQol0ooooooooool01_ooool03_l0m_ooHol0o`3o:?l0
oe;o803oo`0:ool01?ooooooo`3Hool0ROoo0:7oooooool0ooco0?nK0_ooool03ol0Jooo0?oBolCo
0?l0j_oo0?3oo`3o5_l04?oo0?o<oeL0ool0Pooo09_oog/0ool0@?oo0<cooaX0o`02ooooo`0<oed0
ool20?ooj?l0olX0ool0[_ooW`3oofT0oooX0?oo07goo`3oYol0UOoo05;o0_l0omh01ol0i?oo9P3o
o`3oC?mGo`3oooooo`3o]?l0=?l00oooool01?l0FOooooooo`3o4?l0oa02okP0o`;o0?mO00?ooooo
o`3om_ooool00ol0omh00onb0?ooooooooooo`06ooooo`03och0oooooooooooo00;ooooo0_n10?l5
ooooo`GoMOl000?o5?l0olX0ooo:0?l03Onno`02ogGo00;o0?l@00?oMOl0og/0oomeo`000_meo`02
ooooo`?o0?mO0_ooool2od[o0003oe3o0?oXo`3oj?l0017ooooo00?oj03oooooooooool00_ooool2
okP0o`05oil0oooooooo07Ooo`1gool0oo`00oooool00olP0?ooooooooooo`02ooooo`;ok_l01ooo
ool00ol0omSoooooooooo`02ooooo`;oKol01Oooool00olJo`3ooooook80o`02ok80o`06ooooool0
1?oooooooooooonbo`3o0?lF1oooool2o`;o00cooooo0on10?l6ooooo`03ob3o0?l0UOoo09Go00Wo
oooo0_l0ok@2ooooo`?oG@3o8_ooool2o`3oY`?ooooo0ol02_l7ooooo`?o0?m[0_l0oi/7ooooo`?o
07go3oooool3ofT0o`;o6P3o0omG0?l:ooooo`;o0?m<6?ooool2ocko00?o0?o`6oooool3o`0doaCo
oooo2?l0l?l5ocSo01Sooooo1OlV0?lCooooo`006Oooool00ol0003oooooooooo`0Gooooo`03ohOo
0?oooooooooo00Kooooo02?o0?Koo`3o1?l0obSoJOl0ob00ool02_oo00CooaCo0?l0oh?o08Woo`2Q
oooooooo0?olooooool0oi_oooooo`1[ool0om;oooooo`3Zool0l?oo0?mgo`3o5_l04?oo0?o<oeL0
ool0Pooo09_oog/0ool0c?oooooooaX0ooooooooa?l0oed0o`02o`80o`0>olX0ool0ol3oW`3oofT0
oooX0?oo07goo`3oYol0UOoo05;oocSo0?l0olKo0>CoobH0ool0omh2ooooo`05o`3o]?l0=?oooooo
ooooool0FOl00oooool00ol0;_oo02SookP0o`03o`3ogP03o`3om_oooooooooo00;ooooo0_nb0?l4
ooooo`;o?P3o1?ooool2o`80o`03oooooon10?ooP@3o00Oooooo0_o:0?l?ogGo00;o0?l@00?o0?l4
og/0oomk0?l01?ooool2o`3oG`05ohOo0?oooooooooooooooom:o`000_m@o`000ooXo`3ooooooooo
o`0?ooooo`;oj03o0_ooool3okP0o`;oW`3o0_l0Mol01?oooooo0?olooooooooool2ob00o`?ooooo
0_o^o`07ooooo`;o0?oH1?ooool00om_o`3oooooooooo`03ooooo`;o6_l00_nb0?l3ooooo`03o`04
oooooooo/_l000;o0?lF1_ooool2o`;o00_ooooo0on10?l6ooooo`?o8?l000?o09Goooooooooool0
1oooool2o`3o]0;ooooo0_mM0?lSooooo`;o0?nW0_ooool3o`0:o`Sooooo0_l0of/3o`3oV`Kooooo
0ol0OOl@ooooo`;oJ@3o0_lJ0?l3oeL0o`[ooooo0ol0od`Fooooo`?o?_l00ol0oo0Kooooo`?o03Co
4?ooool7o`3`o`Ko>?l06_mSo`05obH0o`_oHol03Oooool001Wooooo0ol0000Gooooo`03ohOo0?oo
oooooooo00Kooooo00oo0?Koo`3o1?l0obSoJOl0o`3oD_lP0?oo00CooaCo0?l0oh?o0=Soo`29oooo
oooo0?olooooool0oi/00_ooool08ol0Jooo0?oBooooool0j_oo0?3oo`3o5_l04?oo0?o<oeL0ool0
Pooo09_oo`3of?mk0?oo0<coolCo0?lJ0?oooooooed0oooooooo0_l0o`80ooo:0?oo0?o0oil0oomY
0?ooj03oo`1mool0ojOo05;oocSo0?oooooo0>CooooooolV0?oo07Oo00?o0?oN00Co03Coo`3og_l0
omko05Wo0ol0omh01?l0;_oo02SookP0oonh0?l2o`3oG`03o`3om_oooooooooo00?ooooo00Co/P3o
ooooooln0?oo?P3o1?ooool2o`80o`03ofWo0?oooooooooo00;ooooo00?oP@3oooooooooool00ooo
ool00oo:0?ooooooooooo`0=ooooo`;o0?l@00?oooooo`3o1?mk0?l00oooool3o`3oG`04oooooon7
o`3oooooooooo`;oB_l000?oD?l0onSo0?oXo`004?ooool2onP0o`05oooooonh0?oo^03ookP0oooo
ool00_nO0?l01Ooooooo07Oooooooooooooo0?ol00;ooooo00Co803ooooooooooooooooo0_o^o`08
ooooo`03o`3of?oooooooooo00;ooooo0_m_o`05ooooo`03oa[o0?nb0?oo/P3o00?ooooo0_l01?l2
ok;o0003o`3o5_oooooooooo00?ooooo0ol2o`0:ooooo`?oP@3o1oooool2ob3o0003ooooool0UOoo
09Go00Sooooo0_l0ok@2ooooo`;oG@3o8oooool2o`3oY`;ooooo0_l02_l8ooooo`?o0?m[0_l0oi/6
ooooo`?o07go4?ooool01?l0@?ooJ@3oofT0oolJ0?l3oeL0o`[ooooo0ol0od`Fooooo`?o?_l00ol0
oo0Kooooo`?o03Co3?ooool7o`3`o`03of?o0?lho`3o>?l000?o>?l01_mSo`0Fooooo`Go9P3o4?mM
o`0=ooooo`006Oooool00ol0003oooooooooo`0Gooooo`03ohOo0?oooooooooo00Oooooo023o0?Ko
of?o0?l0obSo0?mBob00ool02_oo00Coooooool0f?oo08Woo`2Qoooooooo0?olooooool0oi_ooooo
o`1[ool0om;oooooo`3Zool0l?oo0?mgo`3o5_l04?oo0?o<oeL0ool0Pooo09_oo`10oomk0?oo?P3o
oaX0o`;ooooo01;oG@3oo`;o0?oXo`3o0P3oolX0oonO0?ooJ@3oo`3ol?oX0?oo0?nWooooool0D_oo
>?l0o`3oa_l0i?oo9P3oo`3oC?l0Mol2ooooo`05o`3o]?l0=?ooooooooo80?l0FOl00oooool00ol0
;_oo02Soo`3o4002okP0o`03o`3om_l0oeoo0?mO00Cooooo0_nb0?l3ooooo`;o0P3o00?oooooofWo
0?ooool01Oooool2oh40o`03ooooooo:0?oobP3o00gooooo0ol0oa02ooooo`;oN`3o00Coooooo`3o
Gol0oeoo0?mO0oooool01on7o`3ooooooooooom:o`3ooooooe3o0?oXo`004Oooool01?oX0?oo^03o
okP0oonh0?l3ooooo`04oil0oooooooo07Ooo`1go`;ooooo00Co0?oloooooooooooo803o0oooool0
0oo^o`3oooooooooo`07ooooo`03o`3of?oooooooooo00;ooooo00?oKol0ooooooooool00oooool3
ok80o`Cooooo00Go00Cooooooonbo`3oooooo`3o5P04ooooo`;o0_l02_ooool3oh40o`Sooooo0_lP
o`000ooooooo09Goo`2Eo`08ooooo`;o0?nd0_ooool2oed0ob?ooooo0_l0ojL01?oooooo00[oo`0:
ool02_l8ooooo`;o0?m[00?oooooo`3oVol0oi/01Oooool3o`1mo`oooooo0_l0@?l00olJ0?ooJ@3o
ofT0o`03oeL0o`[ooooo0ol0od`Fooooo`?o?_l00ol0oo0Kooooo`?o03Co2?ooool7o`3`o`?oHol0
1Olho`08oooooa?oGOl01_lV0?l00omMo`3oooooooooo`0Oooooo`006Oooool00ol0003ooooooooo
o`0Gooooo`03ohOo0?oooooooooo00Oooooo00oo0?Koo`3o1?l0obSoJOl0ob00ool02_oo00CooaCo
0?l0oh?o08Woo`2Qoooooooo0?olooooool0oi/00_ooool04?l0Jooo0?oBooooool0j_oo0?3oo`3o
5_l04?oo0?o<oeL0ool0Pooo09_oo`3of?mk0?oo0<cooch0oolJ0?l2ooooo`04oed0ool2o`3oj?l0
o`2^o`;obP3o00coJ@3oo`3ol?oX0?oo0?nWo`1Boooooooo>?l0o`3oa_l0i?oo9P3oo`3oC?l0Mol2
ooooo`05o`0doooob03oooooooooool0FOl00oooool01ol0;_oo02Soo`3o4?l0oa3o^03oo`3om_oo
ool00_l0oel2och0o`;ooooo0_nb0?l01?l20?oooooooooooomYo`08ooooo`;obP3o00?o5?l0oooo
ooooool02Oooool3o`3o40?ooooo0_mk0?l3o`3oG`Gooooo00KoQol0ooooooooooooB_l0onSo0?m@
o`0Aooooo`;oj03o00?o^03oooooooooool00_ooool2oil0o`;o07Oo0oooool01?l0oocooooooooo
oolP0?l2ooooo`;ok_l02?ooool2o`3of0?ooooo0_m_o`04ooooo`;o/P3o00?o6_l0ooooooooool0
0_ooool2o`04o`;o/_l00_l0oaH3ooooo`;o0_l02Oooool3oh40o`Wooooo0_lPo`000ooooooo09Go
o`2Eo`08ooooo`;o0?nd0_ooool2oed0ob?ooooo0_l0ojL3o`0:o`Sooooo0ol0of/00ooooooo0?nK
o`3oV`04ooooo`?o07go3oooool2o`10o`;o6P3o0_mY0?l2oeL0o`[ooooo0ol0od`Fooooo`?o?_l0
0ol0oo0Kooooo`?o03Co0_ooool4of?o00Go0?3o0_mSo`03ooooo`Go>?l00oooool:oego00kooooo
1OlV0?lXooooo`006Oooool00ol0003oooooooooo`0Hooooo`03ohOo0?oooooooooo00Kooooo03Wo
0?Koo`3o1?l0obSoJOl0o`3oD_lP0?oo00CooaCo0?oooooo0=Soo`29ool0XOooooooo`3oo?l0oggo
0?nKooooool0Jooo0?oBooooool0j_oo0?3oo`3oMol0oaKo013oo`3oc?mG0?oo08?oo`2Kool0@?oo
N`3oooooooln0?oo6P3oooooool0ok[oG@3oo`;o0?oXo`3o0:koo`80ooo:0?ooJ@3ooooooooX0?oo
0?nWo`1Boolho`3oooooo`3Toooooooo9P3oo`3oC?l0MoooolP0o`3o]?l0=?l00oooool02?l0FOoo
oooooooooooooooo02koo`0Xoooooooo0?l@0_nh0?l2och0o`;o0?mO0_l20?l2ooooo`03ok80oooo
ooooJOl000Kooooo0oo:0?l2ooooo`;oP@3o1Oooool5o`3o40;ooooo0ol0oel00omk0?oo0?mOo`3o
G`08ooooo`05ohOo0?m:o`3oB_l0onSo0?m@o`004?ooool00onh0?ooj03ookP0o`04ooooo`;oW`3o
0_l0Mol4ooooo`05o`3oo?oooooo803oob00ooooool00_o^o`09ooooo`03o`3of?oooooooooo00;o
oooo00?oKol0ooooooooool00_ooool2ok80o`03oa[o0?oooooooooo00?ooooo00Go00Cook;o0?nb
o`3oooooo`3o5P03ooooo`;o0_l02Oooool2oh40o`[ooooo0_lPo`000ooooooo09Goo`2Eo`08oooo
o`;o0?nd0_ooool2oed0ob?ooooo0_l0ojL2o`0:o`Sooooo0ol0of/2ooooo`;o0?nK0oooool3o`1m
o`kooooo0ol0@?l3oaX0o`;oJ@3o00?oE`3oooooooooool02?ooool3o`3oC1Kooooo0olno`03o`3o
l1[ooooo00CoHol0o`0dool0=?oo03Co1?mSo`05o`3`o`Gooooo1Olho`08oego01;ooooo1_lV0?l]
ooooo`006Oooool00ol0003oooooooooo`0Hooooo`03ohOo0?oooooooooo00Oooooo00oo0?Koof?o
0?l0obSo0?mBob00ool02_oo00CooaCo0?l0oh?o08Woo`2Qoooooooo0?olooooool0oi/00_ooool0
4?l0Jooo0?oBooooool0j_oo0?3oooooool04?oo0?o<oeL0ool0Pooo09_oo`3of?l0@?ooN`3ooooo
ooln0?l2ooooo`06oed0ool2o`3oooooo`2^ool0ol3ooooo0_o:0?l02_ooooooj03oonko0?l0D_oo
>?l0o`3oa_l0i?ooooooobH0ool0od`2o`1go`05o`3o]?l0=?ooooooooooool0FOl01?ooool00ol0
;_oo02Sooch0o`02och0o`05okP0ool20?oo0P3oo`80ool0oa001?l0oel2ok80o`Cooooo0_o:0?l4
ooooo`03oaCo0?oooooooooo00;oP@3o0ol0oa03ooooo`Co0?mO00Goooooog/0oomk0?ooooooo`3o
1008ooooo`05ohOo0?m:o`3oj?l0oooooom@o`003_ooool2okP0o`;oj03o1?ooool2oil0o`;o07Oo
1Oooool01?l0oocoooooob00ooooool2onko00[ooooo00Co0?oHoooooooooooooooo0_m_o`02oooo
o`?o/P3o0_lJo`05ooooo`05o`04oonbo`3oooooooooool0oaH00_ooool2o`;o00Sooooo0on10?l:
ooooo`;o8?l000?oooooo`2Eool0UOl02?ooool2o`3o]0;ooooo0_mM0?lRooooo`;o0?nW0ol02_l8
ooooo`;o0?m[0_ooool3o`3oV`;ooooo0ol0OOl>ooooo`?o043o0olJ0?l01?mGo`3oJ@3oofT0oomG
0?l9ooooo`?o0?m<5_ooool3ocko00?o0?o`5_ooool5of?o00?o03Co0_ooool5o`3`o`03oooooomM
o`3oGOl000;oGOl01Olho`02oego01Sooooo1OlV0?lcooooo`006Oooool00ol0003oooooooooo`0H
ooooo`03ohOo0?oooooooooo00Oooooo00oo0?Koo`3o1?l0obSoJOl0ob00ool02_oo00CooaCo0?l0
oh?o0=Soo`29ool0XOooooooo`3oo?l0oi/00_ooool04?l0Jooo0?oBooooool0j_oo0?3oo`3oMol0
4?oo0?mUo`3oc?mG0?oo08?oo`2Kool0omSo043oog/0ooooool3och0o`0Foed0ool2o`3oooooo`2^
ool0ol3ooooooil0ooo:0?oo0P3oonP0ool0D_ooooooocSo0?l0olKo0>CooooooolV0?oo0?m<oeOo
0?l0Mooo0?ndo`0do`;ooooo00Co05Wooooooooooooooooo0_ln0?l01?oooooo0P3oo`80ool20?l2
okP0o`;ooooo1Ol0oa000ooooooo/P3oo`3oG`02olX0o`Co0?mO1?l0oa03o`3oG`?oP@3o0ol0oel3
ooooo`;oN`3o0_ooool00ol0o`Coooooooooo`06ooooo`;oB_l000?ooooooe3o0?m@o`003?ooool3
okP0o`;oj03o1Oooool00onO0?oo07Ooo`1go`06ooooo`05o`3oo?oooooo803oooooooo^o`002_oo
ool2o`3of0?ooooo00?oKol0ooooooooool00_nb0?l2ooooo`03oa[o0?oooooooooo00?ooooo0_l0
1?l01Onbo`3oooooo`3o5_l0oaKooooo00;o0_l01oooool3oh40o`_ooooo0_lPo`000ooooooo09Go
o`2Eo`08ooooo`;o0?nd0_ooool2oed0ob;ooooo0_l0ojL2o`0:o`Sooooo0ol0of/2ooooo`;o0?nK
0_ooool3o`1mo`kooooo0ol0@?l3oaX0o`;oEol00_mY0?l00omG0?ooooooooooo`06ooooo`?o0?m<
5_ooool3ocko0003ooooool0oo3o0?o`01;ooooo1omSo`02ooooo`?o03Co1Ol0l?l6oego00Co>?l0
6_ooool5obH0ocSooooo000Iooooo`03o`000?oooooooooo01Sooooo00?oQol0ooooooooool01ooo
ool04?l0m_oo0?l4o`3o:?oooooo0?mBob00oooooooo00CooaCo0?l0f?oo08Woo`2Qoooooooo0?ol
ooooool0oi/2ooooo`0@o`1[ool0om;oooooo`3Zool0l?ooooooo`0@ool0olcoE`3oo`23ool0Vooo
ooooo`10ool0c?ooN`3ooaX0o`;ooooo00So?P3ooed0ool2o`3oooooo`2^oooXo`3ooooooil0o`;o
bP3o00goj03oo`80ool20?ooooooo`3oa_l0i?ooooooobH0ool0odcoEol0o`1gool0okCo03Co00;o
oooo0oln0?l3o`80o`Cooooo00Ko0?ofokP0oonh0?oo^03ooooooomYo`02ooooo`04o`3o4?o:0?oo
bP3ook80o`Go0?l@1?l0oel6ooooo`;oP@3o0oooool00omk0?ooooooooooo`02ooooo`03o`3o1?oo
oooooooo00Gooooo00CoB_l0onSo0?ooooooD?l02oooool3okP0o`;ooooo00?oj03oooooooooool0
0oooool2oil0o`03o`1goooooooooooo00Gooooo00?o0?olob00oolP0?l00_o^o`0:ooooo`04o`3o
f?ooooooooooooooo`;oKol000?ooooook80oonb0?l00_ooool2oa[o00Gooooo00Ko00Cook;o0?oo
ooooooooo`3o5_ooool2o`;o00Kooooo0on10?l=ooooo`04ob3o0?oooooo09Goo`2Eo`Oooooo0ol0
ok@2ooooo`;oG@3o8_ooool01?l0ojOo00[oo`0:ool02_l8ooooo`;o0?m[0oooool2o`3oV`04oooo
ool0OOoo07goo`1mo`kooooo0ol0@?l3oaX0o`?oEol00_mY0?l8ooooo`?o0?m<5_ooool3ocko0004
ooooool0oo3o0?o`o`3ol0gooooo1omSo`07ooooo`;o03Co0ol0l?l2oego00Gooooo1?lho`0Joooo
o`Co9P3o6?oooolHo`3Ho`gooooo000Iooooo`03o`000?oooooooooo01Sooooo00?oQol0oooooooo
ool02?ooool03ol0m_ooHol0o`3o:?l0oe;o803oo`0:ool01?oo5?l0o`3oPol0f?oo08Woo`2Qool0
oocoooooo`3oV`02ooooo`0?o`1[ool0om;oooooo`3Zool0l?oo0?mgo`0@ool0ofGo0?o<oeL0ool0
Pooo09_oo`3of?l0@?oo0<co00;oN`3o0_oob0003?mM0?oo?P3oooo80?l0[_oo0?o0onSo0?mY0?oo
W`3oooo80?l0OOooj03oolX0o`Go0P3o00?o9P3oo`80ool20?l00_l20?l2och0o`;o0P3o0oooool0
0ol0;_oo02Soooooo`03ooooo`03o`3om_oooooooooo00;o^03o0oo:0?l3ooooo`;o/P3o0_ooool0
0olDo`3oooooooooo`0:ooooo`;oP@3o00?oN`3oooooooooool00_ooool00ol0o`Coooooooooo`04
ooooo`;oB_l00_ooool00om@o`3oooooooooo`07ooooo`?o^03o0oooool2onP0o`Cooooo0_nO0?l0
0ol0Moooooooooooo`06ooooo`04o`3oo?lP0?ook_l0onko00_ooooo00Go0?oHoooooooooooooooo
ofoo0003ok80o`?ooooo00?o6_l0ooooooooool01?ooool00ol01?ooooooooooo`02o`3o5P;o0_l0
1Oooool3oh40o`kooooo0_lPo`02o`2Eo`Oooooo0_l0ok@3ooooo`;oG@3o8_ooool3o`0:o`Wooooo
0_l0of/3ooooo`;o0?nK0ol0OOl>ooooo`?o043o0olJ0?l3oeOo0003oooooomY0?ooJ@3o00Sooooo
0_l0od`Fooooo`?o?_l000Coooooo`3ol?l0oo3o0?o`2oooool5of?o00Oooooo0omMo`001Ol0l?oo
03Coo`0dool0=?oo0?3o00Kooooo1Olho`0Jooooo`Co9P3o3_ooool>o`3HobGooooo000Iooooo`03
o`000?oooooooooo01Wooooo00?oQol0ooooooooool01oooool04?l0m_oo0?l4o`3o:?mYo`3o803o
o`0:ool01?ooGOl0oaCo0?l0f?oo08Woo`2Qoooooooo0?olooooool0oi/2ooooo`0Do`1[ool0om;o
ooooo`3Zool0l?ooooooo`0@ool0olcoE`3oo`23ool0Voooooooo`3of?l0@?ooB_l0o`3oUOmk0?oo
ooooo`3o^_mM0?l4och0o`05onSo0?mY0?ooW`3oo`1mool0ojL00_oX0?l2olX0o`03o`3Toooooooo
9P3o00Co?P3o00Go03Coo`3o]?ooooooooooo`1Io`03ooooo`03o`0^ool0:?oooooo00?ooooo00Go
0?ofooooooo:0?oobP3oooooo`03okP0o`Cooooo0_nb0?l00olDo`3oooooooooo`09ooooo`;oN`3o
00?ooooooh40oon10?l00_ooool00ol0o`Coooooooooo`03ooooo`03onSo0?m:o`3oQol000;ooooo
00?oD?l0ooooooooool01Oooool3okP0o`Cooooo0_oX0?l4ooooo`;oW`3o0_l0Mol8ooooo`03o`3o
o?lP0?ook_l000cooooo00?o0?oHooooooooool00onb0?l4ooooo`;o6_l01Oooool2o`04o`;ooooo
00?o0?lFo`;o0?l2o`000oooool4oh40o`oooooo0_lPo`02o`2Eo`Oooooo0_l0ok@3ooooo`;oG@3o
8_ooool2o`0:o`Wooooo0ol0of/3ooooo`;o0?nK0_l0OOl>ooooo`?o043o0olJ0?l01OooooooEol0
oeOo0?ooooooE`3o00;oJ@3o1oooool3o`3oC1Gooooo0olno`001?oooooo0?o`o`3ol?l0oo09oooo
o`GoHol01Oooool6oego00?o0?3o0_l0=?l6ooooo`Co>?l06oooool4obH0o`Sooooo2_l0f?lcoooo
o`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Wooooo00?o0000oooooooo
ool06Oooool00on7o`3oooooooooo`07ooooo`0@o`3fool0o`Co0?lXooooool0oe;o803oooooool0
1?oo5?l0o`3oPol0f?oo08Woo`2Qool0oocoooooo`3oV`;ooooo01co06_oo`3od_oooooo0>[oo`3`
ool0ogOo013oo`3oIOl0olcoE`3oo`23ool0Vooo0?oHo`10ool0c?ooB_l0oaX0oomk0?ooooooo`3o
^_mM0?oo0_l0o`2^ool0ol3o?P3oofT0ooln0?ooW`3o0oln0?l03_oX0?oo?P3oolX0ooo:0?oo?P3o
obH0ool0odcoEol0ooooool0Mooo03Coo`3o]?oooooo05Wo1?ooool00ol0;_oo02Soooooo`02oooo
o`;obP3o1_ooool3okP0o`;ooooo00?o5?l0ok80oonb0?l02Oooool00omk0?ooooooooooo`03oooo
o`?oP@3o0oooool01?oXo`3oB_l0od[o0?n7o`02ooooo`04oe3o0?ooooooooooooooo`Go^03o1Ooo
ool2onP0o`Gooooo00?oW`3oo`1gool0Mol02Oooool00ol0ooco803oooooo`0;ooooo`;o0?oH0onb
0?l00om_o`3oooooooooo`03ooooo`03oa[o0?oooooooooo00?ooooo00?o/_l0o`04ooooool00_oo
ool00ol0oaKo0_l0oh40o`04oh40oa;ooooo0ol0UOl7ooooo`;o0?nd0oooool2oed0ob;ooooo0_l0
2_l9ooooo`;o0?m[1?ooool01?l0oi_o07goo`1mool0OOl=ooooo`?o043o0olJ0?l01_ooooooEol0
oeOo0?mGo`3ooooooeL0o`;oJ@3o1oooool2o`3oC1Gooooo0olno`02ooooo`;o0?o`1oooool5of?o
00?ooooo1omMo`02ooooo`Co0?3o0ol0=?l4ooooo`Co>?l06oooool4obH0o`03ooooool0f?oo0=So
00Wo0=So?Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool06Oooool00on7o`3oooooooooo`07ooooo`0Ao`3fool0o`Co
Hol0o`3o:?l0oe;o803oo`0:ool01?ooGOl0oaCo0?l0f?oo08Woo`2Qoooooooo0?olooooool0oi/0
0_ooool08_l0Joooooooooooool0j_oo0?mgok;o0?l04?oo0?o<oeL0ool0ocCo08?oo`2Kool0omSo
043oo`3<oom:o`3o6P3oog/0ool0ok[oG@3oooooool2o`3o0:koo`3o`?ooooooJ@3oo`3ol?nO0?oo
07goooooool0D_ooj03oocSo0?l0olHColX0o`03ofWo0?oooooo0?of00Sooooo0onh0?l2ooooo`;o
/P3o1Oooool2og/0o`Oooooo00?o0?l4oooooon10?l00_n10?l00om:o`3oooooohOo0002ooooo`Go
^03o2?ooool2onP0o`Gooooo0_nO0?l00ol0Moooooooooooo`07ooooo`03onko0?l0ooco803o00co
oooo0onb0?l00oooooooKol0ooooo`04ooooo`;o6_l01Oooool2o`04o`;ooooo1?n10?lEooooo`;o
09Go2?ooool2o`3o]0?ooooo0_mM0?lRooooo`;o00[o2Oooool2o`3oJ`Cooooo0ol0OOl=ooooo`?o
043o0olJ0?l2ooooo`;oEol00_ooool00omG0?ooJ@3oofT0o`07ooooo`;o0?m<5?ooool3ocko00;o
oooo0ol0oo03ooooo`KoHol000?ooooooego0?mMo`001OmMo`05ooooo`Co0?3o00Coooooo`0dool0
=?oo03Co0_ooool5ocSo01_ooooo1?lV0?l5o`3HodSooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00?o0000ooooooooool01_ooool4o`0001Sooooo00?oQol0ooooooooool02?ooool04?l0
m_oo0?l4o`3o:?mYo`3o0?mBob00oooooooo00CooaCo0?l0f?oo0?n?o`29oooooooo0?olooooool0
oi/2ooooo`0Ho`1[ool0om;oooooo`3Zool0l?oo/_l0o`0@ool0ofGo0?o<oeL0ool0Pooo09_ooooo
ool0omSo043oooooool0oiGo6P3oog/0ool0ok[oG@3oooooool2o`3o0:ko0_ooool03_mY0?ooj?l0
oil0oonO0?ooooooo`1BoooX0?oo>?l0o`3oa_l0i?ooooooobH0ool0odcoEol00_ooool01?l0=?oo
0?ndooooool0FOl4ooooo`03o`0^oooooooo02So00?ooooo00?o0?ofooooooooool01Oooool00olD
o`3oooooooooo`05okP0o`04ok80ooooooooN`3oog/0o`Sooooo00?o0?l4onSo0?oXo`000_m:o`00
0oooooooP@3ookP0o`03okP0o`_ooooo0_oX0?l5ooooo`;oW`3o00?o07Ooooooooooool01oooool2
onko0003o`3oo?lP0?oooooo00Sooooo1?nb0?l2ooooo`;oKol01Oooool00olJo`3oooooooooo`03
ooooo`03ok;o0?l01?ooP@3o00?oP@3o5oooool2o`2Eo`Sooooo0_l0ok@3ooooo`;oG@3o8_ooool2
o`0:o`Sooooo0ol0of/3ooooo`?o07go00?o0?nKooooooooool02_ooool3o`10o`03oooooolJ0?oo
6P3o00;ooooo0omGo`000oooooooE`3ooeL0o`02ofT0o`Kooooo0ol0od`Cooooo`?o?_l00oooool2
o`3ol003oooooomSo`3oHol000?oHol000?ooooooego0?mMo`001?mMo`08ooooo`Co0?3o0oooool2
o`0do`03oooooolho`3o>?l000;o>?l06_ooool2o`3Ho`Co9P3o00?o0=Soooooooooool0C_ooool0
0005ooooool0003oooooooooool000002Oooool2o`0000Wooooo00?o0000ooooooooool06_ooool0
0on7o`3oooooooooo`07ooooo`0Do`3fool0o`Co0?lXooooool0oe;o803oooooool01?ooGOl0oaCo
0?l0f?oo08Woo`2Qoooooooo0?olo`3oOOl0oi_oooooo`1[ool0om82ooooo`0?o`3Zool0ogOo/_l0
o`0@ool0olco0?m[oeL0ool0Pooo09_oo`3of?l0@?oo0<cooooooolJ0?oooooo00;oN`3o00coG@3o
ooooool0[_oo0?o0oooooomY0?oo0?o`onSo0?l0OOooW`3oooooool0D_l2onP0o`06onko0?l0i?oo
ooooobH0ool0odcoEol00_ooool01?l0=?oo0?ndo`3o]?l0FOl4ooooo`03o`0^oooooooo02So00?o
oooo00?o0?ofooooooooool00oooool00olDo`3oooooooooo`06oooooa?o^03o00?oQol0oe3o0?n1
0?l00on10?l7ooooo`;oj03o1Oooool2oil0o`03o`1goooooooooooo00Kooooo0oo^o`000ooooooo
0?olob00o`07ooooo`?o/P3o00?oooooo`3of?l0omP00_ooool00om_o`3oooooooooo`04ooooo`04
oa[o0?ooooooooooooooo`GoP@3o00?oooooo`;o0?l0oaH05_ooool2o`2Eo`Sooooo0_l0ok@3oooo
o`;oG@3o8_ooool2o`0:o`Sooooo0_l0of/4ooooo`;o07go0_l0oi/;ooooo`?o043o00CooooooaX0
oolJ0?oo6P3o0_ooool2oeOo00;ooooo0_mG0?l2ofT0o`Kooooo0_l0od`Cooooo`?o?_l00oooool3
o`3ol0?oHol000?ooooooego0?mMo`000omMo`0;ooooo`?o0?3o1?ooool3o`0do`?o>?l05oooool6
o`3Ho`?o9P3oEOooool00005ooooool0003oooooooooool000002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01[ooooo00?oQol0ooooooooool01oooool04Ol0m_oo0?l4of?o0?l0
obSo0?mBoooooolP0?ooooooo`04oolDo`3o0=Soo`29ool0XOooooooo`3oo?oooooo0?nK00;ooooo
01Go06_oo`3od_oooooo0>[oo`3`oonbo`3o013oo`3oIOl0olcoE`3oo`23ool0Voooooooo`3of?l0
@?ooooooo`3oUOlJ0?ooB_l0o`3o^_mk0?l00_ooool04_l0[_oo0?o0oooooomY0?oo0?o`ooooool0
OOooW`3oo`1Boooooooo09GoonP0ooo^o`3o0>CooooooolV0?oo0?m<oeOo00;ooooo00?o03Coo`1g
ool0FOl00oooool01OmYo`3oooooo`0^oooooooo02So00?ooooo00?o0?ofooooooooool00_ooool0
0olDo`3oooooooooo`05ooooo`;oN`3o0oooool2ok80o`?ooooo0_oXo`000ol0o`CoB_l0ooooo`04
ooooo`03ohOo0?m@o`3ooooo00Cooooo1On10?l2onP0o`Gooooo0_nO0?l00ol0Moooooooooooo`06
ooooo`;ok_l00oooool00ol0ooco803oooooo`04ooooo`?o/P3o0oooool00ol0omSoooooooooo`02
ofoo00Gooooo00?o6_l0oh40oon10?l00on10?l01Onbo`3o00Coo`04oooooooo0_l000;o0?lF5Ooo
ool2o`2Eo`03ob3o0?oooooooooo00Cooooo0ol0ok@3ooooo`;oG@3o8Oooool3o`0:o`Sooooo0_l0
of/3ooooo`?o07go0_l0oi/:ooooo`?o043o00CooooooaX0oolJ0?oo6P3o0oooool2oeOo0006oooo
oomG0?ooE`3ooeL0ooooooooJ@3o1Oooool3o`3oC1;ooooo0olno`02ooooo`;oHol00_l0oo000omS
o`3oooooooooo`04oego00cooooo1?l0l?l5ooooo`;o03Co0_lho`0Eooooo`Ko0=So0_ooool4obH0
oeSooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo01[ooooo00?oQol0ooooooooool02?ooool0:?l0m_oo0?l4o`3o:?oo
oooo0?mBob00oooooooo00Cooego0?l0f?ooooooo`29ool0XOoo0?olooooool0oggo0?nKooooool0
Jooo0?oBooooool0j_oo0?3oo`3oMonbo`3o013oo`3oc?l0of_oE`3oo`23ool0Voooooooo`3of?l0
@?ooooooo`3oUOlJ0?ooB_l0o`3o^_mk0?l2ooooo`04o`2^ooooooooooooofT0o`;ooooo00Go07go
oil0ool0D_ooooooo`2Eo`02onP0o`05oooooolV0?ooooooo`3oC?mGo`000_ooool01Ol0=?oo07Oo
o`1IooooooooJOl000?ooooo00?o02koooooool0:?l00oooool01?l0ooKooooooooooolDo`06oooo
o`;oN`3o1oooool3ok80o`03od[o0?l0o`Cooooo00Gooooo00?oQol0oe3o0?ooool02?ooool2onP0
o`GoP@3o0_nO0?l9ooooo`;ok_l01?ooool00ol0ooco803oooooo`02ooooo`?o/P3o1Oooool01?l0
omSooooooooooom_o`03ooooo`GoP@3o0oooool2ok;o0005o`04oooooooo0_l0o`;o0?l0oaH05Ooo
ool2o`2Eo`03ob3o0?oooooooooo00Cooooo0_l0ok@5ooooo`03oed0oooooooooooo01oooooo0_l0
2_l00ol0ojOoooooooooo`06ooooo`;o0?m[0_ooool3o`1mo`03ooooool0oi_o0?nK00Wooooo0ol0
@?l01?oooooo6P3ooaX0oolJ0?l3ooooo`?oEol000?ooooooeL0oomG0?l00_ooool2ofT0o`Cooooo
0_l0od`Booooo`?o?_l01?mSo`03o`3ol003oooooomMo`3oGOl000;oGOl03?ooool4o`3`o`Cooooo
0_lho`03o`0doaCooooo1Ol0f?l4ooooo`Co9P3oG?ooool000;ooooo0_l00009ooooo`?o00002Ooo
ool00ol0003oooooooooo`0Jooooo`03ohOo0?oooooooooo00Sooooo017o0?Koo`3o1?l0obSooooo
o`3oD_lP0?oo00[oo`04oomMo`3o5?l0o`3Hool0ROoo0:7oooooool0oocoooooo`3oV`02ooooo`0E
o`1[ool0om;oooooo`3Zool0l?ooooooo`0@ool0oaKo0?o<oeL0ool0ocCo08?oo`2Kool0omSo043o
o`3<oooooooo6P3oooooool0ok[ooooo00;oN`3o00Go0:koo`3o`?ooooooJ@3oo`3ol002ooooo`0>
o`1moonO0?ooW`3oonSo0?l0UOoo0?o6onP0oooooooo9P3oooooool0odcoEol0ooooool0=?l2oooo
o`03o`1Iool0Mooooooo00?ooooo00?o02koooooool0:?l00oooool00ol0ooKo5?l0ooooo`03oooo
o`?oN`3o1oooool2onSo00;ooooo00?oB_l0ok80oonb0?l00_nb0?l4ooooo`03oe3o0?oooooooooo
00Kooooo0_oX0?l3ooooo`;o07Oo0_nO0?l8oh40o`03ooooooo^o`3ok_l000Gooooo0_lP0?l01?oo
oooo/P3ook80oonb0?l3ooooo`coP@3o00?ooooooa[o0?lJo`001?ooool00onbo`3oooooo`04o`02
o`;o0003ooooool0oaKooooo01?ooooo0_l0UOl00olPo`3oooooooooo`04ooooo`;o0?nd1Oooool2
oed0ob3ooooo0_l02_l9ooooo`;o0?m[00Coooooo`1mool0OOoo07go0oooool00ol0oi_ooooooooo
o`06ooooo`?o043o0_ooool2oaX0o`Cooooo0_mGo`02ooooo`;oE`3o0_ooool2ofT0o`?ooooo0ol0
od`Aooooo`?o?_l00omSo`02ooooo`;o0?o`1?mMo`0=ooooo`?o0?3o1?ooool4ocSo00;o03Co4ooo
ool4o`3Ho`Kooooo0olV0?mPooooo`006Oooool00ol0003oooooooooo`0Jooooo`03ohOo0?oooooo
oooo00Sooooo033o0?Koo`3o1?mSo`3o0?lXooooool0oe;o803oooooool01?ooGOl0o`3Hool0o`[o
08Woo`2Qool0oocoooooo`3oOOl0oi_oooooo`1[ool0om;oooooo`3Zool0l?oo0?mgok;o0?l04?oo
0?mUo`3oc?mG0?oo08?oo`2Koooooooo0?oHo`10oooooooo0?nEoaX0oooooooo0?njoooooomM0?oo
N`3oo`2^ool2o`3oooooofT0ool0oo02ooooo`06o`1mooooooooW`3oonSo0?l0UOoooooo0_oX0?l0
0olV0?ooooooo`3oC002ooooo`04o`0doomYo`3oooooo`1Io`;o07Oo0oooool00ol0;_ooooooo`0X
o`02ooooo`04oaCo0?l0ooKoooooooooo`;oN`3o1oooool3onSo00;ooooo0_m:o`000ol0o`Cooooo
ooooo`02ooooo`Co/P3o1oooool2onP0o`;ooooo0_l0Mol3oil0o`Wooooo00?ok_l0oh40oon10?l0
1?n10?l5ok80o`KoP@3o0_ooool00ol0omSoooooooooo`02ofoo00Gooooo00?o6_l0ooooooooool0
0_ooool2ok;o0004ooooool01?oo0_l0ooooo`;o0?lF4oooool2o`2Eo`;o8?l01Oooool2o`3o]0Go
oooo0_mM0?lPooooo`;o00[o2Oooool2o`3oJ`03ooooool0OOoo07go00Cooooo0_l0oi/7ooooo`;o
043o0_ooool3oaX0o`?ooooo0omGo`001?ooooooE`3ooeL0oomG0?l2ooooo`;oJ@3o0_ooool3o`3o
C17ooooo0olno`03of?o00;ooooo0ol0oo000omMo`3oooooooooo`0=ooooo`?o0?3o0oooool4ocSo
00;ooooo0_l0=?lAooooo`Co0=So1_ooool4obH0odcooooo2_l0oiD=ooooo`006Oooool00ol0003o
ooooooooo`0Kooooo`03ohOo0?oooooooooo00Sooooo017o0?Koo`3o1?l0obSoooooo`3oD_lP0?oo
ooooo`04oomMo`3o5?l0o`3Hool0ROoo0:7oooooool0oocoooooo`3oV`02ooooo`0Go`1[ool0om;o
ooooo`3Zool0l?ooooooo`0@ool0oaKo0?o<o`3oJomG0?oo08?oo`2Kool0omSoooooo`10oooooooo
0?nEoaX0ool0ok[oB_l0oed0ooooool00omk0?l00ol2o`3oJ@3oo`3ol002ooooo`07o`1moooooooo
W`3ooil0ool0UOooooooo`3To`02onP0o`05o`3oC?mGo`3oooooofWo0?l0=?l00_ooool00ol0FOoo
0?ndo`1go`02o`1go`05ooooool0;_ooooooo`0XoolDo`000_ooool2og/0o`Oooooo0_oXo`03oooo
o`;oB_l00_ooool00ol0o`Coooooooooo`03ooooo`;oD?l000?ooooook80oonb0?l00onb0?l2onP0
o`;o/P3o0_l0Mol2oil0o`Sooooo2onb0?l00olP0?ooooooooooo`09ooooo`04o`3of?oooooooooo
ofoo00Kooooo00?o6_l0ooooooooool00_ooool01?nbo`3o0_l0o`04ool01?l2ooooo`03o`3o5_oo
oooooooo017ooooo0_l0UOl2ob3o00Gooooo0_l0ok@5ooooo`;oG@3o8?ooool2o`0:o`Wooooo0_l0
of/3o`1mo`Cooooo0_l0oi/6ooooo`?o043o00CooooooaX0oolJ0?oo6P3o1?ooool2oeOo00;ooooo
0_mG0?l4ooooo`03ofT0oooooooooooo00;o0?m<4_ooool2ocko00?oHol00_ooool00omMo`3o0?o`
o`3ol00@ooooo`?o0?3o00?oooooocSo0?lho`000olho`03ooooo`?o03Co3_ooool5o`3Ho`Kooooo
1?lV0?m1ooooo`oo0?nE5oooool001Wooooo00?o0000ooooooooool06oooool00on7o`3ooooooooo
o`08ooooo`0Ao`3fool0o`Co0?lXooooool0oe;oJOl0ob00oooooooo00Cooego0?l0f?oo0?n?o`29
ool0XOoo0?olooooool0oi/00_ooool06_l0Jooo0?oBooooool0j_oo0?3oo`3oMooooooo013oo`3o
IOl0olcoE`3oo`23ool0Voooooooo`3of?l0@?ooooooo`3oUOlJ0?ooooooo`3o^_m:o`3oG@3ooooo
ool0[_oo0?o00_mk0?l02?mY0?oo0?o`ooooool0OOoo0?nWooooool0D_ooW`3o0_l0UOl01Ol0i?oo
j?l0onP0ool0odcoEol000;ooooo00Go03Coooooool0FOooooooo`3o]002ooooo`;o07Oo00?o02ko
oaCo0?mk0?l00_mk0?l00ooooooo0?ofooooo`03ooooo`?oj?l00oooool2od[o00?ooooo00?o0?l4
ooooooooool00oooool00om@o`3oQol0ooooo`04ooooo`;oj03o00Coooooo`1gool0Mooooooo3?nb
0?l2onko00Sooooo00?o803oooooooooool02?ooool2o`3of003oooooom_o`3oKol000Gooooo0_lJ
o`03ooooo`04ok;o0?l2o`3o0_l0o`04o`?ooooo00?o0?lFooooooooool04?ooool2o`2Eo`;o8?l0
1?ooool3o`3o]0Kooooo00?oG@3oooooooooool07_ooool2o`0:o`Wooooo0_l0of/2o`1mo`Gooooo
0_l0oi/5ooooo`?o043o0_ooool2oaX0o`Gooooo0_mGo`001?ooooooE`3ooeL0oomG0?l4ooooo`;o
J@3o0ol0od`Aooooo`?o?_l00_mSo`000oooooooGOl0oego0003o`3ol0oooooo0ol0l?l4ocSo00Ko
oooo0_l0=?l=ooooo`Co0=So2?ooool3obH0oc_ooooo2_l0oiDVooooo`006Oooool00ol0003ooooo
ooooo`0Kooooo`03ohOo0?oooooooooo00Sooooo01;o0?Koo`3o1?mSo`3o0?lXooooool0oe;o803o
ooooool01?ooGOl0o`3Hool0oh?o08Woo`2Qoooooooo0?olooooool0oi/2ooooo`0Io`1[ool0om;o
ooooo`3Zool0l?oooooook;o0?l04?oo0?o<o`3oJomG0?oo08?oo`2Koooooooo0?oHo`10oooooooo
0?nEoaX0oooooooo0?njoooooomM0?ooB_l0o`2^o`02ooooo`?oN`3o00Goooooo`1moooooooo05;o
ooooo`02oil0o`03o`2Eooooooook_l000;oj03o00WoEol0onSo0?oooooo03Coooooool0FOoooooo
o`3o]?ooool01?mk0?l00ol0Mooo02Soooooo`02onSo0004o`3om_oXo`3oj?l0onSo00Cooooo0_m:
o`04ooooo`03o`3o1?oooooooooo00?ooooo00?oD?l0oooooon7o`000_ooool3onP0o`?o07Oo00?o
oooooil0oonO0?l02Oooool2onko00[ooooo00?o803oooooooooool02?ooool01?l0omSooooooooo
oom_o`06ooooo`05oa[o0?oooooooooooooooonbo`000_l2o`001?oooooo00Coooooooooool2o`3o
5Q7ooooo0_l0UOl00ooooooo8?l0ooooo`03ooooo`;o0?nd1oooool2oed0oaoooooo0_l02_l9oooo
o`04o`3oJol0OOoo07goo`1mo`Gooooo0_l0oi/4ooooo`?o043o0_ooool3oaX0o`Cooooo0omGo`00
0oooooooE`3ooeL0o`05ooooo`;oJ@3o0_l0od`Booooo`;o?_l00_mSo`000oooooooGOl0oego0003
o`3ol0oooooo0ol0l?l3ocSo00Oooooo0ol0=?l;ooooo`Co0=So2?ooool4obH0ocCooooo2_l0oiD`
ooooo`006Oooool00ol0003oooooooooo`0Kooooo`03ohOo0?oooooooooo00Wooooo00go0?Koo`3o
1?l0obSoooooo`3oD_oooooo803oooooool01?ooooooo`3Hool0ohoo08Wo00;ooooo01ko0?olo`3o
Voooooooooooo`1[ool0om;oooooo`3Zool0l?oo0?mgooooool04?oo0?lFo`3oc?l0of_oE`3oo`23
ool0Vooo0?oHo`3<ool0@?ooooooo`3oUOlJ0?oo0?njoooooomM0?ooooooo`2^ool0ol02ooooo`03
o`;o0?mY0?ooN`3o00?oN`3o00?o05;oooooooooool00_nO0?l00omYo`3ok_l0obH0o`03onP0o`03
onSo0?mk0?ooN`3o00?oN`3o00So0?ndonSo0?lDo`3oj?l0o`0^oooXo`3o02Soo`1go`;ooooo00?o
0?ofooooooooool00_ooool2od[o00Gooooo00?o0?l4ooooooooool00oooool00om@o`3oooooohOo
0003onP0o`?o07Oo0_ooool2oil0o`Sooooo0oo^o`0;ooooo`03ob00oooooooooooo00Sooooo00Co
0?oHooooooooooooKol01Oooool2oa[o00;ooooo0ol2o`02ooooo`04o`04ooooooooooooo`3o5Q3o
oooo0ol0UOl00ooooooo8?l0ob3o0003ooooo`;o0?nd1oooool2oed0oaoooooo0_l02_l9ooooo`03
o`3oJol0OOoo07go00Kooooo0_l0oi/4ooooo`;o043o0oooool2oaX0o`Gooooo0_mGo`02ooooo`;o
E`3o1Oooool2ofT0o`;o0?m<4Oooool3ocko0003of?o0?mMo`3oGOl000;oGOl00_l0oo0?ooooo`?o
0?3o0olho`08ooooo`;o03Co2Oooool5o`3Ho`Sooooo1?lV0?laooooo`Oo0?nE>_ooool001Wooooo
00?o0000ooooooooool06oooool00on7o`3oooooooooo`09ooooo`0Bo`3fool0o`Coooooo`3o:?oo
oooo0?mBob00oooooooo00Cooego0?l0f?oo0?l:o`29ool0XOooooooo`3oo?l0oggo0?nK0_ooool0
1Ol0Joooooooooooool0j_oo0?3o00;ooooo01Oo013oo`3oc?ooooooE`3oo`23ool0Voooooooo`3o
f?l0@?ooooooo`3oUOlJ0?ooooooo`3o^_ooooooG@3oooooool0[_oo0?o0od[o0?oooooo0_l0ofT0
o`02ooooo`03o`1moomk0?ooN`3o00?oN`3o00?oW`3oog/0oomk0?l00omk0?l2onP0o`03ooooool0
=?oo05Wo00;ooooo00Oo0?ndooooooooooooooooo`0^oooooooo02So00Go07Oo0_m:o`07ooooo`04
o`3o1?ooooooooooooooo`;o07Oo0ooX0?l3o`1go`?ooooo0_nO0?l8ooooo`;ok_l03Oooool00olP
0?ooooooooooo`08ooooo`04o`3of?ooooooKol0ofoo00Gooooo00?o6_l0ooooooooool00_l2o`00
0onbo`3oooooooooo`02o`04o`;ooooo00?o0?lFooooooooool03Oooool2o`2Eo`;ooooo0_lPo`03
ooooo`;o0?nd1oooool2oed0oaoooooo0_l02_l9ooooo`03o`3oJol0OOoo07go00Oooooo00?o0?nK
ooooooooool00_ooool2o`10o`;ooooo0olJ0?l5ooooo`;oEol00_ooool2oeL0o`Gooooo00?o0?m<
ofT0ool0od`04Oooool3ocko0005of?o0?mMo`3oGOl0oego0?ooool00ol0oo0>ooooo`?o0?3o0olh
o`08ooooo`?o03Co1oooool4o`3Ho`[ooooo0olV0?l^ooooo`Oo0?nE4ooooolMo`3o2PCo02ko3Ooo
ool001Wooooo00?o0000ooooooooool07?ooool00on7o`3oooooooooo`08ooooo`0Bo`3foooooooo
0?l4o`3o:?oooooo0?mBob00ool02_oo00Cooego0?oooooo0=Soo`29ool0XOooKol0ooooool0ooco
0?nK0_ooool05Ol0Jooo0?oBooooool0j_oo0?3oo`3oMooooooo013oo`3o5_l0olco0?m[oeL0ool0
Pooo09_oooooool0omSo043oooooool0oiGo6P3oo`3o^P02ooooo`04oed0oooooooo0:koo`3o`0;o
B_l000[oJ@3oo`3ol?ooooooooooo`1moooooooo05;oofWo0?l0olKo>?l00_nO0?l01OlV0?oooooo
o`3oC?mGo`3ok_l000?oj03o00?o05WooaCo0?ooool00_l0ok@2ooooo`04o`0^oooooooo02Sooooo
o`;oB_l000?o0?ofo`1gool0Mol02Ol0Mol4onP0o`03ohOo0?oooooooooo00?ooooo0onO0?l7oooo
o`?ok_l03_ooool00olP0?ooooooooooo`07ooooo`;o0?oH00?oooooofoo0?ooool01Oooool01OlJ
o`3oooooo`;o0?l2o`3o/_l000?ooooo00?o00Coooooooooool00_l0oaH>ooooo`;o09Go0_ooool2
ob3o00;ooooo0ol0ok@8ooooo`03oed0oooooooooooo01gooooo0_l02_l9ooooo`?o07go1oooool2
o`3oV`;ooooo0ol0@?l01?oooooo6P3ooaX0oolJ0?l6ooooo`;oEol00_ooool2oeL0o`Gooooo00?o
0?m<ofT0oomY0?l04?ooool01?mSo`3o?_l0ocko0?ooool3oego00;ooooo0_l0oo0>ooooo`?o0?3o
0_lho`09ooooo`?o03Co1_ooool4o`3Ho`_ooooo0olV0?l[ooooo`Ko0?nE1ooooolCo`3o2QSooooo
1Ol0;_lAooooo`006Oooool3o`0001cooooo00?oQol0ooooooooool02Oooool00ol0m_oo0?l4o`3o
:002ooooo`0@o`3oD_lP0?ooooooo`04oomMo`3o0=Soo`3o2_l0ROoo0:7oooooool0ooco0?mmo`3o
Vooooooo06_oo`3odP;ooooo00[o0>[oo`3`ool0ogOoooooo`0@ool0ofGo0?o<oeL0ool0Pooo09_o
0_ooool01_l0c?oo043oo`3oUOlJ0?ooooooo`3o^P;ooooo00?oG@3oooooool0[_l00oooool01?mY
0?oo0?o`ooooooooool2o`1mo`05o`1Boooooooo0?o6ooooool0i?l00onO0?l00ol0odcoEol0oeOo
0002onko00Coj03o00Ooooooo`3o]?ooooooooooo`0^oom:o`3o02So00?ooooo00?o0?ofoooooooo
ool01?ooool4onP0o`05oooooom@o`3ooooooooooon7o`000_ooool3oil0o`Oooooo0oo^o`0@oooo
o`03ob00oooooooooooo00Oooooo00Co0?oHooooooooooooKol01Oooool01?lJo`3o0_l0o`;o0?l2
o`02ok;o00?ooooo00Co00Cooooooooooooo0?lF3_ooool2o`2Eo`?ooooo00?o8?l0ooooooooool0
0_l0ok@9ooooo`;oG@3o7Oooool3o`0:o`Wooooo0_l0OOl8ooooo`;o0?nK0_ooool2o`10o`;ooooo
0_lJ0?l7ooooo`;oEol00_ooool2oeL0o`Cooooo0_l0od`2ofT0o`kooooo0_mSo`03ocko00?oGOl0
0_ooool3o`3ol0gooooo0ol0l?l2ocSo00[ooooo0_l0=?l5ooooo`Co0=So3?ooool3obH0obOooooo
0_l0o`X5o`3oU@go0?l:9_ooool5o`0^oaKooooo000Iooooo`03o`000?oooooooooo01cooooo00?o
Qol0ooooooooool02Oooool04_l0m_ooHol0o`3o1?l0obSoooooo`3oD_lP0?ooJOl0o`04oomMo`3o
0=Soo`3oPol0ROoo0:7ooe3o0?oooooo0?olo`3oV`;ooooo00ko06_oo`3od_oooooo0>[oooooool0
l?oooooook;o0?l04?oo0?o<oooooomG0?oo08?oo`2Ko`;ooooo00Ko043oooooool0oiGo6P3ooooo
ool0okX2ooooo`03oed0oooooooo0:ko00?ooooo00KoJ@3oo`3ol?m:o`3oJOl0o`3oYol0D_l2oooo
o`05o`3oa_oooooo0>Coo`2EoolV0?l01?nO0?l01Ooooooo5?l0o`0dool0FOook_l0017oj03o00?o
0?l4ooooooooool00_m@o`02ooooo`04ohOo0?nO0?ooW`3ooil0o`Oooooo0oo^o`0Aooooo`;o803o
2Oooool01?l0omSoooooofoo0?m_o`05ooooo`;o0_l00_ooool00onbo`3oooooooooo`02ooooo`04
o`04ooooooooooooo`3o5Pgooooo0_l0UOl3ooooo`;o8?l00ol0ok@9ooooo`;oG@3o7Oooool2o`0:
o`03o`3oYooooooooooo00Kooooo0ol0OOl8ooooo`;o0?nK0_ooool2o`10o`04oooooolJ0?oo6P3o
oaX0o`Kooooo0omGo`02ooooo`;oE`3o1?ooool2o`3oC0;oJ@3o3Oooool3of?o00;o?_l00omMo`02
ooooo`?o0?o`3Oooool3o`3`o`;o>?l02_ooool3o`0do`?ooooo1?l0f?l=ooooo`?o9P3o8oooool4
o`3o2PGo0?nE<oooool5o`0^oa_ooooo000Iooooo`03o`000?oooooooooo01gooooo00?oQol0oooo
ooooool02?ooool05_l0m_ooooooo`3o1?l0obSoooooo`3oD_oooooo803oofWo0?l01?ooGOl0o`3H
ool0o`[o08Woo`2Qoom_o`3oooooo`3oo?l0oi_oooooo`1[ool0om82ooooo`0:o`3Zool0l?oo0?mg
ooooool04?oo0?lFo`3oc?l0of_oE`3oo`23o`;ooooo00Ko0<coo`10oooooooo0?nEoaX0ool0okX3
ooooo`03oed0ool0[_oo0?o000?ooooo00goJ@3oo`3ol?m:o`3oB_l0o`3oYol0D_ooB_l0o`3oa_lh
o`3o0>Coooooool0UOoo9P3o00;oB_l000?o0?m<oil0oonO0?l00_nO0?l01?l0FOooB_l0onko0?o^
o`02o`3o]004ooooool0;_ooooooo`0Xo`?ooooo00Go0?ofooooooooooooooooo`3o1002ooooo`03
oe3o0?ooooooW`3o00?oW`3o1_ooool4onko01?ooooo00?o803oo`3oo?ooool01oooool2o`3of003
oooooom_o`3ooooo00Cooooo0_l2o`02ooooo`;o/_l00oooool2o`04o`;ooooo00?o0?lFoooooooo
ool02_ooool2o`2Eo`?ooooo0_lPo`02o`3o]0[ooooo0_mM0?lMooooo`;o00[o00?o0?nWoooooooo
ool01_ooool2o`1mo`03o`3oJooooooooooo00Kooooo0_l0oi/2ooooo`;o043o00?ooooooaX0oolJ
0?l01oooool2oeOo00?ooooo0_mG0?l4ooooo`;o0?m<0_mY0?l;ooooo`CoHol00olno`02oego00?o
oooo0_l0oo0=ooooo`?o0?3o0_lho`0;ooooo`;o03Co0oooool3o`3Ho`kooooo0olV0?lOooooo`Ko
0?l:1Ol0oiDcooooo`Go02ko3oooool4o`1<o`gooooo000Iooooo`03o`000?oooooooooo01gooooo
00?oQol0ooooooooool02Oooool04_l0m_ooHol0o`3o1?l0obSoooooo`3oD_lP0?ooooooo`04oomM
o`3o0=Soo`3oPol0ROoo0:7ooe3o0?oooooo0?olo`3oV`;ooooo00Ko06_oo`3od_ooooooooooo`3Z
ool0l?l2ooooo`06o`0@ool0olcooooooeL0ool0Pooo09_o0_ooool01_l0c?oo043oo`3oUOlJ0?oo
ooooo`3o^P?ooooo01;oG@3oo`2^ool0ol3oooooofWo0?ooooooJ@3oo`3ol?l2o`3oooooo`3oYol0
D_ooooooo`3oa_lho`3o0>Cood[o0?l0UOl2obH0o`03oaCo0?l0odcoEol000;ooooo1?nO0?l2onko
00;o0?nd00?o02koooooool0:?l00oooool2o`3omPKoW`3o00?oooooohOo0?ooool00oooool4onko
01Kooooo00?o803oo`3oo?ooool01oooool01?l0omSooooooooooom_o`03ooooo`?o0_l00_ooool2
ok;o00Cooooo00?o00Coooooooooool00_l0oaH:ooooo`?o09Go0oooool01?lPo`3o0?ndo`3o]?l0
ok@:ooooo`;oG@3o7Oooool2o`0:o`Sooooo0ol0OOl00ol0of_oooooooooo`06ooooo`;o0?nK0_oo
ool2o`10o`03oooooolJ0?oo6P3o00Oooooo0_mGo`03ooooo`;oE`3o0oooool3o`3oC003oooooomY
0?oooooo00Wooooo0omSo`02ooooo`;o?_l00_mMo`04ooooo`;o0?o`3?ooool3o`3`o`;o>?l02ooo
ool3o`0do`03ooooool0f?oo0=So00;o0=So3_ooool3obH0oa_ooooo1ol0o`X6o`3oUCCooooo1?l0
;_l?ooooo`Go04co4Oooool001Wooooo00?o0000ooooooooool07Oooool00on7o`3oooooooooo`09
ooooo`0Fo`3foomSo`3o0?l4o`3o:?oooooo0?mBoooooolP0?ooJOl0o`04oomMo`3o0=Soo`3oSol0
ROoo0:7ooe3o0?oooooo0?olo`3oVooooooo06_oo`3odP;ooooo00_o0>[oo`3`ool0ogOoooooo`0@
ool0oaKo0?o<oooooomG0?oo08?oo`2Ko`02ooooo`05o`10oooooooo0?nEoaX0ool0okX01?ooool0
0omM0?oo0:koofWo0003ooooo`0;ofT0oooooooo0_l0o`;o0?l0ojOo05;oooooool0olKo>?l0o`3T
ooooool00_l0UOl01?lV0?ooooooo`3oC?mGo`02ooooo`03o`0dool0FOoooooo00coW`3o00?o0?of
onko0?m@o`001?o^o`000on7o`3ok_l0onko0002onko01Wooooo00?o803oo`3oo?ooool01oooool0
1Ol0omSooooooooooom_o`3ooooo00?o0_l000Gooooooa[o0?oooooooooook;o0005ooooo`04o`04
ooooooooooooo`3o5P[ooooo0_l0UOl5ooooo`;o0?nd2oooool2oed0oagooooo0_l02_l8ooooo`;o
07go00?oooooo`3oJoooool02?ooool00ol0oi_oooooo`10o`02o`10o`?o6P3o1_ooool3oeOo00?o
oooo0_mG0?l3ooooo`;o0?m<0_ooool2ofT0o`Sooooo0omSo`03ooooo`;o?_l000?oGOl0oooooooo
ool00_ooool3o`3ol0cooooo0_l0l?l2ocSo00_ooooo0ol0=?l4o`3Ho`oooooo0olV0?lGooooo`Oo
0?l:0_ooool5o`3oUCGooooo1Ol0;_l=ooooo`Ko04co5_ooool001Wooooo00?o0000ooooooooool0
7_ooool00on7o`3oooooooooo`09ooooo`0Bo`3fool0o`Coooooo`3o:?oooooo0?mBob00oooooooo
00Cooego0?l0f?oo0?n3o`29ool0XOoooooooe3o0?l0ooco0?nK0_ooool01_l0Jooo0?oBoooooooo
oooo0>[oo`3`o`;ooooo00Ko013oo`3oc?lJo`3o0?m[oeL0ool0Vol2ooooo`06o`3<ool0@?oo0?nE
oooooolJ0?oo0?nj1?ooool00omM0?oo0:koooooo`02ooooo`0BofT0ool0oo3oooooooooool2o`3o
0?nWo`1Boooooooo0?o6ocSo0?l0i?oo5?l0ooooool0UOoo9P3oooooool0odcoEol00_ooool00ol0
=?oo05Woooooo`04ooooo`04o`3o]?l0;_ooooooo`0Xo`;ooooo00?o0?l4ooooool0ooH01?ooool0
0on7o`3oooooooooo`0Kooooo`03ob00ool0oocooooo00Oooooo00Co0?oHoooooom_o`3oKol00_l2
o`02ooooo`;o6_l000?ooooook;o0?nbo`001Oooool01?l01?ooooooooooool0oaH9ooooo`;o09Go
1?ooool3o`3o]0_ooooo0_mM0?lMooooo`;o00[o2?ooool2o`1mo`03ooooool0of_o0?m[00Sooooo
0_l0oi/2o`10o`03oooooolJ0?oo6P3o00Oooooo0_mGo`04ooooo`;oE`3o0oooool2o`3oC0;ooooo
0_mY0?l7ooooo`?oHol00oooool3ocko00Gooooo0_l0oo0<ooooo`?o0?3o00?o>?l0ooooooooool0
2_ooool2o`0do`?o0=So4?ooool3obH0oa?ooooo1ol0o`X3ooooo`Ko0?nE=_ooool4o`0^o`gooooo
1Ol0C?l4ooooo`_o0?mU3Oooool001Wooooo00?o0000ooooooooool07_ooool00on7o`3ooooooooo
o`09ooooo`0Bo`3foomSo`3o0?l4o`3o:?oooooo0?mBob00oooooooo00Cooego0?mYo`3o0=Soo`3o
Sol0ROoo8?l0oe3o0?oooooo0?ol0_ooool01ol0Jooo0?oBoooooooooooo0>[oooooool0l?l00_oo
ool01_l04?oo0?o<oooooomG0?oo08?oo`2Ko`;ooooo00Oo0<coo`10ool0oiGo6P3oooooool0ok[o
oooo00;oJOl000?ooooooed0ool0ol000oooool02_mY0?oo0?o`oooooooooooo0_l0o`3oYol0D_oo
0?o6oooooolDo`02o`3To`05ooooool0UOoo9P3oooooool0od`00_mGo`000ooooooo03Coo`1Io`06
ooooo`08o`0^ool0okCo02Soo`3o1?ooooooD?l0ooooool0ooH2ooooo`03ohOo0?oooooooooo01_o
oooo00?o803oo`3oo?ooool01_ooool2o`3of004ooooool2o`3o0_l0o`;o00?ooooo00Co6_l0oooo
oonbo`3o/_l01Oooool2o`04o`03ooooool0oaKo0?lF00Oooooo0ol0UOl4ooooo`;o0?nd00?o8?l0
ooooooooool02Oooool2oed0oagooooo0_l02_l7ooooo`?o07go00?oooooo`3oJol0of/02?ooool2
o`3oV`;o043o00?ooooooaX0oolJ0?l01_ooool3oeOo00Cooooo0_mG0?l2ooooo`?o0?m<0_ooool2
ofT0o`Oooooo0_mSo`03ooooo`03oego0?lno`3o?_l000Kooooo0_l0oo0;ooooo`?o0?3o00?o>?l0
ooooooooool02_ooool3o`0do`;o0=So3oooool4obH0o`oooooo1ol0o`X5ooooo`Go0?nE>?ooool4
o`0^o`Sooooo1?l0ofD5o`1<o`Wo0?mU6?ooool001Wooooo00?o0000ooooooooool07_ooool00on7
o`3oooooooooo`09ooooo`0Co`3foooooooo0?l4ooooool0obSoooooo`3oD_lP0?ooooooo`04oomM
o`3o0=Soooooool0ROoo0:7oob3o0?m@o`3o0?olo`3oV`02ooooo`0>o`1[ool0om;oooooooooool0
j_oo0?3oo`3oMooooooo013oo`3o5_l0olcooooooeL0ool0Pol2ooooo`07o`3<ool0@?oo0?oHo`3o
UOlJ0?ooooooo`3o^P04ooooo`03oed0ool0ob;ooooo00;ooooo00?oJ@3oo`3ol?ooool00_ooool0
1?l0D_oo07goo`3oa_ooool2ocSo0005o`3Toooooooo09GoobH0ooooool00_l0od`01?mGo`3ooooo
o`0dool0FOl6ooooo`04o`0^ool0okCo02Soo`0Xo`?ooooo00?o0?ofohOo0?ooool07?ooool00olP
0?oo0?olooooo`06ooooo`04o`3of?oooooo0_l0o`;o00Cooooo0_lJo`02ok;o00Kooooo00Co00Co
oooooooooooo0?lF1oooool2o`2Eo`Cooooo0ol0ok@00olPo`3oooooooooo`09ooooo`;oG@3o7Ooo
ool00ol0ojOo00[oooooo`06ooooo`;o07go0_ooool2o`3oJ`Sooooo00Co0?nKo`10ool0@?oo043o
0olJ0?l6ooooo`;oEol01Oooool2oeL0o`;ooooo0_l0od`3ooooo`;oJ@3o1_ooool3of?o00;ooooo
00CoGOl0ocko0?lno`3o?_l01_ooool2o`3ol0[ooooo0ol0l?l00olho`3oooooooooo`0;ooooo`;o
03Co0_l0f?l?ooooo`?o9P3o3?ooool7o`3o2POooooo1Ol0oiDiooooo`Co02ko0_ooool:o`3oI@Co
04co5_ooool3o`2^o`gooooo000Iooooo`03o`000?oooooooooo01oooooo00?oQol0ooooooooool0
2Oooool04_l0m_ooHol0o`3o1?l0obSoooooo`3oD_lP0?ooooooo`04oomMo`3oooooo`3Hool0ROoo
0:7oob3o0?m_o`3oD?l0o`3oo0;ooooo00Oo06_oooooool0om;oooooo`3Zoooooooo0?3o00;ooooo
00Ko013oo`3oc?lJo`3oE`3oo`23ool0Vol2ooooo`06o`3<ool0@?oo0?oHoooooolJ0?oo0?nj1Ooo
ool00omM0?ooooooooooo`02ooooo`03ofT0ool0oo3ooooo00;ooooo00?o05;oo`1mool0olH00_oo
ool01Olho`3o0>Coooooool0UOoo9P3o00;ooooo00Go0?m<oeOo0?oooooo03Coo`1Io`05ooooo`05
o`3o1?l0;_oo0?ndo`3o]?l0:?l00oooool00ol0ooKoooooooooo`0Jooooo`03ob00ool0oocooooo
00Kooooo00Co0?oHo`;o0?l2o`3oKol01?ooool00olJo`3ooooook;o0007ooooo`04o`04oooooooo
ooooo`3o5PKooooo0_l0UOl3ooooo`?o0?nd00?oooooob3o0?lPo`002_ooool2oed0oagooooo00?o
0?nWo`0:ool02_l01_ooool2o`1mo`;ooooo0_l0of/9ooooo`;o043o00?ooooooaX0oolJ0?l01ooo
ool2oeOo00Gooooo0_mG0?l2ooooo`;o0?m<0oooool2ofT0o`Kooooo0_mSo`02ooooo`;oGOl00_ln
o`07ooooo`;o0?o`2Oooool01?lho`3o0?3oo`3`oolho`0=ooooo`?o03Co00?o0=Soooooooooool0
3Oooool3obH0o`Sooooo1ol0o`X9ooooo`Go0?nE>Oooool5o`0^o`Ko0?mU1_ooool4o`1<oaGooooo
1Ol0[_l@ooooo`006Oooool00ol0003oooooooooo`0Oooooo`03ohOo0?oooooooooo00Wooooo01?o
0?Koof?o0?l0o`Coooooo`3o:?l0oe;oooooob00oooooooo00Cooego0?l0f?ooJOl0o`29ool0XOoo
8?l0ofoo0?l0oggo0?ol00;ooooo00oo06_oo`3od_ooooooooooo`3Zool0l?oo0?mgooooool04?oo
0?lFo`3oc?lJo`3oE`3oo`23ool0Vol00_ooool01_l0c?oo043oo`3of?oooooo6P3oo`3o^PGooooo
00?oG@3oooooooooool00_ooool02?mY0?oo0?o`oooooolDo`3oooooo`1Bool0OOoo0?o60_ooool0
3?lho`3o0>Cooooooooooooo9P3oo`2Eoooooooo0?m<oeOo0?oooooo03Coo`1Io`?ooooo00?o0?l4
oe3o0?ooool00_l0;_l01Ol0okCo02Soo`3o]?n7o`3ooooo00;o0?of6Oooool00olP0?oo0?oloooo
o`04ooooo`05o`;o0?l0omSo0?oHoooooom_o`001Oooool00olJo`3o/_l0ok;o0006ooooo`;o00Co
00?oooooo`3o5_l0oaH01?ooool3o`2Eo`;ooooo0ol0ok@2ooooo`;o8?l02_ooool2oed0oagooooo
00?o0?nWo`0:ool02_l01Oooool3o`1mo`?ooooo00?o0?m[ooooooooool01_ooool3o`10o`03oooo
oolJ0?oo6P3o00Kooooo0omGo`05ooooo`;oE`3o00Coooooo`3oC?l0odco0?m<1?ooool00omY0?oo
ooooooooo`04ooooo`;oHol000?ooooooego0?mMo`000olno`06ooooo`?o0?o`2?ooool01?lho`3o
0?3oo`3`ool0l?l>ooooo`;o03Co00?o0=Soooooooooool03Oooool3obH0o`Gooooo1_l0o`X<oooo
o`Co0?nE<oooool7o`3oI@Co02ko3Oooool4o`1<oaGooooo1?l0[_lEooooo`006Oooool00ol0003o
ooooooooo`0Oooooo`03ohOo0?oooooooooo00[ooooo01;o0?Koof?o0?l0o`Co0?lXooooool0oe;o
803oooooool01?ooGOl0ooooool0f?oo08Woo`2QoolPo`3oooooofoo0?l0oo`3ooooo`06o`1[ool0
om;oooooooooool0j_oo0?3o0_ooool01_l04?oo0?o<ok;o0?l0ocCoE`3oo`2Ko`;ooooo00Oo0<co
o`10oooooooo0?oHoooooolJ0?oo0?nj00Gooooo0_mM0?l3ooooo`03ofT0ool0oo3ooooo00;ooooo
00?o05;oo`1mool0OOl00_l2o`001Olho`3o0>Cooooooooooooo9P3o00;o09Go00So0?m<oeOo0?oo
oooo03Coo`1IooooooooD?l0o`3o10Cooooo00Go02koooooool0:?oo02Soo`3o]002ooooo`03o`3o
m_oooooooooo01Cooooo0_lP0?l01?l0oocoooooooooooooool3o`;o0004o`3of?ooooooooooofoo
00Cooooo0_lJo`000onbo`3oooooooooo`05ooooo`04o`04ooooooooooooo`3o5PCooooo0_l0UOl2
ooooo`?o0?nd1?ooool00olPo`3oooooooooo`08ooooo`;oG@3o7Oooool00ol0ojOo00[oo`0:o`05
ooooo`;o07go1?ooool2o`3oJ`Oooooo0_l0@?l01?l0oi_ooooooaX0oolJ0?l6ooooo`;oEol01_oo
ool2oeL0o`03ooooool0odco0?m<00Gooooo0_mY0?l4ooooo`?oHol00omMo`02ocko00Oooooo0_l0
oo08ooooo`;o>?l00_l0l?l>ooooo`03o`3Hool0=?oo03Co00oooooo0olV0?l4ooooo`Co0?l:3_oo
ool4o`3oUBkooooo2Ol0ofD3ooooo`Co02ko3Oooool4o`1<oaCooooo1Ol0[_lIooooo`006Oooool0
0ol0003oooooooooo`0Pooooo`03ohOo0?oooooooooo00Wooooo01?o0?Koof?o0?l0o`Co0?lXoooo
ool0oe;o00[oob00oooooooo00Cooego0?l0f?ooooooo`29ool0XOoo8?l0ofoo0?l0oggo0?ol00;o
oooo01So06_oo`3od_ooooooooooo`3Zoooooooo0?3oooooool04?ooooooo`3oc?nbo`3oE`3oo`23
ool0VoooJOl0ooooool0c?oo043oooooool0omSooooooaX0ool0okX4ooooo`04o`2^ool0ob;oG@3o
ooooo`;o5?l000?oJ@3oooooooooool00_ooool2o`1Bo`05o`1moooooooo0_l0o`;o0?l0i?l00_oo
ool02OlV0?ooooooo`2Eool0UOooEol0ooooool0=?oo05Woo`3o1006ooooo`04o`0^oooooooooooo
o`0Xo`?o0?nd00?o0?ofooooooooool04_ooool01?lP0?ooooooo`3oo?ooool3o`;o0004ooooool0
omSo0?oHooooo`;oKol01?ooool00olJo`3o/_l0ooooo`07ooooo`04o`04ooooooooooooo`3o5P;o
oooo0ol0UOl01?oooooo0?ndo`3o]?l0ok@5ooooo`;o8?l02Oooool2oed0oagooooo0_l0ojL00ol0
2_ooooooooooo`03ooooo`;o07go1?ooool2o`3oJ`Oooooo0_l0@?l01?l0oi_o6P3ooaX0oolJ0?l5
ooooo`?oEol01_ooool2oeL0o`?o0?m<1Oooool2ofT0o`Cooooo0_mSo`03oego0003oooooolno`3o
?_l000Oooooo0_l0oo07ooooo`;o>?l00ol0l?l=ooooo`04o`3Hool0=?oo03Coo`0do`kooooo0olV
0?l2ooooo`Go0?l:3Oooool5o`3oUB_ooooo1ol0ofD7ooooo`Go02ko2Oooool4o`3o:0Co04co4ol0
obP5o`2^o`Go0?lX6Oooool001Wooooo0ol0000Pooooo`03ohOo0?oooooooooo00[ooooo01;o0?Ko
of?o0?l0o`Co0?lXooooool0oe;o00[oob00oooooooo00Coooooool0f?oo08Woo`2QoolDo`3ooooo
ofoo0?l0oo`3ooooo`06o`1[ool0om;oooooooooool0j_oo0?3o0_ooool01_l04?oo0?o<o`3oIOlJ
o`3oE`3oo`23o`;ooooo00Oo0<coooooool0@?oo0?nEo`3of?oooooo6P3o00Gooooo00?o0:koo`3o
8_mM0?l00_ooool00omY0?oo0?o`ooooo`04ooooo`06o`1Bool0OOoooooooooooolho`3o0>Co0_l2
o`02obH0o`06ooooool0UOoo09Gooe3o0?l0=?oo05Wo1_ooool01On7o`3o02koo`0^oooooooo02So
00;ooooo00Co0?ndo`3om_l0okCo0?nd4?ooool00olP0?ooooooo`3oo002o`;o00;ooooo0_l0omP2
ooooo`03ofoo0?oooooooooo00;ooooo0_lJo`09ooooo`03o`04oooooooo0?lF00Co09Go00Cooooo
o`3o]?l0okCo0?nd1oooool00olPo`3oooooooooo`07ooooo`;oG@3o7Oooool2o`3oY`;o00[o0ooo
ool3o`1mo`Cooooo0_l0of/6ooooo`?o043o00?o0?nKoaX0oolJ0?l01_ooool2oeOo00Sooooo00?o
E`3oo`3oC?l0od`01_ooool2ofT0o`?ooooo0_mSo`03oego0004oooooolno`3o?_l0ocko00Oooooo
0_l0oo06ooooo`?o>?l00_l0l?l=ooooo`;o0=So0_l0=?l>ooooo`?o9P3o00?oooooo`3o2_l0o`X0
0_l0o`X>ooooo`Co0?nE:Oooool7o`3oI@[ooooo1?l0;_l=o`3o:0Go04co4_ooool5o`2^o`[ooooo
3?l0obP=ooooo`006Oooool00ol0003oooooooooo`0Pooooo`03ohOo0?oooooooooo00[ooooo01?o
0?Koof?o0?l0o`Co0?lXooooool0oe;o00[oob00oooooooo00Cooego0?l0oh?o0=Soo`29ool0XOoo
5?l0ofWo0?l0oggo0?ol00;ooooo00oo06_oo`3od_l0oeWoooooo`3Zoooooooo0?3ooooooomYo`3o
013oo`3oc?oooooo0?m[oeL0ool0Vol00_ooool01?l0c?ooooooo`10ool0oiD2o`3of003oaX0oooo
oooooooo00;ooooo00Co5?l0o`2^ooooooooG@3o0_ooool00omY0?oo0?o`ooooo`04ooooo`07o`1B
ool0OOoo07gooooooolho`3o0>Coooooo`02o`;o0007obH0oom@o`3o0?m<o`2EoomGo`3o03Coo`1I
o`04ooooo`07ohOo0?ooooooooooooooool0;_ooooooo`0Xo`03ooooo`03o`3om_oooooo0?nd00?o
0?nd2_ooool01?l2o`3o803oo`;o0?l0oo`4ooooo`03o`3of?oooooooooo00;oKol01?ooool00olJ
o`3o/_l0ooooo`07ooooo`;o00Co0ol0UOl5o`3o]0Sooooo0_lPo`08ooooo`;oG@3o7_ooool00ol0
ojOo00[oo`0:o`02ooooo`?o07go1Oooool2o`3oJ`Kooooo0_l0@?l2ooooo`;o6P3o1Oooool3oeOo
00Sooooo0_mG0?l7ooooo`;oJ@3o0oooool01?mSo`3oGOl0oego0?mMo`02ooooo`;o?_l01oooool3
o`3ol0Gooooo0olho`03o`3`o`gooooo00Co0=Soo`0dool0=?oo03Co3Oooool3obH0o`Co0?l:3ooo
ool3o`3oUBKooooo1ol0ofD>o`3o:0?o02ko3Oooool4o`1<oa7ooooo1_l0[_lXooooo`006Oooool0
0ol0003oooooooooo`0Qooooo`03ohOo0?oooooooooo00Wooooo01Co0?Koof?o0?oooooo0?l4o`3o
:?oooooo0?mBo`0:oolP0?ooooooo`04oooooooo0=Soo`29ool0XOoooooooaCo0?m_o`3o0?mmo`3o
o0;oJOl000oo06_oo`3od_mYo`3oJOl0o`3Zool0l?oo0?mgooooool04?ooooooo`3oc?ooooooE`3o
o`23ool0Vol00_ooool01ol0c?ooooooo`10ool0oiGoooooo`3of?lJ0?l00_ooool01OlDo`3ooooo
ooooool0[_oooooo00;oG@3o00?oooooofT0ool0oo001Oooool00ol0D_ooooooo`1mo`02ooooo`07
o`3Toooooooooooooe3o0?lV0?oo0_l0o`3o1002o`2Eo`05o`0dool0FOoooooooooooon7o`001Ooo
ool01?l0;_ooooooo`0Xool0:?l2ooooo`03o`3om_oooooooooo00;ooooo0ol0ok@7o`;o0003ob00
oooooooo0?ol00?ooooo0_l0omP2ooooo`03ofoo0?oooooooooo00;ooooo00?o/_l0oa[o0?ooool0
1_ooool2o`2Eo`03o`04ool0UOoo0?nd00?o0?nd3?ooool00olPo`3oooooooooo`05ooooo`?oG@3o
7_ooool01?l0ojOo00[oo`0:ooooool3o`1mo`Kooooo0_l0of/5ooooo`?o043o00CooooooaX0oolJ
0?oo6P3o1Oooool2oeOo00Sooooo00?o0?m<oeL0oomG0?l01oooool2ofT0o`?ooooo0omMo`03oooo
o`;o?_l01oooool2o`3ol0Gooooo0olho`000ooooooo0?3oo`3`o`0=ooooo`;o0=So0_l0=?l=oooo
o`?o9P3o0ol0o`X?ooooo`Co0?nE8_ooool7o`3oI@;o0?lX3oooool4o`0^o`cooooo1?l0C?l@oooo
o`Go0:ko;_ooool001Wooooo00?o0000ooooooooool08Oooool00on7o`3oooooooooo`0:ooooo`0L
o`3foomSo`3o0?l4o`3o:?oooooo0?mBo`0:oooooooo803oo`04oooooooo0?n3o`3Hool0ROoo0:7o
ob3o0?lDo`3o0?mmo`3oo?m@o`3oooooo`1[oooooooo0?oBooooool0j_ooooooo`3`o`;ooooo00Ko
013oo`3oc?l0oaKo0?ldoeL0ool0Vol3ooooo`08o`3<oooooooo043oo`3oUOoooooo0?oHoaX0oolD
o`03ooooo`08o`3o`?l0[_oooooooooooomM0?ooooooofT0ool0oo05ooooo`05o`1Bool0ojOo07go
o`1mooooool00_l0i?l2ooooo`08obH0ooooooooooooo`3oC?l2o`3o03Coo`1Iool0UOl7ooooo`04
o`0^ooooooooooooo`0Xo`;ooooo00?o0?ofo`;o0?l2o`001?l2o`06o`3o]003ob00oooooooo0?ol
00?ooooo00?o0?oHooooooooool00_m_o`03ooooo`03ok;o0?lJo`3o6_l000;ooooo0ol0ok@3o`2E
o`03o`3o]?l01?oo0?nd00;o0?lF3Oooool2ob3o00Kooooo0_mM0?lOooooo`;o0?nW00Co00[ooooo
ool0OOoo07go1oooool2o`3oJ`Gooooo0_l0@?l2ooooo`;o6P3o00?o0?nKooooooooool00_ooool3
oeOo00Sooooo00?o0?m<oeL0oomG0?l01oooool2ofT0o`;ooooo00?oHol0oego0?mMo`000oooool3
ocko00Oooooo0_l0oo04ooooo`?o>?l000Coooooo`3`ool0l?oo0?3o3Oooool2o`3Ho`;o03Co3?oo
ool3obH0o`;o0?l:4?ooool3o`3oUAoooooo1ol0ofD00ol0obSoooooooooo`0Booooo`?o02ko2ooo
ool5o`1<o`oooooo1Ol0[_lcooooo`006Oooool00ol0003oooooooooo`0Qooooo`03ohOo0?oooooo
oooo00[ooooo01So0?Koof?o0?l0o`Coooooo`3o:?l0oe;oooooo`0:oolP0?ooooooo`04ool0oh?o
0=Soo`29ool0XOooooooob3o0?lDo`3o0?mmo`3oo?m@o`3oooooo`1[ool0om82ooooo`0;o`3Zool0
l?oo0?mgooooool04?ooooooo`3oc?l0oaKoE`3oo`23ool0Vol00_ooool02?l0c?ooooooooooool0
@?oooooooaCo0?l0omSo6P3o1?ooool01ol0[_oo0?lRooooooooooooG@3ooooooomY0?l00_l0oo04
ooooo`0:o`1Bool0ojOoD?l0o`1moooooooo>?l0o`3Tool0o`CoooooobH0o`;ooooo00?o0?m<oeOo
0?l0=?l00_l0FOl3o`2Eo`Co0_l00_l0;_l01?l2o`3o02Soo`;o0?ooool2o`3omPWooooo00?o803o
ooooool0oo`00_l0ok@2o`3of0go0?nd0ol0UOl2ooooo`;o00Co00?oooooo`3o5_ooool03?ooool2
ob3o00Kooooo0_mM0?lOooooo`;o0?nW0_l02_l2o`1mo`Oooooo0_l0of/5ooooo`;o043o0_ooool2
oaX0o`;o0?nK0oooool2oeOo00Sooooo0_l0od`2oeL0o`Oooooo0_mY0?l2ooooo`03of?o0?mMo`3o
GOl000?ooooo0_lno`07ooooo`?o0?o`0oooool3ocSo00;ooooo0_l0l?l=ooooo`;o0=So0ol0=?l:
ooooo`04o`3o2_lV0?oo9P3oobH0oa7ooooo1?l0oiDLooooo`Ko0?mU0ol0obPEooooo`Co02ko2_oo
ool4o`1<o`oooooo1Ol0[_lUooooo`Ko0>Co3Oooool001Wooooo00?o0000ooooooooool08_ooool0
0on7o`3oooooooooo`0:ooooo`0Do`3foooooooo0?l4o`3o:?oooooo0?mBooooool02_oo803ooego
0?l01?oo0?n3o`3Hool0ROooooooob3o0?ooooooKol0o`3oVol0oo`2oe3o0006o`1[ool0om;ooooo
ooooool0j_oo0?3o0_ooool01ol04?oo0?o<o`3oIOooooooE`3oo`23oonbo`000_ooool01?l0c?oo
ooooooooool0@?l2ooooo`03o`3of?lJ0?oo6P3o00?ooooo00Ko0:kooooooooooooooooooed0oooo
ool2ofT0o`0<o`3ol?oooooooooooooooom@o`3o05;oo`3oYooooooo07goooooool0o`Co0>Co0_oo
ool01OlV0?ooooooooooool0odcoEol000;o03Co00?o05Woooooooooool01?l0UOl2ooooo`04o`0^
oooooooo02Soo`0Xo`;ooooo00?o0?ofooooooooool01Oooool01?lP0?ooooooo`3oo?ooool2o`3o
f0;ooooo0_m_o`02ooooo`03ok;o0?lJo`3o6_l000;ooooo1?l0UOl4ooooo`04o`04oooooooooooo
o`3o5Pgooooo00?o8?l0ooooooooool01?ooool2oed0oaoooooo0_l0ojL2o`0:o`03o`1moooooooo
oooo00Kooooo0_l0of/4ooooo`?o043o00CooooooaX0oolJ0?oo6P3o0_l0oi/3ooooo`;oEol02?oo
ool2o`3oC0;oE`3o1oooool2ofT0o`;ooooo0omMo`03ooooo`;o?_l01oooool2o`3ol0?ooooo0olh
o`03ooooo`;o0?3o3Oooool2o`3Ho`;o03Co2Oooool2o`3o2P?o9P3o4Oooool3o`3oUAKooooo1Ol0
obP5o`3oI@03o`3o:?oooooooooo01Sooooo0ol0;_l;ooooo`?o04co3oooool4o`2^ob7ooooo2Ol0
i?lCooooo`006Oooool00ol0003oooooooooo`0Rooooo`03ohOo0?oooooooooo00[ooooo01go0?Ko
of?o0?l0o`Coooooo`3o:?l0oe;oooooo`0:oooooooo803oo`04ool0oh?o0=Soo`29ool0XOoooooo
ob3o0?oooooo0?mmo`3oo?lDo`3oooooo`1[ool0om;o0?mIooooool0j_ooooooo`3`o`02ooooo`07
o`0@ool0olco0?lFo`3o=?mG0?oo09_ook;o0002ooooo`04o`3<oolDo`3oooooo`10o`;ooooo0_l0
omP01OlJ0?oooooooooooooooooo0:ko00?ooooo00OoG@3oooooooooooooJ@3oo`3ol?ooooooD?l0
00;ooooo00?o05;oo`3oYoooool00_l0OOl02?lho`3o0>Cooooooooooooo9P3ooooooon7o`3o0?m<
0_mGo`000ol0=?oo05Woooooo`04ooooo`?o09Go00Co02koo`2Eool0UOoo02So0_ooool00ol0ooKo
ooooooooo`03ooooo`03ob00oooooooo0?ol00;o0?oH0oooool00om_o`3oooooooooo`07o`2Eo`Oo
oooo00Co00Cooooooooooooo0?lF3?ooool2ob3o00Gooooo0_mM0?lOooooo`04o`3oYol0OOoo07go
o`0:o`Wooooo0_l0of/4ooooo`;o043o0_ooool2oaX0o`;ooooo00?o0?nKooooooooool00omGo`07
ooooo`?o0?m<0_mG0?l8ooooo`03ofT0oooooooooooo00;oGOl00oooool3ocko00Oooooo0_l0oo02
ooooo`?o>?l01?ooool2o`3`o`gooooo0_l0f?l2o`0do`Kooooo1?l0o`X3obH0oa3ooooo1?l0oiDA
ooooo`So0?lX00?oooooo`3oIOl0ofD00_l0ofDLooooo`Co02ko2oooool3o`1<o`kooooo1?l0[_lK
ooooo`[o0>Co7?ooool001Wooooo00?o0000ooooooooool08_ooool00on7o`3oooooooooo`0;oooo
o`0>o`3foooooooo0?l4o`3o:?oooooo0?mBooooool02_oo803ooego0?l01?oo0?n3o`29ool0XOl2
ooooo`04ob3o0?m_o`3o0?mmo`3oo0;o5?l000Ko06_oo`3od_ooooooooooo`3Zool0l?l2ooooo`0>
o`0@ool0olco0?mUo`3o5_mG0?oo08?oo`2Koonbo`3o5?l0ooooool0c?ooooooo`3oUOl0@?l2oooo
o`03o`3o^_l0omSo6P3o00;ooooo00?o0?o0o`2^ooooool00_ooool2oed0o`03oooooomY0?oo0?o`
00Cooooo00Co05;oo`3oYol0o`Cooooo0_l0OOl01?l0i?oooooooooooolV0?l2ooooo`;o0?m<00?o
Eol0o`0dool0FOl02?ooool2o`0^o`03o`2Eool0:?oo09Go00Go09Go00?o803oo`2Eool0UOl02Ol0
UOl2oa[o00_ooooo00Co00Coooooool0oaKo0?lF3?ooool00olPo`3oooooooooo`02ooooo`?oG@3o
7_ooool01?l0ojOo07goo`1mool0OOl2o`0:o`Sooooo0_l0of/4ooooo`;o043o0_ooool2oaX0o`;o
oooo0_l0oi/00oooooooEol0oeOo0007ooooo`?o0?m<00?ooooooeL0oomG0?l02?ooool2ofT0o`03
oooooomMo`3oGOl000?ooooo0_lno`07ooooo`?o0?o`00CoooooocSo0?lho`3o>?l01Oooool2o`3`
o`cooooo0ol0f?l2o`0do`Gooooo0ol0o`X01?oooooo9P3oobH0oolV0?l?ooooo`Co0?nE4?ooool5
o`3o:0Gooooo1?l0ofDLooooo`Co02ko3?ooool3o`1<o`cooooo1Ol0[_lDooooo`_o0>Co9_ooool0
01Wooooo00?o0000ooooooooool08oooool00on7o`3oooooooooo`0:ooooo`0?o`3foomSo`3o0?l4
o`3o:?oooooo0?mBooooool02_ooooooob00ool01?oo0?n3o`3Hool0ROoo0:7o00;ooooo00co8?l0
o`3oOOl0oi_o0?olooooool0Jooo0?oBo`3oFOoooooo0>[oooooool0l?l2ooooo`0:o`0@ool0olco
ooooo`3o=?mG0?oo08?oo`2Koonbo`3oooooo`3<o`;ooooo00Oo0?nEo`10ooooooooooooo`3o^_oo
oooo6P3o00;ooooo00?o0:koo`3o8_ooool00_ooool01Om@o`3oG@3ooed0oomY0?oo0?o`00Cooooo
00?o05;oo`3oYol0ojL00_ooool01Ol0OOoo0>CoohOo0?oooooo9P3o00?ooooo00Co0?m<oeOo0?l0
=?oo05Wo2Oooool00ol0;_ooooooo`0Xo`02ooooo`05o`3om_lP0?oo803oo`3of?l0oo`01?ooool2
ofoo00;o/_l00_lJo`0;ooooo`;o00Co00?oooooo`3o5_ooool02oooool2ob3o00?ooooo0_mM0?lN
ooooo`05o`3oYol0OOoo07goo`1mooooool00_l02_l8ooooo`;o0?m[1?ooool2o`10o`04oooooolJ
0?oo6P3ooaX0o`?ooooo00Co0?nKoeOo0?mGo`3oEol01_ooool3o`3oC0;ooooo0_mG0?l8ooooo`;o
J@3o0omMo`03ooooo`;o?_l01oooool2o`3ol004oooooolho`3o>?l0ocSo00Kooooo0_l0l?l<oooo
o`;o0=So00?oooooo`0dool0=?l01?ooool3o`3o2P;ooooo0_lV0?l?ooooo`?o0?nE3oooool5o`3o
:0Gooooo1Ol0ofDMooooo`?o02ko3Oooool3o`1<o`_ooooo1?l0[_l?ooooo`[o0>Co8?ooool4o`0X
o`gooooo000Iooooo`03o`000?oooooooooo02?ooooo00?oQol0ooooooooool02_ooool03ol0m_oo
Hol0ooooool0o`Co0?lXooooool0oe;oooooo`0:oolP0?ooGOl0o`04ool0oh?o08Woo`2Qo`02oooo
o`04ob3o0?oooooo0?mmo`3oo0;ooooo01?o06_oo`3od_lDo`3o5?l0o`3Zool0l?oo0?mgoaCo0?l0
4?oo5?l0o`3oc?lDo`3o0?ldoeL0ool0Pooo6_l0ok;o0?oooooo0<co00;ooooo00Co0?nEo`10ool0
@?oo0?nj0_ooool01OlJ0?oo0?oHooooool0[_oooooo00;oD?l00oooool00omM0?ooJ@3oo`3ol002
ooooo`04o`3o1?oooooo05;oooooo`;o0?nW00?oooooo`1mool0OOl00_ooool01?lV0?oooooooooo
ooooool2o`3oC0;o03Co2Oooool02?l0;_ooooooo`0Xool0:?oo803oo`3om_l0omSo0?ol1?ooool0
0om_o`3o/_l0ok;o0002oa[o00cooooo00Co00Cooooooooooooo0?lF3?ooool01?lPo`3ooooooooo
ooooool2oed0oakooooo0ol0OOl3ooooo`03o`0:oooooooooooo00Kooooo0_l0of/4ooooo`;o043o
0olJ0?l4ooooo`;o0?nK00?oEol0ooooooooool01?ooool3o`3oC0?ooooo0_mG0?l8ooooo`;oJ@3o
0_mMo`03ooooo`?o?_l01oooool2o`3ol0?o>?l01_ooool3o`3`o`_ooooo0ol0f?l3o`0do`?ooooo
0ol0o`X2ooooo`?o9P3o3Oooool4o`3oU@gooooo1Ol0obP6ooooo`Co0?mU7_ooool4o`0^o`gooooo
0ol0C?l;ooooo`?o0:ko3?ooool7o`3Tob?ooooo1ol0:?l4o`3o=0gooooo000Iooooo`03o`000?oo
oooooooo02?ooooo00?oQol0ooooooooool02oooool01_l0m_ooooooooooool0obSoooooo`3oDP;o
oooo00Oo00[oob00ool01?oo0?n3o`3Hool0ROoo0:7o00;ooooo00co8?l0o`3oOOl0oi_o0?oloooo
ool0Joooooooo`3od_oooooo0>[oooooool0l?l2ooooo`07o`0@ool0olco0?mUooooool0ocCoE`3o
o`23o`02oa[o0008ok;o0?l0c?ooooooooooool0oiGoooooo`10ool0okX2ooooo`04oaX0ool0omSo
0?oHo`2^o`Kooooo00CoG@3oofT0ool0oo3o0?o`0oooool01_l0D_ooooooooooool0ojOoQol0oooo
o`;o07go00?oooooobH0oolV0?l00oooool2o`3oC003o`0doooooooooooo00Oooooo00Oo02koo`3o
f?lP0?oo02Soooooool0ooco0?of00;ooooo0_m_o`000onbo`3o6_l0oa[o000=ooooo`04o`04oooo
oooo0?lFo`3o5P_ooooo0_lPo`001?ooooooG@3ooed0oomM0?lLooooo`Co07go1?ooool2o`0:o`Oo
oooo0_l0of/3ooooo`?o043o0_lJ0?l5ooooo`03oeOo0?l0oi_oEol000Gooooo0ol0od`4ooooo`;o
E`3o2?ooool2ofT0o`;oGOl00oooool2ocko00Oooooo0ol0oo02ocSo00Oooooo0_l0l?l<ooooo`;o
0=So00?oooooo`0dool0=?l00oooool3o`3o2P;ooooo0olV0?l<ooooo`Co0?nE3?ooool5o`3o:0Oo
oooo1?l0ofDNooooo`Co02ko3_ooool3o`1<o`[ooooo1?l0[_l8ooooo`Oo0>Co8oooool7o`0Xo`Go
0?ld4oooool001Wooooo0ol0000Tooooo`03ohOo0?oooooooooo00[ooooo00Ko0?Koof?o0?oooooo
0?l4o`3o:?l0oe82ooooo`07o`0:oooooooo803oo`04oooooooo08Woo`2Qo`03ooooo`07ob3o0?l0
oggo0?nKo`3oo?oooooo06_oo`3odP02ooooo`03o`3Zoom@o`3o0?3o00;ooooo00_o013oo`3oc?oo
ooooooooo`3o=?mG0?oo09_ooooooolJo`3o/_l0o`3<o`02ooooo`04o`3oUOoooooo043oo`3o^P;o
D?l000Co6P3oooooool0omSo0:ko1oooool00omY0?ooG@3oo`3ol003ooooo`03o`1BooooooooQol0
00;o0?nW00?oooooo`3Tool0OOl00_ooool00olV0?ooooooooooo`02ooooo`03o`3oC?l0=?ooEol0
00Gooooo0_l0omP2ob00o`03o`0^ool0ooco02So00;ooooo00?o0?ofofoo0?nbo`000_lJo`0=oooo
o`;o00Co00?oooooo`3o5_ooool02_ooool2ob3o00?oG@3o7?ooool3o`1mo`03o`3oYooooooooooo
00Cooooo00?o00[oooooooooool01Oooool2o`3oJ`?ooooo0_l0@?l3oaX0o`Cooooo0_mGo`02o`3o
V`Cooooo0ol0od`5ooooo`;oE`3o2?ooool2ofT0o`;oGOl00oooool2ocko00Oooooo0_l0oo02ocSo
00Sooooo0_l0l?l<ooooo`;o0=So00?oooooo`0dool0=?l00_ooool3o`3o2P;ooooo0olV0?l<oooo
o`?o0?nE2oooool5o`3o:0Oooooo1Ol0ofDOooooo`?o02ko3oooool3o`1<o`[ooooo0ol0[_l5oooo
o`Oo0>Co8Oooool9o`0Xo`03o`3o=?oooooooooo01cooooo000Iooooo`03o`000?oooooooooo02Co
oooo00?oQol0ooooooooool02oooool01_l0m_ooooooooooool0obSoooooo`3oDP;ooooo00Oo00[o
ob00oomMo`3o00Coo`3Hool0ROoo0:7o00;ooooo00Co8?l0o`3oOOoooooo0?ol0_ooool01_l0Jooo
0?oBoooooooooooo0>[oo`3`o`;oD?l000?o013oo`3oc?l0ofD00_ooool01_l0ocCoE`3oo`2Koooo
oooo6_l0o`3<o`;ooooo00GoD?l0o`3oUOm@o`3o043oo`3o^P02ooooo`04oaX0oooooooo0?oHo`2^
o`Gooooo00?o0?l4oooooomY0?l00_mM0?l3ooooo`04o`1Booooooooooooooooo`;o0?nW00Go0>Co
o`1mool0OOooooooobH0o`04ooooo`04o`3oC?l0=?ooEol0ooooo`?o0?oH00Ooooooob00oooooooo
ooooo`3oo?l0;_oooooo00;o02So00?oKol0o`3om_l0ooH03_ooool01?l01?ooooooooooool0oaH;
ooooo`?oG@3o7?ooool3o`1mo`;o0?nW1_ooool2o`0:o`Kooooo0_l0of/3ooooo`;o043o0_lJ0?l4
ooooo`?oEol000?oooooo`3oVoooool00_ooool3o`3oC0Kooooo0_mG0?l8ooooo`;oJ@3o0_mMo`02
ooooo`?o?_l01oooool2o`3ol003ocSo0?oooooooooo00Oooooo0_l0l?l<ooooo`;o0=So0ol0=?l0
1?oooooo0?l:o`3o2_l0o`X2ooooo`?o9P3o3?ooool3o`3oU@Wooooo1Ol0obP8ooooo`Co0?mU8?oo
ool4o`0^o`oooooo0ol0C?l9ooooo`Co0:ko00?oooooo`3Tool0i?l01Ol0i?lMooooo`_o02So0_l0
oc@Vooooo`006Oooool00ol0003oooooooooo`0Tooooo`03ohOo0?oooooooooo00_ooooo00Ko0?Ko
ooooooooooooooooo`3o:?l0oe82ooooo`08o`0:oooooooo803oo`04oooooooo08Woooooool0XOl2
ooooo`0Eob3o0?l0oggo0?nKo`3oo?oooooo06_oo`3od_l0oeWoooooo`3Zoooooooo0?3ooooooom@
o`3o013oo`3oc?l0ofGoD?l0o`3o=?l0oaKoE`3o00?oD?l000Oo0<cooe3o0?ooooooooooo`3oUOoo
oooo043o00?ooooo00Co6P3oooooool0ol3o0:ko0_l0omP00ooooooo0?l4ooooo`02ooooo`07ofT0
ooooooooG@3ooed0oon7o`3oooooo`1Bo`04ooooo`03o`3oYol0i?oo0>Co00;o07go00?o9P3ooooo
ooooool00oooool2o`0do`04oeOo0?ooooooooooob00o`;ooooo00Ko0?oloooooooooooo02koofoo
0?ooool2o`0Xo`03ooooool0ooKooooo00_ooooo00Co00Coooooool0oaKo0?lF2Oooool3oed0oaco
oooo0ol0OOl2o`3oY`Sooooo00?o00[oooooooooool01?ooool2o`3oJ`?ooooo00Co043ooaX0oolJ
0?oo6P3o0oooool3oeOo00;ooooo0_l0oi/01?oooooo0?m<o`3oC?l0od`7ooooo`;oE`3o2?ooool2
ofT0o`;oGOl00_ooool2ocko00Oooooo0ol0oo0:ooooo`;o0?3o3?ooool01Ol0f?oo03Coo`0dool0
=?oooooo00?o0?l:0_ooool3obH0o`cooooo0ol0oiD8ooooo`Co0?lX2Oooool4o`3oIB3ooooo1?l0
;_l@ooooo`?o04co2Oooool3o`2^o`Go0>Co6oooool9o`0Xo`?ooooo1Ol0oc@[ooooo`006Oooool0
0ol0003oooooooooo`0Uooooo`03ohOo0?oooooooooo00_ooooo00Ko0?Kooooooooooooo0?lXoooo
ool0oe82ooooo`07o`0:oomMo`3o803oo`04ool0f?oo08Woo`2Qo`03ooooo`07ob3o0?l0oggo0?nK
o`3oo?oooooo06_oo`3odP02ooooo`0<o`3Zool0l?ooooooooooool04?ooooooo`3oc?l0ofGooooo
o`3o=?mG0?oo08?o0oooool01ol0c?oo6_l0ok;o0?oooooo0?nEooooool0@?l00oooool01OlJ0?oo
0?o0ooooool0[_oooooo00?o0?oH0oooool2ofT0o`05o`3ol?mM0?ooG@3oooooool0D_l01?ooool2
o`3oY`03o`3Toooooooooooo00;o9P3o0ol0omP00ooooooo05Woo`0do`02ob00o`;ooooo00?o0?ol
ok;o0?nbo`000_m_o`02o`0^o`;ooooo00?o02Soooooool0ooH02Oooool2o`04o`;o0?lF2?ooool3
oed0o`03ob3o0?oooooooooo01Wooooo0ol0OOl2o`3oY`Wooooo0_l02_l6ooooo`04o`3oJooooooo
ooooo`10o`?o6P3o0oooool3oeOo00Cooooo00Co0?nKo`3oC?l0odco0?m<2?ooool2oeL0o`Sooooo
0_mY0?l2oego00;ooooo0_lno`06ooooo`03ocSo0?l0oo3o0?o`00_ooooo0_l0l?l<ooooo`04o`3H
ool0=?oo03Coooooo`?o0?l:0_ooool3obH0o`cooooo0ol0oiD6ooooo`Go0?lX2Oooool4o`3oIB3o
oooo1?l0;_lAooooo`?o04co1_ooool2o`3To`Co0:ko00?o0>Coooooooooool06Oooool7o`0Xo`Oo
oooo1Ol0oc@Coooooa3o08?o3Oooool001Wooooo00?o0000ooooooooool09Oooool00on7o`3ooooo
ooooo`0;ooooo`06o`3fooooooooooooooooool0obSo0?mB0_ooool02?l02_ooooooob00ool01?oo
ooooo`3Hool0ROoo0:7o0oooool02ol0oggo0?nKooooool0ooco06_oo`3od_l0oeWoooooo`3Zoooo
oooo0?3o00;ooooo00So013oooooool0olco0?mUooooool0ocCoE`3oo`23o`?ooooo00Oo0<cooa[o
0?lJo`3o/_l0o`3oUOoooooo043o00?ooooo0_lJ0?l00ooooooo0:koooooo`02ooooo`Go0?oH00Ko
J@3oo`3ol?ooooooG@3oooooool0D_l4ooooo`;o0?oH00Go0>Coo`3of?l0omSo0?oHobH0o`02o`1m
o`;ooooo00?o803oo`0dool0=?l00_l0oo`00omGo`3oKol0ofoo0002oa[o00;ooooo00?o02kooooo
ooooool00_l0:?l2o`3omPKooooo00?o00Coo`3o5_l0oaH02?ooool2oed0o`03oooooolPo`3ooooo
01Wooooo0ol0OOl3o`3oY`Wooooo0_l02_l6ooooo`;o0?m[0_l0@?l2oaX0o`?ooooo0omGo`05oooo
o`;o0?nK00?o0?m<ooooooooool01oooool2oeL0o`Sooooo0_mY0?l2oego0004oooooolno`3o?_l0
ocko00Gooooo0_lho`02o`3ol0_ooooo0_l0l?l;ooooo`04o`3Hool0=?oo03Coo`0do`?o0?l:00?o
ooooobH0oolV0?l00_lV0?l<ooooo`?o0?nE1Oooool4o`3o:0[ooooo1?l0ofDPooooo`Co02ko4_oo
ool3o`1<o`Cooooo1?l0i?l3o`2^oaWooooo1ol0:?l8ooooo`Ko0?ld3_ooool:o`23oagooooo000I
ooooo`03o`000?oooooooooo02Gooooo00?oQol0ooooooooool02oooool01ol0m_ooHol0oooooooo
oooo0?lXo`3o1?l0oe800_ooool01ol02_ooGOl0ob00ool01?ooooooo`29ool0XOl00oooool01olP
o`3o0?mmo`3oVooooooo0?olo`1[ool0om800_ooool00ol0j_ooooooo`3`o`02ooooo`03o`0@oooo
oooo0?o<00;ooooo00?o0?ldoeL0ool0Pol00oooool01ol0c?oooooooa[o0?oooooo0?nEok;o0?l0
@?l01?ooool00olJ0?ooooooo`2^o`06ooooo`03ohOo0?ooooooJ@3o00;o0?o`1?mM0?l2o`3of0?o
oooo00Ko0>Coo`3oYolho`3oooooobH0ooooool2ob00o`;o/_l000Co05Woo`0dool0odco0?m<0_lJ
o`05ooooo`;o02ko0_ooool2o`0Xo`03o`3om_oooooooooo00;ooooo00?o00Coo`3o5_ooool01_oo
ool3oed0o`03oooooolPo`3o8?l001Sooooo0ol0OOl3o`3oY`_ooooo00?o00[oooooooooool01?oo
ool2o`3oJ`05o`10oolJ0?oo6P3ooaX0ooooool01?mGo`05ooooo`;o0?m<00?o0?nKooooooooool0
2?ooool2oeL0o`Sooooo0_mY0?l2oego00?o?_l01Oooool2ocSo00?o0?o`2oooool2o`3`o`_ooooo
00?o0=Soo`0dool0=?l00ol0o`X01?oooooo9P3oobH0oolV0?l=ooooo`?o0?nE1Oooool3o`3o:0_o
oooo0ol0ofDPooooo`Co02ko4oooool3o`1<o`03ooooool0i?oo0>Co00Co0>Co00Coooooo`2^ool0
[_oo0:ko5Oooool7o`0Xo`[ooooo1Ol0oc@9ooooo`_o08?o9oooool001Wooooo00?o0000oooooooo
ool09_ooool00on7o`3oooooooooo`0;ooooo`06o`3fooooooooooooo`3o:?l0o`Co0?mB0oooool0
1ol02_ooGOl0ob00ool01?oo0=Soo`29ool0XOl00oooool02ol0oggoooooo`3oVooooooo06_ooooo
ool0om;oooooo`3Zoooooooo0?3o00?ooooo00So013oo`3oc?l0ofGoooooo`3o=?ooooooE`3oo`3o
J`;ooooo00?o0<coooooooooool00_lJo`002_l0oiGo0?njo`10oonbo`3oooooo`3o1?oooooo6P3o
ooooool0[_l4ooooo`07ohOo0?oooooooooooooooomY0?ooooooo`3ol002ooooo`03o`1BoomM0?oo
G@3o00?oG@3o00Koooooo`3Tool0ojOo0?nWoooooolV0?l2ok;o00?o07go00?o05Woo`0dool0=?l0
0_l0od`2oeOo00Gooooo0_l0;_l2ooooo`;o02So00?o0?ofo`3o5_l01?l01_ooool3oed0o`?ooooo
00?o8?l0ooooooooool04oooool5o`1mo`?o0?nW3?ooool2o`0:o`Gooooo00?o0?m[o`10ool0@?l0
0_lJ0?l4oeOo00Kooooo0ol0od`2o`3oV`Wooooo0_mG0?l9ooooo`03ofT0oomMo`3o?_l000;o?_l0
1?ooool4ocSo00;o0?o`3?ooool2o`3`o`_ooooo0ol0=?l2o`3o2P04oooooolV0?oo9P3oobH0o`go
oooo0ol0oiD5ooooo`?o0?lX2_ooool4o`3oIAoooooo1?l0;_lDooooo`?o04co1?l0i?l4ooooo`?o
0:ko4Oooool7o`0Xo`_ooooo1_l0oc@3ooooo`_o08?o8Oooool4o`3oM`gooooo000Iooooo`03o`00
0?oooooooooo02Kooooo00?oQol0ooooooooool02oooool01_l0m_ooHol0oooooooooooo0?lXo`3o
DP?ooooo00Oo00[ooego0?oooooo803oo`04ool0ROoo0:7o00Cooooo00_o0?mmo`3oVooooooooooo
o`1[ool0om;o0?mIooooool0j_ooooooo`3`o`03ooooo`07o`0@ool0olco0?mUooooool0ocCooooo
oeL0o`02o`3oJ`03ooooool0c?oooooo00;ooooo00Go6_l0o`3oUOl0ok[o043oo`3o1002ok;o0004
oooooolJ0?oo6P3oo`2^o`;ooooo00?oQol0ooooooooool00oooool00omY0?ooooooo`3ol002oooo
o`03o`1Boooooooooooo00;ooooo0omM0?l00onbo`3o803oo`3oY`02obH0o`08o`3oo?m_o`3o6_l0
o`1mool0FOoo07goo`0dooooool2o`3oC0;oEol01Oooool01?l0;_ooooooooooool0oaH2o`04o`;o
oooo1OmM0?l4ooooo`;o8?l04Oooool5o`1mo`;ooooo0ol0ojL>ooooo`03o`0:oooooooooooo00?o
oooo00?o0?m[o`10ool0@?l00_lJ0?l2oeOo00Oooooo0ol0od`2ooooo`03o`3oVooooooooooo00Oo
oooo0_mG0?l9ooooo`;oJ@3o0_lno`04ooooo`?o>?l00_ooool2o`3ol0cooooo0_l0l?l:ooooo`?o
03Co0_l0o`X01?oooooo9P3oobH0oolV0?l=ooooo`?o0?nE1?ooool4o`3o:0Wooooo1?l0ofDPoooo
o`?o02ko5?ooool4o`1<o`;o0>Co1_ooool3o`2^o`gooooo1ol0:?l=ooooo`Co0?ld2_l0PolUoooo
o`Oo0?mg4Oooool001Wooooo00?o0000ooooooooool09_ooool00on7o`3oooooooooo`0<ooooo`06
o`3fooooooooooooo`3o:?oooooo0?mB0oooool01ol02_ooGOl0ob00ool01?oo0=Soo`29ool0XOl0
0oooool00ol0oggoooooo`3oV`02ooooo`06o`1[ool0om;oooooooooool0j_oo0?3o0oooool03?l0
4?ooooooo`3oc?l0ofGoooooo`3o=?ooooooE`3oooooool0of_oooooo`3<o`Cooooo00Go0?nEo`3o
^_l0@?oo043oooooo`02ok;o0004o`3o`?lJ0?oo0:koohOo00Oooooo00GoJ@3oooooool0oo3ooooo
ok;o0002o`1Bo`Co/_l000?o803ooed0oomM0?l00omM0?l2obH0o`?ooooo00Co05Woooooool0=?oo
03Co1?l0OOl2oeOo00[oG@3o1oooool2ob3o00kooooo1Ol0OOl3ooooo`Co0?nW3oooool2o`0:o`Co
oooo0_l0@?l3oaX0o`03oeOo0?oooooooooo00Cooooo1?l0od`3ooooo`;o0?nK2?ooool2oeL0o`Wo
oooo0_mY0?l2ocko00?ooooo0olho`02ooooo`?o0?o`3?ooool2o`3`o`[ooooo0_l0=?l00ol0f?oo
0?l:ooooo`03obH0o`kooooo0_l0oiD4ooooo`?o0?lX2_ooool3o`3oIB3ooooo1?l0;_lCooooo`05
o`3Tool0C?oo04coo`1<ool0i?l02?ooool3o`2^o`Wooooo1ol0:?l?ooooo`Wo08?o:?ooool7o`3o
MaSooooo000Iooooo`03o`000?oooooooooo02Oooooo00?oQol0ooooooooool02oooool01ol0m_oo
Hol0oooooooooooo0?lXo`3oD_l0o`@00_ooool01ol02_ooGOl0oooooolP0?oo00Coo`29ool0XOl0
1?ooool02ol0oggo0?nKoooooooooooo06_oo`3oo?l0oeWoooooo`3Zoooooooo0?3o00?ooooo00?o
013oooooool0ol`00_ooool01ol0ocCo09_ooeL0oooooooo0?m[ooooool0c?l00_ooool01Ol0o`Co
ooooo`3oUOl0ok[o6_l000;o043o0_ooool00ol0ol3o6P3ooaX0o`08ok;o0003ofT0oonbo`3o0?o`
00?ooooo00Oo05;ooooooooooooo803ooooooolJo`3o0>Co00;o0?ol00?o>?l0oed0oomM0?l03OmM
0?l4o`1mo`03o`04ool0;_oo02ko00;ooooo0_l0:?l5ooooo`03ob3o0?oooooooooo00?ooooo2ol0
OOl5ooooo`?o0?nW4_ooool01?l02_ooooooooooooooool3o`10o`;o6P3o1_ooool4o`3oC0Kooooo
00?o0?nKooooooooool01_ooool2oeL0o`Wooooo0_mY0?l00olno`3oooooooooo`04ocSo00?ooooo
0_l0oo0=ooooo`;o0?3o2Oooool3o`0do`03o`3Hoooooooo9P3o00;o9P3o3_ooool3o`3oU@?ooooo
0ol0obP9ooooo`Co0?mU8?ooool3o`0^oa;ooooo0ol0i?l3o`1<o`Wooooo0ol0[_l7ooooo`Go02So
3oooool7o`23ob[ooooo1ol0ogLOooooo`006Oooool00ol0003oooooooooo`0Wooooo`03ohOo0?oo
oooooooo00cooooo00Oo0?Koof?o0?oooooo0?lXooooool0oe;o0?l400;ooooo00Oo00[ooego0?oo
oooo803oo`04ool0ROoo0:7o00?ooooo00?o0?mmob3o0?l0oi/00_ooool01ol0Jooo0?olofoo0?m_
o`3o0>[oooooool0l?l00oooool00ol04?oo0?o<o`3oI@02ooooo`08o`3o=?l0VoooE`3oooooool0
of_o0<coooooool0o`@3ooooo`05o`3o^_l0oiGoooooooooool0@?l00_lJo`000ol0ol3o6_l0oaX0
o`08ooooo`04ofT0oooooooo0?o`ooooo`;o6_l000Oo05;oob00oolJo`3o6_l0ofoo0?l0ooco0>Co
00?ooooo0_lho`02obH0o`;o0?nW00?o05Woooooooooool00_l0=?l3ooooo`;o0?m<0_l01?l01?mG
o`3o07goo`1mool0;_l3o`1mo`;o02So2Ol0OOl;ooooo`Go0?nW4oooool2o`0:o`;ooooo0_l0@?l0
0ol0of_o6P3ooaX0o`04ooooo`Co0?m<2?ooool2o`3oV`Oooooo0_mG0?l8ooooo`05ocko0?mY0?oo
J@3ooego0?ooool00olho`04ooooo`?o0?o`3Oooool2o`3`o`Sooooo0ol0=?l2o`3Ho`?o9P3o3_oo
ool3o`3oU@;ooooo1?l0obP9ooooo`?o0?mU8?ooool4o`0^oa3ooooo1Ol0i?l3o`1<o`Sooooo1?l0
[_l5ooooo`Go02So3Oooool7o`23o`;o0?ld:?ooool7o`3oMa7ooooo2?l0m_l=ooooo`006Oooool0
0ol0003oooooooooo`0Wooooo`03ohOo0?oooooooooo00cooooo00So0?Koof?o0?ooooooooooo`3o
:?l0oe;oooooo`3o10;ooooo00Oo00[ooego0?l0oh?o803oo`3Hool0ROoo0:7o00?ooooo00Wo0?mm
ob3o0?l0oi_oooooo`1[ool0om;o0?olooooool0j_l00_ooool03ol0l?oooooooooooooooooo013o
o`3oc?l0ofGoooooo`3o=?oooooo08?ooeL0oooooooo0?m[o`3<o`05ooooo`04o`3o^_l0oiGooooo
ooooo`;o043o00Coooooo`3o`?lJo`3o6P3o2?lJo`001?mY0?oo6_l0o`3ol?l0oo02ob00o`04o`1B
oom_o`3o0?olo`3oo0;ooooo0_l0i?l3ooooo`;o>?l00_lV0?l00ol0ojOo05Woo`3oY`02o`3oY`;o
03Co00Co0?lFooooool01?oooooo0ol0od`2ooooo`;o02ko0_mGo`000ol0ooKo02Soooooo`0=oooo
o`Go0?nW5_ooool2o`0:o`04oeOo0?l0@?oo043oo`10o`?o6P3o0_ooool4o`3oC0_ooooo00?o0?nK
ooooooooool01_ooool00omG0?ooooooooooo`06ooooo`04ocko0?mY0?ooJ@3ooego00?o>?l01?oo
ool3o`3ol0kooooo0_l0l?l7ooooo`?o03Co00?o0?l:obH0oolV0?l00_lV0?l>ooooo`?o0?nE00?o
ooooo`3o:?l0obP00_l0obP:ooooo`?o0?mU8?ooool3o`0^o`kooooo1_l0i?l2ooooo`?o04co2?oo
ool3o`2^o`Cooooo1Ol0:?l;ooooo`Oo08?o1?l0oc@Vooooo`Oo0?mg3Oooool;o`3fo`So05;o3Ooo
ool001Wooooo0ol0000Xooooo`03ohOo0?oooooooooo00_ooooo00So0?KooooooomSo`3oooooo`3o
:?oooooo0?mBo`3o10;ooooo00Oo00[ooego0?oooooo0?n3ob00ool0ROoo0:7o00Cooooo00co0?mm
o`3oVoooooooooooo`1[ool0om;o0?olooooool0j_ooKol0ooooool0l?l2ooooo`0<o`0@oooooooo
0?o<o`3oIOoooooo0?ldooooool0PoooE`3oo`3o1?l0of_o0<co0_l0oaH3ooooo`09o`3o^_l0oiGo
ooooohOo0?oooooo043oooooool0ol3ooooo00;o6P3o1oooool01omY0?ooooooob00ool0oo3o?_l0
ooooool0D_l01_ooool2o`3To`?ooooo00Ko>?l0oooooolV0?ooooooo`1Iooooool2o`3o5P04o`3o
Yol0=?oo00Coo`3oY`Cooooo1?l0od`01?l0;_oo8?l0ooooooooool2o`0Xo`;oEol01_ooool4o`3o
Ya;ooooo2?mGo`001Ol02_oo043oo`10ool0@?oooooo00;o6P3o1Ol0od`=ooooo`;o0?nK1oooool2
oeL0o`Kooooo0_lno`02ofT0o`?o>?l01Oooool2o`3ol0oooooo0_l0l?l7ooooo`;o03Co00Co0?l:
obH0oolV0?oo9P3o3oooool3o`3oU@04ooooool0obSo0?lXo`3o:0[ooooo1?l0ofDOooooo`Co02ko
3?ooool5o`3To`Gooooo0ol0C?l8ooooo`?o0:ko00?oooooo`0Xool0:?l01?l0:?l;ooooo`Go08?o
00?oooooo`3o=?l0oc@00ol0oc@Tooooo`Oo0?mg2_ooool:o`3fo`_o05;o0_ooool6o`0@o`gooooo
000Iooooo`03o`000?oooooooooo02Sooooo00?oQol0ooooooooool03?ooool02?l0m_ooHol0oooo
oooooooo0?lXo`3oD_oooooo0?l40_ooool01ol02_ooGOl0ooooool0oh?o803oo`29ool0XOl00ooo
ool03Ol0oggoooooo`3oVooooooo06_oooooool0om;o0?olooooool0j_ooKol0o`3oMol0l?l00_oo
ool03Ol04?ooooooo`3oc?l0ofGoooooo`3o=?l0Vooo08?ooeL0oooooooo0?m[o`3<ooooool00_l0
oaH2ooooo`03o`3o^_l0oiGooooo00;ooooo0_l0@?l00ol0ol3oooooo`2^o`02oaX0o`Kooooo0_mY
0?l01Ooooooo0?o`o`3oo?lno`3o05;o00Oooooo00Co0>Cooooooooooooooooo0_lho`02obH0o`;o
05Wo0_ooool01?l01?ooooooo`0dool0=?l8o`3oY`;o02ko0_l0ojL00ol0ooKo02Soo`0Xo`06o`3o
Y`OoEol00_ooool=oeOo00Kooooo0_l02_l00ol0@?oooooooaX0o`02oaX0o`;o0?m<4Oooool00ol0
oi_oooooooooo`05ooooo`;oE`3o1Oooool2ocko00?oJ@3o0_lho`05ooooo`?o0?o`3oooool2o`3`
o`Kooooo0_l0=?l4obH0o`03o`3Hoooooooooooo00cooooo0ol0oiD4o`3o:0[ooooo0ol0ofDOoooo
o`Co02ko2_ooool6o`3To`Oooooo0ol0C?l7ooooo`?o0:ko1Ol0:?l;ooooo`Ko08?o0_ooool4o`3o
=2Cooooo1Ol0ogL6ooooo`_o0?Ko2_l0D_l2o`3oF@_o013o1_l0oeT=ooooo`006Oooool00ol0003o
ooooooooo`0Xooooo`03ohOo0?oooooooooo00cooooo00Ko0?KooooooomSo`3oooooo`3o:?l0oe82
ooooo`;o0?l400Oo00[ooego0?oooooo0?n3oooooolP0?oo0:7o00Cooooo00Oo0?mmo`3oVolPo`3o
ooooo`1[ool0om;o0?mI00;o0?ol00Co0>[oooooool0ogOo0?3o0_ooool02ol04?ooooooo`3oc?l0
ofGoooooo`3o=?l0Vooo08?ooeL0oooooooo0<co00?ooooo0ol0oaH00ol0ok[o0?nEo`3oU@03oooo
o`05o`10ool0ol3oooooo`2^ooooool00_lJ0?l2ooooo`;o803o0_ooool00omY0?oo0?olooooo`02
o`3ol003o`1Boooooooooooo00Gooooo0_l0i?l01Ooooooo0?lFo`3o5_l0oaKo>?l000;o9P3o0_l0
1?l4ooooo`;o03Co00?oooooob3o0?lPo`001Oooool2o`0^o`03o`3oC?l0ooKo0?of00?o02So2Ooo
ool4oeOo013ooooo0_l02_l01Ol0odco6P3ooaX0oolJ0?oo0?m[01?ooooo0_l0oi/6ooooo`;oE`3o
1Oooool01olno`3o>?l0ofT0oomY0?oo>?l0oego0?mSo`001Oooool2o`3ol13ooooo0_l0l?l5oooo
o`;o03Co0olV0?l3o`3Ho`gooooo0ol0oiD3o`3o:0_ooooo0ol0ofDOooooo`?o02ko2Oooool5o`3T
o`[ooooo0ol0C?l7ooooo`Ko02So2oooool5o`23o`?ooooo1Ol0oc@Rooooo`Ko0?mg0_ooool00ol0
oeWo0?Koo`3fo`06o`3fo`_o05;o1?l0oeT8o`0@oakooooo000Iooooo`03o`000?oooooooooo02Wo
oooo00?oQol0ooooooooool03?ooool01_l0m_ooHol0oooooooooooo0?lXo`3oDP?ooooo00So0?l4
o`0:oomMo`3oooooo`3oPol01?oo803oo`2Qo`?ooooo00Oo0?mmooooool0oi_o8?l0ooooool0Jooo
0?oB00;ooooo00Co0>[oo`3oo?oooooo0?3o0_m_o`003?oooooo013oo`3oc?oooooo0?mUooooool0
ocCo09_oo`23oomG0?ooooooo`3<o`Cooooo00GoQol0o`3o5_l0ok[o0?lFo`3oU@03ooooo`;o043o
00Coooooo`2^ooooooooKol00_lP0?l3ooooo`04o`3oo?ooooooJ@3oofT0o`;ooooo00?o0?o`o`1B
ooooool01_ooool00ol0oaKo0>Coo`3To`03ooooo`05ocSo0?l01?oo9P3oobH0ool0FOl01?ooool0
0olPo`3o03Coo`0do`08ooooo`03o`0^oooooooooooo00;o0?of00Co0?m<o`0Xool0:?oo02So5ol0
od`2o`10o`Co6P3o0_l0of/Dooooo`03o`3oVooooooooooo00Cooooo0_mG0?l3ooooo`Co>?l00_mY
0?l2oego0003of?o0?oooooooooo00;ooooo0ol0oo0@ooooo`;o0?3o1?ooool00ol0=?oo9P3oobH0
o`02obH0o`03ooooool0f?oo0=So00gooooo0ol0oiD2o`3o:0cooooo0ol0ofDNooooo`Co02ko1ooo
ool5o`3To`cooooo0ol0C?l5ooooo`Go02So2oooool6o`23o`Cooooo1?l0oc@Rooooo`Go0?mg1?l0
oeT2o`3fo`_o05;o2?ooool7o`0@obKooooo000Iooooo`03o`000?oooooooooo02Wooooo00?oQol0
ooooooooool03?ooool01_l0m_ooooooof?o0?oooooo0?lXo`3oDPCooooo00Ko0?l4o`0:oomMo`3o
0?n3ooooool01?l2ob00o`?ooooo00Oo0?mmooooool0oi_o8?l0o`1[ool0om;o0?mI00;ooooo00Go
0>[oo`3oo?l0ooco0?3oooooo`02ofoo000;o`0@ool0olcoooooo`3oIOl0ocCoooooo`2Kool0Pooo
E`3oooooool0c?l00_ooool02?n7o`3ooooooooooooooooo0?njo`3o5_l0oiGo0?lF0oooool2o`10
o`;o803o0_ooool3oaX0o`Cooooo0_mY0?l01?oooooo0?o`o`1Boolno`02ooooo`?o0?lF0oooool0
1Ol0i?ooooooooooool01?oooooo00;o>?l00olV0?l00ooooooo8?l0ooooo`02ooooo`;o03Co1ooo
ool2o`0^o`;ooooo00Co0?ofoooooooooooooooo0_l0:?lBooooo`;o043o0olJ0?l2ooooo`;o0?m[
5?ooool2o`3oV`Gooooo0_mG0?l00ooooooo>?l0ocSo0002ocSo0004ocko0?mY0?ooJ@3oofT0o`;o
GOl000?oHol0ooooooooool00_ooool2o`3ol17ooooo0_l0l?l3ooooo`04o`0doolV0?oo9P3oobH0
o`;o0?l:00?oooooo`3Hool0f?l03?ooool3o`3oU@;o0?lX3?ooool3o`3oIAgooooo1?l0;_l6oooo
o`Go0>Co3oooool2o`1<o`;ooooo1_l0:?l2o`2^o`Wooooo1Ol0Pol6ooooo`Co0?ld7Oooool4o`3o
F@Go0?mg00?o0?mIo`1Bool0D_l02?l0D_l<ooooo`Oo013o;Oooool001Wooooo00?o0000oooooooo
ool0:_ooool00on7o`3oooooooooo`0<ooooo`06o`3foomSo`3oooooo`3o:?oooooo0?mB1?ooool0
1Ol02_ooGOl0ooooool0oh?o0?n?00;o00Co00_o803ooooooooooooo0?mmooooool0oi_oooooob3o
0?l0Jooo0?oBo`3oF@02ooooo`0Co`3Zoooooooo0?olo`3`oooooooo0?l4o`0@oom_o`3o0?o<oooo
ool0ofGo0?ldo`2Kool0PooooooooeL0oooooooo0<coo`3oJ`05ooooo`03o`3o^_oooooo0?nE00?o
0?lF00?oooooob00ooooool00_l0@?l2o`3oo0;ooooo0_lJ0?l3ooooo`04o`3o5_mY0?oo0?lFo`3o
5P;o05;o00?o0?lFooooooooool01Oooool2o`04o`Gooooo00Co>?l0o`1IoolV0?oo9P3o1Oooool3
o`0do`Kooooo0ol0;_l2o`3omP?ooooo0ol0:?l<ooooo`03o`10oolJ0?oo6P3o00;o6P3o00?o00[o
ooooool0of/00_l0of/Eooooo`03o`3oVooooooooooo00?ooooo0_mG0?l3ocSo00?o?_l00_mY0?l0
1?ooooooGOl0oego0?mSo`03ooooo`?o0?o`4Oooool2o`3`o`;ooooo1?lV0?l2o`3o2P;ooooo0_l0
f?l;ooooo`?o0?nE0_l0obP<ooooo`?o0?mU7Oooool3o`0^o`Kooooo1?l0i?lAooooo`Oo02So00Co
ooooo`2^ool0[_oo0:ko2?ooool5o`23o`Oooooo1?l0oc@Fooooo`_o0?mI00?o0?mgo`1Bool0D_l0
1ol0D_l2o`3fo`cooooo2?l04?ldooooo`006Oooool00ol0003oooooooooo`0Zooooo`03ohOo0?oo
oooooooo00cooooo00Ko0?KooooooomSo`3oooooo`3o:?l0oe85ooooo`07o`0:ool0o`Co0?l4o`3o
Pol0f?oo08Woo`04o`02ob00o`09ooooool0oggoooooo`3oVooooooo06_oooooool0om;o0?mI00;o
oooo00Co0>[oooooool0ooco0?3o0_ooool03Ol04?ooooooo`3oc?m_o`3o0?mUo`3o=?l0Vooo08?o
ofoo0?mG0?ooKol0o`3<ool0of/01Om_o`001?l0ok[oooooo`3oUOl0oiD2ob00o`04o`3o5_l0ooco
0?olo`2^o`;o043o1?l0oaH3oaX0o`;ooooo0_mY0?l01Ooooooo0?o`o`1Bool0D_oo?_l000Cooooo
00?o00Coooooooooool00_l0i?l2ooooo`;o8?l000?oooooo`1Iool0FOl00_lV0?l2ocSo00Cooooo
0_l0=?l7ooooo`;o02ko0_l0ooH4ooooo`;o02So1oooool01?l0@?oo6P3ooaX0oolJ0?l2ooooo`;o
00[o0_l0of/Fooooo`;o0?nK0oooool01Olho`3oE`3ooeL0oolho`3ooooo00?o?_l000CoooooofT0
oomY0?oooooo0_mMo`000omSo`3oooooooooo`03o`3ol1;ooooo0_l0l?l01Ol0=?oo9P3oobH0oolV
0?oooooo00?o0?l:0_ooool2o`3Ho`[ooooo0ol0oiD2o`3o:0cooooo0ol0ofDLooooo`Co02ko1Ooo
ool4o`3To`kooooo1ol0:?l5ooooo`?o0:ko1_ooool5o`23o`Sooooo1?l0oc@Aooooo`Wo0?mI1Ooo
ool7o`1Bo`Ko0?Ko2_ooool7o`0@occooooo000Iooooo`03o`000?oooooooooo02_ooooo00?oQol0
ooooooooool02oooool01ol0m_oooooooooooomSo`3o0?lXooooool0oe801Oooool03?l02_oooooo
o`3oPooooooo08Woo`2Qool01?ooooooob00ool0oggoooooo`3oV`;ooooo01Go06_oob3o0?l0om;o
0?mIo`3o1?l0j_oo0?l4ooooool0ooco0?3oo`3oo?oooooo013oooooool0olcoooooo`3oIOl0ocCo
09_oo`23ooooool00_mG0?l00ol0c?oo0?m[ooooo`04ooooo`03o`3o^_lP0?oo803o00?o0?ol00Go
ooooo`3o`?oooooo0:koooooo`02o`10o`Gooooo0olJ0?l02?ooooooJ@3ooooooooooooo0?o`o`1B
oolno`3ooooo0_l01?l5ooooo`;o0>Co1Oooool01?l0FOooooooobH0oolV0?l3ocSo00?ooooo0_l0
=?l7ooooo`;o02ko0_l0ooH4ooooo`?o02So1OlJ0?l3ooooo`;o00[o0_l0of/Gooooo`03o`3oVolh
o`3o>?l000;o>?l00_mG0?l01Ooooooo?_l0ocko0?lno`3ooooo00?oJ@3o00Gooooooego0?mMo`3o
Hol0ooooo`03o`3ol1;ooooo0_l0l?l4obH0o`;ooooo0_l0o`X3ooooo`;o0=So2_ooool2o`3oU@?o
0?lX2oooool3o`3oIA_ooooo1?l0;_l4ooooo`Go0>Co2oooool7o`0Xo`;ooooo0ol0C?l4ooooo`?o
0:ko1?ooool5o`23o`Wooooo1?l0oc@>ooooo`Oo0?mI1oooool7o`1Bo`03o`3oMooooooo0?Ko00Co
0?Ko2Oooool7o`0@od?ooooo000Iooooo`03o`000?oooooooooo02_ooooo00?oQol0ooooooooool0
3?ooool01_l0m_ooooooof?o0?oooooo0?lXo`3oDPGooooo00Wo00[ooego0?oooooo0?n3o`3Hool0
ROoo0:7oo`04ooooool00_lP0?l02_oooooo0?nKo`3o1?l0o`Co06_oo`3od_l0oc[o0?mIooooool0
j_l2ooooo`06o`3oMol0l?oo0?olo`3oo?l04?oo0?o<0_ooool01?l0ofGo09_oooooool0Pol2oooo
o`03oeL0ool0c?oo0?m[00?ooooo0_lP0?l2o`3oo003ooooool0oiGooooo00;ooooo00?o0?o0oooo
ool0[_l00_ooool4o`10o`Cooooo0_lJ0?l2ofT0o`06ooooool0olKo00Coo`04ool0oo3o?_l00ooo
ool2ob3o00;ooooo0_l0i?l4ooooo`;o05Wo00CoooooobH0oolV0?oo9P3o1?lho`000ooooooo03Co
o`0do`07ooooo`?o02ko00?ooooooaX0oolJ0?l00olJ0?l3o`0Xo`Cooooo00?o00[oo`3oJol0of/0
5Oooool3ocSo0004o`3oVolho`3oooooooooo`;oE`3o0olno`02ooooo`;oJ@3o0_ooool2oego0004
of?o0?l0oo3o0?o`o`3ol1?ooooo00Co03CoobH0oolV0?oo9P3o0oooool3o`3o2P?ooooo0_l0f?l9
ooooo`?o0?nE0_l0obP;ooooo`?o0?mU6Oooool5o`0^o`?ooooo1Ol0i?l;ooooo`Go02So1oooool2
o`1<o`Cooooo0ol0[_l2ooooo`Go08?o2oooool3o`3o=0_ooooo1ol0oeT7ooooo`Oo05;o0ol0ogL6
o`3fo`Sooooo1_l04?m:ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`00
00Sooooo00?o0000ooooooooool0;?ooool00on7o`3oooooooooo`0;ooooo`07o`3foooooooooooo
of?o0?l0obSoooooo`3oDP05ooooo`08o`0:oomMo`3o0?n3ooooool0ROoo0:7oo`3o2_l01?l2o`3o
1003ob00ool0o`Co0?nK00;ooooo00Ko06_oo`3od_l0oc[o0?mIooooool0j_l2ooooo`05o`3`oooo
ooooooooooooool04?l00ol0oo`00ol0ofGo09_oooooo`02o`23o`04oooooomG0?oo0<coo`3oo0;o
803o0_l0oo`01Ooooooo0?njoooooooooooo0?nE00?ooooo00?o0?o0ooooool0[_l01Oooool4o`10
o`?ooooo00Go6P3oofT0oomY0?ooJ@3oooooo`02o`1Bo`03o`3ol?lPo`3o8?l000Kooooo0_l0i?l4
ooooo`04o`1Iooooooooooooooooo`;o9P3o0_ooool3ocSo00?o03Co0oooool5oaX0o`03o`0^ool0
@?oooooo00Gooooo0_l0:?l2o`0:o`03o`3oJooooooooooo013ooooo1Olho`001?oooooo0?nKo`3o
Voooool3oeL0o`;o?_l00oooool2ofT0o`;ooooo0_mMo`03o`3ol1?ooooo1?lV0?l3ooooo`?o0?l:
1?ooool2o`3Ho`Sooooo0ol0oiD3o`3o:0[ooooo0ol0ofDHooooo`Co02ko0oooool5o`3To`[ooooo
1_l0:?l9ooooo`?o04co0oooool3o`2^o`03ooooool0Pooo08?o00;o08?o3?ooool4o`3o=0Oooooo
1ol0oeT9ooooo`Go05;o0oooool2o`3oM`Go0?Ko2_ooool4o`0@oe3ooooo00001Ooooooo0000oooo
oooooooo000000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0/ooooo`03ohOo
0?oooooooooo00cooooo00Oo0?KooooooomSo`3oooooo`3o:?oooooo0?mB00Cooooo00_o00[ooego
0?oooooo0?n3o`3oSol0ROoo0:7oo`3o2_l01?ooooooo`3oO@02ob00o`?ooooo00Ko06_oo`3od_l0
oeWo8?l0ooooool0j_l2ooooo`07o`3`ooooooooooooo`0@oooooooo0?o<ooooo`02o`3oo005o`2K
ool0ooco0?olo`23ool0oo`00_mG0?l00ooooooo0?m[o`3oJ`02ooooo`05o`3o^_oooooooooooooo
ool0oiD00oooool01?l0ol3oooooo`2^ool0[_l7ooooo`?o043o0_l01?l2ooooo`;oJ@3o1_lJ0?l6
ooooo`;o0>Co0oooool00ol0FOooooooooooo`02ooooo`?o9P3o00?ooooooaX0oolJ0?l01OlJ0?l2
o`10o`?o>?l000?oooooo`0^ool0;_l01Oooool2o`0:o`03o`3oJol0:?oo02So00;o02So1_ooool:
ocSo00Gooooo00Co0?nKocko0?mG0?ooE`3o0_lno`03ooooo`?oJ@3o0_ooool01?mMo`3o0?o`o`3o
l?l0oo0Aooooo`;o03Co0olV0?l00ol0l?ooooooooooo`02ooooo`;o0?l:1Oooool2o`3Ho`Oooooo
0ol0oiD00ooooooo0?lXo`3o:009ooooo`Co0?mU5oooool4o`0^o`;ooooo1Ol0i?l:ooooo`Go02So
3Oooool2o`1<o`?ooooo0ol0[_l4o`23o`cooooo1?l0oc@4ooooo`Oo0?mI2_ooool6o`1Bo`Cooooo
00?o0?mgo`3fool0m_l00ol0m_l:ooooo`Go013o:ooooolLo`3o>Pgooooo00001Ooooooo0000oooo
oooooooo000000Oooooo1Ol00008ooooo`Co0000;?ooool00on7o`3oooooooooo`0;ooooo`07o`3f
ooooooooooooof?o0?l0obSoooooo`3oDP05ooooo`0<o`0:oomMo`3o0?n3ooooool0ROoo0:7ooooo
ool0o`[o00Coooooool0oggooooo0olP0?l01_l0Joooooooo`3od_l0oeWo8?l0o`3Zo`?ooooo00Ko
0?3ooooooooooooo013oooooool0ol`2ooooo`03o`3oIOl0Vooo803o00;o803o0_ooool00omG0?oo
ooooooooo`02o`3oJ`03ooooool0ok[ooooo00;ooooo0_l0oiD2ooooo`04o`3o`?ooooooooooo`2^
o`Sooooo00?o00Coo`10ool0@?l00ol0@?l00ol0olKoJ@3oofT0o`02o`1Bo`;o0?o`4olJ0?l4obH0
o`04o`10ooooooooooooooooo`?o03Co0_ooool3ocSo00?o02ko00?o0?m[o`0:oolho`001_lho`03
o`0Xo`?o>?l02oooool2ocko00;o0?nK0_mG0?l4ooooo`?oJ@3o0_ooool4o`3ol003of?o0?oooooo
oooo00cooooo0ol0=?l4obH0o`;o0?3o0oooool3o`3o2PGooooo0_l0f?l7ooooo`;o0?nE00Cooooo
o`3o:?l0obSo0?lX2?ooool3o`3oIAOooooo1?l0;_l00ooooooo0>Coo`3To`03o`3To`Wooooo1_l0
:?l?ooooo`?o04co00?oooooo`2^ool0[_l01Ol0Pol=ooooo`?o0?ld00?oooooo`3oFOl0oeT01Ol0
oeT<ooooo`Go05;o1Oooool2o`3oM`Co0?Ko2oooool4o`0@obKooooo2_l0ocXYooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
;Oooool00on7o`3oooooooooo`0<ooooo`07o`3fooooooooHol0ooooool0obSoooooo`3oDP05oooo
o`0:o`0:oooooooo0?n3o`3oSol0ROoo0:7oooooool0o`[o00Coo`3oO@;ooooo00?o0?nKoooooolP
0?l01?lP0?l01_oooooo0>[oob3o0?oooooo0?mgo`3`o`;ooooo00?o013oob00oolP0?l00olP0?l0
1?l0ofGoooooooooool0Pol2ooooo`;oE`3o0_ooool2o`3oJ`03o`3o^_oooooooooo00;ooooo00?o
0?nEooooooooool00_l0ol000ooooooo0:koooooo`04ooooo`;o00Co0oooool2ob3o0004ooooool0
@?oo043oo`10o`;oJ@3o5?l0@?l5ooooo`Go9P3o0_ooool4o`0do`?o0?m[0_l02_l00ol0;_oooooo
ooooo`08ooooo`Co02So1?ooool6ocko0004ooooool0oi_oE`3ooeL0o`?ooooo0omY0?l5o`3ol0;o
GOl00_mSo`09ooooo`Co03Co1OlV0?l2ooooo`;o0?3o0oooool2o`3o2PKooooo0_l0f?l6ooooo`?o
0?nE00?oooooo`3o:?l0obP02?ooool3o`3oIAGooooo1Ol0;_l5o`3To`Oooooo1ol0:?lCooooo`;o
04co00?oooooo`2^ool0Pol00ol0Pol?ooooo`03o`3o=?l0oeWo0?mI00Co0?mI3Oooool6o`1Bo`Ko
oooo00?o0?mgo`3fool0m_l00ol0m_l;ooooo`Co013o7oooool;o`3o>S?ooooo00001Ooooooo0000
oooooooooooo000000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0^ooooo`03
ohOo0?oooooooooo00_ooooo00Oo0?KoooooooooooooHol0ooooool0obSo0?mB00Gooooo00_o00[o
oego0?oooooo0?n3o`3Hool0ROooooooo`3o2_oooooo00Coo`3oO@02ooooo`06o`3oVooooooooooo
o`1[ool0om;o0?lj2OlP0?l00ol04?oo0?o<ooooo`02ooooo`05o`2Kool0ofGoooooooooool0Pol0
0_ooool00ol0c?ooE`3oooooo`02ooooo`03o`3oJol0ok[ooooo00?ooooo00Oo0?nEoooooooooooo
ooooo`3o`?oooooo0:ko00;ooooo0_l01?l3ooooo`;o8?l01Oooool00ol0olKoooooooooo`02ofT0
o`;o05;o00?oooooo`3ol?l0oo000_l0oo05ocko00?o0>Co0_l0FOl;ooooo`Ko9P3o00?o03Coo`0:
ool02_l00ol0=?l3o`0^o`[ooooo00?o?_l0o`0Xool0:?l00_l0:?l5ooooo`03o`3oVomG0?ooE`3o
00;ooooo0omY0?l3o`3ol0?ooooo0_mMo`000oooooooHol0ooooo`05ooooo`?o03Co1_lV0?l5oooo
o`;o0?3o0_ooool3o`3o2PKooooo0_l0f?l5ooooo`?o0?nE00Coooooo`3o:?l0obSo0?lX1oooool3
o`3oIACooooo1?l0;_l4o`3To`Kooooo1ol0:?lHooooo`;o04co1?l0Pol?ooooo`Go0?mI3_ooool5
o`1Bo`Sooooo00?o0?mgo`3fool0m_l00_l0m_l;ooooo`Go013o6?ooool;o`3o>Skooooo00001Ooo
oooo0000oooooooooooo000000Wooooo0_l00009ooooo`03o`000?oooooooooo02kooooo00?oQol0
ooooooooool02oooool02?l0m_oooooooooooomSo`3oooooo`3o:?oooooo0?mB1Oooool02_l02_oo
GOl0o`3oPooooooo08Woo`2Qoooooooo0?l:ooooool01?l3ooooo`0Ao`3oVoooooooooooo`1[ool0
om;oooooo`3oFOoooooo0>[ooooooolPo`3o0?mgo`3`oooooooo013oooooool0ol`00oooool01Ol0
Vooo0?mUoooooooooooo08?o00;ooooo00?o0<cooeL0ooooool00oooool00ol0ok[oooooooooo`02
ooooo`06o`3oUOooooooooooooooool0ol3ooooo0_l01?l2ooooo`?o8?l02?ooool01?l0olKooooo
ooooooooool3ofT0o`04o`1Booooooooooooooooo`Co0?o`0_ooool2ocko00;o0>Co00?o05Wooooo
ooooool02?ooool3o`3oJ`;ooooo00?o00[oobH0oolV0?l00olV0?l01?oooooo03Coo`0dool0=?l4
o`0^o`03oooooolno`3o?_l000?o?_l01Oooool3o`0Xo`04oooooomG0?ooE`3oooooo`?oJ@3o0_l0
oo05ooooo`;oGOl000Coooooof?o0?mSo`3ooooo1?l0=?l5obH0o`Wooooo0_l0l?l01?oooooo0?l:
o`3o2_l0o`X7ooooo`;o0=So1?ooool3o`3oU@04ooooool0obSo0?lXo`3o:0Oooooo0ol0ofDCoooo
o`Co02ko0ol0i?l3ooooo`So02So7?ooool3o`1<o`;o08?o3Oooool6o`3oF@03o`3o=?oooooooooo
00_ooooo1Ol0D_l9ooooo`03o`3oMol0m_oo0?Ko00;o0?Ko2_ooool5o`0@oa;ooooo2ol0ocY9oooo
o`000_ooool2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0_ooooo`03
ohOo0?oooooooooo00_ooooo00Oo0?KoooooooooooooHol0ooooool0obSo0?mB00Kooooo00Go00[o
oego0?l0oh?o0?n?o`29o`02ooooo`04o`3o2_oooooo00Coo`04o`;ooooo017o0?nKooooool0Jooo
0?oBo`3o>_oooooo0?mIooooool0j_ooQol0ooooool0ogOo0?3oob3o0?l04?ooooooo`3oc003oooo
o`04o`2Kool0ofGoooooooooo`;o08?o00Coooooo`3<oomG0?ooE`3o0oooool00ol0ok[o0?m[o`3o
J`02ooooo`;o0?nE00?oooooo`04ool01?l00_lPo`000ol0[_oo8?l0ooooo`0;ooooo`03o`3oa_oo
oooooooo00?ooooo1?mY0?l4ooooo`?o0?o`0oooool00ol0i?oo05Woocko0004ocko0004ooooool0
of_o0?m[o`3oJ`Cooooo00?o00[oooooooooool01?ooool4obH0o`04o`3om_lno`3o?_l0ocko00?o
02ko1_l0=?l3ooooo`?oE`3o0omY0?l01?l0:?ooooooooooooooool6o`0do`[o9P3o3?ooool2o`3`
o`03ooooool0o`[o0?l:00Sooooo0_l0f?l3ooooo`?o0?nE00Coooooo`3o:?l0obSo0?lX1oooool3
o`3oIA7ooooo1?l0;_l;o`0Xob7ooooo00Go08?oo`1<ool0C?oo08?oo`2^o`0;ooooo`Go0?mI00Co
ooooo`3o=?l0ocCo0?ld2oooool5o`1Bo`[ooooo00?o0?mgo`3fool0m_l00_l0m_l8ooooo`Ko013o
3?ooool;o`3o>UCooooo000Iooooo`03o`000?oooooooooo033ooooo00?oQol0ooooooooool02_oo
ool02?l0m_ooooooooooooooooooHol0o`3o:?oooooo0?mB1_ooool01Ol02_oo0?n3ooooool0ROoo
0:7o00;ooooo00?o0?l:ooooool0ogd00_l01?l02Ooooooo0?nKooooool0Jooo0?oBo`3o>_l0oeWo
ooooo`3Zo`03ooooo`05o`3oMol0l?ooooooo`0@oolPo`000_l0ol`2ooooo`03o`2Kool0ofGo0?mU
00;ooooo00Co08?oooooool0c?oooooo0_mG0?l2ooooo`03o`3o^_oooooo0?m[00;o0?m[0_l01?l0
0ol0oiGo8?l0o`3o`002ooooo`03o`2^oooooooooooo00_ooooo0_l0olH6ooooo`03o`1BoomY0?oo
J@3o00;oJ@3o0oooool4o`3ol004ooooool0FOoo05Woo`3To`?o0?m[1Olno`02o`0:o`Wo?_l00_oo
ool=obH0o`;oE`3o1?mY0?l=obH0o`;oHol04_ooool2o`3`o`03ooooool0o`[o0?l:00Sooooo0_l0
f?l2ooooo`?o0?nE0_ooool2o`3o:0Oooooo0ol0ofD>ooooo`[o02So:?ooool3o`23o`;o04co00?o
0:koooooooooool01oooool5o`3oF@?ooooo0ol0oc@8ooooo`Ko05;o3?ooool4o`3fo`Oooooo1Ol0
4?l:ooooo`So0?ljGoooool001Wooooo00?o0000ooooooooool0<?ooool00on7o`3oooooooooo`0;
ooooo`07o`3fooooooooooooof?o0?oooooo0?lXo`3oDP07ooooo`07o`0:ool0oh?o0?n?o`29ool0
XOooooooo`3o2P02ooooo`0<o`3oOOoooooo00Coo`04ool0oi_oooooo`1[ool0om;o0?ljo`3oFOoo
oooo0>[o0oooool01ol0ogOo0?3oooooool04?ooooooob3o0?l0ol`00_lPo`000ol0Vooo0?ldo`3o
I@02ooooo`03o`23oooooooo0<co00;ooooo0_mG0?l00olPo`3o0?njob3o0002o`04o`?o0?m[00?o
0?nEooooool0ol000_ooool00ol0[_ooooooooooo`0<ooooo`03o`3oa_oooooooooo00Gooooo0_l0
D_l01?ooooooJ@3oofT0oomY0?l4ooooo`?o0?o`0_l0FOl3o`3To`04o`3ol?oooooo00[oo`0:oa3o
oooo00?o0?o`o`3om_l0ooH01?l0oo05ofT0o`;o02ko2_ooool00omMo`3o02Soo`0Xo`08o`0Xo`co
oooo0_l0l?l3o`3o2PSooooo0_l0f?l01?oooooo0?nEo`3oUOl0oiD2ooooo`?o0?lX1_ooool3o`3o
I@Oooooo2_l0:?l2o`3Tobcooooo1?l0Pol3o`1<o`Oooooo1Ol0oeT5ooooo`?o0?ld1?ooool7o`1B
o`kooooo00Co0?mgo`3fool0m_oo0?Ko1_ooool5o`0@o`Sooooo1ol0ocYWooooo`006Oooool00ol0
003oooooooooo`0aooooo`03ohOo0?oooooooooo00[ooooo00So0?Koooooooooooooooooof?o0?oo
oooo0?lXo`3oDPOooooo00Co00[oo`3oPol0ROoo0:7o0_ooool01?l0o`[oooooooooool0ogd2oooo
o`;o00Co00Ooooooo`1[ool0om;o0?ljo`3oFOoooooo0>[o00;ooooo00Co0?mgooooool0l?oooooo
0_l04?l01ooooooo0?o<oooooolPo`3o09_oo`3o=?l0ofD00_lPo`001?l0Pooo8?l0o`3<oolPo`02
ooooo`;oE`3o00?o00Coooooooooool00oooool01_l0of_o0?nEo`3oUOl0ol3o0?m[ooooo`;o0:ko
3Oooool2o`3oaPOooooo00Co05;ooooooooooooo0?m[1?mY0?l00ol0of_oooooooooo`02ooooo`03
o`1Ioooooooooooo00;o00[o00?o0>Coo`3ol?l0oo003ol0oo02ooooo`GoJ@3o0_ooool2o`3oV`?o
oooo1_l0;_l2ooooo`;oGOl00_ooool00omSo`3oooooooooo`06ooooo`go02So00?o0?l:oooooooo
ool01oooool2o`3Ho`?o0?nE0_ooool3o`3o:0Kooooo00?o0?mUo`0Xool0:?l02_l0:?l3o`0^o`Co
0>Co;_ooool3o`23o`04ooooool0[_oo04coo`1<o`Kooooo1?l0oeT6ooooo`Co0?ld1ol0D_lAoooo
o`03o`3oMol0m_oo0?Ko00;o0?Ko1_ooool3o`0@o`Kooooo1ol0ocY^ooooo`006Oooool00ol0003o
ooooooooo`0aooooo`03ohOo0?oooooooooo00_ooooo00So0?KoooooooooooooHol0ooooool0obSo
ooooo`3oDPOooooo00Co00[oo`3oSol0ROoo0:7o0_ooool00ol0o`[oooooo`3oO@04ooooo`?o00Co
00Goooooo`3o>_l0oeWoooooo`3Zo`02ooooo`03o`3oMooooooo0?3o00;ooooo00?o013oooooool0
ol`00_ooool00ol0Vooo0?ldo`3oI@02ooooo`03o`23oooooooo00Co00;o00Co0_ooool2oeL0o`Oo
oooo00?o0?nEo`3o`?l0of/00_l0of/00ol0[_oo0?m[o`3oJ`0<ooooo`04o`3oa_oooooooooooooo
o`Co0?m[0_l0D_l5oooooakoJ@3o0_mG0?l00ooooooo0?ofo`3omP02o`3oV`_ooooo1_l0;_lBoooo
o`;o0?3o00?o0?l:ooooool0:?l06_l0:?l00ooooooo02koo`0^o`05o`0^o`03ooooool0i?oo0>Co
00?o0>Co;oooool4o`23o`03ooooool0[_oo0:ko00;o04co1?ooool4o`3oF@Oooooo1ol0D_lEoooo
o`Co0?Ko1oooool3o`0@o`;ooooo1ol0ocYLooooo`co0?lR3Oooool001Wooooo00?o0000oooooooo
ool0<_ooool00on7o`3oooooooooo`0;ooooo`07o`3fooooooooooooof?o0?oooooo0?lXo`3oDP08
ooooo`03o`0:ool0ohoo08Wo00?ooooo00?o0?l:ooooool0ogd00_ooool01?n7o`3oooooo`3oVol0
Jol4o`04o`06o`3Zooooooooooooooooool0ogOooooo0_l0l?l01?oooooo013oooooool0ol`2oooo
o`03o`2Kool0ocCo00Co00?o00Co00?oooooo`3<ooooool01?ooool00omG0?oo0?njooooo`06oooo
o`04o`3o`?ooooooooooooooo`;o0:ko3Ol0of/00ol0olKo0?m[o`3oJ`06ooooo`;o05;o2?ooool2
o`0:o`03ooooool0FOoo05Wo00Gooooo0ol0i?l8ooooo`?oE`3o1Oooool00ol0oi_o0?ofo`3omP09
ooooo`;oGOl00oooool00omSo`3oooooooooo`05o`0^o`_ooooo0_l0l?l00ol0o`[oooooooooo`05
ooooo`;o0?nE0_l0f?l4ooooo`;o0?lX1_ooool3o`3oI@Go02ko0_ooool6o`3Toc7ooooo0ol0Pol2
ooooo`;o0:ko0ol0C?l00ooooooo0?mIo`3oF@03o`3oF@Kooooo1Ol0D_lIooooo`?o0?Ko1oooool4
o`0@o`Go0?ljE?ooool?o`3o8QWooooo000Iooooo`03o`000?oooooooooo03?ooooo00?oQol0oooo
ooooool02_ooool02?l0m_ooooooooooooooooooHol0o`3o:?oooooo0?mB1oooool01?l0oh?o00[o
o`29ool0XOl3ooooo`04o`3o2_oooooo0?mmohOo00?ooooo00Go0?nKo`1[ool0om;oooooo`3o>P0@
o`04o`04o`3o=?l0ofGo0?mUooooo`;o08?o00?o0<coooooooooool00oooool2oeL0o`Oooooo00Ko
0?o0o`3oUOooooooooooo`3o8_l0[_l=ooooo`;o0?o62?ooool2o`1Bo`Cooooo0_l02_l5ooooo`;o
05Wo1_ooool4o`3To`04oooooomG0?ooE`3ooeL0o`Kooooo0_l0oi/3ooooo`?o0?of1?ooool2oego
00?ooooo0_mSo`08ooooobSo02ko0_ooool5o`3Toc?ooooo1?l0Pol2ooooo`?o0:ko0_l0C?l4o`3o
F@Kooooo1Ol0D_l00ol0ocCoooooooooo`0Gooooo`Co0?Ko1oooool3o`0@o`Co0?ljD_ooool7o`3o
8RSooooo000Iooooo`03o`000?oooooooooo03Cooooo00?oQol0ooooooooool02_ooool01ol0m_oo
oooooooooomSo`3oooooo`3o:?l0oe802?ooool00ol0oh?o00[oo`29o`04ooooo`03o`3o2_n7o`3o
0?mm00Gooooo00Ko06_oo`3od_oooooo0?ljo`3oFOl0j_l3ooooo`;o0?mg00Koooooo`3`oooooooo
013oooooool0ol`2ooooo`03o`2Kool0ocCooooo00;o0?mU00?oooooo`23ool0c?l01_ooool3oeL0
o`Gooooo0_l0ol000ol0oiGoooooo`3o8P02o`2^o`gooooo00?o0?o6ooooooooool01oooool2o`1B
o`;o00[o2Oooool00ol0FOooooooooooo`05ooooo`?oE`3o1?l0i?l3ooooo`;o0?nK2?ooool2o`3o
mP;oGOl01?ooool00omSo`3oooooooooo`0?ooooo`;o0?3o00?o0?l:ooooooooool00_ooool4o`3o
U@;ooooo0_l0f?l2ooooo`;o0?lX1Oooool3o`3oI@So0>Co=Oooool3o`23o`?ooooo0ol0[_l3o`1<
o`;o0?mI1Oooool5o`1Bo`?o0?ld6Oooool3o`3fo`03o`3oMooooooooooo00Cooooo00Go0?ljo`0@
ool04?oo013oo`3o>P1Aooooo`Oo0?lR;oooool001Wooooo0ol0000eooooo`03ohOo0?oooooooooo
00Wooooo00So0?Koooooooooooooooooof?o0?oooooo0?lXo`3oDPSooooo00?o0?n3o`0:ool0XOl0
0_ooool01On7o`3oooooo`3o2_oooooo0?mm00Gooooo00Ko06_oo`3od_oooooo0?ljo`3oFOl0j_l4
ooooo`07o`3oMooooooo0?3oooooool04?ooooooo`3oc002ooooo`08o`2Kool0ocCoooooooooool0
ofGoooooo`23ool0c?l6ooooo`03o`3o^_ooooooE`3o00;oE`3o1?ooool00ol0ol3o0?nEooooo`02
o`3o8P03o`2^oooooooooooo00_ooooo0_l0olH7ooooo`;o00[o0_l0D_l:ooooo`;o05Wo0_ooool3
oeL0o`Oooooo1Ol0i?l8ooooo`;oGOl00_l0ooH2ooooo`;oHol04?ooool2o`3`o`Cooooo0ol0oiD4
ooooo`;o0=So00?oooooo`3o:?l0obP02ol0i?liooooo`Co08?o0oooool3o`2^o`04o`3oFOl0C?oo
04coo`3oF@?ooooo1_l0D_l01?oooooo0?ldo`3o=?l0oc@Iooooo`Co0?Ko00?o0?mgooooooooool0
0_ooool2o`3o>PCo013oC_ooool7o`3o8SKooooo000Iooooo`03o`000?oooooooooo03Kooooo00?o
Qol0ooooooooool02Oooool01ol0m_oooooooooooomSo`3oooooo`3o:?l0oe802?ooool01Ol0oh?o
0?n?o`0:ool02_ooQol000?ooooo00?o0?l:ooooool0ogd01Oooool01Ol0Jooo0?oBooooool0oc[o
0>[o00Gooooo00Oo0?mgooooool0l?oo0?3oo`0@oooooooo0?o<00;ooooo00Co09_oo`3o=?oooooo
oooo0_l0ofD00ol0Pooo0<coooooo`05ooooo`;o0?nj0_ooool3oeL0o`;ooooo00Go0?o0o`3oUOl0
oiGo0?nEo`3o8P02o`2^o`gooooo00?o0?o6ooooooooool00_ooool2o`0:o`Cooooo0ol0D_l8oooo
o`?oE`3o2_ooool2o`3oV`?ooooo2_l0i?l2ooooo`?o0?of3oooool2o`3`o`;ooooo1?l0oiD5oooo
o`;o0=So1Ol0i?l2ooooo`?o0?mU>oooool4o`23o`Cooooo0ol0[_l2o`3oF@;o04co00?oooooo`1B
ool0D_l00ol0D_l4ooooo`?o0?ld6Oooool3o`3fo`;o0?mg0oooool2o`3o>PCo013oB?ooooldo`3o
DPKo06_o3Oooool001Wooooo00?o0000ooooooooool0=oooool00on7o`3oooooooooo`09ooooo`07
o`3fooooooooooooof?o0?oooooo0?lXo`3oDP08ooooo`04o`3oPol0ohoo08Woo`0:o`Cooooo00?o
0?l:o`3oOOooool01?ooool01_l0Jooo0?nKo`3od_oooooo0?ljo`3Zo`Gooooo00Oo0?mgoooooooo
oooo0?3oo`0@oooooooo0?o<00;ooooo00?o09_oo`3o=?ooool00_ooool00ol0ofGo08?oo`3<o`07
ooooo`03o`3o^_oooooooooo00;ooooo0_mG0?l01?oooooo0?o0ooooooooool3o`3oU@03o`2^oooo
oooooooo00_ooooo00Co0?o6ooooool02_oo00[o2Oooool3o`1Bo`03oooooomG0?ooE`3o00;oE`3o
0oooool2o`1Io`Kooooo0_l0oi/9ooooo`;oGOl01?oooolOo`3To`;o0=So00?oooooo`3o:?l0obP0
0oooool3o`3oIC_ooooo0ol0Pol4ooooo`Co0:ko00?o0?mIooooool0C?l00_l0C?l3o`1Bo`Kooooo
0ol0oc@Hooooo`Co0?Ko0_l0ogL00ooooooo0?ljo`3o>P05o`0@od7ooooo2ol0oe83o`3o8RKooooo
2ol0Jol6o`29o`gooooo000Iooooo`03o`000?oooooooooo03Sooooo0_n7o`09ooooo`08o`3foooo
oooooooooooooomSo`3o0?lXooooool0oe87ooooo`05o`3oPon7o`3o08Woo`3Hool02_l01?ooool0
0ol0o`[o0?mmooooo`04ooooo`06o`1[ool0oi_o0?oBooooool0oc[o0>[o1Oooool01ol0ogOooooo
ooooool0l?oo013oooooool0ol`00_ooool00ol0Vooo0?ldooooo`03ooooo`03o`23ool0c?oo0<co
00Kooooo00?o0?njooooooooool00oooool5oeL0o`03ooooool0ob;o0?nE00;o0:ko2oooool2o`0:
o`03o`3oa_oooooooooo00Oooooo1OmG0?l2o`1Bo`Oooooo00?o05Woooooooooool00_ooool00ol0
oi_oooooooooo`07ooooo`;oGOl01Oooool2of?o00Oooooo0ol0ooH4ooooo`;o0?3o0ol0oiD9oooo
o`;o0=So0ol0obP2ooooo`?o0?mU>_ooool4o`23o`Cooooo0ol0[_l01?l0oeWoooooo`1Bool0D_l2
o`1<o`03o`1Boooooooooooo00Kooooo0ol0oc@Hooooo`?o0?Ko0ol0ogL2o`3o>PCo013o<OoooolE
o`3oDPOo0?lR5Oooool?o`3odPWo06_o2_l0ROl2o`3Zo`Go0?oB3Oooool001Wooooo00?o0000oooo
ooooool0>_ooool00on7o`3oooooooooo`07ooooo`07o`3fooooooooooooof?o0?oooooo0?lXo`3o
DP06ooooo`;oQol000Go0?n3ooooool0ROoo0:7oo`0:o`04ooooo`03o`3o2_l0oggooooo00Cooooo
00Go06_oo`3oVol0om;oooooo`3o>P02o`3Zo`Cooooo00Oo0?mgoooooooooooo0?3oo`0@ool0C?oo
0?o<00;ooooo00?o09_oo`3o=?ooool00oooool2o`23o`03o`3<oooooooooooo00Cooooo00?o0?nj
ooooooooool01Oooool00ol0ol3ooooooeL0o`07oeL0o`Kooooo0_l02_l2ooooo`[oE`3o1oooool3
o`1Bo`Gooooo0_l0FOl2o`3oV`Sooooo0_mMo`05ooooo`;oHol03?ooool2o`3omP;o0?3o00?o0?nE
ooooooooool02_ooool00ol0f?oo0?lXo`3o:002ooooo`?o0?mU>Oooool4o`23o`Cooooo00?o0?mI
o`2^ool0[_l01Ol0D_l3o`1<o`Sooooo0ol0oc@Hooooo`?o0?Ko0ol0ogL00ol0oc[o013oo`0@o`02
o`0@obgooooo2?l0oe8=ooooo`Oo0?lR2_oooolCo`3odPSooooo1ol0Jol8o`29o`Co0>[o6oooool0
01Wooooo00?o0000ooooooooool0>oooool00on7o`3oooooooooo`06ooooo`08o`3foooooooooooo
oooooomSo`3oooooo`3o:?l0oe84ooooo`08ohOo0?ooooooooooooooool0oh?o0?n?o`29ool0XOl2
o`0:o`?ooooo00?o0?l:o`3oOOooool01?ooool01?l0Jooo0?nKo`3od_ooool2o`3o>P03o`3Zoooo
oooooooo00;ooooo00Oo0?mgoooooooooooo0?3oo`0@ool0C?oo0?o<00;ooooo00?o09_oo`3o=?oo
ool01?ooool00ol0Pooo0<coooooo`05ooooo`03o`3o^_oooooooooo00Gooooo00Co0?o0oooooooo
oooooooo0_l0ob82ooooo`03o`2^oomG0?ooE`3o00SoE`3o0_ooool2o`3oaQ3ooooo1?l0D_l00ooo
oooo0?nKo`3oV`02o`1Io`Kooooo0_mMo`06ooooo`03of?o0?oooooooooo00[ooooo00Go0?nEo`3`
ool0l?oo0?3oooooo`03o`3omPWooooo0_l0f?l00ol0obSoooooo`3oI@02o`3oICWooooo0ol0Pol5
ooooo`03o`3oFOl0D_oo05;o00?o05;o0oooool2o`1<o`Sooooo0ol0oc@Hooooo`?o0?Ko0_l0ogL0
0ol0oc[o013oo`0@o`02o`0@ob_ooooo1_l0oe8>ooooo`Oo0?lR1oooool:o`3odQCooooo1ol0Jol6
o`29o`Co0>[o9?ooool001Wooooo00?o0000ooooooooool0??ooool00on7o`3oooooooooo`06oooo
o`04o`3fooooooooooooof?o00;ooooo00?o0?lXo`3oD_ooool00_n7o`05ooooo`06o`3oPol0ROoo
GOl0o`2Qoooooooo00[o1?ooool00ol0oggoooooooooo`02ooooo`04o`1[oooooooo0?nKo`3odP;o
oooo00?o0?ljo`3Zooooool00oooool01ol0ogOoooooooooool0l?oo013oo`1<ool0ol`00_ooool0
0ol0Vooo0?ldooooo`04ooooo`;o08?o1_ooool2o`3o^PKooooo00?o0?o0ooooooooool00_ooool0
0ol0ob;oooooooooo`02o`2^o`;o00[o00?o0?nEooooooooool01oooool00ol0olKoooooooooo`0?
ooooo`;o0?nK0ol0D_l2ooooo`;o05Wo0_ooool2oego00Kooooo0_mSo`09ooooo`?o0?nE0_l0l?l7
ooooo`?o0?of1?ooool2o`3Ho`04ooooool0ofGo0?mUo`3oICSooooo1?l0Pol3ooooo`Ko05;o1Ooo
ool3o`1<o`Oooooo0ol0oc@Hooooo`?o0?Ko0_l0ogL01?l0oc[o013oo`0@ool04?lYooooo`Ko0?mB
3Oooool7o`3o8P?ooooo2ol0om8Gooooo`Oo06_o1_l0ROl4o`3Zoa;o0?n36Oooool001Wooooo00?o
0000ooooooooool0?Oooool3ohOo00Gooooo00Go0?Koooooooooooooooooof?o0002ooooo`03o`3o
D_n7o`3ooooo00Oooooo00Go0?n3o`29ool0f?oo0:7oooooo`02o`0:o`;ooooo00?o0?mmo`3o2_oo
ool00oooool00ol0Joooooooo`3oV`02o`3odP03ooooool0oc[o0>[o00Cooooo00Oo0?mgoooooooo
ooooooooo`0@ool0C?oo0?o<00;ooooo00?o09_oo`3o=?ooool01Oooool2o`23o`Kooooo00?o0?nj
ooooooooool01?ooool00ol0ol3oooooooooo`02ooooo`;o0?lR0_l02_l2o`2^o`03ooooool0oiGo
0?nE00;o0?nE1_ooool00ol0olKoooooooooo`0<ooooo`;o0?nK1Oooool4o`1Bo`?o05Wo1Oooool2
of?o00Oooooo1?l0oiD00ol0o`[o0?3oo`3`o`0<ooooo`;o0?of0_l0f?l3o`3oICSooooo0ol0Pol2
ooooo`Go05;o0ol0[_l5ooooo`?o04co1oooool3o`3o=1Wooooo0_l0m_l2o`3oM`04ooooool04?oo
013oo`0@obGooooo1ol0oe8<ooooo`Oo0?lR0_ooool8o`3odQ;ooooo2Ol0oh<7o`1[o`Ko08Wo1?l0
j_lIooooo`co0?n33Oooool001Wooooo00?o0000ooooooooool0@?ooool3ohOo00?ooooo00So0?Ko
oooooon7o`3oQol0of?o0?n7o`3o0?lXo`3oDPWooooo00Co0?n3o`29ool0f?oo0:7o0_ooool01Ol0
2_ooooooooooool0oggo0?l:00Cooooo00So06_oooooool0oi_o0?nKo`3od_oooooo0?ljo`3Zo`Co
oooo00Oo0?mgooooooooooooooooo`0@ool0C?oo0?o<00;ooooo00?o09_oo`3o=?ooool01_ooool0
0ol0Pooo0?mUooooo`04ooooo`03o`3o^_oooooooooo00Cooooo00Co0?o0oooooooooooooooo0_l0
2_l2o`3o8P;ooooo00?o0:koooooooooool00_ooool7o`3oU@;o0?o62_ooool2o`3oV`Wooooo0_mM
o`04o`1Bo`03o`1Iool0oiGo0?nE00[o0?nE00?oooooo`3o2_l0l?l00_l0l?l>ooooo`;o0=So00Co
0?mUo`3om_l0ooKo0?of=Oooool00ol0Pooo05;oo`1Bo`06o`1Bo`;o0?mI0ol0[_l6ooooo`;o04co
1oooool3o`3o=1Sooooo00Ko0?ljo`3fool0m_oo0?Koo`3oMoooool3o`0@ob7ooooo1ol0oe8<oooo
o`Oo0?lR0_ooool7o`3odPOooooo4ol0oh<2ooooo`Oo06_o1Ol0ROl4o`3Zoa?ooooo6_l0c?l=oooo
o`006Oooool00ol0003oooooooooo`13ooooo`CoQol000So0?Koooooooooooooooooof?o0?oooooo
0?lXo`3oDPWooooo00Co0?n?o`29ool0f?oo0:7o0_ooool2o`0:o`04ooooool0oggo0?l:o`3o2P?o
oooo00So06_ooooooooooooo0?nKo`3od_oooooo0?ljo`3Zo`Cooooo00Oo0?mgoooooooooooooooo
o`0@ool0C?oo0?o<00;ooooo00?o09_oo`3o=?l0oc@01_ooool2o`23o`Gooooo00?o0?njoooooooo
ool01?ooool00ol0ol3o00[oo`0:o`04ooooo`03o`3o8_oooooooooo00;o0:ko2Oooool2o`3oU@;o
0?o61_l0oiD2o`3oV`Oooooo2_l0oiD3o`1Bo`Sooooo0_l0o`X2o`3`o`cooooo0ol0ofD2o`3Ho`Ko
oooo1?l0ooHWooooo`_o05;o0oooool3o`3oF@Co0:ko1_ooool3o`1<o`Kooooo0ol0oc@Fooooo`Co
0?lj0_l0m_l00ol0ogOoooooo`0@o`02o`0@oagooooo1ol0oe8=ooooo`Ko0?lR0_ooool7o`3odPCo
oooo2_l0oh<>ooooo`Oo06_o1Ol0ROl4o`3Zo`Gooooo5Ol0c?lWooooo`006Oooool00ol0003ooooo
ooooo`17ooooo`03o`3foooooooooooo00;ooooo00CoHol0ooooool0obSo0?mB2?ooool01Ol0oh?o
08Woooooool0XOooGOl000?ooooo0_l02_l00ol0oggoooooo`3o2P03ooooo`;o06_o00Koooooo`3o
Vol0om;oooooo`3o>_l0j_l4ooooo`07o`3oMoooooooooooooooool04?oo04coo`3`o`02ooooo`;o
09_o00?o0?ldooooooooool01?ooool01?l0c?oo08?oo`3oIOl0ofD3ooooo`;o0?nj0_ooool3o`0:
o`03ooooool0ol3ooooo00Cooooo0_l0ob82ooooo`;o0:ko2oooool2o`3oaP;ooooo0_l0oi/2oooo
o`Oo0?nE0_mMo`07ooooo`;oHol00_ooool7o`1Bo`03o`3o2_l0l?oo0?3o00Wooooo1Ol0ofD00ooo
oooo0=Soo`3Ho`0<ooooo`Go0?of6?ooool:o`1Bo`?ooooo1?l0Pol4ooooo`;o0?mI1?l0[_l8oooo
o`;o04co1_ooool3o`3o=1Gooooo1?l0ocX01Ooooooo0?Koo`3fool0m_oooooo00?o013o6Oooool7
o`3oDPoooooo1Ol0ob88o`3odP_o0?n34oooool5o`1[o`Go08Wo1?l0j_l00ooooooo0<coo`3<o`09
o`3<occooooo000Iooooo`03o`000?oooooooooo04Sooooo00Go0?Koooooooooooooooooof?o0002
ooooo`03o`3oD_oooooooooo00Oooooo00Go0?n3o`29oooooooo0:7ooego0004ooooo`04o`0:ool0
oggoooooo`3o2PCooooo00Oo06_oooooool0oi_o0?oBooooool0oc[o0>[o00Cooooo00Ko0?mgoooo
ooooooooooooo`0@ool0C?l2o`3`o`;ooooo00?o09_oo`3o=?ooool01Oooool00ol0c?oo08?oo`23
o`03o`3oI@04ooooool02_oo00[oo`0:o`Gooooo0_l0ol05ooooo`04o`3o8_ooooooooooooooo`?o
0:ko2Oooool00ol0oi_o0?o6o`3oaP09ooooo`;oGOl02?ooool00omSo`3oooooooooo`04ooooo`;o
05Wo00?o0?l:o`3`ool0l?l02?l0D_l4o`3oI@Cooooo0_l0f?lCooooo`Co0?of3Oooool7o`1Bo`[o
oooo0ol0Pol5ooooo`03o`3oFOl0[_oo0:ko00;o0:ko2Oooool3o`1<o`Gooooo0ol0oc@Dooooo`Co
0?lj00?oooooo`3oMol0m_l00_l0m_l01?oooooo013oo`0@ool04?lEooooo`Oo0?mB4?ooool3o`3o
8PSo0?oB2?l0oh<Iooooo`Go06_o0ol0ROl3o`3Zo`Wo0<coAoooool001Wooooo0ol00018ooooo`03
o`3foooooooooooo00;ooooo00CoHol0ooooool0obSo0?mB2Oooool01Ol0ohoo08Woooooool0XOoo
0=So00Cooooo0ol02_l00ol0o`[oooooooooo`02ooooo`04o`1[oooooooo0?nKo`3odP;ooooo00?o
0>[oooooooooool00_ooool02?l0ogOooooooooooooooooo013oo`1<ool0olco0?3o0_ooool00ol0
Vooo0?ldo`3o=006ooooo`03o`3<ool0Pooo00[o00;o00[o0_l0ofD00ol0ok[oooooooooo`05oooo
o`03o`3o`?oooooooooo00?ooooo0_l0ob84ooooo`;o0:ko1Oooool2o`3oV`?ooooo0_l0olH5oooo
o`;oGOl02?ooool2of?o00Gooooo0_l0o`X2o`3`o`?o05Wo0oooool5o`3oI@ko05;o4Oooool?o`1B
o`gooooo1?l0Pol4ooooo`03o`3oFOl0[_oo0:ko00;o0:ko2_ooool3o`1<o`Gooooo0ol0oc@Coooo
o`Co0?lj0_ooool2o`3oM`;o0?Ko1?l04?lBooooo`Ko0?mB4_ooool00ol0ob;o0?oBo`3odP05o`3o
dPOo0?n37Oooool5o`1[o`?o08Wo00?o0>[oo`3<ool0c?l01Ol0c?m@ooooo`006Oooool00ol0003o
ooooooooo`19ooooo`03o`3foooooooooooo00;ooooo00CoHol0ooooool0obSo0?mB2Oooool01_l0
ROooooooooooool0XOoo0=Sooego00?ooooo00?o0?mmooooool02_l00_l02_l3ooooo`03o`1[oooo
oooooooo00;o0?oB00?oooooo`3Zool0oeT00oooool01ol0ogOooooooooooooooooo013oo`1<ool0
ol`00_l0l?l01?oooooo09_oooooool0oc@3ooooo`Co00[o00?o0<coo`23ool0Pol00oooool00ol0
ok[o0?mUo`3oI@05ooooo`;o0?o01Oooool2o`3o8PCooooo0_l0[_l00ooooooo0?nKo`3oV`07oooo
o`;o0?o60omMo`08ooooo`;oHol01Oooool01?l0o`[o0?3oo`3`ool0l?l4ooooo`04o`3oIOl0FOoo
05Woo`3oI@Wooooo00?o0?lXo`3Hooooool01ooooolAo`1Bo`Kooooo1Ol0ooH=ooooo`Co08?o1Ooo
ool4o`2^o`cooooo0_l0C?l5ooooo`?o0?ld4_ooool4o`3o>P?ooooo0_l0ogL2o`3fo`?o013o4Ooo
ool5o`3oDQ;ooooo00?o0?lRo`3od_l0om801?l0om87o`3oPakooooo1_l0Jol3o`29o`Ko0<co;Ooo
oolMo`3oc0gooooo000Iooooo`03o`000?oooooooooo04[ooooo00?o0?Koooooooooool00_ooool0
0omSo`3oooooo`3oDP0:ooooo`06o`29ooooooooooooo`2Qool0f?ooGOl00oooool01?l0oggooooo
ooooooooool5o`0:o`?ooooo00?o0?oBo`3oVol0j_l00_l0oeT2ooooo`05o`3oMooooooooooooooo
ool04?l00_l0C?l01?l0olco0?3oo`3`ool0Vol4o`0:o`Gooooo00?o0<coooooool0Pol00oooool0
0ol0ok[oooooo`3oI@02o`3oI@Cooooo00?o0?o0ooooooooool01?ooool2o`3o8P?ooooo00Co0?nK
o`2^ool0[_oo0:ko1oooool2oego0003o`3oa_oooooooooo00Kooooo0_mSo`04ooooo`04o`3o2_l0
l?oo0?3oo`3`o`;ooooo1Ol0ofD3ooooo`;o05Wo1_ooool00ol0obSo0=Soo`3Ho`0Uooooo`Go0?of
0oooool5o`23o`Gooooo1?l0[_l=ooooo`?o04co1?ooool3o`3o=17ooooo1?l0ocX3ooooo`?o0?mg
00?o0?Koo`0@ool04?l00_l04?l@ooooo`Co0?mB4_ooool00ol0ob;o0?oBo`3odP03o`3odPKo0?n3
8?ooool5o`1[o`Co08Wo1?l0c?lRoooooa;o0?o<:_ooool001Wooooo00?o0000ooooooooool0B_oo
ool00ol0m_ooooooooooo`02ooooo`04of?o0?ooooooooooo`3oDP[ooooo00Ko08Woooooool0XOoo
ooooo`3HoomMo`03ooooo`05o`3oOOooooooooooooooool0o`X00oooool5o`0:o`04o`3oVol0j_oo
0?nKo`3oF@;ooooo00Co0?mgoooooooooooooooo1_l02_l01?l0l?oo09_oo`3`ool0oc@6ooooo`;o
0<co0_l0Pol2ooooo`;o0?nj0_ooool4o`3oI@03ooooool0ol3o0?o000Kooooo0ol0oi/4ooooo`Co
0:ko00?ooooooego0?mMo`000oooool2o`3oaPCooooo0_mSo`04ooooo`?o0?3o1Ol0ofD:ooooo`?o
05Wo00Coooooo`3o:?l0f?oo0=So:oooool4o`23o`Go0?of00?oooooo`2^ool0[_l00_l0[_l00ol0
oeWoooooooooo`0<ooooo`;o04co0oooool4o`3o=13ooooo1?l0ocX4ooooo`?o0?mg00Co0?Koo`0@
ool04?oo013o4?ooool4o`3oDQ3ooooo0_l0ob85o`3odPGo0?n38Oooool5o`1[o`Co08Wo00Co0<co
o`3Zool0j_oo0>[o4_oooolEo`3oc3cooooo000Iooooo`03o`000?oooooooooo04_ooooo00?o0?Ko
ooooooooool00_ooool01?mSo`3oooooooooool0oe89ooooo`07o`3oSol0ROooooooo`2Qoooooooo
0=Sooego0003ooooo`05o`3oOOooooooooooooooool0o`X00oooool01?l0Joooooooooooooooool:
o`0:o`;ooooo00Co013oo`1<ool0olco0?o<0_ooool01?l0Vooo0?3oo`3`ool0l?l6ooooo`04o`3<
oooooooo08?oo`23o`;ooooo00?o0?njooooooooool00oooool3o`3oI@04o`3o`?l0ofGo0?mUo`3o
I@;o0?nK00Co0?mUooooool0ob;o0?lR1_ooool01?mMo`3o0:koo`2^ool0[_l5ooooo`;o0?o600?o
ooooof?o0?ooool00_ooool3o`3`o`?o0?mU4Oooool01?l0obSo05Woo`1Iool0FOlXooooo`Co08?o
1Oooool5o`2^o`Oo0?of2_ooool2o`1<o`;ooooo0ol0oc@Aooooo`?o0?lj1Oooool3o`3oM`Co013o
3_ooool5o`3oDPoooooo0_l0ob85o`3odPGo0?n38Oooool5o`1[o`Go08Wo0ol0j_l<ooooo`_o0?o<
4?ooooldo`3omPgooooo000Iooooo`03o`000?oooooooooo04cooooo00?o0?Koooooooooool00_oo
ool01?mSo`3oooooo`3oD_l0obP9ooooo`06o`3oSol0ROooooooo`2Qoooooooo0=So0_mMo`02oooo
o`;o0?mm0_ooool3o`3o2P03ooooool0Jooooooo00;ooooo00Go0?oBooooool0j_oo0?ljooooo`02
o`3oV`03o`3oMooooooooooo00;ooooo00Co013oo`1<ool0C?oo0?o<0_ooool00ol0Voooooooo`3o
=002o`3`o`Gooooo0_l0c?l01?oooooo08?oo`23ool0Pol2o`3o^POooooo0_l0ol001?l0oi_ooooo
ooooooooool=o`3oI@Co0:ko0ol0ofD00ol0olKo0?3oo`3`o`02o`3`o`03o`3oIOoooooooooo017o
oooo0_l0obP2o`3Ho`?ooooo0ol0FOlQooooo`Co08?o1Oooool4o`2^o`?o0?mI2Oooool6o`3omP05
ooooool0C?oo04coo`1<ooooool00ol0oc@@ooooo`Co0?lj1?ooool4o`3oM`?o013o00?o0?Kooooo
ooooool02oooool4o`3oDPkooooo0ol0ob85o`3odPGo0?n38?ooool00ol0c?oo06_oo`1[o`03o`1[
o`03o`3<ool0ROoo08Wo00;o08Wo1?l0j_l5ooooo`_o0?o<1OoooolFo`3omT7ooooo000Iooooo`03
o`000?oooooooooo04cooooo00?o0?Koooooooooool00oooool01?mSo`3oooooo`3oD_l0obP9oooo
o`07o`3oSol0ROooooooo`2Qoooooooo0=Soooooo`02oego00;ooooo00?o0?mmooooooooool00_oo
ool2o`3o2P08o`1[ooooooooooooooooool0om;oooooo`3Zool0ocX2ooooo`?o0?nK0oooool2o`0@
o`05o`1<ool0olco0?o<ooooool0Vol00_ooool01?l0ocCo0?3oo`3`ool0l?l4ooooo`04o`3<oooo
ooooooooooooo`Co08?o00?oooooo`3oVol0oi/00_l0oi/2ooooo`03o`3o`?oooooooooo00Kooooo
0_l0ob89ooooo`06o`3`ool0[_oo0:koo`2^ool0l?oo0?l:0_l0olHCooooo`;o0?lX0_l0f?l8oooo
o`?o05Wo6Oooool5o`23o`Gooooo1?l0[_l3o`3oFA;ooooo0_l0C?l7o`3omPgooooo0ol0ocX5oooo
o`?o0?mg1?l04?l00ol0m_ooooooooooo`0:ooooo`Co0?mB3Oooool3o`3o8PGo0?oB1Ol0oh<Noooo
o`?o0<co1Ol0Jol2ooooo`Co08Wo1?l0j_l4o`3oc1Go0?ofEoooool001Wooooo00?o0000oooooooo
ool0COooool00ol0m_ooooooooooo`03ooooo`;oHol000?o0?mBo`3o:?ooool02?ooool01_l0ohoo
08Woooooool0XOooooooo`3Ho`;ooooo0_mMo`000ooooooo0?mmooooo`05ooooo`;o06_o0_ooool2
o`3odP06o`3Zool0oc[oooooooooool0oeWo0?mg1Ol0oi/01Ol04?oo04coo`1<ool0olcooooo00;o
09_o0_ooool2o`3o=0Co0?3o00?oooooo`3<ool0c?l00_ooool2o`3oV`04o`3o^_l0Pooo08?oo`23
o`Gooooo0_l0ol03ooooo`?oGOl00_ooool3o`3o8P03ooooool0l?oo0?3o00?o0?3o0ol0o`X00ooo
oooo0:koo`2^o`02o`2^o`;o0?o63_ooool3o`3o:0;o0=So3Oooool3o`1Ioa7ooooo1Ol0Pol5oooo
o`Go0:ko1?l0oeTCooooo`;o04co0ol0oc@6oooooaCo0?of1?l04?l2o`3fo`[ooooo1Ol0oe8<oooo
o`Co0?lR1?l0om84o`3oPagooooo1Ol0c?l5o`1[o`?o0?of1?l0ROl3o`3Zo`Wo0?ofK?ooool001Wo
oooo00?o0000ooooooooool0C_ooool00ol0m_ooooooooooo`04ooooo`03of?o0?l0oe;o0?lX00Wo
oooo00Ko0?n?o`29oooooooo0:7oooooool0f?l3ooooo`;oGOl000?o0?mmooooooooool01Oooool0
1ol0Jooo0?l:oooooooooooo0?oBo`3Zool0ocX00oooool00ol0oeWo0?mgooooo`02ooooo`05o`3o
Vol04?oo013oo`1<ool0ol`00_l0oi/00ol0Vooo0?nKo`3oV`05o`3oV`?o0?3o0_l0c?l01_l0l?oo
oooooooooooooooo0?njooooo`Co08?o0oooool00ol0ol3oGOl0oego0002ooooo`Oo0?3o00?o0?lR
ooooool0o`X00_l0o`X8ooooo`Go0:ko2Oooool2o`3o:0?o0=So4_ooool3o`1Io`[ooooo1?l0Pol5
ooooo`Go0:ko0_ooool3o`3oFACooooo0ol0C?l2o`3o=0oooooo0ol0ocX6ooooo`;o0?mg0ol04?l0
0ooooooo0?Koo`3fo`11o`3omPKo0<co00?o0?ofo`1[ool0Jol00_l0Jol3o`3omP03o`3oc?l0ROoo
08Wo00;o08Wo0ol0j_miooooo`006Oooool00ol0003oooooooooo`1>ooooo`03o`3foooooooooooo
00Gooooo00?oHol0o`3oD_l0obP02Oooool00ol0ohoo08Woo`2Qo`02ooooo`;o0=So0oooool00omM
o`3o0?mmoego0006ooooo`07o`1[ool0o`[oooooooooool0om;o0>[oo`3o>P04ooooo`03o`3oMol0
oeWooooo00?ooooo00Ko013oo`1<ool0olco0?o<ooooool0Vol3ooooo`;o0?ld1_ooool2o`3<o`So
0?3o0ol0Pol5o`3`o`Gooooo0ol0o`X2o`3o8Poooooo1Ol0[_l2ooooo`;o0?lX0_l0f?lHooooo`?o
05Wo0_ooool5o`23o`Wo0:ko0oooool4o`3oFAGooooo0_l0C?l2o`3o=0kooooo1?l0ocX6ooooo`03
o`3oMol04?oo013o00;o013o00Coooooo`3fool0m_oo0?Ko1oooool4o`3oDP[ooooo1_l0ob85o`3o
dP03o`3oPooooooooooo01Wooooo1ol0c?l2ooooo`Go06_o1Ol0ol`3o`29o`?o0>[oOOooool001Wo
oooo00?o0000ooooooooool0Coooool00ol0m_ooooooooooo`05ooooo`04of?o0?l0oe;o0?lXo`3o
:0Sooooo00?o0?n?o`29ool0XOl00oooool00ol0f?ooooooooooo`02ooooo`03o`3oOOmMo`3oGOl0
00Gooooo00Oo06_oo`3o2_l0o`[o0?l:o`3od_l0j_oo0?lj00Cooooo0_l0ogL01Ol0oeWooooooooo
oooooooo013o00;o04co0_l0ol`00ol0Voooooooooooo`02ooooo`;o0?ld1_ooool2o`3<o`?ooooo
00?o0?njoego0?mMo`000oooool3o`23o`03o`3o`?oooooooooo00Co0?l:00?oooooof?o0?ooool0
0_ooool3o`3o8Pkooooo0ol0olH=o`2^o`kooooo0ol0[_l3o`23o`?o05Wo0_l0[_l9ooooo`Go0?mI
5_ooool3o`1<o`03o`3o=?oooooooooo00_ooooo1?l0ocX7ooooo`Co013o0_ooool3o`3fo`Kooooo
1?l0oe89ooooo`Go0?lR00?oooooo`3oPol0om800ol0om800ol0oh?oooooooooo`0Gooooo`Oo0<co
1Oooool4o`1[o`Go0?o<00?oooooo`29ool0ROl00_l0ROl2o`3Zoh7ooooo000Iooooo`?o0000D?oo
ool00ol0m_ooooooooooo`06ooooo`03o`3oD_oooooo0?lX00Sooooo00?o0?n?o`29ool0XOl00ooo
ool2o`3Ho`?ooooo00?o0?mmoooooomMo`000_mMo`03ooooo`06o`1[ooooooooooooooooool0om;o
0>[o0_l0ocX4ooooo`03o`3oMol0oeWooooo00;ooooo0_l04?l2o`1<o`03o`3oc?l0Vooo09_o00Co
oooo0_l0oc@3ooooo`?oGOl00_l0c?l01?mMo`3oooooo`3o^_l0okX6ooooo`Go08?o00?oooooof?o
0?mSo`001oooool3o`3o8P_ooooo0_l0obP00ooooooo0=Soo`3Ho`0;ooooo`co0:ko1Ol0Pol6oooo
o`Co05Wo0oooool4o`3oFASooooo0ol0C?l>ooooo`?o0?lj2?ooool3o`0@o`Cooooo0_l0m_l5oooo
o`Co0?mB2?ooool5o`3o8P03ooooool0oh?o0?oB00Co0?oB5oooool7o`3<o`Wooooo0ol0Jol2o`3o
c0Cooooo1?l0ROl2o`3ZohGooooo000Iooooo`03o`000?oooooooooo053ooooo00?o0?Kooooooooo
ool01oooool00ol0oe;oHol0o`3o:008ooooo`03o`3oSol0ROoo0:7o00Cooooo00Go0=Sooooooooo
ooooooooo`3oO@03ooooo`?oGOl000?oooooo`1[ooooool00_ooool00ol0om;o0>[oo`3Zo`02o`3o
>P?ooooo0_l0ogL01?l0oeWoooooooooooooool2o`0@o`;o04co00?o0?o<o`2Kooooool00_ooool2
oego00;o0?ld00?oGOl0ooooooooool00oooool2o`3<o`;ooooo00?o0?njooooool0o`X00ol0o`X3
ooooo`;o0?o01Ol0Pol8ooooo`?o0?lR1Oooool3o`3o:003ooooool0f?oo0=So00;ooooo0_l0olH=
ooooo`So08?o3_ooool00ol0oeWo05Woo`1Io`03o`1IoaOooooo0ol0C?l=ooooo`Co0?lj1oooool4
o`0@o`Cooooo0ol0m_l2ooooo`Go0?mB1oooool5o`3o8P03ooooool0oh?o0?oB00Co0?oB5oooool5
o`3<o`[ooooo0ol0ol`3o`1[o`Kooooo0ol0ROl2o`3Zog7ooooo2ol0FOl=ooooo`006Oooool00ol0
003oooooooooo`1Aooooo`03o`3foooooooooooo00Oooooo00?o0?mBof?o0?l0obP02?ooool01?l0
ohoo08Woo`2Qool0XOl3ooooo`05o`3Hooooooooooooooooool0ogd01Oooool2oego0004o`1[oomM
o`3oooooooooo`;o0?oB00?o0>[oooooool0ocX01?l0o`X00ol0ogOo0?mIo`3oF@03ooooo`;o013o
00?o04coo`3oc?l0Vol00_mMo`04ooooo`?o0?ld0oooool2o`3o2P03o`3<ool0o`[o0?l:00;o0?nj
1Oooool2of?o0003ooooool0ol3o0?o000?ooooo3Ol0Pol01?l0ob;o0?lXo`3o:?ooool3o`3Ho`?o
oooo4?l0PolAooooo`Go0?mI1_ooool4o`1Io`oooooo1?l0C?l<ooooo`Co0?lj2?ooool3o`0@o`Ko
oooo0_l0m_l00ooooooo0?mBo`3oDP02o`3oDPKooooo1_l0ob800ooooooo0?n3o`3odP04o`3odQKo
oooo1_l0c?l:ooooo`Co0?o<1?l0Jol5ooooo`Co08Wo00?o0>[oooooooooool0G_oooolEo`1Io`Go
oooo1_l0okX=ooooo`006Oooool00ol0003oooooooooo`1Booooo`03o`3foooooooooooo00Oooooo
00?o0?mBof?o0?l0obP02?ooool01?l0ohoo08Woo`29ool0XOl3ooooo`;o0=So0_ooool00ol0oggo
ooooooooo`05ooooo`03o`1[oomMo`3oGOl000;oGOl000?o0?oBo`3ZoomMo`000_l0ocX3oego0003
o`3oMomMo`3o0?mI00;o0?mI0_l0o`X01Ol04?oo04coo`1<ool0Vooo0?o<00Oo0?l:0_l0oc@01?l0
o`[oooooooooooooool2o`3<o`;ooooo00?o0?njooooooooool00_mSo`05ooooo`;o0?o03?ooool2
o`3o:0[o08?o1_ooool2o`3oaQCooooo1Ol0oeT?ooooo`Co05Wo2?ooool3o`1<o`gooooo0ol0ocX9
ooooo`?o013o1_ooool3o`3fo`?o0?mB0oooool7o`3o8P;ooooo00?o0?n3o`3od_l0om800ol0om8F
ooooo`Go0<co2_ooool6o`3oc004ooooool0Jooo06_oo`1[o`Gooooo1?l0ROm?oooooaKo05Wo3ooo
ool;o`3o^Q?ooooo000Iooooo`03o`000?oooooooooo05;ooooo00?o0?Koooooooooool02?ooool0
1?l0oe;oHol0o`3o:?l0obP7ooooo`;o0?n?00?o08Woo`2Qooooool00oooool01?l0f?oooooooooo
ool0ogd7ooooo`03o`1[oooooooooooo00;ooooo00Co0?oBo`3Zoooooooooooo0_l0ocX2ooooo`;o
0?mg0_ooool3o`3oF@;o013o0_l0C?l2o`3oc0Oooooo0_l0oc@4ooooo`;o0<co00?oHol0o`3o^_l0
okX02Oooool2o`3o`0Oooooo0ol0obP2ooooo`;o0=So0oooool3o`3o8P[ooooo0ol0olH<ooooo`Go
0?mI6?ooool5o`1Io`?o04co3?ooool4o`3o>PWooooo0ol04?l6ooooo`?o0?Ko0_l0oe87o`3o8PGo
oooo1Ol0om8Eooooo`Ko0<co2?ooool7o`3oc0Cooooo0ol0Jol3ooooo`Go08Wo@oooool@o`1Ioa_o
oooo2_l0okXNooooo`006Oooool00ol0003oooooooooo`1Cooooo`03o`3foooooooooooo00Sooooo
00?o0?mBoooooomSo`000_l0obP7ooooo`03o`3oSol0ROoo0:7o00Cooooo0_l0f?l00ooooooo0?mm
ooooo`06ooooo`03o`1[oooooooooooo00?ooooo0_l0j_l2ooooo`04o`3o>_ooooooooooooooo`;o
0?mg0oooool2o`3oF@;o013o0_l0C?l2o`3oc0Oooooo0ol0oc@00oooooooHol0of?o0002o`3<o`03
ooooool0ok[ooooo00Wooooo0_l0ol02ooooo`?o0?lX0oooool2o`3Ho`Sooooo1Ol0ob88ooooo`;o
0?o61Oooool5o`3oFAkooooo00Co0?ldo`1<ool0C?oo04co1Ol0FOl6ooooo`Co0?lj2_ooool3o`0@
o`Oooooo0_l0m_l00ol0oe;o0?lRo`3o8P02o`3o8POooooo00?o0?n3o`3od_l0om800_l0om8Eoooo
o`Go0<co1oooool7o`3oc0Oooooo1?l0Jol2ooooo`Co08Wo00?o0>[oooooooooool0>oooool:o`1I
ob3ooooo2ol0okX=ooooo`ko0?mm3Oooool001Wooooo00?o0000ooooooooool0E?ooool00ol0m_oo
ooooooooo`08ooooo`;o0?mB00?oHol0ooooool0obP01oooool00ol0ohoo08Woo`2Qo`05ooooo`;o
0=So00?o0?mmooooooooool01Oooool2o`1[o`Cooooo00Co0?oBo`3Zoooooooooooo0_l0ocX3oooo
o`;o0?mg1Oooool2o`0@o`?o04co00?o0?o<ooooooooool01Oooool01?mSo`3o0?ldo`3o=?l0oc@2
ooooo`;o0<co0_l0okX:ooooo`03o`3o`?l0obSooooo00;ooooo0ol0f?l?ooooo`Ko0?lR1?ooool3
o`3oaP;o0?mI7oooool00ol0ocCo04coo`1<o`02o`1<o`Sooooo1Ol0FOl00ol0oc[oooooooooo`09
ooooo`?o013o1Oooool00ol0ob;o0?mBo`3fo`02o`3fo`[ooooo00?o0?n3o`3od_l0om800_l0om8D
ooooo`Go0<co1Oooool7o`3oc0[ooooo1?l0Jol2ooooo`Co08Wo<_ooool@o`1Ioaoooooo2ol0okX;
ooooo`go0?mm6oooool001Wooooo00?o0000ooooooooool0EOooool00ol0m_ooooooooooo`09oooo
o`03o`3oD_mSo`3ooooo00;o0?lX1_ooool00ol0ohoo08Woo`2Qo`06ooooo`;o0=So2?ooool00ol0
Joooooooooooo`02ooooo`03o`3od_l0j_oooooo00;ooooo0_l0ocX3ooooo`03o`3oMooooooooooo
00Cooooo0ol04?l3o`1<o`?ooooo0_mSo`04ooooo`?o0?ld00Coooooo`3<ool0c?oo0<co0_l0okX4
ooooo`?o0?lX00?oooooo`3o`?l0f?l00_l0f?lGooooo`Go0?mI00?o0?lRooooooooool00ol0olHK
ooooo`04o`3o=?l0C?oo04coo`1<o`Wooooo1?l0ocX4ooooo`Go05Wo1?ooool3o`0@o`Ko0?lR0_l0
oe82o`3fo`Wooooo1Ol0om8Cooooo`Go0<co1Oooool5o`3oc0kooooo0ol0Jol2ooooo`Co08Wo9_oo
ool@o`1IobGooooo2_l0okX00ooooooo0?mmo`3oO@0Co`3oOBSooooo000Iooooo`03o`000?oooooo
oooo05Kooooo00?o0?Koooooooooool02Oooool01?l0oe;oHol0of?o0?ooool2o`3o:0Gooooo00?o
0?n?o`29ool0XOl01oooool2o`3Ho`Oooooo00?o06_oooooooooool00oooool00ol0j_oooooooooo
o`02ooooo`?o0?lj00?oooooo`3oMol0ogL01oooool3o`0@o`?o04co2Oooool3o`3o=003ooooool0
c?oo0<co00;o0<co0_l0obP2ooooo`?o0=So00?oooooo`3o`?l0ol004_ooool5o`3oF@Kooooo1Ol0
ob83o`3oaP?o0?lR4?ooool2o`3o=0Co04co2?ooool4o`3o>PWooooo1?l0ob84o`0@o`Go05Wo0ol0
oe83o`3fo`Oooooo1?l0om8Booooo`Ko0<co1?ooool6o`3oc0oooooo1?l0Jol2ooooo`?o08Wo7ooo
ool;o`1Iobcooooo2Ol0okX;o`3oOCgooooo000Iooooo`03o`000?oooooooooo05Oooooo00?o0?Ko
ooooooooool02Oooool01Ol0oe;oooooof?o0?mSo`3ooooo00;o0?lX1?ooool00ol0ohoo08Woo`29
o`07ooooo`04o`3oOOl0f?oo0=Soo`3Ho`Gooooo0_l0Jol4ooooo`;o0>[o1Oooool2o`3o>P03oooo
ool0ogOo0?mg00Gooooo0_mSo`001?l0Vooo013oo`0@ool04?l3o`1<o`Go0?mI1?ooool3o`3o=003
o`3o:?oooooo0<co00;o0<co00?o0=Soooooooooool01?ooool2o`3o`0_ooooo1Ol0oeTCooooo`Co
0?o62Ol0ob85o`3o=0?o04co2?ooool4o`3o>Pgo0?lR1?l04?l6ooooo`?o0?mB3_l0FOl>ooooo`Oo
0<co1Oooool5o`3oc17ooooo1?l0Jol2ooooo`04o`3Zool0ROoo08Woo`29oa;ooooo4?l0FOl`oooo
o`Oo0?nj00?oooooo`3oOOl0ogd01_l0oge8ooooo`006Oooool00ol0003oooooooooo`1Hooooo`03
o`3foooooooooooo00Wooooo00?o0?mBooooooooool00_mSo`000ooooooo0?lXo`3o:003ooooo`;o
0?n?00?o08Woooooooooool01Oooool00ol0oggoooooooooo`03o`3Ho`Cooooo00?o06_ooooooooo
ool00oooool2o`3Zo`Gooooo0_l0ocX00ooooooo0?mgo`3oM`03of?o00?ooooo0_l0Vol01?oooooo
013oo`0@ool0ol`3o`1<o`;ooooo1ol0oeT3o`3Ho`03o`3oFOl0ok[o0<co00?o0<co1Ol0oeT2o`3o
`0Wo0?mI7?ooool5o`3oaPCo0?ld00?oooooo`1<ool0C?l00_l0C?l6o`3o8PGo0?lj3?ooool5o`0@
o`03o`3oMooooooooooo00?ooooo1?l0oe82ooooo`;o0?Ko0oooool4o`3odP03o`3oPooooooooooo
00?ooooo6_l0FOl>ooooobCo05Wo>Oooool7o`3o^P03ooooool0oggo0?mm00Go0?mm<oooool@o`2Q
o`gooooo000Iooooo`03o`000?oooooooooo05Wooooo00?o0?Koooooooooool02Oooool01?l0oe;o
ooooooooooooool2of?o0003ooooool0obSo0?lX00?ooooo00?o0?n?o`29ool0XOl01_ooool00ol0
oggoooooooooo`02ooooo`?o0=So0_ooool2o`1[o`Gooooo00?o0>[oo`3od_l0om801?ooool3o`3o
>P?o0?mg1Oooool2o`2Ko`05ooooool04?oo013oo`0@ool0ol`00ol0C?l00ol0obSoooooooooo`03
o`3Ho`Cooooo0ol0oc@2o`3o^PCo0<co0oooool2o`3o`1cooooo2?l0oc@4ooooo`;o0?o60ol0C?l6
ooooo`Co0?lj3Oooool4o`0@o`?o0?mg1Oooool3o`3oDP?ooooo0ol0m_l00ooooooo0?oBo`3odP02
o`3odP03o`3oPooooooooooo00Kooooo2?l0c?l6ooooo`Oo0?o<1_ooool>o`1Io`03ooooool0Jooo
06_o00;o06_o0_ooool2o`3Zo`?o08WoBOooool8o`3o^P03ooooool0oggo0?mm00Go0?mm9OoooolE
o`2Qoagooooo000Iooooo`?o0000F_ooool00ol0m_ooooooooooo`09ooooo`03o`3oD_oooooooooo
00;ooooo0omSo`001ol0obSooooooooooooooooo0?n?o`29ool0XOl01_ooool00ol0oggooooooooo
o`04ooooo`Co0=So00?o06_oooooooooool00oooool2o`3Zo`;o0?oB0_mSo`03ooooo`?o0?lj0ol0
ogL4ooooo`04o`2Koooooooo0?lXo`3o:0;o013o0_l0f?l3o`1<o`cooooo0_l0okX2o`3o=0?o0<co
0_l0oc@2o`3o`003o`3o=?oooooooooo00kooooo2Ol0oc@9ooooo`Go04co0_ooool4o`3oaP?o0?lj
3Oooool4o`0@o`?o0?mg1Oooool4o`3oDPCooooo0_l0m_l4o`3odP;o0?n30oooool8o`3<o`Oooooo
1ol0ol`Hooooo`Co06_o0_ooool3o`3Zo`?o08WoAOooool7o`3o^P03ooooool0oggo0?mm00Ko0?mm
8oooool9o`2QoaGooooo4?l0olH=ooooo`006Oooool00ol0003oooooooooo`1Kooooo`03o`3foooo
oooooooo00Wooooo00?o0?mBooooooooool01?ooool00omSo`3o0?lXo`3o:002o`3o:003o`3oSol0
ROoo0:7o00Kooooo00?o0?mmooooooooool01oooool00ol0f?oo06_oo`3Ho`03o`3Ho`;oHol00_l0
j_l2o`3odPOooooo0_l0ocX3o`3oM`04o`3o:?l0f?oo09_oo`2Ko`?o0=So0ol04?l2o`3oc0?o04co
2oooool3o`3o^P;ooooo1Ol0c?l2o`3o`0ko0?ld3Oooool5o`1<o`Gooooo1Ol0ocX00ooooooo0?o6
o`3oaP03o`3oaPKooooo1Ol04?l01?oooooo0?mgo`3oMol0ogL5ooooo`?o0?mB1Oooool3o`3fo`04
o`3od_l0oh?o0?n3o`3oP`Oo0<co2Oooool6o`3oc1_ooooo1?l0Jol2ooooo`Co0>[o0ol0ROm1oooo
o`Oo0?nj2?l0ogdTooooo`Oo0:7o1?ooool7o`3oSa?o0?o64?l0ohl=ooooo`006Oooool00ol0003o
ooooooooo`1Looooo`03o`3foooooooooooo00Wooooo00?o0?mBooooooooool02?ooool01?l0obSo
0?n?o`29ool0XOl2of?o00Cooooo0_l0ogd4ooooo`GoHol00_l0Jol00omSo`3oooooo`3Ho`0Bo`3H
o`;o0?mg00?oooooo`2Kooooool01?ooool4o`0@o`03o`3oc?l0C?oo04co00Oo04co1Oooool2o`3o
^PGooooo1_l0c?lBooooo`Go04co0oooool7o`3o>P_ooooo00?o0?o6o`0@ool04?l00ol04?l00ooo
oooo0?mgo`3oM`03o`3oM`Cooooo1?l0oe84ooooo`;o0?oB0_l0m_l7o`3<o`Wooooo1ol0ol`Moooo
o`Co06_o00?oooooo`3Zool0j_l00ol0j_l4o`29ocgooooo1ol0okX7o`3oOBGooooo1ol0XOlBo`3o
aS3ooooo000Iooooo`03o`000?oooooooooo05gooooo0_l0m_l:ooooo`03o`3oD_oooooooooo00Wo
oooo00Co0?n?o`29ool0ROoo0?n31?l0obP2of?o0004o`3oOOmSo`3oHol0of?o00Oooooo0_l0Jol5
ooooo`;o0>[o00Co0?lXo`3od_l0om;o0?oB2?ooool2o`3o>P;o0?mg0_l0Vol7ooooo`Go013o1Ooo
ool7o`1<o`;o0?nj1oooool2o`3o`0Go0<co00?oooooo`1<ool0C?l02_l0C?l8o`3o>Pgooooo1_l0
4?l00ooooooo0?mgo`3oM`04o`3oaPGooooo0ol0oe84ooooo`?o0?oB1Ol0c?l9ooooo`Oo0?o<8?oo
ool4o`1[o`03ooooool0j_oo0>[o00;o0>[o0_ooool3o`29oc[ooooo1ol0okX00ooooooo0?mmo`3o
O@04o`3oOA[ooooo2Ol0olH9o`2Qo`?o0?o6A_ooool001Wooooo00?o0000ooooooooool0Goooool0
0ol0m_ooooooooooo`08ooooo`;o0?mB2_ooool2o`3oS`03o`29ool0oh?ooooo00;ooooo0ol0obP0
1?l0oggo0?lXo`3o:?l0obP6ooooo`;o0?lX0_l0Jol5o`3o:0;o0>[o0_ooool3o`3odPSooooo0_l0
ocX00ol0ogOo09_oo`2Ko`0:ooooo`Go013o1ooooolAo`1<o`Co0<co0oooool5o`3o>Q3ooooo1Ol0
4?l2ooooo`Go0?mg1_ooool7o`3oaPSo0<co1_ooool8o`3oc2?ooooo1?l0Jol00ooooooo0>[oo`3Z
o`02o`3Zo`?ooooo0ol0ROlfooooo`Oo0?nj0oooool5o`3oO@_ooooo4ol0olH;o`2Qoe;ooooo000I
ooooo`03o`000?oooooooooo063ooooo00?o0?Koooooooooool02Oooool00ol0oe;oooooooooo`09
ooooo`04o`3oSol0ROoo0?n3o`3oP`Gooooo0_l0ogd00ooooooo0?lXo`3o:004o`3o:0Cooooo00?o
06_oooooooooool01?ooool2o`3Zo`?ooooo0ol0om89ooooo`04o`3o>_l0Vooo0?mgo`3oM`Ko0?lj
1Oooool00ol0olco013oo`0@o`03o`0@o`Oooooo0ol0okX5ooooo`?o0?o01Ol0ocX=o`3<o`_o013o
0_oooolGo`3<o`03o`3od_l0olKo0?o600?o0?Ko00?o0?o6o`3oc?l0ol`01Ol0ol`Wooooo`Co06_o
00?oooooo`3Zool0j_l00_l0j_l3ooooo`Co08Wo<Oooool8o`3o^PCooooo5_l0olH7ooooo`Co0?n?
2?l0XOmMooooo`006Oooool00ol0003oooooooooo`1Qooooo`03o`3foooooooooooo00Wooooo0_l0
oe8:ooooo`03o`3oSol0ROoooooo00;o0?n31Oooool00ol0oggoooooooooo`09ooooo`;o06_o1_oo
ool2o`3Zo`Cooooo0_l0om89ooooo`;o09_o0ol0ogL3ooooo`So0?lj0ol0ol`>o`0@o`?o0?lj00Go
ooooo`3o`?l0ol3o0?o0ooooo`0>o`0@o`Gooooo2?l0c?l00ol0ogOoooooooooo`08ooooo`?o0?mB
00?oooooo`3od_l0om800ol0om82o`3oP`04ooooool0olco0?Koo`3fo`Co0?o<0oooool;o`3oaQgo
oooo0ol0Jol00ooooooo0>[oo`3Zo`02o`3Zo`Cooooo0ol0ROl/oooooaGo0?o600?o0?mmoooooooo
ool03oooool9o`3oS`Ko0:7oIOooool001Wooooo00?o0000ooooooooool0H_ooool00ol0m_oooooo
ooooo`0:ooooo`03o`3oD_oooooooooo00Sooooo00Co0?n?o`29oooooooooooo0_l0oh<4ooooo`;o
0?mm2oooool2o`1[o`Kooooo0_l0j_l4ooooo`?o0?oB2?ooool3o`2Ko`Co0?mg2oooool;o`3oc003
ooooool0ok[o013o00Oo013o0_l0ol0?ooooo`Oo0?mg2oooool2o`3oDPGo0?oB1_l0ol`3o`3foaCo
oooo2?l0olHAooooo`Co06_o00Coooooo`3Zool0j_oo0>[o1Oooool3o`29oaoooooo4?l0olH2o`3o
^PWooooo1_l0ogd=ooooo`Wo0?n?1?ooool5o`2QoeCooooo2_l0ol0=ooooo`006Oooool00ol0003o
ooooooooo`1Sooooo`03o`3foooooooooooo00[ooooo00?o0?mBooooooooool02?ooool00ol0ohoo
08Woooooo`02ooooo`;o0?n31?ooool00ol0oggoooooooooo`0:ooooo`;o06_o1_ooool2o`3Zo`Go
oooo1?l0om87ooooo`;o09_o0_ooool9o`3oM`gooooo1ol0ol`00ol0ok[oooooooooo`02ooooo`?o
0?o01?ooool8o`3oM`kooooo1_l0om84o`3oc0Gooooo0_l0m_lOooooo`go0?o61?l0Jol00ol0olKo
0>[oo`3Zo`02o`3Zo`Co0?o61?l0ROlRo`3oaPCooooo1ol0okX;ooooo`Go0?mm3?ooool7o`3oS`Oo
oooo1_l0XOm1oooooaSo0?o05oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00009ooooo`03o`000?oooooooooo06Cooooo00?o0?Koooooooooool02_ooool2o`3oDPWooooo
00?o0?n?o`29ool0ROl00oooool3o`3oP`;ooooo00?o0?mmooooooooool02oooool2o`1[o`Kooooo
0_l0j_l7ooooo`Ko0?oB0oooool2o`2Ko`Wooooo5?l0ogLMo`3oc0Go0?oB00?o0?o<o`3oPol0oh<0
0_l0oh<7ooooo`?o0?Ko:oooool3o`1[o`03ooooool0j_oo0>[o00;o0>[o1Oooool3o`29ob?ooooo
1ol0okX<ooooo`Ko0?mm2_ooool7o`3oS`Sooooo1_l0XOlfoooooa7o0?o0;oooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0IOooool00ol0m_ooooooooooo`0;ooooo`03o`3oD_oooooooooo00Oooooo0_l0ohl2o`29o`Co
oooo0_l0oh<00ooooooo0?mmo`3oO@0=ooooo`;o06_o1_ooool2o`3Zo`_ooooo1Ol0om83o`2Koako
oooo1?l0okX4ooooo`Go0?o01?ooool8o`3odP;o0?mB1?l0oh<9ooooo`;o0?Ko:_ooool4o`1[o`04
ooooool0j_oo0>[oo`3Zo`Gooooo1?l0ROlOooooo`Oo0?nj3_ooool5o`3oO@Sooooo2?l0ohl8oooo
o`Oo0:7o;?ooool@o`3o`1Kooooo7Ol0Vol=ooooo`0000Goooooo`000?ooooooooooo`00000;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I_ooool00ol0m_ooooooooooo`0;oooo
o`;o0?mB2Oooool00ol0ohoo0:7oo`29o`05ooooo`;o0?n300?oooooo`3oOOl0ogd03Oooool2o`1[
o`Kooooo0ol0j_l>ooooo`;o0?oB0_l0Vol2o`3odQkooooo1?l0okX00ooooooo0?oBo`3odP06o`3o
dPCooooo00?o0?mBo`3oPol0oh<00ol0oh<:ooooo`?o0?Ko9oooool5o`1[o`03ooooool0j_oo0>[o
00;o0>[o1Oooool3o`29oa_ooooo2?l0okX?ooooo`Ko0?mm1_ooool7o`3oS`Wooooo1ol0XOlXoooo
o`_o0?o06oooool;o`2Kob[ooooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000oooo
ooooool01_ooool4o`0006Kooooo0_l0m_l=ooooo`;o0?mB2Oooool00ol0ohoo08Woo`29o`05oooo
o`?o0?n30_l0ogd=ooooo`;o06_o1oooool2o`3Zoa3ooooo0_l0VolSo`3odP;o0?nj1_ooool4o`3o
`003o`3oPooooooooooo00[ooooo0ol0m_lVooooo`Co06_o00?oooooo`3Zool0j_l00ol0j_l5oooo
o`Co08Wo4oooool;o`3o^Q;ooooo1Ol0ogd5ooooo`Oo0?n?2_ooool6o`2Qob3ooooo3ol0ol0Goooo
o`oo09_o=Oooool00005ooooool0003oooooooooool000001oooool4o`0000Wooooo00?o0000oooo
ooooool0JOooool00ol0m_ooooooooooo`0<ooooo`;o0?mB2?ooool2o`3oS`;o08Wo1_ooool3o`3o
P`kooooo0_l0Jol7ooooo`;o0>[o4?ooool3o`2Kob;ooooo1ol0okX3ooooo`Go0?o01_ooool2o`3f
obGooooo1?l0Jol5o`3Zo`Oooooo0ol0ROl>ooooo`Wo0?nj6?ooool5o`3oO@Cooooo1_l0ohl<oooo
o`Go0:7o5_ooool@o`3o`1Oooooo3ol0Vom4ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0J_ooool2o`3fo`kooooo0_l0oe88oooo
o`03o`3oSol0XOoo08Wo00Sooooo0ol0oh<=ooooo`?o06_o1_ooool3o`3Zoa3ooooo0_l0VolMoooo
o`Go0?n31Oooool7o`3o^P04ooooool0ol3o0?o0o`3o`0?o0?Ko8_ooool5o`1[o`Co0>[o2?ooool4
o`29o`[ooooo1ol0okXLooooo`Go0?mm1?ooool5o`3oS`cooooo1_l0XOl@ooooo`_o0?o08?ooool7
o`2Koe?ooooo0002ooooo`;o00002?ooool5o`0000Sooooo00?o0000ooooooooool0K?ooool00ol0
m_ooooooooooo`0=ooooo`;o0?mB2?ooool00ol0ohoo08Woo`29o`08ooooo`03o`3oOOl0oh?o0?n3
00?o0?n32oooool3o`1[o`Kooooo1?l0j_l>ooooo`;o09_o5_ooool5o`3oPa7ooooo0_l0okX2o`3f
o`;o0?nj1_l0ol0Iooooo`Co06_o1?l0j_l9ooooo`Co08Wo1oooool7o`3o^Qgooooo1_l0ogd4oooo
o`Go0?n?3?ooool5o`2Qo`_ooooo2ol0ol0Tooooo`Oo09_oF_ooool001Wooooo00?o0000oooooooo
ool0KOooool00ol0m_ooooooooooo`0>ooooo`;o0?mB1oooool01?l0ohoo0:7oo`29ool0ROl8oooo
o`;o0?mm0_ooool5o`3oP`Wooooo0ol0Jol7ooooo`?o0>[o3Oooool3o`2Ko`_ooooo2?l0oh<00ol0
oe;oooooooooo`0Booooo`?o0?Ko2Oooool00ol0ok[o0?o0o`3o`003o`3o`0_o0?nj1?ooool5o`1[
o`;o0>[o0_ooool:o`3o^P?o08Wo2ol0okXOooooo`Go0?mm1Oooool5o`3oS`cooooo1Ol0XOl5oooo
o`_o0?o09_ooool9o`2Kof7ooooo000Iooooo`03o`000?oooooooooo06kooooo0_l0m_l@ooooo`?o
0?mB1_ooool01?l0ohoo0:7oo`29ool0ROl8ooooo`;o0?mm1Oooool5o`3oP`Oooooo0ol0Jol7oooo
o`Go0>[o2oooool3o`2Ko`03ooooool0oh?o0?n300Go0?n31?l0oe8Fooooo`?o0?Ko4_ooool6o`3o
`0Cooooo1Ol0Jol2o`3Zo`Oo0?nj1_ooool4o`29obSooooo1Ol0ogd4ooooo`Ko0?n?2oooool2o`3o
`0Co0:7o2_l0ol0Vooooo`_o09_oJ_ooool001Wooooo00?o0000ooooooooool0L?ooool00ol0m_oo
ooooooooo`0@ooooo`Co0?mB1?ooool00ol0ohoo0:7oo`29o`09ooooo`;o0?mm2?ooool7o`3oP`?o
oooo0ol0Jol9ooooo`Ko0>[o2?l0oh<3o`2Ko`Co0?mB6?ooool3o`3foa[ooooo1Ol0Jol2o`3Zo`Go
0?o02Oooool4o`29obOooooo1Ol0ogd4ooooo`Go0?n?00?oooooo`3o`?l0ol002ol0ol05o`2Qob[o
oooo2_l0Vomeooooo`006Oooool00ol0003oooooooooo`1aooooo`;o0?Ko5?ooool5o`3oDP04oooo
ool0ohoo08Woo`29o`Wooooo0_l0ogd=ooooo`Ko0?n30ol0Jol;o`3oP`03ooooool0j_oo0>[o00?o
0>[o1Ol0oe801?oooooo09_oo`2Kool0VolFooooo`?o0?Ko5oooool6o`1[o`;o0>[o2_ooool6o`3o
`0?o08Wo2?l0ol0Mooooo`Co0?mm4Ol0ol09ooooo`Co0:7o9?ooool;o`2Kogoooooo000Iooooo`03
o`000?oooooooooo07?ooooo0_l0m_lGooooo`;o0?mB00Co0?n?o`2Qool0ROoo08Wo2Oooool2o`3o
OACooooo1Ol0Jol7ooooo`Go0?mB1Ol0j_l4ooooo`Co09_o3oooool3o`3foa;ooooo0ol0j_l5o`1[
oaCooooo1?l0ROl;ooooob7o0?o01Ol0ohlAooooo`Co0:7o7oooool9o`2Koh[ooooo000Iooooo`03
o`000?oooooooooo07Gooooo00?o0?Koooooooooool06?ooool01?l0ohoo0:7oo`29ool0ROl2o`3o
DPOooooo0_l0ogdGooooo`Ko06_o00?o0?mBooooooooool02?ooool8o`3Zo`?o09_o2Oooool3o`3f
o`_ooooo1?l0j_l9o`1[oaGooooo1?l0ROlQooooo`Ko0?mm0oooool6o`3oSa7ooooo1Ol0XOlLoooo
o`Oo09_oToooool001Wooooo00?o0000ooooooooool0M_ooool2o`3foa[ooooo00?o0?n?o`2Qool0
ROl00_l0ROl8o`3oDP?o0?mm2Oooool<o`3oDPGooooo3Ol0Jol8ooooo`03o`3Zool0Vooo09_o00?o
09_o2Ol0j_l=o`1[oaWooooo1Ol0ROlPooooo`Go0?mm1?ooool5o`3oSa;ooooo1Ol0XOlJooooo`Oo
09_oV_ooool001Wooooo0ol0001hooooo`;o0?Ko6_ooool00ol0ohoo0:7oo`2Qo`03o`29o`Gooooo
0ol0oe83o`3oO@Ko0?mB7_oooolGo`1[ob;ooooo1?l0ROlPooooo`Go0?mm0oooool6o`3oSa;ooooo
1Ol0XOlGooooo`So09_oXOooool001Wooooo00?o0000ooooooooool0N_ooool2o`3foa_ooooo0_l0
XOl01?l0ohoo08Woo`29ool0ROl8ooooo`?o0?mm:_ooool3o`3fo`Oooooo1Ol0VolMooooo`Co08Wo
7oooool5o`3oO@?ooooo1Ol0ohlCooooo`Go0:7o4Oooool;o`2KojWooooo000Iooooo`03o`000?oo
oooooooo07cooooo0_l0m_lKooooo`;o0:7o0_l0ohl2o`29o`Wooooo0ol0ogdSooooo`Co0?Ko3ooo
ool5o`2Koa?ooooo1Ol0ROlNooooo`Go0?mm0_ooool6o`3oSa;ooooo1_l0XOl<ooooo`[o09_o]?oo
ool001Wooooo00?o0000ooooooooool0O_ooool3o`3foa[ooooo0_l0XOl2o`3oS`?o08Wo2Oooool3
o`3oOAcooooo1?l0m_lHooooo`Go09_o2Oooool5o`29oakooooo1Ol0ogd7o`3oSa?ooooo1Ol0XOl7
ooooo`_o09_o__ooool001Wooooo00?o0000ooooooooool0POooool2o`3foa[ooooo0ol0XOl2o`3o
S`Co08Wo2?ooool3o`3oOAKooooo0ol0m_lQooooo`?o09_o1_l0ROl2o`2Koa[ooooo1Ol0ogd7o`3o
SaCooooo1_l0XOl00ooooooo09_oo`2Ko`09o`2KolWooooo000Iooooo`03o`000?oooooooooo08?o
oooo0ol0m_lJooooo`Co0:7o0_l0ohl6o`29o`Gooooo1Ol0ogd<ooooo`Go0?Ko8_ooool5o`29o`So
oooo3_l0Vol5ooooo`Go0?mm1ol0ohl>oooooaCo09_oe?ooool001Wooooo00?o0000ooooooooool0
Q_ooool4o`3foa[ooooo0ol0XOl3o`3oS`;ooooo1_l0ROl4ooooo`Ko0?mm00?oooooo`3fool0m_l0
0ol0m_lOooooo`So08Wo6Oooool2o`3oOAoo09_o0oooool5o`2Qon3ooooo000Iooooo`03o`000?oo
oooooooo08[ooooo1Ol0m_lHooooo`Co0:7o0_l0ohl5ooooo`Go08Wo00?oooooo`3fool0m_l00ol0
m_l5o`3oOAOooooo2?l0ROlHooooo`Oo0?mm1ol0ohlJooooo`Go0:7oiOooool001Wooooo00?o0000
ooooooooool0Soooool6o`3foaKooooo0ol0XOl3o`3oS`;ooooo1?l0m_lRo`29oa;ooooo3?l0ogd9
o`3oSacooooo1Ol0XOoZooooo`006Oooool00ol0003oooooooooo`2Eooooo`go0?Ko00?oooooo`3f
ool0m_l02Ol0m_l3o`2Qo`;o0?Ko2Ol0ohlBoooooago0?mm0_ooool:o`3oSb3ooooo1Ol0XOo_oooo
o`006Oooool00ol0003oooooooooo`2Qooooo`?o0?Ko3Oooool5o`2Qo`Kooooo1Ol0ohlTooooo`So
0?n?8_ooool8o`2QooCooooo000Iooooo`03o`000?oooooooooo0;Kooooo1_l0XOl5ooooobCo0?n?
7oooool;o`2Qoocooooo000Iooooo`?o0000_?ooool6o`2QocWooooo2Ol0XOooooooo`Sooooo000I
ooooo`03o`000?oooooooooo0<;ooooo1Ol0XOl_ooooo`Go0:7ooooooolAooooo`006Oooool00ol0
003oooooooooo`37ooooo`oo0:7o3OoooolCo`2Qoooooooo5_ooool001Wooooo00?o0000oooooooo
ool0e_ooool=o`2Qoooooooo:Oooool001Wooooo00?o0000ooooooooool0ooooooooooooo`gooooo
000Iooooo`03o`000?oooooooooo0?ooooooooooool=ooooo`006Oooool00ol0003oooooooooo`3o
oooooooooooo3Oooool001Wooooo00?o0000ooooooooool0ooooooooooooo`gooooo000Iooooo`03
o`000?oooooooooo0?ooooooooooool=ooooo`006Oooool00ol0003oooooooooo`3ooooooooooooo
3Oooool001Wooooo00?o0000ooooooooool0ooooooooooooo`gooooo0000\
\>"],
  ImageRangeCache->{{{0, 550.75}, {340, 0}} -> {-49.5875, -0.0270663, 1.9535, \
0.00172202}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(wrules = 
        Table[SIDify[Wus[i]] \[Rule] \ Wus[i], \ {i, 1, 
            ncells}];\)\)], "Input"],

Cell["\<\
Convert MathSBML form to xCellerator form: need to make these \
uniform!!!!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wsim = {MapThread[
          Rule[Wus[#1], #2] &, \ {Range[ncells], 
            Head /@ Flatten[\((\(#[t] &\) /@ WusVars)\) /. sim]}]}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{\(Wus[1]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[2]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[3]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[4]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[5]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[6]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[7]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[8]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[9]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[10]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[11]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[12]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[13]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[14]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[15]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[16]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[17]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[18]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[19]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[20]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[21]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[22]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[23]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[24]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[25]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[26]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[27]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[28]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[29]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[30]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[31]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[32]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[33]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[34]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[35]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[36]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[37]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[38]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[39]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[40]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[41]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[42]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[43]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[44]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[45]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[46]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[47]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[48]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[49]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[50]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[51]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[52]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[53]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[54]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[55]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[56]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[57]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[58]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[59]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[60]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[61]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[62]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[63]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[64]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[65]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[66]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[67]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[68]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[69]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[70]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[71]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[72]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[73]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[74]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[75]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[76]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[77]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[78]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[79]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[80]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[81]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[82]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[83]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[84]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[85]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[86]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[87]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[88]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[89]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[90]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[91]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[92]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[93]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[94]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[95]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[96]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[97]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[98]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[99]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[100]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[101]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[102]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[103]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[104]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[105]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[106]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[107]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[108]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[109]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[110]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[111]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[112]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[113]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[114]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[115]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[116]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[117]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[118]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[119]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[120]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[121]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[122]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[123]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[124]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[125]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[126]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[127]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[128]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[129]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[130]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[131]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[132]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[133]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[134]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[135]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[136]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[137]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[138]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[139]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[140]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[141]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[142]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[143]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[144]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[145]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[146]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[147]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[148]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[149]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[150]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[151]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[152]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[153]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[154]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[155]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[156]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[157]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[158]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[159]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[160]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[161]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[162]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[163]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[164]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[165]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[166]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[167]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[168]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[169]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[170]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[171]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[172]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[173]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[174]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[175]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[176]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[177]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[178]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[179]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[180]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[181]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[182]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[183]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[184]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[185]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[186]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[187]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[188]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[189]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[190]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[191]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[192]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[193]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[194]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[195]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[196]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[197]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[198]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[199]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[200]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[201]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[202]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[203]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[204]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[205]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[206]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[207]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[208]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[209]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[210]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[211]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[212]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[213]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[214]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[215]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[216]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[217]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[218]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[219]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[220]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[221]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[222]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[223]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[224]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[225]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[226]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[227]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[228]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[229]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[230]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[231]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[232]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[233]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[234]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[235]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[236]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[237]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[238]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[239]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[240]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[241]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[242]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[243]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[244]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[245]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[246]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[247]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[248]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[249]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[250]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[251]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[252]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}], ",", 
          RowBox[{\(Wus[253]\), "\[Rule]", 
            TagBox[\(InterpolatingFunction[{{0.`, 1000.`}}, "<>"]\),
              False,
              Editable->False]}]}], "}"}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(animation[wsim, \ {Wus, \ 0, \  .5}, \ {0, \ 1000, \ 10}, \ 
      cellCoordinates \[Rule] \ xymeristem, 
      RGBColors \[Rule] \ {{1, 0, 1}, {0, 1, 0}}, \ 
      cellNumbers \[Rule] \ False, \ wallThickness \[Rule] \ 0.001, 
      Background \[Rule] \ Blue, ImageSize \[Rule] \ 300, 
      TextStyle \[Rule] \ {FontFamily \[Rule] \ Times, \ 
          FontSize \[Rule] \ 24}]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -37.9062 0 ]
[.5 1.04444 37.9062 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -98.9063 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
126.875 23.000 moveto
(D) show
134.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
1 0 1 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
1 0 1 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
1 0 1 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
1 0 1 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
1 0 1 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
1 0 1 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
1 0 1 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
1 0 1 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
1 0 1 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
1 0 1 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
1 0 1 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
1 0 1 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
1 0 1 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
1 0 1 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
1 0 1 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
1 0 1 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
1 0 1 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
1 0 1 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
1 0 1 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
1 0 1 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
1 0 1 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
1 0 1 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
1 0 1 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
1 0 1 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
1 0 1 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
1 0 1 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
1 0 1 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
1 0 1 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
1 0 1 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
1 0 1 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
1 0 1 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
1 0 1 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
1 0 1 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
1 0 1 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
1 0 1 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
1 0 1 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
1 0 1 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
1 0 1 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
1 0 1 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
1 0 1 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
1 0 1 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
1 0 1 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
1 0 1 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
1 0 1 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
1 0 1 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
1 0 1 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
1 0 1 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
1 0 1 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
1 0 1 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
1 0 1 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
1 0 1 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
1 0 1 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
1 0 1 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
1 0 1 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
1 0 1 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
1 0 1 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
1 0 1 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
1 0 1 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
1 0 1 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
1 0 1 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
1 0 1 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
1 0 1 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
1 0 1 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
1 0 1 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
1 0 1 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
1 0 1 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
1 0 1 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
1 0 1 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
1 0 1 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
1 0 1 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
1 0 1 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
1 0 1 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
1 0 1 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
1 0 1 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
1 0 1 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
1 0 1 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
1 0 1 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
1 0 1 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
1 0 1 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
1 0 1 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
1 0 1 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
1 0 1 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
1 0 1 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
1 0 1 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
1 0 1 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
1 0 1 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
1 0 1 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
1 0 1 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
1 0 1 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
1 0 1 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
1 0 1 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
1 0 1 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
1 0 1 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
1 0 1 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
1 0 1 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
1 0 1 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
1 0 1 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
1 0 1 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
1 0 1 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
1 0 1 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
1 0 1 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
1 0 1 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
1 0 1 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
1 0 1 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
1 0 1 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
1 0 1 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
1 0 1 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
1 0 1 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
1 0 1 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
1 0 1 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
1 0 1 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
1 0 1 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
1 0 1 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
1 0 1 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
1 0 1 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
1 0 1 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
1 0 1 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
1 0 1 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
1 0 1 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
1 0 1 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
1 0 1 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
1 0 1 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
1 0 1 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
1 0 1 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
1 0 1 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
1 0 1 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
1 0 1 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
1 0 1 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
1 0 1 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
1 0 1 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
1 0 1 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
1 0 1 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
1 0 1 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
1 0 1 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
1 0 1 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
1 0 1 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
1 0 1 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
1 0 1 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
1 0 1 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
1 0 1 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
1 0 1 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
1 0 1 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
1 0 1 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
1 0 1 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
1 0 1 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
1 0 1 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
1 0 1 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
1 0 1 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
1 0 1 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
1 0 1 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
1 0 1 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
1 0 1 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
1 0 1 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
1 0 1 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
1 0 1 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
1 0 1 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
1 0 1 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
1 0 1 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
1 0 1 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
1 0 1 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
1 0 1 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
1 0 1 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
1 0 1 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
1 0 1 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
1 0 1 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
1 0 1 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
1 0 1 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
1 0 1 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
1 0 1 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
1 0 1 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
1 0 1 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
1 0 1 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
1 0 1 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
1 0 1 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
1 0 1 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
1 0 1 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
1 0 1 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
1 0 1 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
1 0 1 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
1 0 1 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
1 0 1 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
1 0 1 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
1 0 1 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
1 0 1 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
1 0 1 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
1 0 1 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
1 0 1 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
1 0 1 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
1 0 1 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
1 0 1 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
1 0 1 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
1 0 1 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
1 0 1 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
1 0 1 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
1 0 1 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
1 0 1 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
1 0 1 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
1 0 1 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
1 0 1 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
1 0 1 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
1 0 1 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
1 0 1 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
1 0 1 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
1 0 1 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
1 0 1 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
1 0 1 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
1 0 1 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
1 0 1 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
1 0 1 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
1 0 1 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
1 0 1 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
1 0 1 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
1 0 1 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
1 0 1 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
1 0 1 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
1 0 1 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
1 0 1 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
1 0 1 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
1 0 1 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
1 0 1 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
1 0 1 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
1 0 1 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
1 0 1 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
1 0 1 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
1 0 1 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
1 0 1 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
1 0 1 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
1 0 1 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
1 0 1 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
1 0 1 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
1 0 1 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
1 0 1 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
1 0 1 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
1 0 1 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
1 0 1 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
1 0 1 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
1 0 1 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
1 0 1 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo`3oool0ool0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000coo`3o00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ool0o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo
0?ooo`3o00_oo`3o0ol00003ool0o`03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo`3oool0o`06
ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:
ool0o`04o`000?oo0?ooo`3oool0o`;o00002_oo0?l2o`000003ool0ool0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0ool000002ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o00Coo`3o0_l00005ool0o`?o00001?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00003ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo`3o0_l000000ooo
0?oo0000o`000007ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ool0oooo
0?l02?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oo`000005ool0o`;o00002ooo0?l2o`0000Koo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0;ool0o`05o`000?oo0?ooo`3oool0ool0
00003_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?oo0?ooo`3oool0ool0
00000ooo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?oo0?ooo`3oo`0000?oo`3o0_l00008ool0
o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0ool000003ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo000000_o
o`3o0_l00004ool0o`03o`000?oo0?oo000000_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0
o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?oo0?ooo`3oool0o`?o0000
3ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01?oo0?l2o`0000_oo`3o1?l0
0009ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l01?l0003oo`3oo`00
0?l00003ool0o`;o00003?oo0?l2o`00013oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l01?l0003oo`3o
ool0oooo0?l5o`0000Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Goo`3o0_l00008ool0o`;o00000_oo0?l00ol0003oo`3oool0o`0=ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00;o0000
3Ooo0?l00ol0003oo`3oool0o`07ool0o`Ko00000_oo0?l4o`0000goo`3o00?o0000ool0oooo0?l0
1ooo0?l2o`0000Goo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000ool0ool000003ooo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l3o`0000Woo`3o00?o
0000ool0oooo0?l02_oo0?l2o`000003ool0ool0003o000000Ooo`3o00?o0000ool0oooo0?l02ooo
0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol00005
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00Co0000ool0oooo0?ooo`3o1Ol00003ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ool0oooo0?l02ooo0?l2o`0000ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0:
ool0o`?o000000?oo`3oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ool0oooo0?l03_oo0?l3o`0000Soo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?oo0?ooo`3o00Soo`3o0ol000000ooo
0?oo0000ool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o2ol0000;ool0o`Go00003?oo0?l00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo`3oo`000?oo0?oo0000
00Soo`3o0ol00005ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`0=ool0o`;o00004?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo`3oool0oooo0?l2o`00
00Goo`3o0ol00009ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00goo`3o00Co0000ool0oooo0?oo00003ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Woo`3o1?l0000;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oo`000002o`00
00coo`3o00Co0000ool0ool0003o00002Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00goo`3o00Go0000ool0oooo0?ooo`3oo`00000=ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00;oo`3o0_l00007ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l2o`0000?o
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o00Woo`3o0_l000000ooo0?oo0000ool0o`0<ool0o`?o00003_oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000?oo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l00006ool0o`;o00002_oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`?o00002_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l01?l0
003oo`3oool0oooo0?l2o`0000koo`3o0_l00006ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00coo`3o0ol0000=
ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0@ool0o`Co00004_oo0?l00ol0
003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`000005
ool0o`Oo00003?oo0?l01Ol0003oo`3oool0oooo0?oo000000coo`3o00?o0000ool0oooo0?l02?oo
0?l3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0=
ool0o`?o000000Coo`3oo`000?l0003o00004ooo0?l2o`0000;oo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003oo`3oo`000006o`0000Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0
o`03ool0o`;o00002?oo0?l3o`0000Koo`3o1?l00002ool0o`03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003oo`3oo`000?oo0?l3o`0000goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0
o`0;ool0o`?o00000ooo0?l01Ol0003oo`3oo`000?oo0?oo000001Coo`3o00?o0000ool0ool00000
4ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00008ool0o`03o`00
0?oo0?ooo`3o00Go00000ooo0?l00ol0003oo`3oool0o`03o`0000Ooo`3o00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?oo0?ooo`3oo`0000Coo`3o0ol0000:ool0o`03o`000?oo0?ooo`3o00?oo`3o
00?o0000ool0oooo0?l02Ooo0?l3o`0000Goo`3o00Co0000ool0oooo0?oo00000_oo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l00009ool0o`;o00002_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`000007ool0o`;o00001ooo0?l5o`0000;o
o`3o00?o0000ool0oooo0?l01_oo0?l3o`0000Soo`3o00Co0000ool0oooo0?oo00000ooo0?l00ol0
003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l04?oo0?l01Ol0
003oo`3oool0oooo0?oo000000coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000Coo`3o00?o0000ool0oooo0?l01ooo0?l3o`00
0004ool0ool0003o0000o`0000Goo`3o0_l00006ool0o`?o00002_oo0?l01Ol0003oo`3oool0oooo
0?oo000000Coo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0ool000003Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00?o00003Ooo0?l0
1Ol0003oo`3oool0oooo0?oo000000Goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ool0oooo0?l01Ooo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0000?ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`?o00004Ooo0?l0
0ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02_oo0?l2
o`0000?oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ool0oooo0?l01ooo0?l2o`0000_oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`;o00001_oo0?l2o`0000koo`3o00?o0000ool0
oooo0?l04ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ool0
o`03o`000?oo0?oo000000_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0;ool0
o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Dool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ool0o`04o`000?oo0?ooo`3oo`00
00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`02ool0o`;o00003?oo0?l2o`00
00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`09ool0o`04
o`000?oo0?oo0000o`00013oo`3o0_l00008ool0o`03o`000?oo0?ooo`3o01Coo`3o0ol0000;ool0
o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03Ooo0?l01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0o`;o00002_oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0
o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l01Ol00005ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l03_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0;ool0o`04
o`000?oo0?ooo`3oo`0000Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o01?oo`3o0_l00003ool0o`Co00005?oo0?l00ol0003oo`3oool0o`06ool0
o`Co000000?oo`3oo`000?oo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`09ool0o`;o00001?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Eool0o`03
o`000?oo0?oo000000Coo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o0_l0000<ool0o`03
o`000?oo0?ooo`3o00coo`3o0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3o
ool0o`06ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
ool0o`05ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l01_oo0?l3o`0000coo`3o
00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`09ool0o`Go00002Ooo0?l2o`000003ool0
ool0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003oo`3o00Woo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l00_oo
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l05ooo
0?l00ol0003oo`3oool0o`09ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`0>ool0o`Ko00001?oo
0?l00ol0003oo`3oool0o`03ool0o`Go00000_oo0?l2o`0000Coo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?oo0?ooo`3oool0ool000002ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o00Goo`3o0_l0000;ool0o`04o`000?oo0?ooo`3oo`0000_oo`3o00?o0000ool0oooo0?l0
2Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00goo`3o0ol00005ool0o`03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l4o`0000_oo`3o0_l00006ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`02ool0o`ko00001_oo0?l00ol0003oo`3oool0
o`05ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0ool000002ooo0?l00ol0003oo`3oool0
o`07ool0o`?o00006?oo0?l00ol0003oo`3oool0o`0@ool0o`?o000000?oo`3oo`000?oo0?l04?oo
0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01Ooo
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o0_l00004
ool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l00ooo0?l4o`0000;oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0oooo0?l03Ooo0?l6o`0000?oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0:ool0o`03o`000?oo0?oo000000?o00001ooo0?l00ol0003oo`3oool0o`0Dool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ool0ool000004ooo0?l4o`0000Woo`3o0_l0000<ool0o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00Co0000ool0oooo0?ooo`3o1Ol00003ool0o`03o`000?oo0?ooo`3o00go
o`3o0ol0000@ool0o`;o00006?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01ooo0?l3o`00013oo`3o00?o0000ool0oooo0?l0
1Ol00009ool0o`;o000000?oo`3oo`000?oo0?l05ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02?oo0?l2o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01_oo0?l4o`0000Coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?oo000000[oo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02?oo0?l=
o`0000[oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l4o`0000Goo`3o00?o0000ool0oooo0?l05_oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01?oo0?l2
o`0000?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo000000Koo`3o00?o0000ool0
oooo0?l05_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02?oo0?l4o`0000oo
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0;ool0o`04o`000?oo0?ooo`3oo`00
00Ooo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l00ooo0?l5o`0000?oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03
o`000?oo0?ooo`3o00[oo`3o00Go0000ool0oooo0?ooo`3oo`000007ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00;o00002?oo0?l00ol0003oo`3oool0o`08ool0o`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`Go00002Ooo0?l00ol0003o
o`3oool0o`0<ool0o`;o00003?oo0?l00ol0003oo`3oool0o`0:ool0o`05o`000?oo0?ooo`3oool0
ool000002?oo0?l00ol0003oo`3oool0o`0Dool0o`?o00001ooo0?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?oo000000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l03?oo0?l01?l0003oo`3oool0ool0000;ool0o`03o`000?oo0?ooo`3o
00_oo`3o00Co0000ool0oooo0?oo00002_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0Aool0o`?o00000ooo0?l0
0ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00goo`3o1?l0000;ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Koo`3o00Co0000ool0
oooo0?ooo`3o1?l00008ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l0
0ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00_oo0?l0
0ol0003oo`3oool0o`03ool0o`Go00002ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l00_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0
o`?o00001?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l01?oo0?l5o`0000Coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l3o`0000[oo`3o00Go0000ool0
oooo0?ooo`3oo`00000>ool0o`03o`000?oo0?ooo`3o00Coo`3o0_l00009ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l01Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l01Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l0000>ool0
o`Co00003?oo0?l2o`0000Woo`3o00?o0000ool0oooo0?l01ooo0?l01?l0003oo`3oool0ool0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`07ool0o`;o00000ooo0?l00ol0
003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02Ooo0?l4o`00
00?oo`3o0ol0000@ool0o`05o`000?oo0?ooo`3oool0ool000002_oo0?l00ol0003oo`3oool0o`0:
ool0o`Ko00000ooo0?l00ol0003oo`3oo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l00ol0
003oo`3oool0o`0:ool0o`04o`000?oo0?ooo`3oo`0000[oo`3o00?o0000ool0oooo0?l01ooo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01ooo0?l0
0ol0003oo`3oool0o`08ool0o`;o00001_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00Woo`3o00Co0000ool0oooo0?ooo`3o0ol0000Bool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
0006ool0o`;o00003Ooo0?l00ol0003oo`3oool0o`03ool0o`Go00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ool0oooo0?l00ooo0?l0
0ol0003oo`3oool0o`0<ool0o`;o00002_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o00Koo`3o0_l00002ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03ooo0?l0
0ol0003oo`3oool0o`06ool0o`;o00000ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00Ooo`3o0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Woo`3o00Go0000ool0oooo0?ooo`3oo`00000;ool0o`03o`000?oo0?ooo`3o00Coo`3o0_l00005
ool0o`05o`000?oo0?ooo`3oool0ool000002?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo0?l01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?oo0?ooo`3oo`00017oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o00Co0000ool0oooo0?oo00003?oo0?l00ol0003o
o`3oool0o`02ool0o`;o00002?oo0?l00ol0003oo`3oo`000009ool0o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000Bool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
3?oo0?l00ol0003oo`3oool0o`02o`0000_oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0;ool0o`;o00003_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0?ool0o`?o00000ooo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00Co0000ool0oooo0?ooo`3o
0_l0000:ool0o`?o00003Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0ool000000_l0000:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00coo`3o0_l0
0003ool0o`03o`000?oo0?oo0000017oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`04ool0o`;o00002?oo0?l00ol0003oo`3oool0o`0>ool0o`;o00002?oo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`0=ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00007ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00Woo`3o0_l00006ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000>ool0o`03o`000?oo0?oo
o`3o00?o00001Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol00004
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol00008ool0o`03o`000?oo0?ooo`3o
017oo`3o00Co0000ool0oooo0?ooo`3o1?l0000;ool0o`;o000000Coo`3oo`000?l0003o00000ooo
0?l2o`0000_oo`3o00?o0000ool0oooo0?l01?oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`08ool0o`Co00002_oo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00;oo`3o0_l0000<ool0o`03o`000?oo0?oo
o`3o013oo`3o1?l00003ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o3?l0000>ool0o`03o`000?oo0?oo
o`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00Co0000ool0
ool0003o00003_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`;o00001_oo0?l00ol0003oo`3oool0o`08
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000=ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`09ool0o`;o00000ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l02_oo0?l4o`0000Coo`3o00?o0000ool0oooo0?l04?oo0?l01?l0
003oo`3oo`000?l0000<ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03ooo0?l@o`0000[oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oo`00000<ool0o`05o`000?oo0?oo0000ool0ool000002_oo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol00004ool0o`?o000000?oo`3o
o`000?oo0?l04Ooo0?l01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l00ooo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07
ool0o`04o`000?oo0?ooo`3oo`0000goo`3o00Go0000ool0oooo0?ooo`3oo`000009ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`04ool0o`;o00002_oo0?l00ol0003oo`3oool0o`04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00ol0000=ool0o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ool0oooo0?l01_oo0?l2o`0000Woo`3o0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`?o00003ooo0?l0
0ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l00ooo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01Ooo0?l0
0ol0003oo`3oool0o`0;ool0o`;o00004Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09ool0o`Go00000_oo0?l00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l00ol0
003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0
003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00004ool0o`03o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Coo`3o1Ol00007ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`03ool0o`03
o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l2o`000003ool0ool0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0ool00000
1?l0000<ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
ool0o`02ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l01Ooo0?l3o`00017oo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`09ool0o`04o`000?oo0?ooo`3oo`0000[oo`3o00?o0000ool0oooo0?l0
1ooo0?l00ol0003oo`3oool0o`08ool0o`05o`000?oo0?ooo`3oool0ool000003Ooo0?l00ol0003o
o`3oool0o`0Aool0o`?o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o1Ol0000;ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo`3oool0ool0000=ool0o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l00ol0000:ool0o`Co00003Ooo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ool0oooo0?ooo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[oo`3o1Ol0000<ool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Koo`3o00?o0000ool0
oooo0?l00_oo0?l5o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l01?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l01ooo0?lEo`0000Go
o`3o00?o0000ool0oooo0?l02?oo0?l3o`00013oo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000;o
o`3o00?o0000ool0oooo0?l02?oo0?l5o`0000?oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`Co0000
3ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
1?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`;o0000
1_oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`;o0000
4?oo0?l3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oo`000002ool0o`?o00003?oo0?l01?l0003oo`3oool0
oooo0?l2o`0000coo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`02ool0o`03o`00
0?oo0?ooo`3o00Coo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0ool00000
4_oo0?l00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o
0000ool0oooo0?l01_oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000[oo`3o00?o
0000ool0ool000003ooo0?l01?l0003oo`3oo`000?l0000;ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l02?oo0?l01?l0003oo`3oo`000?l00009ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l03?oo0?l01?l0003oo`3oool0ool0000Cool0o`03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`05ool0o`?o00001_oo0?l4o`00013o
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l02_oo0?l2o`0000Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`02ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0ool000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Woo`3o00Co0000ool0oooo0?oo
o`3o0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o0ol000000ooo0?oo0000o`000004ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`03o`0000ko
o`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0
ool000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0ool000002?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l02?oo0?l2o`0000ooo`3o0_l00002ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
1ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
2ooo0?l2o`0000goo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07ool0o`04o`00
0?oo0?ooo`3oo`0000koo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`09ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000Soo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000Wo
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00Co0000ool0oooo0?oo00003?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00Koo`3o00Go0000ool0oooo0?ooo`3oo`00000>ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ool0o`03o`000?oo0?ooo`3o
00Woo`3o00Co0000ool0oooo0?oo00002Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_oo0?l3o`0000Woo`3o00?o0000ool0
oooo0?l00_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`?o00001Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`05o`000?oo0?ooo`3oool0
ool000003Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol000000ooo0?oo0000ool0o`06ool0o`03
o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0<ool0o`05
o`000?oo0?ooo`3oool0ool000002_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0ool000000_l000000ooo0?oo0000ool0o`07ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oo`00000=ool0o`Co00001Ooo0?l00ol0
003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0ool000003?oo0?l:o`0000Ooo`3o0ol00005ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l3o`000003ool0ool0003oo`3o00_o
o`3o0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`;o0000
2ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00008ool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`08ool0o`?o0000
0_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0>ool0o`04o`000?oo0?ooo`3oo`0000Woo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo`3o
o`000?l0000<ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00009ool0o`03o`000?oo0?ooo`3o00Co
o`3o1?l00006ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l00ooo0?l>o`0000goo`3o00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
0ol0000:ool0o`?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02?oo
0?l01Ol0003oo`3oool0oooo0?oo000000_oo`3o00?o0000ool0oooo0?l00ol00009ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`03ool0o`?o0000
3Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o0_l0000=ool0o`03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02?oo
0?l4o`0000coo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000Goo`3o00?o0000ool0oooo0?l01_oo
0?l01Ol0003oo`3oool0oooo0?oo000000ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3o
ool0o`06ool0o`03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l3o`0000Koo`3o0ol0
0003ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01_oo0?l3o`000003ool0ool0
003oo`3o00Woo`3o00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00Ooo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00Co0000ool0oooo0?ooo`3o
0ol0000?ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02_oo
0?l01?l0003oo`3oool0oooo0?l2o`000004ool0ool0003o0000o`0000Koo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l01ooo0?l4o`0000Soo`3o00Co0000ool0oooo0?oo00000ooo0?l2o`0000goo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l01?l0003o
o`3oool0oooo0?l7o`0000;oo`3o0_l00006ool0o`;o00003?oo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00ko
o`3o1Ol00002ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000Wo
o`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0:ool0o`;o0000
3_oo0?l3o`0000goo`3o0ol00005ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0;ool0o`;o0000
2_oo0?l2o`0000Ooo`3o0ol00009ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l>o`0000Woo`3o0ol000000ooo0?oo0000
ool0o`0:ool0o`?o00000_oo0?l00ol0003oo`3oool0o`09ool0o`;o00002Ooo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0ool000002ooo0?l2o`0000Coo`3o
00Co0000ool0oooo0?ooo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002ooo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00005ool0o`03o`000?oo0?ooo`3o00Coo`3o
1?l00006ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l02_oo0?l01Ol0003oo`3oool0oooo0?oo000000coo`3o0_l000000ooo0?oo
0000ool0o`05ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000Woo`3o00?o0000ool0oooo0?l0
0ol0000;ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol0000>ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l01_oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`?o00003Ooo
0?l4o`0000_oo`3o0ol0000?ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000ool0oooo0?l0
1ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l0
1ooo0?l3o`0000_oo`3o1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00003ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oo`00000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00Co
0000ool0oooo0?ooo`3o1Ol00002ool0o`03o`000?oo0?ooo`3o00Woo`3o00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`?o0000
00?oo`3oo`000?l000001ooo0?l00ol0003oo`3oool0o`08ool0o`?o00002_oo0?l2o`0000;oo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo
0?l4o`0000;oo`3o0_l00003ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l00006ool0o`;o00000ooo
0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Coo`3o0_l00004
ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`[o00002_oo0?l00ol0003oo`3oool0o`08
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ool0
oooo0?l03ooo0?l01?l0003oo`3oool0oooo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`0:ool0o`04o`000?oo0?oo0000o`0000Soo`3o00Co0000ool0oooo0?ooo`3o
0_l00007ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`06ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo`3oool0o`0?ool0o`04o`000?oo
0?oo0000o`0000Woo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000ool0ool000002Ooo0?l00ol0003oo`3oool0o`0>ool0o`;o0000
4_oo0?l00ol0003oo`3oool0o`09ool0o`;o00001_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l02_oo0?l2o`0000Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00
0002o`0000ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`03o`0000goo`3o00?o
0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ool0oooo0?l03ooo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02Ooo0?l2
o`0000_oo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00ooo0?l3
o`0000coo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?oo000000[oo`3o00Co0000ool0oooo0?oo00002_oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`;o00003ooo0?l00ol0003oo`3oool0o`02
ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l01_oo0?l01Ol0003oo`3oool0oooo0?oo000000Soo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`06ool0o`Co00003?oo0?l00ol0003oo`3oool0o`08
ool0o`?o00000_oo0?l3o`000003ool0ool0003oo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o00?oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00007ool0
o`;o00003_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`02ool0o`;o00002?oo0?l3o`0000;o
o`3o0_l000000ooo0?oo0000ool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l01?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Soo`3o00Co0000ool0oooo0?oo00002Ooo0?l01Ol0003o
o`3oool0oooo0?oo000000Soo`3o00Go0000ool0oooo0?ooo`3oo`00000=ool0o`;o00001?oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01ooo0?l0
0ol0003oo`3oool0o`08ool0o`Co00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?oo
o`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00009ool0
o`03o`000?oo0?oo000000_oo`3o00?o0000ool0ool000002_oo0?l00ol0003oo`3oo`00000?ool0
o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo`3oool0oooo0?l7
o`0000;oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ool0
o`03o`000?oo0?ooo`3o00Soo`3o0ol00003ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l00ooo0?l2o`0000coo`3o00?o0000ool0oooo0?l02?oo0?l<o`0000?oo`3o0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l01_oo0?l3o`0000Ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0000>ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo000000;o
00000_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo
0?l01_oo0?l3o`0000?oo`3o0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`03ool0o`?o00002ooo0?l00ol0003oo`3o
ool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00007ool0o`?o000000?oo`3oo`000?oo0?l0
3Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
2ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ool0oooo0?l00ooo0?l4o`000004ool0ool0
003o0000o`0000ooo`3o00?o0000ool0oooo0?l00ooo0?l>o`0000?oo`3o0_l00002ool0o`?o0000
1Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l0
1_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
1ooo0?l2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oo
0?oo000000;o00001?oo0?l2o`0001;oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00009ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000ool0oooo0?l02?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`?o000000?oo`3o
o`000?oo0?l02ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`09ool0o`04o`000?oo0?oo0000o`0000Koo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0<ool0o`;o00000ooo0?l2o`0000coo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`0:ool0o`Wo00002ooo0?l00ol0003oo`3oool0o`02ool0o`?o00000_oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00_oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`09ool0
o`;o00002_oo0?l2o`0000Goo`3o00?o0000ool0ool000002_oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Goo`3o0ol00009ool0o`?o00003Ooo0?l01Ol0003oo`3oool0oooo0?oo
000000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l01Ooo0?l2o`0000Ooo`3o00Co0000ool0oooo0?oo00002Ooo0?l00ol0003oo`3oool0o`06
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00Soo`3o0ol00002ool0o`Go00000_oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?oo000000coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l00_oo0?l5o`00
00Coo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00;o00002?oo0?l00ol0003oo`3oool0o`0<ool0o`Co00002_oo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ool0oooo0?l03_oo0?l01?l0003oo`3oo`000?l0000:ool0o`03o`000?oo0?ooo`3o
00;oo`3o00?o0000ool0oooo0?l00_oo0?l4o`0000Woo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l01Ol0
003oo`3oool0oooo0?oo000000[oo`3o0ol0000;ool0o`04o`000?oo0?ooo`3oool0o`Co00001Ooo
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l01?l00006ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol00002ool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l00_oo0?l3o`000003ool0ool0003oo`3o00[oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0
003oo`3oool0o`04ool0o`?o00000_oo0?l00ol0003oo`3oool0o`0:ool0o`;o00003_oo0?l00ol0
003oo`3oool0o`0;ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Koo`3o0_l00007ool0o`03o`000?oo0?oo000000;o00001Ooo0?l00ol0003o
o`3oool0o`08ool0o`?o00001?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`;o00003_oo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`03o`0000Coo`3o
0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00Co0000ool0oooo0?ooo`3o0ol000000ooo0?oo
0000ool0o`09ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01?oo0?l2o`000003ool0ool0003oo`3o00[oo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o
0ol00007ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo
0?ooo`3o00Goo`3o0ol00009ool0o`05o`000?oo0?ooo`3oool0ool000002Ooo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`06ool0o`05o`000?oo0?ooo`3oool0ool000001ooo0?l00ol0003oo`3oool0o`03ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`09ool0o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oo`000004o`0000;oo`3o00?o0000ool0oooo0?l0
1ooo0?l01?l0003oo`3oool0ool00009ool0o`;o00003Ooo0?l00ol0003oo`3oool0o`02ool0o`03
o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ool0oooo
0?l01?oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l03_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Soo`3o
00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oo`000009ool0o`04o`000?oo0?ooo`3oo`0000go
o`3o00Co0000ool0oooo0?oo00003?oo0?l01Ol0003oo`3oool0oooo0?oo000000Soo`3o0_l00005
ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oo`00000>ool0o`03o`000?oo0?oo0000
00_oo`3o00?o0000ool0oooo0?l00_oo0?l01Ol0003oo`3oool0oooo0?oo000000coo`3o00?o0000
ool0oooo0?l03_oo0?l3o`0000Woo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o
00?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00_oo`3o0_l00003ool0o`04o`000?oo0?ooo`3oo`0000[oo`3o0ol0000>ool0o`;o00000ooo0?l2
o`0000Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0
oooo0?l01ooo0?l3o`00017oo`3o00?o0000ool0oooo0?l03Ooo0?l01Ol0003oo`3oool0ool0003o
o`3o00Co00000ooo0?l5o`0000;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000Ooo`3o0_l00004
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o
00Coo`3o0ol00002ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`04o`000?oo0?oo0000
o`0000Coo`3o0ol00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0000;ool0o`;o00000_oo0?l0
0ol0003oo`3oool0o`07ool0o`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03?oo0?l6o`0000Ooo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`03o`0000Koo`3o00?o0000ool0oooo0?l03Ooo0?l01?l0
003oo`3oool0ool0000?ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o0ol00008ool0o`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oo0?l00ol0003oo`3oool0o`04ool0
o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00_oo`3o0_l00007ool0
o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00_oo0?l2o`0001;oo`3o00?o0000ool0
oooo0?l00ooo0?l3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`06ool0o`05o`000?oo0?ooo`3oool0
ool000003Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`08ool0o`;o000000?oo`3oo`000?oo0?l01ooo0?l00ol0
003oo`3oool0o`09ool0o`04o`000?oo0?oo0000o`0001Coo`3o00?o0000ool0oooo0?l00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oo`00000=ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o
00Goo`3o0_l00003ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`0Eool0o`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ool0oooo
0?l03ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l02?oo0?l00ol0003oo`3oool0o`02ool0o`;o00001_oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l03?oo0?l2o`0000coo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3o
ool0o`04ool0o`03o`000?oo0?ooo`3o00[oo`3o00Co0000ool0ool0003o00002?oo0?l00ol0003o
o`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0Aool0o`Co0000
0_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo000000;o00002?oo0?l00ol0003oo`3o
ool0o`0?ool0o`Ko00003_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Koo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o
0_l0000?ool0o`03o`000?oo0?ooo`3o00?oo`3o0ol00005ool0o`;o00004?oo0?l01_l0003oo`3o
ool0ool0003oo`3oo`0000koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0
o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04ooo0?l2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol000001?oo0?oo0000ool0oooo0?l3o`00
00coo`3o00Go0000ool0oooo0?ooo`3oo`000002ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l0000A
ool0o`?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`04ool0o`oo00003?oo0?l00ol0003oo`3oool0o`04ool0
o`?o00002?oo0?l00ol0003oo`3oool0o`02ool0o`05o`000?oo0?ooo`3oool0ool000003?oo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o3?l00002ool0o`;o00003Ooo0?l2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`02ool0
o`;o00002Ooo0?l2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`?o000000?oo`3oo`000?oo
0?l01Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Soo`3o3_l00003ool0o`;o
00002ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oo`00000;ool0o`03o`000?oo0?ooo`3o00[oo`3o
0_l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0ool000003Ooo0?l00ol0003oo`3o
ool0o`06ool0o`;o000000?oo`3oo`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o00Co
0000ool0oooo0?oo00002_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo000000koo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Koo`3o
00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l00_oo
0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo
0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00goo`3o3ol0000;
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0
003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ool0o`03o`000?oo0?ooo`3o
00Woo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Koo`3o1Ol000000ooo0?oo0000ool0o`0?ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`04o`0000Koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`?o
000000?oo`3oo`000?oo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00?o
o`3o0_l0000?ool0o`;o00003Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Coo`3o00Co0000ool0oooo0?oo
o`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00005ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00002ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ool0ool000003?oo0?l00ol0003oo`3oo`000002o`0000Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Soo`3o
1_l00004ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`04ool0o`04o`000?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003oo`3o
ool0o`03ool0o`Co00002?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Ooo`3o
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00?oo`3o00Co0000ool0oooo0?oo00003Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`06ool0o`04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
1_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0000>ool0o`?o0000
0ooo0?l00ol0003oo`3oo`00000=ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
2?oo0?l:o`0000Koo`3o0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000Ooo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`06ool0o`;o000000?oo`3oo`000?oo0?l02ooo
0?l2o`0000?oo`3o1Ol0000>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`03ool0o`Co00000_oo0?l00ol0003oo`3oool0o`0;
ool0o`03o`000?oo0?ooo`3o00?oo`3o0ol00004ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00008
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol000000ooo0?oo0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00Ooo`3o0_l0000?ool0o`03o`000?oo0?ooo`3o00;o00002?oo0?l00ol0
003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02?oo0?l01?l0
003oo`3oool0ool0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00koo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00;oo`3o0_l0000;ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00Go0000ool0oooo0?ooo`3oo`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o0_l0000<ool0o`04o`000?oo0?oo0000
o`0000goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Koo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00Co0000ool0
oooo0?oo00003?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o1?l0000;
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00koo`3o00Co0000ool0oooo0?ooo`3o1ol00003ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03_oo0?l4o`00
00_oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo
0?l03?oo0?l7o`0000Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o
1Ol00009ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00Co0000ool0oooo0?ooo`3o1Ol00004ool0o`03
o`000?oo0?ooo`3o00Woo`3o1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=ool0o`03o`000?oo0?ooo`3o00Woo`3o
0_l00009ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0?ool0o`Ko00001?oo0?l4o`0000Goo`3o0_l000000ooo0?oo0000ool0o`0;ool0o`04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?oo0?ooo`3oool0o`?o00002_oo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?oo000000;o00001ooo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00Soo`3o1Ol0000Aool0o`03o`000?oo0?ooo`3o00?oo`3o1?l0000;ool0o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000Ooo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02ool0o`?o00001Ooo0?l00ol0003oo`3o
ool0o`04ool0o`04o`000?oo0?ooo`3oool0o`Oo00001?oo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09ool0o`03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`08ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol00003ool0o`04o`000?oo0?ooo`3oool0o`Ko
00003?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ool0o`?o000000?oo`3oo`000?oo0?l0
3?oo0?l00ol0003oo`3oool0o`08ool0o`?o000000Coo`3oo`000?l0003o00000_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000=ool0o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ool0oooo0?l03?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02_oo0?l01?l0003oo`3oool0oooo0?l2o`0000[o
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00?o
000000?oo`3oo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
2Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?oo000000;o00001ooo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000Coo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00[oo`3o0ol0000;ool0o`Ko00001?oo0?l00ol0003oo`3oool0o`08
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`05
ool0o`?o000000?oo`3oo`000?oo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l01?l00006ool0o`03o`000?oo0?ooo`3o00Coo`3o1?l0000<ool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`08ool0o`Go00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01Ooo0?l3o`0000;oo`3o00?o0000ool0oooo
0?l02?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo
0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Woo`3o1?l00008ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3o
ool0o`05ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0000<ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l01?oo0?l4o`0000Coo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00_oo
0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?l0
0009ool0o`Ko00003?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ool0oooo0?ooo`3o0_l0
000=ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01Ol0003oo`3oool0
oooo0?oo000000Woo`3o00?o0000ool0oooo0?l02ooo0?l2o`0000goo`3o00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
0002ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000ool0ool000002Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`03ool0o`;o00002_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo
o`3o00Soo`3o1Ol00008ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001ooo0?l2o`0000Soo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o00?oo`3o0ol00005ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000Woo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000co
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`07ool0o`?o000000?oo`3oo`000?oo
0?l03Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l01_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?oo0?ooo`3o00Ooo`3o
0_l00004ool0o`03o`000?oo0?ooo`3o00;o00002_oo0?l00ol0003oo`3oool0o`03ool0o`;o0000
3Ooo0?l2o`0000goo`3o0ol0000=ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Soo`3o0_l0
00000ooo0?oo0000ool0o`04ool0o`03o`000?oo0?ooo`3o00Ooo`3o00Co0000ool0oooo0?ooo`3o
0_l00002ool0o`03o`000?oo0?ooo`3o00coo`3o3Ol00003ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l02?oo0?l01?l0003oo`3oool0oooo0?l4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00008ool0o`03o`000?oo0?oo000000Goo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00;oo`3o
0_l00009ool0o`03o`000?oo0?ooo`3o00[oo`3o0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01ooo0?l4o`0000?oo`3o0ol0
0007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`04ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l0
1?l0003oo`3oool0oooo0?l3o`0000;oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0
o`04ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o00Coo`3o00Go0000ool0oooo0?ooo`3oo`000008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`;o00001?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00ooo0?l0
0ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l00_oo0?l0
0ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`09ool0o`05o`000?oo0?ooo`3oool0ool000002Ooo0?l00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`03
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00Woo`3o1?l00009ool0o`03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l02?oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`06ool0o`;o00001_oo0?l8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l01Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Woo`3o00Go0000ool0oooo
0?ooo`3oo`00000<ool0o`03o`000?oo0?ooo`3o00Coo`3o0_l00008ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo
0?l00ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oo`000004o`0000Woo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000[o
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`;o0000
2ooo0?l00ol0003oo`3oool0o`03ool0o`Oo00000_oo0?l00ol0003oo`3oool0o`02o`0000_oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo`3oool0oooo0?oo000000Soo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
o`000002o`0000Soo`3o00?o0000ool0oooo0?l02_oo0?l5o`0000goo`3o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?oo0?oo000000Woo`3o00?o
0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`03ool0o`?o00001?oo0?l00ol0003oo`3oool0
o`0=ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol000000ooo0?oo0000ool0o`0>ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?oo0?ooo`3o00;oo`3o1_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`07ool0o`?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l00ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo
0?l01Ooo0?l2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00_oo`3o5?l00004ool0o`;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ool0o`04o`000?oo0?ooo`3oo`0000koo`3o
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_oo0?l00ol0003oo`3oo`00000>ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Woo`3o1Ol0
000Bool0o`;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00;oo`3o1ol00004ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00coo`3o1?l0000<ool0o`03o`000?oo0?ooo`3o00coo`3o0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo
0?l02Ooo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000ooo0?l2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0ool000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00W_l00?l5oooo013o003o1Oooo`1co`00o`7ooooo002N
o`00o`;oool000?o<S;<o`00ool00?l04_l00?l00olb</coool0oooo001co`00o`7ooooo002No`00
o`;oool05_l00?l2oooo07?o003o0Oooool009ko003o0_ooo`0Fo`00o`;oool0Lol00?l1ooooo`00
N?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool02Ol00?l2oooo07?o003o0Oooool007So003o0_oo
o`06o`00o`;oool02Ol00?l2oooo00?o003o1?ooo`02o`00o`;oool00ol00?l2oooo0003o`00oooo
o`3oool000So003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1co`00o`7ooooo001h
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Lol00?l1
ooooo`00Mol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00Oo003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1co`00o`7ooooo001go`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000Oo003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Lol00?l1ooooo`00Mol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Lol00?l1ooooo`00M_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo07?o003o0Oooool007Ko003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo07?o003o0Oooool007Ko003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo07?o003o0Oooool007Go003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0Lol00?l1ooooo`00MOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool01_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Lol00?l1ooooo`00MOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1co`00
o`7ooooo001do`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00Ko
003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1co`00o`7ooooo001do`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0
Lol00?l1ooooo`00M?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_oo
o`000olb</co003oo`00o`04o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Lol0
0?l1ooooo`00Lol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05
o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1co`00o`7ooooo001bo`00o`Koool000?o003ooooo
0?ooo`001Oooo`03o`00o`Goool08Ol00?l4oooo07ko003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(10) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.982 .018 .982 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.981 .019 .981 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.981 .019 .981 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.981 .019 .981 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.935 .065 .935 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.982 .018 .982 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.931 .069 .931 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.955 .045 .955 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.951 .049 .951 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.985 .015 .985 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.937 .063 .937 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.982 .018 .982 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.954 .046 .954 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.943 .057 .943 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.981 .019 .981 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.954 .046 .954 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.938 .062 .938 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.985 .015 .985 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.984 .016 .984 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.93 .07 .93 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.948 .052 .948 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.887 .113 .887 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.923 .077 .923 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.923 .077 .923 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.925 .075 .925 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.957 .043 .957 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.948 .052 .948 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.982 .018 .982 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.93 .07 .93 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.94 .06 .94 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.927 .073 .927 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.938 .062 .938 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.952 .048 .952 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.982 .018 .982 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.956 .044 .956 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.931 .069 .931 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.966 .034 .966 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.949 .051 .949 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.924 .076 .924 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.981 .019 .981 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.96 .04 .96 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.944 .056 .944 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.951 .049 .951 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.945 .055 .945 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.92 .08 .92 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.938 .062 .938 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.93 .07 .93 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.981 .019 .981 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.929 .071 .929 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.911 .089 .911 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.963 .037 .963 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.966 .034 .966 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.934 .066 .934 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.931 .069 .931 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.953 .047 .953 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.981 .019 .981 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.96 .04 .96 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.956 .044 .956 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.945 .055 .945 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.862 .138 .862 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.927 .073 .927 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.952 .048 .952 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.963 .037 .963 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.92 .08 .92 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.899 .101 .899 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.903 .097 .903 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.915 .085 .915 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.958 .042 .958 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.917 .083 .917 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.938 .062 .938 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.932 .068 .932 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.952 .048 .952 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.956 .044 .956 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.949 .051 .949 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.954 .046 .954 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.983 .017 .983 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.921 .079 .921 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.936 .064 .936 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.913 .087 .913 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.982 .018 .982 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.962 .038 .962 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.946 .054 .946 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.899 .101 .899 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.921 .079 .921 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.956 .044 .956 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.937 .063 .937 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.937 .063 .937 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.951 .049 .951 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.905 .095 .905 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.935 .065 .935 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.941 .059 .941 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.932 .068 .932 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.955 .045 .955 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.959 .041 .959 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.958 .042 .958 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.909 .091 .909 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.932 .068 .932 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.956 .044 .956 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.939 .061 .939 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.939 .061 .939 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.944 .056 .944 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.936 .064 .936 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.927 .073 .927 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.918 .082 .918 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.982 .018 .982 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.92 .08 .92 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.946 .054 .946 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.927 .073 .927 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.94 .06 .94 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.954 .046 .954 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.982 .018 .982 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.958 .042 .958 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.948 .052 .948 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.951 .049 .951 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.957 .043 .957 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.939 .061 .939 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.932 .068 .932 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.942 .058 .942 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.944 .056 .944 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.983 .017 .983 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.965 .035 .965 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.952 .048 .952 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.965 .035 .965 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.924 .076 .924 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.924 .076 .924 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.899 .101 .899 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.935 .065 .935 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.934 .066 .934 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.957 .043 .957 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.967 .033 .967 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.919 .081 .919 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.981 .019 .981 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.945 .055 .945 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.939 .061 .939 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.953 .047 .953 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.953 .047 .953 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.942 .058 .942 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.951 .049 .951 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.963 .037 .963 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.922 .078 .922 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.942 .058 .942 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.954 .046 .954 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.977 .023 .977 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.92 .08 .92 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.941 .059 .941 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.953 .047 .953 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.955 .045 .955 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.983 .017 .983 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.93 .07 .93 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.982 .018 .982 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.959 .041 .959 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.962 .038 .962 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.955 .045 .955 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.937 .063 .937 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.923 .077 .923 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.942 .058 .942 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.941 .059 .941 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.96 .04 .96 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.963 .037 .963 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.963 .037 .963 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.949 .051 .949 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.977 .023 .977 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.947 .053 .947 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.938 .062 .938 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.911 .089 .911 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.913 .087 .913 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.939 .061 .939 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.948 .052 .948 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.982 .018 .982 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.95 .05 .95 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.945 .055 .945 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.909 .091 .909 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.957 .043 .957 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.963 .037 .963 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.936 .064 .936 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.982 .018 .982 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.93 .07 .93 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.95 .05 .95 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.946 .054 .946 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.982 .018 .982 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.939 .061 .939 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.947 .053 .947 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.956 .044 .956 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.952 .048 .952 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.935 .065 .935 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.98 .02 .98 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.936 .064 .936 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.967 .033 .967 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.939 .061 .939 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.907 .093 .907 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.902 .098 .902 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.922 .078 .922 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.948 .052 .948 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.95 .05 .95 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.958 .042 .958 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.963 .037 .963 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.958 .042 .958 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.982 .018 .982 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.977 .023 .977 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.941 .059 .941 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.982 .018 .982 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.944 .056 .944 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.96 .04 .96 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.948 .052 .948 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.949 .051 .949 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.962 .038 .962 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.961 .039 .961 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.951 .049 .951 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.982 .018 .982 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.955 .045 .955 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.955 .045 .955 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.981 .019 .981 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.977 .023 .977 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.984 .016 .984 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.981 .019 .981 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.972 .028 .972 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.983 .017 .983 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.952 .048 .952 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.983 .017 .983 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.919 .081 .919 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.945 .055 .945 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.932 .068 .932 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.97 .03 .97 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.964 .036 .964 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.957 .043 .957 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.97 .03 .97 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.959 .041 .959 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.96 .04 .96 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.958 .042 .958 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.942 .058 .942 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.938 .062 .938 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.985 .015 .985 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.944 .056 .944 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.938 .062 .938 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.983 .017 .983 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.945 .055 .945 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.963 .037 .963 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.944 .056 .944 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.945 .055 .945 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.966 .034 .966 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.914 .086 .914 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.983 .017 .983 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.983 .017 .983 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.981 .019 .981 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.951 .049 .951 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.982 .018 .982 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.982 .018 .982 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.983 .017 .983 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.983 .017 .983 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.983 .017 .983 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.982 .018 .982 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003ol`ccoo<<lol0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000oo<<looc3?<00_oc3?<00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oc3??ol`cc00?ol`cc00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000oo<<looc3?<01Ooc3?<00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ol`ccoo<<l`06oo<<l`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000oo<<looc3?<02?oc3?<00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?o_4>oo0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000col`cc00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003onl@k`03o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003om@[eooD:m@05ooD:m@03o`000?oc
3??ol`cc00_ol`cc0ol00003oo@;m003o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
onl@koo_4>l00oo_4>l00ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003om@[eooD:m@06
ooD:m@03o`000?oc3??ol`cc00[ol`cc00?o0000oo@;m?od2o@01?od2o@00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?of2OKomPWfooH9mP;o00002_ok1?/2o`000003ooH9m_l0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?ok1?_o
n`Ck00Won`Ck00?o0000on`Ck?l000002ook1?/00ol0003om@[eooD:m@06ooD:m@03o`000?oc3??o
l`cc00Wol`cc00?o0000oo@;m?od2o@01_od2o@00ol0003on`Ckoo/4n`08oo/4n`03o`000?of2OKo
mPWf00ComPWf0_l00005oo/4n`?o00001?of2OH00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008onl@k`03o`000?ok1?_on`Ck00Oon`Ck0_l00003on`C
k003o`000?ok1?_on`Ck00Oon`Ck00?o0000ooD:mOoe2_D01ooe2_D00ol0003ol`ccoo<<l`09oo<<
l`03o`000?od2oCom0_d00Oom0_d00?o0000oo/4nook1?/01Ook1?/2o`0000WomPWf0_l000000ook
1?_o0000o`000007ooH9mP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000onl@koo_
4>l02?o_4>l00ol0003on`Ckoo/4n`06oo/4n`03o`000?o/4ncok1?/00?ok1?/00?o0000oo/4nook
1?/01ook1?/00ol0003om@[eooD:m@08ooD:m@03o`000?oc3??ol`cc00Ool`cc00?o0000oo@;m?od
2o@02Ood2o@00ol0003on`Ckoo/4n`03oo/4n`03o`000?of2OKomPWf00_omPWf00?o0000ooH9m_of
2OH01oof2OH00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003ol@kao`000005oo/4n`;o00002oo_4>l2o`0000Kon`Ck
00?o0000on`Ck?o/4n`01Oo/4n`00ol0003on`Ckoo/4n`06oo/4n`03o`000?oe2_Gom@[e00Som@[e
00?o0000oo<<looc3?<01_oc3?<00ol0003om0_doo@;m00;oo@;m005o`000?ok1?_on`Ckoo/4nol0
00003_of2OH00ol0003omPWfooH9mP08ooH9mP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oa3_7ol@kaoo4>lOl0
00000ook1?/00ol0003oka3_onl@k`0:onl@k`04o`000?oe2_Gom@[eo`0000?on`Ck0_l00008on`C
k003o`000?ok1?_on`Ck00Kon`Ck00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ol`ccoo<<l`05oo<<
l`03o`000?od2oCom0_d00com0_d00?o0000oo/4nol000003oof2OH00ol0003omPWfooH9mP08ooH9
mP03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003ol@kaoo4>l@03oo4>l@03o`000?ok1?_o000000_o
ka3_0_l00004ooD:m@03o`000?ok1?_o000000_ok1?/00?o0000oo/4nook1?/01Ook1?/00ol0003o
m@[eooD:m@09ooD:m@03o`000?oc3??ol`cc00Col`cc00?o0000oo@;m?od2o@03_od2o@00ol0003o
mPWfooH9mP0>ooH9mP03o`000?of2OKomPWf00WomPWf00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000oo4>lOoa3_40
1?oa3_400ol0003oka3_onl@k`09onl@k`03o`000?oe2_Gom@[e00Gom@[e00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003on`Ckoo/4n`05oo/4n`03o`000?oe2_Gom@[e00[om@[e00?o0000oo<<looc3?<0
0ooc3?<00ol0003om0_doo@;m00>oo@;m003o`000?of2OKomPWf00gomPWf00?o0000ooH9m_of2OH0
2_of2OH00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ol@kaoo4>
l@05oo4>l@03o`000?o_4>ooka3_00Ooka3_0_l00008ooD:m@03o`000?o/4ncok1?/00_ok1?/00?o
0000oo/4nook1?/01?ok1?/00ol0003om@[eooD:m@0:ooD:m@04o`000?oc3??ol`ccoo<<l`?o0000
3ood2o@00ol0003omPWfooH9mP0>ooH9mP03o`000?of2OKomPWf00[omPWf00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oa3_7ol@ka00Ool@ka00?o0000onl@koo_4>l01?o_4>l2o`0000_om@[e1?l0
0009on`Ck003o`000?ok1?_on`Ck00?on`Ck00?o0000ooD:mOoe2_D02ooe2_D01?l0003ol`cco`00
0?l00003ooH9mP;o00003?od2o@2o`00013omPWf00?o0000ooH9m_of2OH02oof2OH00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003ol@ka
oo4>l@07oo4>l@03o`000?o_4>ooka3_00?oka3_00?o0000ooD:mOoe2_D02ooe2_D01?l0003om`Sg
ooL8moog2?L5o`0000Gok1?/00?o0000oo/4nook1?/00_ok1?/00ol0003om@[eooD:m@0<ooD:m@03
o`000?of2OKomPWf00GomPWf0_l00008oo@;m0;o00000_oe2_D00ol0003omPWfooH9mP0=ooH9mP03
o`000?of2OKomPWf00_omPWf00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003ol@kaoo4>l@09oo4>l@03o`000?o_4>ooka3_00;o0000
3Ooe2_D00ol0003om`SgooL8m`07ooL8m`Ko00000_ok1?/4o`0000gom@[e00?o0000ooH9m_of2OH0
1oof2OH2o`0000Gom0_d00?o0000ooD:mOoe2_D00ooe2_D00ol0003omPWfooH9mP0<ooH9mP03o`00
0?of2OKomPWf00comPWf00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oa3_7ol@ka00Wol@ka00?o
0000onl@kol000003ooe2_D00ol0003om`SgooL8m`0<ooL8m`?o00001?of2OH3o`0000Wom@[e00?o
0000ooH9m_of2OH02_of2OH2o`000003oo@;m?l0003o000000Oom@[e00?o0000ooH9m_of2OH02oof
2OH00ol0003omPWfooH9mP0<ooH9mP03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oa3_7ol@ka00_ol@ka00?o0000
ooD:mOoe2_D03_oe2_D00ol0003om`SgooL8m`0=ooL8m`03o`000?of2OKomPWf00KomPWf0ol00005
ooD:m@03o`000?of2OKomPWf00gomPWf00?o0000ooD:mOoe2_D02?oe2_D00ol0003omPWfooH9mP09
ooH9mP03o`000?of2OKomPWf00gomPWf00Co0000oo/4nook1?_on`Ck1Ol00003ooH9mP03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
oo4>lOoa3_402ooa3_42o`0000oom@[e00?o0000ooL8moog2?L03Oog2?L00ol0003omPWfooH9mP0:
ooH9mP?o000000?om@[eo`000?of2OH03oof2OH00ol0003om@[eooD:m@09ooD:m@03o`000?of2OKo
mPWf00SomPWf00?o0000ooH9m_of2OH03_of2OH3o`0000SomPWf00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oa3_7ol@ka00Sol@ka0ol000000ooc
3??o0000ooD:m@0>ooD:m@03o`000?og2?Oom`Sg00gom`Sg00?o0000ooH9m_of2OH03Oof2OH00ol0
003omPWfooH9mP0?ooH9mP03o`000?oe2_Gom@[e00[om@[e2ol0000;ooH9mPGo00003?of2OH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02_ok1?/01Ol0003om@[eo`000?ok1?_o0000
00Sol@ka0ol00005oo<<l`03o`000?oe2_Gom@[e00com@[e00?o0000ooL8moog2?L03Oog2?L00ol0
003omPWfooH9mP0=ooH9mP;o00004?of2OH00ol0003om@[eooD:m@0:ooD:m@03o`000?of2OKomPWf
00OomPWf00?o0000ooH9m_of2OH00_of2OH7o`0000Com0_d00?o0000ooH9m_of2OH02_of2OH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02Ook1?/01?l0003om@[eooD:mOoe2_D2o`00
00Gol@ka0ol00009oo<<l`;o00002ooe2_D00ol0003om`SgooL8m`0=ooL8m`03o`000?of2OKomPWf
00gomPWf00Co0000ooX5n_oj1O[o00003oof2OH00ol0003om@[eooD:m@09ooD:m@03o`000?of2OKo
mPWf00WomPWf1?l0000;oo@;m003o`000?of2OKomPWf00[omPWf00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?ok1?_on`Ck00Son`Ck00?o0000ooD:mOoe2_D01?oe2_D00ol0003ol@kao`000002o`00
00col`cc00Co0000ooH9m_l0003o00002Ooe2_D00ol0003om`SgooL8m`0=ooL8m`03o`000?of2OKo
mPWf00gomPWf00Go0000ooX5n_oj1O[onPGjo`00000=ooH9mP03o`000?oe2_Gom@[e00[om@[e00?o
0000ooH9m_of2OH02Oof2OH00ol0003om0_doo@;m00<oo@;m003o`000?of2OKomPWf00[omPWf00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000ooD:mOoe2_D01_oe2_D0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?of2OKomPWf00;omPWf0_l00007ooD:m@03o`000?og2?Oo
m`Sg00com`Sg00?o0000ooH9m_of2OH03Oof2OH00ol0003onPGjooX5nP03ooX5nP03o`000?of2OKo
mPWf00[omPWf00?o0000ooD:mOoe2_D02_oe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCo
m0_d00com0_d00?o0000ooH9m_of2OH02oof2OH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4
nook1?/01_ok1?/00ol0003om@[eooD:m@06ooD:m@03o`000?oc3??ol`cc00_ol`cc00?o0000ooH9
m_of2OH01Oof2OH00ol0003om@[eooD:m@03ooD:m@03o`000?og2?Oom`Sg00gom`Sg00?o0000ooH9
m_of2OH03Oof2OH00ol0003onPGjooX5nP04ooX5nP03o`000?of2OKomPWf00WomPWf00?o0000ooD:
mOoe2_D02Ooe2_D00ol0003omPWfooH9mP0:ooH9mP03o`000?od2oCom0_d00com0_d00?o0000ooH9
m_of2OH02oof2OH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook1?/01Ook1?/00ol0003o
m@[eooD:m@07ooD:m@03o`000?oc3??ol`cc00_ol`cc00?o0000ooH9m_of2OH01_of2OH2o`0000?o
m@[e00?o0000ooL8moog2?L03Oog2?L00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooH9m_of2OH02?of2OH00ol0003om@[eooD:m@09ooD:m@03o`000?of2OKomPWf00[o
mPWf00?o0000oo@;m?od2o@03?od2o@00ol0003omPWfooH9mP0;ooH9mP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?ok1?_on`Ck00Con`Ck00?o0000ooD:mOoe2_D02?oe2_D00ol0003ol`ccoo<<l`0:oo<<l`03o`00
0?of2OKomPWf00WomPWf0_l000000ooe2_Go0000ooL8m`0<ooL8m`?o00003_of2OH00ol0003onPGj
ooX5nP07ooX5nP03o`000?of2OKomPWf00OomPWf00?o0000ooD:mOoe2_D02Ooe2_D00ol0003omPWf
ooH9mP0;ooH9mP03o`000?od2oCom0_d00com0_d00?o0000ooH9m_of2OH02_of2OH00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000ooD:mOoe2_D02_oe2_D00ol0003ol`ccoo<<
l`09oo<<l`03o`000?of2OKomPWf00_omPWf00?o0000ooL8moog2?L02_og2?L2o`0000?om`Sg00?o
0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?of2OKomPWf00KomPWf00?o
0000ooD:mOoe2_D02?oe2_D00ol0003omPWfooH9mP0<ooH9mP03o`000?od2oCom0_d00com0_d00?o
0000ooH9m_of2OH02_of2OH00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ook1?/0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oe2_Gom@[e00_om@[e00?o0000oo<<looc3?<02?oc3?<0
0ol0003omPWfooH9mP0<ooH9mP03o`000?og2?Oom`Sg00Som`Sg0_l00006ooL8m`;o00002_of2OH0
0ol0003onPGjooX5nP0:ooX5nP03o`000?of2OKomPWf00GomPWf00?o0000ooD:mOoe2_D02?oe2_D0
0ol0003omPWfooH9mP0<ooH9mP03o`000?od2oCom0_d00com0_d00?o0000ooH9m_of2OH02oof2OH0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?on`Ck00Go0000oo/4nook1?_on`Cko`00000=
ooD:m@03o`000?oc3??ol`cc00Ool`cc00?o0000ooH9m_of2OH03_of2OH00ol0003om`SgooL8m`04
ooL8m`?o00002_og2?L00ol0003omPWfooH9mP07ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000
ooH9m_of2OH00oof2OH00ol0003om@[eooD:m@09ooD:m@03o`000?of2OKomPWf00comPWf00?o0000
oo@;m?od2o@03?od2o@00ol0003omPWfooH9mP0;ooH9mP;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003om@[eooD:m@0<ooD:m@03o`000?oc3??ol`cc00Ool`cc00?o0000ooH9m_of2OH03oof2OH01?l0
003om`SgooL8moog2?L2o`0000kom`Sg0_l00006ooH9mP03o`000?oj1O[onPGj00gonPGj00?o0000
ooH9m_of2OH00_of2OH00ol0003om@[eooD:m@08ooD:m@03o`000?of2OKomPWf00comPWf0ol0000=
oo@;m003o`000?of2OKomPWf00_omPWf00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oom@[e00?o0000oo<<looc3?<01_oc3?<00ol0003omPWfooH9mP0@ooH9mPCo00004_og2?L00ol0
003omPWfooH9mP03ooH9mP03o`000?oj1O[onPGj00konPGj00Go0000ooH9m_of2OKomPWfo`000005
ooD:m@Oo00003?of2OH01Ol0003ol`ccoo<<looc3??o000000com0_d00?o0000ooH9m_of2OH02?of
2OH3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oom@[e00?o0000oo<<looc3?<01_oc3?<00ol0003omPWfooH9mP0=
ooH9mP?o000000Com0_do`000?l0003o00004oog2?L2o`0000;omPWf00?o0000ooX5n_oj1OX04?oj
1OX00ol0003omPWfo`000006o`0000OonPGj00?o0000ooH9m_of2OH02?of2OH00ol0003ol`ccoo<<
l`03oo<<l`;o00002?od2o@3o`0000KomPWf1?l00002ooL8m`03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003okQ7^o`000?od2o@3o`0000gom@[e00?o0000oo<<looc3?<01?oc3?<00ol0003omPWfooH9
mP0;ooH9mP?o00000ood2o@01Ol0003om0_do`000?oe2_Go000001Com`Sg00?o0000ooH9m_l00000
4ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?of2OKomPWf00GomPWf0_l00008oo<<l`03o`00
0?od2oCom0_d00Go00000ooe2_D00ol0003omPWfooH9mP03o`0000Oom`Sg00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?o^4NkokQ7^o`0000Com0_d0ol0000:ooD:m@03o`000?oc3??ol`cc00?ol`cc
00?o0000ooH9m_of2OH02Oof2OH3o`0000Gom0_d00Co0000oo@;m?od2oCo00000_oe2_D00ol0003o
m`SgooL8m`0BooL8m`03o`000?oj1O[onPGj01;onPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
mPWfooH9mP03ooH9mP03o`000?oc3??ol`cc00Wol`cc0_l00009ooD:m@;o00002_og2?L00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000onhAk_o^4NkokQ7^o`000007oo@;m0;o00001ooe2_D5o`0000;o
l`cc00?o0000ooH9m_of2OH01_of2OH3o`0000Som0_d00Co0000oo@;m?od2oCo00000ooe2_D00ol0
003om`SgooL8m`0AooL8m`03o`000?oj1O[onPGj017onPGj00?o0000ooX5n_oj1OX04?oj1OX01Ol0
003omPWfooH9m_of2OKo000000col`cc00?o0000ooD:mOoe2_D02?oe2_D00ol0003om`SgooL8m`0:
ooL8m`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000CokQ7^00?o0000oo@;m?od2o@01ood2o@3o`00
0004ooD:mOl0003o0000o`0000Gom@[e0_l00006ooH9mP?o00002_od2o@01Ol0003om0_doo@;m?od
2oCo000000Com@[e00?o0000ooL8moog2?L04?og2?L00ol0003onPGjooX5nP0AooX5nP03o`000?oj
1O[onPGj017onPGj00?o0000ooH9m_l000003Ooc3?<00ol0003om@[eooD:m@08ooD:m@03o`000?og
2?Oom`Sg00[om`Sg00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o^4NkokQ7^00CokQ7^00?o0000
oo@;m?od2o@02_od2o@00ol0003om@[eooD:m@08ooD:m@03o`000?of2OKomPWf00?o00003Ood2o@0
1Ol0003om0_doo@;m?od2oCo000000Gom@[e00?o0000ooL8moog2?L03oog2?L00ol0003onPGjooX5
nP0AooX5nP03o`000?oj1O[onPGj01;onPGj00?o0000oo<<looc3?<03?oc3?<00ol0003om@[eooD:
m@08ooD:m@03o`000?og2?Oom`Sg00_om`Sg00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000onhAk_o^4Nh01Oo^4Nh0
0ol0003om0_doo@;m00:oo@;m003o`000?oe2_Gom@[e00Wom@[e0_l0000?oo@;m003o`000?od2oCo
m0_d00;om0_d00?o0000ooD:mOoe2_D01?oe2_D00ol0003om`SgooL8m`0=ooL8m`?o00004Ooj1OX0
0ol0003onPGjooX5nP0CooX5nP03o`000?oc3??ol`cc00_ol`cc00?o0000ooD:mOoe2_D02Ooe2_D0
0ol0003om`SgooL8m`0;ooL8m`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo/4n`;o00002?o^4Nh0
0ol0003om0_doo@;m00:oo@;m003o`000?oe2_Gom@[e00Wom@[e00?o0000oo@;m?od2o@03Ood2o@0
0ol0003om0_doo@;m003oo@;m003o`000?oe2_Gom@[e00Gom@[e00?o0000ooL8moog2?L02_og2?L2
o`0000?onPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP0CooX5nP03o`000?oc3??o
l`cc00_ol`cc00?o0000ooD:mOoe2_D02Ooe2_D00ol0003om`SgooL8m`0;ooL8m`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Gon`Ck00?o0000onhAk_o^4Nh01oo^4Nh2o`0000_om0_d00?o0000ooD:
mOoe2_D02ooe2_D00ol0003om0_doo@;m00<oo@;m003o`000?od2oCom0_d00?om0_d00?o0000ooD:
mOoe2_D01_oe2_D00ol0003om`SgooL8m`07ooL8m`;o00001_oj1OX2o`0000konPGj00?o0000ooX5
n_oj1OX04ooj1OX00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oe2_Gom@[e00Wom@[e00?o0000ooL8
moog2?L03?og2?L00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo/4nook1?_on`Cko`000009onhA
kP03o`000?oS7>?o000000_om0_d00?o0000ooD:mOoe2_D02ooe2_D00ol0003om0_doo@;m00;oo@;
m003o`000?od2oCom0_d00Com0_d00?o0000ooD:mOoe2_D01ooe2_D00ol0003om`SgooL8m`05ooL8
m`03o`000?oj1O[onPGj00SonPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP0DooX5
nP03o`000?oc3??ol`cc00_ol`cc00?o0000ooD:mOoe2_D02Ooe2_D00ol0003om`SgooL8m`0<ooL8
m`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003on`Cko`000009onhAkP04o`000?oS7>?ohacSo`00
00_om0_d00?o0000ooD:mOoe2_D02ooe2_D00ol0003om0_doo@;m00;oo@;m003o`000?od2oCom0_d
00Com0_d00?o0000ooD:mOoe2_D02?oe2_D00ol0003om`SgooL8m`02ooL8m`;o00003?oj1OX2o`00
00[onPGj00?o0000ooX5n_oj1OX05?oj1OX00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oe2_Gom@[e
00Wom@[e00?o0000ooL8moog2?L03Oog2?L00ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003okQ7^onhAkP07onhAkP03
o`000?oS7>?ohacS00;ohacS00?o0000oo@;m?od2o@02?od2o@00ol0003om@[eooD:m@0<ooD:m@03
o`000?od2oCom0_d00Wom0_d00?o0000oo@;m?od2o@01Ood2o@00ol0003om@[eooD:m@09ooD:m@04
o`000?og2?Oo0000o`00013onPGj0_l00008ooX5nP03o`000?oj1O[onPGj01ConPGj0ol0000;oo<<
l`03o`000?oe2_Gom@[e00Wom@[e00?o0000ooL8moog2?L03Oog2?L01?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003okQ7^onhAkP06onhAkP03o`000?oS7>?ohacS00?ohacS00?o0000oo@;
m?od2o@02?od2o@00ol0003om@[eooD:m@0;ooD:m@;o00002_od2o@00ol0003om0_doo@;m006oo@;
m003o`000?oe2_Gom@[e00[om@[e00?o0000ooX5n_oj1OX04_oj1OX00ol0003onPGjooX5nP04ooX5
nP03o`000?oj1O[onPGj01GonPGj00?o0000ooP7n?oh1oP01Ol00005oo<<l`03o`000?oe2_Gom@[e
00[om@[e00?o0000ooL8moog2?L03_og2?L3o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP04onhAkP03
o`000?oS7>?ohacS00CohacS00?o0000oo@;m?od2o@01ood2o@00ol0003om@[eooD:m@0;ooD:m@04
o`000?of2OKomPWfo`0000Wom0_d00?o0000oo@;m?od2o@01_od2o@00ol0003om@[eooD:m@0:ooD:
m@03o`000?oj1O[onPGj01?onPGj0_l00003ooX5nPCo00005?oj1OX00ol0003on0OhooP7n006ooP7
n0Co000000?ol`cco`000?oe2_D02ooe2_D00ol0003om`SgooL8m`0>ooL8m`03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003okQ7^onhAkP03onhAkP03o`000?oS7>?ohacS00GohacS00?o0000oo@;m?od
2o@01ood2o@00ol0003om@[eooD:m@09ooD:m@;o00001?of2OH00ol0003om0_doo@;m005oo@;m003
o`000?od2oCom0_d00Oom0_d00?o0000ooD:mOoe2_D02_oe2_D00ol0003onPGjooX5nP0EooX5nP03
o`000?oj1O[o000000ConPGj0ol0000@ooX5nP03o`000?oh1oSon0Oh00_on0Oh0_l0000<ooD:m@03
o`000?og2?Oom`Sg00com`Sg0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onhAk_o^4Nh00_o^4Nh00ol0003ohacS
on<Lh`06on<Lh`03o`000?od2oCom0_d00Oom0_d00?o0000ooD:mOoe2_D02?oe2_D00ol0003omPWf
ooH9mP05ooH9mP03o`000?od2oCom0_d00Com0_d00?o0000oo@;m?od2o@01ood2o@00ol0003om@[e
ooD:m@0:ooD:m@03o`000?oj1O[onPGj01KonPGj00?o0000ooX5n_oj1OX01_oj1OX3o`0000conPGj
00?o0000ooP7n?oh1oP03Ooh1oP00ol0003om@[eooD:m@09ooD:m@Go00002Oog2?L2o`000003oo<<
lol0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003onhAk_l0003ohacS00WohacS00?o0000oo@;m?od2o@01_od
2o@00ol0003om@[eooD:m@07ooD:m@03o`000?of2OKomPWf00OomPWf00?o0000oo@;m?od2o@00_od
2o@00ol0003om0_doo@;m008oo@;m003o`000?oe2_Gom@[e00Wom@[e00?o0000ooX5n_oj1OX05ooj
1OX00ol0003onPGjooX5nP09ooX5nP?o00002Ooj1OX00ol0003on0OhooP7n00>ooP7n0Ko00001?oe
2_D00ol0003ol@kaoo4>l@03oo4>l@Go00000_og2?L2o`0000Col`cc00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?o_4>ooka3_onl@kol000002ooS7><00ol0003om0_doo@;m006oo@;m003o`000?oe
2_Gom@[e00Gom@[e0_l0000;ooH9mP04o`000?od2oCom0_do`0000_om0_d00?o0000ooD:mOoe2_D0
2Ooe2_D00ol0003onPGjooX5nP0FooX5nP03o`000?oj1O[onPGj00gonPGj0ol00005ooX5nP03o`00
0?oh1oSon0Oh00oon0Oh00?o0000ooP7n?oh1oP00ooh1oP4o`0000_ol@ka0_l00006oo<<l`03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`02onl@k`ko00001_od2o@00ol0003om@[eooD:
m@05ooD:m@03o`000?of2OKomPWf00comPWf00?o0000oo@;m?l000002ood2o@00ol0003om@[eooD:
m@07ooD:m@?o00006?oj1OX00ol0003onPGjooX5nP0@ooX5nP?o000000?onPGjo`000?oh1oP04?oh
1oP00ol0003on0OhooP7n007ooP7n003o`000?oa3_7ol@ka00[ol@ka00?o0000oo<<looc3?<01Ooc
3?<00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005onl@k`03o`000?o/4ncok1?/00_ok1?/0_l00004
oo@;m003o`000?oe2_Gom@[e00?om@[e0_l0000@ooH9mP03o`000?od2oCom0_d00[om0_d00?o0000
ooD:mOoe2_D00ooe2_D4o`0000;ol`cc00?o0000ooX5n_oj1OX05Ooj1OX00ol0003onPGjooX5nP0D
ooX5nP03o`000?oh1oSon0Oh013on0Oh00?o0000ooP7n?oh1oP01ooh1oP00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?oc3??ol`cc00Gol`cc00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o_4>ooka3_
00Goka3_00?o0000on`Ck?o/4n`03Oo/4n`6o`0000?om@[e00?o0000ooH9m_of2OH04?of2OH00ol0
003om0_doo@;m00:oo@;m003o`000?oe2_Go000000?o00001ooc3?<00ol0003onPGjooX5nP0DooX5
nP03o`000?oj1O[onPGj01ConPGj00?o0000ooP7n?oh1oP03ooh1oP00ol0003on0OhooP7n008ooP7
n003o`000?oa3_7ol@ka00[ol@ka00?o0000oo<<looc3?<01Ooc3?<00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003ok1?/on`Ck00=on`Ck003o`000?og2?Oom`Sg00?o
m`Sg00?o0000ooD:mOl000004oof2OH4o`0000Wom0_d0_l0000<oo<<l`03o`000?oj1O[onPGj01?o
nPGj00?o0000ooX5n_oj1OX05Ooj1OX00ol0003on0OhooP7n00>ooP7n003o`000?oh1oSon0Oh00So
n0Oh00?o0000oo4>lOoa3_402Ooa3_400ol0003ol`ccoo<<l`07oo<<l`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?o_4>ooka3_00Soka3_00?o0000on`Ck?o/4n`02oo/4n`00ol0003om`SgooL8m`05ooL8m`03o`00
0?of2OKomPWf01;omPWf00Co0000ooD:mOoe2_Gom@[e1Ol00003oo@;m003o`000?oc3??ol`cc00go
l`cc0ol0000@ooX5nP;o00006?oj1OX00ol0003on0OhooP7n00=ooP7n003o`000?oh1oSon0Oh00Wo
n0Oh00?o0000oo4>lOoa3_402Ooa3_400ol0003ol`ccoo<<l`07oo<<l`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_oka3_00?o0000on`Ck?o/4n`02_o/4n`00ol0003om`SgooL8m`06ooL8m`03o`00
0?of2OKomPWf017omPWf00?o0000ooD:mOoe2_D01ooe2_D3o`00013ol`cc00?o0000oo<<looc3?<0
1Ol00009ooX5nP;o000000?om@[eo`000?oj1OX05ooj1OX00ol0003on0OhooP7n00=ooP7n003o`00
0?oh1oSon0Oh00Won0Oh00?o0000oo4>lOoa3_402?oa3_42o`0000[ol`cc00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?o^4NkokQ7^00;okQ7^00?o0000onl@koo_4>l02Oo_4>l00ol0003ok1?/on`C
k00:on`Ck003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooH9m_of2OH03oof2OH00ol0003om@[eooD:
m@0:ooD:m@03o`000?oc3??ol`cc00gol`cc00?o0000oo<<looc3?<01_oc3?<4o`0000ConPGj00?o
0000ooD:mOoe2_D00_oe2_D00ol0003onPGjooX5nP0FooX5nP03o`000?oh1oSon0Oh00_on0Oh00?o
0000ooP7n?oh1oP02ooh1oP00ol0003ol@kaoo4>l@06oo4>l@03o`000?oY5^Wo000000[ol`cc00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?o^4NkokQ7^00?okQ7^00?o0000onl@koo_4>l02?o_4>l=
o`0000[om`Sg00?o0000ooH9m_of2OH03oof2OH00ol0003om@[eooD:m@0;ooD:m@03o`000?oc3??o
l`cc00col`cc00?o0000oo<<looc3?<02_oc3?<4o`0000Gom@[e00?o0000ooX5n_oj1OX05_oj1OX0
0ol0003on0OhooP7n00:ooP7n003o`000?oh1oSon0Oh00con0Oh00?o0000oo4>lOoa3_401?oa3_42
o`0000?ojAKY00?o0000oo<<looc3?<02?oc3?<00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000onhA
k_o^4Nh00oo^4Nh00ol0003oka3_onl@k`07onl@k`03o`000?o/4ncok1?/00Wok1?/00?o0000ooL8
moog2?L02Oog2?L00ol0003omPWfooH9mP0=ooH9mP03o`000?oe2_Gom@[e00com@[e00?o0000oo<<
looc3?<03?oc3?<00ol0003ol`ccoo<<l`0;oo<<l`03o`000?o_4>oo000000Kom@[e00?o0000ooX5
n_oj1OX05_oj1OX00ol0003on0OhooP7n009ooP7n003o`000?oh1oSon0Oh00con0Oh00?o0000oo4>
lOoa3_400ooa3_400ol0003ojAKYonTFj@03onTFj@03o`000?oc3??ol`cc00Sol`cc00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?o^4NkokQ7^00CokQ7^00?o0000onl@koo_4>l01_o_4>l00ol0003o
k1?/on`Ck008on`Ck003o`000?og2?Oom`Sg00_om`Sg00?o0000ooH9m_of2OH02?of2OH4o`0000oo
m@[e00?o0000oo<<looc3?<02ooc3?<00ol0003ol`ccoo<<l`0;oo<<l`04o`000?o_4>ooka3_o`00
00Oom@[e00?o0000ooX5n_oj1OX05Ooj1OX00ol0003on0OhooP7n008ooP7n003o`000?oh1oSon0Oh
00gon0Oh00?o0000oo4>lOoa3_400_oa3_400ol0003ojAKYonTFj@05onTFj@03o`000?oc3??ol`cc
00Ool`cc00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?o^4NkokQ7^00GokQ7^00?o0000onl@koo_
4>l01Oo_4>l00ol0003ok1?/on`Ck008on`Ck003o`000?og2?Oom`Sg00_om`Sg00?o0000ooH9m_of
2OH00oof2OH5o`0000?om@[e00?o0000ooD:mOoe2_D03_oe2_D00ol0003ol`ccoo<<l`0:oo<<l`03
o`000?oc3??ol`cc00[ol`cc00Go0000onl@koo_4>ooka3_o`000007ooD:m@03o`000?oj1O[onPGj
01GonPGj00?o0000ooP7n?oh1oP02?oh1oP00ol0003on0OhooP7n00=ooP7n003o`000?oa3_7ol@ka
00;o00002?oY5^T00ol0003ol`ccoo<<l`08oo<<l`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003okQ7^onhAkP05onhAkP03o`000?o_4>ooka3_00Go
ka3_00?o0000on`Ck?o/4n`02?o/4n`00ol0003om`SgooL8m`0<ooL8m`Go00002Ooe2_D00ol0003o
m@[eooD:m@0<ooD:m@;o00003?oc3?<00ol0003ol`ccoo<<l`0:oo<<l`05o`000?o_4>ooka3_onl@
kol000002?oe2_D00ol0003onPGjooX5nP0DooX5nP?o00001ooh1oP00ol0003on0OhooP7n00>ooP7
n003o`000?oa3_7o000000_ojAKY00?o0000oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oka3_onl@k`04onl@k`03o`000?o/4ncok1?/00Oo
k1?/00?o0000ooL8moog2?L03?og2?L01?l0003omPWfooH9m_l0000;ooD:m@03o`000?oe2_Gom@[e
00_om@[e00Co0000onl@koo_4>oo00002_oc3?<00ol0003ol`ccoo<<l`0:oo<<l`03o`000?o_4>oo
ka3_00;oka3_00?o0000ooD:mOoe2_D01_oe2_D00ol0003onPGjooX5nP0AooX5nP?o00000oof2OH0
0ol0003on0OhooP7n004ooP7n003o`000?oh1oSon0Oh00gon0Oh1?l0000;onTFj@03o`000?oc3??o
l`cc00Gol`cc00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o^4NkokQ7^00KokQ7^00Co0000onl@
koo_4>ooka3_1?l00008on`Ck003o`000?og2?Oom`Sg00_om`Sg00?o0000ooH9m_of2OH00_of2OH0
0ol0003om@[eooD:m@08ooD:m@03o`000?oe2_Gom@[e00[om@[e00?o0000onl@koo_4>l00_o_4>l0
0ol0003ol`ccoo<<l`03oo<<l`Go00002ooc3?<00ol0003oka3_onl@k`03onl@k`03o`000?oe2_Go
m@[e00Oom@[e00?o0000ooX5n_oj1OX03_oj1OX2o`0000OomPWf00?o0000ooP7n?oh1oP00_oh1oP0
0ol0003on0OhooP7n00=ooP7n003o`000?oa3_7ol@ka00;ol@ka00?o0000onTFjOoY5^T02OoY5^T0
0ol0003ol`ccoo<<l`03oo<<l`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003okQ7^onhAkP07onhA
kP?o00001?od2o@00ol0003ok1?/on`Ck005on`Ck003o`000?og2?Oom`Sg00[om`Sg00?o0000ooH9
m_of2OH00oof2OH00ol0003om@[eooD:m@09ooD:m@03o`000?oe2_Gom@[e00Som@[e00?o0000onl@
koo_4>l01?o_4>l5o`0000CoiQWV00?o0000oo<<looc3?<02Ooc3?<00ol0003oka3_onl@k`03onl@
k`03o`000?oe2_Gom@[e00Som@[e00?o0000ooX5n_oj1OX02_oj1OX3o`0000[omPWf00Go0000ooP7
n?oh1oSon0Oho`00000>ooP7n003o`000?oa3_7ol@ka00Col@ka0_l00009onTFj@03o`000?oc3??o
l`cc00;ol`cc00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?o^4NkokQ7^00OokQ7^00?o0000oo@;
m?od2o@01Ood2o@00ol0003ok1?/on`Ck003on`Ck003o`000?og2?Oom`Sg00[om`Sg00?o0000ooH9
m_of2OH01?of2OH00ol0003om@[eooD:m@09ooD:m@03o`000?oe2_Gom@[e00Oom@[e00?o0000onl@
koo_4>l01Oo_4>l00ol0003oiQWVonHIiP07onHIiP03o`000?oc3??ol`cc00Ool`cc00?o0000onl@
koo_4>l01?o_4>l00ol0003om@[eooD:m@08ooD:m@03o`000?oj1O[onPGj00SonPGj0_l0000>ooH9
mPCo00003?oh1oP2o`0000Wol@ka00?o0000onTFjOoY5^T01ooY5^T01?l0003ol`ccoo<<lol0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003om0_doo@;m007oo@;m0;o00000oo/4n`00ol0
003om`SgooL8m`09ooL8m`03o`000?of2OKomPWf00KomPWf00?o0000ooD:mOoe2_D02Ooe2_D00ol0
003om@[eooD:m@05ooD:m@03o`000?o_4>ooka3_00Koka3_00?o0000onHIi_oV6NH02?oV6NH00ol0
003ol`ccoo<<l`06oo<<l`03o`000?o_4>ooka3_00Coka3_00?o0000ooD:mOoe2_D02Ooe2_D4o`00
00?onPGj0ol0000@ooH9mP05o`000?oj1O[onPGjooX5n_l000002_oh1oP00ol0003ol@kaoo4>l@0:
oo4>l@Ko00000ooY5^T00ol0003ol`cco`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000onhAk_o^4Nh01?o^4Nh00ol0
003om0_doo@;m00:oo@;m004o`000?o/4ncok1?/o`0000[om`Sg00?o0000ooH9m_of2OH01oof2OH0
0ol0003om@[eooD:m@09ooD:m@03o`000?oe2_Gom@[e00Com@[e00?o0000onl@koo_4>l01oo_4>l0
0ol0003oiQWVonHIiP08onHIiP;o00001_oc3?<00ol0003oka3_onl@k`05onl@k`03o`000?oe2_Go
m@[e00Wom@[e00Co0000oo<<looc3??ol`cc0ol0000BooH9mP03o`000?oj1O[onPGj00?onPGj0_l0
0006ooP7n0;o00003Ooa3_400ol0003ol@kaoo4>l@03oo4>l@Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000onhAk_o^4Nh00oo^4Nh0
0ol0003om0_doo@;m00<oo@;m0;o00002_og2?L00ol0003omPWfooH9mP08ooH9mP03o`000?oe2_Go
m@[e00[om@[e00?o0000ooD:mOoe2_D00_oe2_D00ol0003oka3_onl@k`08onl@k`03o`000?oV6NKo
iQWV00KoiQWV0_l00002onl@k`03o`000?oc3??ol`cc00;ol`cc00?o0000onl@koo_4>l01_o_4>l0
0ol0003om@[eooD:m@08ooD:m@03o`000?oc3??ol`cc00Col`cc00?o0000ooH9m_of2OH03oof2OH0
0ol0003onPGjooX5nP06ooX5nP;o00000ooh1oP00ol0003ol@kaoo4>l@0=oo4>l@03o`000?oa3_7o
l@ka00Ool@ka0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003okQ7^onhAkP02onhAkP03o`000?od2oCom0_d
00kom0_d00?o0000ooL8moog2?L01oog2?L00ol0003omPWfooH9mP0:ooH9mP03o`000?oe2_Gom@[e
00Wom@[e00Go0000ooD:mOoe2_Gom@[eo`00000;onl@k`03o`000?oV6NKoiQWV00CoiQWV0_l00005
onl@k`05o`000?oc3??ol`ccoo<<lol000002?o_4>l00ol0003om@[eooD:m@08ooD:m@03o`000?oc
3??ol`cc00Gol`cc00?o0000ooH9m_of2OH03_of2OH00ol0003onPGjooX5nP08ooX5nP03o`000?oh
1oSo000000ool@ka00?o0000oo4>lOoa3_402?oa3_401?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?o^4NkokQ7^o`00017om0_d00?o0000ooL8moog2?L01_og2?L00ol0003omPWf
ooH9mP0;ooH9mP03o`000?oe2_Gom@[e00Wom@[e00Co0000ooD:mOoe2_Go00003?o_4>l00ol0003o
iQWVonHIiP02onHIiP;o00002?o_4>l00ol0003ol`cco`000009onl@k`03o`000?oe2_Gom@[e00So
m@[e00?o0000oo<<looc3?<01Ooc3?<00ol0003omPWfooH9mP0=ooH9mP03o`000?oj1O[onPGj00[o
nPGj00?o0000oo4>lOoa3_403_oa3_400ol0003ol@kaoo4>l@07oo4>l@03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000Boo@;m003o`00
0?og2?Oom`Sg00Com`Sg00?o0000ooH9m_of2OH03?of2OH00ol0003om@[eooD:m@0:ooD:m@?o0000
3?o_4>l00ol0003oiQWVonHIiP02o`0000_oka3_00?o0000onl@koo_4>l02?o_4>l00ol0003om@[e
ooD:m@07ooD:m@03o`000?oc3??ol`cc00Ool`cc00?o0000ooH9m_of2OH03?of2OH00ol0003onPGj
ooX5nP0;ooX5nP;o00003_oa3_400ol0003ol@kaoo4>l@07oo4>l@03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000oo@;m?od2o@00ood2o@00ol0003om0_doo@;m00?oo@;m0?o00000oog
2?L00ol0003omPWfooH9mP0>ooH9mP03o`000?oe2_Gom@[e00Som@[e00Co0000oo0?l?o`3o3ol0o`
0_l0000:onl@k`?o00003Oo_4>l00ol0003oka3_onl@k`08onl@k`03o`000?oe2_Gom@[e00Oom@[e
00?o0000oo<<looc3?<01ooc3?<00ol0003omPWfooH9mP0;ooH9mP03o`000?oj1O[onPGj00conPGj
00?o0000oo0?l?l000000_l0000:oo4>l@03o`000?oa3_7ol@ka00Sol@ka00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003om0_doo@;m004oo@;m003o`000?od2oCom0_d00com0_d0_l0
0003oo@;m003o`000?og2?Oo0000017omPWf00?o0000ooD:mOoe2_D01ooe2_D00ol0003ol0o`oo0?
l004oo0?l0;o00002?o_4>l00ol0003oka3_onl@k`0>onl@k`;o00002?o_4>l00ol0003om@[eooD:
m@06ooD:m@03o`000?oc3??ol`cc00Wol`cc00?o0000ooH9m_of2OH02Oof2OH00ol0003onPGjooX5
nP0=ooX5nP03o`000?o`3o3ol0o`00;ol0o`0ol00007oo4>l@03o`000?oa3_7ol@ka00Ool@ka00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003om0_doo@;m005oo@;m003o`000?od2oCo
m0_d00Wom0_d0_l00006oo@;m003o`000?of2OKomPWf013omPWf00?o0000ooD:mOoe2_D01_oe2_D0
0ol0003ol0o`oo0?l007oo0?l003o`000?o_4>ooka3_00Coka3_0ol0000>onl@k`03o`000?o[5>_o
jaC[00?o00001Oo_4>l00ol0003om@[eooD:m@06ooD:m@03o`000?oc3??ol`cc00[ol`cc00?o0000
ooH9m_of2OH02?of2OH00ol0003onPGjooX5nP0=ooX5nP03o`000?o`3o3ol0o`00Gol0o`0ol00004
oo4>l@03o`000?oa3_7ol@ka00Ool@ka00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003om0_doo@;m006oo@;m003o`000?od2oCom0_d00Gom0_d0ol00008oo@;m003o`000?of2OKomPWf
017omPWf00Co0000ooD:mOoe2_Gom@[e1?l0000;oo0?l0;o000000Coka3_o`000?l0003o00000oob
3O82o`0000_oka3_00?o0000on/Djoo[5>/01?o[5>/2o`0000?oka3_00?o0000ooD:mOoe2_D01_oe
2_D00ol0003ol`ccoo<<l`0:oo<<l`03o`000?of2OKomPWf00OomPWf00?o0000ooX5n_oj1OX03_oj
1OX00ol0003ol0o`oo0?l008oo0?l0Co00002_oa3_400ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003om0_doo@;m007oo@;m003o`000?od2oCom0_d00;om0_d0_l0000<oo@;m003o`000?of2OKo
mPWf013omPWf1?l00003oo<<l`03o`000?o`3o3ol0o`00_ol0o`00?o0000oo8=l_ob3O801_ob3O80
0ol0003oka3_onl@k`07onl@k`03o`000?o[5>_ojaC[00OojaC[3?l0000>oo<<l`03o`000?of2OKo
mPWf00KomPWf00?o0000ooX5n_oj1OX03_oj1OX00ol0003ol0o`oo0?l00;oo0?l003o`000?oa3_7o
l@ka00Ool@ka00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?od2oCom0_d00Wom0_d00Co0000oo@;
m?l0003o00003_od2o@00ol0003omPWfooH9mP0?ooH9mP03o`000?oc3??ol`cc00Kol`cc00?o0000
oo0?l?o`3o002_o`3o000ol0003olPgboo8=lP07oo8=lP;o00001_o_4>l00ol0003ojaC[on/Dj`08
on/Dj`03o`000?of2OKomPWf00SomPWf00?o0000oo<<looc3?<03?oc3?<00ol0003omPWfooH9mP05
ooH9mP03o`000?oj1O[onPGj00oonPGj0_l0000=oo0?l003o`000?oa3_7ol@ka00Kol@ka00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?od2oCom0_d00[om0_d00?o0000oo@;m?od2o@03_od2o@00ol0
003omPWfooH9mP0>ooH9mP03o`000?oc3??ol`cc00Ool`cc00?o0000oo0?l?o`3o002_o`3o000ol0
003olPgboo8=lP09oo8=lP;o00000oo_4>l00ol0003ojaC[on/Dj`09on/Dj`03o`000?of2OKomPWf
00WomPWf00?o0000oo<<looc3?<02_oc3?<4o`0000ComPWf00?o0000ooX5n_oj1OX04?oj1OX01?l0
003ol@kao`000?l0000<oo0?l003o`000?oa3_7ol@ka00Gol@ka00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?od2oCom0_d00[om0_d00?o0000oo@;m?od2o@03ood2o@@o`0000[ol`cc00?o0000oo0?
l?o`3o002Oo`3o000ol0003okA;]o`00000<oo8=lP05o`000?o_4>oo0000on`Ck?l000002_o[5>/0
0ol0003omPWfooH9mP09ooH9mP03o`000?oc3??ol`cc00Ool`cc0ol00004ooL8m`?o000000?omPWf
o`000?oj1OX04Ooj1OX01?l0003ol@kaoo4>lOoa3_42o`0000_ol0o`00?o0000oo4>lOoa3_400ooa
3_400ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003om0_doo@;m00?
oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000oo<<looc3?<02Ooc3?<00ol0003ol0o`oo0?l007
oo0?l004o`000?o]4^gokA;]o`0000golPgb00Go0000on`Ck?o/4ncok1?/o`000009on/Dj`03o`00
0?of2OKomPWf00[omPWf00?o0000oo<<looc3?<00ooc3?<3o`0000[om`Sg00?o0000ooX5n_oj1OX0
4?oj1OX00ol0003ol@kaoo4>l@04oo4>l@;o00002_o`3o000ol0003ol@kaoo4>l@04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000com0_d00?o0000oo@;m?od2o@03ood2o@00ol0003om`SgooL8m`0<ooL8m`03o`000?oc
3??ol`cc00Wol`cc00?o0000oo0?l?o`3o001_o`3o000ol0003okA;]ondBk@02ondBk@03o`000?ob
3O;olPgb00[olPgb00?o0000on`Ck?o/4n`00_o/4n`00ol0003ojaC[on/Dj`06on/Dj`03o`000?of
2OKomPWf00[omPWf00?o0000oo<<looc3?<00ol0000=ooL8m`03o`000?oj1O[onPGj013onPGj00?o
0000oo4>lOoa3_401_oa3_42o`0000Wol0o`0_l00004oo/4n`03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003om0_doo@;m00=oo@;m0?o00003oog2?L0
0ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00Gol0o`00?o0000ondBkOo]4^d00oo]4^d0
0ol0003olPgboo8=lP0:oo8=lP03o`000?o/4ncok1?/00?ok1?/00?o0000on/Djoo[5>/01Oo[5>/0
0ol0003omPWfooH9mP0;ooH9mP;o00004Oog2?L00ol0003onPGjooX5nP0?ooX5nP03o`000?oa3_7o
l@ka00Sol@ka0_l00007oo0?l003o`000?ok1?_on`Ck00Con`Ck00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000oo@;m?od2o@02?od2o@00ol0003om0_doo@;m009oo@;m0Go00000_ob3O800ol0
003om`SgooL8m`0=ooL8m`03o`000?oc3??ol`cc00Wol`cc00?o0000oo0?l?o`3o001?o`3o000ol0
003okA;]ondBk@04ondBk@03o`000?ob3O;olPgb00SolPgb00?o0000on`Ck?o/4n`01Oo/4n`00ol0
003ojaC[on/Dj`04on/Dj`03o`000?of2OKomPWf00_omPWf00?o0000ooL8moog2?L04?og2?L00ol0
003onPGjooX5nP0?ooX5nP03o`000?oa3_7ol@ka00[ol@ka0_l00004oo0?l003o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003om0_doo@;m007oo@;m003o`000?od2oCom0_d00Com0_d1Ol00007oo8=lP03
o`000?og2?Oom`Sg00gom`Sg00?o0000oo<<looc3?<02Ooc3?<00ol0003ol0o`oo0?l003oo0?l003
o`000?o]4^gokA;]00GokA;]00?o0000oo8=l_ob3O802?ob3O800ol0003ok1?/on`Ck006on`Ck003
o`000?o[5>_ojaC[00?ojaC[00?o0000ooH9m_of2OH02oof2OH00ol0003om`SgooL8m`0@ooL8m`03
o`000?oj1O[onPGj00oonPGj00?o0000oo4>lOoa3_403?oa3_42o`000003oo0?l?l0003on`Ck00[o
n`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?od2oCom0_d00Oom0_d00?o0000oo@;m?l00000
1?l0000<oo8=lP03o`000?og2?Oom`Sg00kom`Sg00?o0000oo<<looc3?<02?oc3?<00ol0003ol0o`
oo0?l002oo0?l003o`000?o]4^gokA;]00OokA;]00?o0000oo8=l_ob3O801oob3O800ol0003ok1?/
on`Ck007on`Ck003o`000?o[5>_ojaC[00;ojaC[00?o0000ooH9m_of2OH02oof2OH00ol0003om`Sg
ooL8m`0AooL8m`03o`000?oj1O[onPGj00gonPGj00?o0000oo4>lOoa3_403ooa3_400ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000oo@;m?od2o@01Ood2o@3o`00017olPgb00?o0000ooL8moog2?L03_og
2?L00ol0003ol`ccoo<<l`09oo<<l`04o`000?o`3o3ol0o`o`0000[okA;]00?o0000oo8=l_ob3O80
1oob3O800ol0003ok1?/on`Ck008on`Ck005o`000?o[5>_ojaC[on/Djol000003Oof2OH00ol0003o
m`SgooL8m`0AooL8m`?o00003Ooj1OX00ol0003ol@kaoo4>l@0?oo4>l@03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_od2o@2o`0000;ol@ka00?o0000oo8=l_ob3O803oob3O800ol0003o
m`SgooL8m`0>ooL8m`03o`000?oc3??ol`cc00Sol`cc1Ol0000;ondBk@03o`000?ob3O;olPgb00Ko
lPgb00?o0000on`Ck?o/4n`02Oo/4n`01?l0003ojaC[on/Djol0000=ooH9mP03o`000?og2?Oom`Sg
017om`Sg00?o0000oo8=l_ob3O800ol0000:ooX5nPCo00003Ooa3_400ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000onl@koo_4>ooka3_0_l00005oo4>l@03o`000?ob3O;olPgb00kolPgb00?o0000ooL8
moog2?L03_og2?L00ol0003ol`ccoo<<l`07oo<<l`03o`000?oc3??ol`cc00?ol`cc00?o0000ondB
kOo]4^d02?o]4^d00ol0003olPgboo8=lP05oo8=lP03o`000?o/4ncok1?/00[ok1?/1Ol0000<ooH9
mP03o`000?og2?Oom`Sg013om`Sg00?o0000oo8=l_ob3O801?ob3O83o`0000KonPGj00?o0000ooD:
mOoe2_D00_oe2_D5o`0000Sol@ka00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o_4>ooka3_00?o
ka3_00?o0000oo4>lOoa3_401?oa3_400ol0003olPgboo8=lP0=oo8=lP03o`000?og2?Oom`Sg00oo
m`Sg00?o0000oo<<looc3?<01?oc3?<2o`0000Ool`cc00?o0000ondBkOo]4^d01oo]4^dEo`0000Go
kQ7^00?o0000ooH9m_of2OH02?of2OH3o`00013om`Sg00?o0000oo8=l_ob3O802?ob3O83o`0000;o
nPGj00?o0000ooD:mOoe2_D02?oe2_D5o`0000?ol@ka00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?o_4>ooka3_00Coka3_00?o0000oo4>lOoa3_401Ooa3_400ol0003olPgboo8=lP0;oo8=lPCo0000
3oog2?L00ol0003ol`ccoo<<l`03oo<<l`03o`000?oc3??ol`cc00Sol`cc00?o0000ondBkOo]4^d0
1?o]4^d2o`0000Sol`cc00?o0000oo4>lOoa3_402?oa3_400ol0003okQ7^onhAkP05onhAkP;o0000
1_of2OH2o`0000?om0_d00?o0000ooL8moog2?L03?og2?L00ol0003olPgboo8=lP0<oo8=lP;o0000
4?oe2_D3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?oa3_7ol@ka00Kol@ka00?o
0000oo8=l_ob3O802Oob3O800ol0003okA;]o`000002oo<<l`?o00003?og2?L01?l0003ol`ccoo<<
looc3?<2o`0000col`cc00?o0000ondBkOo]4^d00_o]4^d00ol0003ol`ccoo<<l`08oo<<l`03o`00
0?oa3_7ol@ka00Sol@ka00?o0000onhAk_o^4Nh01oo^4Nh00ol0003omPWfooH9mP02ooH9mP03o`00
0?od2oCom0_d00Com0_d0_l0000;ooL8m`03o`000?ob3O;olPgb00colPgb00?o0000oo@;m?l00000
4_oe2_D00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003oka3_onl@k`06onl@k`03o`000?oa3_7ol@ka00Ool@ka00?o
0000oo8=l_ob3O801_ob3O82o`0000;okA;]00?o0000oo<<looc3?<00ooc3?<3o`0000[om`Sg00?o
0000oo<<lol000003ooc3?<01?l0003okA;]o`000?l0000;oo<<l`03o`000?oa3_7ol@ka00Sol@ka
00?o0000onhAk_o^4Nh02?o^4Nh01?l0003omPWfo`000?l00009oo@;m003o`000?og2?Oom`Sg00Oo
m`Sg00?o0000oo8=l_ob3O803?ob3O801?l0003om0_doo@;m?l0000CooD:m@03o`000?ok1?_on`Ck
00con`Ck0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000onl@koo_4>l01oo_4>l00ol0003ol@kaoo4>l@08oo4>l@03o`000?ob3O;olPgb00Co
lPgb00?o0000ondBkOo]4^d00oo]4^d00ol0003ol`ccoo<<l`05oo<<l`?o00001_og2?L4o`00013o
l`cc00?o0000oo<<looc3?<03?oc3?<00ol0003ol@kaoo4>l@07oo4>l@03o`000?o^4NkokQ7^00Wo
kQ7^00?o0000oo@;m?od2o@02_od2o@2o`0000Kom`Sg00?o0000oo8=l_ob3O803?ob3O800ol0003o
m0_doo@;m002oo@;m003o`000?oe2_Gom@[e00oom@[e00?o0000oo0?l?l000002ook1?/2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003oka3_onl@k`08onl@k`03o`000?oa3_7ol@ka00Wol@ka00Co0000oo8=l_ob3O;o
lPgb0_l00006ondBk@03o`000?oc3??ol`cc00Sol`cc0ol000000oog2?Oo0000o`000004oo@;m003
o`000?oc3??ol`cc00gol`cc00?o0000oo<<looc3?<03?oc3?<00ol0003ol@kaoo4>l@07oo4>l@03
o`000?o^4NkokQ7^00WokQ7^00?o0000oo@;m?od2o@03?od2o@00ol0003om`SgooL8m`03o`0000ko
lPgb00?o0000oo@;m?od2o@00ood2o@00ol0003om@[eooD:m@0>ooD:m@05o`000?o`3o3ol0o`oo0?
l?l000002?ok1?/2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003oka3_onl@k`09onl@k`03o`000?oa3_7ol@ka00[o
l@ka00?o0000oo8=l_l000002?o]4^d00ol0003ol`ccoo<<l`0;oo<<l`03o`000?od2oCom0_d00Go
m0_d00?o0000oo<<looc3?<03?oc3?<00ol0003ol`ccoo<<l`0<oo<<l`03o`000?oa3_7ol@ka00Oo
l@ka00?o0000onhAk_o^4Nh02?o^4Nh2o`0000oom0_d0_l00002ooD:m@03o`000?ob3O;olPgb00_o
lPgb00?o0000oo@;m?od2o@01?od2o@00ol0003om@[eooD:m@0=ooD:m@03o`000?o`3o3ol0o`00?o
l0o`00?o0000oo/4nook1?/00_ok1?/3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onl@k`03o`000?oa3_7ol@ka00_ol@ka00?o0000ondBkOo]4^d0
1oo]4^d00ol0003ol`ccoo<<l`0;oo<<l`03o`000?od2oCom0_d00Kom0_d00?o0000oo<<looc3?<0
2ooc3?<2o`0000gol`cc00?o0000oo4>lOoa3_401ooa3_400ol0003okQ7^onhAkP07onhAkP04o`00
0?o`3o3ol0o`o`0000kom0_d00?o0000ooD:mOoe2_D00_oe2_D00ol0003olPgboo8=lP09oo8=lP03
o`000?od2oCom0_d00Kom0_d00?o0000ooD:mOoe2_D02ooe2_D00ol0003ol0o`oo0?l005oo0?l004
o`000?ok1?_o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000Soka3_00?o0000oo4>lOoa3_402_oa3_42o`0000Wo
kA;]00?o0000oo<<looc3?<02ooc3?<00ol0003om0_doo@;m007oo@;m003o`000?oc3??ol`cc00Wo
l`cc00Co0000on/Djoo[5>_o00003?oc3?<00ol0003ol@kaoo4>l@07oo4>l@03o`000?o^4NkokQ7^
00KokQ7^00Go0000oo0?l?o`3o3ol0o`o`00000>oo@;m003o`000?oe2_Gom@[e00?om@[e00?o0000
oo8=l_ob3O801oob3O800ol0003om0_doo@;m007oo@;m003o`000?oe2_Gom@[e00[om@[e00?o0000
oo0?l?o`3o001oo`3o000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006onl@k`03o`000?oa3_7ol@ka
00Wol@ka00Co0000on`Ck?o/4nco00002Oo]4^d00ol0003ol`ccoo<<l`09oo<<l`03o`000?od2oCo
m0_d00Wom0_d00?o0000oo<<looc3?<01ooc3?<00ol0003ojaC[on/Dj`02on/Dj`03o`000?oc3??o
l`cc00Wol`cc00?o0000oo4>lOoa3_401ooa3_400ol0003okQ7^onhAkP05onhAkP03o`000?o`3o3o
l0o`00?ol0o`00?o0000oo@;m?od2o@02_od2o@00ol0003om@[eooD:m@05ooD:m@03o`000?ob3O;o
lPgb00GolPgb00?o0000oo@;m?od2o@02?od2o@00ol0003om@[eooD:m@09ooD:m@03o`000?o`3o3o
l0o`00Sol0o`00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_o_4>l3o`0000Wol@ka00?o0000on`C
k?o/4n`00_o/4n`00ol0003okA;]ondBk@06ondBk@03o`000?oc3??ol`cc00Wol`cc00?o0000oo@;
m?od2o@02_od2o@00ol0003ol`ccoo<<l`05oo<<l`03o`000?o[5>_ojaC[00CojaC[00?o0000oo<<
looc3?<02?oc3?<00ol0003ol@kaoo4>l@07oo4>l@03o`000?o^4NkokQ7^00CokQ7^00?o0000oo0?
l?o`3o001?o`3o000ol0003om0_doo@;m00:oo@;m003o`000?oe2_Gom@[e00Kom@[e00?o0000oo8=
l_ob3O800oob3O800ol0003om0_doo@;m009oo@;m003o`000?oe2_Gom@[e00Som@[e00?o0000oo0?
l?o`3o002Oo`3o000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003oo<<l`?o00001Ooa3_400ol0003o
k1?/on`Ck003on`Ck003o`000?o]4^gokA;]00KokA;]00?o0000oo<<looc3?<02Ooc3?<00ol0003o
m0_doo@;m00;oo@;m003o`000?oc3??ol`cc00?ol`cc00?o0000on/Djoo[5>/01_o[5>/00ol0003o
l`ccoo<<l`08oo<<l`03o`000?oa3_7ol@ka00Kol@ka00?o0000onhAk_o^4Nh00_o^4Nh2o`0000So
l0o`00?o0000oo@;m?od2o@02Ood2o@00ol0003om@[eooD:m@07ooD:m@05o`000?ob3O;olPgboo8=
l_l000003Ood2o@00ol0003om@[eooD:m@06ooD:m@03o`000?o`3o3ol0o`00[ol0o`00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oc3??ol`cc00Gol`cc0ol000000ooa3_7o0000on`Ck006on`Ck003
o`000?o]4^gokA;]00GokA;]00?o0000oo<<looc3?<02Ooc3?<00ol0003om0_doo@;m00<oo@;m005
o`000?oc3??ol`ccoo<<lol000002_o[5>/00ol0003ol`ccoo<<l`07oo<<l`03o`000?oa3_7ol@ka
00Kol@ka00?o0000onhAk_l000000_l000000oof2OKo0000oo0?l007oo0?l003o`000?od2oCom0_d
00Som0_d00?o0000ooD:mOoe2_D02Ooe2_D00ol0003olPgbo`00000=oo@;m0Co00001Ooe2_D00ol0
003ol0o`oo0?l00;oo0?l003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003ol`ccoo<<l`08oo<<l`03
o`000?o/4ncok1?/00Ook1?/00?o0000ondBkOo]4^d01?o]4^d00ol0003ol`ccoo<<l`09oo<<l`03
o`000?od2oCom0_d00gom0_d00?o0000oo<<lol000003?o[5>/:o`0000Ool@ka0ol00005ooH9mP03
o`000?o`3o3ol0o`00Kol0o`00?o0000oo@;m?od2o@01ood2o@00ol0003om@[eooD:m@0:ooD:m@03
o`000?od2oCom0_d00_om0_d00?o0000oo4>lOoa3_400_oa3_43o`000003ooD:mOl0003ol0o`00_o
l0o`0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000oo<<looc3?<02Ooc3?<00ol0003ok1?/on`Ck007on`Ck003o`00
0?o]4^gokA;]00GokA;]00?o0000oo<<looc3?<01ooc3?<00ol0003om0_doo@;m00?oo@;m0;o0000
2oo[5>/00ol0003om0_doo@;m007oo@;m003o`000?oa3_7ol@ka00;ol@ka0ol00008ooH9mP03o`00
0?o`3o3ol0o`00Kol0o`00?o0000oo@;m?od2o@01ood2o@00ol0003om@[eooD:m@0:ooD:m@03o`00
0?od2oCom0_d00[om0_d00?o0000oo4>lOoa3_401_oa3_400ol0003ol0o`oo0?l008oo0?l0?o0000
0_oa3_400ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo<<looc3?<02Ooc3?<00ol0003ok1?/on`C
k008on`Ck003o`000?o]4^gokA;]00CokA;]00?o0000oo<<looc3?<01ooc3?<00ol0003om0_doo@;
m00>oo@;m004o`000?o^4NkokQ7^o`0000WojaC[00?o0000oo@;m?od2o@02Ood2o@01?l0003ol@ka
o`000?l0000<ooH9mP03o`000?o`3o3ol0o`00Kol0o`00?o0000oo@;m?od2o@01_od2o@00ol0003o
m@[eooD:m@0;ooD:m@03o`000?od2oCom0_d00Oom0_d0_l00009oo4>l@03o`000?o`3o3ol0o`00Co
l0o`1?l00006oo4>l@03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003ol`ccoo<<l`09oo<<l`03o`00
0?o/4ncok1?/00Sok1?/00?o0000ondBkOo]4^d00oo]4^d>o`0000gom0_d00?o0000onhAk_o^4Nh0
0_o^4Nh00ol0003ojaC[on/Dj`05on/Dj`03o`000?od2oCom0_d00_om0_d00?o0000ooH9m_of2OH0
3?of2OH00ol0003ol0o`oo0?l006oo0?l003o`000?od2oCom0_d00Gom0_d00?o0000ooD:mOoe2_D0
3?oe2_D00ol0003om0_doo@;m006oo@;m003o`000?oa3_7ol@ka00[ol@ka00?o0000oo0?l?o`3o00
0ol0000:oo4>l@?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oc3??ol`cc00_ol`cc00?o0000on`Ck?o/4n`02?o/
4n`01Ol0003okA;]ondBkOo]4^go000000_ol@ka00?o0000onLHiooW6>L00ol00009oo@;m003o`00
0?o^4NkokQ7^00CokQ7^00?o0000on/Djoo[5>/00oo[5>/00ol0003om0_doo@;m00<oo@;m003o`00
0?of2OKomPWf00gomPWf00?o0000oo0?l?o`3o001_o`3o000ol0003om0_doo@;m003oo@;m0?o0000
3Ooe2_D00ol0003om0_doo@;m005oo@;m003o`000?oa3_7ol@ka00col@ka0_l0000=oo4>l@03o`00
0?ok1?_on`Ck00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oc3??ol`cc00_ol`cc00?o0000on`Ck?o/4n`02?o/
4n`4o`0000col@ka00?o0000onLHiooW6>L00ooW6>L3o`0000Gom0_d00?o0000onhAk_o^4Nh01_o^
4Nh01Ol0003ojaC[on/Djoo[5>_o000000oom0_d00?o0000ooH9m_of2OH03Oof2OH00ol0003ol0o`
oo0?l006oo0?l003o`000?od2oCom0_d00?o00000oo`3o000ol0003om@[eooD:m@0;ooD:m@03o`00
0?od2oCom0_d00?om0_d00?o0000oo4>lOoa3_403Ooa3_400ol0003ol@kaoo4>l@0;oo4>l@03o`00
0?ok1?_on`Ck00Con`Ck0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<02_oc3?<3o`0000Kok1?/0ol0
0003onhAkP03o`000?oa3_7ol@ka00[ol@ka00?o0000onLHiooW6>L01_oW6>L3o`000003oo@;m?l0
003okQ7^00WokQ7^00?o0000on/Djol000004?od2o@00ol0003omPWfooH9mP0=ooH9mP03o`000?o`
3o3ol0o`00Ool0o`0_l00007oo0?l003o`000?oe2_Gom@[e00[om@[e00Co0000oo@;m?od2oCom0_d
0ol0000?oo4>l@03o`000?oa3_7ol@ka00_ol@ka00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo<<looc3?<02_oc
3?<01?l0003ol0o`oo0?l?o`3o02o`000004on`Ck?l0003o0000o`0000KokQ7^00?o0000oo4>lOoa
3_402_oa3_400ol0003oiaSWonLHi`09onLHi`03o`000?o^4NkokQ7^00[okQ7^00?o0000oo@;m?od
2o@03ood2o@00ol0003omPWfooH9mP0>ooH9mP03o`000?o`3o3ol0o`00Kol0o`00?o0000oo0?l?o`
3o001oo`3o04o`0000Som@[e00Co0000oo@;m?od2oCo00000oo[5>/2o`0000gol@ka00?o0000oo4>
lOoa3_402_oa3_400ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo<<looc3?<02Ooc3?<00ol0003o
l0o`oo0?l004oo0?l003o`000?o^4NkokQ7^00OokQ7^00?o0000oo4>lOoa3_402Ooa3_400ol0003o
iaSWonLHi`0:onLHi`03o`000?o^4NkokQ7^00[okQ7^00?o0000oo@;m?od2o@03ood2o@00ol0003o
mPWfooH9mP0>ooH9mP03o`000?o`3o3ol0o`00Gol0o`00?o0000oo0?l?o`3o002?o`3o001?l0003o
lPgboo8=l_ob3O87o`0000;om@[e0_l00006on/Dj`;o00003?oa3_400ol0003ol@kaoo4>l@09oo4>
l@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00Go
l0o`00?o0000onhAk_o^4Nh02?o^4Nh00ol0003ol@kaoo4>l@08oo4>l@03o`000?oW6>OoiaSW00[o
iaSW00?o0000onhAk_o^4Nh02oo^4Nh00ol0003om0_doo@;m00>oo@;m003o`000?of2OKomPWf00ko
mPWf1Ol00002oo0?l003o`000?o`3o3ol0o`00Wol0o`00?o0000oo8=l_ob3O802?ob3O83o`0000Wo
jaC[0_l0000:oo4>l@03o`000?oa3_7ol@ka00Sol@ka00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oc3??ol`cc00Sol`cc00?o0000oo0?l?o`3o001oo`3o000ol0003okQ7^onhAkP07onhAkP03o`00
0?oa3_7ol@ka00Sol@ka00?o0000onLHiooW6>L02_oW6>L00ol0003okQ7^onhAkP0:onhAkP;o0000
3_od2o@3o`0000gomPWf0ol00005ooH9mP;o00002oo`3o000ol0003olPgboo8=lP0;oo8=lP;o0000
2_o[5>/2o`0000Ool@ka0ol00009oo4>l@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:oo0?l003o`00
0?o^4NkokQ7^00OokQ7^00?o0000oo4>lOoa3_402?oa3_4>o`0000WokQ7^0ol000000ooX5nSo0000
oo@;m00:oo@;m0?o00000_og2?L00ol0003omPWfooH9mP09ooH9mP;o00002Oof2OH00ol0003ol0o`
oo0?l009oo0?l003o`000?ob3O;olPgb00_olPgb00?o0000oo@;m?l000002oo[5>/2o`0000Col@ka
00Co0000ooD:mOoe2_Gom@[e0_l00007oo4>l@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ool0o`00ol0003ol0o`
oo0?l009oo0?l003o`000?o^4NkokQ7^00KokQ7^00?o0000oo4>lOoa3_402?oa3_400ol0003ojQGZ
onXEjP0:onXEjP03o`000?o^4NkokQ7^00CokQ7^0ol00005onPGj003o`000?od2oCom0_d00Com0_d
1?l00006ooL8m`03o`000?of2OKomPWf00KomPWf0_l0000;ooH9mP03o`000?o`3o3ol0o`00Wol0o`
00?o0000oo8=l_ob3O802_ob3O801Ol0003om0_doo@;m?od2oCo000000cojaC[0_l000000ooa3_7o
0000ooD:m@05ooD:m@03o`000?oa3_7ol@ka00?ol@ka00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o`3o3ol0o`00Sol0o`00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ol@kaoo4>l@07oo4>l@03o`00
0?oZ5N[ojQGZ00_ojQGZ00?o0000onhAk_o^4Nh00_o^4Nh2o`0000Woj1OX00?o0000oo@;m?od2o@0
0ol0000;ooL8m`03o`000?of2OKomPWf00;omPWf0ol0000>ooH9mP03o`000?o`3o3ol0o`00Ool0o`
00?o0000oo8=l_ob3O802oob3O800ol0003om0_doo@;m002oo@;m003o`000?o[5>_ojaC[00_ojaC[
00?o0000ooD:mOoe2_D01_oe2_D2o`0000?ol@ka00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o`
3o3ol0o`00Ool0o`00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ol@kaoo4>l@05oo4>l@?o00003OoZ
5NX4o`0000_oj1OX0ol0000?ooL8m`04o`000?of2OKo0000o`00017omPWf00?o0000oo0?l?o`3o00
1oo`3o000ol0003olPgboo8=lP0:oo8=lP03o`000?od2oCom0_d00Com0_d00?o0000on/Djoo[5>/0
1oo[5>/3o`0000_om@[e1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003okQ7^onhA
kP06onhAkP03o`000?oa3_7ol@ka00;ol@ka0ol00003onl@k`03o`000?oZ5N[ojQGZ00[ojQGZ00?o
0000onPGj?oX5nP02ooX5nP00ol0003ojaC[o`00000AooL8m`03o`000?of2OKomPWf017omPWf00?o
0000oo0?l?o`3o001oo`3o000ol0003olPgboo8=lP0:oo8=lP03o`000?od2oCom0_d00Gom0_d00Co
0000on/Djoo[5>_ojaC[1Ol00002onhAkP03o`000?oe2_Gom@[e00Wom@[e00Co0000oo/4nook1?_o
n`Ck0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`3o000ol0003okQ7^onhAkP05onhAkP?o0000
00?ol@kao`000?l000001oo_4>l00ol0003ojQGZonXEjP08onXEjP?o00002_oX5nP2o`0000;ojaC[
00?o0000ooL8moog2?L03oog2?L00ol0003omPWfooH9mP0AooH9mP03o`000?o`3o3ol0o`00Ool0o`
00?o0000oo8=l_ob3O802Oob3O800ol0003om0_doo@;m007oo@;m0?o00001oo^4Nh00ol0003om@[e
ooD:m@09ooD:m@03o`000?ok1?_on`Ck00Con`Ck0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`
3o04o`0000;okQ7^0_l00003oo4>l@03o`000?o_4>ooka3_00Soka3_0_l00006onXEjP;o00000oo[
5>/00ol0003oj1OXonPGj006onPGj003o`000?o[5>_ojaC[00?ojaC[00?o0000ooL8moog2?L03_og
2?L00ol0003omPWfooH9mP0BooH9mP03o`000?o`3o3ol0o`00Gol0o`00?o0000oo8=l_ob3O802Oob
3O800ol0003om0_doo@;m008oo@;m003o`000?o^4NkokQ7^00OokQ7^00?o0000ooD:mOoe2_D02?oe
2_D00ol0003on`Ckoo/4n`07oo/4n`;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`00Col0o`0_l00004
oo@;m0;o00001Ooa3_400ol0003oka3_onl@k`0:onl@k`03o`000?oZ5N[ojQGZ00;ojQGZ00?o0000
on/Djoo[5>/01?o[5>/00ol0003oj1OXonPGj004onPGj003o`000?o[5>_ojaC[00CojaC[00?o0000
ooL8moog2?L03_og2?L00ol0003omPWfooH9mP0BooH9mP[o00002_ob3O800ol0003om0_doo@;m008
oo@;m003o`000?o^4NkokQ7^00OokQ7^00?o0000ooD:mOoe2_D02?oe2_D00ol0003on`Ckoo/4n`09
oo/4n`?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ol0o`oo0?l?o`3o02o`0000Oom0_d00?o0000oo4>lOoa3_401?oa3_40
0ol0003oka3_onl@k`0:onl@k`04o`000?oZ5N[o0000o`0000SojaC[00Co0000onPGj?oX5nSoj1OX
0_l00007on/Dj`03o`000?og2?Oom`Sg00kom`Sg00?o0000ooH9m_of2OH04_of2OH00ol0003olPgb
oo8=lP07oo8=lP03o`000?ob3O;olPgb00KolPgb00?o0000oo@;m?od2o@02_od2o@00ol0003okQ7^
onhAkP06onhAkP03o`000?oe2_Gom@[e00Som@[e00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o`
3o3o0000o`0000Wom0_d00?o0000oo4>lOoa3_401?oa3_400ol0003oka3_onl@k`0;onl@k`03o`00
0?o[5>_ojaC[00WojaC[00?o0000onPGj?l000002Oo[5>/00ol0003om`SgooL8m`0>ooL8m`;o0000
4_of2OH00ol0003olPgboo8=lP09oo8=lP;o00001_ob3O800ol0003om0_doo@;m00:oo@;m003o`00
0?o^4NkokQ7^00KokQ7^00?o0000ooD:mOoe2_D02?oe2_D00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000oo@;m?od2o@02Ood2o@00ol0003ol@kaoo4>l@05oo4>l@03o`000?o_4>ooka3_00[oka3_00?o
0000on/Djoo[5>/02_o[5>/2o`0000WojaC[00?o0000ooL8moog2?L03_og2?L00ol0003om0_do`00
0002o`0000oomPWf00?o0000oo8=l_ob3O802oob3O800ol0003olPgboo8=lP03o`0000gom0_d00?o
0000onhAk_o^4Nh01_o^4Nh00ol0003om@[eooD:m@07ooD:m@03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003om0_doo@;m009oo@;m003o`000?oa3_7ol@ka00Gol@ka00?o0000onl@koo_4>l02Oo_4>l2
o`0000_ojaC[0_l0000;on/Dj`03o`000?og2?Oom`Sg00com`Sg00?o0000oo@;m?od2o@00ood2o@3
o`0000comPWf00?o0000oo8=l_ob3O803?ob3O82o`0000;ol0o`00?o0000oo@;m?od2o@03?od2o@0
0ol0003okQ7^onhAkP05onhAkP03o`000?oe2_Gom@[e00Oom@[e00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?od2oCom0_d00[om0_d00?o0000oo4>lOoa3_401_oa3_400ol0003oka3_onl@k`07onl@
k`03o`000?o[5>_o000000[ojaC[00Co0000onLHiooW6>Oo00002_o[5>/00ol0003om`SgooL8m`0<
ooL8m`03o`000?od2oCom0_d00Kom0_d0_l00008ooH9mP;o00003oob3O800ol0003ol0o`oo0?l002
oo0?l003o`000?od2oCom0_d00_om0_d00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003om@[eooD:m@07
ooD:m@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003om0_doo@;m00:oo@;m003o`000?oa3_7ol@ka
00Kol@ka00?o0000onl@koo_4>l01_o_4>l01Ol0003ojaC[on/Djoo[5>_o000000SojaC[00?o0000
onLHiooW6>L00_oW6>L00ol0003ojaC[on/Dj`06on/Dj`Co00003?og2?L00ol0003om0_doo@;m008
oo@;m0?o00000_of2OH3o`000003oo4>lOl0003olPgb00golPgb00?o0000oo0?l?o`3o001?o`3o00
0ol0003om0_doo@;m00:oo@;m003o`000?o^4NkokQ7^00GokQ7^00?o0000ooD:mOoe2_D01_oe2_D0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo@;m?od2o@02ood2o@00ol0003ol@kaoo4>l@07oo4>
l@03o`000?o_4>ooka3_00?oka3_0_l00005on/Dj`03o`000?o[5>_ojaC[00CojaC[00?o0000onLH
iooW6>L00ooW6>L00ol0003ojaC[on/Dj`05on/Dj`03o`000?o`3o3ol0o`00;ol0o`0ol00007ooL8
m`;o00003_od2o@2o`0000Gol@ka00?o0000oo8=l_ob3O802_ob3O800ol0003ol0o`oo0?l005oo0?
l003o`000?od2oCom0_d00_om0_d00?o0000onhAk_o^4Nh01?o^4Nh00ol0003om@[eooD:m@06ooD:
m@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003om0_doo@;m00;oo@;m003o`000?oa3_7ol@ka00Oo
l@ka00?o0000onl@koo_4>l00_o_4>l00ol0003ojaC[on/Dj`06on/Dj`03o`000?o[5>_ojaC[00;o
jaC[00?o0000onLHiooW6>L01OoW6>L00ol0003ojaC[on/Dj`02on/Dj`;o00002?o`3o03o`0000;o
m`Sg0_l000000ooa3_7o0000oo@;m00=oo@;m003o`000?oa3_7ol@ka00Gol@ka00?o0000oo8=l_ob
3O802?ob3O800ol0003ol0o`oo0?l007oo0?l003o`000?od2oCom0_d00[om0_d00?o0000onhAk_o^
4Nh01?o^4Nh00ol0003om@[eooD:m@06ooD:m@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003om0_d
oo@;m00<oo@;m003o`000?oa3_7ol@ka00Sol@ka00Co0000onl@koo_4>oo00002Oo[5>/01Ol0003o
jaC[on/Djoo[5>_o000000SoiaSW00Go0000on/Djoo[5>_ojaC[o`00000=oo0?l0;o00001?oa3_40
0ol0003om0_doo@;m00;oo@;m003o`000?oa3_7ol@ka00Kol@ka00?o0000oo8=l_ob3O801oob3O80
0ol0003ol0o`oo0?l008oo0?l0Co00002?od2o@00ol0003okQ7^onhAkP04onhAkP03o`000?oe2_Go
m@[e00Kom@[e00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?od2oCom0_d00_om0_d0ol00009oo4>
l@03o`000?o_4>oo000000_ojaC[00?o0000on/Djol000002_oW6>L00ol0003ojaC[o`00000?oo0?
l003o`000?oa3_7ol@ka00;ol@ka00?o0000oo@;m?od2o@02ood2o@00ol0003ol@kaoo4>l@06oo4>
l@03o`000?ob3O;olPgb00KolPgb00?o0000oo0?l?o`3o002Oo`3o001?l0003ol`ccoo<<looc3?<7
o`0000;om0_d00?o0000onhAk_o^4Nh00oo^4Nh00ol0003om@[eooD:m@05ooD:m@03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?od2oCom0_d00Som0_d0ol00003oo0?l003o`000?oa3_7ol@ka00Ool@ka00?o0000on/D
joo[5>/02oo[5>/00ol0003oiaSWonLHi`0:onLHi`03o`000?o`3o3ol0o`00gol0o`00?o0000oo4>
lOoa3_401?oa3_400ol0003om0_doo@;m009oo@;m003o`000?oa3_7ol@ka00Sol@ka00?o0000oo8=
l_ob3O800oob3O82o`0000col0o`00?o0000oo<<looc3?<02?oc3?<<o`0000?om@[e0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000oo@;m?od2o@01_od2o@3o`0000Ool0o`00?o0000oo4>lOoa3_401_oa3_400ol0003o
jaC[on/Dj`0;on/Dj`03o`000?oW6>OoiaSW00WoiaSW0_l0000>oo0?l003o`000?oa3_7ol@ka00Go
l@ka00?o0000oo@;m?od2o@02Ood2o@00ol0003ol@kaoo4>l@09oo4>l@03o`000?ob3O;o000000;o
00000_o_4>l00ol0003ol0o`oo0?l008oo0?l003o`000?oc3??ol`cc00col`cc00?o0000ooP7n?oh
1oP01_oh1oP3o`0000?oo0?l0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003om0_doo@;m003oo@;m0?o00002oo`3o000ol0003ol@ka
oo4>l@04oo4>l@03o`000?o[5>_ojaC[00_ojaC[0ol00007onLHi`?o000000?okQ7^o`000?o`3o00
3Oo`3o000ol0003ol@kaoo4>l@06oo4>l@03o`000?od2oCom0_d00Som0_d00?o0000oo4>lOoa3_40
2_oa3_400ol0003oka3_onl@k`04onl@k`03o`000?o`3o3ol0o`00Ool0o`00?o0000oo<<looc3?<0
2ooc3?<00ol0003on0OhooP7n008ooP7n003o`000?ol0ocoo0?l00Coo0?l0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004oo@;m?l0
003o0000o`0000ool0o`00?o0000oo4>lOoa3_400ooa3_4>o`0000?ojaC[0_l00002onLHi`?o0000
1Oo^4Nh00ol0003ol0o`oo0?l00:oo0?l003o`000?oa3_7ol@ka00Ool@ka00?o0000oo@;m?od2o@0
2?od2o@00ol0003ol@kaoo4>l@0:oo4>l@03o`000?o_4>ooka3_00Goka3_00?o0000oo0?l?o`3o00
1_o`3o000ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh00Son0Oh00?o0000oo`3o?ol0o`0
1ool0o`2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;ol0o`00?o0000oo4>lOoa3_400_oa3_400ol0003oiQWVonHI
iP0:onHIiP03o`000?o[5>_ojaC[00?ojaC[0_l00009onhAkP03o`000?o`3o3ol0o`00Wol0o`00?o
0000oo4>lOoa3_402?oa3_42o`0000Som0_d00?o0000oo4>lOoa3_402Ooa3_400ol0003oka3_onl@
k`07onl@k`03o`000?o`3o3ol0o`00Col0o`00?o0000oo<<looc3?<02ooc3?<00ol0003on0OhooP7
n009ooP7n003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ol0o`oo0?l00?oo0?l0?o000000?ol@ka
o`000?oV6NH02ooV6NH00ol0003ojaC[on/Dj`04on/Dj`03o`000?o^4NkokQ7^00WokQ7^00?o0000
oo0?l?o`3o001oo`3o000ol0003ol@kaoo4>l@09oo4>l@04o`000?o`3o3o0000o`0000Kom0_d00?o
0000oo4>lOoa3_402Ooa3_400ol0003oka3_onl@k`08onl@k`03o`000?o`3o3ol0o`00?ol0o`00?o
0000oo<<looc3?<02ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003ol0o`oo0?l00<oo0?l0;o00000oo^4Nh2o`0000coiQWV00?o0000on/Djoo[5>/01?o[5>/0
0ol0003okQ7^onhAkP0:onhAkPWo00002ooa3_400ol0003ol0o`oo0?l002oo0?l0?o00000_od2o@0
0ol0003ol@kaoo4>l@0:oo4>l@03o`000?o_4>ooka3_00Woka3_00?o0000oo0?l?o`3o000_o`3o00
0ol0003ol`ccoo<<l`0:oo<<l`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o`3o02o`0000GokQ7^00?o0000onhAk_l000002_oV6NH00ol0003ojaC[on/Dj`06on/D
j`03o`000?o^4NkokQ7^00WokQ7^00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003ol@kaoo4>l@09oo4>
l@03o`000?o`3o3ol0o`00Gol0o`0ol00009oo4>l@?o00003Oo_4>l01Ol0003ol0o`oo0?l?o`3o3o
000000col`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo0?
l?o`3o001Oo`3o02o`0000OokQ7^00Co0000onhAk_o^4Nko00002OoV6NH00ol0003ojaC[on/Dj`06
on/Dj`03o`000?o^4NkokQ7^00SokQ7^00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ol@kaoo4>l@07
oo4>l@03o`000?o`3o3ol0o`00Sol0o`0ol00002oo4>l@Go00000_oX5nP00ol0003oka3_onl@k`0<
onl@k`03o`000?o`3o3o000000col`cc00?o0000ooP7n?oh1oP02_oh1oP00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000oo0?l?o`3o000_o`3o02o`0000SokQ7^00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00CoiQWV00?o0000on/Djoo[5>/01_o[5>/00ol0003okQ7^onhAkP08onhAkP03o`000?o^4NkokQ7^
00OokQ7^00?o0000oo4>lOoa3_401ooa3_400ol0003ol0o`oo0?l008oo0?l003o`000?oY5^WojAKY
00;o00002?oX5nP00ol0003oka3_onl@k`0<onl@k`Co00002_oc3?<00ol0003on0OhooP7n00:ooP7
n003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003ol0o`o`000?l0000:onhAkP03o`000?o^4NkokQ7^
00;okQ7^00?o0000om`Sg?oL8m`00_oL8m`4o`0000WojaC[00?o0000onhAk_o^4Nh02?o^4Nh00ol0
003okQ7^onhAkP08onhAkP03o`000?oa3_7ol@ka00Gol@ka00?o0000oo0?l?o`3o002?o`3o001Ol0
003ojAKYonTFjOoY5^Wo000000[oj1OX0ol0000;onl@k`04o`000?oe2_Gom@[eooD:m@Co00001Ooc
3?<00ol0003on0OhooP7n00;ooP7n003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003okQ7^onhAkP0:
onhAkP03o`000?o^4NkokQ7^00?okQ7^00?o0000om`Sg?oL8m`01?oL8m`00ol0003ojaC[on/Dj`07
on/Dj`03o`000?o^4NkokQ7^00KokQ7^0_l0000;onhAkP03o`000?oa3_7ol@ka00Gol@ka00?o0000
oo0?l?o`3o002?o`3o000ol0003ojAKYonTFj@02onTFj@03o`000?oX5nSoj1OX00Ooj1OX00?o0000
onl@koo_4>l01?l00006onl@k`03o`000?oe2_Gom@[e00Kom@[e0ol00002oo<<l`03o`000?oh1oSo
n0Oh00_on0Oh00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^4NkokQ7^00WokQ7^00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003og2?Lom`Sg005om`Sg003o`000?o[5>_ojaC[00OojaC[00?o0000onhA
k_o^4Nh00_o^4Nh3o`000003oo0?l?l0003okQ7^00[okQ7^00?o0000oo4>lOoa3_401Ooa3_400ol0
003ol0o`oo0?l007oo0?l003o`000?oY5^WojAKY00?ojAKY00?o0000onPGj?oX5nP01ooX5nP00ol0
003oka3_onl@k`04onl@k`?o00000_o_4>l00ol0003om@[eooD:m@0:ooD:m@;o00003_oh1oP00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003okQ7^onhAkP04onhAkP03
o`000?oL8mcog2?L00Kog2?L0_l00007on/Dj`03o`000?o^4Nko000000;o00001Oo`3o000ol0003o
kQ7^onhAkP08onhAkP?o00001?oa3_400ol0003ol0o`oo0?l008oo0?l003o`000?oY5^WojAKY00Co
jAKY00?o0000onPGj?oX5nP01_oX5nP00ol0003oka3_onl@k`07onl@k`;o00003_oe2_D00ol0003o
n0OhooP7n00;ooP7n003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^onhAkP08onhAkP03o`00
0?o^4NkokQ7^00GokQ7^00?o0000om`Sg?oL8m`01?oL8m`00ol0003ojQGZonXEjP03o`0000CojaC[
0_l00008oo0?l003o`000?o^4NkokQ7^00OokQ7^00Co0000oo@;m?od2oCom0_d0ol000000ooa3_7o
0000oo0?l009oo0?l003o`000?oY5^WojAKY00CojAKY00?o0000onPGj?oX5nP01OoX5nP00ol0003o
ka3_onl@k`09onl@k`03o`000?oe2_Gom@[e00gom@[e00?o0000ooP7n?oh1oP02_oh1oP00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003okQ7^onhAkP06onhAkP03o`00
0?oL8mcog2?L00?og2?L00?o0000onXEj_oZ5NX01?oZ5NX2o`000003on/Djol0003ol0o`00[ol0o`
00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003om0_doo@;m005oo@;m003o`000?o`3o3ol0o`00Ool0o`
0ol00007onTFj@03o`000?oX5nSoj1OX00Coj1OX00?o0000onl@koo_4>l02Oo_4>l00ol0003om@[e
ooD:m@0=ooD:m@03o`000?oh1oSon0Oh00[on0Oh00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^
4NkokQ7^00GokQ7^0ol00009onhAkP05o`000?oL8mcog2?Lom`Sg?l000002OoZ5NX00ol0003ol0o`
oo0?l00;oo0?l003o`000?o^4NkokQ7^00?okQ7^00?o0000oo@;m?od2o@01_od2o@00ol0003ol0o`
oo0?l006oo0?l005o`000?oa3_7ol@kaoo4>lOl000001ooY5^T00ol0003oj1OXonPGj003onPGj003
o`000?o_4>ooka3_00Woka3_00?o0000ooD:mOoe2_D03_oe2_D00ol0003on0OhooP7n009ooP7n003
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^o`000004o`0000;olPgb00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003og2?Lom`Sg?l00009onXEjP;o00003Oo`3o000ol0003okQ7^onhAkP02onhAkP03
o`000?od2oCom0_d00Som0_d00?o0000oo0?l?o`3o000oo`3o02o`0000Gol@ka00?o0000onTFjOoY
5^T01?oY5^T00ol0003oj1OXonPGj003onPGj003o`000?o_4>ooka3_00Woka3_00?o0000ooD:mOoe
2_D03_oe2_D00ol0003on0OhooP7n009ooP7n003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000SolPgb
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003og2?Lo`000009onXEjP04o`000?ob3O;olPgbo`0000go
l0o`00Co0000onhAk_o^4Nko00003?od2o@01Ol0003ol0o`oo0?l?o`3o3o000000Sol@ka0_l00005
onTFj@03o`000?oX5nSoj1OX00;oj1OX00?o0000onl@koo_4>l02Oo_4>l00ol0003om@[eooD:m@0>
ooD:m@03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ob3O;olPgb
00OolPgb00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ojQGZonXEjP07onXEjP03o`000?ob3O;olPgb
00;olPgb00?o0000oo0?l?o`3o002_o`3o000ol0003okQ7^o`00000>oo@;m003o`000?o`3o3o0000
00_ol@ka00?o0000onTFjOoY5^T00_oY5^T01Ol0003oj1OXonPGj?oX5nSo000000coka3_00?o0000
ooD:mOoe2_D03_oe2_D3o`0000Won0Oh00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb
00WolPgb00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ojQGZonXEjP06onXEjP03o`000?ob3O;olPgb
00?olPgb00?o0000oo0?l?o`3o002oo`3o000ol0003om0_doo@;m00>oo@;m003o`000?oa3_7ol@ka
00_ol@ka0_l00003onTFj@04o`000?oX5nSoj1OXo`0000[oka3_0ol0000>ooD:m@;o00000ook1?/2
o`0000Oon0Oh00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb00[olPgb00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ojQGZonXEjP06onXEjP03o`000?ob3O;olPgb00GolPgb00?o0000oo0?
l?o`3o001oo`3o03o`00017om0_d00?o0000oo4>lOoa3_403Ooa3_401Ol0003ojAKYonTFjOl0003o
j1OX00Co00000oo_4>l5o`0000;ol0o`00?o0000ooD:mOoe2_D02_oe2_D2o`0000Oon`Ck0_l00004
ooP7n003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003olPgboo8=lP0;oo8=lP03o`000?o^4NkokQ7^
00CokQ7^00?o0000onXEj_oZ5NX01OoZ5NX00ol0003olPgboo8=lP06oo8=lP03o`000?o`3o3ol0o`
00Col0o`0ol00002oo8=lP03o`000?od2oCom0_d00oom0_d0_l0000?oo4>l@04o`000?oY5^Wo0000
o`0000CokQ7^0ol00008oo0?l003o`000?oe2_Gom@[e00Oom@[e0_l0000;oo/4n`;o00000_oh1oP0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo8=l_ob3O803?ob3O86o`0000OojQGZ00?o0000oo8=
l_ob3O802?ob3O800ol0003ol0o`oo0?l003o`0000KolPgb00?o0000oo@;m?od2o@03Ood2o@01?l0
003ol`ccoo<<lol0000?oo4>l@03o`000?o^4NkokQ7^00GokQ7^00?o0000oo0?l?o`3o002?o`3o00
0ol0003om@[eooD:m@05ooD:m@03o`000?ok1?_on`Ck00gon`Ck0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ob3O800ol0003okA;]ondBk@04ondB
k@03o`000?oZ5N[ojQGZ00?ojQGZ00?o0000oo8=l_ob3O802_ob3O82o`0000[olPgb00?o0000oo@;
m?od2o@02ood2o@00ol0003ol`ccoo<<l`02oo<<l`03o`000?oa3_7ol@ka00_ol@ka0_l00007onhA
kP03o`000?o`3o3ol0o`00Wol0o`00?o0000ooD:mOoe2_D00_oe2_D2o`0001;on`Ck00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000oo8=l_ob3O802oob3O800ol0003okA;]ondBk@06ondBk@05o`000?oZ5N[ojQGZonXE
j_l000003Oob3O800ol0003olPgboo8=lP0:oo8=lP03o`000?od2oCom0_d00Wom0_d00?o0000oo<<
looc3?<01?oc3?<00ol0003ol@kaoo4>l@08oo4>l@;o000000?ojAKYo`000?o^4Nh01oo^4Nh00ol0
003ol0o`oo0?l009oo0?l004o`000?oe2_Go0000o`0001Con`Ck00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ob3O;olPgb
00WolPgb00?o0000ondBkOo]4^d02?o]4^d00ol0003ojQGZo`00000=oo8=lP03o`000?ob3O;olPgb
00_olPgb00?o0000oo@;m?od2o@02?od2o@00ol0003ol`ccoo<<l`06oo<<l`03o`000?oa3_7ol@ka
00Gol@ka0_l00003onTFj@03o`000?o^4NkokQ7^00KokQ7^00?o0000oo0?l?o`3o002_o`3o000ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003olPgboo8=lP07oo8=lP03o`000?o]4^gokA;]00[okA;]00?o0000oo8=l_ob
3O803?ob3O800ol0003olPgboo8=lP0<oo8=lP03o`000?od2oCom0_d00Kom0_d00?o0000oo<<looc
3?<02?oc3?<00ol0003ol@kaoo4>l@02oo4>l@;o00001_oY5^T00ol0003okQ7^onhAkP05onhAkP03
o`000?o`3o3ol0o`00[ol0o`00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ob3O;olPgb00GolPgb
00?o0000ondBkOo]4^d03?o]4^d2o`0000colPgb00?o0000oo8=l_ob3O803Oob3O800ol0003om0_d
oo@;m004oo@;m003o`000?oc3??ol`cc00[ol`cc00Co0000oo4>lOl0003o00002?oY5^T00ol0003o
kQ7^onhAkP06onhAkP03o`000?o`3o3ol0o`00Wol0o`00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_ob3O800ol0003okA;]ondBk@0=ondBk@03o`000?o`3o3o000000;o00002?ob3O800ol0003olPgb
oo8=lP0?oo8=lPKo00003_oc3?<00ol0003ojAKYonTFj@08onTFj@03o`000?o^4NkokQ7^00KokQ7^
00?o0000oo0?l?o`3o002Oo`3o000ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000oo0?l?o`3o3ol0o`
0_l0000?ondBk@03o`000?o`3o3ol0o`00?ol0o`0ol00005oo8=lP;o00004?ob3O801_l0003oka3_
onl@kol0003ojaC[o`0000kol`cc00?o0000onTFjOoY5^T02OoY5^T00ol0003okQ7^onhAkP05onhA
kP03o`000?o`3o3ol0o`00Wol0o`00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000oo0?l?o`3o000oo`3o000ol0003o
kA;]ondBk@0=ondBk@03o`000?o`3o3ol0o`00Kol0o`0ol000001?ob3O;o0000oo0?l?o`3o03o`00
00colPgb00Go0000onl@koo_4>ooka3_o`000002on/Dj`03o`000?oc3??ol`cc00_ol`cc00?o0000
onTFjOoY5^T02OoY5^T00ol0003okQ7^onhAkP06onhAkP03o`000?o`3o3ol0o`00Sol0o`0_l0000A
oo/4n`?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ol0o`oo0?l004oo0?l0oo00003?o`3o000ol0003ol0o`oo0?l004oo0?
l0?o00002?ob3O800ol0003oka3_onl@k`02onl@k`05o`000?o[5>_ojaC[on/Djol000003?oc3?<0
0ol0003ojAKYonTFj@09onTFj@03o`000?o^4NkokQ7^00GokQ7^3?l00002oo8=lP;o00003Ook1?/2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ol0o`oo0?l005oo0?l003o`000?oY5^WojAKY00_ojAKY00?o0000oo0?
l?o`3o002_o`3o000ol0003ol0o`oo0?l007oo0?l0;o00001Oob3O800ol0003oka3_onl@k`03onl@
k`03o`000?o[5>_ojaC[00;ojaC[00?o0000oo<<looc3?<02Ooc3?<00ol0003ojAKYonTFj@0:onTF
j@03o`000?o^4NkokQ7^00?okQ7^00?o0000onPGj?oX5nP02OoX5nP00ol0003olPgboo8=lP02oo8=
lP;o00002Ook1?/2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ol0o`oo0?l006oo0?l003o`000?oY5^WojAKY00[o
jAKY00?o0000oo0?l?o`3o002oo`3o000ol0003ol0o`oo0?l009oo0?l0?o000000?olPgbo`000?o_
4>l01Oo_4>l00ol0003ojaC[on/Dj`03on/Dj`03o`000?oc3??ol`cc00Sol`cc3_l00003onhAkP;o
00002ooX5nP00ol0003olPgboo8=lP05oo8=lP03o`000?ok1?_on`Ck00?on`Ck0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000oo0?l?o`3o001Oo`3o000ol0003ok1?/o`00000;onTFj@03o`000?o`3o3ol0o`00[ol0o`
0_l0000>oo0?l003o`000?o_4>ooka3_00Goka3_00?o0000on/Djoo[5>/00oo[5>/00ol0003ol`cc
oo<<l`08oo<<l`03o`000?o`3o3ol0o`00_ol0o`00?o0000onhAk_l000003OoX5nP00ol0003olPgb
oo8=lP06oo8=lP;o000000?on`Cko`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o`3o3ol0o`00Kol0o`00Co
0000on`Ck?o/4nco00002_oY5^T00ol0003ol0o`oo0?l009oo0?l003o`000?o_4>oo000000kol0o`
00?o0000onl@koo_4>l01Oo_4>l00ol0003ojaC[on/Dj`04on/Dj`03o`000?oc3??ol`cc00Kol`cc
00?o0000oo0?l?o`3o003Oo`3o000ol0003oj1OXonPGj00<onPGj003o`000?ob3O;olPgb00SolPgb
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o`3o3ol0o`00Gol0o`00?o0000on`Ck?o/4n`00_o/
4n`00ol0003ojAKYonTFj@06onTFj@03o`000?o`3o3ol0o`00Sol0o`0_l00003onl@k`03o`000?o`
3o3ol0o`00_ol0o`00?o0000onl@koo_4>l01Oo_4>l00ol0003ojaC[on/Dj`05on/Dj`03o`000?oc
3??ol`cc00Gol`cc00?o0000oo0?l?o`3o003Oo`3o000ol0003oj1OXonPGj00;onPGj003o`000?ob
3O;olPgb00WolPgb00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o`3o3ol0o`00Kol0o`00?o0000
on`Ck?o/4n`00oo/4n`00ol0003ojAKYonTFj@05onTFj@03o`000?o`3o3ol0o`00Ool0o`00?o0000
onl@koo_4>l00oo_4>l00ol0003ol0o`oo0?l00:oo0?l003o`000?o_4>ooka3_00Koka3_00?o0000
on/Djoo[5>/01_o[5>/00ol0003ol`ccoo<<l`04oo<<l`03o`000?o`3o3ol0o`00gol0o`3ol0000;
oo8=lP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?o`3o3ol0o`00Kol0o`00?o0000on`Ck?o/4n`01Oo/4n`00ol0
003ojAKYonTFj@04onTFj@03o`000?o`3o3ol0o`00Gol0o`0_l00006onl@k`03o`000?o`3o3ol0o`
00Wol0o`0_l00008onl@k`03o`000?o[5>_ojaC[00KojaC[1Ol000000ooc3??o0000oo0?l00?oo0?
l003o`000?oV6NKoiQWV00_oiQWV00?o0000oo8=l_ob3O802Oob3O800ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?o`3o3ol0o`00Kol0o`00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
jAKYonTFj@04o`0000Kol0o`00?o0000onl@koo_4>l01oo_4>l00ol0003ol0o`oo0?l005oo0?l0?o
000000?okA;]o`000?o_4>l01oo_4>l00ol0003ojaC[on/Dj`05on/Dj`03o`000?od2oCom0_d00?o
m0_d0_l0000?oo0?l0;o00003OoV6NH00ol0003olPgboo8=lP08oo8=lP03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000Wol0o`00?o0000on`Ck?o/4n`01oo/4n`2o`0000Com0_d00Co0000oo0?l?o`3o3o
l0o`0_l0000:onl@k`03o`000?o`3o3ol0o`00;ol0o`0ol00005ondBk@03o`000?o_4>ooka3_00Go
ka3_00?o0000on/Djoo[5>/01?o[5>/00ol0003om0_doo@;m006oo@;m003o`000?o`3o3ol0o`00[o
l0o`0_l00002onl@k`03o`000?oV6NKoiQWV00[oiQWV00?o0000oo8=l_ob3O802?ob3O800ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000oo0?l?o`3o001_o`3o000ol0003ok1?/on`Ck008on`Ck003o`00
0?od2oCom0_d00Com0_d00?o0000oo0?l?l000003?o_4>l00ol0003ol0o`o`000002o`0000WokA;]
00?o0000onl@koo_4>l01?o_4>l00ol0003ojaC[on/Dj`03on/Dj`03o`000?od2oCom0_d00Som0_d
1_l00004oo0?l0;o00001Oo_4>l00ol0003oiQWVonHIiP09onHIiP03o`000?ob3O;olPgb00SolPgb
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o`3o3ol0o`00Gol0o`00?o0000on`Ck?o/4n`01oo/
4n`00ol0003om0_doo@;m006oo@;m003o`000?o_4>ooka3_00coka3_00?o0000ondBkOo]4^d02_o]
4^d00ol0003oka3_onl@k`04onl@k`04o`000?o[5>_ojaC[on/Dj`;o00002ood2o@00ol0003olPgb
oo8=lP03oo8=lPCo00002?o_4>l00ol0003oiQWVonHIiP08onHIiP03o`000?ob3O;olPgb00OolPgb
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000oo0?l?o`3o000oo`3o000ol0003ok1?/on`Ck007on`Ck003o`000?od
2oCom0_d00Oom0_d00?o0000onl@koo_4>l03?o_4>l00ol0003okA;]ondBk@0;ondBk@03o`000?o_
4>ooka3_00?oka3_00Co0000on/Djoo[5>_o00003Ood2o@00ol0003olPgboo8=lP06oo8=lP03o`00
0?o_4>ooka3_00Ooka3_00?o0000onHIi_oV6NH01ooV6NH00ol0003olPgboo8=lP06oo8=lP04o`00
0?ok1?_on`Ckoo/4n`;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o`3o3ol0o`00;ol0o`00?o0000on`Ck?o/4n`0
1_o/4n`00ol0003om0_doo@;m009oo@;m003o`000?o_4>ooka3_00Woka3_0_l0000>ondBk@?o0000
0oo_4>l00ol0003ojaC[o`00000=oo@;m003o`000?ob3O;olPgb00OolPgb00?o0000onl@koo_4>l0
2?o_4>l:o`0000KolPgb0_l00006oo/4n`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000Ook1?/00?o
0000oo@;m?od2o@02_od2o@00ol0003oka3_onl@k`06onl@k`;o000000?oka3_o`000?o]4^d02oo]
4^d2o`0000?om0_d1Ol0000>oo@;m003o`000?ob3O;olPgb00OolPgb00?o0000onl@koo_4>l02?o_
4>l00ol0003ok1?/on`Ck006on`Ck003o`000?ob3O;olPgb00?olPgb00?o0000oo/4nook1?/01ook
1?/2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003ol`ccoo<<l`03oo<<l`Co00000_o/4n`00ol0003om0_doo@;m00;
oo@;m003o`000?o_4>ooka3_00?oka3_0ol00004onl@k`03o`000?o]4^gokA;]00OokA;]0_l00008
oo@;m003o`000?od2oCom0_d00gom0_d00?o0000oo8=l_ob3O802?ob3O800ol0003oka3_onl@k`07
onl@k`03o`000?o/4ncok1?/00Ook1?/0ol000000oob3O;o0000oo/4n`0;oo/4n`;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oc3??ol`cc00Ool`cc0_l0000?oo@;m003o`000?o_4>ooka3_00;o00002?o_4>l00ol0
003okA;]ondBk@05ondBk@03o`000?od2oCom0_d00Som0_d00?o0000oo@;m?od2o@03Ood2o@00ol0
003olPgboo8=lP08oo8=lP03o`000?o_4>ooka3_00Koka3_00?o0000on`Ck?o/4n`02?o/4n`01?l0
003ol@kaoo4>lOl0000?oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003ol`ccoo<<l`09oo<<
l`03o`000?od2oCom0_d00kom0_d0_l0000;onl@k`03o`000?o]4^gokA;]00;okA;]0_l0000;oo@;
m003o`000?od2oCom0_d00gom0_d00?o0000oo8=l_ob3O802?ob3O800ol0003oka3_onl@k`06onl@
k`03o`000?o/4ncok1?/00Ook1?/00Go0000oo4>lOoa3_7ol@kao`00000@oo/4n`;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003ol`ccoo<<l`0:oo<<l`03o`000?od2oCom0_d00gom0_d0_l0000<onl@k`04o`000?o]4^go0000
o`0000gom0_d00?o0000oo@;m?od2o@03?od2o@00ol0003olPgboo8=lP09oo8=lP03o`000?o_4>oo
ka3_00Koka3_00?o0000on`Ck?o/4n`01_o/4n`00ol0003ol@kaoo4>l@03oo4>l@03o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003ol`ccoo<<l`0:oo<<l`03o`000?od2oCom0_d00com0_d00Co0000onHI
i_oV6NKo00003?o_4>l00ol0003om0_doo@;m00>oo@;m003o`000?od2oCom0_d00Som0_d1?l0000;
oo8=lP03o`000?o_4>ooka3_00Koka3_00?o0000on`Ck?o/4n`01Oo/4n`00ol0003ol@kaoo4>l@04
oo4>l@03o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003ol`ccoo<<l`0;oo<<l`03o`000?od2oCom0_d
00_om0_d00?o0000onHIi_oV6NH00_oV6NH00ol0003oka3_onl@k`09onl@k`03o`000?od2oCom0_d
00kom0_d00Co0000oo@;m?od2oCom0_d1ol00003oo@;m003o`000?ob3O;olPgb00WolPgb00?o0000
onl@koo_4>l01_o_4>l00ol0003ok1?/on`Ck004on`Ck003o`000?oa3_7ol@ka00Kol@ka00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oc3??ol`cc00col`cc00?o0000oo@;m?od2o@02_od2o@00ol0
003oiQWVonHIiP03onHIiP03o`000?o_4>ooka3_00Soka3_00?o0000oo@;m?od2o@03_od2o@4o`00
00_om0_d00?o0000oo8=l_ob3O802?ob3O800ol0003oka3_onl@k`05onl@k`03o`000?o/4ncok1?/
00Gok1?/00?o0000oo4>lOoa3_401_oa3_400ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000oo<<looc
3?<03?oc3?<7o`0000Gom0_d00?o0000onHIi_oV6NH01OoV6NH00ol0003oka3_onl@k`07onl@k`03
o`000?od2oCom0_d00kom0_d00?o0000oo@;m?od2o@03Ood2o@00ol0003olPgboo8=lP08oo8=lP03
o`000?o_4>ooka3_00Coka3_00?o0000on`Ck?o/4n`01?o/4n`00ol0003ol@kaoo4>l@07oo4>l@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oc3??ol`cc00Col`cc
1Ol00009onHIiP03o`000?o_4>ooka3_00Koka3_00?o0000oo@;m?od2o@03_od2o@00ol0003om0_d
oo@;m00=oo@;m003o`000?ob3O;olPgb00SolPgb00Co0000onl@koo_4>ooka3_1Ol00004on`Ck003
o`000?oa3_7ol@ka00Wol@ka1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=oo<<l`03o`000?oc3??ol`cc00Wol`cc
0_l00009onHIiP03o`000?o_4>ooka3_00Koka3_00?o0000oo@;m?od2o@03?od2o@00ol0003om0_d
oo@;m00?oo@;m0Ko00001?ob3O84o`0000Gol`cc0_l000000oo/4nco0000oo4>l@0;oo4>l@04o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?ob3O;olPgboo8=lP?o00002_oc3?<00ol0003o
l`ccoo<<l`09oo<<l`03o`000?oY5^Wo000000;o00001ooV6NH00ol0003oka3_onl@k`05onl@k`03
o`000?od2oCom0_d00Som0_d1Ol0000Aoo@;m003o`000?ob3O;olPgb00?olPgb1?l0000;oo<<l`03
o`000?oa3_7ol@ka00[ol@ka00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000oo8=l_ob3O801Oob3O82o`0000Ool`cc
00?o0000oo<<looc3?<02_oc3?<00ol0003ojAKYonTFj@02onTFj@?o00001OoV6NH00ol0003oka3_
onl@k`04onl@k`04o`000?od2oCom0_doo@;m0Oo00001?oa3_400ol0003om0_doo@;m00>oo@;m003
o`000?ob3O;olPgb00OolPgb00?o0000oo<<looc3?<02Ooc3?<00ol0003ol@kaoo4>l@09oo4>l@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003olPgboo8=lP08oo8=lP;o00001?oc3?<00ol0003ol`cc
oo<<l`0;oo<<l`03o`000?oY5^WojAKY00GojAKY0ol00003onHIiP04o`000?o_4>ooka3_onl@k`Ko
00003?oa3_400ol0003om0_doo@;m00=oo@;m003o`000?ob3O;olPgb00OolPgb00?o0000oo<<looc
3?<02_oc3?<00ol0003ol@kaoo4>l@08oo4>l@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo8=lP?o000000?ol`cco`000?oc3?<0
3?oc3?<00ol0003ojAKYonTFj@08onTFj@?o000000CoiQWVo`000?l0003o00000_od2o@00ol0003o
l@kaoo4>l@0=oo4>l@03o`000?od2oCom0_d00com0_d00?o0000oo8=l_ob3O802?ob3O800ol0003o
l`ccoo<<l`0;oo<<l`03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
lPgb00?o0000oo<<looc3?<03?oc3?<00ol0003ojAKYonTFj@0;onTFj@03o`000?od2oCom0_d00?o
m0_d00?o0000oo4>lOoa3_403?oa3_400ol0003ok1?/o`00000=oo@;m003o`000?ob3O;olPgb00So
lPgb00?o0000oo<<looc3?<03?oc3?<3o`0000Gol@ka00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?ob3O;olPgb00colPgb00?o0000oo<<looc3?<03?oc3?<00ol0003ojAKYonTFj@0:onTFj@03o`00
0?od2oCom0_d00Gom0_d00?o0000oo4>lOoa3_402_oa3_401?l0003ok1?/on`Ck?o/4n`2o`0000[o
m0_d00?o0000oo8=l_ob3O802Oob3O800ol0003ol`ccoo<<l`0<oo<<l`03o`000?oc3??ol`cc00?o
000000?ol@kao`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?ob3O;olPgb00_olPgb00?o0000oo<<looc3?<0
3?oc3?<00ol0003ojAKYonTFj@09onTFj@03o`000?od2oCom0_d00Kom0_d00?o0000oo4>lOoa3_40
2Ooa3_400ol0003ok1?/on`Ck002on`Ck003o`000?oc3??o000000;o00001ood2o@00ol0003olPgb
oo8=lP09oo8=lP03o`000?oc3??ol`cc00_ol`cc00?o0000oo<<looc3?<01?oc3?<00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000oo8=l_ob3O802oob3O800ol0003ol`ccoo<<l`0;oo<<l`03o`000?oY
5^WojAKY00SojAKY00?o0000oo@;m?od2o@01ood2o@00ol0003ol@kaoo4>l@08oo4>l@03o`000?o/
4ncok1?/00?ok1?/00?o0000oo<<looc3?<00_oc3?<2o`0000Com0_d00?o0000oo8=l_ob3O802_ob
3O800ol0003ol`ccoo<<l`0:oo<<l`03o`000?oc3??ol`cc00Gol`cc00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?ob3O;olPgb00[olPgb0ol0000;oo<<l`Ko00001?oY5^T00ol0003om0_doo@;m008
oo@;m003o`000?oa3_7ol@ka00Ool@ka00?o0000on`Ck?o/4n`00oo/4n`00ol0003ol`ccoo<<l`05
oo<<l`?o000000?om0_do`000?ob3O802oob3O800ol0003ol`ccoo<<l`09oo<<l`03o`000?oc3??o
l`cc00Ool`cc00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?ob3O;olPgb00WolPgb00?o0000onhA
k_o^4Nh01?l00006oo<<l`03o`000?ob3O;olPgb00ColPgb1?l0000<oo@;m003o`000?oa3_7ol@ka
00Gol@ka00?o0000on`Ck?o/4n`01?o/4n`00ol0003ol`ccoo<<l`08oo<<l`03o`000?ob3O;olPgb
00_olPgb00?o0000oo<<looc3?<02?oc3?<00ol0003ol`ccoo<<l`08oo<<l`Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?ob3O;olPgb00OolPgb00?o0000onhAk_o^4Nh01Oo^4Nh3o`0000;ol`cc00?o0000oo8=l_ob
3O802?ob3O800ol0003om0_doo@;m00:oo@;m003o`000?oa3_7ol@ka00Col@ka00?o0000on`Ck?o/
4n`01Oo/4n`00ol0003ol`ccoo<<l`08oo<<l`03o`000?ob3O;olPgb00WolPgb1?l00008oo<<l`03
o`000?oc3??ol`cc00Wol`cc00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003olPgb
oo8=lP05oo8=lP03o`000?o^4NkokQ7^00WokQ7^0_l0000<oo8=lP03o`000?od2oCom0_d00Wom0_d
00?o0000oo4>lOoa3_400ooa3_400ol0003ok1?/on`Ck005on`Ck003o`000?oc3??ol`cc00[ol`cc
00?o0000oo8=l_ob3O801?ob3O84o`0000ColPgb00?o0000oo<<looc3?<01?oc3?<00ol0003ol`cc
oo<<l`0:oo<<l`03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ob3O;olPgb00?olPgb00?o0000onhAk_o^4Nh02oo^
4Nh00ol0003olPgboo8=lP0:oo8=lP03o`000?od2oCom0_d00Wom0_d00?o0000oo4>lOoa3_400_oa
3_400ol0003ok1?/on`Ck006on`Ck003o`000?oc3??ol`cc00[ol`cc00?o0000oo8=l_ob3O801?l0
0009oo8=lPKo00003?oc3?<00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000oo8=l_ob3O;olPgb0_l0
000=onhAkP03o`000?ob3O;olPgb00[olPgb00?o0000oo@;m?od2o@02Ood2o@01Ol0003ol@kaoo4>
lOoa3_7o000000Wok1?/00?o0000oo<<looc3?<02ooc3?<2o`0000golPgb00?o0000oo8=l_ob3O80
0_ob3O800ol0003ol`ccoo<<l`0:oo<<l`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003olPgbo`00
0002on/Dj`;o00002oo^4Nh00ol0003olPgboo8=lP0;oo8=lP03o`000?od2oCom0_d00Wom0_d00?o
0000oo4>lOl000002Oo/4n`00ol0003ol`ccoo<<l`0<oo<<l`03o`000?ob3O;olPgb00colPgb00?o
0000oo8=l_ob3O800oob3O800ol0003ol`ccoo<<l`09oo<<l`03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ojaC[on/Dj`03on/Dj`;o00002_o^4Nh00ol0003olPgboo8=lP0:oo8=lP03o`000?od2oCo
m0_d00Som0_d1Ol00008on`Ck003o`000?oc3??ol`cc00col`cc00?o0000oo8=l_ob3O802oob3O80
0ol0003olPgboo8=lP05oo8=lP03o`000?oc3??ol`cc00Sol`cc00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001oo[5>/2o`0000SokQ7^00?o0000oo8=l_ob3O802_ob3O800ol0003om0_doo@;m007oo@;
m003o`000?oa3_7ol@ka00?ol@ka0ol00005on`Ck003o`000?oc3??ol`cc00_ol`cc00?o0000oo8=
l_ob3O803?ob3O800ol0003olPgboo8=lP06oo8=lP03o`000?oc3??ol`cc00Ool`cc00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000WojaC[00?o0000onhAk_o^4Nh01Oo^4Nh2o`0000co
lPgb00?o0000oo@;m?od2o@01Ood2o@00ol0003ol@kaoo4>l@07oo4>l@?o000000?ok1?/o`000?oc
3?<03Ooc3?<00ol0003olPgboo8=lP0<oo8=lP03o`000?ob3O;olPgb00KolPgb00?o0000oo<<looc
3?<01_oc3?<00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?o[5>_ojaC[00OojaC[
0_l00004onhAkP03o`000?o]4^gokA;]00;o00002_ob3O800ol0003om0_doo@;m003oo@;m0;o0000
3Ooa3_42o`0000gol`cc0ol0000=oo8=lP03o`000?ob3O;olPgb00OolPgb00?o0000oo<<looc3?<0
1Ooc3?<00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?o[5>_ojaC[00SojaC[0_l0
00000oo^4Nko0000ondBk@04ondBk@03o`000?ob3O;olPgb00OolPgb00Co0000oo@;m?od2oCom0_d
0_l00002oo0?l003o`000?oa3_7ol@ka00col@ka3Ol00003on`Ck003o`000?ob3O;olPgb00[olPgb
00?o0000oo8=l_ob3O802?ob3O801?l0003ol`ccoo<<looc3?<4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003ojaC[
on/Dj`09on/Dj`03o`000?o]4^gokA;]00GokA;]0_l00008oo8=lP03o`000?od2oCo000000Gol0o`
00?o0000oo4>lOoa3_402ooa3_400ol0003ol@kaoo4>l@09oo4>l@03o`000?o/4ncok1?/00;ok1?/
0_l00009oo8=lP03o`000?ob3O;olPgb00[olPgb0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?o[5>_ojaC[00SojaC[00?o0000ondBkOo]4^d01oo]4^d4o`0000?olPgb0ol0
0007oo0?l003o`000?oa3_7ol@ka00[ol@ka00?o0000oo4>lOoa3_402Ooa3_400ol0003ok1?/on`C
k004on`Ck0;o00001oob3O800ol0003olPgboo8=lP0:oo8=lP03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?o[5>_ojaC[00OojaC[00?o0000ondBkOo]4^d02?o]4^d0
1?l0003okQ7^onhAk_o^4Nh3o`0000;oka3_00?o0000oo0?l?o`3o001_o`3o000ol0003ol@kaoo4>
l@08oo4>l@03o`000?oa3_7ol@ka00[ol@ka00?o0000on`Ck?o/4n`01_o/4n`00ol0003olPgboo8=
lP04oo8=lP03o`000?ob3O;olPgb00WolPgb00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000on/Djoo[5>/01Oo[5>/00ol0003okA;]ondBk@08ondBk@03o`000?o^4Nko
kQ7^00CokQ7^00Go0000onl@koo_4>ooka3_o`000008oo0?l003o`000?oa3_7ol@ka00Ool@ka00?o
0000oo4>lOoa3_402_oa3_400ol0003ok1?/on`Ck007on`Ck0;o00001?ob3O800ol0003olPgboo8=
lP08oo8=lP03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on/Djoo[5>/00oo[5>/0
0ol0003okA;]ondBk@08ondBk@03o`000?o^4NkokQ7^00CokQ7^00?o0000onl@koo_4>l00_o_4>l0
0ol0003ol0o`oo0?l007oo0?l003o`000?oa3_7ol@ka00Kol@ka00?o0000oo4>lOoa3_402_oa3_40
0ol0003ok1?/on`Ck009on`Ck005o`000?ob3O;olPgboo8=l_l000002Oob3O800ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_okA;]00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oka3_onl@k`03
onl@k`03o`000?o`3o3ol0o`00Ool0o`00?o0000oo4>lOoa3_401Ooa3_400ol0003ol@kaoo4>l@0:
oo4>l@03o`000?o/4ncok1?/00Wok1?/1?l00009oo8=lP03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?o`3o3ol0o`
oo0?l?l000002_o]4^d00ol0003okQ7^onhAkP05onhAkP03o`000?o_4>ooka3_00?oka3_00?o0000
oo0?l?o`3o002?o`3o000ol0003ol@kaoo4>l@04oo4>l@03o`000?oa3_7ol@ka00Wol@ka00?o0000
on`Ck?o/4n`02?o/4n`2o`0000?ol0o`00?o0000oo8=l_ob3O801_ob3O800ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo0?l?o`3o000oo`3o000ol0003okA;]ondBk@06ondBk@03o`000?o^4NkokQ7^
00GokQ7^00?o0000onl@koo_4>l01?o_4>l00ol0003ol0o`oo0?l009oo0?l003o`000?oa3_7ol@ka
00;ol@ka00?o0000oo4>lOoa3_402_oa3_400ol0003ok1?/on`Ck006on`Ck0;o00001_o`3o08o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003ol0o`oo0?l005oo0?l003o`000?o]4^gokA;]00GokA;]00?o0000onhAk_o^
4Nh01Oo^4Nh00ol0003oka3_onl@k`05onl@k`03o`000?o`3o3ol0o`00Wol0o`00Go0000oo4>lOoa
3_7ol@kao`00000<oo4>l@03o`000?o/4ncok1?/00Cok1?/0_l00008oo0?l003o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?o`3o3ol0o`00Ool0o`00?o0000ondBkOo]
4^d00oo]4^d00ol0003okQ7^onhAkP06onhAkP03o`000?o_4>ooka3_00Goka3_00?o0000oo0?l?o`
3o002_o`3o000ol0003ol@kao`000004o`0000Wol@ka00?o0000on`Ck?o/4n`00_o/4n`2o`0000[o
l0o`00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003ol0o`oo0?l007oo0?l003o`00
0?o]4^gokA;]00;okA;]00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oka3_onl@k`07onl@k`;o0000
2oo`3o000ol0003ol0o`oo0?l003oo0?l0Oo00000_oa3_400ol0003ok1?/on`Ck002o`0000_ol0o`
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo0?l?o`3o002Oo`
3o001Ol0003okA;]ondBkOo]4^go000000SokQ7^00?o0000onl@koo_4>l01oo_4>l00ol0003ol@ka
o`000002o`0000Sol0o`00?o0000oo0?l?o`3o002_o`3o05o`0000gol0o`00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<oo0?l003o`000?o]4^go000000WokQ7^00?o
0000onl@koo_4>l01_o_4>l00ol0003ol@kaoo4>l@03oo4>l@?o00001?o`3o000ol0003ol0o`oo0?
l00=oo0?l003o`000?o`3o3ol0o`00gol0o`00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ook1?/2o`0000_ol0o`00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oka3_onl@k`07
onl@k`03o`000?oa3_7ol@ka00Kol@ka0ol000000oo`3o3o0000oo0?l00>oo0?l003o`000?o`3o3o
l0o`00col0o`00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009oo0?
l003o`000?o^4NkokQ7^00;okQ7^1_l00008onl@k`03o`000?oa3_7ol@ka00[ol@ka00?o0000oo0?
l?o`3o003oo`3o000ol0003ol0o`oo0?l00:oo0?l0;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007oo0?l0Go00001_od2o@00ol0003oka3_onl@k`05onl@k`03o`000?oa3_7ol@ka00[o
l@ka00?o0000oo0?l?o`3o003oo`3o000ol0003ol0o`oo0?l007oo0?l0?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005oo0?l003o`000?od2oCom0_d00Wom0_d00?o0000onl@koo_
4>l00oo_4>l00ol0003ol@kaoo4>l@0;oo4>l@03o`000?o`3o3ol0o`00ool0o`00?o0000oo0?l?o`
3o001Oo`3o02o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?ol0o`o`000?l00000
3Ood2o@00ol0003oka3_onl@k`02onl@k`03o`000?oa3_7ol@ka00_ol@ka5?l00004oo0?l0;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003on`Cko`00000>oo@;m004o`000?o_4>ooka3_o`0000kol@ka
00?o0000oo<<looc3?<04?oc3?<00ol0003ol0o`o`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000003_od2o@00ol0003oka3_o`00000>oo4>l@03o`00
0?oc3??ol`cc017ol`cc00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00_ok1?/00ol0003om0_doo@;m00=oo@;m003o`000?oa3_7ol@ka00Wol@ka1Ol0
000Boo<<l`;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/01?ok1?/0
0ol0003om0_doo@;m00<oo@;m003o`000?oa3_7ol@ka00;ol@ka1ol00004oo/4n`03o`000?oc3??o
l`cc00ool`cc00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?od2oCom0_d00com0_d1?l0000<oo/4n`03o`000?oc3??ol`cc00col`cc0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000oo@;m?od2o@03?od2o@00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oc3??ol`cc00_o
l`cc00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/02Ook1?/00ol0003om0_doo@;m00:oo@;m003o`000?ok1?_on`Ck00kon`Ck00?o0000oo<<looc
3?<02Ooc3?<2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?oc3??ol`cc00Kol`cc0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003on`Ck00gon`Ck3?l0
000Aoo/4n`?o00001_oc3?<00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000ooc3?<2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000oo<<lol000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01ol00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo000:o`00o`;oool02?l00?l2oooo00?o003o00?oool0o`00ool00?l01_l0
0?l2oooo06go003o0Oooool007;o003o0_ooo`06o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03
o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000:o`00o`;oool01ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`07o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000:o`00o`;oool01ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1]o`00o`7ooooo001ao`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0:o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06go003o0Oooool006oo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`002_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Ooo
ool006oo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3
oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1]o`00o`7ooooo001_o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00
o`7ooooo001^o`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o
003o0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00
K_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00[o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1]o`00o`7ooooo001^o`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o0_ooo`07o`00o`;oool01?l0
0?l2oooo00Ko003o00?o<S;<oooo0?ooo`00KOl00?l1ooooo`00KOl00?l3oooo00Go003o0oooo`07
o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05o`00o`Coool02?l00?l2oooo00;o003o0_ooo`05
o`00o`Goool0KOl00?l1ooooo`00K?l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
02;o003o0_ooo`09o`00o`Coool0N?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(20) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.979 .021 .979 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.978 .022 .978 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.978 .022 .978 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.979 .021 .979 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.886 .114 .886 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.979 .021 .979 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.879 .121 .879 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.92 .08 .92 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.91 .09 .91 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.981 .019 .981 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.882 .118 .882 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.979 .021 .979 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.91 .09 .91 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.888 .112 .888 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.98 .02 .98 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.909 .091 .909 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.882 .118 .882 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.981 .019 .981 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.98 .02 .98 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.875 .125 .875 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.897 .103 .897 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.783 .217 .783 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.849 .151 .849 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.849 .151 .849 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.854 .146 .854 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.918 .082 .918 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.905 .095 .905 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.863 .137 .863 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.885 .115 .885 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.858 .142 .858 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.886 .114 .886 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.908 .092 .908 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.979 .021 .979 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.914 .086 .914 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.869 .131 .869 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.933 .067 .933 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.903 .097 .903 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.851 .149 .851 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.979 .021 .979 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.925 .075 .925 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.891 .109 .891 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.904 .096 .904 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.892 .108 .892 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.862 .138 .862 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.896 .104 .896 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.864 .136 .864 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.979 .021 .979 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.861 .139 .861 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.828 .172 .828 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.927 .073 .927 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.933 .067 .933 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.871 .129 .871 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.864 .136 .864 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.907 .093 .907 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.979 .021 .979 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.922 .078 .922 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.912 .088 .912 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.9 .1 .9 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.737 .263 .737 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.859 .141 .859 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.905 .095 .905 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.928 .072 .928 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.844 .156 .844 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.805 .195 .805 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.811 .189 .811 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.835 .165 .835 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.916 .084 .916 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.838 .162 .838 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.879 .121 .879 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.867 .133 .867 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.905 .095 .905 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.912 .088 .912 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.899 .101 .899 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.918 .082 .918 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.979 .021 .979 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.845 .155 .845 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.875 .125 .875 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.831 .169 .831 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.979 .021 .979 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.926 .074 .926 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.894 .106 .894 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.805 .195 .805 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.846 .154 .846 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.913 .087 .913 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.876 .124 .876 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.888 .112 .888 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.904 .096 .904 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.816 .184 .816 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.874 .126 .874 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.883 .117 .883 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.867 .133 .867 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.911 .089 .911 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.921 .079 .921 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.916 .084 .916 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.823 .177 .823 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.866 .134 .866 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.914 .086 .914 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.879 .121 .879 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.88 .12 .88 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.895 .105 .895 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.874 .126 .874 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.856 .144 .856 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.84 .16 .84 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.979 .021 .979 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.844 .156 .844 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.893 .107 .893 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.856 .144 .856 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.882 .118 .882 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.909 .091 .909 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.979 .021 .979 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.916 .084 .916 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.898 .102 .898 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.904 .096 .904 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.915 .085 .915 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.881 .119 .881 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.866 .134 .866 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.885 .115 .885 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.889 .111 .889 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.98 .02 .98 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.931 .069 .931 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.906 .094 .906 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.931 .069 .931 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.852 .148 .852 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.867 .133 .867 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.806 .194 .806 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.872 .128 .872 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.871 .129 .871 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.915 .085 .915 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.935 .065 .935 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.843 .157 .843 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.978 .022 .978 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.891 .109 .891 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.88 .12 .88 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.919 .081 .919 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.906 .094 .906 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.885 .115 .885 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.902 .098 .902 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.929 .071 .929 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.847 .153 .847 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.887 .113 .887 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.908 .092 .908 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.954 .046 .954 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.844 .156 .844 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.884 .116 .884 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.907 .093 .907 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.911 .089 .911 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.98 .02 .98 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.864 .136 .864 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.979 .021 .979 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.923 .077 .923 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.924 .076 .924 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.912 .088 .912 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.877 .123 .877 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.849 .151 .849 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.887 .113 .887 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.893 .107 .893 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.92 .08 .92 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.927 .073 .927 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.927 .073 .927 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.899 .101 .899 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.954 .046 .954 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.896 .104 .896 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.878 .122 .878 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.826 .174 .826 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.831 .169 .831 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.88 .12 .88 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.899 .101 .899 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.979 .021 .979 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.908 .092 .908 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.891 .109 .891 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.822 .178 .822 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.916 .084 .916 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.928 .072 .928 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.875 .125 .875 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.979 .021 .979 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.864 .136 .864 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.903 .097 .903 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.903 .097 .903 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.979 .021 .979 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.881 .119 .881 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.895 .105 .895 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.918 .082 .918 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.905 .095 .905 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.872 .128 .872 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.96 .04 .96 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.874 .126 .874 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.934 .066 .934 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.884 .116 .884 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.82 .18 .82 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.812 .188 .812 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.85 .15 .85 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.898 .102 .898 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.912 .088 .912 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.917 .083 .917 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.927 .073 .927 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.917 .083 .917 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.954 .046 .954 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.884 .116 .884 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.979 .021 .979 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.901 .099 .901 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.923 .077 .923 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.908 .092 .908 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.9 .1 .9 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.929 .071 .929 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.923 .077 .923 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.904 .096 .904 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.979 .021 .979 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.91 .09 .91 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.912 .088 .912 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.979 .021 .979 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.955 .045 .955 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.98 .02 .98 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.978 .022 .978 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.945 .055 .945 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.98 .02 .98 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.905 .095 .905 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.98 .02 .98 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.843 .157 .843 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.893 .107 .893 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.867 .133 .867 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.943 .057 .943 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.931 .069 .931 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.916 .084 .916 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.94 .06 .94 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.919 .081 .919 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.923 .077 .923 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.921 .079 .921 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.89 .11 .89 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.884 .116 .884 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.981 .019 .981 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.89 .11 .89 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.888 .112 .888 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.98 .02 .98 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.904 .096 .904 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.932 .068 .932 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.889 .111 .889 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.903 .097 .903 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.936 .064 .936 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.833 .167 .833 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.979 .021 .979 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.909 .091 .909 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.979 .021 .979 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.979 .021 .979 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.979 .021 .979 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.979 .021 .979 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.979 .021 .979 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003oj1OXonPGj?l0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000onPGj?oX5nP00_oX5nP00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oX5nSoj1OX00?oj1OX00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000onPGj?oX5nP01OoX5nP00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oj1OXonPGj006onPGj003
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000onPGj?oX5nP02?oX5nP00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oS7>?o0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000coj1OX00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003on<Lh`03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ok1?/on`Ck005on`Ck003o`000?oX
5nSoj1OX00_oj1OX0ol00003on/Dj`03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
on<LhooS7><00ooS7><00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003ok1?/on`Ck006
on`Ck003o`000?oX5nSoj1OX00[oj1OX00?o0000on/Djoo[5>/01?o[5>/00ol0003onPGjooX5nP0:
ooX5nP04o`000?o]4^gokA;]ondBk@;o00002_oj1OX2o`000003onhAk_l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003ohacSon<Lh`05on<Lh`03o`000?oj1O[o
nPGj00WonPGj00?o0000omdRgOl000002ooj1OX00ol0003ok1?/on`Ck006on`Ck003o`000?oX5nSo
j1OX00Woj1OX00?o0000on/Djoo[5>/01_o[5>/00ol0003onPGjooX5nP08ooX5nP03o`000?o]4^go
kA;]00CokA;]0_l00005ooX5nP?o00001?o^4Nh00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008on<Lh`03o`000?oj1O[onPGj00OonPGj0_l00003omdR
g@03o`000?oj1O[onPGj00OonPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003oj1OXonPGj009onPG
j003o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj1OX01Ooj1OX2o`0000WokA;]0_l000000ooj
1O[o0000o`000007onhAkP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000on<LhooS
7><02?oS7><00ol0003onPGjooX5nP06ooX5nP03o`000?oM8]gogB;M00?ogB;M00?o0000ooX5n_oj
1OX01ooj1OX00ol0003ok1?/on`Ck008on`Ck003o`000?oX5nSoj1OX00Ooj1OX00?o0000on/Djoo[
5>/02Oo[5>/00ol0003onPGjooX5nP03ooX5nP03o`000?o]4^gokA;]00_okA;]00?o0000onhAk_o^
4Nh01oo^4Nh00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003oiQWVo`000005ooX5nP;o00002ooS7><2o`0000KonPGj
00?o0000omdRgOoM8]d01OoM8]d00ol0003onPGjooX5nP06ooX5nP03o`000?o/4ncok1?/00Sok1?/
00?o0000onPGj?oX5nP01_oX5nP00ol0003ojaC[on/Dj`0;on/Dj`05o`000?oj1O[onPGjooX5n_l0
00003_o]4^d00ol0003okQ7^onhAkP08onhAkP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oV6NKoiQWVonHIi_l0
00000ooj1OX00ol0003ohacSon<Lh`0:on<Lh`04o`000?o[5>_ojaC[o`0000?onPGj0_l00008omdR
g@03o`000?oj1O[onPGj00KonPGj00?o0000on`Ck?o/4n`02Oo/4n`00ol0003oj1OXonPGj005onPG
j003o`000?o[5>_ojaC[00cojaC[00?o0000ooX5n_l000003oo]4^d00ol0003okQ7^onhAkP08onhA
kP03o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oiQWVonHIiP03onHIiP03o`000?oj1O[o000000_o
hacS0_l00004on/Dj`03o`000?oj1O[o000000_ogB;M00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
k1?/on`Ck009on`Ck003o`000?oX5nSoj1OX00Coj1OX00?o0000on/Djoo[5>/03_o[5>/00ol0003o
kA;]ondBk@0>ondBk@03o`000?o^4NkokQ7^00WokQ7^00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000onHIi_oV6NH0
1?oV6NH00ol0003ohacSon<Lh`09on<Lh`03o`000?o[5>_ojaC[00GojaC[00?o0000omdRgOoM8]d0
2_oM8]d00ol0003onPGjooX5nP05ooX5nP03o`000?o/4ncok1?/00[ok1?/00?o0000onPGj?oX5nP0
0ooX5nP00ol0003ojaC[on/Dj`0>on/Dj`03o`000?o]4^gokA;]00gokA;]00?o0000onhAk_o^4Nh0
2_o^4Nh00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oiQWVonHI
iP05onHIiP03o`000?oS7>?ohacS00OohacS0_l00008on/Dj`03o`000?oM8]gogB;M00_ogB;M00?o
0000ooX5n_oj1OX01?oj1OX00ol0003ok1?/on`Ck00:on`Ck004o`000?oX5nSoj1OXonPGj0?o0000
3oo[5>/00ol0003okA;]ondBk@0>ondBk@03o`000?o^4NkokQ7^00[okQ7^00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oV6NKoiQWV00OoiQWV00?o0000on<LhooS7><01?oS7><2o`0000_ojaC[1?l0
0009omdRg@03o`000?oj1O[onPGj00?onPGj00?o0000on`Ck?o/4n`02oo/4n`01?l0003oj1OXo`00
0?l00003ondBk@;o00003?o[5>/2o`00013okA;]00?o0000onhAk_o^4Nh02oo^4Nh00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003oiQWV
onHIiP07onHIiP03o`000?oS7>?ohacS00?ohacS00?o0000on/Djoo[5>/02oo[5>/01?l0003okQ7^
onhAk_o^4Nh5o`0000GogB;M00?o0000ooX5n_oj1OX00_oj1OX00ol0003ok1?/on`Ck00<on`Ck003
o`000?o]4^gokA;]00GokA;]0_l00008on/Dj`;o00000_oZ5NX00ol0003okA;]ondBk@0=ondBk@03
o`000?o^4NkokQ7^00_okQ7^00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003oiQWVonHIiP09onHIiP03o`000?oS7>?ohacS00;o0000
3Oo[5>/00ol0003okQ7^onhAkP07onhAkPKo00000_oj1OX4o`0000gok1?/00?o0000ondBkOo]4^d0
1oo]4^d2o`0000GojaC[00?o0000onXEj_oZ5NX00ooZ5NX00ol0003okA;]ondBk@0<ondBk@03o`00
0?o^4NkokQ7^00cokQ7^00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oV6NKoiQWV00WoiQWV00?o
0000on<Lhol000003oo[5>/00ol0003okQ7^onhAkP0<onhAkP?o00001?o]4^d3o`0000Wok1?/00?o
0000ondBkOo]4^d02_o]4^d2o`000003on/Djol0003o000000OojQGZ00?o0000ondBkOo]4^d02oo]
4^d00ol0003okQ7^onhAkP0<onhAkP03o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oj1O[onPGj00KonPGj00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oV6NKoiQWV00_oiQWV00?o0000
on/Djoo[5>/03_o[5>/00ol0003okQ7^onhAkP0=onhAkP03o`000?o]4^gokA;]00KokA;]0ol00005
on`Ck003o`000?o]4^gokA;]00gokA;]00?o0000onXEj_oZ5NX02?oZ5NX00ol0003okA;]ondBk@09
ondBk@03o`000?o^4NkokQ7^00gokQ7^00Co0000ooX5n_oj1O[onPGj1Ol00003onhAkP03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
onHIi_oV6NH02ooV6NH2o`0000oojaC[00?o0000onhAk_o^4Nh03Oo^4Nh00ol0003okA;]ondBk@0:
ondBk@?o000000?ok1?/o`000?o]4^d03oo]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?o]4^go
kA;]00SokA;]00?o0000onhAk_o^4Nh03_o^4Nh3o`0000SokQ7^00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oV6NKoiQWV00SoiQWV0ol000000ooW
6>Oo0000on/Dj`0>on/Dj`03o`000?o^4NkokQ7^00gokQ7^00?o0000ondBkOo]4^d03Oo]4^d00ol0
003okA;]ondBk@0?ondBk@03o`000?oZ5N[ojQGZ00[ojQGZ2ol0000;onhAkPGo00003?o^4Nh00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02_oj1OX01Ol0003ok1?/o`000?oj1O[o0000
00SoiQWV0ol00005onLHi`03o`000?o[5>_ojaC[00cojaC[00?o0000onhAk_o^4Nh03Oo^4Nh00ol0
003okA;]ondBk@0=ondBk@;o00004?o]4^d00ol0003ojQGZonXEjP0:onXEjP03o`000?o/4ncok1?/
00Ook1?/00?o0000onhAk_o^4Nh00_o^4Nh7o`0000CojQGZ00?o0000onhAk_o^4Nh02_o^4Nh00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02Ooj1OX01?l0003ok1?/on`Ck?o/4n`2o`00
00GoiQWV0ol00009onLHi`;o00002oo[5>/00ol0003okQ7^onhAkP0=onhAkP03o`000?o]4^gokA;]
00gokA;]00Co0000oo@;m?od2oCo00003oo]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?o/4nco
k1?/00Wok1?/1?l0000;onXEjP03o`000?o^4NkokQ7^00[okQ7^00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5
nP03o`000?oj1O[onPGj00SonPGj00?o0000on`Ck?o/4n`01?o/4n`00ol0003oiQWVo`000002o`00
00coiaSW00Co0000ondBkOl0003o00002Oo[5>/00ol0003okQ7^onhAkP0=onhAkP03o`000?o]4^go
kA;]00gokA;]00Go0000oo@;m?od2oCom0_do`00000=ondBk@03o`000?oZ5N[ojQGZ00[ojQGZ00?o
0000on`Ck?o/4n`02Oo/4n`00ol0003ojQGZonXEjP0<onXEjP03o`000?o^4NkokQ7^00[okQ7^00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000on`Ck?o/4n`01_o/4n`0
0ol0003oiaSWonLHi`0<onLHi`03o`000?o]4^gokA;]00;okA;]0_l00007on/Dj`03o`000?o^4Nko
kQ7^00cokQ7^00?o0000ondBkOo]4^d03Oo]4^d00ol0003om0_doo@;m003oo@;m003o`000?o]4^go
kA;]00[okA;]00?o0000onXEj_oZ5NX02_oZ5NX00ol0003ok1?/on`Ck009on`Ck003o`000?oZ5N[o
jQGZ00cojQGZ00?o0000onhAk_o^4Nh02oo^4Nh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5
n_oj1OX01_oj1OX00ol0003ok1?/on`Ck006on`Ck003o`000?oW6>OoiaSW00_oiaSW00?o0000ondB
kOo]4^d01Oo]4^d00ol0003ojaC[on/Dj`03on/Dj`03o`000?o^4NkokQ7^00gokQ7^00?o0000ondB
kOo]4^d03Oo]4^d00ol0003om0_doo@;m004oo@;m003o`000?o]4^gokA;]00WokA;]00?o0000onXE
j_oZ5NX02OoZ5NX00ol0003ok1?/on`Ck00:on`Ck003o`000?oZ5N[ojQGZ00cojQGZ00?o0000onhA
k_o^4Nh02oo^4Nh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
k1?/on`Ck007on`Ck003o`000?oW6>OoiaSW00_oiaSW00?o0000ondBkOo]4^d01_o]4^d2o`0000?o
jaC[00?o0000onhAk_o^4Nh03Oo^4Nh00ol0003okA;]ondBk@0<ondBk@03o`000?od2oCom0_d00Ko
m0_d00?o0000ondBkOo]4^d02?o]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?o/4ncok1?/00[o
k1?/00?o0000onXEj_oZ5NX03?oZ5NX00ol0003okQ7^onhAkP0;onhAkP03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooX5nP03o`00
0?oj1O[onPGj00ConPGj00?o0000on`Ck?o/4n`02?o/4n`00ol0003oiaSWonLHi`0:onLHi`03o`00
0?o]4^gokA;]00WokA;]0_l000000oo[5>_o0000onhAkP0<onhAkP?o00003_o]4^d00ol0003om0_d
oo@;m007oo@;m003o`000?o]4^gokA;]00OokA;]00?o0000onXEj_oZ5NX02OoZ5NX00ol0003ok1?/
on`Ck00;on`Ck003o`000?oZ5N[ojQGZ00cojQGZ00?o0000onhAk_o^4Nh02_o^4Nh00ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000on`Ck?o/4n`02_o/4n`00ol0003oiaSWonLH
i`09onLHi`03o`000?o]4^gokA;]00_okA;]00?o0000onhAk_o^4Nh02_o^4Nh2o`0000?oka3_00?o
0000ondBkOo]4^d02_o]4^d00ol0003om0_doo@;m009oo@;m003o`000?o]4^gokA;]00KokA;]00?o
0000onXEj_oZ5NX02?oZ5NX00ol0003ok1?/on`Ck00<on`Ck003o`000?oZ5N[ojQGZ00cojQGZ00?o
0000onhAk_o^4Nh02_o^4Nh00ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ooj1OX0
0ol0003onPGjooX5nP02ooX5nP03o`000?o/4ncok1?/00_ok1?/00?o0000onLHiooW6>L02?oW6>L0
0ol0003okA;]ondBk@0<ondBk@03o`000?o^4NkokQ7^00SokQ7^0_l00006onl@k`;o00002_o]4^d0
0ol0003om0_doo@;m00:oo@;m003o`000?o]4^gokA;]00GokA;]00?o0000onXEj_oZ5NX02?oZ5NX0
0ol0003ok1?/on`Ck00<on`Ck003o`000?oZ5N[ojQGZ00cojQGZ00?o0000onhAk_o^4Nh02oo^4Nh0
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?onPGj00Go0000ooX5n_oj1O[onPGjo`00000=
on`Ck003o`000?oW6>OoiaSW00OoiaSW00?o0000ondBkOo]4^d03_o]4^d00ol0003okQ7^onhAkP04
onhAkP?o00002_o_4>l00ol0003okA;]ondBk@07ondBk@03o`000?od2oCom0_d00_om0_d00?o0000
ondBkOo]4^d00oo]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?o/4ncok1?/00cok1?/00?o0000
onXEj_oZ5NX03?oZ5NX00ol0003okQ7^onhAkP0;onhAkP;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003ok1?/on`Ck00<on`Ck003o`000?oW6>OoiaSW00OoiaSW00?o0000ondBkOo]4^d03oo]4^d01?l0
003okQ7^onhAk_o^4Nh2o`0000koka3_0_l00006ondBk@03o`000?od2oCom0_d00gom0_d00?o0000
ondBkOo]4^d00_o]4^d00ol0003ojQGZonXEjP08onXEjP03o`000?o/4ncok1?/00cok1?/0ol0000=
onXEjP03o`000?o^4NkokQ7^00_okQ7^00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00ook1?/00?o0000onLHiooW6>L01_oW6>L00ol0003okA;]ondBk@0@ondBk@Co00004_o_4>l00ol0
003okA;]ondBk@03ondBk@03o`000?od2oCom0_d00kom0_d00Go0000ondBkOo]4^gokA;]o`000005
onXEjPOo00003?o/4n`01Ol0003oiaSWonLHiooW6>Oo000000cojQGZ00?o0000onhAk_o^4Nh02?o^
4Nh3o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000ook1?/00?o0000onLHiooW6>L01_oW6>L00ol0003okA;]ondBk@0=
ondBk@?o000000CojAKYo`000?l0003o00004oo_4>l2o`0000;okA;]00?o0000oo@;m?od2o@04?od
2o@00ol0003okA;]o`000006o`0000Oom0_d00?o0000on`Ck?o/4n`02?o/4n`00ol0003oiaSWonLH
i`03onLHi`;o00002?oZ5NX3o`0000KokQ7^1?l00002onl@k`03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003ogaoOo`000?oY5^T3o`0000gok1?/00?o0000onLHiooW6>L01?oW6>L00ol0003okA;]ondB
k@0;ondBk@?o00000ooY5^T01Ol0003ojAKYo`000?oZ5N[o000001Coka3_00?o0000ondBkOl00000
4ood2o@00ol0003om0_doo@;m00=oo@;m003o`000?o/4ncok1?/00Gok1?/0_l00008onLHi`03o`00
0?oZ5N[ojQGZ00Go00000oo[5>/00ol0003okQ7^onhAkP03o`0000Ooka3_00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oO7moogaoOo`0000CojAKY0ol0000:on`Ck003o`000?oW6>OoiaSW00?oiaSW
00?o0000ondBkOo]4^d02Oo]4^d3o`0000GojAKY00Co0000onTFjOoY5^Wo00000_oZ5NX00ol0003o
ka3_onl@k`0Bonl@k`03o`000?od2oCom0_d01;om0_d00?o0000oo@;m?od2o@03_od2o@00ol0003o
k1?/on`Ck003on`Ck003o`000?oW6>OoiaSW00WoiaSW0_l00009on/Dj`;o00002_o_4>l00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000omlOgooO7moogaoOo`000007onTFj@;o00001oo/4n`5o`0000;o
iaSW00?o0000ondBkOo]4^d01_o]4^d3o`0000SojAKY00Co0000onTFjOoY5^Wo00000ooZ5NX00ol0
003oka3_onl@k`0Aonl@k`03o`000?od2oCom0_d017om0_d00?o0000oo@;m?od2o@04?od2o@01Ol0
003ok1?/on`Ck?o/4nco000000coiaSW00?o0000on/Djoo[5>/02?o[5>/00ol0003oka3_onl@k`0:
onl@k`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CogaoO00?o0000onTFjOoY5^T01ooY5^T3o`00
0004on`Ck?l0003o0000o`0000Gok1?/0_l00006ondBk@?o00002_oY5^T01Ol0003ojAKYonTFjOoY
5^Wo000000CojQGZ00?o0000onl@koo_4>l04?o_4>l00ol0003om0_doo@;m00Aoo@;m003o`000?od
2oCom0_d017om0_d00?o0000on`Ck?l000003OoW6>L00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_
4>ooka3_00[oka3_00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oO7moogaoO00CogaoO00?o0000
onTFjOoY5^T02_oY5^T00ol0003ok1?/on`Ck008on`Ck003o`000?o]4^gokA;]00?o00003OoY5^T0
1Ol0003ojAKYonTFjOoY5^Wo000000GojQGZ00?o0000onl@koo_4>l03oo_4>l00ol0003om0_doo@;
m00Aoo@;m003o`000?od2oCom0_d01;om0_d00?o0000onLHiooW6>L03?oW6>L00ol0003ojaC[on/D
j`08on/Dj`03o`000?o_4>ooka3_00_oka3_00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000omlOgooO7ml01OoO7ml0
0ol0003ojAKYonTFj@0:onTFj@03o`000?o/4ncok1?/00Wok1?/0_l0000?onTFj@03o`000?oY5^Wo
jAKY00;ojAKY00?o0000onXEj_oZ5NX01?oZ5NX00ol0003oka3_onl@k`0=onl@k`?o00004Ood2o@0
0ol0003om0_doo@;m00Coo@;m003o`000?oW6>OoiaSW00_oiaSW00?o0000on/Djoo[5>/02Oo[5>/0
0ol0003oka3_onl@k`0;onl@k`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oO7ml0
0ol0003ojAKYonTFj@0:onTFj@03o`000?o/4ncok1?/00Wok1?/00?o0000onTFjOoY5^T03OoY5^T0
0ol0003ojAKYonTFj@03onTFj@03o`000?oZ5N[ojQGZ00GojQGZ00?o0000onl@koo_4>l02_o_4>l2
o`0000?om0_d00?o0000oo@;m?od2o@03_od2o@00ol0003om0_doo@;m00Coo@;m003o`000?oW6>Oo
iaSW00_oiaSW00?o0000on/Djoo[5>/02Oo[5>/00ol0003oka3_onl@k`0;onl@k`03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000omlOgooO7ml01ooO7ml2o`0000_ojAKY00?o0000on`C
k?o/4n`02oo/4n`00ol0003ojAKYonTFj@0<onTFj@03o`000?oY5^WojAKY00?ojAKY00?o0000onXE
j_oZ5NX01_oZ5NX00ol0003oka3_onl@k`07onl@k`;o00001_od2o@2o`0000kom0_d00?o0000oo@;
m?od2o@04ood2o@00ol0003oiaSWonLHi`0;onLHi`03o`000?o[5>_ojaC[00WojaC[00?o0000onl@
koo_4>l03?o_4>l00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009omlO
g`03o`000?o8=lSo000000_ojAKY00?o0000on`Ck?o/4n`02oo/4n`00ol0003ojAKYonTFj@0;onTF
j@03o`000?oY5^WojAKY00CojAKY00?o0000onXEj_oZ5NX01ooZ5NX00ol0003oka3_onl@k`05onl@
k`03o`000?od2oCom0_d00Som0_d00?o0000oo@;m?od2o@02_od2o@00ol0003om0_doo@;m00Doo@;
m003o`000?oW6>OoiaSW00_oiaSW00?o0000on/Djoo[5>/02Oo[5>/00ol0003oka3_onl@k`0<onl@
k`03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009omlOg`04o`000?o8=lSob3O8o`00
00_ojAKY00?o0000on`Ck?o/4n`02oo/4n`00ol0003ojAKYonTFj@0;onTFj@03o`000?oY5^WojAKY
00CojAKY00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oka3_onl@k`02onl@k`;o00003?od2o@2o`00
00[om0_d00?o0000oo@;m?od2o@05?od2o@00ol0003oiaSWonLHi`0;onLHi`03o`000?o[5>_ojaC[
00WojaC[00?o0000onl@koo_4>l03Oo_4>l00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ogaoOomlOg`07omlOg`03
o`000?o8=lSob3O800;ob3O800?o0000onTFjOoY5^T02?oY5^T00ol0003ok1?/on`Ck00<on`Ck003
o`000?oY5^WojAKY00WojAKY00?o0000onTFjOoY5^T01OoY5^T00ol0003ojQGZonXEjP09onXEjP04
o`000?o_4>oo0000o`00013om0_d0_l00008oo@;m003o`000?od2oCom0_d01Com0_d0ol0000;onLH
i`03o`000?o[5>_ojaC[00WojaC[00?o0000onl@koo_4>l03Oo_4>l01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003ogaoOomlOg`06omlOg`03o`000?o8=lSob3O800?ob3O800?o0000onTF
jOoY5^T02?oY5^T00ol0003ok1?/on`Ck00;on`Ck0;o00002_oY5^T00ol0003ojAKYonTFj@06onTF
j@03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo@;m?od2o@04_od2o@00ol0003om0_doo@;m004oo@;
m003o`000?od2oCom0_d01Gom0_d00?o0000oo4>lOoa3_401Ol00005onLHi`03o`000?o[5>_ojaC[
00[ojaC[00?o0000onl@koo_4>l03_o_4>l3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ogaoOomlOg`04omlOg`03
o`000?o8=lSob3O800Cob3O800?o0000onTFjOoY5^T01ooY5^T00ol0003ok1?/on`Ck00;on`Ck004
o`000?o]4^gokA;]o`0000WojAKY00?o0000onTFjOoY5^T01_oY5^T00ol0003ojQGZonXEjP0:onXE
jP03o`000?od2oCom0_d01?om0_d0_l00003oo@;m0Co00005?od2o@00ol0003ol@kaoo4>l@06oo4>
l@Co000000?oiaSWo`000?o[5>/02oo[5>/00ol0003oka3_onl@k`0>onl@k`03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003ogaoOomlOg`03omlOg`03o`000?o8=lSob3O800Gob3O800?o0000onTFjOoY
5^T01ooY5^T00ol0003ok1?/on`Ck009on`Ck0;o00001?o]4^d00ol0003ojAKYonTFj@05onTFj@03
o`000?oY5^WojAKY00OojAKY00?o0000onXEj_oZ5NX02_oZ5NX00ol0003om0_doo@;m00Eoo@;m003
o`000?od2oCo000000Com@[e0ol0000@oo@;m003o`000?oa3_7ol@ka00_ol@ka0_l0000<on/Dj`03
o`000?o_4>ooka3_00coka3_0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000omlOgooO7ml00_oO7ml00ol0003ob3O8
olPgb006olPgb003o`000?oY5^WojAKY00OojAKY00?o0000on`Ck?o/4n`02?o/4n`00ol0003okA;]
ondBk@05ondBk@03o`000?oY5^WojAKY00CojAKY00?o0000onTFjOoY5^T01ooY5^T00ol0003ojQGZ
onXEjP0:onXEjP03o`000?od2oCom0_d01Kom0_d00?o0000ooD:mOoe2_D01_oe2_D3o`0000com0_d
00?o0000oo4>lOoa3_403Ooa3_400ol0003ojaC[on/Dj`09on/Dj`Go00002Oo_4>l2o`000003onPG
j?l0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003omlOgol0003ob3O800Wob3O800?o0000onTFjOoY5^T01_oY
5^T00ol0003ok1?/on`Ck007on`Ck003o`000?o]4^gokA;]00OokA;]00?o0000onTFjOoY5^T00_oY
5^T00ol0003ojAKYonTFj@08onTFj@03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo@;m?od2o@05ood
2o@00ol0003om@[eooD:m@09ooD:m@?o00002Ood2o@00ol0003ol@kaoo4>l@0>oo4>l@Ko00001?o[
5>/00ol0003ohacSon<Lh`03on<Lh`Go00000_o_4>l2o`0000Coj1OX00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?oQ7^7ohAkQon4NhOl000002oo8=lP00ol0003ojAKYonTFj@06onTFj@03o`000?o/
4ncok1?/00Gok1?/0_l0000;ondBk@04o`000?oY5^WojAKYo`0000_ojAKY00?o0000onXEj_oZ5NX0
2OoZ5NX00ol0003om0_doo@;m00Foo@;m003o`000?oe2_Gom@[e00gom@[e0ol00005oo@;m003o`00
0?oa3_7ol@ka00ool@ka00?o0000oo0?l?o`3o000oo`3o04o`0000_ohacS0_l00006onPGj003o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003ohAkQon4Nh@02on4Nh@ko00001_oY5^T00ol0003ok1?/on`C
k005on`Ck003o`000?o]4^gokA;]00cokA;]00?o0000onTFjOl000002ooY5^T00ol0003ojQGZonXE
jP07onXEjP?o00006?od2o@00ol0003om@[eooD:m@0@ooD:m@?o000000?om0_do`000?oa3_404?oa
3_400ol0003ol0o`oo0?l007oo0?l003o`000?oS7>?ohacS00[ohacS00?o0000onPGj?oX5nP01OoX
5nP00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005on4Nh@03o`000?oI9]WofBKI00_ofBKI0_l00004
onTFj@03o`000?o/4ncok1?/00?ok1?/0_l0000@ondBk@03o`000?oY5^WojAKY00[ojAKY00?o0000
onXEj_oZ5NX00ooZ5NX4o`0000;oiaSW00?o0000oo@;m?od2o@05Ood2o@00ol0003om@[eooD:m@0D
ooD:m@03o`000?oa3_7ol@ka013ol@ka00?o0000oo0?l?o`3o001oo`3o000ol0003ohacSon<Lh`0:
on<Lh`03o`000?oX5nSoj1OX00Goj1OX00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oQ7^7ohAkQ
00GohAkQ00?o0000omTVfOoI9]T03OoI9]T6o`0000?ok1?/00?o0000ondBkOo]4^d04?o]4^d00ol0
003ojAKYonTFj@0:onTFj@03o`000?oZ5N[o000000?o00001ooW6>L00ol0003om0_doo@;m00Doo@;
m003o`000?oe2_Gom@[e01Com@[e00?o0000oo4>lOoa3_403ooa3_400ol0003ol0o`oo0?l008oo0?
l003o`000?oS7>?ohacS00[ohacS00?o0000onPGj?oX5nP01OoX5nP00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000on4NhOoQ7^401_oQ7^400ol0003ofBKIomTVf@0=omTVf@03o`000?o^4NkokQ7^00?o
kQ7^00?o0000on`Ck?l000004oo]4^d4o`0000WojAKY0_l0000<onLHi`03o`000?od2oCom0_d01?o
m0_d00?o0000ooD:mOoe2_D05Ooe2_D00ol0003ol@kaoo4>l@0>oo4>l@03o`000?o`3o3ol0o`00So
l0o`00?o0000on<LhooS7><02OoS7><00ol0003oj1OXonPGj007onPGj003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?oQ7^7ohAkQ00SohAkQ00?o0000omTVfOoI9]T02ooI9]T00ol0003okQ7^onhAkP05onhAkP03o`00
0?o]4^gokA;]01;okA;]00Co0000onXEj_oZ5N[ojQGZ1Ol00003onTFj@03o`000?oW6>OoiaSW00go
iaSW0ol0000@oo@;m0;o00006?oe2_D00ol0003ol@kaoo4>l@0=oo4>l@03o`000?o`3o3ol0o`00Wo
l0o`00?o0000on<LhooS7><02OoS7><00ol0003oj1OXonPGj007onPGj003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_ohAkQ00?o0000omTVfOoI9]T02_oI9]T00ol0003okQ7^onhAkP06onhAkP03o`00
0?o]4^gokA;]017okA;]00?o0000onXEj_oZ5NX01ooZ5NX3o`00013oiaSW00?o0000onHIi_oV6NH0
1Ol00009oo@;m0;o000000?ojaC[o`000?oe2_D05ooe2_D00ol0003ol@kaoo4>l@0=oo4>l@03o`00
0?o`3o3ol0o`00Wol0o`00?o0000on<LhooS7><02?oS7><2o`0000[oj1OX00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oQ7^7ohAkQ00;ohAkQ00?o0000on4NhOoQ7^402OoQ7^400ol0003ofBKIomTV
f@0:omTVf@03o`000?o^4NkokQ7^00OokQ7^00?o0000ondBkOo]4^d03oo]4^d00ol0003ojQGZonXE
jP0:onXEjP03o`000?oW6>OoiaSW00goiaSW00?o0000onHIi_oV6NH01_oV6NH4o`0000Com0_d00?o
0000on/Djoo[5>/00_o[5>/00ol0003om@[eooD:m@0FooD:m@03o`000?oa3_7ol@ka00_ol@ka00?o
0000oo0?l?o`3o002oo`3o000ol0003ohacSon<Lh`06on<Lh`03o`000?oE:]Go000000[oj1OX00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000on4NhOoQ7^402?oQ7^4=
o`0000[okQ7^00?o0000ondBkOo]4^d03oo]4^d00ol0003ojQGZonXEjP0;onXEjP03o`000?oW6>Oo
iaSW00coiaSW00?o0000onHIi_oV6NH02_oV6NH4o`0000GojaC[00?o0000ooD:mOoe2_D05_oe2_D0
0ol0003ol@kaoo4>l@0:oo4>l@03o`000?o`3o3ol0o`00col0o`00?o0000on<LhooS7><01?oS7><2
o`0000?oeB[E00?o0000onPGj?oX5nP02?oX5nP00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000on4N
hOoQ7^400ooQ7^400ol0003ohAkQon4Nh@07on4Nh@03o`000?oI9]WofBKI00WofBKI00?o0000onhA
k_o^4Nh02Oo^4Nh00ol0003okA;]ondBk@0=ondBk@03o`000?oZ5N[ojQGZ00cojQGZ00?o0000onLH
iooW6>L03?oW6>L00ol0003oiQWVonHIiP0;onHIiP03o`000?oP7n3o000000KojaC[00?o0000ooD:
mOoe2_D05_oe2_D00ol0003ol@kaoo4>l@09oo4>l@03o`000?o`3o3ol0o`00col0o`00?o0000on<L
hooS7><00ooS7><00ol0003oeB[EomDZe@03omDZe@03o`000?oX5nSoj1OX00Soj1OX00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oQ7^7ohAkQ00CohAkQ00?o0000on4NhOoQ7^401_oQ7^400ol0003o
fBKIomTVf@08omTVf@03o`000?o^4NkokQ7^00_okQ7^00?o0000ondBkOo]4^d02?o]4^d4o`0000oo
jQGZ00?o0000onLHiooW6>L02ooW6>L00ol0003oiQWVonHIiP0;onHIiP04o`000?oP7n3oh1oPo`00
00OojaC[00?o0000ooD:mOoe2_D05Ooe2_D00ol0003ol@kaoo4>l@08oo4>l@03o`000?o`3o3ol0o`
00gol0o`00?o0000on<LhooS7><00_oS7><00ol0003oeB[EomDZe@05omDZe@03o`000?oX5nSoj1OX
00Ooj1OX00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oQ7^7ohAkQ00GohAkQ00?o0000on4NhOoQ
7^401OoQ7^400ol0003ofBKIomTVf@08omTVf@03o`000?o^4NkokQ7^00_okQ7^00?o0000ondBkOo]
4^d00oo]4^d5o`0000?ojQGZ00?o0000onXEj_oZ5NX03_oZ5NX00ol0003oiaSWonLHi`0:onLHi`03
o`000?oV6NKoiQWV00[oiQWV00Go0000on0Oh?oP7n3oh1oPo`000007on/Dj`03o`000?oe2_Gom@[e
01Gom@[e00?o0000oo4>lOoa3_402?oa3_400ol0003ol0o`oo0?l00=oo0?l003o`000?oS7>?ohacS
00;o00002?oE:]D00ol0003oj1OXonPGj008onPGj0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003ohAkQon4Nh@05on4Nh@03o`000?oQ7^7ohAkQ00Go
hAkQ00?o0000omTVfOoI9]T02?oI9]T00ol0003okQ7^onhAkP0<onhAkPGo00002OoZ5NX00ol0003o
jQGZonXEjP0<onXEjP;o00003?oW6>L00ol0003oiQWVonHIiP0:onHIiP05o`000?oP7n3oh1oPon0O
h?l000002?o[5>/00ol0003om@[eooD:m@0DooD:m@?o00001ooa3_400ol0003ol0o`oo0?l00>oo0?
l003o`000?oS7>?o000000_oeB[E00?o0000onPGj?oX5nP01_oX5nP00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000on4NhOoQ7^401OoQ7^400ol0003ohAkQon4Nh@04on4Nh@03o`000?oI9]WofBKI00Oo
fBKI00?o0000onhAk_o^4Nh03?o^4Nh01?l0003okA;]ondBkOl0000;onXEjP03o`000?oZ5N[ojQGZ
00_ojQGZ00Co0000omlPgooO8=oo00002_oW6>L00ol0003oiQWVonHIiP0:onHIiP03o`000?oP7n3o
h1oP00;oh1oP00?o0000on/Djoo[5>/01_o[5>/00ol0003om@[eooD:m@0AooD:m@?o00000oo]4^d0
0ol0003ol@kaoo4>l@04oo4>l@03o`000?o`3o3ol0o`00gol0o`1?l0000;omDZe@03o`000?oX5nSo
j1OX00Goj1OX00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oQ7^7ohAkQ00KohAkQ00Co0000on4N
hOoQ7^7ohAkQ1?l00008omTVf@03o`000?o^4NkokQ7^00_okQ7^00?o0000ondBkOo]4^d00_o]4^d0
0ol0003ojQGZonXEjP08onXEjP03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000omlPgooO8=l00_oO8=l0
0ol0003oiaSWonLHi`03onLHi`Go00002ooV6NH00ol0003oh1oPon0Oh003on0Oh003o`000?o[5>_o
jaC[00OojaC[00?o0000ooD:mOoe2_D03_oe2_D2o`0000OokA;]00?o0000oo4>lOoa3_400_oa3_40
0ol0003ol0o`oo0?l00=oo0?l003o`000?oS7>?ohacS00;ohacS00?o0000omDZeOoE:]D02OoE:]D0
0ol0003oj1OXonPGj003onPGj003o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ohAkQon4Nh@07on4N
h@?o00001?oX5nP00ol0003ofBKIomTVf@05omTVf@03o`000?o^4NkokQ7^00[okQ7^00?o0000ondB
kOo]4^d00oo]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?oZ5N[ojQGZ00SojQGZ00?o0000omlP
gooO8=l01?oO8=l5o`0000CocS7>00?o0000onHIi_oV6NH02OoV6NH00ol0003oh1oPon0Oh003on0O
h003o`000?o[5>_ojaC[00SojaC[00?o0000ooD:mOoe2_D02_oe2_D3o`0000[okA;]00Go0000oo4>
lOoa3_7ol@kao`00000>oo0?l003o`000?oS7>?ohacS00CohacS0_l00009omDZe@03o`000?oX5nSo
j1OX00;oj1OX00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000onPG
j?oX5nP01OoX5nP00ol0003ofBKIomTVf@03omTVf@03o`000?o^4NkokQ7^00[okQ7^00?o0000ondB
kOo]4^d01?o]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?oZ5N[ojQGZ00OojQGZ00?o0000omlP
gooO8=l01OoO8=l00ol0003ocS7>olhacP07olhacP03o`000?oV6NKoiQWV00OoiQWV00?o0000on0O
h?oP7n001?oP7n000ol0003ojaC[on/Dj`08on/Dj`03o`000?oe2_Gom@[e00Som@[e0_l0000>ondB
k@Co00003?o`3o02o`0000WohacS00?o0000omDZeOoE:]D01ooE:]D01?l0003oj1OXonPGj?l0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000on4NhOoQ7^401OoQ7^400ol0003oj1OXonPGj007onPGj0;o00000ooI9]T00ol0
003okQ7^onhAkP09onhAkP03o`000?o]4^gokA;]00KokA;]00?o0000onXEj_oZ5NX02OoZ5NX00ol0
003ojQGZonXEjP05onXEjP03o`000?oO8=oogb3O00Kogb3O00?o0000olhac_o><Lh02?o><Lh00ol0
003oiQWVonHIiP06onHIiP03o`000?oP7n3oh1oP00Coh1oP00?o0000on/Djoo[5>/02Oo[5>/4o`00
00?om@[e0ol0000@ondBk@05o`000?od2oCom0_doo@;m?l000002_o`3o000ol0003ohacSon<Lh`0:
on<Lh`Ko00000ooE:]D00ol0003oj1OXo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000on4NhOoQ7^401?oQ7^400ol0
003oj1OXonPGj00:onPGj004o`000?oI9]WofBKIo`0000[okQ7^00?o0000ondBkOo]4^d01oo]4^d0
0ol0003ojQGZonXEjP09onXEjP03o`000?oZ5N[ojQGZ00CojQGZ00?o0000omlPgooO8=l01ooO8=l0
0ol0003ocS7>olhacP08olhacP;o00001_oV6NH00ol0003oh1oPon0Oh005on0Oh003o`000?o[5>_o
jaC[00WojaC[00Co0000onLHiooW6>OoiaSW0ol0000BondBk@03o`000?od2oCom0_d00?om0_d0_l0
0006oo0?l0;o00003OoS7><00ol0003oiaSWonLHi`03onLHi`Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000on4NhOoQ7^400ooQ7^40
0ol0003oj1OXonPGj00<onPGj0;o00002_o^4Nh00ol0003okA;]ondBk@08ondBk@03o`000?oZ5N[o
jQGZ00[ojQGZ00?o0000onXEj_oZ5NX00_oZ5NX00ol0003ogb3OomlPg`08omlPg`03o`000?o><Lko
cS7>00KocS7>0_l00002omhQgP03o`000?oV6NKoiQWV00;oiQWV00?o0000on0Oh?oP7n001_oP7n00
0ol0003ojaC[on/Dj`08on/Dj`03o`000?oW6>OoiaSW00CoiaSW00?o0000ondBkOo]4^d03oo]4^d0
0ol0003om0_doo@;m006oo@;m0;o00000oo`3o000ol0003ohacSon<Lh`0=on<Lh`03o`000?oW6>Oo
iaSW00OoiaSW0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003ohAkQon4Nh@02on4Nh@03o`000?oX5nSoj1OX
00koj1OX00?o0000onhAk_o^4Nh01oo^4Nh00ol0003okA;]ondBk@0:ondBk@03o`000?oZ5N[ojQGZ
00WojQGZ00Go0000onXEj_oZ5N[ojQGZo`00000;omlPg`03o`000?o><LkocS7>00CocS7>0_l00005
omhQgP05o`000?oV6NKoiQWVonHIi_l000002?oP7n000ol0003ojaC[on/Dj`08on/Dj`03o`000?oW
6>OoiaSW00GoiaSW00?o0000ondBkOo]4^d03_o]4^d00ol0003om0_doo@;m008oo@;m003o`000?o`
3o3o000000oohacS00?o0000onLHiooW6>L02?oW6>L01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oQ7^7ohAkQo`00017oj1OX00?o0000onhAk_o^4Nh01_o^4Nh00ol0003okA;]
ondBk@0;ondBk@03o`000?oZ5N[ojQGZ00WojQGZ00Co0000onXEj_oZ5N[o00003?oO8=l00ol0003o
cS7>olhacP02olhacP;o00002?oN8Mh00ol0003oiQWVo`000009on0Oh003o`000?o[5>_ojaC[00So
jaC[00?o0000onLHiooW6>L01OoW6>L00ol0003okA;]ondBk@0=ondBk@03o`000?od2oCom0_d00[o
m0_d00?o0000on<LhooS7><03_oS7><00ol0003oiaSWonLHi`07onLHi`03o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000BonPGj003o`00
0?o^4NkokQ7^00CokQ7^00?o0000ondBkOo]4^d03?o]4^d00ol0003ojQGZonXEjP0:onXEjP?o0000
3?oO8=l00ol0003ocS7>olhacP02o`0000_ogR7N00?o0000on0Oh?oP7n002?oP7n000ol0003ojaC[
on/Dj`07on/Dj`03o`000?oW6>OoiaSW00OoiaSW00?o0000ondBkOo]4^d03?o]4^d00ol0003om0_d
oo@;m00;oo@;m0;o00003_oS7><00ol0003oiaSWonLHi`07onLHi`03o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on/Djoo[5>/00oo[5>/00ol0003oj1OXonPGj00?onPGj0?o00000oo^
4Nh00ol0003okA;]ondBk@0>ondBk@03o`000?oZ5N[ojQGZ00SojQGZ00Co0000on8Mh_oR7N;ohQgR
0_l0000:omlPg`?o00003OoN8Mh00ol0003oh1oPon0Oh008on0Oh003o`000?o[5>_ojaC[00OojaC[
00?o0000onLHiooW6>L01ooW6>L00ol0003okA;]ondBk@0;ondBk@03o`000?od2oCom0_d00com0_d
00?o0000on8Mh_l000000_l0000:on<Lh`03o`000?oW6>OoiaSW00SoiaSW00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003ojaC[on/Dj`04on/Dj`03o`000?oX5nSoj1OX00coj1OX0_l0
0003onPGj003o`000?o^4Nko0000017okA;]00?o0000onXEj_oZ5NX01ooZ5NX00ol0003ohQgRon8M
hP04on8MhP;o00002?oO8=l00ol0003ogR7NomhQgP0>omhQgP;o00002?oP7n000ol0003ojaC[on/D
j`06on/Dj`03o`000?oW6>OoiaSW00WoiaSW00?o0000ondBkOo]4^d02Oo]4^d00ol0003om0_doo@;
m00=oo@;m003o`000?oR7N;ohQgR00;ohQgR0ol00007on<Lh`03o`000?oW6>OoiaSW00OoiaSW00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojaC[on/Dj`05on/Dj`03o`000?oX5nSo
j1OX00Woj1OX0_l00006onPGj003o`000?o]4^gokA;]013okA;]00?o0000onXEj_oZ5NX01_oZ5NX0
0ol0003ohQgRon8MhP07on8MhP03o`000?oO8=oogb3O00Cogb3O0ol0000>omhQgP03o`000?oH9mSo
f2OH00?o00001OoP7n000ol0003ojaC[on/Dj`06on/Dj`03o`000?oW6>OoiaSW00[oiaSW00?o0000
ondBkOo]4^d02?o]4^d00ol0003om0_doo@;m00=oo@;m003o`000?oR7N;ohQgR00GohQgR0ol00004
on<Lh`03o`000?oW6>OoiaSW00OoiaSW00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ojaC[on/Dj`06on/Dj`03o`000?oX5nSoj1OX00Goj1OX0ol00008onPGj003o`000?o]4^gokA;]
017okA;]00Co0000onXEj_oZ5N[ojQGZ1?l0000;on8MhP;o000000Cogb3Oo`000?l0003o00000ooU
6^D2o`0000_ogR7N00?o0000omPWf?oH9mP01?oH9mP2o`0000?oh1oP00?o0000on/Djoo[5>/01_o[
5>/00ol0003oiaSWonLHi`0:onLHi`03o`000?o]4^gokA;]00OokA;]00?o0000oo@;m?od2o@03_od
2o@00ol0003ohQgRon8MhP08on8MhPCo00002_oW6>L00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003ojaC[on/Dj`07on/Dj`03o`000?oX5nSoj1OX00;oj1OX0_l0000<onPGj003o`000?o]4^go
kA;]013okA;]1?l00003onLHi`03o`000?oR7N;ohQgR00_ohQgR00?o0000onDJiOoU6^D01_oU6^D0
0ol0003ogR7NomhQgP07omhQgP03o`000?oH9mSof2OH00Oof2OH3?l0000>onLHi`03o`000?o]4^go
kA;]00KokA;]00?o0000oo@;m?od2o@03_od2o@00ol0003ohQgRon8MhP0;on8MhP03o`000?oW6>Oo
iaSW00OoiaSW00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o[5>_ojaC[00WojaC[00Co0000onPG
j?l0003o00003_oX5nP00ol0003okA;]ondBk@0?ondBk@03o`000?oW6>OoiaSW00KoiaSW00?o0000
on8Mh_oR7N802_oR7N800ol0003oiA[UonDJi@07onDJi@;o00001_oN8Mh00ol0003of2OHomPWf008
omPWf003o`000?o]4^gokA;]00SokA;]00?o0000onLHiooW6>L03?oW6>L00ol0003okA;]ondBk@05
ondBk@03o`000?od2oCom0_d00oom0_d0_l0000=on8MhP03o`000?oW6>OoiaSW00KoiaSW00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o[5>_ojaC[00[ojaC[00?o0000onPGj?oX5nP03_oX5nP00ol0
003okA;]ondBk@0>ondBk@03o`000?oW6>OoiaSW00OoiaSW00?o0000on8Mh_oR7N802_oR7N800ol0
003oiA[UonDJi@09onDJi@;o00000ooN8Mh00ol0003of2OHomPWf009omPWf003o`000?o]4^gokA;]
00WokA;]00?o0000onLHiooW6>L02_oW6>L4o`0000CokA;]00?o0000oo@;m?od2o@04?od2o@01?l0
003ohacSo`000?l0000<on8MhP03o`000?oW6>OoiaSW00GoiaSW00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?o[5>_ojaC[00[ojaC[00?o0000onPGj?oX5nP03ooX5nP@o`0000[oiaSW00?o0000on8M
h_oR7N802OoR7N800ol0003ofbCKo`00000<onDJi@05o`000?oN8Mko0000omPWf?l000002_oH9mP0
0ol0003okA;]ondBk@09ondBk@03o`000?oW6>OoiaSW00OoiaSW0ol00004onl@k`?o000000?okA;]
o`000?od2o@04Ood2o@01?l0003ohacSon<LhooS7><2o`0000_ohQgR00?o0000onLHiooW6>L00ooW
6>L00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000on/Djoo[5>/02_o[5>/00ol0003oj1OXonPGj00?
onPGj003o`000?o^4NkokQ7^00cokQ7^00?o0000onLHiooW6>L02OoW6>L00ol0003ohQgRon8MhP07
on8MhP04o`000?oK9=_ofbCKo`0000goiA[U00Go0000omPWf?oH9mSof2OHo`000009omPWf003o`00
0?o]4^gokA;]00[okA;]00?o0000onLHiooW6>L00ooW6>L3o`0000[oka3_00?o0000oo@;m?od2o@0
4?od2o@00ol0003ohacSon<Lh`04on<Lh`;o00002_oR7N800ol0003oiaSWonLHi`04o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000cojaC[00?o0000onPGj?oX5nP03ooX5nP00ol0003okQ7^onhAkP0<onhAkP03o`000?oW
6>OoiaSW00WoiaSW00?o0000on8Mh_oR7N801_oR7N800ol0003ofbCKom/Tf`02om/Tf`03o`000?oU
6^GoiA[U00[oiA[U00?o0000omPWf?oH9mP00_oH9mP00ol0003of2OHomPWf006omPWf003o`000?o]
4^gokA;]00[okA;]00?o0000onLHiooW6>L00ol0000=onl@k`03o`000?od2oCom0_d013om0_d00?o
0000on<LhooS7><01_oS7><2o`0000WohQgR0_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000on/Djoo[5>/02_o[5>/00ol0003oj1OXonPGj00=onPGj0?o00003oo^4Nh0
0ol0003oiaSWonLHi`08onLHi`03o`000?oR7N;ohQgR00GohQgR00?o0000om/TfooK9=/00ooK9=/0
0ol0003oiA[UonDJi@0:onDJi@03o`000?oH9mSof2OH00?of2OH00?o0000omPWf?oH9mP01OoH9mP0
0ol0003okA;]ondBk@0;ondBk@;o00004Oo_4>l00ol0003om0_doo@;m00?oo@;m003o`000?oS7>?o
hacS00SohacS0_l00007on8MhP03o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000on/Djoo[5>/02?o[5>/00ol0003oj1OXonPGj009onPGj0Go00000_oU6^D00ol0
003okQ7^onhAkP0=onhAkP03o`000?oW6>OoiaSW00WoiaSW00?o0000on8Mh_oR7N801?oR7N800ol0
003ofbCKom/Tf`04om/Tf`03o`000?oU6^GoiA[U00SoiA[U00?o0000omPWf?oH9mP01OoH9mP00ol0
003of2OHomPWf004omPWf003o`000?o]4^gokA;]00_okA;]00?o0000onl@koo_4>l04?o_4>l00ol0
003om0_doo@;m00?oo@;m003o`000?oS7>?ohacS00[ohacS0_l00004on8MhP03o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003ojaC[on/Dj`07on/Dj`03o`000?oX5nSoj1OX00Coj1OX1Ol00007onDJi@03
o`000?o^4NkokQ7^00gokQ7^00?o0000onLHiooW6>L02OoW6>L00ol0003ohQgRon8MhP03on8MhP03
o`000?oK9=_ofbCK00GofbCK00?o0000onDJiOoU6^D02?oU6^D00ol0003of2OHomPWf006omPWf003
o`000?oH9mSof2OH00?of2OH00?o0000ondBkOo]4^d02oo]4^d00ol0003oka3_onl@k`0@onl@k`03
o`000?od2oCom0_d00oom0_d00?o0000on<LhooS7><03?oS7><2o`000003on8Mh_l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o[5>_ojaC[00OojaC[00?o0000onPGj?l00000
1?l0000<onDJi@03o`000?o^4NkokQ7^00kokQ7^00?o0000onLHiooW6>L02?oW6>L00ol0003ohQgR
on8MhP02on8MhP03o`000?oK9=_ofbCK00OofbCK00?o0000onDJiOoU6^D01ooU6^D00ol0003of2OH
omPWf007omPWf003o`000?oH9mSof2OH00;of2OH00?o0000ondBkOo]4^d02oo]4^d00ol0003oka3_
onl@k`0Aonl@k`03o`000?od2oCom0_d00gom0_d00?o0000on<LhooS7><03ooS7><00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on/Djoo[5>/01Oo[5>/3o`00017oiA[U00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003oiaSWonLHi`09onLHi`04o`000?oR7N;ohQgRo`0000[ofbCK00?o0000onDJiOoU6^D0
1ooU6^D00ol0003of2OHomPWf008omPWf005o`000?oH9mSof2OHomPWf?l000003Oo]4^d00ol0003o
ka3_onl@k`0Aonl@k`?o00003Ood2o@00ol0003ohacSon<Lh`0?on<Lh`03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_o[5>/2o`0000;ohacS00?o0000onDJiOoU6^D03ooU6^D00ol0003o
kQ7^onhAkP0>onhAkP03o`000?oW6>OoiaSW00SoiaSW1Ol0000;om/Tf`03o`000?oU6^GoiA[U00Ko
iA[U00?o0000omPWf?oH9mP02OoH9mP01?l0003of2OHomPWf?l0000=ondBk@03o`000?o_4>ooka3_
017oka3_00?o0000onHIi_oV6NH00ol0000:oo@;m0Co00003OoS7><00ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000on8Mh_oR7N;ohQgR0_l00005on<Lh`03o`000?oU6^GoiA[U00koiA[U00?o0000onhA
k_o^4Nh03_o^4Nh00ol0003oiaSWonLHi`07onLHi`03o`000?oW6>OoiaSW00?oiaSW00?o0000om/T
fooK9=/02?oK9=/00ol0003oiA[UonDJi@05onDJi@03o`000?oH9mSof2OH00[of2OH1Ol0000<ondB
k@03o`000?o_4>ooka3_013oka3_00?o0000onHIi_oV6NH01?oV6NH3o`0000Kom0_d00?o0000on`C
k?o/4n`00_o/4n`5o`0000SohacS00?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oR7N;ohQgR00?o
hQgR00?o0000on<LhooS7><01?oS7><00ol0003oiA[UonDJi@0=onDJi@03o`000?o^4NkokQ7^00oo
kQ7^00?o0000onLHiooW6>L01?oW6>L2o`0000OoiaSW00?o0000om/TfooK9=/01ooK9=/Eo`0000Go
gB;M00?o0000ondBkOo]4^d02?o]4^d3o`00013oka3_00?o0000onHIi_oV6NH02?oV6NH3o`0000;o
m0_d00?o0000on`Ck?o/4n`02?o/4n`5o`0000?ohacS00?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oR7N;ohQgR00CohQgR00?o0000on<LhooS7><01OoS7><00ol0003oiA[UonDJi@0;onDJi@Co0000
3oo^4Nh00ol0003oiaSWonLHi`03onLHi`03o`000?oW6>OoiaSW00SoiaSW00?o0000om/TfooK9=/0
1?oK9=/2o`0000SoiaSW00?o0000on<LhooS7><02?oS7><00ol0003ogB;MomdRg@05omdRg@;o0000
1_o]4^d2o`0000?ojQGZ00?o0000onl@koo_4>l03?o_4>l00ol0003oiQWVonHIiP0<onHIiP;o0000
4?o/4n`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?oS7>?ohacS00KohacS00?o
0000onDJiOoU6^D02OoU6^D00ol0003ofbCKo`000002onLHi`?o00003?o^4Nh01?l0003oiaSWonLH
iooW6>L2o`0000coiaSW00?o0000om/TfooK9=/00_oK9=/00ol0003oiaSWonLHi`08onLHi`03o`00
0?oS7>?ohacS00SohacS00?o0000omdRgOoM8]d01ooM8]d00ol0003okA;]ondBk@02ondBk@03o`00
0?oZ5N[ojQGZ00CojQGZ0_l0000;onl@k`03o`000?oV6NKoiQWV00coiQWV00?o0000onPGj?l00000
4_o/4n`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003ohQgRon8MhP06on8MhP03o`000?oS7>?ohacS00OohacS00?o
0000onDJiOoU6^D01_oU6^D2o`0000;ofbCK00?o0000onLHiooW6>L00ooW6>L3o`0000[okQ7^00?o
0000onLHiol000003ooW6>L01?l0003ofbCKo`000?l0000;onLHi`03o`000?oS7>?ohacS00SohacS
00?o0000omdRgOoM8]d02?oM8]d01?l0003okA;]o`000?l00009onXEjP03o`000?o_4>ooka3_00Oo
ka3_00?o0000onHIi_oV6NH03?oV6NH01?l0003oj1OXonPGj?l0000Con`Ck003o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000on8Mh_oR7N801ooR7N800ol0003ohacSon<Lh`08on<Lh`03o`000?oU6^GoiA[U00Co
iA[U00?o0000om/TfooK9=/00ooK9=/00ol0003oiaSWonLHi`05onLHi`?o00001_o^4Nh4o`00013o
iaSW00?o0000onLHiooW6>L03?oW6>L00ol0003ohacSon<Lh`07on<Lh`03o`000?oM8]gogB;M00Wo
gB;M00?o0000onXEj_oZ5NX02_oZ5NX2o`0000Koka3_00?o0000onHIi_oV6NH03?oV6NH00ol0003o
j1OXonPGj002onPGj003o`000?o/4ncok1?/00ook1?/00?o0000on<Lhol000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003ohQgRon8MhP08on8MhP03o`000?oS7>?ohacS00WohacS00Co0000onDJiOoU6^Go
iA[U0_l00006om/Tf`03o`000?oW6>OoiaSW00SoiaSW0ol000000oo^4Nko0000o`000004onTFj@03
o`000?oW6>OoiaSW00goiaSW00?o0000onLHiooW6>L03?oW6>L00ol0003ohacSon<Lh`07on<Lh`03
o`000?oM8]gogB;M00WogB;M00?o0000onXEj_oZ5NX03?oZ5NX00ol0003oka3_onl@k`03o`0000ko
iQWV00?o0000onPGj?oX5nP00ooX5nP00ol0003ok1?/on`Ck00>on`Ck005o`000?oS7>?ohacSon<L
hol000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003ohQgRon8MhP09on8MhP03o`000?oS7>?ohacS00[o
hacS00?o0000onDJiOl000002?oK9=/00ol0003oiaSWonLHi`0;onLHi`03o`000?oY5^WojAKY00Go
jAKY00?o0000onLHiooW6>L03?oW6>L00ol0003oiaSWonLHi`0<onLHi`03o`000?oS7>?ohacS00Oo
hacS00?o0000omdRgOoM8]d02?oM8]d2o`0000oojQGZ0_l00002onXEjP03o`000?oV6NKoiQWV00_o
iQWV00?o0000onPGj?oX5nP01?oX5nP00ol0003ok1?/on`Ck00=on`Ck003o`000?oS7>?ohacS00?o
hacS00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on8MhP03o`000?oS7>?ohacS00_ohacS00?o0000om/TfooK9=/0
1ooK9=/00ol0003oiaSWonLHi`0;onLHi`03o`000?oY5^WojAKY00KojAKY00?o0000onLHiooW6>L0
2ooW6>L2o`0000goiaSW00?o0000on<LhooS7><01ooS7><00ol0003ogB;MomdRg@07omdRg@04o`00
0?oP7n3oh1oPo`0000kojQGZ00?o0000onXEj_oZ5NX00_oZ5NX00ol0003oiQWVonHIiP09onHIiP03
o`000?oX5nSoj1OX00Koj1OX00?o0000on`Ck?o/4n`02oo/4n`00ol0003ohacSon<Lh`05on<Lh`04
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000SohQgR00?o0000on<LhooS7><02_oS7><2o`0000Wo
fbCK00?o0000onLHiooW6>L02ooW6>L00ol0003ojAKYonTFj@07onTFj@03o`000?oW6>OoiaSW00Wo
iaSW00Co0000omPWf?oH9mSo00003?oW6>L00ol0003ohacSon<Lh`07on<Lh`03o`000?oM8]gogB;M
00KogB;M00Go0000on0Oh?oP7n3oh1oPo`00000>onXEjP03o`000?oZ5N[ojQGZ00?ojQGZ00?o0000
onHIi_oV6NH01ooV6NH00ol0003oj1OXonPGj007onPGj003o`000?o/4ncok1?/00[ok1?/00?o0000
on<LhooS7><01ooS7><00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006on8MhP03o`000?oS7>?ohacS
00WohacS00Co0000omXUf_oJ9M[o00002OoK9=/00ol0003oiaSWonLHi`09onLHi`03o`000?oY5^Wo
jAKY00WojAKY00?o0000onLHiooW6>L01ooW6>L00ol0003of2OHomPWf002omPWf003o`000?oW6>Oo
iaSW00WoiaSW00?o0000on<LhooS7><01ooS7><00ol0003ogB;MomdRg@05omdRg@03o`000?oP7n3o
h1oP00?oh1oP00?o0000onXEj_oZ5NX02_oZ5NX00ol0003ojQGZonXEjP05onXEjP03o`000?oV6NKo
iQWV00GoiQWV00?o0000onPGj?oX5nP02?oX5nP00ol0003ok1?/on`Ck009on`Ck003o`000?oS7>?o
hacS00SohacS00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oR7N83o`0000WohacS00?o0000omXU
f_oJ9MX00_oJ9MX00ol0003ofbCKom/Tf`06om/Tf`03o`000?oW6>OoiaSW00WoiaSW00?o0000onTF
jOoY5^T02_oY5^T00ol0003oiaSWonLHi`05onLHi`03o`000?oH9mSof2OH00Cof2OH00?o0000onLH
iooW6>L02?oW6>L00ol0003ohacSon<Lh`07on<Lh`03o`000?oM8]gogB;M00CogB;M00?o0000on0O
h?oP7n001?oP7n000ol0003ojQGZonXEjP0:onXEjP03o`000?oZ5N[ojQGZ00KojQGZ00?o0000onHI
i_oV6NH00ooV6NH00ol0003oj1OXonPGj009onPGj003o`000?o/4ncok1?/00Sok1?/00?o0000on<L
hooS7><02OoS7><00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003onPGj0?o00001OoS7><00ol0003o
fRGJomXUfP03omXUfP03o`000?oK9=_ofbCK00KofbCK00?o0000onLHiooW6>L02OoW6>L00ol0003o
jAKYonTFj@0;onTFj@03o`000?oW6>OoiaSW00?oiaSW00?o0000omPWf?oH9mP01_oH9mP00ol0003o
iaSWonLHi`08onLHi`03o`000?oS7>?ohacS00KohacS00?o0000omdRgOoM8]d00_oM8]d2o`0000So
h1oP00?o0000onXEj_oZ5NX02OoZ5NX00ol0003ojQGZonXEjP07onXEjP05o`000?oV6NKoiQWVonHI
i_l000003OoX5nP00ol0003ok1?/on`Ck006on`Ck003o`000?oS7>?ohacS00[ohacS00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oX5nSoj1OX00Goj1OX0ol000000ooS7>?o0000omXUfP06omXUfP03
o`000?oK9=_ofbCK00GofbCK00?o0000onLHiooW6>L02OoW6>L00ol0003ojAKYonTFj@0<onTFj@05
o`000?oW6>OoiaSWonLHiol000002_oH9mP00ol0003oiaSWonLHi`07onLHi`03o`000?oS7>?ohacS
00KohacS00?o0000omdRgOl000000_l000000oo/4nco0000on0Oh007on0Oh003o`000?oZ5N[ojQGZ
00SojQGZ00?o0000onXEj_oZ5NX02OoZ5NX00ol0003oiQWVo`00000=onPGj0Co00001Oo/4n`00ol0
003ohacSon<Lh`0;on<Lh`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oj1OXonPGj008onPGj003
o`000?oJ9M[ofRGJ00OofRGJ00?o0000om/TfooK9=/01?oK9=/00ol0003oiaSWonLHi`09onLHi`03
o`000?oY5^WojAKY00gojAKY00?o0000onLHiol000003?oH9mP:o`0000OohacS0ol00005on`Ck003
o`000?oP7n3oh1oP00Koh1oP00?o0000onXEj_oZ5NX01ooZ5NX00ol0003ojQGZonXEjP0:onXEjP03
o`000?oX5nSoj1OX00_oj1OX00?o0000on@Ki?oT6n@00_oT6n@3o`000003on`Ck?l0003ohacS00_o
hacS0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000onPGj?oX5nP02OoX5nP00ol0003ofRGJomXUfP07omXUfP03o`00
0?oK9=_ofbCK00GofbCK00?o0000onLHiooW6>L01ooW6>L00ol0003ojAKYonTFj@0?onTFj@;o0000
2ooH9mP00ol0003ojQGZonXEjP07onXEjP03o`000?oS7>?ohacS00;ohacS0ol00008on`Ck003o`00
0?oP7n3oh1oP00Koh1oP00?o0000onXEj_oZ5NX01ooZ5NX00ol0003ojQGZonXEjP0:onXEjP03o`00
0?oX5nSoj1OX00[oj1OX00?o0000on@Ki?oT6n@01_oT6n@00ol0003ohacSon<Lh`08on<Lh`?o0000
0_oW6>L00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000onPGj?oX5nP02OoX5nP00ol0003ofRGJomXU
fP08omXUfP03o`000?oK9=_ofbCK00CofbCK00?o0000onLHiooW6>L01ooW6>L00ol0003ojAKYonTF
j@0>onTFj@04o`000?oM8]gogB;Mo`0000Wof2OH00?o0000onXEj_oZ5NX02OoZ5NX01?l0003ohacS
o`000?l0000<on`Ck003o`000?oP7n3oh1oP00Koh1oP00?o0000onXEj_oZ5NX01_oZ5NX00ol0003o
jQGZonXEjP0;onXEjP03o`000?oX5nSoj1OX00Ooj1OX0_l00009on@Ki003o`000?oS7>?ohacS00Co
hacS1?l00006onLHi`03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003oj1OXonPGj009onPGj003o`00
0?oJ9M[ofRGJ00SofRGJ00?o0000om/TfooK9=/00ooK9=/>o`0000gojAKY00?o0000omdRgOoM8]d0
0_oM8]d00ol0003of2OHomPWf005omPWf003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000on`Ck?o/4n`0
3?o/4n`00ol0003oh1oPon0Oh006on0Oh003o`000?oZ5N[ojQGZ00GojQGZ00?o0000onXEj_oZ5NX0
3?oZ5NX00ol0003oj1OXonPGj006onPGj003o`000?oT6nCoi1_T00[oi1_T00?o0000on<LhooS7><0
0ol0000:onLHi`?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oX5nSoj1OX00_oj1OX00?o0000omXUf_oJ9MX02?oJ
9MX01Ol0003ofbCKom/TfooK9=_o000000_oi1_T00?o0000oll`coo?<<l00ol00009onTFj@03o`00
0?oM8]gogB;M00CogB;M00?o0000omPWf?oH9mP00ooH9mP00ol0003ojQGZonXEjP0<onXEjP03o`00
0?o/4ncok1?/00gok1?/00?o0000on0Oh?oP7n001_oP7n000ol0003ojQGZonXEjP03onXEjP?o0000
3OoZ5NX00ol0003oj1OXonPGj005onPGj003o`000?oT6nCoi1_T00coi1_T0_l0000=onLHi`03o`00
0?oj1O[onPGj00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oX5nSoj1OX00_oj1OX00?o0000omXUf_oJ9MX02?oJ
9MX4o`0000coi1_T00?o0000oll`coo?<<l00oo?<<l3o`0000GojAKY00?o0000omdRgOoM8]d01_oM
8]d01Ol0003of2OHomPWf?oH9mSo000000oojQGZ00?o0000on`Ck?o/4n`03Oo/4n`00ol0003oh1oP
on0Oh006on0Oh003o`000?oZ5N[ojQGZ00?o00000ooQ7^400ol0003ojQGZonXEjP0;onXEjP03o`00
0?oX5nSoj1OX00?oj1OX00?o0000on@Ki?oT6n@03OoT6n@00ol0003oiaSWonLHi`0;onLHi`03o`00
0?oj1O[onPGj00ConPGj0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000onPGj?oX5nP02_oX5nP3o`0000KofRGJ0ol0
0003om`Sg003o`000?oT6nCoi1_T00[oi1_T00?o0000oll`coo?<<l01_o?<<l3o`000003onTFjOl0
003ogB;M00WogB;M00?o0000omPWf?l000004?oZ5NX00ol0003ok1?/on`Ck00=on`Ck003o`000?oP
7n3oh1oP00Ooh1oP0_l00007on4Nh@03o`000?oZ5N[ojQGZ00[ojQGZ00Co0000onPGj?oX5nSoj1OX
0ol0000?on@Ki003o`000?oW6>OoiaSW00_oiaSW00?o0000ooX5n_oj1OX01ooj1OX4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000onPGj?oX5nP02_oX
5nP01?l0003ohAkQon4NhOoQ7^42o`000004omXUf_l0003o0000o`0000Kog2?L00?o0000on@Ki?oT
6n@02_oT6n@00ol0003occ3?oll`c`09oll`c`03o`000?oM8]gogB;M00[ogB;M00?o0000onXEj_oZ
5NX03ooZ5NX00ol0003ok1?/on`Ck00>on`Ck003o`000?oP7n3oh1oP00Koh1oP00?o0000on4NhOoQ
7^401ooQ7^44o`0000SojQGZ00Co0000onPGj?oX5nSo00000ooG:=L2o`0000goi1_T00?o0000onLH
iooW6>L02_oW6>L00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000onPGj?oX5nP02OoX5nP00ol0003o
hAkQon4Nh@04on4Nh@03o`000?oL8mcog2?L00Oog2?L00?o0000on@Ki?oT6n@02OoT6n@00ol0003o
cc3?oll`c`0:oll`c`03o`000?oM8]gogB;M00[ogB;M00?o0000onXEj_oZ5NX03ooZ5NX00ol0003o
k1?/on`Ck00>on`Ck003o`000?oP7n3oh1oP00Goh1oP00?o0000on4NhOoQ7^402?oQ7^401?l0003o
iA[UonDJiOoU6^D7o`0000;ojQGZ0_l00006omLXe`;o00003?oT6n@00ol0003oiaSWonLHi`09onLH
i`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oj1OXonPGj008onPGj003o`000?oQ7^7ohAkQ00Go
hAkQ00?o0000om`Sg?oL8m`02?oL8m`00ol0003oi1_Ton@Ki008on@Ki003o`000?o?<<oocc3?00[o
cc3?00?o0000omdRgOoM8]d02ooM8]d00ol0003ojQGZonXEjP0>onXEjP03o`000?o/4ncok1?/00ko
k1?/1Ol00002on0Oh003o`000?oQ7^7ohAkQ00WohAkQ00?o0000onDJiOoU6^D02?oU6^D3o`0000Wo
ebSG0_l0000:on@Ki003o`000?oW6>OoiaSW00SoiaSW00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oX5nSoj1OX00Soj1OX00?o0000on4NhOoQ7^401ooQ7^400ol0003og2?Lom`Sg007om`Sg003o`00
0?oT6nCoi1_T00Soi1_T00?o0000oll`coo?<<l02_o?<<l00ol0003ogB;MomdRg@0:omdRg@;o0000
3_oZ5NX3o`0000gok1?/0ol00005ondBk@;o00002ooQ7^400ol0003oiA[UonDJi@0;onDJi@;o0000
2_oG:=L2o`0000Ooi1_T0ol00009onLHi`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:on4Nh@03o`00
0?oL8mcog2?L00Oog2?L00?o0000on@Ki?oT6n@02?oT6n@>o`0000WogB;M0ol000000ooB;M;o0000
onXEjP0:onXEjP?o00000_o^4Nh00ol0003ok1?/on`Ck009on`Ck0;o00002Oo]4^d00ol0003ohAkQ
on4Nh@09on4Nh@03o`000?oU6^GoiA[U00_oiA[U00?o0000onTFjOl000002ooG:=L2o`0000Coi1_T
00Co0000on/Djoo[5>_ojaC[0_l00007onLHi`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ook1?/00ol0003ohAkQ
on4Nh@09on4Nh@03o`000?oL8mcog2?L00Kog2?L00?o0000on@Ki?oT6n@02?oT6n@00ol0003oeB[E
omDZe@0:omDZe@03o`000?oM8]gogB;M00CogB;M0ol00005om8]dP03o`000?oZ5N[ojQGZ00CojQGZ
1?l00006onhAkP03o`000?o/4ncok1?/00Kok1?/0_l0000;ondBk@03o`000?oQ7^7ohAkQ00WohAkQ
00?o0000onDJiOoU6^D02_oU6^D01Ol0003ojAKYonTFjOoY5^Wo000000coebSG0_l000000ooT6nCo
0000on/Dj`05on/Dj`03o`000?oW6>OoiaSW00?oiaSW00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oQ7^7ohAkQ00SohAkQ00?o0000om`Sg?oL8m`01_oL8m`00ol0003oi1_Ton@Ki007on@Ki003o`00
0?oE:]GoeB[E00_oeB[E00?o0000omdRgOoM8]d00_oM8]d2o`0000WodRgB00?o0000onXEj_oZ5NX0
0ol0000;onhAkP03o`000?o/4ncok1?/00;ok1?/0ol0000>ondBk@03o`000?oQ7^7ohAkQ00OohAkQ
00?o0000onDJiOoU6^D02ooU6^D00ol0003ojAKYonTFj@02onTFj@03o`000?oG:=OoebSG00_oebSG
00?o0000on/Djoo[5>/01_o[5>/2o`0000?oiaSW00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oQ
7^7ohAkQ00OohAkQ00?o0000om`Sg?oL8m`01ooL8m`00ol0003oi1_Ton@Ki005on@Ki0?o00003OoE
:]D4o`0000_odRgB0ol0000?onhAkP04o`000?o/4nco0000o`00017okA;]00?o0000on4NhOoQ7^40
1ooQ7^400ol0003oiA[UonDJi@0:onDJi@03o`000?oY5^WojAKY00CojAKY00?o0000omLXeooG:=L0
1ooG:=L3o`0000_ojaC[1?l0000=ooX5nP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on4NhOoQ7^402?oQ7^400ol0003og2?Lom`S
g006om`Sg003o`000?oT6nCoi1_T00;oi1_T0ol00003omhQgP03o`000?oE:]GoeB[E00[oeB[E00?o
0000om8]d_oB;M802ooB;M800ol0003oebSGo`00000AonhAkP03o`000?o]4^gokA;]017okA;]00?o
0000on4NhOoQ7^401ooQ7^400ol0003oiA[UonDJi@0:onDJi@03o`000?oY5^WojAKY00GojAKY00Co
0000omLXeooG:=OoebSG1Ol00002omdRg@03o`000?o[5>_ojaC[00WojaC[00Co0000ooX5n_oj1O[o
nPGj0ol00009ooX5nP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000on4NhOoQ7^401ooQ7^400ol0003og2?Lom`Sg005om`Sg0?o0000
00?oi1_To`000?l000001ooN8Mh00ol0003oeB[EomDZe@08omDZe@?o00002_oB;M82o`0000;oebSG
00?o0000onhAk_o^4Nh03oo^4Nh00ol0003okA;]ondBk@0AondBk@03o`000?oQ7^7ohAkQ00OohAkQ
00?o0000onDJiOoU6^D02OoU6^D00ol0003ojAKYonTFj@07onTFj@?o00001ooM8]d00ol0003ojaC[
on/Dj`09on/Dj`03o`000?oj1O[onPGj00ConPGj0_l00007ooX5nP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000on4NhOoQ7^401ooQ
7^44o`0000;og2?L0_l00003on@Ki003o`000?oN8MkogR7N00SogR7N0_l00006omDZe@;o00000ooH
9mP00ol0003odRgBom8]dP06om8]dP03o`000?oG:=OoebSG00?oebSG00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003okA;]ondBk@0BondBk@03o`000?oQ7^7ohAkQ00GohAkQ00?o0000onDJiOoU6^D02OoU
6^D00ol0003ojAKYonTFj@08onTFj@03o`000?oM8]gogB;M00OogB;M00?o0000on/Djoo[5>/02?o[
5>/00ol0003onPGjooX5nP07ooX5nP;o00001Ooj1OX00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oQ7^7ohAkQ00CohAkQ0_l00004
on/Dj`;o00001OoT6n@00ol0003ogR7NomhQgP0:omhQgP03o`000?oE:]GoeB[E00;oeB[E00?o0000
omPWf?oH9mP01?oH9mP00ol0003odRgBom8]dP04om8]dP03o`000?oG:=OoebSG00CoebSG00?o0000
onhAk_o^4Nh03_o^4Nh00ol0003okA;]ondBk@0BondBk@[o00002_oU6^D00ol0003ojAKYonTFj@08
onTFj@03o`000?oM8]gogB;M00OogB;M00?o0000on/Djoo[5>/02?o[5>/00ol0003onPGjooX5nP09
ooX5nP?o000000?onPGjo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003ohAkQon4NhOoQ7^42o`0000OojaC[00?o0000on@Ki?oT6n@01?oT6n@0
0ol0003ogR7NomhQgP0:omhQgP04o`000?oE:]Go0000o`0000Sof2OH00Co0000om8]d_oB;M;odRgB
0_l00007omLXe`03o`000?o^4NkokQ7^00kokQ7^00?o0000ondBkOo]4^d04_o]4^d00ol0003oiA[U
onDJi@07onDJi@03o`000?oU6^GoiA[U00KoiA[U00?o0000onTFjOoY5^T02_oY5^T00ol0003ogB;M
omdRg@06omdRg@03o`000?o[5>_ojaC[00SojaC[00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oQ
7^7o0000o`0000WojaC[00?o0000on@Ki?oT6n@01?oT6n@00ol0003ogR7NomhQgP0;omhQgP03o`00
0?oH9mSof2OH00Wof2OH00?o0000om8]d_l000002OoG:=L00ol0003okQ7^onhAkP0>onhAkP;o0000
4_o]4^d00ol0003oiA[UonDJi@09onDJi@;o00001_oU6^D00ol0003ojAKYonTFj@0:onTFj@03o`00
0?oM8]gogB;M00KogB;M00?o0000on/Djoo[5>/02?o[5>/00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000on/Djoo[5>/02Oo[5>/00ol0003oi1_Ton@Ki005on@Ki003o`000?oN8MkogR7N00[ogR7N00?o
0000omPWf?oH9mP02_oH9mP2o`0000WoebSG00?o0000onhAk_o^4Nh03_o^4Nh00ol0003ojAKYo`00
0002o`0000ookA;]00?o0000onDJiOoU6^D02ooU6^D00ol0003oiA[UonDJi@03o`0000gojAKY00?o
0000omdRgOoM8]d01_oM8]d00ol0003ojaC[on/Dj`07on/Dj`03o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ojaC[on/Dj`09on/Dj`03o`000?oT6nCoi1_T00Goi1_T00?o0000omhQg_oN8Mh02OoN8Mh2
o`0000_of2OH0_l0000;omLXe`03o`000?o^4NkokQ7^00cokQ7^00?o0000onTFjOoY5^T00ooY5^T3
o`0000cokA;]00?o0000onDJiOoU6^D03?oU6^D2o`0000;ohQgR00?o0000onTFjOoY5^T03?oY5^T0
0ol0003ogB;MomdRg@05omdRg@03o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o[5>_ojaC[00[ojaC[00?o0000on@Ki?oT6n@01_oT6n@00ol0003ogR7NomhQgP07omhQ
gP03o`000?oH9mSo000000[of2OH00Co0000om0_d?o@;m3o00002_oG:=L00ol0003okQ7^onhAkP0<
onhAkP03o`000?oY5^WojAKY00KojAKY0_l00008ondBk@;o00003ooU6^D00ol0003ohQgRon8MhP02
on8MhP03o`000?oY5^WojAKY00_ojAKY00?o0000omdRgOoM8]d01OoM8]d00ol0003ojaC[on/Dj`07
on/Dj`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ojaC[on/Dj`0:on/Dj`03o`000?oT6nCoi1_T
00Koi1_T00?o0000omhQg_oN8Mh01_oN8Mh01Ol0003of2OHomPWf?oH9mSo000000Sof2OH00?o0000
om0_d?o@;m000_o@;m000ol0003oebSGomLXe`06omLXe`Co00003?o^4Nh00ol0003ojAKYonTFj@08
onTFj@?o00000_o]4^d3o`000003on@Ki?l0003oiA[U00goiA[U00?o0000on8Mh_oR7N801?oR7N80
0ol0003ojAKYonTFj@0:onTFj@03o`000?oM8]gogB;M00GogB;M00?o0000on/Djoo[5>/01_o[5>/0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000on/Djoo[5>/02oo[5>/00ol0003oi1_Ton@Ki007on@K
i003o`000?oN8MkogR7N00?ogR7N0_l00005omPWf003o`000?oH9mSof2OH00Cof2OH00?o0000om0_
d?o@;m000oo@;m000ol0003oebSGomLXe`05omLXe`03o`000?oQ7^7ohAkQ00;ohAkQ0ol00007onhA
kP;o00003_oY5^T2o`0000Goi1_T00?o0000onDJiOoU6^D02_oU6^D00ol0003ohQgRon8MhP05on8M
hP03o`000?oY5^WojAKY00_ojAKY00?o0000omdRgOoM8]d01?oM8]d00ol0003ojaC[on/Dj`06on/D
j`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ojaC[on/Dj`0;on/Dj`03o`000?oT6nCoi1_T00Oo
i1_T00?o0000omhQg_oN8Mh00_oN8Mh00ol0003of2OHomPWf006omPWf003o`000?oH9mSof2OH00;o
f2OH00?o0000om0_d?o@;m001Oo@;m000ol0003oebSGomLXe`02omLXe`;o00002?oQ7^43o`0000;o
kQ7^0_l000000ooT6nCo0000onTFj@0=onTFj@03o`000?oT6nCoi1_T00Goi1_T00?o0000onDJiOoU
6^D02?oU6^D00ol0003ohQgRon8MhP07on8MhP03o`000?oY5^WojAKY00[ojAKY00?o0000omdRgOoM
8]d01?oM8]d00ol0003ojaC[on/Dj`06on/Dj`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ojaC[
on/Dj`0<on/Dj`03o`000?oT6nCoi1_T00Soi1_T00Co0000omhQg_oN8Mko00002OoH9mP01Ol0003o
f2OHomPWf?oH9mSo000000Sod2o@00Go0000omLXeooG:=OoebSGo`00000=on4Nh@;o00001?oT6n@0
0ol0003ojAKYonTFj@0;onTFj@03o`000?oT6nCoi1_T00Koi1_T00?o0000onDJiOoU6^D01ooU6^D0
0ol0003ohQgRon8MhP08on8MhPCo00002?oY5^T00ol0003ogB;MomdRg@04omdRg@03o`000?o[5>_o
jaC[00KojaC[00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o[5>_ojaC[00_ojaC[0ol00009on@K
i003o`000?oN8Mko000000_of2OH00?o0000omPWf?l000002_o@;m000ol0003oebSGo`00000?on4N
h@03o`000?oT6nCoi1_T00;oi1_T00?o0000onTFjOoY5^T02ooY5^T00ol0003oi1_Ton@Ki006on@K
i003o`000?oU6^GoiA[U00KoiA[U00?o0000on8Mh_oR7N802OoR7N801?l0003oiaSWonLHiooW6>L7
o`0000;ojAKY00?o0000omdRgOoM8]d00ooM8]d00ol0003ojaC[on/Dj`05on/Dj`03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?o[5>_ojaC[00SojaC[0ol00003on8MhP03o`000?oT6nCoi1_T00Ooi1_T00?o0000omPW
f?oH9mP02ooH9mP00ol0003od2o@om0_d00:om0_d003o`000?oQ7^7ohAkQ00gohAkQ00?o0000on@K
i?oT6n@01?oT6n@00ol0003ojAKYonTFj@09onTFj@03o`000?oT6nCoi1_T00Soi1_T00?o0000onDJ
iOoU6^D00ooU6^D2o`0000cohQgR00?o0000onLHiooW6>L02?oW6>L<o`0000?ojaC[0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on/Djoo[5>/01_o[5>/3o`0000OohQgR00?o0000on@Ki?oT6n@01_oT6n@00ol0003o
f2OHomPWf00;omPWf003o`000?o@;m3od2o@00Wod2o@0_l0000>on4Nh@03o`000?oT6nCoi1_T00Go
i1_T00?o0000onTFjOoY5^T02OoY5^T00ol0003oi1_Ton@Ki009on@Ki003o`000?oU6^Go000000;o
00000_oO8=l00ol0003ohQgRon8MhP08on8MhP03o`000?oW6>OoiaSW00coiaSW00?o0000oo4>lOoa
3_401_oa3_43o`0000?on`Ck0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ojaC[on/Dj`03on/Dj`?o00002ooR7N800ol0003oi1_T
on@Ki004on@Ki003o`000?oH9mSof2OH00_of2OH0ol00007om0_d0?o000000?ogB;Mo`000?oQ7^40
3OoQ7^400ol0003oi1_Ton@Ki006on@Ki003o`000?oY5^WojAKY00SojAKY00?o0000on@Ki?oT6n@0
2_oT6n@00ol0003ogb3OomlPg`04omlPg`03o`000?oR7N;ohQgR00OohQgR00?o0000onLHiooW6>L0
2ooW6>L00ol0003ol@kaoo4>l@08oo4>l@03o`000?ok1?_on`Ck00Con`Ck0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004on/Djol0
003o0000o`0000oohQgR00?o0000on@Ki?oT6n@00ooT6n@>o`0000?of2OH0_l00002om0_d0?o0000
1OoM8]d00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oT6nCoi1_T00Ooi1_T00?o0000onTFjOoY5^T0
2?oY5^T00ol0003oi1_Ton@Ki00:on@Ki003o`000?oO8=oogb3O00Gogb3O00?o0000on8Mh_oR7N80
1_oR7N800ol0003oiaSWonLHi`0;onLHi`03o`000?oa3_7ol@ka00Sol@ka00?o0000oo/4nook1?/0
1ook1?/2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;ohQgR00?o0000on@Ki?oT6n@00_oT6n@00ol0003ocS7>olha
cP0:olhacP03o`000?oH9mSof2OH00?of2OH0_l00009omdRg@03o`000?oQ7^7ohAkQ00WohAkQ00?o
0000on@Ki?oT6n@02?oT6n@2o`0000SojAKY00?o0000on@Ki?oT6n@02OoT6n@00ol0003ogb3OomlP
g`07omlPg`03o`000?oR7N;ohQgR00CohQgR00?o0000onLHiooW6>L02ooW6>L00ol0003ol@kaoo4>
l@09oo4>l@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ohQgRon8MhP0?on8MhP?o000000?oi1_T
o`000?o><Lh02oo><Lh00ol0003of2OHomPWf004omPWf003o`000?oM8]gogB;M00WogB;M00?o0000
on4NhOoQ7^401ooQ7^400ol0003oi1_Ton@Ki009on@Ki004o`000?oR7N;o0000o`0000KojAKY00?o
0000on@Ki?oT6n@02OoT6n@00ol0003ogb3OomlPg`08omlPg`03o`000?oR7N;ohQgR00?ohQgR00?o
0000onLHiooW6>L02ooW6>L00ol0003ol@kaoo4>l@09oo4>l@03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ohQgRon8MhP0<on8MhP;o00000ooN8Mh2o`0000cocS7>00?o0000omPWf?oH9mP01?oH9mP0
0ol0003ogB;MomdRg@0:omdRg@Wo00002ooT6n@00ol0003ohQgRon8MhP02on8MhP?o00000_oY5^T0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?oO8=oogb3O00Wogb3O00?o0000on8Mh_oR7N800_oR7N80
0ol0003oiaSWonLHi`0:onLHi`03o`000?oa3_7ol@ka00Wol@ka00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oR7N82o`0000GogR7N00?o0000omdRgOl000002_o><Lh00ol0003of2OHomPWf006omPW
f003o`000?oM8]gogB;M00WogB;M00?o0000omdRgOoM8]d01OoM8]d00ol0003oi1_Ton@Ki009on@K
i003o`000?oR7N;ohQgR00GohQgR0ol00009on@Ki0?o00003OoO8=l01Ol0003ohQgRon8Mh_oR7N;o
000000coiaSW00?o0000oo4>lOoa3_402Ooa3_400ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on8M
h_oR7N801OoR7N82o`0000OogR7N00Co0000omdRgOoM8]go00002Oo><Lh00ol0003of2OHomPWf006
omPWf003o`000?oM8]gogB;M00SogB;M00?o0000omdRgOoM8]d01ooM8]d00ol0003oi1_Ton@Ki007
on@Ki003o`000?oR7N;ohQgR00SohQgR0ol00002on@Ki0Go00000_oB;M800ol0003ogb3OomlPg`0<
omlPg`03o`000?oR7N;o000000coiaSW00?o0000oo4>lOoa3_402_oa3_400ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000on8Mh_oR7N800_oR7N82o`0000SogR7N00?o0000omdRgOoM8]d00_oM8]d5o`00
00CocS7>00?o0000omPWf?oH9mP01_oH9mP00ol0003ogB;MomdRg@08omdRg@03o`000?oM8]gogB;M
00OogB;M00?o0000on@Ki?oT6n@01ooT6n@00ol0003ohQgRon8MhP08on8MhP03o`000?oC;=?odbcC
00;o00002?oB;M800ol0003ogb3OomlPg`0<omlPg`Co00002_oW6>L00ol0003ol@kaoo4>l@0:oo4>
l@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ohQgRo`000?l0000:omhQgP03o`000?oM8]gogB;M
00;ogB;M00?o0000oka3_?nl@k`00_nl@k`4o`0000Wof2OH00?o0000omdRgOoM8]d02?oM8]d00ol0
003ogB;MomdRg@08omdRg@03o`000?oT6nCoi1_T00Goi1_T00?o0000on8Mh_oR7N802?oR7N801Ol0
003odbcCom</dooC;=?o000000[odRgB0ol0000;omlPg`04o`000?o/4ncok1?/on`Ck0Co00001OoW
6>L00ol0003ol@kaoo4>l@0;oo4>l@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ogR7NomhQgP0:
omhQgP03o`000?oM8]gogB;M00?ogB;M00?o0000oka3_?nl@k`01?nl@k`00ol0003of2OHomPWf007
omPWf003o`000?oM8]gogB;M00KogB;M0_l0000;omdRg@03o`000?oT6nCoi1_T00Goi1_T00?o0000
on8Mh_oR7N802?oR7N800ol0003odbcCom</d`02om</d`03o`000?oB;M;odRgB00OodRgB00?o0000
omlPgooO8=l01?l00006omlPg`03o`000?o/4ncok1?/00Kok1?/0ol00002onLHi`03o`000?oa3_7o
l@ka00_ol@ka00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oN8MkogR7N00WogR7N00?o0000omdR
gOoM8]d01?oM8]d00ol0003o_4>loka3_005oka3_003o`000?oH9mSof2OH00Oof2OH00?o0000omdR
gOoM8]d00_oM8]d3o`000003on4NhOl0003ogB;M00[ogB;M00?o0000on@Ki?oT6n@01OoT6n@00ol0
003ohQgRon8MhP07on8MhP03o`000?oC;=?odbcC00?odbcC00?o0000om8]d_oB;M801ooB;M800ol0
003ogb3OomlPg`04omlPg`?o00000_oO8=l00ol0003ok1?/on`Ck00:on`Ck0;o00003_oa3_400ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omhQg_oN8Mh02OoN8Mh00ol0003ogB;MomdRg@04omdRg@03
o`000?nl@kco_4>l00Ko_4>l0_l00007omPWf003o`000?oM8]go000000;o00001OoQ7^400ol0003o
gB;MomdRg@08omdRg@?o00001?oT6n@00ol0003ohQgRon8MhP08on8MhP03o`000?oC;=?odbcC00Co
dbcC00?o0000om8]d_oB;M801_oB;M800ol0003ogb3OomlPg`07omlPg`;o00003_o/4n`00ol0003o
l@kaoo4>l@0;oo4>l@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ogR7NomhQgP08omhQgP03o`00
0?oM8]gogB;M00GogB;M00?o0000oka3_?nl@k`01?nl@k`00ol0003oeRWFomHYeP03o`0000Cof2OH
0_l00008on4Nh@03o`000?oM8]gogB;M00OogB;M00Co0000onXEj_oZ5N[ojQGZ0ol000000ooT6nCo
0000on8MhP09on8MhP03o`000?oC;=?odbcC00CodbcC00?o0000om8]d_oB;M801OoB;M800ol0003o
gb3OomlPg`09omlPg`03o`000?o/4ncok1?/00gok1?/00?o0000oo4>lOoa3_402_oa3_400ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omhQg_oN8Mh01ooN8Mh00ol0003ogB;MomdRg@06omdRg@03o`00
0?nl@kco_4>l00?o_4>l00?o0000omHYe_oF:MH01?oF:MH2o`000003omPWf?l0003ohAkQ00[ohAkQ
00?o0000omdRgOoM8]d01OoM8]d00ol0003ojQGZonXEjP05onXEjP03o`000?oR7N;ohQgR00OohQgR
0ol00007om</d`03o`000?oB;M;odRgB00CodRgB00?o0000omlPgooO8=l02OoO8=l00ol0003ok1?/
on`Ck00=on`Ck003o`000?oa3_7ol@ka00[ol@ka00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oN
8MkogR7N00GogR7N0ol00009omdRg@05o`000?nl@kco_4>loka3_?l000002OoF:MH00ol0003ohAkQ
on4Nh@0;on4Nh@03o`000?oM8]gogB;M00?ogB;M00?o0000onXEj_oZ5NX01_oZ5NX00ol0003ohQgR
on8MhP06on8MhP05o`000?oS7>?ohacSon<Lhol000001ooC;=<00ol0003odRgBom8]dP03om8]dP03
o`000?oO8=oogb3O00Wogb3O00?o0000on`Ck?o/4n`03_o/4n`00ol0003ol@kaoo4>l@09oo4>l@03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ogR7No`000004o`0000;oiaSW00?o0000omdRgOoM8]d0
1ooM8]d01?l0003o_4>loka3_?l00009omHYeP;o00003OoQ7^400ol0003ogB;MomdRg@02omdRg@03
o`000?oZ5N[ojQGZ00SojQGZ00?o0000on8Mh_oR7N800ooR7N82o`0000GohacS00?o0000om</dooC
;=<01?oC;=<00ol0003odRgBom8]dP03om8]dP03o`000?oO8=oogb3O00Wogb3O00?o0000on`Ck?o/
4n`03_o/4n`00ol0003ol@kaoo4>l@09oo4>l@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SoiaSW
00?o0000omdRgOoM8]d01_oM8]d00ol0003o_4>lo`000009omHYeP04o`000?oT6nCoi1_To`0000go
hAkQ00Co0000omdRgOoM8]go00003?oZ5NX01Ol0003ohQgRon8Mh_oR7N;o000000SohacS0_l00005
om</d`03o`000?oB;M;odRgB00;odRgB00?o0000omlPgooO8=l02OoO8=l00ol0003ok1?/on`Ck00>
on`Ck003o`000?oa3_7ol@ka00Wol@ka00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oW6>OoiaSW
00OoiaSW00?o0000omdRgOoM8]d01ooM8]d00ol0003oeRWFomHYeP07omHYeP03o`000?oT6nCoi1_T
00;oi1_T00?o0000on4NhOoQ7^402_oQ7^400ol0003ogB;Mo`00000>onXEjP03o`000?oR7N;o0000
00_ohacS00?o0000om</dooC;=<00_oC;=<01Ol0003odRgBom8]d_oB;M;o000000cogb3O00?o0000
on`Ck?o/4n`03_o/4n`3o`0000Wol@ka00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oW6>OoiaSW
00WoiaSW00?o0000omdRgOoM8]d01_oM8]d00ol0003oeRWFomHYeP06omHYeP03o`000?oT6nCoi1_T
00?oi1_T00?o0000on4NhOoQ7^402ooQ7^400ol0003ojQGZonXEjP0>onXEjP03o`000?oS7>?ohacS
00_ohacS0_l00003om</d`04o`000?oB;M;odRgBo`0000[ogb3O0ol0000>on`Ck0;o00000ooj1OX2
o`0000Ool@ka00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oW6>OoiaSW00[oiaSW00?o0000omdR
gOoM8]d01?oM8]d00ol0003oeRWFomHYeP06omHYeP03o`000?oT6nCoi1_T00Goi1_T00?o0000on4N
hOoQ7^401ooQ7^43o`00017ojQGZ00?o0000on<LhooS7><03OoS7><01Ol0003odbcCom</dol0003o
dRgB00Co00000ooO8=l5o`0000;ohQgR00?o0000on`Ck?o/4n`02_o/4n`2o`0000OonPGj0_l00004
oo4>l@03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oiaSWonLHi`0;onLHi`03o`000?oM8]gogB;M
00CogB;M00?o0000omHYe_oF:MH01OoF:MH00ol0003oi1_Ton@Ki006on@Ki003o`000?oQ7^7ohAkQ
00CohAkQ0ol00002on@Ki003o`000?oZ5N[ojQGZ00oojQGZ0_l0000?on<Lh`04o`000?oC;=?o0000
o`0000CogB;M0ol00008on8MhP03o`000?o/4ncok1?/00Ook1?/0_l0000;ooX5nP;o00000_oa3_40
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onLHiooW6>L03?oW6>L6o`0000OoeRWF00?o0000on@K
i?oT6n@02?oT6n@00ol0003ohAkQon4Nh@03o`0000Koi1_T00?o0000onXEj_oZ5NX03OoZ5NX01?l0
003oj1OXonPGj?l0000?on<Lh`03o`000?oM8]gogB;M00GogB;M00?o0000on8Mh_oR7N802?oR7N80
0ol0003ok1?/on`Ck005on`Ck003o`000?oj1O[onPGj00gonPGj0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oW6>L00ol0003og2?Lom`Sg004om`S
g003o`000?oF:MKoeRWF00?oeRWF00?o0000on@Ki?oT6n@02_oT6n@2o`0000[oi1_T00?o0000onXE
j_oZ5NX02ooZ5NX00ol0003oj1OXonPGj002onPGj003o`000?oS7>?ohacS00_ohacS0_l00007omdR
g@03o`000?oR7N;ohQgR00WohQgR00?o0000on`Ck?o/4n`00_o/4n`2o`0001;onPGj00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000onLHiooW6>L02ooW6>L00ol0003og2?Lom`Sg006om`Sg005o`000?oF:MKoeRWFomHY
e_l000003OoT6n@00ol0003oi1_Ton@Ki00:on@Ki003o`000?oZ5N[ojQGZ00WojQGZ00?o0000onPG
j?oX5nP01?oX5nP00ol0003ohacSon<Lh`08on<Lh`;o000000?oe2_Do`000?oM8]d01ooM8]d00ol0
003ohQgRon8MhP09on8MhP04o`000?o/4nco0000o`0001ConPGj00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oW6>OoiaSW
00WoiaSW00?o0000om`Sg?oL8m`02?oL8m`00ol0003oeRWFo`00000=on@Ki003o`000?oT6nCoi1_T
00_oi1_T00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oj1OXonPGj006onPGj003o`000?oS7>?ohacS
00GohacS0_l00003om@[e003o`000?oM8]gogB;M00KogB;M00?o0000on8Mh_oR7N802_oR7N800ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003oiaSWonLHi`07onLHi`03o`000?oL8mcog2?L00[og2?L00?o0000on@Ki?oT
6n@03?oT6n@00ol0003oi1_Ton@Ki00<on@Ki003o`000?oZ5N[ojQGZ00KojQGZ00?o0000onPGj?oX
5nP02?oX5nP00ol0003ohacSon<Lh`02on<Lh`;o00001_oD:m@00ol0003ogB;MomdRg@05omdRg@03
o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oW6>OoiaSW00GoiaSW
00?o0000om`Sg?oL8m`03?oL8m`2o`0000coi1_T00?o0000on@Ki?oT6n@03OoT6n@00ol0003ojQGZ
onXEjP04onXEjP03o`000?oX5nSoj1OX00[oj1OX00Co0000on<Lhol0003o00002?oD:m@00ol0003o
gB;MomdRg@06omdRg@03o`000?oR7N;ohQgR00WohQgR00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oW6>L00ol0003og2?Lom`Sg00=om`Sg003o`000?oQ7^7o000000;o00002?oT6n@00ol0003oi1_T
on@Ki00?on@Ki0Ko00003_oX5nP00ol0003oe2_Dom@[e008om@[e003o`000?oM8]gogB;M00KogB;M
00?o0000on8Mh_oR7N802OoR7N800ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000on8Mh_oR7N;ohQgR
0_l0000?om`Sg003o`000?oQ7^7ohAkQ00?ohAkQ0ol00005on@Ki0;o00004?oT6n@01_l0003ogb3O
omlPgol0003oebSGo`0000koj1OX00?o0000om@[e?oD:m@02OoD:m@00ol0003ogB;MomdRg@05omdR
g@03o`000?oR7N;ohQgR00WohQgR00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000on8Mh_oR7N800ooR7N800ol0003o
g2?Lom`Sg00=om`Sg003o`000?oQ7^7ohAkQ00KohAkQ0ol000001?oT6nCo0000on4NhOoQ7^43o`00
00coi1_T00Go0000omlPgooO8=oogb3Oo`000002omLXe`03o`000?oX5nSoj1OX00_oj1OX00?o0000
om@[e?oD:m@02OoD:m@00ol0003ogB;MomdRg@06omdRg@03o`000?oR7N;ohQgR00SohQgR0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003ohQgRon8MhP04on8MhPoo00003?oQ7^400ol0003ohAkQon4Nh@04on4N
h@?o00002?oT6n@00ol0003ogb3OomlPg`02omlPg`05o`000?oG:=OoebSGomLXeol000003?oX5nP0
0ol0003oe2_Dom@[e009om@[e003o`000?oM8]gogB;M00GogB;M3?l00002onPGj0;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?oC;=?odbcC00_odbcC00?o0000on4N
hOoQ7^402_oQ7^400ol0003ohAkQon4Nh@07on4Nh@;o00001OoT6n@00ol0003ogb3OomlPg`03omlP
g`03o`000?oG:=OoebSG00;oebSG00?o0000onPGj?oX5nP02OoX5nP00ol0003oe2_Dom@[e00:om@[
e003o`000?oM8]gogB;M00?ogB;M00?o0000om4^dOoA;]402OoA;]400ol0003oj1OXonPGj002onPG
j0;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP06on8MhP03o`000?oC;=?odbcC00[o
dbcC00?o0000on4NhOoQ7^402ooQ7^400ol0003ohAkQon4Nh@09on4Nh@?o000000?oi1_To`000?oO
8=l01OoO8=l00ol0003oebSGomLXe`03omLXe`03o`000?oX5nSoj1OX00Soj1OX3_l00003omdRg@;o
00002ooA;]400ol0003oj1OXonPGj005onPGj003o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000on8Mh_oR7N801OoR7N800ol0003ofBKIo`00000;om</d`03o`000?oQ7^7ohAkQ00[ohAkQ
0_l0000>on4Nh@03o`000?oO8=oogb3O00Gogb3O00?o0000omLXeooG:=L00ooG:=L00ol0003oj1OX
onPGj008onPGj003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omdRgOl000003OoA;]400ol0003oj1OX
onPGj006onPGj0;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00KohQgR00Co
0000omTVfOoI9]Wo00002_oC;=<00ol0003ohAkQon4Nh@09on4Nh@03o`000?oO7moo000000kohAkQ
00?o0000omlPgooO8=l01OoO8=l00ol0003oebSGomLXe`04omLXe`03o`000?oX5nSoj1OX00Koj1OX
00?o0000on4NhOoQ7^403OoQ7^400ol0003odBkAom4^d@0<om4^d@03o`000?oX5nSoj1OX00Soj1OX
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oR7N;ohQgR00GohQgR00?o0000omTVfOoI9]T00_oI
9]T00ol0003odbcCom</d`06om</d`03o`000?oQ7^7ohAkQ00SohAkQ0_l00003omlOg`03o`000?oQ
7^7ohAkQ00_ohAkQ00?o0000omlPgooO8=l01OoO8=l00ol0003oebSGomLXe`05omLXe`03o`000?oX
5nSoj1OX00Goj1OX00?o0000on4NhOoQ7^403OoQ7^400ol0003odBkAom4^d@0;om4^d@03o`000?oX
5nSoj1OX00Woj1OX00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oR7N;ohQgR00KohQgR00?o0000
omTVfOoI9]T00ooI9]T00ol0003odbcCom</d`05om</d`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000
omlOgooO7ml00ooO7ml00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oO8=oogb3O00Kogb3O00?o0000
omLXeooG:=L01_oG:=L00ol0003oj1OXonPGj004onPGj003o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
onPGj003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?oR7N;ohQgR00KohQgR00?o0000omTVfOoI9]T01OoI9]T00ol0
003odbcCom</d`04om</d`03o`000?oQ7^7ohAkQ00GohAkQ0_l00006omlOg`03o`000?oQ7^7ohAkQ
00WohAkQ0_l00008omlPg`03o`000?oG:=OoebSG00KoebSG1Ol000000ooX5nSo0000on4Nh@0?on4N
h@03o`000?o?<<oocc3?00_occ3?00?o0000onPGj?oX5nP02OoX5nP00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?oR7N;ohQgR00KohQgR00?o0000omTVfOoI9]T01_oI9]T00ol0003o
dbcCom</d`04o`0000KohAkQ00?o0000omlOgooO7ml01ooO7ml00ol0003ohAkQon4Nh@05on4Nh@?o
000000?ofbCKo`000?oO8=l01ooO8=l00ol0003oebSGomLXe`05omLXe`03o`000?oX5nSoj1OX00?o
j1OX0_l0000?on4Nh@;o00003Oo?<<l00ol0003oj1OXonPGj008onPGj003o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WohQgR00?o0000omTVfOoI9]T01ooI9]T2o`0000CojAKY00Co0000on4NhOoQ7^7o
hAkQ0_l0000:omlOg`03o`000?oQ7^7ohAkQ00;ohAkQ0ol00005om/Tf`03o`000?oO8=oogb3O00Go
gb3O00?o0000omLXeooG:=L01?oG:=L00ol0003oj1OXonPGj006onPGj003o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002omlOg`03o`000?o?<<oocc3?00[occ3?00?o0000onPGj?oX5nP02?oX5nP00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000on8Mh_oR7N801_oR7N800ol0003ofBKIomTVf@08omTVf@03o`00
0?oY5^WojAKY00CojAKY00?o0000on4NhOl000003?oO7ml00ol0003ohAkQo`000002o`0000WofbCK
00?o0000omlPgooO8=l01?oO8=l00ol0003oebSGomLXe`03omLXe`03o`000?oX5nSoj1OX00Soj1OX
1_l00004on4Nh@;o00001OoO7ml00ol0003occ3?oll`c`09oll`c`03o`000?oX5nSoj1OX00Soj1OX
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oR7N;ohQgR00GohQgR00?o0000omTVfOoI9]T01ooI
9]T00ol0003ojAKYonTFj@06onTFj@03o`000?oO7moogaoO00cogaoO00?o0000om/TfooK9=/02_oK
9=/00ol0003ogb3OomlPg`04omlPg`04o`000?oG:=OoebSGomLXe`;o00002ooX5nP00ol0003oiA[U
onDJi@03onDJi@Co00002?oO7ml00ol0003occ3?oll`c`08oll`c`03o`000?oX5nSoj1OX00Ooj1OX
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000on8Mh_oR7N800ooR7N800ol0003ofBKIomTVf@07omTVf@03o`000?oY
5^WojAKY00OojAKY00?o0000omlOgooO7ml03?oO7ml00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oO
8=oogb3O00?ogb3O00Co0000omLXeooG:=Oo00003OoX5nP00ol0003oiA[UonDJi@06onDJi@03o`00
0?oO7moogaoO00OogaoO00?o0000oll`coo?<<l01oo?<<l00ol0003oj1OXonPGj006onPGj004o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00;ohQgR00?o0000omTVfOoI9]T0
1_oI9]T00ol0003ojAKYonTFj@09onTFj@03o`000?oO7moogaoO00WogaoO0_l0000>om/Tf`?o0000
0ooO8=l00ol0003oebSGo`00000=onPGj003o`000?oU6^GoiA[U00OoiA[U00?o0000omlOgooO7ml0
2?oO7ml:o`0000Koj1OX0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OofBKI00?o
0000onTFjOoY5^T02_oY5^T00ol0003ogaoOomlOg`06omlOg`;o000000?oh1oPo`000?oK9=/02ooK
9=/2o`0000?oj1OX1Ol0000>onPGj003o`000?oU6^GoiA[U00OoiA[U00?o0000omlOgooO7ml02?oO
7ml00ol0003ofBKIomTVf@06omTVf@03o`000?oX5nSoj1OX00?oj1OX00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oj1OXonPGj003onPGj0Co00000_oI9]T00ol0003ojAKYonTFj@0;
onTFj@03o`000?oO7moogaoO00?ogaoO0ol00004on0Oh003o`000?oK9=_ofbCK00OofbCK0_l00008
onPGj003o`000?oX5nSoj1OX00goj1OX00?o0000onDJiOoU6^D02?oU6^D00ol0003ogaoOomlOg`07
omlOg`03o`000?oI9]WofBKI00OofBKI0ol000000ooX5nSo0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oX5nSoj1OX00Ooj1OX0_l0000?onTFj@03o`000?oO7moogaoO00;o00002?oP7n000ol0
003ofbCKom/Tf`05om/Tf`03o`000?oX5nSoj1OX00Soj1OX00?o0000onPGj?oX5nP03OoX5nP00ol0
003oiA[UonDJi@08onDJi@03o`000?oO7moogaoO00KogaoO00?o0000omTVfOoI9]T02?oI9]T01?l0
003oiQWVonHIi_l0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oj1OXonPGj009onPG
j003o`000?oY5^WojAKY00kojAKY0_l0000;on0Oh003o`000?oK9=_ofbCK00;ofbCK0_l0000;onPG
j003o`000?oX5nSoj1OX00goj1OX00?o0000onDJiOoU6^D02?oU6^D00ol0003ogaoOomlOg`06omlO
g`03o`000?oI9]WofBKI00OofBKI00Go0000onHIi_oV6NKoiQWVo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oj1OXonPGj00:onPGj003o`000?oY5^WojAKY00gojAKY0_l0000<on0Oh004o`000?oK9=_o0000
o`0000goj1OX00?o0000onPGj?oX5nP03?oX5nP00ol0003oiA[UonDJi@09onDJi@03o`000?oO7moo
gaoO00KogaoO00?o0000omTVfOoI9]T01_oI9]T00ol0003oiQWVonHIiP03onHIiP03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oj1OXonPGj00:onPGj003o`000?oY5^WojAKY00cojAKY00Co0000olha
c_o><Lko00003?oP7n000ol0003oj1OXonPGj00>onPGj003o`000?oX5nSoj1OX00Soj1OX1?l0000;
onDJi@03o`000?oO7moogaoO00KogaoO00?o0000omTVfOoI9]T01OoI9]T00ol0003oiQWVonHIiP04
onHIiP03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oj1OXonPGj00;onPGj003o`000?oY5^WojAKY
00_ojAKY00?o0000olhac_o><Lh00_o><Lh00ol0003oh1oPon0Oh009on0Oh003o`000?oX5nSoj1OX
00koj1OX00Co0000onPGj?oX5nSoj1OX1ol00003onTFj@03o`000?oU6^GoiA[U00WoiA[U00?o0000
omlOgooO7ml01_oO7ml00ol0003ofBKIomTVf@04omTVf@03o`000?oV6NKoiQWV00KoiQWV00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oX5nSoj1OX00coj1OX00?o0000onTFjOoY5^T02_oY5^T00ol0
003ocS7>olhacP03olhacP03o`000?oP7n3oh1oP00Soh1oP00?o0000onPGj?oX5nP03_oX5nP4o`00
00_ojAKY00?o0000onDJiOoU6^D02?oU6^D00ol0003ogaoOomlOg`05omlOg`03o`000?oI9]WofBKI
00GofBKI00?o0000onHIi_oV6NH01_oV6NH00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000onPGj?oX
5nP03?oX5nP7o`0000GojAKY00?o0000olhac_o><Lh01Oo><Lh00ol0003oh1oPon0Oh007on0Oh003
o`000?oX5nSoj1OX00koj1OX00?o0000onTFjOoY5^T03OoY5^T00ol0003oiA[UonDJi@08onDJi@03
o`000?oO7moogaoO00CogaoO00?o0000omTVfOoI9]T01?oI9]T00ol0003oiQWVonHIiP07onHIiP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oj1OXonPGj00=onPGj003o`000?oX5nSoj1OX00Coj1OX
1Ol00009olhacP03o`000?oP7n3oh1oP00Koh1oP00?o0000onPGj?oX5nP03_oX5nP00ol0003ojAKY
onTFj@0=onTFj@03o`000?oU6^GoiA[U00SoiA[U00Co0000omlOgooO7moogaoO1Ol00004omTVf@03
o`000?oV6NKoiQWV00WoiQWV1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=onPGj003o`000?oX5nSoj1OX00Woj1OX
0_l00009olhacP03o`000?oP7n3oh1oP00Koh1oP00?o0000onPGj?oX5nP03?oX5nP00ol0003ojAKY
onTFj@0?onTFj@Ko00001?oU6^D4o`0000GoiaSW0_l000000ooI9]Wo0000onHIiP0;onHIiP04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oW6>OoiaSWonLHi`?o00002_oX5nP00ol0003o
j1OXonPGj009onPGj003o`000?oD:mCo000000;o00001oo><Lh00ol0003oh1oPon0Oh005on0Oh003
o`000?oX5nSoj1OX00Soj1OX1Ol0000AonTFj@03o`000?oV6NKoiQWV00?oiQWV1?l0000;onLHi`03
o`000?oV6NKoiQWV00[oiQWV00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000onLHiooW6>L01OoW6>L2o`0000Ooj1OX
00?o0000onPGj?oX5nP02_oX5nP00ol0003oe2_Dom@[e002om@[e0?o00001Oo><Lh00ol0003oh1oP
on0Oh004on0Oh004o`000?oX5nSoj1OXonPGj0Oo00001?oR7N800ol0003ojAKYonTFj@0>onTFj@03
o`000?oV6NKoiQWV00OoiQWV00?o0000onLHiooW6>L02OoW6>L00ol0003oiQWVonHIiP09onHIiP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oiaSWonLHi`08onLHi`;o00001?oX5nP00ol0003oj1OX
onPGj00;onPGj003o`000?oD:mCoe2_D00Goe2_D0ol00003olhacP04o`000?oP7n3oh1oPon0Oh0Ko
00003?oR7N800ol0003ojAKYonTFj@0=onTFj@03o`000?oV6NKoiQWV00OoiQWV00?o0000onLHiooW
6>L02_oW6>L00ol0003oiQWVonHIiP08onHIiP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onLHi`?o000000?oj1OXo`000?oX5nP0
3?oX5nP00ol0003oe2_Dom@[e008om@[e0?o000000CocS7>o`000?l0003o00000_oY5^T00ol0003o
hQgRon8MhP0=on8MhP03o`000?oY5^WojAKY00cojAKY00?o0000onHIi_oV6NH02?oV6NH00ol0003o
iaSWonLHi`0;onLHi`03o`000?oV6NKoiQWV00KoiQWV00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
iaSW00?o0000onPGj?oX5nP03?oX5nP00ol0003oe2_Dom@[e00;om@[e003o`000?oY5^WojAKY00?o
jAKY00?o0000on8Mh_oR7N803?oR7N800ol0003ofRGJo`00000=onTFj@03o`000?oV6NKoiQWV00So
iQWV00?o0000onLHiooW6>L03?oW6>L3o`0000GoiQWV00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oW6>OoiaSW00coiaSW00?o0000onPGj?oX5nP03?oX5nP00ol0003oe2_Dom@[e00:om@[e003o`00
0?oY5^WojAKY00GojAKY00?o0000on8Mh_oR7N802_oR7N801?l0003ofRGJomXUf_oJ9MX2o`0000[o
jAKY00?o0000onHIi_oV6NH02OoV6NH00ol0003oiaSWonLHi`0<onLHi`03o`000?oY5^WojAKY00?o
000000?oiQWVo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oW6>OoiaSW00_oiaSW00?o0000onPGj?oX5nP0
3?oX5nP00ol0003oe2_Dom@[e009om@[e003o`000?oY5^WojAKY00KojAKY00?o0000on8Mh_oR7N80
2OoR7N800ol0003ofRGJomXUfP02omXUfP03o`000?oW6>Oo000000;o00001ooY5^T00ol0003oiQWV
onHIiP09onHIiP03o`000?oW6>OoiaSW00_oiaSW00?o0000onTFjOoY5^T01?oY5^T00ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000onLHiooW6>L02ooW6>L00ol0003oj1OXonPGj00;onPGj003o`000?oD
:mCoe2_D00Soe2_D00?o0000onTFjOoY5^T01ooY5^T00ol0003ohQgRon8MhP08on8MhP03o`000?oJ
9M[ofRGJ00?ofRGJ00?o0000onLHiooW6>L00_oW6>L2o`0000CojAKY00?o0000onHIi_oV6NH02_oV
6NH00ol0003oiaSWonLHi`0:onLHi`03o`000?oY5^WojAKY00GojAKY00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oW6>OoiaSW00[oiaSW0ol0000;onPGj0Ko00001?oD:m@00ol0003ojAKYonTFj@08
onTFj@03o`000?oR7N;ohQgR00OohQgR00?o0000omXUf_oJ9MX00ooJ9MX00ol0003oiaSWonLHi`05
onLHi`?o000000?ojAKYo`000?oV6NH02ooV6NH00ol0003oiaSWonLHi`09onLHi`03o`000?oY5^Wo
jAKY00OojAKY00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oW6>OoiaSW00WoiaSW00?o0000omdR
gOoM8]d01?l00006onPGj003o`000?oV6NKoiQWV00CoiQWV1?l0000<onTFj@03o`000?oR7N;ohQgR
00GohQgR00?o0000omXUf_oJ9MX01?oJ9MX00ol0003oiaSWonLHi`08onLHi`03o`000?oV6NKoiQWV
00_oiQWV00?o0000onLHiooW6>L02?oW6>L00ol0003ojAKYonTFj@08onTFj@Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oW6>OoiaSW00OoiaSW00?o0000omdRgOoM8]d01OoM8]d3o`0000;oj1OX00?o0000onHIi_oV
6NH02?oV6NH00ol0003ojAKYonTFj@0:onTFj@03o`000?oR7N;ohQgR00CohQgR00?o0000omXUf_oJ
9MX01OoJ9MX00ol0003oiaSWonLHi`08onLHi`03o`000?oV6NKoiQWV00WoiQWV1?l00008onLHi`03
o`000?oY5^WojAKY00WojAKY00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oiaSW
onLHi`05onLHi`03o`000?oM8]gogB;M00WogB;M0_l0000<onHIiP03o`000?oY5^WojAKY00WojAKY
00?o0000on8Mh_oR7N800ooR7N800ol0003ofRGJomXUfP05omXUfP03o`000?oW6>OoiaSW00[oiaSW
00?o0000onHIi_oV6NH01?oV6NH4o`0000CoiQWV00?o0000onLHiooW6>L01?oW6>L00ol0003ojAKY
onTFj@0:onTFj@03o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oW6>OoiaSW00?oiaSW00?o0000omdRgOoM8]d02ooM
8]d00ol0003oiQWVonHIiP0:onHIiP03o`000?oY5^WojAKY00WojAKY00?o0000on8Mh_oR7N800_oR
7N800ol0003ofRGJomXUfP06omXUfP03o`000?oW6>OoiaSW00[oiaSW00?o0000onHIi_oV6NH01?l0
0009onHIiPKo00003?oY5^T00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000onLHiooW6>OoiaSW0_l0
000=omdRg@03o`000?oV6NKoiQWV00[oiQWV00?o0000onTFjOoY5^T02OoY5^T01Ol0003ohQgRon8M
h_oR7N;o000000WofRGJ00?o0000onLHiooW6>L02ooW6>L2o`0000goiQWV00?o0000onLHiooW6>L0
0_oW6>L00ol0003ojAKYonTFj@0:onTFj@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oiaSWo`00
0002om`Sg0;o00002ooM8]d00ol0003oiQWVonHIiP0;onHIiP03o`000?oY5^WojAKY00WojAKY00?o
0000on8Mh_l000002OoJ9MX00ol0003oiaSWonLHi`0<onLHi`03o`000?oV6NKoiQWV00coiQWV00?o
0000onLHiooW6>L00ooW6>L00ol0003ojAKYonTFj@09onTFj@03o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003og2?Lom`Sg003om`Sg0;o00002_oM8]d00ol0003oiQWVonHIiP0:onHIiP03o`000?oY5^Wo
jAKY00SojAKY1Ol00008omXUfP03o`000?oW6>OoiaSW00coiaSW00?o0000onHIi_oV6NH02ooV6NH0
0ol0003oiaSWonLHi`05onLHi`03o`000?oY5^WojAKY00SojAKY00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooL8m`2o`0000SogB;M00?o0000onHIi_oV6NH02_oV6NH00ol0003ojAKYonTFj@07onTF
j@03o`000?oS7>?ohacS00?ohacS0ol00005omXUfP03o`000?oW6>OoiaSW00_oiaSW00?o0000onHI
i_oV6NH03?oV6NH00ol0003oiaSWonLHi`06onLHi`03o`000?oY5^WojAKY00OojAKY00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000Wog2?L00?o0000omdRgOoM8]d01OoM8]d2o`0000co
iQWV00?o0000onTFjOoY5^T01OoY5^T00ol0003ohacSon<Lh`07on<Lh`?o000000?ofRGJo`000?oW
6>L03OoW6>L00ol0003oiQWVonHIiP0<onHIiP03o`000?oW6>OoiaSW00KoiaSW00?o0000onTFjOoY
5^T01_oY5^T00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?oL8mcog2?L00Oog2?L
0_l00004omdRg@03o`000?oK9=_ofbCK00;o00002_oV6NH00ol0003ojAKYonTFj@03onTFj@;o0000
3OoS7><2o`0000goiaSW0ol0000=onHIiP03o`000?oW6>OoiaSW00OoiaSW00?o0000onTFjOoY5^T0
1OoY5^T00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?oL8mcog2?L00Sog2?L0_l0
00000ooM8]go0000om/Tf`04om/Tf`03o`000?oV6NKoiQWV00OoiQWV00Co0000onTFjOoY5^WojAKY
0_l00002on4Nh@03o`000?oS7>?ohacS00cohacS3Ol00003omTVf@03o`000?oV6NKoiQWV00[oiQWV
00?o0000onLHiooW6>L02?oW6>L01?l0003ojAKYonTFjOoY5^T4o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003og2?L
om`Sg009om`Sg003o`000?oK9=_ofbCK00GofbCK0_l00008onHIiP03o`000?oY5^Wo000000GohAkQ
00?o0000on<LhooS7><02ooS7><00ol0003ohQgRon8MhP09on8MhP03o`000?oI9]WofBKI00;ofBKI
0_l00009onHIiP03o`000?oW6>OoiaSW00[oiaSW0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?oL8mcog2?L00Sog2?L00?o0000om/TfooK9=/01ooK9=/4o`0000?oiQWV0ol0
0007on4Nh@03o`000?oS7>?ohacS00[ohacS00?o0000on8Mh_oR7N802OoR7N800ol0003ofBKIomTV
f@04omTVf@;o00001ooV6NH00ol0003oiaSWonLHi`0:onLHi`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oL8mcog2?L00Oog2?L00?o0000om/TfooK9=/02?oK9=/0
1?l0003ogB;MomdRgOoM8]d3o`0000;ogb3O00?o0000on4NhOoQ7^401_oQ7^400ol0003ohacSon<L
h`08on<Lh`03o`000?oR7N;ohQgR00[ohQgR00?o0000omTVfOoI9]T01_oI9]T00ol0003oiQWVonHI
iP04onHIiP03o`000?oW6>OoiaSW00WoiaSW00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om`Sg?oL8m`01OoL8m`00ol0003ofbCKom/Tf`08om/Tf`03o`000?oM8]go
gB;M00CogB;M00Go0000omlPgooO8=oogb3Oo`000008on4Nh@03o`000?oS7>?ohacS00OohacS00?o
0000on8Mh_oR7N802_oR7N800ol0003ofBKIomTVf@07omTVf@;o00001?oV6NH00ol0003oiaSWonLH
i`08onLHi`03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om`Sg?oL8m`00ooL8m`0
0ol0003ofbCKom/Tf`08om/Tf`03o`000?oM8]gogB;M00CogB;M00?o0000omlPgooO8=l00_oO8=l0
0ol0003ohAkQon4Nh@07on4Nh@03o`000?oS7>?ohacS00KohacS00?o0000on8Mh_oR7N802_oR7N80
0ol0003ofBKIomTVf@09omTVf@05o`000?oV6NKoiQWVonHIi_l000002OoW6>L00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_ofbCK00?o0000omdRgOoM8]d01?oM8]d00ol0003ogb3OomlPg`03
omlPg`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000on<LhooS7><01OoS7><00ol0003ohQgRon8MhP0:
on8MhP03o`000?oI9]WofBKI00WofBKI1?l00009onLHi`03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oU6^GoiA[U
onDJiOl000002_oK9=/00ol0003ogB;MomdRg@05omdRg@03o`000?oO8=oogb3O00?ogb3O00?o0000
on4NhOoQ7^402?oQ7^400ol0003ohacSon<Lh`04on<Lh`03o`000?oR7N;ohQgR00WohQgR00?o0000
omTVfOoI9]T02?oI9]T2o`0000?oi1_T00?o0000onLHiooW6>L01_oW6>L00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000onDJiOoU6^D00ooU6^D00ol0003ofbCKom/Tf`06om/Tf`03o`000?oM8]gogB;M
00GogB;M00?o0000omlPgooO8=l01?oO8=l00ol0003ohAkQon4Nh@09on4Nh@03o`000?oS7>?ohacS
00;ohacS00?o0000on8Mh_oR7N802_oR7N800ol0003ofBKIomTVf@06omTVf@;o00001_oT6n@8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003oiA[UonDJi@05onDJi@03o`000?oK9=_ofbCK00GofbCK00?o0000omdRgOoM
8]d01OoM8]d00ol0003ogb3OomlPg`05omlPg`03o`000?oQ7^7ohAkQ00WohAkQ00Go0000on<LhooS
7>?ohacSo`00000<on8MhP03o`000?oI9]WofBKI00CofBKI0_l00008on@Ki003o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oU6^GoiA[U00OoiA[U00?o0000om/TfooK
9=/00ooK9=/00ol0003ogB;MomdRg@06omdRg@03o`000?oO8=oogb3O00Gogb3O00?o0000on4NhOoQ
7^402_oQ7^400ol0003ohacSo`000004o`0000WohQgR00?o0000omTVfOoI9]T00_oI9]T2o`0000[o
i1_T00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003oiA[UonDJi@07onDJi@03o`00
0?oK9=_ofbCK00;ofbCK00?o0000omdRgOoM8]d01_oM8]d00ol0003ogb3OomlPg`07omlPg`;o0000
2ooQ7^400ol0003ohAkQon4Nh@03on4Nh@Oo00000_oR7N800ol0003ofBKIomTVf@02o`0000_oi1_T
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000onDJiOoU6^D02OoU
6^D01Ol0003ofbCKom/TfooK9=_o000000SogB;M00?o0000omlPgooO8=l01ooO8=l00ol0003oiA[U
o`000002o`0000SohAkQ00?o0000on4NhOoQ7^402_oQ7^45o`0000goi1_T00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<onDJi@03o`000?oK9=_o000000WogB;M00?o
0000omlPgooO8=l01_oO8=l00ol0003oiA[UonDJi@03onDJi@?o00001?oQ7^400ol0003ohAkQon4N
h@0=on4Nh@03o`000?oT6nCoi1_T00goi1_T00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ooj1OX2o`0000_oiA[U00?o0000omdRgOoM8]d01ooM8]d00ol0003ogb3OomlPg`07
omlPg`03o`000?oU6^GoiA[U00KoiA[U0ol000000ooQ7^7o0000on4Nh@0>on4Nh@03o`000?oT6nCo
i1_T00coi1_T00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00KonPGj0_l00009onDJ
i@03o`000?oM8]gogB;M00;ogB;M1_l00008omlPg`03o`000?oU6^GoiA[U00[oiA[U00?o0000on4N
hOoQ7^403ooQ7^400ol0003oi1_Ton@Ki00:on@Ki0;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00So
nPGj0_l00007onDJi@Go00001_o[5>/00ol0003ogb3OomlPg`05omlPg`03o`000?oU6^GoiA[U00[o
iA[U00?o0000on4NhOoQ7^403ooQ7^400ol0003oi1_Ton@Ki007on@Ki0?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oj1O[onPGj00[onPGj0_l00005onDJi@03o`000?o[5>_ojaC[00WojaC[00?o0000omlPgooO
8=l00ooO8=l00ol0003oiA[UonDJi@0;onDJi@03o`000?oQ7^7ohAkQ00oohAkQ00?o0000on@Ki?oT
6n@01OoT6n@2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5nP0<ooX5nP;o000000?oiA[Uo`000?l00000
3Oo[5>/00ol0003ogb3OomlPg`02omlPg`03o`000?oU6^GoiA[U00_oiA[U5?l00004on@Ki0;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooX5n_oj1OX03_oj1OX00ol0003onPGjo`00000>on/Dj`04o`000?oO8=oogb3Oo`0000koiA[U
00?o0000on/Djoo[5>/04?o[5>/00ol0003oi1_To`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5
nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000003_o[5>/00ol0003ogb3Oo`00000>onDJi@03o`00
0?o[5>_ojaC[017ojaC[00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00conPGj00?o
0000ooX5n_oj1OX00_oj1OX00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oU6^GoiA[U00WoiA[U1Ol0
000Bon/Dj`;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003ojaC[on/Dj`0<on/Dj`03o`000?oU6^GoiA[U00;oiA[U1ol00004ooX5nP03o`000?o[5>_o
jaC[00oojaC[00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003onPGjooX5nP06ooX5
nP03o`000?o[5>_ojaC[00cojaC[1?l0000<ooX5nP03o`000?o[5>_ojaC[00cojaC[0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00Oo
nPGj00?o0000on/Djoo[5>/03?o[5>/00ol0003onPGjooX5nP0=ooX5nP03o`000?o[5>_ojaC[00_o
jaC[00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ojaC[on/Dj`0:on/Dj`03o`000?oj1O[onPGj00konPGj00?o0000on/Djoo[
5>/02Oo[5>/2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000on/Djoo[5>/02_o[5>/00ol0003onPGj
ooX5nP0?ooX5nP03o`000?o[5>_ojaC[00KojaC[0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooX5n_l0003onPGj00gonPGj3?l0
000AooX5nP?o00001_o[5>/00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000oo[5>/2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000on/Djol000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01_l00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0007o`00o`Soool01Ol00?l2oooo00?o003o00?oool0o`00ool00?l01_l0
0?l2oooo06go003o0Oooool007;o003o0_ooo`06o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03
o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo0008o`00o`03oooo0?l00?oo
003o00?o003o0_ooo`03o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1]o`00o`7ooooo001ao`00
o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00
o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`002Ol00?l00ooo
o`3o003oo`00o`03o`00o`04oooo0?l00?oo003oo`00o`;oool01Ol00?l00oooo`3o003oo`00o`05
o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol0
0?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0009o`00
o`;oool02?l00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1]o`00
o`7ooooo001ao`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo
003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0:o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool0073o003o0_ooo`02o`00o`04oooo
0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co
003o0_ooo`0;o`00o`03oooo0?l00?oo003o00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06go
003o0Oooool0073o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003o
o`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co
003o00?oool0o`00ool00?l00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00
L?l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o
0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l2oooo00Co
003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_ooo`04o`00o`03oooo
0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`03o`00o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001_o`00o`;oool01Ol00?l3oooo00Go003o00?o
ool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_oo
o`0=o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00o`;oool00ol00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00K_l00?l3oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00
o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`05o`00o`;oool01?l00?l2oooo00Co
003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo
0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`04o`00o`;oool00ol00?l3oooo00Co003o
0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001]o`00o`7ooooo001]o`00o`?oool01Ol0
0?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Go003o1_ooo`06o`00o`;oool00_l0
0?l2oooo00Go003o1Oooo`1]o`00o`7ooooo001/o`00o`Koool000?o003ooooo0?ooo`001Oooo`03
o`00o`Goool08Ol00?l4oooo00So003o1?ooo`1ho`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(30) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.979 .021 .979 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.978 .022 .978 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.978 .022 .978 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.978 .022 .978 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.857 .143 .857 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.978 .022 .978 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.848 .152 .848 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.899 .101 .899 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.878 .122 .878 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.979 .021 .979 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.838 .162 .838 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.979 .021 .979 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.869 .131 .869 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.838 .162 .838 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.866 .134 .866 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.834 .166 .834 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.979 .021 .979 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.979 .021 .979 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.841 .159 .841 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.848 .152 .848 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.694 .306 .694 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.781 .219 .781 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.781 .219 .781 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.788 .212 .788 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.886 .114 .886 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.872 .128 .872 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.8 .2 .8 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.837 .163 .837 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.793 .207 .793 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.846 .154 .846 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.87 .13 .87 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.978 .022 .978 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.873 .127 .873 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.816 .184 .816 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.901 .099 .901 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.867 .133 .867 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.784 .216 .784 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.978 .022 .978 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.9 .1 .9 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.84 .16 .84 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.858 .142 .858 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.84 .16 .84 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.828 .172 .828 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.876 .124 .876 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.803 .197 .803 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.978 .022 .978 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.798 .202 .798 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.752 .248 .752 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.892 .108 .892 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.901 .099 .901 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.811 .189 .811 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.802 .198 .802 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.863 .137 .863 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.978 .022 .978 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.884 .116 .884 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.87 .13 .87 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.87 .13 .87 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.626 .374 .626 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.798 .202 .798 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.861 .139 .861 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.892 .108 .892 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.772 .228 .772 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.719 .281 .719 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.726 .274 .726 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.759 .241 .759 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.876 .124 .876 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.763 .237 .763 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.822 .178 .822 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.809 .191 .809 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.86 .14 .86 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.87 .13 .87 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.851 .149 .851 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.896 .104 .896 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.979 .021 .979 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.774 .226 .774 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.816 .184 .816 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.754 .246 .754 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.978 .022 .978 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.89 .11 .89 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.844 .156 .844 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.718 .282 .718 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.775 .225 .775 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.871 .129 .871 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.818 .182 .818 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.855 .145 .855 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.858 .142 .858 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.733 .267 .733 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.817 .183 .817 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.828 .172 .828 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.804 .196 .804 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.868 .132 .868 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.889 .111 .889 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.875 .125 .875 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.742 .258 .742 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.803 .197 .803 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.872 .128 .872 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.822 .178 .822 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.824 .176 .824 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.854 .146 .854 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.815 .185 .815 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.79 .21 .79 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.767 .233 .767 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.978 .022 .978 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.772 .228 .772 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.842 .158 .842 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.79 .21 .79 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.827 .173 .827 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.865 .135 .865 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.978 .022 .978 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.876 .124 .876 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.849 .151 .849 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.858 .142 .858 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.874 .126 .874 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.825 .175 .825 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.804 .196 .804 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.831 .169 .831 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.836 .164 .836 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.979 .021 .979 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.898 .102 .898 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.86 .14 .86 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.898 .102 .898 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.784 .216 .784 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.833 .167 .833 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.719 .281 .719 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.812 .188 .812 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.811 .189 .811 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.875 .125 .875 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.904 .096 .904 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.77 .23 .77 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.977 .023 .977 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.839 .161 .839 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.827 .173 .827 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.9 .1 .9 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.862 .138 .862 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.831 .169 .831 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.856 .144 .856 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.9 .1 .9 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.777 .223 .777 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.833 .167 .833 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.864 .136 .864 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.931 .069 .931 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.773 .227 .773 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.83 .17 .83 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.862 .138 .862 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.868 .132 .868 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.979 .021 .979 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.8 .2 .8 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.978 .022 .978 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.897 .103 .897 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.888 .112 .888 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.869 .131 .869 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.82 .18 .82 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.782 .218 .782 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.833 .167 .833 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.862 .138 .862 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.882 .118 .882 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.891 .109 .891 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.892 .108 .892 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.851 .149 .851 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.932 .068 .932 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.847 .153 .847 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.82 .18 .82 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.748 .252 .748 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.754 .246 .754 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.823 .177 .823 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.852 .148 .852 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.978 .022 .978 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.879 .121 .879 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.84 .16 .84 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.742 .258 .742 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.875 .125 .875 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.894 .106 .894 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.817 .183 .817 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.978 .022 .978 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.8 .2 .8 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.859 .141 .859 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.873 .127 .873 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.978 .022 .978 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.825 .175 .825 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.845 .155 .845 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.889 .111 .889 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.859 .141 .859 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.813 .187 .813 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.941 .059 .941 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.816 .184 .816 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.903 .097 .903 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.838 .162 .838 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.743 .257 .743 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.731 .269 .731 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.784 .216 .784 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.849 .151 .849 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.89 .11 .89 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.879 .121 .879 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.892 .108 .892 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.877 .123 .877 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.978 .022 .978 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.931 .069 .931 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.83 .17 .83 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.978 .022 .978 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.873 .127 .873 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.889 .111 .889 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.882 .118 .882 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.853 .147 .853 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.902 .098 .902 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.886 .114 .886 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.859 .141 .859 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.979 .021 .979 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.868 .132 .868 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.869 .131 .869 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.978 .022 .978 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.933 .067 .933 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.978 .022 .978 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.978 .022 .978 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.918 .082 .918 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.979 .021 .979 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.86 .14 .86 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.979 .021 .979 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.773 .227 .773 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.844 .156 .844 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.806 .194 .806 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.919 .081 .919 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.905 .095 .905 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.876 .124 .876 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.911 .089 .911 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.88 .12 .88 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.89 .11 .89 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.892 .108 .892 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.846 .154 .846 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.839 .161 .839 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.979 .021 .979 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.84 .16 .84 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.855 .145 .855 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.978 .022 .978 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.881 .119 .881 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.909 .091 .909 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.838 .162 .838 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.877 .123 .877 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.911 .089 .911 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.762 .238 .762 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.978 .022 .978 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.879 .121 .879 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.979 .021 .979 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.978 .022 .978 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.979 .021 .979 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.978 .022 .978 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.978 .022 .978 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ohAkQon4NhOl0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000on4NhOoQ7^400_oQ7^400ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000on4NhOoQ7^401OoQ7^400ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ohAkQon4Nh@06on4Nh@03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000on4NhOoQ7^402?oQ7^400ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oJ9M[o0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cohAkQ00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omXUfP03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oiA[UonDJi@05onDJi@03o`000?oQ
7^7ohAkQ00_ohAkQ0ol00003on<Lh`03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omXUf_oJ9MX00ooJ9MX00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003oiA[UonDJi@06
onDJi@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000on<LhooS7><01?oS7><00ol0003onPGjooX5nP0:
ooX5nP04o`000?oV6NKoiQWVonHIiP;o00002_oj1OX2o`000003onLHiol0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofRGJomXUfP05omXUfP03o`000?oj1O[o
nPGj00WonPGj00?o0000omDZeOl000002ooj1OX00ol0003oiA[UonDJi@06onDJi@03o`000?oQ7^7o
hAkQ00WohAkQ00?o0000on<LhooS7><01_oS7><00ol0003onPGjooX5nP08ooX5nP03o`000?oV6NKo
iQWV00CoiQWV0_l00005ooX5nP?o00001?oW6>L00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omXUfP03o`000?oj1O[onPGj00OonPGj0_l00003omDZ
e@03o`000?oj1O[onPGj00OonPGj00?o0000onDJiOoU6^D01ooU6^D00ol0003ohAkQon4Nh@09on4N
h@03o`000?oS7>?ohacS00OohacS00?o0000ooX5n_oj1OX01Ooj1OX2o`0000WoiQWV0_l000000ooj
1O[o0000o`000007onLHi`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omXUf_oJ
9MX02?oJ9MX00ol0003onPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000ooX5n_oj
1OX01ooj1OX00ol0003oiA[UonDJi@08onDJi@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000on<LhooS
7><02OoS7><00ol0003onPGjooX5nP03ooX5nP03o`000?oV6NKoiQWV00_oiQWV00?o0000onLHiooW
6>L01ooW6>L00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003ogR7No`000005ooX5nP;o00002ooJ9MX2o`0000KonPGj
00?o0000omDZeOoE:]D01OoE:]D00ol0003onPGjooX5nP06ooX5nP03o`000?oU6^GoiA[U00SoiA[U
00?o0000on4NhOoQ7^401_oQ7^400ol0003ohacSon<Lh`0;on<Lh`05o`000?oj1O[onPGjooX5n_l0
00003_oV6NH00ol0003oiaSWonLHi`08onLHi`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oN8MkogR7NomhQg_l0
00000ooj1OX00ol0003ofRGJomXUfP0:omXUfP04o`000?oS7>?ohacSo`0000?onPGj0_l00008omDZ
e@03o`000?oj1O[onPGj00KonPGj00?o0000onDJiOoU6^D02OoU6^D00ol0003ohAkQon4Nh@05on4N
h@03o`000?oS7>?ohacS00cohacS00?o0000ooX5n_l000003ooV6NH00ol0003oiaSWonLHi`08onLH
i`03o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ogR7NomhQgP03omhQgP03o`000?oj1O[o000000_o
fRGJ0_l00004on<Lh`03o`000?oj1O[o000000_oeB[E00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
iA[UonDJi@09onDJi@03o`000?oQ7^7ohAkQ00CohAkQ00?o0000on<LhooS7><03_oS7><00ol0003o
iQWVonHIiP0>onHIiP03o`000?oW6>OoiaSW00WoiaSW00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omhQg_oN8Mh0
1?oN8Mh00ol0003ofRGJomXUfP09omXUfP03o`000?oS7>?ohacS00GohacS00?o0000omDZeOoE:]D0
2_oE:]D00ol0003onPGjooX5nP05ooX5nP03o`000?oU6^GoiA[U00[oiA[U00?o0000on4NhOoQ7^40
0ooQ7^400ol0003ohacSon<Lh`0>on<Lh`03o`000?oV6NKoiQWV00goiQWV00?o0000onLHiooW6>L0
2_oW6>L00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003ogR7NomhQ
gP05omhQgP03o`000?oJ9M[ofRGJ00OofRGJ0_l00008on<Lh`03o`000?oE:]GoeB[E00_oeB[E00?o
0000ooX5n_oj1OX01?oj1OX00ol0003oiA[UonDJi@0:onDJi@04o`000?oQ7^7ohAkQon4Nh@?o0000
3ooS7><00ol0003oiQWVonHIiP0>onHIiP03o`000?oW6>OoiaSW00[oiaSW00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oN8MkogR7N00OogR7N00?o0000omXUf_oJ9MX01?oJ9MX2o`0000_ohacS1?l0
0009omDZe@03o`000?oj1O[onPGj00?onPGj00?o0000onDJiOoU6^D02ooU6^D01?l0003ohAkQo`00
0?l00003on@Ki0;o00003?oS7><2o`00013oiQWV00?o0000onLHiooW6>L02ooW6>L00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003ogR7N
omhQgP07omhQgP03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000on<LhooS7><02ooS7><01?l0003oiA[U
onDJiOoU6^D5o`0000GoeB[E00?o0000ooX5n_oj1OX00_oj1OX00ol0003oiA[UonDJi@0<onDJi@03
o`000?oT6nCoi1_T00Goi1_T0_l00008on<Lh`;o00000_oQ7^400ol0003oiQWVonHIiP0=onHIiP03
o`000?oW6>OoiaSW00_oiaSW00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003ogR7NomhQgP09omhQgP03o`000?oJ9M[ofRGJ00;o0000
3OoS7><00ol0003oiA[UonDJi@07onDJi@Ko00000_oj1OX4o`0000goiA[U00?o0000on@Ki?oT6n@0
1ooT6n@2o`0000GohacS00?o0000on4NhOoQ7^400ooQ7^400ol0003oiQWVonHIiP0<onHIiP03o`00
0?oW6>OoiaSW00coiaSW00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oN8MkogR7N00WogR7N00?o
0000omXUf_l000003ooS7><00ol0003oiA[UonDJi@0<onDJi@?o00001?oV6NH3o`0000WoiA[U00?o
0000on@Ki?oT6n@02_oT6n@2o`000003on<Lhol0003o000000OohAkQ00?o0000onHIi_oV6NH02ooV
6NH00ol0003oiaSWonLHi`0<onLHi`03o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oj1O[onPGj00KonPGj00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oN8MkogR7N00_ogR7N00?o0000
on<LhooS7><03_oS7><00ol0003oiA[UonDJi@0=onDJi@03o`000?oV6NKoiQWV00KoiQWV0ol00005
onDJi@03o`000?oT6nCoi1_T00goi1_T00?o0000on4NhOoQ7^402?oQ7^400ol0003oiQWVonHIiP09
onHIiP03o`000?oW6>OoiaSW00goiaSW00Co0000ooX5n_oj1O[onPGj1Ol00003onPGj003o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
omhQg_oN8Mh02ooN8Mh2o`0000oohacS00?o0000onDJiOoU6^D03OoU6^D00ol0003oiQWVonHIiP0:
onHIiP?o000000?oiA[Uo`000?oT6n@03ooT6n@00ol0003ohAkQon4Nh@09on4Nh@03o`000?oV6NKo
iQWV00SoiQWV00?o0000onLHiooW6>L03_oW6>L3o`0000Soj1OX00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oN8MkogR7N00SogR7N0ol000000ooL
8mco0000on<Lh`0>on<Lh`03o`000?oU6^GoiA[U00goiA[U00?o0000onHIi_oV6NH03OoV6NH00ol0
003oi1_Ton@Ki00?on@Ki003o`000?oQ7^7ohAkQ00[ohAkQ2ol0000;onLHi`Go00003?oX5nP00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02_oj1OX01Ol0003oiQWVo`000?oj1O[o0000
00SogR7N0ol00005om`Sg003o`000?oS7>?ohacS00cohacS00?o0000onDJiOoU6^D03OoU6^D00ol0
003oiQWVonHIiP0=onHIiP;o00004?oT6n@00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oR7N;ohQgR
00OohQgR00?o0000onLHiooW6>L00_oW6>L7o`0000Coh1oP00?o0000onPGj?oX5nP02_oX5nP00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02Ooj1OX01?l0003oiQWVonHIi_oV6NH2o`00
00GogR7N0ol00009om`Sg0;o00002ooS7><00ol0003oiA[UonDJi@0=onDJi@03o`000?oV6NKoiQWV
00goiQWV00Co0000onhAk_o^4Nko00003ooT6n@00ol0003ohAkQon4Nh@09on4Nh@03o`000?oR7N;o
hQgR00WohQgR1?l0000;on0Oh003o`000?oX5nSoj1OX00[oj1OX00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5
nP03o`000?oj1O[onPGj00SonPGj00?o0000onHIi_oV6NH01?oV6NH00ol0003ogR7No`000002o`00
00cog2?L00Co0000on<Lhol0003o00002OoS7><00ol0003oiA[UonDJi@0=onDJi@03o`000?oV6NKo
iQWV00goiQWV00Go0000onhAk_o^4NkokQ7^o`00000=on@Ki003o`000?oQ7^7ohAkQ00[ohAkQ00?o
0000on8Mh_oR7N802OoR7N800ol0003oh1oPon0Oh00<on0Oh003o`000?oX5nSoj1OX00[oj1OX00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000onHIi_oV6NH01_oV6NH0
0ol0003og2?Lom`Sg00<om`Sg003o`000?oS7>?ohacS00;ohacS0_l00007on<Lh`03o`000?oU6^Go
iA[U00coiA[U00?o0000onHIi_oV6NH03OoV6NH00ol0003okQ7^onhAkP03onhAkP03o`000?oT6nCo
i1_T00[oi1_T00?o0000on4NhOoQ7^402_oQ7^400ol0003ohQgRon8MhP09on8MhP03o`000?oP7n3o
h1oP00coh1oP00?o0000onPGj?oX5nP02ooX5nP00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5
n_oj1OX01_oj1OX00ol0003oiQWVonHIiP06onHIiP03o`000?oL8mcog2?L00_og2?L00?o0000on<L
hooS7><01OoS7><00ol0003ohacSon<Lh`03on<Lh`03o`000?oU6^GoiA[U00goiA[U00?o0000onHI
i_oV6NH03OoV6NH00ol0003okQ7^onhAkP04onhAkP03o`000?oT6nCoi1_T00Woi1_T00?o0000on4N
hOoQ7^402OoQ7^400ol0003ohQgRon8MhP0:on8MhP03o`000?oP7n3oh1oP00coh1oP00?o0000onPG
j?oX5nP02ooX5nP00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
iQWVonHIiP07onHIiP03o`000?oL8mcog2?L00_og2?L00?o0000on<LhooS7><01_oS7><2o`0000?o
hacS00?o0000onDJiOoU6^D03OoU6^D00ol0003oiQWVonHIiP0<onHIiP03o`000?o^4NkokQ7^00Ko
kQ7^00?o0000on@Ki?oT6n@02?oT6n@00ol0003ohAkQon4Nh@09on4Nh@03o`000?oR7N;ohQgR00[o
hQgR00?o0000on0Oh?oP7n003?oP7n000ol0003oj1OXonPGj00;onPGj003o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooX5nP03o`00
0?oj1O[onPGj00ConPGj00?o0000onHIi_oV6NH02?oV6NH00ol0003og2?Lom`Sg00:om`Sg003o`00
0?oS7>?ohacS00WohacS0_l000000ooS7>?o0000onDJi@0<onDJi@?o00003_oV6NH00ol0003okQ7^
onhAkP07onhAkP03o`000?oT6nCoi1_T00Ooi1_T00?o0000on4NhOoQ7^402OoQ7^400ol0003ohQgR
on8MhP0;on8MhP03o`000?oP7n3oh1oP00coh1oP00?o0000onPGj?oX5nP02_oX5nP00ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000onHIi_oV6NH02_oV6NH00ol0003og2?Lom`S
g009om`Sg003o`000?oS7>?ohacS00_ohacS00?o0000onDJiOoU6^D02_oU6^D2o`0000?oiaSW00?o
0000onHIi_oV6NH02_oV6NH00ol0003okQ7^onhAkP09onhAkP03o`000?oT6nCoi1_T00Koi1_T00?o
0000on4NhOoQ7^402?oQ7^400ol0003ohQgRon8MhP0<on8MhP03o`000?oP7n3oh1oP00coh1oP00?o
0000onPGj?oX5nP02_oX5nP00ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ooj1OX0
0ol0003onPGjooX5nP02ooX5nP03o`000?oV6NKoiQWV00_oiQWV00?o0000om`Sg?oL8m`02?oL8m`0
0ol0003ohacSon<Lh`0<on<Lh`03o`000?oU6^GoiA[U00SoiA[U0_l00006onLHi`;o00002_oV6NH0
0ol0003okQ7^onhAkP0:onhAkP03o`000?oT6nCoi1_T00Goi1_T00?o0000on4NhOoQ7^402?oQ7^40
0ol0003ohQgRon8MhP0<on8MhP03o`000?oP7n3oh1oP00coh1oP00?o0000onPGj?oX5nP02ooX5nP0
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?onPGj00Go0000ooX5n_oj1O[onPGjo`00000=
onHIiP03o`000?oL8mcog2?L00Oog2?L00?o0000on<LhooS7><03_oS7><00ol0003oiA[UonDJi@04
onDJi@?o00002_oW6>L00ol0003oiQWVonHIiP07onHIiP03o`000?o^4NkokQ7^00_okQ7^00?o0000
on@Ki?oT6n@00ooT6n@00ol0003ohAkQon4Nh@09on4Nh@03o`000?oR7N;ohQgR00cohQgR00?o0000
on0Oh?oP7n003?oP7n000ol0003oj1OXonPGj00;onPGj0;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003oiQWVonHIiP0<onHIiP03o`000?oL8mcog2?L00Oog2?L00?o0000on<LhooS7><03ooS7><01?l0
003oiA[UonDJiOoU6^D2o`0000koiaSW0_l00006onHIiP03o`000?o^4NkokQ7^00gokQ7^00?o0000
on@Ki?oT6n@00_oT6n@00ol0003ohAkQon4Nh@08on4Nh@03o`000?oR7N;ohQgR00cohQgR0ol0000=
on0Oh003o`000?oX5nSoj1OX00_oj1OX00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00ooiQWV00?o0000om`Sg?oL8m`01_oL8m`00ol0003ohacSon<Lh`0@on<Lh`Co00004_oW6>L00ol0
003oiQWVonHIiP03onHIiP03o`000?o^4NkokQ7^00kokQ7^00Go0000on@Ki?oT6nCoi1_To`000005
on4Nh@Oo00003?oR7N801Ol0003og2?Lom`Sg?oL8mco000000coh1oP00?o0000onPGj?oX5nP02?oX
5nP3o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000ooiQWV00?o0000om`Sg?oL8m`01_oL8m`00ol0003ohacSon<Lh`0=
on<Lh`?o000000CogR7No`000?l0003o00004ooW6>L2o`0000;oiQWV00?o0000onhAk_o^4Nh04?o^
4Nh00ol0003oi1_To`000006o`0000OokQ7^00?o0000on8Mh_oR7N802?oR7N800ol0003og2?Lom`S
g003om`Sg0;o00002?oP7n03o`0000Koj1OX1?l00002onTFj@03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003oebSGo`000?oO8=l3o`0000goiQWV00?o0000om`Sg?oL8m`01?oL8m`00ol0003ohacSon<L
h`0;on<Lh`?o00000ooN8Mh01Ol0003ogb3Oo`000?oP7n3o000001CoiaSW00?o0000onHIi_l00000
4oo^4Nh00ol0003okQ7^onhAkP0=onhAkP03o`000?oR7N;ohQgR00GohQgR0_l00008om`Sg003o`00
0?oP7n3oh1oP00Go00000ooQ7^400ol0003oj1OXonPGj003o`0000OojAKY00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oG:=OoebSGo`0000Cogb3O0ol0000:onHIiP03o`000?oL8mcog2?L00?og2?L
00?o0000on<LhooS7><02OoS7><3o`0000GogR7N00Co0000omlPgooO8=oo00000_oP7n000ol0003o
iaSWonLHi`0BonLHi`03o`000?o^4NkokQ7^01;okQ7^00?o0000onhAk_o^4Nh03_o^4Nh00ol0003o
hQgRon8MhP03on8MhP03o`000?oL8mcog2?L00Wog2?L0_l00009on4Nh@;o00002_oY5^T00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000omLXeooG:=OoebSGo`000007omlPg`;o00001ooV6NH5o`0000;o
g2?L00?o0000on<LhooS7><01_oS7><3o`0000SogR7N00Co0000omlPgooO8=oo00000ooP7n000ol0
003oiaSWonLHi`0AonLHi`03o`000?o^4NkokQ7^017okQ7^00?o0000onhAk_o^4Nh04?o^4Nh01Ol0
003ohQgRon8Mh_oR7N;o000000cog2?L00?o0000on4NhOoQ7^402?oQ7^400ol0003ojAKYonTFj@0:
onTFj@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CoebSG00?o0000omlPgooO8=l01ooO8=l3o`00
0004onHIi_l0003o0000o`0000GohQgR0_l00006on<Lh`?o00002_oN8Mh01Ol0003ogb3OomlPgooO
8=oo000000Coh1oP00?o0000onLHiooW6>L04?oW6>L00ol0003okQ7^onhAkP0AonhAkP03o`000?o^
4NkokQ7^017okQ7^00?o0000on8Mh_l000003OoL8m`00ol0003ohAkQon4Nh@08on4Nh@03o`000?oY
5^WojAKY00[ojAKY00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oG:=OoebSG00CoebSG00?o0000
omlPgooO8=l02_oO8=l00ol0003ohQgRon8MhP08on8MhP03o`000?oS7>?ohacS00?o00003OoN8Mh0
1Ol0003ogb3OomlPgooO8=oo000000Goh1oP00?o0000onLHiooW6>L03ooW6>L00ol0003okQ7^onhA
kP0AonhAkP03o`000?o^4NkokQ7^01;okQ7^00?o0000om`Sg?oL8m`03?oL8m`00ol0003ohAkQon4N
h@08on4Nh@03o`000?oY5^WojAKY00_ojAKY00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000omLXeooG:=L01OoG:=L0
0ol0003ogb3OomlPg`0:omlPg`03o`000?oR7N;ohQgR00WohQgR0_l0000?omhQgP03o`000?oO8=oo
gb3O00;ogb3O00?o0000on0Oh?oP7n001?oP7n000ol0003oiaSWonLHi`0=onLHi`?o00004Oo^4Nh0
0ol0003okQ7^onhAkP0ConhAkP03o`000?oL8mcog2?L00_og2?L00?o0000on4NhOoQ7^402OoQ7^40
0ol0003ojAKYonTFj@0;onTFj@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oG:=L0
0ol0003ogb3OomlPg`0:omlPg`03o`000?oR7N;ohQgR00WohQgR00?o0000omhQg_oN8Mh03OoN8Mh0
0ol0003ogb3OomlPg`03omlPg`03o`000?oP7n3oh1oP00Goh1oP00?o0000onLHiooW6>L02_oW6>L2
o`0000?okQ7^00?o0000onhAk_o^4Nh03_o^4Nh00ol0003okQ7^onhAkP0ConhAkP03o`000?oL8mco
g2?L00_og2?L00?o0000on4NhOoQ7^402OoQ7^400ol0003ojAKYonTFj@0;onTFj@03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000omLXeooG:=L01ooG:=L2o`0000_ogb3O00?o0000on8M
h_oR7N802ooR7N800ol0003ogR7NomhQgP0<omhQgP03o`000?oO8=oogb3O00?ogb3O00?o0000on0O
h?oP7n001_oP7n000ol0003oiaSWonLHi`07onLHi`;o00001_o^4Nh2o`0000kokQ7^00?o0000onhA
k_o^4Nh04oo^4Nh00ol0003og2?Lom`Sg00;om`Sg003o`000?oQ7^7ohAkQ00WohAkQ00?o0000onTF
jOoY5^T03?oY5^T00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009omLX
e`03o`000?naC[7o000000_ogb3O00?o0000on8Mh_oR7N802ooR7N800ol0003ogR7NomhQgP0;omhQ
gP03o`000?oO8=oogb3O00Cogb3O00?o0000on0Oh?oP7n001ooP7n000ol0003oiaSWonLHi`05onLH
i`03o`000?o^4NkokQ7^00SokQ7^00?o0000onhAk_o^4Nh02_o^4Nh00ol0003okQ7^onhAkP0DonhA
kP03o`000?oL8mcog2?L00_og2?L00?o0000on4NhOoQ7^402OoQ7^400ol0003ojAKYonTFj@0<onTF
j@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009omLXe`04o`000?naC[7o/Djao`00
00_ogb3O00?o0000on8Mh_oR7N802ooR7N800ol0003ogR7NomhQgP0;omhQgP03o`000?oO8=oogb3O
00Cogb3O00?o0000on0Oh?oP7n002?oP7n000ol0003oiaSWonLHi`02onLHi`;o00003?o^4Nh2o`00
00[okQ7^00?o0000onhAk_o^4Nh05?o^4Nh00ol0003og2?Lom`Sg00;om`Sg003o`000?oQ7^7ohAkQ
00WohAkQ00?o0000onTFjOoY5^T03OoY5^T00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oebSGomLXe`07omLXe`03
o`000?naC[7o/Dja00;o/Dja00?o0000omlPgooO8=l02?oO8=l00ol0003ohQgRon8MhP0<on8MhP03
o`000?oN8MkogR7N00WogR7N00?o0000omlPgooO8=l01OoO8=l00ol0003oh1oPon0Oh009on0Oh004
o`000?oW6>Oo0000o`00013okQ7^0_l00008onhAkP03o`000?o^4NkokQ7^01CokQ7^0ol0000;om`S
g003o`000?oQ7^7ohAkQ00WohAkQ00?o0000onTFjOoY5^T03OoY5^T01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oebSGomLXe`06omLXe`03o`000?naC[7o/Dja00?o/Dja00?o0000omlP
gooO8=l02?oO8=l00ol0003ohQgRon8MhP0;on8MhP;o00002_oN8Mh00ol0003ogb3OomlPg`06omlP
g`03o`000?oP7n3oh1oP00[oh1oP00?o0000onhAk_o^4Nh04_o^4Nh00ol0003okQ7^onhAkP04onhA
kP03o`000?o^4NkokQ7^01GokQ7^00?o0000on/Djoo[5>/01Ol00005om`Sg003o`000?oQ7^7ohAkQ
00[ohAkQ00?o0000onTFjOoY5^T03_oY5^T3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSGomLXe`04omLXe`03
o`000?naC[7o/Dja00Co/Dja00?o0000omlPgooO8=l01ooO8=l00ol0003ohQgRon8MhP0;on8MhP04
o`000?oT6nCoi1_To`0000WogR7N00?o0000omlPgooO8=l01_oO8=l00ol0003oh1oPon0Oh00:on0O
h003o`000?o^4NkokQ7^01?okQ7^0_l00003onhAkPCo00005?o^4Nh00ol0003ojaC[on/Dj`06on/D
j`Co000000?og2?Lo`000?oQ7^402ooQ7^400ol0003ojAKYonTFj@0>onTFj@03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003oebSGomLXe`03omLXe`03o`000?naC[7o/Dja00Go/Dja00?o0000omlPgooO
8=l01ooO8=l00ol0003ohQgRon8MhP09on8MhP;o00001?oT6n@00ol0003ogR7NomhQgP05omhQgP03
o`000?oO8=oogb3O00Oogb3O00?o0000on0Oh?oP7n002_oP7n000ol0003okQ7^onhAkP0EonhAkP03
o`000?o^4Nko000000Col0o`0ol0000@onhAkP03o`000?o[5>_ojaC[00_ojaC[0_l0000<on4Nh@03
o`000?oY5^WojAKY00cojAKY0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000omLXeooG:=L00_oG:=L00ol0003o/Dja
ok5>/@06ok5>/@03o`000?oO8=oogb3O00Oogb3O00?o0000on8Mh_oR7N802?oR7N800ol0003oi1_T
on@Ki005on@Ki003o`000?oN8MkogR7N00CogR7N00?o0000omlPgooO8=l01ooO8=l00ol0003oh1oP
on0Oh00:on0Oh003o`000?o^4NkokQ7^01KokQ7^00?o0000oo0?l?o`3o001_o`3o03o`0000cokQ7^
00?o0000on/Djoo[5>/03Oo[5>/00ol0003ohAkQon4Nh@09on4Nh@Go00002OoY5^T2o`000003on4N
hOl0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003omLXeol0003o/Dja00Wo/Dja00?o0000omlPgooO8=l01_oO
8=l00ol0003ohQgRon8MhP07on8MhP03o`000?oT6nCoi1_T00Ooi1_T00?o0000omhQg_oN8Mh00_oN
8Mh00ol0003ogb3OomlPg`08omlPg`03o`000?oP7n3oh1oP00Woh1oP00?o0000onhAk_o^4Nh05oo^
4Nh00ol0003ol0o`oo0?l009oo0?l0?o00002Oo^4Nh00ol0003ojaC[on/Dj`0>on/Dj`Ko00001?oQ
7^400ol0003oeRWFomHYeP03omHYePGo00000_oY5^T2o`0000CohAkQ00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?oF:MKoeRWFomHYe_l000002onaC[400ol0003ogb3OomlPg`06omlPg`03o`000?oR
7N;ohQgR00GohQgR0_l0000;on@Ki004o`000?oN8MkogR7No`0000_ogb3O00?o0000on0Oh?oP7n00
2OoP7n000ol0003okQ7^onhAkP0FonhAkP03o`000?o`3o3ol0o`00gol0o`0ol00005onhAkP03o`00
0?o[5>_ojaC[00oojaC[00?o0000onTFjOoY5^T00ooY5^T4o`0000_oeRWF0_l00006on4Nh@03o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oeRWFomHYeP02omHYePko00001_oO8=l00ol0003ohQgRon8M
hP05on8MhP03o`000?oT6nCoi1_T00coi1_T00?o0000omhQg_l000002ooO8=l00ol0003oh1oPon0O
h007on0Oh0?o00006?o^4Nh00ol0003ol0o`oo0?l00@oo0?l0?o000000?okQ7^o`000?o[5>/04?o[
5>/00ol0003ojAKYonTFj@07onTFj@03o`000?oF:MKoeRWF00[oeRWF00?o0000on4NhOoQ7^401OoQ
7^400ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005omHYeP03o`000?o7><OoacS700_oacS70_l00004
omlPg`03o`000?oR7N;ohQgR00?ohQgR0_l0000@on@Ki003o`000?oO8=oogb3O00[ogb3O00?o0000
on0Oh?oP7n000ooP7n04o`0000;og2?L00?o0000onhAk_o^4Nh05Oo^4Nh00ol0003ol0o`oo0?l00D
oo0?l003o`000?o[5>_ojaC[013ojaC[00?o0000onTFjOoY5^T01ooY5^T00ol0003oeRWFomHYeP0:
omHYeP03o`000?oQ7^7ohAkQ00GohAkQ00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oF:MKoeRWF
00GoeRWF00?o0000olLhaoo7><L03Oo7><L6o`0000?ohQgR00?o0000on@Ki?oT6n@04?oT6n@00ol0
003ogb3OomlPg`0:omlPg`03o`000?oP7n3o000000?o00001ooL8m`00ol0003okQ7^onhAkP0DonhA
kP03o`000?o`3o3ol0o`01Col0o`00?o0000on/Djoo[5>/03oo[5>/00ol0003ojAKYonTFj@08onTF
j@03o`000?oF:MKoeRWF00[oeRWF00?o0000on4NhOoQ7^401OoQ7^400ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000omHYe_oF:MH01_oF:MH00ol0003oacS7olLha`0=olLha`03o`000?oV6NKoiQWV00?o
iQWV00?o0000on8Mh_l000004ooT6n@4o`0000Wogb3O0_l0000<om`Sg003o`000?o^4NkokQ7^01?o
kQ7^00?o0000oo0?l?o`3o005Oo`3o000ol0003ojaC[on/Dj`0>on/Dj`03o`000?oY5^WojAKY00So
jAKY00?o0000omHYe_oF:MH02OoF:MH00ol0003ohAkQon4Nh@07on4Nh@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?oF:MKoeRWF00SoeRWF00?o0000olLhaoo7><L02oo7><L00ol0003oiQWVonHIiP05onHIiP03o`00
0?oT6nCoi1_T01;oi1_T00Co0000omlOgooO7moogaoO1Ol00003omlPg`03o`000?oL8mcog2?L00go
g2?L0ol0000@onhAkP;o00006?o`3o000ol0003ojaC[on/Dj`0=on/Dj`03o`000?oY5^WojAKY00Wo
jAKY00?o0000omHYe_oF:MH02OoF:MH00ol0003ohAkQon4Nh@07on4Nh@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_oeRWF00?o0000olLhaoo7><L02_o7><L00ol0003oiQWVonHIiP06onHIiP03o`00
0?oT6nCoi1_T017oi1_T00?o0000omlOgooO7ml01ooO7ml3o`00013og2?L00?o0000om/TfooK9=/0
1Ol00009onhAkP;o000000?ohAkQo`000?o`3o005oo`3o000ol0003ojaC[on/Dj`0=on/Dj`03o`00
0?oY5^WojAKY00WojAKY00?o0000omHYe_oF:MH02?oF:MH2o`0000[ohAkQ00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oI9]WofBKI00;ofBKI00?o0000omHYe_oF:MH02OoF:MH00ol0003oacS7olLh
a`0:olLha`03o`000?oV6NKoiQWV00OoiQWV00?o0000on@Ki?oT6n@03ooT6n@00ol0003ogaoOomlO
g`0:omlOg`03o`000?oL8mcog2?L00gog2?L00?o0000om/TfooK9=/01_oK9=/4o`0000CokQ7^00?o
0000on4NhOoQ7^400_oQ7^400ol0003ol0o`oo0?l00Foo0?l003o`000?o[5>_ojaC[00_ojaC[00?o
0000onTFjOoY5^T02ooY5^T00ol0003oeRWFomHYeP06omHYeP03o`000?o3?<?o000000[ohAkQ00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oI9]WofBKI00?ofBKI00?o0000omHYe_oF:MH02?oF:MH=
o`0000[oiQWV00?o0000on@Ki?oT6n@03ooT6n@00ol0003ogaoOomlOg`0;omlOg`03o`000?oL8mco
g2?L00cog2?L00?o0000om/TfooK9=/02_oK9=/4o`0000GohAkQ00?o0000oo0?l?o`3o005_o`3o00
0ol0003ojaC[on/Dj`0:on/Dj`03o`000?oY5^WojAKY00cojAKY00?o0000omHYe_oF:MH01?oF:MH2
o`0000?o`cc300?o0000on4NhOoQ7^402?oQ7^400ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omTV
fOoI9]T00ooI9]T00ol0003oeRWFomHYeP07omHYeP03o`000?o7><OoacS700WoacS700?o0000onHI
i_oV6NH02OoV6NH00ol0003oi1_Ton@Ki00=on@Ki003o`000?oO7moogaoO00cogaoO00?o0000om`S
g?oL8m`03?oL8m`00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oA;]7o000000KohAkQ00?o0000oo0?
l?o`3o005_o`3o000ol0003ojaC[on/Dj`09on/Dj`03o`000?oY5^WojAKY00cojAKY00?o0000omHY
e_oF:MH00ooF:MH00ol0003o`cc3ol<l``03ol<l``03o`000?oQ7^7ohAkQ00SohAkQ00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oI9]WofBKI00CofBKI00?o0000omHYe_oF:MH01_oF:MH00ol0003o
acS7olLha`08olLha`03o`000?oV6NKoiQWV00_oiQWV00?o0000on@Ki?oT6n@02?oT6n@4o`0000oo
gaoO00?o0000om`Sg?oL8m`02ooL8m`00ol0003ofbCKom/Tf`0;om/Tf`04o`000?oA;]7odBkAo`00
00OohAkQ00?o0000oo0?l?o`3o005Oo`3o000ol0003ojaC[on/Dj`08on/Dj`03o`000?oY5^WojAKY
00gojAKY00?o0000omHYe_oF:MH00_oF:MH00ol0003o`cc3ol<l``05ol<l``03o`000?oQ7^7ohAkQ
00OohAkQ00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oI9]WofBKI00GofBKI00?o0000omHYe_oF
:MH01OoF:MH00ol0003oacS7olLha`08olLha`03o`000?oV6NKoiQWV00_oiQWV00?o0000on@Ki?oT
6n@00ooT6n@5o`0000?oh1oP00?o0000omlOgooO7ml03_oO7ml00ol0003og2?Lom`Sg00:om`Sg003
o`000?oK9=_ofbCK00[ofbCK00Go0000om4^dOoA;]7odBkAo`000007on4Nh@03o`000?o`3o3ol0o`
01Gol0o`00?o0000on/Djoo[5>/02?o[5>/00ol0003ojAKYonTFj@0=onTFj@03o`000?oF:MKoeRWF
00;o00002?o3?<<00ol0003ohAkQon4Nh@08on4Nh@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003ofBKIomTVf@05omTVf@03o`000?oF:MKoeRWF00Go
eRWF00?o0000olLhaoo7><L02?o7><L00ol0003oiQWVonHIiP0<onHIiPGo00002OoP7n000ol0003o
gaoOomlOg`0<omlOg`;o00003?oL8m`00ol0003ofbCKom/Tf`0:om/Tf`05o`000?oA;]7odBkAom4^
dOl000002?oQ7^400ol0003ol0o`oo0?l00Doo0?l0?o00001oo[5>/00ol0003ojAKYonTFj@0>onTF
j@03o`000?oF:MKo000000_o`cc300?o0000on4NhOoQ7^401_oQ7^400ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000omTVfOoI9]T01OoI9]T00ol0003oeRWFomHYeP04omHYeP03o`000?o7><OoacS700Oo
acS700?o0000onHIi_oV6NH03?oV6NH01?l0003oi1_Ton@Ki?l0000;on0Oh003o`000?oO7moogaoO
00_ogaoO00Co0000om0_d?o@;m3o00002_oL8m`00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oA;]7o
dBkA00;odBkA00?o0000on4NhOoQ7^401_oQ7^400ol0003ol0o`oo0?l00Aoo0?l0?o00000ooT6n@0
0ol0003ojaC[on/Dj`04on/Dj`03o`000?oY5^WojAKY00gojAKY1?l0000;ol<l``03o`000?oQ7^7o
hAkQ00GohAkQ00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oI9]WofBKI00KofBKI00Co0000omHY
e_oF:MKoeRWF1?l00008olLha`03o`000?oV6NKoiQWV00_oiQWV00?o0000on@Ki?oT6n@00_oT6n@0
0ol0003oh1oPon0Oh008on0Oh003o`000?oO7moogaoO00[ogaoO00?o0000om0_d?o@;m000_o@;m00
0ol0003og2?Lom`Sg003om`Sg0Go00002ooK9=/00ol0003odBkAom4^d@03om4^d@03o`000?oQ7^7o
hAkQ00OohAkQ00?o0000oo0?l?o`3o003_o`3o02o`0000Ooi1_T00?o0000on/Djoo[5>/00_o[5>/0
0ol0003ojAKYonTFj@0=onTFj@03o`000?oG:=OoebSG00;oebSG00?o0000ol<l`oo3?<<02Oo3?<<0
0ol0003ohAkQon4Nh@03on4Nh@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofBKIomTVf@07omTV
f@?o00001?oN8Mh00ol0003oacS7olLha`05olLha`03o`000?oV6NKoiQWV00[oiQWV00?o0000on@K
i?oT6n@00ooT6n@00ol0003oh1oPon0Oh009on0Oh003o`000?oO7moogaoO00SogaoO00?o0000om0_
d?o@;m001?o@;m05o`0000Co^4Nh00?o0000om/TfooK9=/02OoK9=/00ol0003odBkAom4^d@03om4^
d@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo0?l?o`3o002_o`3o03o`0000[oi1_T00Go0000on/D
joo[5>_ojaC[o`00000>onTFj@03o`000?oG:=OoebSG00CoebSG0_l00009ol<l``03o`000?oQ7^7o
hAkQ00;ohAkQ00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oI9]WofBKI00OofBKI00?o0000omhQ
g_oN8Mh01OoN8Mh00ol0003oacS7olLha`03olLha`03o`000?oV6NKoiQWV00[oiQWV00?o0000on@K
i?oT6n@01?oT6n@00ol0003oh1oPon0Oh009on0Oh003o`000?oO7moogaoO00OogaoO00?o0000om0_
d?o@;m001Oo@;m000ol0003o^4NhokQ7^007okQ7^003o`000?oK9=_ofbCK00OofbCK00?o0000om4^
dOoA;]401?oA;]400ol0003ohAkQon4Nh@08on4Nh@03o`000?o`3o3ol0o`00Sol0o`0_l0000>on@K
i0Co00003?oY5^T2o`0000WoebSG00?o0000ol<l`oo3?<<01oo3?<<01?l0003ohAkQon4NhOl0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000omTVfOoI9]T01OoI9]T00ol0003ogR7NomhQgP07omhQgP;o00000oo7><L00ol0
003oiQWVonHIiP09onHIiP03o`000?oT6nCoi1_T00Koi1_T00?o0000on0Oh?oP7n002OoP7n000ol0
003ogaoOomlOg`05omlOg`03o`000?o@;m3od2o@00Kod2o@00?o0000okQ7^?nhAkP02?nhAkP00ol0
003ofbCKom/Tf`06om/Tf`03o`000?oA;]7odBkA00CodBkA00?o0000on4NhOoQ7^402OoQ7^44o`00
00?ol0o`0ol0000@on@Ki005o`000?o^4NkokQ7^onhAk_l000002_oY5^T00ol0003oebSGomLXe`0:
omLXe`Ko00000oo3?<<00ol0003ohAkQo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000omTVfOoI9]T01?oI9]T00ol0
003ogR7NomhQgP0:omhQgP04o`000?o7><OoacS7o`0000[oiQWV00?o0000on@Ki?oT6n@01ooT6n@0
0ol0003oh1oPon0Oh009on0Oh003o`000?oO7moogaoO00CogaoO00?o0000om0_d?o@;m001oo@;m00
0ol0003o^4NhokQ7^008okQ7^0;o00001_oK9=/00ol0003odBkAom4^d@05om4^d@03o`000?oQ7^7o
hAkQ00WohAkQ00Co0000om/TfooK9=_ofbCK0ol0000Bon@Ki003o`000?o^4NkokQ7^00?okQ7^0_l0
0006onTFj@;o00003OoG:=L00ol0003oh1oPon0Oh003on0Oh0Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000omTVfOoI9]T00ooI9]T0
0ol0003ogR7NomhQgP0<omhQgP;o00002_oV6NH00ol0003oi1_Ton@Ki008on@Ki003o`000?oP7n3o
h1oP00[oh1oP00?o0000omlOgooO7ml00_oO7ml00ol0003od2o@om0_d008om0_d003o`000?nhAkSo
^4Nh00Ko^4Nh0_l00002oll`c`03o`000?oK9=_ofbCK00;ofbCK00?o0000om4^dOoA;]401_oA;]40
0ol0003ohAkQon4Nh@08on4Nh@03o`000?oK9=_ofbCK00CofbCK00?o0000on@Ki?oT6n@03ooT6n@0
0ol0003okQ7^onhAkP06onhAkP;o00000ooY5^T00ol0003oebSGomLXe`0=omLXe`03o`000?oP7n3o
h1oP00Ooh1oP0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003ofBKIomTVf@02omTVf@03o`000?oN8MkogR7N
00kogR7N00?o0000onHIi_oV6NH01ooV6NH00ol0003oi1_Ton@Ki00:on@Ki003o`000?oP7n3oh1oP
00Woh1oP00Go0000omlOgooO7moogaoOo`00000;om0_d003o`000?nhAkSo^4Nh00Co^4Nh0_l00005
oll`c`05o`000?oK9=_ofbCKom/Tfol000002?oA;]400ol0003ohAkQon4Nh@08on4Nh@03o`000?oK
9=_ofbCK00GofbCK00?o0000on@Ki?oT6n@03_oT6n@00ol0003okQ7^onhAkP08onhAkP03o`000?oY
5^Wo000000ooebSG00?o0000on0Oh?oP7n002?oP7n001?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oI9]WofBKIo`00017ogR7N00?o0000onHIi_oV6NH01_oV6NH00ol0003oi1_T
on@Ki00;on@Ki003o`000?oP7n3oh1oP00Woh1oP00Co0000omlOgooO7moo00003?o@;m000ol0003o
^4NhokQ7^002okQ7^0;o00002?o?<<l00ol0003ofbCKo`000009om4^d@03o`000?oQ7^7ohAkQ00So
hAkQ00?o0000om/TfooK9=/01OoK9=/00ol0003oi1_Ton@Ki00=on@Ki003o`000?o^4NkokQ7^00[o
kQ7^00?o0000omLXeooG:=L03_oG:=L00ol0003oh1oPon0Oh007on0Oh003o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000BomhQgP03o`00
0?oV6NKoiQWV00CoiQWV00?o0000on@Ki?oT6n@03?oT6n@00ol0003oh1oPon0Oh00:on0Oh0?o0000
3?o@;m000ol0003o^4NhokQ7^002o`0000_occ3?00?o0000om4^dOoA;]402?oA;]400ol0003ohAkQ
on4Nh@07on4Nh@03o`000?oK9=_ofbCK00OofbCK00?o0000on@Ki?oT6n@03?oT6n@00ol0003okQ7^
onhAkP0;onhAkP;o00003_oG:=L00ol0003oh1oPon0Oh007on0Oh003o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000onHIi_oV6NH00ooV6NH00ol0003ogR7NomhQgP0?omhQgP?o00000ooV
6NH00ol0003oi1_Ton@Ki00>on@Ki003o`000?oP7n3oh1oP00Soh1oP00Co0000om</dooC;=?odbcC
0_l0000:om0_d0?o00003Oo?<<l00ol0003odBkAom4^d@08om4^d@03o`000?oQ7^7ohAkQ00OohAkQ
00?o0000om/TfooK9=/01ooK9=/00ol0003oi1_Ton@Ki00;on@Ki003o`000?o^4NkokQ7^00cokQ7^
00?o0000omHYe_l000000_l0000:omLXe`03o`000?oP7n3oh1oP00Soh1oP00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003oiQWVonHIiP04onHIiP03o`000?oN8MkogR7N00cogR7N0_l0
0003omdRg@03o`000?oV6NKo0000017oi1_T00?o0000on0Oh?oP7n001ooP7n000ol0003odbcCom</
d`04om</d`;o00002?o@;m000ol0003occ3?oll`c`0>oll`c`;o00002?oA;]400ol0003ohAkQon4N
h@06on4Nh@03o`000?oK9=_ofbCK00WofbCK00?o0000on@Ki?oT6n@02OoT6n@00ol0003okQ7^onhA
kP0=onhAkP03o`000?oF:MKoeRWF00;oeRWF0ol00007omLXe`03o`000?oP7n3oh1oP00Ooh1oP00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oiQWVonHIiP05onHIiP03o`000?oN8Mko
gR7N00WogR7N0_l00006omdRg@03o`000?oT6nCoi1_T013oi1_T00?o0000on0Oh?oP7n001_oP7n00
0ol0003odbcCom</d`07om</d`03o`000?o@;m3od2o@00Cod2o@0ol0000>oll`c`03o`000?o5>/Go
aC[500?o00001OoA;]400ol0003ohAkQon4Nh@06on4Nh@03o`000?oK9=_ofbCK00[ofbCK00?o0000
on@Ki?oT6n@02?oT6n@00ol0003okQ7^onhAkP0=onhAkP03o`000?oF:MKoeRWF00GoeRWF0ol00004
omLXe`03o`000?oP7n3oh1oP00Ooh1oP00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oiQWVonHIiP06onHIiP03o`000?oN8MkogR7N00GogR7N0ol00008omdRg@03o`000?oT6nCoi1_T
017oi1_T00Co0000on0Oh?oP7n3oh1oP1?l0000;om</d`;o000000Cod2o@o`000?l0003o00000ooI
9]T2o`0000_occ3?00?o0000olDjaOo5>/D01?o5>/D2o`0000?odBkA00?o0000on4NhOoQ7^401_oQ
7^400ol0003ofbCKom/Tf`0:om/Tf`03o`000?oT6nCoi1_T00Ooi1_T00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003oeRWFomHYeP08omHYePCo00002_oP7n000ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003oiQWVonHIiP07onHIiP03o`000?oN8MkogR7N00;ogR7N0_l0000<omdRg@03o`000?oT6nCo
i1_T013oi1_T1?l00003om`Sg003o`000?oC;=?odbcC00_odbcC00?o0000omTVfOoI9]T01_oI9]T0
0ol0003occ3?oll`c`07oll`c`03o`000?o5>/GoaC[500OoaC[53?l0000>om/Tf`03o`000?oT6nCo
i1_T00Koi1_T00?o0000onhAk_o^4Nh03_o^4Nh00ol0003oeRWFomHYeP0;omHYeP03o`000?oP7n3o
h1oP00Ooh1oP00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oV6NKoiQWV00WoiQWV00Co0000omhQ
g_l0003o00003_oM8]d00ol0003oi1_Ton@Ki00?on@Ki003o`000?oL8mcog2?L00Kog2?L00?o0000
om</dooC;=<02_oC;=<00ol0003ofBKIomTVf@07omTVf@;o00001_o?<<l00ol0003oaC[5olDja@08
olDja@03o`000?oT6nCoi1_T00Soi1_T00?o0000om/TfooK9=/03?oK9=/00ol0003oi1_Ton@Ki005
on@Ki003o`000?o^4NkokQ7^00ookQ7^0_l0000=omHYeP03o`000?oP7n3oh1oP00Koh1oP00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oV6NKoiQWV00[oiQWV00?o0000omdRgOoM8]d03_oM8]d00ol0
003oi1_Ton@Ki00>on@Ki003o`000?oL8mcog2?L00Oog2?L00?o0000om</dooC;=<02_oC;=<00ol0
003ofBKIomTVf@09omTVf@;o00000oo?<<l00ol0003oaC[5olDja@09olDja@03o`000?oT6nCoi1_T
00Woi1_T00?o0000om/TfooK9=/02_oK9=/4o`0000Coi1_T00?o0000onhAk_o^4Nh04?o^4Nh01?l0
003of2OHo`000?l0000<omHYeP03o`000?oP7n3oh1oP00Goh1oP00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?oV6NKoiQWV00[oiQWV00?o0000omdRgOoM8]d03ooM8]d@o`0000[og2?L00?o0000om</
dooC;=<02OoC;=<00ol0003obSG:o`00000<omTVf@05o`000?o?<<oo0000olHia_l000002_o5>/D0
0ol0003oi1_Ton@Ki009on@Ki003o`000?oK9=_ofbCK00OofbCK0ol00004onLHi`?o000000?oi1_T
o`000?o^4Nh04Oo^4Nh01?l0003of2OHomPWf?oH9mP2o`0000_oeRWF00?o0000on0Oh?oP7n000ooP
7n000ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000onHIi_oV6NH02_oV6NH00ol0003ogB;MomdRg@0?
omdRg@03o`000?oV6NKoiQWV00coiQWV00?o0000om`Sg?oL8m`02OoL8m`00ol0003odbcCom</d`07
om</d`04o`000?o:=L[obSG:o`0000gofBKI00Go0000olHia_o6>LKoaSW6o`000009olDja@03o`00
0?oT6nCoi1_T00[oi1_T00?o0000om/TfooK9=/00ooK9=/3o`0000[oiaSW00?o0000onhAk_o^4Nh0
4?o^4Nh00ol0003of2OHomPWf004omPWf0;o00002_oF:MH00ol0003oh1oPon0Oh004o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000coiQWV00?o0000omdRgOoM8]d03ooM8]d00ol0003oiQWVonHIiP0<onHIiP03o`000?oL
8mcog2?L00Wog2?L00?o0000om</dooC;=<01_oC;=<00ol0003obSG:olXebP02olXebP03o`000?oI
9]WofBKI00[ofBKI00?o0000olHia_o6>LH00_o6>LH00ol0003oaC[5olDja@06olDja@03o`000?oT
6nCoi1_T00[oi1_T00?o0000om/TfooK9=/00ol0000=onLHi`03o`000?o^4NkokQ7^013okQ7^00?o
0000omPWf?oH9mP01_oH9mP2o`0000WoeRWF0_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000onHIi_oV6NH02_oV6NH00ol0003ogB;MomdRg@0=omdRg@?o00003ooV6NH0
0ol0003og2?Lom`Sg008om`Sg003o`000?oC;=?odbcC00GodbcC00?o0000olXeb_o:=LX00oo:=LX0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o6>LKoaSW600?oaSW600?o0000olDjaOo5>/D01Oo5>/D0
0ol0003oi1_Ton@Ki00;on@Ki0;o00004OoW6>L00ol0003okQ7^onhAkP0?onhAkP03o`000?oH9mSo
f2OH00Sof2OH0_l00007omHYeP03o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000onHIi_oV6NH02?oV6NH00ol0003ogB;MomdRg@09omdRg@Go00000_oI9]T00ol0
003oiQWVonHIiP0=onHIiP03o`000?oL8mcog2?L00Wog2?L00?o0000om</dooC;=<01?oC;=<00ol0
003obSG:olXebP04olXebP03o`000?oI9]WofBKI00SofBKI00?o0000olHia_o6>LH01Oo6>LH00ol0
003oaC[5olDja@04olDja@03o`000?oT6nCoi1_T00_oi1_T00?o0000onLHiooW6>L04?oW6>L00ol0
003okQ7^onhAkP0?onhAkP03o`000?oH9mSof2OH00[of2OH0_l00004omHYeP03o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003oiQWVonHIiP07onHIiP03o`000?oM8]gogB;M00CogB;M1Ol00007omTVf@03
o`000?oV6NKoiQWV00goiQWV00?o0000om`Sg?oL8m`02OoL8m`00ol0003odbcCom</d`03om</d`03
o`000?o:=L[obSG:00GobSG:00?o0000omTVfOoI9]T02?oI9]T00ol0003oaSW6olHiaP06olHiaP03
o`000?o5>/GoaC[500?oaC[500?o0000on@Ki?oT6n@02ooT6n@00ol0003oiaSWonLHi`0@onLHi`03
o`000?o^4NkokQ7^00ookQ7^00?o0000omPWf?oH9mP03?oH9mP2o`000003omHYe_l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oV6NKoiQWV00OoiQWV00?o0000omdRgOl00000
1?l0000<omTVf@03o`000?oV6NKoiQWV00koiQWV00?o0000om`Sg?oL8m`02?oL8m`00ol0003odbcC
om</d`02om</d`03o`000?o:=L[obSG:00OobSG:00?o0000omTVfOoI9]T01ooI9]T00ol0003oaSW6
olHiaP07olHiaP03o`000?o5>/GoaC[500;oaC[500?o0000on@Ki?oT6n@02ooT6n@00ol0003oiaSW
onLHi`0AonLHi`03o`000?o^4NkokQ7^00gokQ7^00?o0000omPWf?oH9mP03ooH9mP00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000onHIi_oV6NH01OoV6NH3o`00017ofBKI00?o0000onHIi_oV6NH03_oV
6NH00ol0003og2?Lom`Sg009om`Sg004o`000?oC;=?odbcCo`0000[obSG:00?o0000omTVfOoI9]T0
1ooI9]T00ol0003oaSW6olHiaP08olHiaP05o`000?o5>/GoaC[5olDjaOl000003OoT6n@00ol0003o
iaSWonLHi`0AonLHi`?o00003Oo^4Nh00ol0003of2OHomPWf00?omPWf003o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_oV6NH2o`0000;oeRWF00?o0000omTVfOoI9]T03ooI9]T00ol0003o
iQWVonHIiP0>onHIiP03o`000?oL8mcog2?L00Sog2?L1Ol0000;olXebP03o`000?oI9]WofBKI00Ko
fBKI00?o0000olHia_o6>LH02Oo6>LH01?l0003oaC[5olDjaOl0000=on@Ki003o`000?oW6>OoiaSW
017oiaSW00?o0000omXUf_oJ9MX00ol0000:onhAkPCo00003OoH9mP00ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000om/TfooK9=_ofbCK0_l00005omHYeP03o`000?oI9]WofBKI00kofBKI00?o0000onHI
i_oV6NH03_oV6NH00ol0003og2?Lom`Sg007om`Sg003o`000?oK9=_ofbCK00?ofbCK00?o0000olXe
b_o:=LX02?o:=LX00ol0003ofBKIomTVf@05omTVf@03o`000?o6>LKoaSW600[oaSW61Ol0000<on@K
i003o`000?oW6>OoiaSW013oiaSW00?o0000omXUf_oJ9MX01?oJ9MX3o`0000KokQ7^00?o0000on<L
hooS7><00_oS7><5o`0000Sof2OH00?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oK9=_ofbCK00?o
fbCK00?o0000omHYe_oF:MH01?oF:MH00ol0003ofBKIomTVf@0=omTVf@03o`000?oV6NKoiQWV00oo
iQWV00?o0000om`Sg?oL8m`01?oL8m`2o`0000OofbCK00?o0000olXeb_o:=LX01oo:=LXEo`0000Go
c3?<00?o0000on@Ki?oT6n@02?oT6n@3o`00013oiaSW00?o0000omXUf_oJ9MX02?oJ9MX3o`0000;o
kQ7^00?o0000on<LhooS7><02?oS7><5o`0000?of2OH00?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oK9=_ofbCK00CofbCK00?o0000omHYe_oF:MH01OoF:MH00ol0003ofBKIomTVf@0;omTVf@Co0000
3ooV6NH00ol0003og2?Lom`Sg003om`Sg003o`000?oK9=_ofbCK00SofbCK00?o0000olXeb_o:=LX0
1?o:=LX2o`0000SofbCK00?o0000omDZeOoE:]D02?oE:]D00ol0003oc3?<ol`cc005ol`cc0;o0000
1_oT6n@2o`0000?ogaoO00?o0000onLHiooW6>L03?oW6>L00ol0003ofRGJomXUfP0<omXUfP;o0000
4?oS7><3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ofbCKom/Tf`05om/Tf`03o`000?oF:MKoeRWF00KoeRWF00?o
0000omTVfOoI9]T02OoI9]T00ol0003obcC;o`000002om/Tf`?o00003?oV6NH01?l0003og2?Lom`S
g?oL8m`2o`0000cofbCK00?o0000olXeb_o:=LX00_o:=LX00ol0003ofbCKom/Tf`08om/Tf`03o`00
0?oE:]GoeB[E00SoeB[E00?o0000ol`cc?o<<l`01oo<<l`00ol0003oi1_Ton@Ki002on@Ki003o`00
0?oO7moogaoO00CogaoO0_l0000;onLHi`03o`000?oJ9M[ofRGJ00cofRGJ00?o0000omhQg_l00000
4_oS7><00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003ofbCKom/Tf`06om/Tf`03o`000?oF:MKoeRWF00OoeRWF00?o
0000omTVfOoI9]T01_oI9]T2o`0000;obcC;00?o0000om/TfooK9=/00ooK9=/3o`0000[oiQWV00?o
0000om`Sg?l000003ooK9=/01?l0003obSG:o`000?l0000;om/Tf`03o`000?oE:]GoeB[E00SoeB[E
00?o0000ol`cc?o<<l`02?o<<l`01?l0003oi1_To`000?l00009omlOg`03o`000?oW6>OoiaSW00Oo
iaSW00?o0000omXUf_oJ9MX03?oJ9MX01?l0003ogR7NomhQg_l0000Con<Lh`03o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000om/TfooK9=/01ooK9=/00ol0003oeRWFomHYeP08omHYeP03o`000?oI9]WofBKI00Co
fBKI00?o0000ol/dboo;=</00oo;=</00ol0003ofbCKom/Tf`05om/Tf`?o00001_oV6NH4o`00013o
fbCK00?o0000om/TfooK9=/03?oK9=/00ol0003oeB[EomDZe@07omDZe@03o`000?o<<lcoc3?<00Wo
c3?<00?o0000omlOgooO7ml02_oO7ml2o`0000KoiaSW00?o0000omXUf_oJ9MX03?oJ9MX00ol0003o
gR7NomhQgP02omhQgP03o`000?oS7>?ohacS00oohacS00?o0000omXUf_l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003ofbCKom/Tf`08om/Tf`03o`000?oF:MKoeRWF00WoeRWF00Co0000omTVfOoI9]Wo
fBKI0_l00006ol/db`03o`000?oK9=_ofbCK00SofbCK0ol000000ooV6NKo0000o`000004omhQgP03
o`000?oK9=_ofbCK00gofbCK00?o0000om/TfooK9=/03?oK9=/00ol0003oeB[EomDZe@07omDZe@03
o`000?o<<lcoc3?<00Woc3?<00?o0000omlOgooO7ml03?oO7ml00ol0003oiaSWonLHi`03o`0000ko
fRGJ00?o0000omhQg_oN8Mh00ooN8Mh00ol0003ohacSon<Lh`0>on<Lh`05o`000?oJ9M[ofRGJomXU
f_l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003ofbCKom/Tf`09om/Tf`03o`000?oF:MKoeRWF00[o
eRWF00?o0000omTVfOl000002?o;=</00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oN8MkogR7N00Go
gR7N00?o0000om/TfooK9=/03?oK9=/00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oE:]GoeB[E00Oo
eB[E00?o0000ol`cc?o<<l`02?o<<l`2o`0000oogaoO0_l00002on0Oh003o`000?oJ9M[ofRGJ00_o
fRGJ00?o0000omhQg_oN8Mh01?oN8Mh00ol0003ohacSon<Lh`0=on<Lh`03o`000?oJ9M[ofRGJ00?o
fRGJ00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;om/Tf`03o`000?oF:MKoeRWF00_oeRWF00?o0000ol/dboo;=</0
1oo;=</00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oN8MkogR7N00KogR7N00?o0000om/TfooK9=/0
2ooK9=/2o`0000gofbCK00?o0000omDZeOoE:]D01ooE:]D00ol0003oc3?<ol`cc007ol`cc004o`00
0?oA;]7odBkAo`0000kogaoO00?o0000on0Oh?oP7n000_oP7n000ol0003ofRGJomXUfP09omXUfP03
o`000?oN8MkogR7N00KogR7N00?o0000on<LhooS7><02ooS7><00ol0003ofRGJomXUfP05omXUfP04
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000SofbCK00?o0000omHYe_oF:MH02_oF:MH2o`0000Wo
bcC;00?o0000om/TfooK9=/02ooK9=/00ol0003ogR7NomhQgP07omhQgP03o`000?oK9=_ofbCK00Wo
fbCK00Co0000olDjaOo5>/Go00003?oK9=/00ol0003oeB[EomDZe@07omDZe@03o`000?o<<lcoc3?<
00Koc3?<00Go0000om4^dOoA;]7odBkAo`00000>omlOg`03o`000?oP7n3oh1oP00?oh1oP00?o0000
omXUf_oJ9MX01ooJ9MX00ol0003ogR7NomhQgP07omhQgP03o`000?oS7>?ohacS00[ohacS00?o0000
omXUf_oJ9MX01ooJ9MX00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006om/Tf`03o`000?oF:MKoeRWF
00WoeRWF00Co0000olTfbOo9=/Wo00002Oo;=</00ol0003ofbCKom/Tf`09om/Tf`03o`000?oN8Mko
gR7N00WogR7N00?o0000om/TfooK9=/01ooK9=/00ol0003oaC[5olDja@02olDja@03o`000?oK9=_o
fbCK00WofbCK00?o0000omDZeOoE:]D01ooE:]D00ol0003oc3?<ol`cc005ol`cc003o`000?oA;]7o
dBkA00?odBkA00?o0000omlOgooO7ml02_oO7ml00ol0003oh1oPon0Oh005on0Oh003o`000?oJ9M[o
fRGJ00GofRGJ00?o0000omhQg_oN8Mh02?oN8Mh00ol0003ohacSon<Lh`09on<Lh`03o`000?oJ9M[o
fRGJ00SofRGJ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oK9=/3o`0000WoeRWF00?o0000olTf
bOo9=/T00_o9=/T00ol0003obcC;ol/db`06ol/db`03o`000?oK9=_ofbCK00WofbCK00?o0000omhQ
g_oN8Mh02_oN8Mh00ol0003ofbCKom/Tf`05om/Tf`03o`000?o5>/GoaC[500CoaC[500?o0000om/T
fooK9=/02?oK9=/00ol0003oeB[EomDZe@07omDZe@03o`000?o<<lcoc3?<00Coc3?<00?o0000om4^
dOoA;]401?oA;]400ol0003ogaoOomlOg`0:omlOg`03o`000?oP7n3oh1oP00Koh1oP00?o0000omXU
f_oJ9MX00ooJ9MX00ol0003ogR7NomhQgP09omhQgP03o`000?oS7>?ohacS00SohacS00?o0000omXU
f_oJ9MX02OoJ9MX00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003on0Oh0?o00001OoF:MH00ol0003o
bCK9olTfb@03olTfb@03o`000?o;=<_obcC;00KobcC;00?o0000om/TfooK9=/02OoK9=/00ol0003o
gR7NomhQgP0;omhQgP03o`000?oK9=_ofbCK00?ofbCK00?o0000olDjaOo5>/D01_o5>/D00ol0003o
fbCKom/Tf`08om/Tf`03o`000?oE:]GoeB[E00KoeB[E00?o0000ol`cc?o<<l`00_o<<l`2o`0000So
dBkA00?o0000omlOgooO7ml02OoO7ml00ol0003oh1oPon0Oh007on0Oh005o`000?oJ9M[ofRGJomXU
f_l000003OoN8Mh00ol0003ohacSon<Lh`06on<Lh`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oP7n3oh1oP00Goh1oP0ol000000ooF:MKo0000olTfb@06olTfb@03
o`000?o;=<_obcC;00GobcC;00?o0000om/TfooK9=/02OoK9=/00ol0003ogR7NomhQgP0<omhQgP05
o`000?oK9=_ofbCKom/Tfol000002_o5>/D00ol0003ofbCKom/Tf`07om/Tf`03o`000?oE:]GoeB[E
00KoeB[E00?o0000ol`cc?l000000_l000000ooS7>?o0000om4^d@07om4^d@03o`000?oO7moogaoO
00SogaoO00?o0000on0Oh?oP7n002OoP7n000ol0003ofRGJo`00000=omhQgPCo00001OoS7><00ol0
003ofRGJomXUfP0;omXUfP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oh1oPon0Oh008on0Oh003
o`000?o9=/WobCK900OobCK900?o0000ol/dboo;=</01?o;=</00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oN8MkogR7N00gogR7N00?o0000om/Tfol000003?o5>/D:o`0000OoeB[E0ol00005on<Lh`03
o`000?oA;]7odBkA00KodBkA00?o0000omlOgooO7ml01ooO7ml00ol0003oh1oPon0Oh00:on0Oh003
o`000?oN8MkogR7N00_ogR7N00?o0000omPWf?oH9mP00_oH9mP3o`000003on<Lhol0003ofRGJ00_o
fRGJ0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000on0Oh?oP7n002OoP7n000ol0003obCK9olTfb@07olTfb@03o`00
0?o;=<_obcC;00GobcC;00?o0000om/TfooK9=/01ooK9=/00ol0003ogR7NomhQgP0?omhQgP;o0000
2oo5>/D00ol0003ogb3OomlPg`07omlPg`03o`000?oE:]GoeB[E00;oeB[E0ol00008on<Lh`03o`00
0?oA;]7odBkA00KodBkA00?o0000omlOgooO7ml01ooO7ml00ol0003oh1oPon0Oh00:on0Oh003o`00
0?oN8MkogR7N00[ogR7N00?o0000omPWf?oH9mP01_oH9mP00ol0003ofRGJomXUfP08omXUfP?o0000
0_oQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000on0Oh?oP7n002OoP7n000ol0003obCK9olTf
b@08olTfb@03o`000?o;=<_obcC;00CobcC;00?o0000om/TfooK9=/01ooK9=/00ol0003ogR7NomhQ
gP0>omhQgP04o`000?o=</gocC;=o`0000WoaC[500?o0000omlPgooO8=l02OoO8=l01?l0003oeB[E
o`000?l0000<on<Lh`03o`000?oA;]7odBkA00KodBkA00?o0000omlOgooO7ml01_oO7ml00ol0003o
h1oPon0Oh00;on0Oh003o`000?oN8MkogR7N00OogR7N0_l00009omPWf003o`000?oJ9M[ofRGJ00Co
fRGJ1?l00006on4Nh@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003oh1oPon0Oh009on0Oh003o`00
0?o9=/WobCK900SobCK900?o0000ol/dboo;=</00oo;=</>o`0000gogR7N00?o0000oldbcOo=</d0
0_o=</d00ol0003oaC[5olDja@05olDja@03o`000?oO8=oogb3O00_ogb3O00?o0000on<LhooS7><0
3?oS7><00ol0003odBkAom4^d@06om4^d@03o`000?oO7moogaoO00GogaoO00?o0000on0Oh?oP7n00
3?oP7n000ol0003ogR7NomhQgP06omhQgP03o`000?oH9mSof2OH00[of2OH00?o0000omXUf_oJ9MX0
0ol0000:on4Nh@?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oP7n3oh1oP00_oh1oP00?o0000olTfbOo9=/T02?o9
=/T01Ol0003obcC;ol/dboo;=<_o000000_oebSG00?o0000okU6^OniA[T00ol00009omhQgP03o`00
0?o=</gocC;=00CocC;=00?o0000olDjaOo5>/D00oo5>/D00ol0003ogb3OomlPg`0<omlPg`03o`00
0?oS7>?ohacS00gohacS00?o0000om4^dOoA;]401_oA;]400ol0003ogaoOomlOg`03omlOg`?o0000
3OoP7n000ol0003ogR7NomhQgP05omhQgP03o`000?oH9mSof2OH00cof2OH0_l0000=on4Nh@03o`00
0?oj1O[onPGj00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oP7n3oh1oP00_oh1oP00?o0000olTfbOo9=/T02?o9
=/T4o`0000coebSG00?o0000okU6^OniA[T00oniA[T3o`0000GogR7N00?o0000oldbcOo=</d01_o=
</d01Ol0003oaC[5olDjaOo5>/Go000000oogb3O00?o0000on<LhooS7><03OoS7><00ol0003odBkA
om4^d@06om4^d@03o`000?oO7moogaoO00?o00000ooC;=<00ol0003oh1oPon0Oh00;on0Oh003o`00
0?oN8MkogR7N00?ogR7N00?o0000omPWf?oH9mP03OoH9mP00ol0003ohAkQon4Nh@0;on4Nh@03o`00
0?oj1O[onPGj00ConPGj0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000on0Oh?oP7n002_oP7n03o`0000KobCK90ol0
0003ol`cc003o`000?oG:=OoebSG00[oebSG00?o0000okU6^OniA[T01_niA[T3o`000003omhQg_l0
003ocC;=00WocC;=00?o0000olDjaOl000004?oO8=l00ol0003ohacSon<Lh`0=on<Lh`03o`000?oA
;]7odBkA00OodBkA0_l00007om</d`03o`000?oP7n3oh1oP00[oh1oP00Co0000omhQg_oN8MkogR7N
0ol0000?omPWf003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ooX5n_oj1OX01ooj1OX4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000on0Oh?oP7n002_oP
7n001?l0003oeB[EomDZeOoE:]D2o`000004olTfbOl0003o0000o`0000Koc3?<00?o0000omLXeooG
:=L02_oG:=L00ol0003o^DJiokU6^@09okU6^@03o`000?o=</gocC;=00[ocC;=00?o0000omlPgooO
8=l03ooO8=l00ol0003ohacSon<Lh`0>on<Lh`03o`000?oA;]7odBkA00KodBkA00?o0000om</dooC
;=<01ooC;=<4o`0000Soh1oP00Co0000omhQg_oN8Mko00000oo5>/D2o`0000gof2OH00?o0000on4N
hOoQ7^402_oQ7^400ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000on0Oh?oP7n002OoP7n000ol0003o
eB[EomDZe@04omDZe@03o`000?o<<lcoc3?<00Ooc3?<00?o0000omLXeooG:=L02OoG:=L00ol0003o
^DJiokU6^@0:okU6^@03o`000?o=</gocC;=00[ocC;=00?o0000omlPgooO8=l03ooO8=l00ol0003o
hacSon<Lh`0>on<Lh`03o`000?oA;]7odBkA00GodBkA00?o0000om</dooC;=<02?oC;=<01?l0003o
fBKIomTVfOoI9]T7o`0000;oh1oP0_l00006olDja@;o00003?oH9mP00ol0003ohAkQon4Nh@09on4N
h@03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oh1oPon0Oh008on0Oh003o`000?oE:]GoeB[E00Go
eB[E00?o0000ol`cc?o<<l`02?o<<l`00ol0003oebSGomLXe`08omLXe`03o`000?niA[Wo^DJi00[o
^DJi00?o0000oldbcOo=</d02oo=</d00ol0003ogb3OomlPg`0>omlPg`03o`000?oS7>?ohacS00ko
hacS1Ol00002om4^d@03o`000?oC;=?odbcC00WodbcC00?o0000omTVfOoI9]T02?oI9]T3o`0000Wo
aC[50_l0000:omPWf003o`000?oQ7^7ohAkQ00SohAkQ00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oP7n3oh1oP00Soh1oP00?o0000omDZeOoE:]D01ooE:]D00ol0003oc3?<ol`cc007ol`cc003o`00
0?oG:=OoebSG00SoebSG00?o0000okU6^OniA[T02_niA[T00ol0003ocC;=oldbc@0:oldbc@;o0000
3_oO8=l3o`0000gohacS0ol00005on@Ki0;o00002ooC;=<00ol0003ofBKIomTVf@0;omTVf@;o0000
2_o5>/D2o`0000Oof2OH0ol00009on4Nh@03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:omDZe@03o`00
0?o<<lcoc3?<00Ooc3?<00?o0000omLXeooG:=L02?oG:=L>o`0000WocC;=0ol000000onm@[go0000
omlPg`0:omlPg`?o00000_oU6^D00ol0003ohacSon<Lh`09on<Lh`;o00002OoT6n@00ol0003odbcC
om</d`09om</d`03o`000?oI9]WofBKI00_ofBKI00?o0000omhQg_l000002oo5>/D2o`0000Cof2OH
00Co0000on@Ki?oT6nCoi1_T0_l00007on4Nh@03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003oeB[E
omDZe@09omDZe@03o`000?o<<lcoc3?<00Koc3?<00?o0000omLXeooG:=L02?oG:=L00ol0003o`Sg2
ol8m`P0:ol8m`P03o`000?o=</gocC;=00CocC;=0ol00005oke2_@03o`000?oO8=oogb3O00Cogb3O
1?l00006onDJi@03o`000?oS7>?ohacS00KohacS0_l0000;on@Ki003o`000?oC;=?odbcC00WodbcC
00?o0000omTVfOoI9]T02_oI9]T01Ol0003ogR7NomhQg_oN8Mko000000coaC[50_l000000ooH9mSo
0000on@Ki005on@Ki003o`000?oQ7^7ohAkQ00?ohAkQ00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?oE:]GoeB[E00SoeB[E00?o0000ol`cc?o<<l`01_o<<l`00ol0003oebSGomLXe`07omLXe`03o`00
0?o2?L;o`Sg200_o`Sg200?o0000oldbcOo=</d00_o=</d2o`0000Wo_D:m00?o0000omlPgooO8=l0
0ol0000;onDJi@03o`000?oS7>?ohacS00;ohacS0ol0000>on@Ki003o`000?oC;=?odbcC00OodbcC
00?o0000omTVfOoI9]T02ooI9]T00ol0003ogR7NomhQgP02omhQgP03o`000?o5>/GoaC[500_oaC[5
00?o0000on@Ki?oT6n@01_oT6n@2o`0000?ohAkQ00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oE
:]GoeB[E00OoeB[E00?o0000ol`cc?o<<l`01oo<<l`00ol0003oebSGomLXe`05omLXe`?o00003Oo2
?L84o`0000_o_D:m0ol0000?onDJi@04o`000?oS7>?o0000o`00017oi1_T00?o0000om</dooC;=<0
1ooC;=<00ol0003ofBKIomTVf@0:omTVf@03o`000?oN8MkogR7N00CogR7N00?o0000olDjaOo5>/D0
1oo5>/D3o`0000_oi1_T1?l0000=ooX5nP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000omDZeOoE:]D02?oE:]D00ol0003oc3?<ol`c
c006ol`cc003o`000?oG:=OoebSG00;oebSG0ol00003oll`c`03o`000?o2?L;o`Sg200[o`Sg200?o
0000oke2_Onm@[d02onm@[d00ol0003oa3_4o`00000AonDJi@03o`000?oT6nCoi1_T017oi1_T00?o
0000om</dooC;=<01ooC;=<00ol0003ofBKIomTVf@0:omTVf@03o`000?oN8MkogR7N00GogR7N00Co
0000olDjaOo5>/GoaC[51Ol00002olhacP03o`000?oT6nCoi1_T00Woi1_T00Co0000ooX5n_oj1O[o
nPGj0ol00009ooX5nP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000omDZeOoE:]D01ooE:]D00ol0003oc3?<ol`cc005ol`cc0?o0000
00?oebSGo`000?l000001oo?<<l00ol0003o`Sg2ol8m`P08ol8m`P?o00002_nm@[d2o`0000;oa3_4
00?o0000onDJiOoU6^D03ooU6^D00ol0003oi1_Ton@Ki00Aon@Ki003o`000?oC;=?odbcC00OodbcC
00?o0000omTVfOoI9]T02OoI9]T00ol0003ogR7NomhQgP07omhQgP?o00001oo><Lh00ol0003oi1_T
on@Ki009on@Ki003o`000?oj1O[onPGj00ConPGj0_l00007ooX5nP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000omDZeOoE:]D01ooE
:]D4o`0000;oc3?<0_l00003omLXe`03o`000?o?<<oocc3?00Socc3?0_l00006ol8m`P;o00000oo6
>LH00ol0003o_D:moke2_@06oke2_@03o`000?o4>lCoa3_400?oa3_400?o0000onDJiOoU6^D03_oU
6^D00ol0003oi1_Ton@Ki00Bon@Ki003o`000?oC;=?odbcC00GodbcC00?o0000omTVfOoI9]T02OoI
9]T00ol0003ogR7NomhQgP08omhQgP03o`000?o><LkocS7>00OocS7>00?o0000on@Ki?oT6n@02?oT
6n@00ol0003onPGjooX5nP07ooX5nP;o00001Ooj1OX00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oE:]GoeB[E00CoeB[E0_l00004
on8MhP;o00001OoG:=L00ol0003occ3?oll`c`0:oll`c`03o`000?o2?L;o`Sg200;o`Sg200?o0000
olHia_o6>LH01?o6>LH00ol0003o_D:moke2_@04oke2_@03o`000?o4>lCoa3_400Coa3_400?o0000
onDJiOoU6^D03_oU6^D00ol0003oi1_Ton@Ki00Bon@Ki0[o00002_oI9]T00ol0003ogR7NomhQgP08
omhQgP03o`000?o><LkocS7>00OocS7>00?o0000on@Ki?oT6n@02?oT6n@00ol0003onPGjooX5nP09
ooX5nP?o000000?onPGjo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003oeB[EomDZeOoE:]D2o`0000OohQgR00?o0000omLXeooG:=L01?oG:=L0
0ol0003occ3?oll`c`0:oll`c`04o`000?o2?L;o0000o`0000SoaSW600Co0000oke2_Onm@[go_D:m
0_l00007ol@ka003o`000?oU6^GoiA[U00koiA[U00?o0000on@Ki?oT6n@04_oT6n@00ol0003of2OH
omPWf007omPWf003o`000?oI9]WofBKI00KofBKI00?o0000omhQg_oN8Mh02_oN8Mh00ol0003ocS7>
olhacP06olhacP03o`000?oT6nCoi1_T00Soi1_T00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?oE
:]Go0000o`0000WohQgR00?o0000omLXeooG:=L01?oG:=L00ol0003occ3?oll`c`0;oll`c`03o`00
0?o6>LKoaSW600WoaSW600?o0000oke2_Ol000002Oo4>l@00ol0003oiA[UonDJi@0>onDJi@;o0000
4_oT6n@00ol0003of2OHomPWf009omPWf0;o00001_oI9]T00ol0003ogR7NomhQgP0:omhQgP03o`00
0?o><LkocS7>00KocS7>00?o0000on@Ki?oT6n@02?oT6n@00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000on8Mh_oR7N802OoR7N800ol0003oebSGomLXe`05omLXe`03o`000?o?<<oocc3?00[occ3?00?o
0000olHia_o6>LH02_o6>LH2o`0000Woa3_400?o0000onDJiOoU6^D03_oU6^D00ol0003ogR7No`00
0002o`0000ooi1_T00?o0000omPWf?oH9mP02ooH9mP00ol0003ofBKIomTVf@03o`0000gogR7N00?o
0000olhac_o><Lh01_o><Lh00ol0003oi1_Ton@Ki007on@Ki003o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ohQgRon8MhP09on8MhP03o`000?oG:=OoebSG00GoebSG00?o0000oll`coo?<<l02Oo?<<l2
o`0000_oaSW60_l0000;ol@ka003o`000?oU6^GoiA[U00coiA[U00?o0000omhQg_oN8Mh00ooN8Mh3
o`0000coi1_T00?o0000omPWf?oH9mP03?oH9mP2o`0000;oe2_D00?o0000omhQg_oN8Mh03?oN8Mh0
0ol0003ocS7>olhacP05olhacP03o`000?oT6nCoi1_T00Ooi1_T00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oR7N;ohQgR00[ohQgR00?o0000omLXeooG:=L01_oG:=L00ol0003occ3?oll`c`07oll`
c`03o`000?o5>/Go000000[oaSW600Co0000ok]4^onkA;_o00002_o4>l@00ol0003oiA[UonDJi@0<
onDJi@03o`000?oN8MkogR7N00KogR7N0_l00008on@Ki0;o00003ooH9mP00ol0003oe2_Dom@[e002
om@[e003o`000?oN8MkogR7N00_ogR7N00?o0000olhac_o><Lh01Oo><Lh00ol0003oi1_Ton@Ki007
on@Ki003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003ohQgRon8MhP0:on8MhP03o`000?oG:=OoebSG
00KoebSG00?o0000oll`coo?<<l01_o?<<l01Ol0003oaC[5olDjaOo5>/Go000000SoaSW600?o0000
ok]4^onkA;/00_nkA;/00ol0003oa3_4ol@ka006ol@ka0Co00003?oU6^D00ol0003ogR7NomhQgP08
omhQgP?o00000_oT6n@3o`000003omLXeol0003of2OH00gof2OH00?o0000om@[e?oD:m@01?oD:m@0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o><LkocS7>00GocS7>00?o0000on@Ki?oT6n@01_oT6n@0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000on8Mh_oR7N802ooR7N800ol0003oebSGomLXe`07omLX
e`03o`000?o?<<oocc3?00?occ3?0_l00005olDja@03o`000?o6>LKoaSW600CoaSW600?o0000ok]4
^onkA;/00onkA;/00ol0003oa3_4ol@ka005ol@ka003o`000?oC;=?odbcC00;odbcC0ol00007onDJ
i@;o00003_oN8Mh2o`0000GoebSG00?o0000omPWf?oH9mP02_oH9mP00ol0003oe2_Dom@[e005om@[
e003o`000?oN8MkogR7N00_ogR7N00?o0000olhac_o><Lh01?o><Lh00ol0003oi1_Ton@Ki006on@K
i003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003ohQgRon8MhP0;on8MhP03o`000?oG:=OoebSG00Oo
ebSG00?o0000oll`coo?<<l00_o?<<l00ol0003oaC[5olDja@06olDja@03o`000?o6>LKoaSW600;o
aSW600?o0000ok]4^onkA;/01OnkA;/00ol0003oa3_4ol@ka002ol@ka0;o00002?oC;=<3o`0000;o
iA[U0_l000000ooF:MKo0000omhQgP0=omhQgP03o`000?oG:=OoebSG00GoebSG00?o0000omPWf?oH
9mP02?oH9mP00ol0003oe2_Dom@[e007om@[e003o`000?oN8MkogR7N00[ogR7N00?o0000olhac_o>
<Lh01?o><Lh00ol0003oi1_Ton@Ki006on@Ki003o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ohQgR
on8MhP0<on8MhP03o`000?oG:=OoebSG00SoebSG00Co0000oll`coo?<<oo00002Oo5>/D01Ol0003o
aSW6olHia_o6>LKo000000So^dBk00Go0000ol@ka?o4>lCoa3_4o`00000=om</d`;o00001?oF:MH0
0ol0003ogR7NomhQgP0;omhQgP03o`000?oG:=OoebSG00KoebSG00?o0000omPWf?oH9mP01ooH9mP0
0ol0003oe2_Dom@[e008om@[e0Co00002?oN8Mh00ol0003ocS7>olhacP04olhacP03o`000?oT6nCo
i1_T00Koi1_T00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oR7N;ohQgR00_ohQgR0ol00009omLX
e`03o`000?o?<<oo000000_oaC[500?o0000olHia_l000002_nkA;/00ol0003oa3_4o`00000?om</
d`03o`000?oF:MKoeRWF00;oeRWF00?o0000omhQg_oN8Mh02ooN8Mh00ol0003oebSGomLXe`06omLX
e`03o`000?oH9mSof2OH00Kof2OH00?o0000om@[e?oD:m@02OoD:m@01?l0003ofbCKom/TfooK9=/7
o`0000;ogR7N00?o0000olhac_o><Lh00oo><Lh00ol0003oi1_Ton@Ki005on@Ki003o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oR7N;ohQgR00SohQgR0ol00003omHYeP03o`000?oG:=OoebSG00OoebSG00?o0000olDj
aOo5>/D02oo5>/D00ol0003o^dBkok]4^`0:ok]4^`03o`000?oC;=?odbcC00godbcC00?o0000omHY
e_oF:MH01?oF:MH00ol0003ogR7NomhQgP09omhQgP03o`000?oG:=OoebSG00SoebSG00?o0000omPW
f?oH9mP00ooH9mP2o`0000coe2_D00?o0000om/TfooK9=/02?oK9=/<o`0000?oi1_T0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000on8Mh_oR7N801_oR7N83o`0000OoeRWF00?o0000omLXeooG:=L01_oG:=L00ol0003o
aC[5olDja@0;olDja@03o`000?nkA;_o^dBk00Wo^dBk0_l0000>om</d`03o`000?oF:MKoeRWF00Go
eRWF00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oebSGomLXe`09omLXe`03o`000?oH9mSo000000;o
00000_o@;m000ol0003oe2_Dom@[e008om@[e003o`000?oK9=_ofbCK00cofbCK00?o0000on/Djoo[
5>/01_o[5>/3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ohQgRon8MhP03on8MhP?o00002ooF:MH00ol0003oebSG
omLXe`04omLXe`03o`000?o5>/GoaC[500_oaC[50ol00007ok]4^`?o000000?ocC;=o`000?oC;=<0
3OoC;=<00ol0003oeRWFomHYeP06omHYeP03o`000?oN8MkogR7N00SogR7N00?o0000omLXeooG:=L0
2_oG:=L00ol0003od2o@om0_d004om0_d003o`000?oD:mCoe2_D00Ooe2_D00?o0000om/TfooK9=/0
2ooK9=/00ol0003ojaC[on/Dj`08on/Dj`03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004on8Mh_l0
003o0000o`0000ooeRWF00?o0000omLXeooG:=L00ooG:=L>o`0000?oaSW60_l00002ok]4^`?o0000
1Oo=</d00ol0003odbcCom</d`0:om</d`03o`000?oF:MKoeRWF00OoeRWF00?o0000omhQg_oN8Mh0
2?oN8Mh00ol0003oebSGomLXe`0:omLXe`03o`000?o@;m3od2o@00God2o@00?o0000om@[e?oD:m@0
1_oD:m@00ol0003ofbCKom/Tf`0;om/Tf`03o`000?o[5>_ojaC[00SojaC[00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;oeRWF00?o0000omLXeooG:=L00_oG:=L00ol0003o^4NhokQ7
^00:okQ7^003o`000?o6>LKoaSW600?oaSW60_l00009oldbc@03o`000?oC;=?odbcC00WodbcC00?o
0000omHYe_oF:MH02?oF:MH2o`0000SogR7N00?o0000omLXeooG:=L02OoG:=L00ol0003od2o@om0_
d007om0_d003o`000?oD:mCoe2_D00Coe2_D00?o0000om/TfooK9=/02ooK9=/00ol0003ojaC[on/D
j`09on/Dj`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oeRWFomHYeP0?omHYeP?o000000?oebSG
o`000?nhAkP02onhAkP00ol0003oaSW6olHiaP04olHiaP03o`000?o=</gocC;=00WocC;=00?o0000
om</dooC;=<01ooC;=<00ol0003oeRWFomHYeP09omHYeP04o`000?oD:mCo0000o`0000KogR7N00?o
0000omLXeooG:=L02OoG:=L00ol0003od2o@om0_d008om0_d003o`000?oD:mCoe2_D00?oe2_D00?o
0000om/TfooK9=/02ooK9=/00ol0003ojaC[on/Dj`09on/Dj`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oeRWFomHYeP0<omHYeP;o00000oo@;m02o`0000co^4Nh00?o0000olHia_o6>LH01?o6>LH0
0ol0003ocC;=oldbc@0:oldbc@Wo00002ooF:MH00ol0003oe2_Dom@[e002om@[e0?o00000_oN8Mh0
0ol0003oebSGomLXe`0:omLXe`03o`000?o@;m3od2o@00Wod2o@00?o0000om@[e?oD:m@00_oD:m@0
0ol0003ofbCKom/Tf`0:om/Tf`03o`000?o[5>_ojaC[00WojaC[00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_oF:MH2o`0000God2o@00?o0000oldbcOl000002_nhAkP00ol0003oaSW6olHiaP06olHi
aP03o`000?o=</gocC;=00WocC;=00?o0000oldbcOo=</d01Oo=</d00ol0003oeRWFomHYeP09omHY
eP03o`000?oD:mCoe2_D00Goe2_D0ol00009omLXe`?o00003Oo@;m001Ol0003oe2_Dom@[e?oD:mCo
000000cofbCK00?o0000on/Djoo[5>/02Oo[5>/00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000omHY
e_oF:MH01OoF:MH2o`0000Ood2o@00Co0000oldbcOo=</go00002OnhAkP00ol0003oaSW6olHiaP06
olHiaP03o`000?o=</gocC;=00SocC;=00?o0000oldbcOo=</d01oo=</d00ol0003oeRWFomHYeP07
omHYeP03o`000?oD:mCoe2_D00Soe2_D0ol00002omLXe`Go00000_nm@[d00ol0003od2o@om0_d00<
om0_d003o`000?oD:mCo000000cofbCK00?o0000on/Djoo[5>/02_o[5>/00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000omHYe_oF:MH00_oF:MH2o`0000Sod2o@00?o0000oldbcOo=</d00_o=</d5o`00
00Co^4Nh00?o0000olHia_o6>LH01_o6>LH00ol0003ocC;=oldbc@08oldbc@03o`000?o=</gocC;=
00OocC;=00?o0000omHYe_oF:MH01ooF:MH00ol0003oe2_Dom@[e008om@[e003o`000?no@;oo_d2o
00;o00002?nm@[d00ol0003od2o@om0_d00<om0_d0Co00002_oK9=/00ol0003ojaC[on/Dj`0:on/D
j`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oeRWFo`000?l0000:om0_d003o`000?o=</gocC;=
00;ocC;=00?o0000oj1OX?nPGj000_nPGj04o`0000WoaSW600?o0000oldbcOo=</d02?o=</d00ol0
003ocC;=oldbc@08oldbc@03o`000?oF:MKoeRWF00GoeRWF00?o0000om@[e?oD:m@02?oD:m@01Ol0
003o_d2ookm0_ono@;oo000000[o_D:m0ol0000;om0_d004o`000?oS7>?ohacSon<Lh`Co00001OoK
9=/00ol0003ojaC[on/Dj`0;on/Dj`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003od2o@om0_d00:
om0_d003o`000?o=</gocC;=00?ocC;=00?o0000oj1OX?nPGj001?nPGj000ol0003oaSW6olHiaP07
olHiaP03o`000?o=</gocC;=00KocC;=0_l0000;oldbc@03o`000?oF:MKoeRWF00GoeRWF00?o0000
om@[e?oD:m@02?oD:m@00ol0003o_d2ookm0_`02okm0_`03o`000?nm@[go_D:m00Oo_D:m00?o0000
om0_d?o@;m001?l00006om0_d003o`000?oS7>?ohacS00KohacS0ol00002om/Tf`03o`000?o[5>_o
jaC[00_ojaC[00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@;m3od2o@00Wod2o@00?o0000oldb
cOo=</d01?o=</d00ol0003oX5nPoj1OX005oj1OX003o`000?o6>LKoaSW600OoaSW600?o0000oldb
cOo=</d00_o=</d3o`000003om8]d_l0003ocC;=00[ocC;=00?o0000omHYe_oF:MH01OoF:MH00ol0
003oe2_Dom@[e007om@[e003o`000?no@;oo_d2o00?o_d2o00?o0000oke2_Onm@[d01onm@[d00ol0
003od2o@om0_d004om0_d0?o00000_o@;m000ol0003ohacSon<Lh`0:on<Lh`;o00003_o[5>/00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000om0_d?o@;m002Oo@;m000ol0003ocC;=oldbc@04oldbc@03
o`000?nPGj3oX5nP00KoX5nP0_l00007olHiaP03o`000?o=</go000000;o00001OoB;M800ol0003o
cC;=oldbc@08oldbc@?o00001?oF:MH00ol0003oe2_Dom@[e008om@[e003o`000?no@;oo_d2o00Co
_d2o00?o0000oke2_Onm@[d01_nm@[d00ol0003od2o@om0_d007om0_d0;o00003_oS7><00ol0003o
jaC[on/Dj`0;on/Dj`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003od2o@om0_d008om0_d003o`00
0?o=</gocC;=00GocC;=00?o0000oj1OX?nPGj001?nPGj000ol0003o`cc3ol<l``03o`0000CoaSW6
0_l00008om8]dP03o`000?o=</gocC;=00OocC;=00Co0000omlOgooO7moogaoO0ol000000ooF:MKo
0000om@[e009om@[e003o`000?no@;oo_d2o00Co_d2o00?o0000oke2_Onm@[d01Onm@[d00ol0003o
d2o@om0_d009om0_d003o`000?oS7>?ohacS00gohacS00?o0000on/Djoo[5>/02_o[5>/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000om0_d?o@;m001oo@;m000ol0003ocC;=oldbc@06oldbc@03o`00
0?nPGj3oX5nP00?oX5nP00?o0000ol<l`oo3?<<01?o3?<<2o`000003olHia_l0003odRgB00[odRgB
00?o0000oldbcOo=</d01Oo=</d00ol0003ogaoOomlOg`05omlOg`03o`000?oD:mCoe2_D00Ooe2_D
0ol00007okm0_`03o`000?nm@[go_D:m00Co_D:m00?o0000om0_d?o@;m002Oo@;m000ol0003ohacS
on<Lh`0=on<Lh`03o`000?o[5>_ojaC[00[ojaC[00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@
;m3od2o@00God2o@0ol00009oldbc@05o`000?nPGj3oX5nPoj1OX?l000002Oo3?<<00ol0003odRgB
om8]dP0;om8]dP03o`000?o=</gocC;=00?ocC;=00?o0000omlOgooO7ml01_oO7ml00ol0003oe2_D
om@[e006om@[e005o`000?oE:]GoeB[EomDZeOl000001ono@;l00ol0003o_D:moke2_@03oke2_@03
o`000?o@;m3od2o@00Wod2o@00?o0000on<LhooS7><03_oS7><00ol0003ojaC[on/Dj`09on/Dj`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003od2o@o`000004o`0000;ogB;M00?o0000oldbcOo=</d0
1oo=</d01?l0003oX5nPoj1OX?l00009ol<l``;o00003OoB;M800ol0003ocC;=oldbc@02oldbc@03
o`000?oO7moogaoO00SogaoO00?o0000om@[e?oD:m@00ooD:m@2o`0000GoeB[E00?o0000okm0_ono
@;l01?no@;l00ol0003o_D:moke2_@03oke2_@03o`000?o@;m3od2o@00Wod2o@00?o0000on<LhooS
7><03_oS7><00ol0003ojaC[on/Dj`09on/Dj`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SogB;M
00?o0000oldbcOo=</d01_o=</d00ol0003oX5nPo`000009ol<l``04o`000?oH9mSof2OHo`0000go
dRgB00Co0000oldbcOo=</go00003?oO7ml01Ol0003oe2_Dom@[e?oD:mCo000000SoeB[E0_l00005
okm0_`03o`000?nm@[go_D:m00;o_D:m00?o0000om0_d?o@;m002Oo@;m000ol0003ohacSon<Lh`0>
on<Lh`03o`000?o[5>_ojaC[00WojaC[00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oM8]gogB;M
00OogB;M00?o0000oldbcOo=</d01oo=</d00ol0003o`cc3ol<l``07ol<l``03o`000?oH9mSof2OH
00;of2OH00?o0000om8]d_oB;M802_oB;M800ol0003ocC;=o`00000>omlOg`03o`000?oD:mCo0000
00_oeB[E00?o0000okm0_ono@;l00_no@;l01Ol0003o_D:moke2_Onm@[go000000cod2o@00?o0000
on<LhooS7><03_oS7><3o`0000WojaC[00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oM8]gogB;M
00WogB;M00?o0000oldbcOo=</d01_o=</d00ol0003o`cc3ol<l``06ol<l``03o`000?oH9mSof2OH
00?of2OH00?o0000om8]d_oB;M802ooB;M800ol0003ogaoOomlOg`0>omlOg`03o`000?oE:]GoeB[E
00_oeB[E0_l00003okm0_`04o`000?nm@[go_D:mo`0000[od2o@0ol0000>on<Lh`;o00000ooj1OX2
o`0000OojaC[00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oM8]gogB;M00[ogB;M00?o0000oldb
cOo=</d01?o=</d00ol0003o`cc3ol<l``06ol<l``03o`000?oH9mSof2OH00Gof2OH00?o0000om8]
d_oB;M801ooB;M83o`00017ogaoO00?o0000omDZeOoE:]D03OoE:]D01Ol0003o_d2ookm0_ol0003o
_D:m00Co00000oo@;m05o`0000;oeRWF00?o0000on<LhooS7><02_oS7><2o`0000OonPGj0_l00004
on/Dj`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003ogB;MomdRg@0;omdRg@03o`000?o=</gocC;=
00CocC;=00?o0000ol<l`oo3?<<01Oo3?<<00ol0003of2OHomPWf006omPWf003o`000?oB;M;odRgB
00CodRgB0ol00002omLXe`03o`000?oO7moogaoO00oogaoO0_l0000?omDZe@04o`000?no@;oo0000
o`0000Coc3?<0ol00008omHYeP03o`000?oS7>?ohacS00OohacS0_l0000;ooX5nP;o00000_o[5>/0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omdRgOoM8]d03?oM8]d6o`0000Oo`cc300?o0000omPW
f?oH9mP02?oH9mP00ol0003odRgBom8]dP03o`0000KoebSG00?o0000omlOgooO7ml03OoO7ml01?l0
003og2?Lom`Sg?l0000?omDZe@03o`000?o<<lcoc3?<00Goc3?<00?o0000omHYe_oF:MH02?oF:MH0
0ol0003ohacSon<Lh`05on<Lh`03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oM8]d00ol0003oc3?<ol`cc004ol`c
c003o`000?o3?<?o`cc300?o`cc300?o0000omPWf?oH9mP02_oH9mP2o`0000[oebSG00?o0000omlO
gooO7ml02ooO7ml00ol0003og2?Lom`Sg002om`Sg003o`000?oE:]GoeB[E00_oeB[E0_l00007ol`c
c003o`000?oF:MKoeRWF00WoeRWF00?o0000on<LhooS7><00_oS7><2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000omdRgOoM8]d02ooM8]d00ol0003oc3?<ol`cc006ol`cc005o`000?o3?<?o`cc3ol<l
`ol000003OoH9mP00ol0003oebSGomLXe`0:omLXe`03o`000?oO7moogaoO00WogaoO00?o0000om`S
g?oL8m`01?oL8m`00ol0003oeB[EomDZe@08omDZe@;o000000?o`Ck1o`000?o<<l`01oo<<l`00ol0
003oeRWFomHYeP09omHYeP04o`000?oS7>?o0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oM8]gogB;M
00WogB;M00?o0000ol`cc?o<<l`02?o<<l`00ol0003o`cc3o`00000=omPWf003o`000?oG:=OoebSG
00_oebSG00?o0000omlOgooO7ml02?oO7ml00ol0003og2?Lom`Sg006om`Sg003o`000?oE:]GoeB[E
00GoeB[E0_l00003ol4n`@03o`000?o<<lcoc3?<00Koc3?<00?o0000omHYe_oF:MH02_oF:MH00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003ogB;MomdRg@07omdRg@03o`000?o<<lcoc3?<00[oc3?<00?o0000omPWf?oH
9mP03?oH9mP00ol0003oebSGomLXe`0<omLXe`03o`000?oO7moogaoO00KogaoO00?o0000om`Sg?oL
8m`02?oL8m`00ol0003oeB[EomDZe@02omDZe@;o00001_o1?/400ol0003oc3?<ol`cc005ol`cc003
o`000?oF:MKoeRWF00[oeRWF00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oM8]gogB;M00GogB;M
00?o0000ol`cc?o<<l`03?o<<l`2o`0000cof2OH00?o0000omLXeooG:=L03OoG:=L00ol0003ogaoO
omlOg`04omlOg`03o`000?oL8mcog2?L00[og2?L00Co0000omDZeOl0003o00002?o1?/400ol0003o
c3?<ol`cc006ol`cc003o`000?oF:MKoeRWF00WoeRWF00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oM8]d00ol0003oc3?<ol`cc00=ol`cc003o`000?oB;M;o000000;o00002?oH9mP00ol0003oebSG
omLXe`0?omLXe`Ko00003_oL8m`00ol0003o`Ck1ol4n`@08ol4n`@03o`000?o<<lcoc3?<00Koc3?<
00?o0000omHYe_oF:MH02OoF:MH00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000omPWf?oH9mSof2OH
0_l0000?ol`cc003o`000?oB;M;odRgB00?odRgB0ol00005omPWf0;o00004?oG:=L01_l0003occ3?
oll`col0003oaC[5o`0000kog2?L00?o0000ol4n`Oo1?/402Oo1?/400ol0003oc3?<ol`cc005ol`c
c003o`000?oF:MKoeRWF00WoeRWF00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000omPWf?oH9mP00ooH9mP00ol0003o
c3?<ol`cc00=ol`cc003o`000?oB;M;odRgB00KodRgB0ol000001?oH9mSo0000om8]d_oB;M83o`00
00coebSG00Go0000oll`coo?<<oocc3?o`000002olDja@03o`000?oL8mcog2?L00_og2?L00?o0000
ol4n`Oo1?/402Oo1?/400ol0003oc3?<ol`cc006ol`cc003o`000?oF:MKoeRWF00SoeRWF0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003of2OHomPWf004omPWf0oo00003?oB;M800ol0003odRgBom8]dP04om8]
dP?o00002?oG:=L00ol0003occ3?oll`c`02oll`c`05o`000?o5>/GoaC[5olDjaOl000003?oL8m`0
0ol0003o`Ck1ol4n`@09ol4n`@03o`000?o<<lcoc3?<00Goc3?<3?l00002on4Nh@;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003of2OHomPWf005omPWf003o`000?o0?l3o`3o000_o`3o000?o0000om8]
d_oB;M802_oB;M800ol0003odRgBom8]dP07om8]dP;o00001OoG:=L00ol0003occ3?oll`c`03oll`
c`03o`000?o5>/GoaC[500;oaC[500?o0000om`Sg?oL8m`02OoL8m`00ol0003o`Ck1ol4n`@0:ol4n
`@03o`000?o<<lcoc3?<00?oc3?<00?o0000oki1__nn@Kh02Onn@Kh00ol0003ohAkQon4Nh@02on4N
h@;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003of2OHomPWf006omPWf003o`000?o0?l3o`3o000[o
`3o000?o0000om8]d_oB;M802ooB;M800ol0003odRgBom8]dP09om8]dP?o000000?oebSGo`000?o?
<<l01Oo?<<l00ol0003oaC[5olDja@03olDja@03o`000?oL8mcog2?L00Sog2?L3_l00003ol`cc0;o
00002onn@Kh00ol0003ohAkQon4Nh@05on4Nh@03o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000omPWf?oH9mP01OoH9mP00ol0003ob3O8o`00000;ol0o`003o`000?oB;M;odRgB00[odRgB
0_l0000>om8]dP03o`000?o?<<oocc3?00Gocc3?00?o0000olDjaOo5>/D00oo5>/D00ol0003og2?L
om`Sg008om`Sg003o`000?oB;M;odRgB00_odRgB00?o0000ol`cc?l000003Onn@Kh00ol0003ohAkQ
on4Nh@06on4Nh@;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oH9mSof2OH00Kof2OH00Co
0000olPgb?o8=lSo00002_o0?l000ol0003odRgBom8]dP09om8]dP03o`000?o@;m3o000000kodRgB
00?o0000oll`coo?<<l01Oo?<<l00ol0003oaC[5olDja@04olDja@03o`000?oL8mcog2?L00Kog2?L
00?o0000om8]d_oB;M803OoB;M800ol0003o_T6noki1_P0<oki1_P03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oH9mSof2OH00Gof2OH00?o0000olPgb?o8=lP00_o8
=lP00ol0003o`3o0ol0o`006ol0o`003o`000?oB;M;odRgB00SodRgB0_l00003om0_d003o`000?oB
;M;odRgB00_odRgB00?o0000oll`coo?<<l01Oo?<<l00ol0003oaC[5olDja@05olDja@03o`000?oL
8mcog2?L00Gog2?L00?o0000om8]d_oB;M803OoB;M800ol0003o_T6noki1_P0;oki1_P03o`000?oQ
7^7ohAkQ00WohAkQ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oH9mSof2OH00Kof2OH00?o0000
olPgb?o8=lP00oo8=lP00ol0003o`3o0ol0o`005ol0o`003o`000?oB;M;odRgB00OodRgB00?o0000
om0_d?o@;m000oo@;m000ol0003odRgBom8]dP0:om8]dP03o`000?o?<<oocc3?00Kocc3?00?o0000
olDjaOo5>/D01_o5>/D00ol0003og2?Lom`Sg004om`Sg003o`000?oB;M;odRgB00godRgB3ol0000;
on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?oH9mSof2OH00Kof2OH00?o0000olPgb?o8=lP01Oo8=lP00ol0
003o`3o0ol0o`004ol0o`003o`000?oB;M;odRgB00GodRgB0_l00006om0_d003o`000?oB;M;odRgB
00WodRgB0_l00008oll`c`03o`000?o5>/GoaC[500KoaC[51Ol000000ooL8mco0000om8]dP0?om8]
dP03o`000?nkA;_o^dBk00_o^dBk00?o0000on4NhOoQ7^402OoQ7^400ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?oH9mSof2OH00Kof2OH00?o0000olPgb?o8=lP01_o8=lP00ol0003o
`3o0ol0o`004o`0000KodRgB00?o0000om0_d?o@;m001oo@;m000ol0003odRgBom8]dP05om8]dP?o
000000?obSG:o`000?o?<<l01oo?<<l00ol0003oaC[5olDja@05olDja@03o`000?oM8]gogB;M00?o
gB;M0_l0000?om8]dP;o00003OnkA;/00ol0003ohAkQon4Nh@08on4Nh@03o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000Wof2OH00?o0000olPgb?o8=lP01oo8=lP2o`0000CogR7N00Co0000om8]d_oB;M;o
dRgB0_l0000:om0_d003o`000?oB;M;odRgB00;odRgB0ol00005olXebP03o`000?o?<<oocc3?00Go
cc3?00?o0000olDjaOo5>/D01?o5>/D00ol0003ogB;MomdRg@06omdRg@03o`000?oB;M;odRgB00[o
dRgB0_l00002om4^d@03o`000?nkA;_o^dBk00[o^dBk00?o0000on4NhOoQ7^402?oQ7^400ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000omPWf?oH9mP01_oH9mP00ol0003ob3O8olPgb008olPgb003o`00
0?oN8MkogR7N00CogR7N00?o0000om8]d_l000003?o@;m000ol0003odRgBo`000002o`0000WobSG:
00?o0000oll`coo?<<l01?o?<<l00ol0003oaC[5olDja@03olDja@03o`000?oM8]gogB;M00SogB;M
1_l00004om8]dP;o00001OoA;]400ol0003o^dBkok]4^`09ok]4^`03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oH9mSof2OH00Gof2OH00?o0000olPgb?o8=lP01oo8
=lP00ol0003ogR7NomhQgP06omhQgP03o`000?o@;m3od2o@00cod2o@00?o0000olXeb_o:=LX02_o:
=LX00ol0003occ3?oll`c`04oll`c`04o`000?o5>/GoaC[5olDja@;o00002ooM8]d00ol0003of2OH
omPWf003omPWf0Co00002?oA;]400ol0003o^dBkok]4^`08ok]4^`03o`000?oQ7^7ohAkQ00OohAkQ
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000omPWf?oH9mP00ooH9mP00ol0003ob3O8olPgb007olPgb003o`000?oN
8MkogR7N00OogR7N00?o0000om0_d?o@;m003?o@;m000ol0003obSG:olXebP0;olXebP03o`000?o?
<<oocc3?00?occ3?00Co0000olDjaOo5>/Go00003OoM8]d00ol0003of2OHomPWf006omPWf003o`00
0?oA;]7odBkA00OodBkA00?o0000ok]4^onkA;/01onkA;/00ol0003ohAkQon4Nh@06on4Nh@04o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oH9mSof2OH00;of2OH00?o0000olPgb?o8=lP0
1_o8=lP00ol0003ogR7NomhQgP09omhQgP03o`000?o@;m3od2o@00Wod2o@0_l0000>olXebP?o0000
0oo?<<l00ol0003oaC[5o`00000=omdRg@03o`000?oH9mSof2OH00Oof2OH00?o0000om4^dOoA;]40
2?oA;]4:o`0000KohAkQ0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000Oob3O800?o
0000omhQg_oN8Mh02_oN8Mh00ol0003od2o@om0_d006om0_d0;o000000?odBkAo`000?o:=LX02oo:
=LX2o`0000?ogB;M1Ol0000>omdRg@03o`000?oH9mSof2OH00Oof2OH00?o0000om4^dOoA;]402?oA
;]400ol0003ob3O8olPgb006olPgb003o`000?oQ7^7ohAkQ00?ohAkQ00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003ogR7NomhQgP03omhQgPCo00000_o8=lP00ol0003ogR7NomhQgP0;
omhQgP03o`000?o@;m3od2o@00?od2o@0ol00004om4^d@03o`000?o:=L[obSG:00OobSG:0_l00008
omdRg@03o`000?oM8]gogB;M00gogB;M00?o0000omPWf?oH9mP02?oH9mP00ol0003odBkAom4^d@07
om4^d@03o`000?o8=lSob3O800Oob3O80ol000000ooQ7^7o0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oN8MkogR7N00OogR7N0_l0000?omhQgP03o`000?o@;m3od2o@00;o00002?oA;]400ol0
003obSG:olXebP05olXebP03o`000?oM8]gogB;M00SogB;M00?o0000omdRgOoM8]d03OoM8]d00ol0
003of2OHomPWf008omPWf003o`000?oA;]7odBkA00KodBkA00?o0000olPgb?o8=lP02?o8=lP01?l0
003ogb3OomlPgol0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ogR7NomhQgP09omhQ
gP03o`000?oN8MkogR7N00kogR7N0_l0000;om4^d@03o`000?o:=L[obSG:00;obSG:0_l0000;omdR
g@03o`000?oM8]gogB;M00gogB;M00?o0000omPWf?oH9mP02?oH9mP00ol0003odBkAom4^d@06om4^
d@03o`000?o8=lSob3O800Oob3O800Go0000omlPgooO8=oogb3Oo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ogR7NomhQgP0:omhQgP03o`000?oN8MkogR7N00gogR7N0_l0000<om4^d@04o`000?o:=L[o0000
o`0000gogB;M00?o0000omdRgOoM8]d03?oM8]d00ol0003of2OHomPWf009omPWf003o`000?oA;]7o
dBkA00KodBkA00?o0000olPgb?o8=lP01_o8=lP00ol0003ogb3OomlPg`03omlPg`03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ogR7NomhQgP0:omhQgP03o`000?oN8MkogR7N00cogR7N00Co0000okM8
]ongB;Oo00003?oA;]400ol0003ogB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00SogB;M1?l0000;
omPWf003o`000?oA;]7odBkA00KodBkA00?o0000olPgb?o8=lP01Oo8=lP00ol0003ogb3OomlPg`04
omlPg`03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003ogR7NomhQgP0;omhQgP03o`000?oN8MkogR7N
00_ogR7N00?o0000okM8]ongB;L00_ngB;L00ol0003odBkAom4^d@09om4^d@03o`000?oM8]gogB;M
00kogB;M00Co0000omdRgOoM8]gogB;M1ol00003omhQgP03o`000?oH9mSof2OH00Wof2OH00?o0000
om4^dOoA;]401_oA;]400ol0003ob3O8olPgb004olPgb003o`000?oO8=oogb3O00Kogb3O00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oN8MkogR7N00cogR7N00?o0000omhQg_oN8Mh02_oN8Mh00ol0
003o]dRgokM8]`03okM8]`03o`000?oA;]7odBkA00SodBkA00?o0000omdRgOoM8]d03_oM8]d4o`00
00_ogR7N00?o0000omPWf?oH9mP02?oH9mP00ol0003odBkAom4^d@05om4^d@03o`000?o8=lSob3O8
00Gob3O800?o0000omlPgooO8=l01_oO8=l00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000omhQg_oN
8Mh03?oN8Mh7o`0000GogR7N00?o0000okM8]ongB;L01OngB;L00ol0003odBkAom4^d@07om4^d@03
o`000?oM8]gogB;M00kogB;M00?o0000omhQg_oN8Mh03OoN8Mh00ol0003of2OHomPWf008omPWf003
o`000?oA;]7odBkA00CodBkA00?o0000olPgb?o8=lP01?o8=lP00ol0003ogb3OomlPg`07omlPg`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003ogR7NomhQgP0=omhQgP03o`000?oL8mcog2?L00Cog2?L
1Ol00009okM8]`03o`000?oA;]7odBkA00KodBkA00?o0000omdRgOoM8]d03_oM8]d00ol0003ogR7N
omhQgP0=omhQgP03o`000?oH9mSof2OH00Sof2OH00Co0000om4^dOoA;]7odBkA1Ol00004olPgb003
o`000?oO8=oogb3O00Wogb3O1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=omhQgP03o`000?oL8mcog2?L00Wog2?L
0_l00009okM8]`03o`000?oA;]7odBkA00KodBkA00?o0000omdRgOoM8]d03?oM8]d00ol0003ogR7N
omhQgP0?omhQgPKo00001?oH9mP4o`0000GofbCK0_l000000oo8=lSo0000omlPg`0;omlPg`04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oO8=oogb3OomlPg`?o00002_oN8Mh00ol0003o
g2?Lom`Sg009om`Sg003o`000?o1?/7o000000;o00001ongB;L00ol0003odBkAom4^d@05om4^d@03
o`000?oM8]gogB;M00SogB;M1Ol0000AomhQgP03o`000?oI9]WofBKI00?ofBKI1?l0000;om/Tf`03
o`000?oO8=oogb3O00[ogb3O00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omlPgooO8=l01OoO8=l2o`0000OogR7N
00?o0000om`Sg?oL8m`02_oL8m`00ol0003o`Ck1ol4n`@02ol4n`@?o00001OngB;L00ol0003odBkA
om4^d@04om4^d@04o`000?oM8]gogB;MomdRg@Oo00001?oD:m@00ol0003ogR7NomhQgP0>omhQgP03
o`000?oI9]WofBKI00OofBKI00?o0000om/TfooK9=/02OoK9=/00ol0003ogb3OomlPg`09omlPg`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003ogb3OomlPg`08omlPg`;o00001?oN8Mh00ol0003og2?L
om`Sg00;om`Sg003o`000?o1?/7o`Ck100Go`Ck10ol00003okM8]`04o`000?oA;]7odBkAom4^d@Ko
00003?oD:m@00ol0003ogR7NomhQgP0=omhQgP03o`000?oI9]WofBKI00OofBKI00?o0000om/TfooK
9=/02_oK9=/00ol0003ogb3OomlPg`08omlPg`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omlPg`?o000000?ogR7No`000?oL8m`0
3?oL8m`00ol0003o`Ck1ol4n`@08ol4n`@?o000000Co]dRgo`000?l0003o00000_oN8Mh00ol0003o
e2_Dom@[e00=om@[e003o`000?oN8MkogR7N00cogR7N00?o0000omTVfOoI9]T02?oI9]T00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oO8=oogb3O00Kogb3O00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
gb3O00?o0000om`Sg?oL8m`03?oL8m`00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?oN8MkogR7N00?o
gR7N00?o0000om@[e?oD:m@03?oD:m@00ol0003ob3O8o`00000=omhQgP03o`000?oI9]WofBKI00So
fBKI00?o0000om/TfooK9=/03?oK9=/3o`0000Gogb3O00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oO8=oogb3O00cogb3O00?o0000om`Sg?oL8m`03?oL8m`00ol0003o`Ck1ol4n`@0:ol4n`@03o`00
0?oN8MkogR7N00GogR7N00?o0000om@[e?oD:m@02_oD:m@01?l0003ob3O8olPgb?o8=lP2o`0000[o
gR7N00?o0000omTVfOoI9]T02OoI9]T00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oS7>?ohacS00?o
000000?ogb3Oo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oO8=oogb3O00_ogb3O00?o0000om`Sg?oL8m`0
3?oL8m`00ol0003o`Ck1ol4n`@09ol4n`@03o`000?oN8MkogR7N00KogR7N00?o0000om@[e?oD:m@0
2OoD:m@00ol0003ob3O8olPgb002olPgb003o`000?oL8mco000000;o00001ooN8Mh00ol0003ofBKI
omTVf@09omTVf@03o`000?oK9=_ofbCK00_ofbCK00?o0000on<LhooS7><01?oS7><00ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omlPgooO8=l02ooO8=l00ol0003og2?Lom`Sg00;om`Sg003o`000?o1
?/7o`Ck100So`Ck100?o0000omhQg_oN8Mh01ooN8Mh00ol0003oe2_Dom@[e008om@[e003o`000?o8
=lSob3O800?ob3O800?o0000om`Sg?oL8m`00_oL8m`2o`0000CogR7N00?o0000omTVfOoI9]T02_oI
9]T00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oS7>?ohacS00GohacS00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oO8=oogb3O00[ogb3O0ol0000;om`Sg0Ko00001?o1?/400ol0003ogR7NomhQgP08
omhQgP03o`000?oD:mCoe2_D00Ooe2_D00?o0000olPgb?o8=lP00oo8=lP00ol0003og2?Lom`Sg005
om`Sg0?o000000?ogR7No`000?oI9]T02ooI9]T00ol0003ofbCKom/Tf`09om/Tf`03o`000?oS7>?o
hacS00OohacS00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oO8=oogb3O00Wogb3O00?o0000oldb
cOo=</d01?l00006om`Sg003o`000?oI9]WofBKI00CofBKI1?l0000<omhQgP03o`000?oD:mCoe2_D
00Goe2_D00?o0000olPgb?o8=lP01?o8=lP00ol0003og2?Lom`Sg008om`Sg003o`000?oI9]WofBKI
00_ofBKI00?o0000om/TfooK9=/02?oK9=/00ol0003ohacSon<Lh`08on<Lh`Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oO8=oogb3O00Oogb3O00?o0000oldbcOo=</d01Oo=</d3o`0000;og2?L00?o0000omTVfOoI
9]T02?oI9]T00ol0003ogR7NomhQgP0:omhQgP03o`000?oD:mCoe2_D00Coe2_D00?o0000olPgb?o8
=lP01Oo8=lP00ol0003og2?Lom`Sg008om`Sg003o`000?oI9]WofBKI00WofBKI1?l00008om/Tf`03
o`000?oS7>?ohacS00WohacS00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ogb3O
omlPg`05omlPg`03o`000?o=</gocC;=00WocC;=0_l0000<omTVf@03o`000?oN8MkogR7N00WogR7N
00?o0000om@[e?oD:m@00ooD:m@00ol0003ob3O8olPgb005olPgb003o`000?oL8mcog2?L00[og2?L
00?o0000omTVfOoI9]T01?oI9]T4o`0000CofRGJ00?o0000om/TfooK9=/01?oK9=/00ol0003ohacS
on<Lh`0:on<Lh`03o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oO8=oogb3O00?ogb3O00?o0000oldbcOo=</d02oo=
</d00ol0003ofBKIomTVf@0:omTVf@03o`000?oN8MkogR7N00WogR7N00?o0000om@[e?oD:m@00_oD
:m@00ol0003ob3O8olPgb006olPgb003o`000?oL8mcog2?L00[og2?L00?o0000omTVfOoI9]T01?l0
0009omXUfPKo00003?oS7><00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omlPgooO8=oogb3O0_l0
000=oldbc@03o`000?oI9]WofBKI00[ofBKI00?o0000omhQg_oN8Mh02OoN8Mh01Ol0003oe2_Dom@[
e?oD:mCo000000Wob3O800?o0000om`Sg?oL8m`02ooL8m`2o`0000gofRGJ00?o0000omlPgooO8=l0
0_oO8=l00ol0003ohacSon<Lh`0:on<Lh`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ogb3Oo`00
0002om</d`;o00002oo=</d00ol0003ofBKIomTVf@0;omTVf@03o`000?oN8MkogR7N00WogR7N00?o
0000om@[e?l000002Oo8=lP00ol0003og2?Lom`Sg00<om`Sg003o`000?oJ9M[ofRGJ00cofRGJ00?o
0000omlPgooO8=l00ooO8=l00ol0003ohacSon<Lh`09on<Lh`03o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003odbcCom</d`03om</d`;o00002_o=</d00ol0003ofBKIomTVf@0:omTVf@03o`000?oN8Mko
gR7N00SogR7N1Ol00008olPgb003o`000?oL8mcog2?L00cog2?L00?o0000omXUf_oJ9MX02ooJ9MX0
0ol0003ogb3OomlPg`05omlPg`03o`000?oS7>?ohacS00SohacS00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooC;=<2o`0000SocC;=00?o0000omTVfOoI9]T02_oI9]T00ol0003ogR7NomhQgP07omhQ
gP03o`000?oF:MKoeRWF00?oeRWF0ol00005olPgb003o`000?oL8mcog2?L00_og2?L00?o0000omXU
f_oJ9MX03?oJ9MX00ol0003ogb3OomlPg`06omlPg`03o`000?oS7>?ohacS00OohacS00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000WodbcC00?o0000oldbcOo=</d01Oo=</d2o`0000co
fBKI00?o0000omhQg_oN8Mh01OoN8Mh00ol0003oeRWFomHYeP07omHYeP?o000000?ob3O8o`000?oL
8m`03OoL8m`00ol0003ofRGJomXUfP0<omXUfP03o`000?oO8=oogb3O00Kogb3O00?o0000on<LhooS
7><01_oS7><00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?oC;=?odbcC00OodbcC
0_l00004oldbc@03o`000?o<<lcoc3?<00;o00002_oI9]T00ol0003ogR7NomhQgP03omhQgP;o0000
3OoF:MH2o`0000gog2?L0ol0000=omXUfP03o`000?oO8=oogb3O00Oogb3O00?o0000on<LhooS7><0
1OoS7><00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?oC;=?odbcC00SodbcC0_l0
00000oo=</go0000ol`cc004ol`cc003o`000?oI9]WofBKI00OofBKI00Co0000omhQg_oN8MkogR7N
0_l00002om</d`03o`000?oF:MKoeRWF00coeRWF3Ol00003olPgb003o`000?oJ9M[ofRGJ00[ofRGJ
00?o0000omlPgooO8=l02?oO8=l01?l0003ohacSon<LhooS7><4o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003odbcC
om</d`09om</d`03o`000?o<<lcoc3?<00Goc3?<0_l00008omTVf@03o`000?oN8Mko000000GodbcC
00?o0000omHYe_oF:MH02ooF:MH00ol0003oe2_Dom@[e009om@[e003o`000?o8=lSob3O800;ob3O8
0_l00009omXUfP03o`000?oO8=oogb3O00[ogb3O0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?oC;=?odbcC00SodbcC00?o0000ol`cc?o<<l`01oo<<l`4o`0000?ofBKI0ol0
0007om</d`03o`000?oF:MKoeRWF00[oeRWF00?o0000om@[e?oD:m@02OoD:m@00ol0003ob3O8olPg
b004olPgb0;o00001ooJ9MX00ol0003ogb3OomlPg`0:omlPg`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oC;=?odbcC00OodbcC00?o0000ol`cc?o<<l`02?o<<l`0
1?l0003occ3?oll`coo?<<l3o`0000;odBkA00?o0000om</dooC;=<01_oC;=<00ol0003oeRWFomHY
eP08omHYeP03o`000?oD:mCoe2_D00[oe2_D00?o0000olPgb?o8=lP01_o8=lP00ol0003ofRGJomXU
fP04omXUfP03o`000?oO8=oogb3O00Wogb3O00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om</dooC;=<01OoC;=<00ol0003oc3?<ol`cc008ol`cc003o`000?o?<<oo
cc3?00Cocc3?00Go0000om4^dOoA;]7odBkAo`000008om</d`03o`000?oF:MKoeRWF00OoeRWF00?o
0000om@[e?oD:m@02_oD:m@00ol0003ob3O8olPgb007olPgb0;o00001?oJ9MX00ol0003ogb3OomlP
g`08omlPg`03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om</dooC;=<00ooC;=<0
0ol0003oc3?<ol`cc008ol`cc003o`000?o?<<oocc3?00Cocc3?00?o0000om4^dOoA;]400_oA;]40
0ol0003odbcCom</d`07om</d`03o`000?oF:MKoeRWF00KoeRWF00?o0000om@[e?oD:m@02_oD:m@0
0ol0003ob3O8olPgb009olPgb005o`000?oJ9M[ofRGJomXUf_l000002OoO8=l00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_oc3?<00?o0000oll`coo?<<l01?o?<<l00ol0003odBkAom4^d@03
om4^d@03o`000?oC;=?odbcC00OodbcC00?o0000omHYe_oF:MH01OoF:MH00ol0003oe2_Dom@[e00:
om@[e003o`000?o8=lSob3O800Wob3O81?l00009omlPg`03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oP7n3oh1oP
on0Oh?l000002_o<<l`00ol0003occ3?oll`c`05oll`c`03o`000?oA;]7odBkA00?odBkA00?o0000
om</dooC;=<02?oC;=<00ol0003oeRWFomHYeP04omHYeP03o`000?oD:mCoe2_D00Woe2_D00?o0000
olPgb?o8=lP02?o8=lP2o`0000?og2?L00?o0000omlPgooO8=l01_oO8=l00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000on0Oh?oP7n000ooP7n000ol0003oc3?<ol`cc006ol`cc003o`000?o?<<oocc3?
00Gocc3?00?o0000om4^dOoA;]401?oA;]400ol0003odbcCom</d`09om</d`03o`000?oF:MKoeRWF
00;oeRWF00?o0000om@[e?oD:m@02_oD:m@00ol0003ob3O8olPgb006olPgb0;o00001_oL8m`8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003oh1oPon0Oh005on0Oh003o`000?o<<lcoc3?<00Goc3?<00?o0000oll`coo?
<<l01Oo?<<l00ol0003odBkAom4^d@05om4^d@03o`000?oC;=?odbcC00WodbcC00Go0000omHYe_oF
:MKoeRWFo`00000<om@[e003o`000?o8=lSob3O800Cob3O80_l00008om`Sg003o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oP7n3oh1oP00Ooh1oP00?o0000ol`cc?o<
<l`00oo<<l`00ol0003occ3?oll`c`06oll`c`03o`000?oA;]7odBkA00GodBkA00?o0000om</dooC
;=<02_oC;=<00ol0003oeRWFo`000004o`0000Woe2_D00?o0000olPgb?o8=lP00_o8=lP2o`0000[o
g2?L00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003oh1oPon0Oh007on0Oh003o`00
0?o<<lcoc3?<00;oc3?<00?o0000oll`coo?<<l01_o?<<l00ol0003odBkAom4^d@07om4^d@;o0000
2ooC;=<00ol0003odbcCom</d`03om</d`Oo00000_oD:m@00ol0003ob3O8olPgb002o`0000_og2?L
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000on0Oh?oP7n002OoP
7n001Ol0003oc3?<ol`cc?o<<lco000000Socc3?00?o0000om4^dOoA;]401ooA;]400ol0003ofRGJ
o`000002o`0000SodbcC00?o0000om</dooC;=<02_oC;=<5o`0000gog2?L00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<on0Oh003o`000?o<<lco000000Wocc3?00?o
0000om4^dOoA;]401_oA;]400ol0003ofRGJomXUfP03omXUfP?o00001?oC;=<00ol0003odbcCom</
d`0=om</d`03o`000?oL8mcog2?L00gog2?L00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ooj1OX2o`0000_oh1oP00?o0000oll`coo?<<l01oo?<<l00ol0003odBkAom4^d@07
om4^d@03o`000?oJ9M[ofRGJ00KofRGJ0ol000000ooC;=?o0000om</d`0>om</d`03o`000?oL8mco
g2?L00cog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00KonPGj0_l00009on0O
h003o`000?o?<<oocc3?00;occ3?1_l00008om4^d@03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000om</
dooC;=<03ooC;=<00ol0003og2?Lom`Sg00:om`Sg0;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00So
nPGj0_l00007on0Oh0Go00001_oU6^D00ol0003odBkAom4^d@05om4^d@03o`000?oJ9M[ofRGJ00[o
fRGJ00?o0000om</dooC;=<03ooC;=<00ol0003og2?Lom`Sg007om`Sg0?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oj1O[onPGj00[onPGj0_l00005on0Oh003o`000?oU6^GoiA[U00WoiA[U00?o0000om4^dOoA
;]400ooA;]400ol0003ofRGJomXUfP0;omXUfP03o`000?oC;=?odbcC00oodbcC00?o0000om`Sg?oL
8m`01OoL8m`2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5nP0<ooX5nP;o000000?oh1oPo`000?l00000
3OoU6^D00ol0003odBkAom4^d@02om4^d@03o`000?oJ9M[ofRGJ00_ofRGJ5?l00004om`Sg0;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooX5n_oj1OX03_oj1OX00ol0003onPGjo`00000>onDJi@04o`000?oA;]7odBkAo`0000kofRGJ
00?o0000onHIi_oV6NH04?oV6NH00ol0003og2?Lo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5
nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000003_oU6^D00ol0003odBkAo`00000>omXUfP03o`00
0?oV6NKoiQWV017oiQWV00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00conPGj00?o
0000ooX5n_oj1OX00_oj1OX00ol0003oiA[UonDJi@0=onDJi@03o`000?oJ9M[ofRGJ00WofRGJ1Ol0
000BonHIiP;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003oiA[UonDJi@0<onDJi@03o`000?oJ9M[ofRGJ00;ofRGJ1ol00004ooX5nP03o`000?oV6NKo
iQWV00ooiQWV00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003onPGjooX5nP06ooX5
nP03o`000?oU6^GoiA[U00coiA[U1?l0000<ooX5nP03o`000?oV6NKoiQWV00coiQWV0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00Oo
nPGj00?o0000onDJiOoU6^D03?oU6^D00ol0003onPGjooX5nP0=ooX5nP03o`000?oV6NKoiQWV00_o
iQWV00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003oiA[UonDJi@0:onDJi@03o`000?oj1O[onPGj00konPGj00?o0000onHIi_oV
6NH02OoV6NH2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000onDJiOoU6^D02_oU6^D00ol0003onPGj
ooX5nP0?ooX5nP03o`000?oV6NKoiQWV00KoiQWV0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooX5n_l0003onPGj00gonPGj3?l0
000AooX5nP?o00001_oV6NH00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooV6NH2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000onHIi_l000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02_l00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0005o`00o`?oool00ol00?l2oooo00Oo003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Ko003o0_ooo`1]o`00o`7ooooo001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04
o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`003?l00?l2
oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06go003o0Oooool0077o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o
00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1]o`00o`7ooooo001ao`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000go003o0_ooo`04o`00o`03oooo0?l00?oo003o00Co
003o00?oool0o`00ool00?l01Ol00?l2oooo06go003o0Oooool0077o003o0_ooo`000ol00?ooool0
o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`05o`00o`Coool0
0_l00?l2oooo00go003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06go003o0Oooool0073o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00co003o0oooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0;o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0008o`00o`Goool01Ol00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_ooo`05o`00
o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02ol00?l2oooo00Go003o0_ooo`06o`00
o`;oool01_l00?l2oooo06go003o0Oooool006ko003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool03?l00?l2oooo00Co003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1]o`00o`7ooooo001^o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool0
1Ol00?l00oooo`3o003oo`00o`04o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0
KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_oo
o`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00o`;oool01?l0
0?l2oooo00Ko003o00?o<S;<oooo0?ooo`00KOl00?l1ooooo`00KOl00?l3oooo00Go003o0oooo`07
o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`03o`00o`;oool00ol00?l2oooo00Oo003o0_ooo`02
o`00o`;oool01Ol00?l5oooo06go003o0Oooool006co003o1_ooo`000ol00?ooool0oooo0005oooo
00?o003o1Oooo`0Po`00o`Coool02Ol00?l4oooo07So003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(40) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.979 .021 .979 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.978 .022 .978 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.978 .022 .978 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.978 .022 .978 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.844 .156 .844 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.978 .022 .978 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.834 .166 .834 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.888 .112 .888 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.857 .143 .857 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.806 .194 .806 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.979 .021 .979 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.832 .168 .832 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.795 .205 .795 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.826 .174 .826 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.796 .204 .796 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.978 .022 .978 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.978 .022 .978 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.824 .176 .824 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.801 .199 .801 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.62 .38 .62 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.718 .282 .718 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.718 .282 .718 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.728 .272 .728 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.86 .14 .86 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.851 .149 .851 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.742 .258 .742 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.799 .201 .799 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.731 .269 .731 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.82 .18 .82 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.838 .162 .838 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.978 .022 .978 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.836 .164 .836 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.773 .227 .773 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.869 .131 .869 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.841 .159 .841 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.724 .276 .724 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.979 .021 .979 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.883 .117 .883 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.792 .208 .792 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.814 .186 .814 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.79 .21 .79 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.815 .185 .815 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.869 .131 .869 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.751 .249 .751 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.978 .022 .978 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.741 .259 .741 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.683 .317 .683 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.857 .143 .857 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.869 .131 .869 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.753 .247 .753 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.744 .256 .744 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.822 .178 .822 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.978 .022 .978 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.849 .151 .849 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.83 .17 .83 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.853 .147 .853 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.529 .471 .529 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.747 .253 .747 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.821 .179 .821 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.858 .142 .858 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.705 .295 .705 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.641 .359 .641 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.648 .352 .648 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.689 .311 .689 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.837 .163 .837 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.693 .307 .693 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.767 .233 .767 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.76 .24 .76 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.816 .184 .816 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.829 .171 .829 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.805 .195 .805 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.884 .116 .884 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.979 .021 .979 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.706 .294 .706 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.76 .24 .76 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.683 .317 .683 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.978 .022 .978 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.856 .144 .856 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.795 .205 .795 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.639 .361 .639 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.708 .292 .708 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.83 .17 .83 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.762 .238 .762 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.839 .161 .839 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.813 .187 .813 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.657 .343 .657 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.765 .235 .765 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.775 .225 .775 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.745 .255 .745 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.827 .173 .827 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.863 .137 .863 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.836 .164 .836 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.668 .332 .668 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.743 .257 .743 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.832 .168 .832 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.768 .232 .768 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.77 .23 .77 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.825 .175 .825 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.759 .241 .759 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.727 .273 .727 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.698 .302 .698 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.978 .022 .978 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.705 .295 .705 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.793 .207 .793 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.727 .273 .727 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.775 .225 .775 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.823 .177 .823 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.978 .022 .978 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.837 .163 .837 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.802 .198 .802 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.814 .186 .814 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.834 .166 .834 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.771 .229 .771 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.745 .255 .745 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.779 .221 .779 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.786 .214 .786 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.979 .021 .979 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.867 .133 .867 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.816 .184 .816 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.865 .135 .865 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.719 .281 .719 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.817 .183 .817 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.639 .361 .639 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.755 .245 .755 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.753 .247 .753 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.835 .165 .835 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.873 .127 .873 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.702 .298 .702 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.978 .022 .978 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.789 .211 .789 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.78 .22 .78 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.892 .108 .892 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.818 .182 .818 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.779 .221 .779 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.81 .19 .81 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.876 .124 .876 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.71 .29 .71 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.782 .218 .782 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.821 .179 .821 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.908 .092 .908 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.705 .295 .705 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.777 .223 .777 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.818 .182 .818 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.826 .174 .826 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.979 .021 .979 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.74 .26 .74 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.978 .022 .978 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.879 .121 .879 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.852 .148 .852 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.828 .172 .828 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.764 .236 .764 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.721 .279 .721 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.781 .219 .781 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.845 .155 .845 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.844 .156 .844 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.857 .143 .857 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.857 .143 .857 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.805 .195 .805 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.91 .09 .91 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.8 .2 .8 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.765 .235 .765 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.674 .326 .674 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.683 .317 .683 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.769 .231 .769 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.809 .191 .809 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.978 .022 .978 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.861 .139 .861 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.79 .21 .79 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.668 .332 .668 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.836 .164 .836 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.862 .138 .862 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.761 .239 .761 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.978 .022 .978 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.741 .259 .741 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.819 .181 .819 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.857 .143 .857 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.978 .022 .978 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.771 .229 .771 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.797 .203 .797 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.871 .129 .871 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.815 .185 .815 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.757 .243 .757 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.921 .079 .921 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.76 .24 .76 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.871 .129 .871 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.801 .199 .801 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.676 .324 .676 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.66 .34 .66 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.728 .272 .728 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.802 .198 .802 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.881 .119 .881 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.842 .158 .842 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.858 .142 .858 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.838 .162 .838 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.978 .022 .978 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.909 .091 .909 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.778 .222 .778 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.978 .022 .978 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.859 .141 .859 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.859 .141 .859 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.869 .131 .869 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.807 .193 .807 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.883 .117 .883 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.851 .149 .851 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.815 .185 .815 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.979 .021 .979 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.827 .173 .827 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.828 .172 .828 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.978 .022 .978 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.912 .088 .912 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.977 .023 .977 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.978 .022 .978 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.892 .108 .892 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.978 .022 .978 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.817 .183 .817 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.979 .021 .979 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.708 .292 .708 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.802 .198 .802 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.75 .25 .75 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.9 .1 .9 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.885 .115 .885 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.839 .161 .839 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.882 .118 .882 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.844 .156 .844 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.862 .138 .862 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.87 .13 .87 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.812 .188 .812 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.805 .195 .805 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.978 .022 .978 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.794 .206 .794 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.837 .163 .837 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.978 .022 .978 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.872 .128 .872 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.895 .105 .895 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.791 .209 .791 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.864 .136 .864 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.893 .107 .893 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.701 .299 .701 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.86 .14 .86 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.978 .022 .978 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.978 .022 .978 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.979 .021 .979 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.978 .022 .978 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.978 .022 .978 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003og2?Lom`Sg?l0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000om`Sg?oL8m`00_oL8m`00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oL8mcog2?L00?og2?L00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000om`Sg?oL8m`01OoL8m`00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003og2?Lom`Sg006om`Sg003
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000om`Sg?oL8m`02?oL8m`00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oF:MKo0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cog2?L00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omHYeP03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ohAkQon4Nh@05on4Nh@03o`000?oL
8mcog2?L00_og2?L0ol00003omhQgP03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omHYe_oF:MH00ooF:MH00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003ohAkQon4Nh@06
on4Nh@03o`000?oL8mcog2?L00[og2?L00?o0000omhQg_oN8Mh01?oN8Mh00ol0003onPGjooX5nP0:
ooX5nP04o`000?oR7N;ohQgRon8MhP;o00002_oj1OX2o`000003on8Mh_l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeRWFomHYeP05omHYeP03o`000?oj1O[o
nPGj00WonPGj00?o0000om4^dOl000002ooj1OX00ol0003ohAkQon4Nh@06on4Nh@03o`000?oL8mco
g2?L00Wog2?L00?o0000omhQg_oN8Mh01_oN8Mh00ol0003onPGjooX5nP08ooX5nP03o`000?oR7N;o
hQgR00CohQgR0_l00005ooX5nP?o00001?oR7N800ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omHYeP03o`000?oj1O[onPGj00OonPGj0_l00003om4^
d@03o`000?oj1O[onPGj00OonPGj00?o0000on4NhOoQ7^401ooQ7^400ol0003og2?Lom`Sg009om`S
g003o`000?oN8MkogR7N00OogR7N00?o0000ooX5n_oj1OX01Ooj1OX2o`0000WohQgR0_l000000ooj
1O[o0000o`000007on8MhP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omHYe_oF
:MH02?oF:MH00ol0003onPGjooX5nP06ooX5nP03o`000?oA;]7odBkA00?odBkA00?o0000ooX5n_oj
1OX01ooj1OX00ol0003ohAkQon4Nh@08on4Nh@03o`000?oL8mcog2?L00Oog2?L00?o0000omhQg_oN
8Mh02OoN8Mh00ol0003onPGjooX5nP03ooX5nP03o`000?oR7N;ohQgR00_ohQgR00?o0000on8Mh_oR
7N801ooR7N800ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofRGJo`000005ooX5nP;o00002ooF:MH2o`0000KonPGj
00?o0000om4^dOoA;]401OoA;]400ol0003onPGjooX5nP06ooX5nP03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000om`Sg?oL8m`01_oL8m`00ol0003ogR7NomhQgP0;omhQgP05o`000?oj1O[onPGjooX5n_l0
00003_oR7N800ol0003ohQgRon8MhP08on8MhP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oJ9M[ofRGJomXUf_l0
00000ooj1OX00ol0003oeRWFomHYeP0:omHYeP04o`000?oL8mcog2?Lo`0000?onPGj0_l00008om4^
d@03o`000?oj1O[onPGj00KonPGj00?o0000on4NhOoQ7^402OoQ7^400ol0003og2?Lom`Sg005om`S
g003o`000?oN8MkogR7N00cogR7N00?o0000ooX5n_l000003ooR7N800ol0003ohQgRon8MhP08on8M
hP03o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofRGJomXUfP03omXUfP03o`000?oj1O[o000000_o
eRWF0_l00004om`Sg003o`000?oj1O[o000000_odBkA00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
hAkQon4Nh@09on4Nh@03o`000?oL8mcog2?L00Cog2?L00?o0000omhQg_oN8Mh03_oN8Mh00ol0003o
hQgRon8MhP0>on8MhP03o`000?oR7N;ohQgR00WohQgR00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omXUf_oJ9MX0
1?oJ9MX00ol0003oeRWFomHYeP09omHYeP03o`000?oL8mcog2?L00Gog2?L00?o0000om4^dOoA;]40
2_oA;]400ol0003onPGjooX5nP05ooX5nP03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000om`Sg?oL8m`0
0ooL8m`00ol0003ogR7NomhQgP0>omhQgP03o`000?oR7N;ohQgR00gohQgR00?o0000on8Mh_oR7N80
2_oR7N800ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofRGJomXU
fP05omXUfP03o`000?oF:MKoeRWF00OoeRWF0_l00008om`Sg003o`000?oA;]7odBkA00_odBkA00?o
0000ooX5n_oj1OX01?oj1OX00ol0003ohAkQon4Nh@0:on4Nh@04o`000?oL8mcog2?Lom`Sg0?o0000
3ooN8Mh00ol0003ohQgRon8MhP0>on8MhP03o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oJ9M[ofRGJ00OofRGJ00?o0000omHYe_oF:MH01?oF:MH2o`0000_og2?L1?l0
0009om4^d@03o`000?oj1O[onPGj00?onPGj00?o0000on4NhOoQ7^402ooQ7^401?l0003og2?Lo`00
0?l00003om`Sg0;o00003?oN8Mh2o`00013ohQgR00?o0000on8Mh_oR7N802ooR7N800ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003ofRGJ
omXUfP07omXUfP03o`000?oF:MKoeRWF00?oeRWF00?o0000om`Sg?oL8m`02ooL8m`01?l0003ogB;M
omdRgOoM8]d5o`0000GodBkA00?o0000ooX5n_oj1OX00_oj1OX00ol0003ohAkQon4Nh@0<on4Nh@03
o`000?oL8mcog2?L00Gog2?L0_l00008omhQgP;o00000_oG:=L00ol0003ohQgRon8MhP0=on8MhP03
o`000?oR7N;ohQgR00_ohQgR00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003ofRGJomXUfP09omXUfP03o`000?oF:MKoeRWF00;o0000
3OoL8m`00ol0003ogB;MomdRg@07omdRg@Ko00000_oj1OX4o`0000gohAkQ00?o0000om`Sg?oL8m`0
1ooL8m`2o`0000GogR7N00?o0000omLXeooG:=L00ooG:=L00ol0003ohQgRon8MhP0<on8MhP03o`00
0?oR7N;ohQgR00cohQgR00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oJ9M[ofRGJ00WofRGJ00?o
0000omHYe_l000003ooL8m`00ol0003ogB;MomdRg@0<omdRg@?o00001?oP7n03o`0000WohAkQ00?o
0000om`Sg?oL8m`02_oL8m`2o`000003omhQg_l0003o000000OoebSG00?o0000on8Mh_oR7N802ooR
7N800ol0003ohQgRon8MhP0<on8MhP03o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oj1O[onPGj00KonPGj00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000
om`Sg?oL8m`03_oL8m`00ol0003ogB;MomdRg@0=omdRg@03o`000?oP7n3oh1oP00Koh1oP0ol00005
on4Nh@03o`000?oL8mcog2?L00gog2?L00?o0000omLXeooG:=L02?oG:=L00ol0003ohQgRon8MhP09
on8MhP03o`000?oR7N;ohQgR00gohQgR00Co0000ooX5n_oj1O[onPGj1Ol00003onDJi@03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
omXUf_oJ9MX02ooJ9MX2o`0000oog2?L00?o0000omdRgOoM8]d03OoM8]d00ol0003oh1oPon0Oh00:
on0Oh0?o000000?ohAkQo`000?oL8m`03ooL8m`00ol0003oebSGomLXe`09omLXe`03o`000?oR7N;o
hQgR00SohQgR00?o0000on8Mh_oR7N803_oR7N83o`0000SoiA[U00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oJ9M[ofRGJ00SofRGJ0ol000000ooB
;M;o0000om`Sg00>om`Sg003o`000?oM8]gogB;M00gogB;M00?o0000on0Oh?oP7n003OoP7n000ol0
003og2?Lom`Sg00?om`Sg003o`000?oG:=OoebSG00[oebSG2ol0000;on8MhPGo00003?oU6^D00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02_oj1OX01Ol0003ohQgRo`000?oj1O[o0000
00SofRGJ0ol00005om8]dP03o`000?oL8mcog2?L00cog2?L00?o0000omdRgOoM8]d03OoM8]d00ol0
003oh1oPon0Oh00=on0Oh0;o00004?oL8m`00ol0003oebSGomLXe`0:omLXe`03o`000?oI9]WofBKI
00OofBKI00?o0000on8Mh_oR7N800_oR7N87o`0000CoeRWF00?o0000onDJiOoU6^D02_oU6^D00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02Ooj1OX01?l0003ohQgRon8Mh_oR7N82o`00
00GofRGJ0ol00009om8]dP;o00002ooL8m`00ol0003ogB;MomdRg@0=omdRg@03o`000?oP7n3oh1oP
00goh1oP00Co0000onPGj?oX5nSo00003ooL8m`00ol0003oebSGomLXe`09omLXe`03o`000?oI9]Wo
fBKI00WofBKI1?l0000;omHYeP03o`000?oU6^GoiA[U00[oiA[U00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5
nP03o`000?oj1O[onPGj00SonPGj00?o0000on8Mh_oR7N801?oR7N800ol0003ofRGJo`000002o`00
00codRgB00Co0000om/Tfol0003o00002OoL8m`00ol0003ogB;MomdRg@0=omdRg@03o`000?oP7n3o
h1oP00goh1oP00Go0000onPGj?oX5nSoj1OXo`00000=om`Sg003o`000?oG:=OoebSG00[oebSG00?o
0000omTVfOoI9]T02OoI9]T00ol0003oeRWFomHYeP0<omHYeP03o`000?oU6^GoiA[U00[oiA[U00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000on8Mh_oR7N801_oR7N80
0ol0003odRgBom8]dP0<om8]dP03o`000?oK9=_ofbCK00;ofbCK0_l00007om`Sg003o`000?oM8]go
gB;M00cogB;M00?o0000on0Oh?oP7n003OoP7n000ol0003oj1OXonPGj003onPGj003o`000?oL8mco
g2?L00[og2?L00?o0000omLXeooG:=L02_oG:=L00ol0003ofBKIomTVf@09omTVf@03o`000?oF:MKo
eRWF00coeRWF00?o0000onDJiOoU6^D02ooU6^D00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5
n_oj1OX01_oj1OX00ol0003ohQgRon8MhP06on8MhP03o`000?oB;M;odRgB00_odRgB00?o0000om/T
fooK9=/01OoK9=/00ol0003og2?Lom`Sg003om`Sg003o`000?oM8]gogB;M00gogB;M00?o0000on0O
h?oP7n003OoP7n000ol0003oj1OXonPGj004onPGj003o`000?oL8mcog2?L00Wog2?L00?o0000omLX
eooG:=L02OoG:=L00ol0003ofBKIomTVf@0:omTVf@03o`000?oF:MKoeRWF00coeRWF00?o0000onDJ
iOoU6^D02ooU6^D00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
hQgRon8MhP07on8MhP03o`000?oB;M;odRgB00_odRgB00?o0000om/TfooK9=/01_oK9=/2o`0000?o
g2?L00?o0000omdRgOoM8]d03OoM8]d00ol0003oh1oPon0Oh00<on0Oh003o`000?oX5nSoj1OX00Ko
j1OX00?o0000om`Sg?oL8m`02?oL8m`00ol0003oebSGomLXe`09omLXe`03o`000?oI9]WofBKI00[o
fBKI00?o0000omHYe_oF:MH03?oF:MH00ol0003oiA[UonDJi@0;onDJi@03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooX5nP03o`00
0?oj1O[onPGj00ConPGj00?o0000on8Mh_oR7N802?oR7N800ol0003odRgBom8]dP0:om8]dP03o`00
0?oK9=_ofbCK00WofbCK0_l000000ooL8mco0000omdRg@0<omdRg@?o00003_oP7n000ol0003oj1OX
onPGj007onPGj003o`000?oL8mcog2?L00Oog2?L00?o0000omLXeooG:=L02OoG:=L00ol0003ofBKI
omTVf@0;omTVf@03o`000?oF:MKoeRWF00coeRWF00?o0000onDJiOoU6^D02_oU6^D00ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000on8Mh_oR7N802_oR7N800ol0003odRgBom8]
dP09om8]dP03o`000?oK9=_ofbCK00_ofbCK00?o0000omdRgOoM8]d02_oM8]d2o`0000?ogb3O00?o
0000on0Oh?oP7n002_oP7n000ol0003oj1OXonPGj009onPGj003o`000?oL8mcog2?L00Kog2?L00?o
0000omLXeooG:=L02?oG:=L00ol0003ofBKIomTVf@0<omTVf@03o`000?oF:MKoeRWF00coeRWF00?o
0000onDJiOoU6^D02_oU6^D00ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ooj1OX0
0ol0003onPGjooX5nP02ooX5nP03o`000?oR7N;ohQgR00_ohQgR00?o0000om8]d_oB;M802?oB;M80
0ol0003ofbCKom/Tf`0<om/Tf`03o`000?oM8]gogB;M00SogB;M0_l00006omlPg`;o00002_oP7n00
0ol0003oj1OXonPGj00:onPGj003o`000?oL8mcog2?L00Gog2?L00?o0000omLXeooG:=L02?oG:=L0
0ol0003ofBKIomTVf@0<omTVf@03o`000?oF:MKoeRWF00coeRWF00?o0000onDJiOoU6^D02ooU6^D0
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?onPGj00Go0000ooX5n_oj1O[onPGjo`00000=
on8MhP03o`000?oB;M;odRgB00OodRgB00?o0000om/TfooK9=/03_oK9=/00ol0003ogB;MomdRg@04
omdRg@?o00002_oO8=l00ol0003oh1oPon0Oh007on0Oh003o`000?oX5nSoj1OX00_oj1OX00?o0000
om`Sg?oL8m`00ooL8m`00ol0003oebSGomLXe`09omLXe`03o`000?oI9]WofBKI00cofBKI00?o0000
omHYe_oF:MH03?oF:MH00ol0003oiA[UonDJi@0;onDJi@;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003ohQgRon8MhP0<on8MhP03o`000?oB;M;odRgB00OodRgB00?o0000om/TfooK9=/03ooK9=/01?l0
003ogB;MomdRgOoM8]d2o`0000kogb3O0_l00006on0Oh003o`000?oX5nSoj1OX00goj1OX00?o0000
om`Sg?oL8m`00_oL8m`00ol0003oebSGomLXe`08omLXe`03o`000?oI9]WofBKI00cofBKI0ol0000=
omHYeP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00oohQgR00?o0000om8]d_oB;M801_oB;M800ol0003ofbCKom/Tf`0@om/Tf`Co00004_oO8=l00ol0
003oh1oPon0Oh003on0Oh003o`000?oX5nSoj1OX00koj1OX00Go0000om`Sg?oL8mcog2?Lo`000005
omLXe`Oo00003?oI9]T01Ol0003odBkAom4^dOoA;]7o000000coeRWF00?o0000onDJiOoU6^D02?oU
6^D3o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000oohQgR00?o0000om8]d_oB;M801_oB;M800ol0003ofbCKom/Tf`0=
om/Tf`?o000000Coe2_Do`000?l0003o00004ooO8=l2o`0000;oh1oP00?o0000onPGj?oX5nP04?oX
5nP00ol0003og2?Lo`000006o`0000Ooj1OX00?o0000omTVfOoI9]T02?oI9]T00ol0003odBkAom4^
d@03om4^d@;o00002?oF:MH3o`0000KoiA[U1?l00002on@Ki003o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003odRgBo`000?oF:MH3o`0000gohQgR00?o0000om8]d_oB;M801?oB;M800ol0003ofbCKom/T
f`0;om/Tf`?o00000ooD:m@01Ol0003oe2_Do`000?oF:MKo000001Cogb3O00?o0000on0Oh?l00000
4ooX5nP00ol0003oj1OXonPGj00=onPGj003o`000?oI9]WofBKI00GofBKI0_l00008om4^d@03o`00
0?oF:MKoeRWF00Go00000ooH9mP00ol0003oiA[UonDJi@03o`0000Ooi1_T00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oB;M;odRgBo`0000CoeRWF0ol0000:on8MhP03o`000?oB;M;odRgB00?odRgB
00?o0000om/TfooK9=/02OoK9=/3o`0000Goe2_D00Co0000om@[e?oD:mCo00000_oF:MH00ol0003o
gb3OomlPg`0BomlPg`03o`000?oX5nSoj1OX01;oj1OX00?o0000onPGj?oX5nP03_oX5nP00ol0003o
fBKIomTVf@03omTVf@03o`000?oA;]7odBkA00WodBkA0_l00009omPWf0;o00002_oT6n@00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000om8]d_oB;M;odRgBo`000007omHYeP;o00001ooR7N85o`0000;o
dRgB00?o0000om/TfooK9=/01_oK9=/3o`0000Soe2_D00Co0000om@[e?oD:mCo00000ooF:MH00ol0
003ogb3OomlPg`0AomlPg`03o`000?oX5nSoj1OX017oj1OX00?o0000onPGj?oX5nP04?oX5nP01Ol0
003ofBKIomTVfOoI9]Wo000000codBkA00?o0000omPWf?oH9mP02?oH9mP00ol0003oi1_Ton@Ki00:
on@Ki003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CodRgB00?o0000omHYe_oF:MH01ooF:MH3o`00
0004on8Mh_l0003o0000o`0000GofBKI0_l00006om/Tf`?o00002_oD:m@01Ol0003oe2_Dom@[e?oD
:mCo000000CoeRWF00?o0000omlPgooO8=l04?oO8=l00ol0003oj1OXonPGj00AonPGj003o`000?oX
5nSoj1OX017oj1OX00?o0000omTVfOl000003OoA;]400ol0003of2OHomPWf008omPWf003o`000?oT
6nCoi1_T00[oi1_T00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oB;M;odRgB00CodRgB00?o0000
omHYe_oF:MH02_oF:MH00ol0003ofBKIomTVf@08omTVf@03o`000?oK9=_ofbCK00?o00003OoD:m@0
1Ol0003oe2_Dom@[e?oD:mCo000000GoeRWF00?o0000omlPgooO8=l03ooO8=l00ol0003oj1OXonPG
j00AonPGj003o`000?oX5nSoj1OX01;oj1OX00?o0000om4^dOoA;]403?oA;]400ol0003of2OHomPW
f008omPWf003o`000?oT6nCoi1_T00_oi1_T00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000om8]d_oB;M801OoB;M80
0ol0003oeRWFomHYeP0:omHYeP03o`000?oI9]WofBKI00WofBKI0_l0000?om@[e003o`000?oD:mCo
e2_D00;oe2_D00?o0000omHYe_oF:MH01?oF:MH00ol0003ogb3OomlPg`0=omlPg`?o00004OoX5nP0
0ol0003oj1OXonPGj00ConPGj003o`000?oA;]7odBkA00_odBkA00?o0000omPWf?oH9mP02OoH9mP0
0ol0003oi1_Ton@Ki00;on@Ki003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oB;M80
0ol0003oeRWFomHYeP0:omHYeP03o`000?oI9]WofBKI00WofBKI00?o0000om@[e?oD:m@03OoD:m@0
0ol0003oe2_Dom@[e003om@[e003o`000?oF:MKoeRWF00GoeRWF00?o0000omlPgooO8=l02_oO8=l2
o`0000?oj1OX00?o0000onPGj?oX5nP03_oX5nP00ol0003oj1OXonPGj00ConPGj003o`000?oA;]7o
dBkA00_odBkA00?o0000omPWf?oH9mP02OoH9mP00ol0003oi1_Ton@Ki00;on@Ki003o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000om8]d_oB;M801ooB;M82o`0000_oeRWF00?o0000omTV
fOoI9]T02ooI9]T00ol0003oe2_Dom@[e00<om@[e003o`000?oD:mCoe2_D00?oe2_D00?o0000omHY
e_oF:MH01_oF:MH00ol0003ogb3OomlPg`07omlPg`;o00001_oX5nP2o`0000koj1OX00?o0000onPG
j?oX5nP04ooX5nP00ol0003odBkAom4^d@0;om4^d@03o`000?oH9mSof2OH00Wof2OH00?o0000on@K
i?oT6n@03?oT6n@00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009om8]
dP03o`000?nNHIko000000_oeRWF00?o0000omTVfOoI9]T02ooI9]T00ol0003oe2_Dom@[e00;om@[
e003o`000?oD:mCoe2_D00Coe2_D00?o0000omHYe_oF:MH01ooF:MH00ol0003ogb3OomlPg`05omlP
g`03o`000?oX5nSoj1OX00Soj1OX00?o0000onPGj?oX5nP02_oX5nP00ol0003oj1OXonPGj00DonPG
j003o`000?oA;]7odBkA00_odBkA00?o0000omPWf?oH9mP02OoH9mP00ol0003oi1_Ton@Ki00<on@K
i003o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009om8]dP04o`000?nNHIkoWV6No`00
00_oeRWF00?o0000omTVfOoI9]T02ooI9]T00ol0003oe2_Dom@[e00;om@[e003o`000?oD:mCoe2_D
00Coe2_D00?o0000omHYe_oF:MH02?oF:MH00ol0003ogb3OomlPg`02omlPg`;o00003?oX5nP2o`00
00[oj1OX00?o0000onPGj?oX5nP05?oX5nP00ol0003odBkAom4^d@0;om4^d@03o`000?oH9mSof2OH
00Wof2OH00?o0000on@Ki?oT6n@03OoT6n@00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003odRgBom8]dP07om8]dP03
o`000?nNHIkoWV6N00;oWV6N00?o0000omHYe_oF:MH02?oF:MH00ol0003ofBKIomTVf@0<omTVf@03
o`000?oD:mCoe2_D00Woe2_D00?o0000om@[e?oD:m@01OoD:m@00ol0003oeRWFomHYeP09omHYeP04
o`000?oO8=oo0000o`00013oj1OX0_l00008onPGj003o`000?oX5nSoj1OX01Coj1OX0ol0000;om4^
d@03o`000?oH9mSof2OH00Wof2OH00?o0000on@Ki?oT6n@03OoT6n@01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003odRgBom8]dP06om8]dP03o`000?nNHIkoWV6N00?oWV6N00?o0000omHY
e_oF:MH02?oF:MH00ol0003ofBKIomTVf@0;omTVf@;o00002_oD:m@00ol0003oe2_Dom@[e006om@[
e003o`000?oF:MKoeRWF00[oeRWF00?o0000onPGj?oX5nP04_oX5nP00ol0003oj1OXonPGj004onPG
j003o`000?oX5nSoj1OX01Goj1OX00?o0000on@Ki?oT6n@01Ol00005om4^d@03o`000?oH9mSof2OH
00[of2OH00?o0000on@Ki?oT6n@03_oT6n@3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odRgBom8]dP04om8]dP03
o`000?nNHIkoWV6N00CoWV6N00?o0000omHYe_oF:MH01ooF:MH00ol0003ofBKIomTVf@0;omTVf@04
o`000?oK9=_ofbCKo`0000Woe2_D00?o0000om@[e?oD:m@01_oD:m@00ol0003oeRWFomHYeP0:omHY
eP03o`000?oX5nSoj1OX01?oj1OX0_l00003onPGj0Co00005?oX5nP00ol0003oi1_Ton@Ki006on@K
i0Co000000?odBkAo`000?oH9mP02ooH9mP00ol0003oi1_Ton@Ki00>on@Ki003o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003odRgBom8]dP03om8]dP03o`000?nNHIkoWV6N00GoWV6N00?o0000omHYe_oF
:MH01ooF:MH00ol0003ofBKIomTVf@09omTVf@;o00001?oK9=/00ol0003oe2_Dom@[e005om@[e003
o`000?oD:mCoe2_D00Ooe2_D00?o0000omHYe_oF:MH02_oF:MH00ol0003oj1OXonPGj00EonPGj003
o`000?oX5nSo000000CojaC[0ol0000@onPGj003o`000?oT6nCoi1_T00_oi1_T0_l0000<omPWf003
o`000?oT6nCoi1_T00coi1_T0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000om8]d_oB;M800_oB;M800ol0003oWV6N
oiiQWP06oiiQWP03o`000?oF:MKoeRWF00OoeRWF00?o0000omTVfOoI9]T02?oI9]T00ol0003ofbCK
om/Tf`05om/Tf`03o`000?oD:mCoe2_D00Coe2_D00?o0000om@[e?oD:m@01ooD:m@00ol0003oeRWF
omHYeP0:omHYeP03o`000?oX5nSoj1OX01Koj1OX00?o0000on/Djoo[5>/01_o[5>/3o`0000coj1OX
00?o0000on@Ki?oT6n@03OoT6n@00ol0003of2OHomPWf009omPWf0Go00002OoT6n@2o`000003om`S
g?l0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003om8]d_l0003oWV6N00WoWV6N00?o0000omHYe_oF:MH01_oF
:MH00ol0003ofBKIomTVf@07omTVf@03o`000?oK9=_ofbCK00OofbCK00?o0000om@[e?oD:m@00_oD
:m@00ol0003oe2_Dom@[e008om@[e003o`000?oF:MKoeRWF00WoeRWF00?o0000onPGj?oX5nP05ooX
5nP00ol0003ojaC[on/Dj`09on/Dj`?o00002OoX5nP00ol0003oi1_Ton@Ki00>on@Ki0Ko00001?oH
9mP00ol0003obSG:olXebP03olXebPGo00000_oT6n@2o`0000Cog2?L00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o><LkocS7>olhac_l000002onNHIh00ol0003oeRWFomHYeP06omHYeP03o`000?oI
9]WofBKI00GofBKI0_l0000;om/Tf`04o`000?oD:mCoe2_Do`0000_oe2_D00?o0000omHYe_oF:MH0
2OoF:MH00ol0003oj1OXonPGj00FonPGj003o`000?o[5>_ojaC[00gojaC[0ol00005onPGj003o`00
0?oT6nCoi1_T00ooi1_T00?o0000on4NhOoQ7^400ooQ7^44o`0000_obSG:0_l00006om`Sg003o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003ocS7>olhacP02olhacPko00001_oF:MH00ol0003ofBKIomTV
f@05omTVf@03o`000?oK9=_ofbCK00cofbCK00?o0000om@[e?l000002ooD:m@00ol0003oeRWFomHY
eP07omHYeP?o00006?oX5nP00ol0003ojaC[on/Dj`0@on/Dj`?o000000?oj1OXo`000?oT6n@04?oT
6n@00ol0003ohAkQon4Nh@07on4Nh@03o`000?o:=L[obSG:00[obSG:00?o0000om`Sg?oL8m`01OoL
8m`00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olhacP03o`000?ngB;Oo]dRg00_o]dRg0_l00004
omHYeP03o`000?oI9]WofBKI00?ofBKI0_l0000@om/Tf`03o`000?oD:mCoe2_D00[oe2_D00?o0000
omHYe_oF:MH00ooF:MH4o`0000;od2o@00?o0000onPGj?oX5nP05OoX5nP00ol0003ojaC[on/Dj`0D
on/Dj`03o`000?oT6nCoi1_T013oi1_T00?o0000on4NhOoQ7^401ooQ7^400ol0003obSG:olXebP0:
olXebP03o`000?oL8mcog2?L00Gog2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o><LkocS7>
00GocS7>00?o0000okM8]ongB;L03OngB;L6o`0000?ofBKI00?o0000om/TfooK9=/04?oK9=/00ol0
003oe2_Dom@[e00:om@[e003o`000?oF:MKo000000?o00001oo@;m000ol0003oj1OXonPGj00DonPG
j003o`000?o[5>_ojaC[01CojaC[00?o0000on@Ki?oT6n@03ooT6n@00ol0003ohAkQon4Nh@08on4N
h@03o`000?o:=L[obSG:00[obSG:00?o0000om`Sg?oL8m`01OoL8m`00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olhac_o><Lh01_o><Lh00ol0003o]dRgokM8]`0=okM8]`03o`000?oN8MkogR7N00?o
gR7N00?o0000omTVfOl000004ooK9=/4o`0000Woe2_D0_l0000<om0_d003o`000?oX5nSoj1OX01?o
j1OX00?o0000on/Djoo[5>/05Oo[5>/00ol0003oi1_Ton@Ki00>on@Ki003o`000?oQ7^7ohAkQ00So
hAkQ00?o0000olXeb_o:=LX02Oo:=LX00ol0003og2?Lom`Sg007om`Sg003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o><LkocS7>00SocS7>00?o0000okM8]ongB;L02ongB;L00ol0003ogR7NomhQgP05omhQgP03o`00
0?oK9=_ofbCK01;ofbCK00Co0000omHYe_oF:MKoeRWF1Ol00003om@[e003o`000?o@;m3od2o@00go
d2o@0ol0000@onPGj0;o00006?o[5>/00ol0003oi1_Ton@Ki00=on@Ki003o`000?oQ7^7ohAkQ00Wo
hAkQ00?o0000olXeb_o:=LX02Oo:=LX00ol0003og2?Lom`Sg007om`Sg003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_ocS7>00?o0000okM8]ongB;L02_ngB;L00ol0003ogR7NomhQgP06omhQgP03o`00
0?oK9=_ofbCK017ofbCK00?o0000omHYe_oF:MH01ooF:MH3o`00013od2o@00?o0000oll`coo?<<l0
1Ol00009onPGj0;o000000?of2OHo`000?o[5>/05oo[5>/00ol0003oi1_Ton@Ki00=on@Ki003o`00
0?oQ7^7ohAkQ00WohAkQ00?o0000olXeb_o:=LX02?o:=LX2o`0000[og2?L00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oE:]GoeB[E00;oeB[E00?o0000olhac_o><Lh02Oo><Lh00ol0003o]dRgokM8
]`0:okM8]`03o`000?oN8MkogR7N00OogR7N00?o0000om/TfooK9=/03ooK9=/00ol0003oeRWFomHY
eP0:omHYeP03o`000?o@;m3od2o@00god2o@00?o0000oll`coo?<<l01_o?<<l4o`0000Coj1OX00?o
0000omPWf?oH9mP00_oH9mP00ol0003ojaC[on/Dj`0Fon/Dj`03o`000?oT6nCoi1_T00_oi1_T00?o
0000on4NhOoQ7^402ooQ7^400ol0003obSG:olXebP06olXebP03o`000?ncC;?o000000[og2?L00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000olhac_o><Lh02?o><Lh=
o`0000[ogR7N00?o0000om/TfooK9=/03ooK9=/00ol0003oeRWFomHYeP0;omHYeP03o`000?o@;m3o
d2o@00cod2o@00?o0000oll`coo?<<l02_o?<<l4o`0000Gof2OH00?o0000on/Djoo[5>/05_o[5>/0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?oQ7^7ohAkQ00cohAkQ00?o0000olXeb_o:=LX01?o:=LX2
o`0000?o/dbc00?o0000om`Sg?oL8m`02?oL8m`00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omDZ
eOoE:]D00ooE:]D00ol0003ocS7>olhacP07olhacP03o`000?ngB;Oo]dRg00Wo]dRg00?o0000omhQ
g_oN8Mh02OoN8Mh00ol0003ofbCKom/Tf`0=om/Tf`03o`000?oF:MKoeRWF00coeRWF00?o0000om0_
d?o@;m003?o@;m000ol0003occ3?oll`c`0;oll`c`03o`000?o3?<?o000000Kof2OH00?o0000on/D
joo[5>/05_o[5>/00ol0003oi1_Ton@Ki009on@Ki003o`000?oQ7^7ohAkQ00cohAkQ00?o0000olXe
b_o:=LX00oo:=LX00ol0003o/dbcok=</`03ok=</`03o`000?oL8mcog2?L00Sog2?L00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00CoeB[E00?o0000olhac_o><Lh01_o><Lh00ol0003o
]dRgokM8]`08okM8]`03o`000?oN8MkogR7N00_ogR7N00?o0000om/TfooK9=/02?oK9=/4o`0000oo
eRWF00?o0000om0_d?o@;m002oo@;m000ol0003occ3?oll`c`0;oll`c`04o`000?o3?<?o`cc3o`00
00Oof2OH00?o0000on/Djoo[5>/05Oo[5>/00ol0003oi1_Ton@Ki008on@Ki003o`000?oQ7^7ohAkQ
00gohAkQ00?o0000olXeb_o:=LX00_o:=LX00ol0003o/dbcok=</`05ok=</`03o`000?oL8mcog2?L
00Oog2?L00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00GoeB[E00?o0000olhac_o>
<Lh01Oo><Lh00ol0003o]dRgokM8]`08okM8]`03o`000?oN8MkogR7N00_ogR7N00?o0000om/TfooK
9=/00ooK9=/5o`0000?oeRWF00?o0000omHYe_oF:MH03_oF:MH00ol0003od2o@om0_d00:om0_d003
o`000?o?<<oocc3?00[occ3?00Go0000ol<l`oo3?<?o`cc3o`000007omPWf003o`000?o[5>_ojaC[
01GojaC[00?o0000on@Ki?oT6n@02?oT6n@00ol0003ohAkQon4Nh@0=on4Nh@03o`000?o:=L[obSG:
00;o00002?ncC;<00ol0003og2?Lom`Sg008om`Sg0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oeB[EomDZe@05omDZe@03o`000?o><LkocS7>00Go
cS7>00?o0000okM8]ongB;L02?ngB;L00ol0003ogR7NomhQgP0<omhQgPGo00002OoF:MH00ol0003o
eRWFomHYeP0<omHYeP;o00003?o@;m000ol0003occ3?oll`c`0:oll`c`05o`000?o3?<?o`cc3ol<l
`ol000002?oH9mP00ol0003ojaC[on/Dj`0Don/Dj`?o00001ooT6n@00ol0003ohAkQon4Nh@0>on4N
h@03o`000?o:=L[o000000_o/dbc00?o0000om`Sg?oL8m`01_oL8m`00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000omDZeOoE:]D01OoE:]D00ol0003ocS7>olhacP04olhacP03o`000?ngB;Oo]dRg00Oo
]dRg00?o0000omhQg_oN8Mh03?oN8Mh01?l0003ofbCKom/Tfol0000;omHYeP03o`000?oF:MKoeRWF
00_oeRWF00Co0000ol8m`_o2?L;o00002_o@;m000ol0003occ3?oll`c`0:oll`c`03o`000?o3?<?o
`cc300;o`cc300?o0000omPWf?oH9mP01_oH9mP00ol0003ojaC[on/Dj`0Aon/Dj`?o00000ooK9=/0
0ol0003oi1_Ton@Ki004on@Ki003o`000?oQ7^7ohAkQ00gohAkQ1?l0000;ok=</`03o`000?oL8mco
g2?L00Gog2?L00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oE:]GoeB[E00KoeB[E00Co0000olha
c_o><LkocS7>1?l00008okM8]`03o`000?oN8MkogR7N00_ogR7N00?o0000om/TfooK9=/00_oK9=/0
0ol0003oeRWFomHYeP08omHYeP03o`000?oF:MKoeRWF00[oeRWF00?o0000ol8m`_o2?L800_o2?L80
0ol0003od2o@om0_d003om0_d0Go00002oo?<<l00ol0003o`cc3ol<l``03ol<l``03o`000?oH9mSo
f2OH00Oof2OH00?o0000on/Djoo[5>/03_o[5>/2o`0000OofbCK00?o0000on@Ki?oT6n@00_oT6n@0
0ol0003ohAkQon4Nh@0=on4Nh@03o`000?o;=<_obcC;00;obcC;00?o0000ok=</oncC;<02OncC;<0
0ol0003og2?Lom`Sg003om`Sg003o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oeB[EomDZe@07omDZ
e@?o00001?oD:m@00ol0003o]dRgokM8]`05okM8]`03o`000?oN8MkogR7N00[ogR7N00?o0000om/T
fooK9=/00ooK9=/00ol0003oeRWFomHYeP09omHYeP03o`000?oF:MKoeRWF00SoeRWF00?o0000ol8m
`_o2?L801?o2?L85o`0000CoXebS00?o0000oll`coo?<<l02Oo?<<l00ol0003o`cc3ol<l``03ol<l
``03o`000?oH9mSof2OH00Sof2OH00?o0000on/Djoo[5>/02_o[5>/3o`0000[ofbCK00Go0000on@K
i?oT6nCoi1_To`00000>on4Nh@03o`000?o;=<_obcC;00CobcC;0_l00009ok=</`03o`000?oL8mco
g2?L00;og2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oE:]GoeB[E00OoeB[E00?o0000om@[
e?oD:m@01OoD:m@00ol0003o]dRgokM8]`03okM8]`03o`000?oN8MkogR7N00[ogR7N00?o0000om/T
fooK9=/01?oK9=/00ol0003oeRWFomHYeP09omHYeP03o`000?oF:MKoeRWF00OoeRWF00?o0000ol8m
`_o2?L801Oo2?L800ol0003oXebSoj=LX`07oj=LX`03o`000?o?<<oocc3?00Oocc3?00?o0000ol<l
`oo3?<<01?o3?<<00ol0003of2OHomPWf008omPWf003o`000?o[5>_ojaC[00SojaC[0_l0000>om/T
f`Co00003?oQ7^42o`0000WobcC;00?o0000ok=</oncC;<01oncC;<01?l0003og2?Lom`Sg?l0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000omDZeOoE:]D01OoE:]D00ol0003oe2_Dom@[e007om@[e0;o00000ongB;L00ol0
003ogR7NomhQgP09omhQgP03o`000?oK9=_ofbCK00KofbCK00?o0000omHYe_oF:MH02OoF:MH00ol0
003oeRWFomHYeP05omHYeP03o`000?o2?L;o`Sg200Ko`Sg200?o0000oj=LXonSG:<02?nSG:<00ol0
003occ3?oll`c`06oll`c`03o`000?o3?<?o`cc300Co`cc300?o0000omPWf?oH9mP02OoH9mP4o`00
00?ojaC[0ol0000@om/Tf`05o`000?oY5^WojAKYonTFjOl000002_oQ7^400ol0003obcC;ol/db`0:
ol/db`Ko00000oncC;<00ol0003og2?Lo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000omDZeOoE:]D01?oE:]D00ol0
003oe2_Dom@[e00:om@[e004o`000?ngB;Oo]dRgo`0000[ogR7N00?o0000om/TfooK9=/01ooK9=/0
0ol0003oeRWFomHYeP09omHYeP03o`000?oF:MKoeRWF00CoeRWF00?o0000ol8m`_o2?L801oo2?L80
0ol0003oXebSoj=LX`08oj=LX`;o00001_o?<<l00ol0003o`cc3ol<l``05ol<l``03o`000?oH9mSo
f2OH00Wof2OH00Co0000om0_d?o@;m3od2o@0ol0000Bom/Tf`03o`000?oY5^WojAKY00?ojAKY0_l0
0006on4Nh@;o00003Oo;=</00ol0003ogB;MomdRg@03omdRg@Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000omDZeOoE:]D00ooE:]D0
0ol0003oe2_Dom@[e00<om@[e0;o00002_oN8Mh00ol0003ofbCKom/Tf`08om/Tf`03o`000?oF:MKo
eRWF00[oeRWF00?o0000omHYe_oF:MH00_oF:MH00ol0003o`Sg2ol8m`P08ol8m`P03o`000?nSG:?o
XebS00KoXebS0_l00002ol0o`003o`000?o?<<oocc3?00;occ3?00?o0000ol<l`oo3?<<01_o3?<<0
0ol0003of2OHomPWf008omPWf003o`000?o@;m3od2o@00Cod2o@00?o0000om/TfooK9=/03ooK9=/0
0ol0003ojAKYonTFj@06onTFj@;o00000ooQ7^400ol0003obcC;ol/db`0=ol/db`03o`000?oM8]go
gB;M00OogB;M0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003oeB[EomDZe@02omDZe@03o`000?oD:mCoe2_D
00koe2_D00?o0000omhQg_oN8Mh01ooN8Mh00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oF:MKoeRWF
00WoeRWF00Go0000omHYe_oF:MKoeRWFo`00000;ol8m`P03o`000?nSG:?oXebS00CoXebS0_l00005
ol0o`005o`000?o?<<oocc3?oll`col000002?o3?<<00ol0003of2OHomPWf008omPWf003o`000?o@
;m3od2o@00God2o@00?o0000om/TfooK9=/03_oK9=/00ol0003ojAKYonTFj@08onTFj@03o`000?oQ
7^7o000000oobcC;00?o0000omdRgOoM8]d02?oM8]d01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oE:]GoeB[Eo`00017oe2_D00?o0000omhQg_oN8Mh01_oN8Mh00ol0003ofbCK
om/Tf`0;om/Tf`03o`000?oF:MKoeRWF00WoeRWF00Co0000omHYe_oF:MKo00003?o2?L800ol0003o
XebSoj=LX`02oj=LX`;o00002?o0?l000ol0003occ3?o`000009ol<l``03o`000?oH9mSof2OH00So
f2OH00?o0000om0_d?o@;m001Oo@;m000ol0003ofbCKom/Tf`0=om/Tf`03o`000?oY5^WojAKY00[o
jAKY00?o0000ol/dboo;=</03_o;=</00ol0003ogB;MomdRg@07omdRg@03o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000Bom@[e003o`00
0?oN8MkogR7N00CogR7N00?o0000om/TfooK9=/03?oK9=/00ol0003oeRWFomHYeP0:omHYeP?o0000
3?o2?L800ol0003oXebSoj=LX`02o`0000_o`3o000?o0000ol<l`oo3?<<02?o3?<<00ol0003of2OH
omPWf007omPWf003o`000?o@;m3od2o@00Ood2o@00?o0000om/TfooK9=/03?oK9=/00ol0003ojAKY
onTFj@0;onTFj@;o00003_o;=</00ol0003ogB;MomdRg@07omdRg@03o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on<LhooS7><00ooS7><00ol0003oe2_Dom@[e00?om@[e0?o00000ooN
8Mh00ol0003ofbCKom/Tf`0>om/Tf`03o`000?oF:MKoeRWF00SoeRWF00Co0000olHia_o6>LKoaSW6
0_l0000:ol8m`P?o00003Oo0?l000ol0003o`cc3ol<l``08ol<l``03o`000?oH9mSof2OH00Oof2OH
00?o0000om0_d?o@;m001oo@;m000ol0003ofbCKom/Tf`0;om/Tf`03o`000?oY5^WojAKY00cojAKY
00?o0000olhac_l000000_l0000:ol/db`03o`000?oM8]gogB;M00SogB;M00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003ohacSon<Lh`04on<Lh`03o`000?oD:mCoe2_D00coe2_D0_l0
0003om</d`03o`000?oN8Mko0000017ofbCK00?o0000omHYe_oF:MH01ooF:MH00ol0003oaSW6olHi
aP04olHiaP;o00002?o2?L800ol0003o`3o0ol0o`00>ol0o`0;o00002?o3?<<00ol0003of2OHomPW
f006omPWf003o`000?o@;m3od2o@00Wod2o@00?o0000om/TfooK9=/02OoK9=/00ol0003ojAKYonTF
j@0=onTFj@03o`000?o><LkocS7>00;ocS7>0ol00007ol/db`03o`000?oM8]gogB;M00OogB;M00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ohacSon<Lh`05on<Lh`03o`000?oD:mCo
e2_D00Woe2_D0_l00006om</d`03o`000?oK9=_ofbCK013ofbCK00?o0000omHYe_oF:MH01_oF:MH0
0ol0003oaSW6olHiaP07olHiaP03o`000?o2?L;o`Sg200Co`Sg20ol0000>ol0o`003o`000?ndBkCo
]4^d00?o00001Oo3?<<00ol0003of2OHomPWf006omPWf003o`000?o@;m3od2o@00[od2o@00?o0000
om/TfooK9=/02?oK9=/00ol0003ojAKYonTFj@0=onTFj@03o`000?o><LkocS7>00GocS7>0ol00004
ol/db`03o`000?oM8]gogB;M00OogB;M00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ohacSon<Lh`06on<Lh`03o`000?oD:mCoe2_D00Goe2_D0ol00008om</d`03o`000?oK9=_ofbCK
017ofbCK00Co0000omHYe_oF:MKoeRWF1?l0000;olHiaP;o000000Co`Sg2o`000?l0003o00000oo=
</d2o`0000_o`3o000?o0000okA;]?ndBk@01?ndBk@2o`0000?o`cc300?o0000omPWf?oH9mP01_oH
9mP00ol0003od2o@om0_d00:om0_d003o`000?oK9=_ofbCK00OofbCK00?o0000onTFjOoY5^T03_oY
5^T00ol0003ocS7>olhacP08olhacPCo00002_oM8]d00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003ohacSon<Lh`07on<Lh`03o`000?oD:mCoe2_D00;oe2_D0_l0000<om</d`03o`000?oK9=_o
fbCK013ofbCK1?l00003om0_d003o`000?o6>LKoaSW600_oaSW600?o0000oldbcOo=</d01_o=</d0
0ol0003o`3o0ol0o`007ol0o`003o`000?ndBkCo]4^d00Oo]4^d3?l0000>om0_d003o`000?oK9=_o
fbCK00KofbCK00?o0000onTFjOoY5^T03_oY5^T00ol0003ocS7>olhacP0;olhacP03o`000?oM8]go
gB;M00OogB;M00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oS7>?ohacS00WohacS00Co0000om@[
e?l0003o00003_oC;=<00ol0003ofbCKom/Tf`0?om/Tf`03o`000?o@;m3od2o@00Kod2o@00?o0000
olHia_o6>LH02_o6>LH00ol0003ocC;=oldbc@07oldbc@;o00001_o0?l000ol0003o]4^dokA;]008
okA;]003o`000?oK9=_ofbCK00SofbCK00?o0000om0_d?o@;m003?o@;m000ol0003ofbCKom/Tf`05
om/Tf`03o`000?oY5^WojAKY00oojAKY0_l0000=olhacP03o`000?oM8]gogB;M00KogB;M00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oS7>?ohacS00[ohacS00?o0000om</dooC;=<03_oC;=<00ol0
003ofbCKom/Tf`0>om/Tf`03o`000?o@;m3od2o@00Ood2o@00?o0000olHia_o6>LH02_o6>LH00ol0
003ocC;=oldbc@09oldbc@;o00000oo0?l000ol0003o]4^dokA;]009okA;]003o`000?oK9=_ofbCK
00WofbCK00?o0000om0_d?o@;m002_o@;m04o`0000CofbCK00?o0000onTFjOoY5^T04?oY5^T01?l0
003occ3?o`000?l0000<olhacP03o`000?oM8]gogB;M00GogB;M00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?oS7>?ohacS00[ohacS00?o0000om</dooC;=<03ooC;=<@o`0000[od2o@00?o0000olHi
a_o6>LH02Oo6>LH00ol0003o^TFjo`00000<oldbc@05o`000?o0?l3o0000okE:]Ol000002_ndBk@0
0ol0003ofbCKom/Tf`09om/Tf`03o`000?o@;m3od2o@00Ood2o@0ol00004omhQgP?o000000?ofbCK
o`000?oY5^T04OoY5^T01?l0003occ3?oll`coo?<<l2o`0000_ocS7>00?o0000omdRgOoM8]d00ooM
8]d00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000on<LhooS7><02_oS7><00ol0003odbcCom</d`0?
om</d`03o`000?oN8MkogR7N00cogR7N00?o0000om0_d?o@;m002Oo@;m000ol0003oaSW6olHiaP07
olHiaP04o`000?njAK[o^TFjo`0000gocC;=00Go0000okE:]OneB[Go]DZeo`000009okA;]003o`00
0?oK9=_ofbCK00[ofbCK00?o0000om0_d?o@;m000oo@;m03o`0000[ogR7N00?o0000onTFjOoY5^T0
4?oY5^T00ol0003occ3?oll`c`04oll`c`;o00002_o><Lh00ol0003ogB;MomdRg@04o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000cohacS00?o0000om</dooC;=<03ooC;=<00ol0003ogR7NomhQgP0<omhQgP03o`000?o@
;m3od2o@00Wod2o@00?o0000olHia_o6>LH01_o6>LH00ol0003o^TFjokY5^P02okY5^P03o`000?o=
</gocC;=00[ocC;=00?o0000okE:]OneB[D00_neB[D00ol0003o]4^dokA;]006okA;]003o`000?oK
9=_ofbCK00[ofbCK00?o0000om0_d?o@;m000ol0000=omhQgP03o`000?oY5^WojAKY013ojAKY00?o
0000oll`coo?<<l01_o?<<l2o`0000WocS7>0_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000on<LhooS7><02_oS7><00ol0003odbcCom</d`0=om</d`?o00003ooN8Mh0
0ol0003od2o@om0_d008om0_d003o`000?o6>LKoaSW600GoaSW600?o0000okY5^_njAKX00onjAKX0
0ol0003ocC;=oldbc@0:oldbc@03o`000?neB[Go]DZe00?o]DZe00?o0000okA;]?ndBk@01OndBk@0
0ol0003ofbCKom/Tf`0;om/Tf`;o00004OoN8Mh00ol0003ojAKYonTFj@0?onTFj@03o`000?o?<<oo
cc3?00Socc3?0_l00007olhacP03o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000on<LhooS7><02?oS7><00ol0003odbcCom</d`09om</d`Go00000_o=</d00ol0
003ogR7NomhQgP0=omhQgP03o`000?o@;m3od2o@00Wod2o@00?o0000olHia_o6>LH01?o6>LH00ol0
003o^TFjokY5^P04okY5^P03o`000?o=</gocC;=00SocC;=00?o0000okE:]OneB[D01OneB[D00ol0
003o]4^dokA;]004okA;]003o`000?oK9=_ofbCK00_ofbCK00?o0000omhQg_oN8Mh04?oN8Mh00ol0
003ojAKYonTFj@0?onTFj@03o`000?o?<<oocc3?00[occ3?0_l00004olhacP03o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003ohacSon<Lh`07on<Lh`03o`000?oC;=?odbcC00CodbcC1Ol00007oldbc@03
o`000?oN8MkogR7N00gogR7N00?o0000om0_d?o@;m002Oo@;m000ol0003oaSW6olHiaP03olHiaP03
o`000?njAK[o^TFj00Go^TFj00?o0000oldbcOo=</d02?o=</d00ol0003o]DZeokE:]@06okE:]@03
o`000?ndBkCo]4^d00?o]4^d00?o0000om/TfooK9=/02ooK9=/00ol0003ogR7NomhQgP0@omhQgP03
o`000?oY5^WojAKY00oojAKY00?o0000oll`coo?<<l03?o?<<l2o`000003olhac_l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oS7>?ohacS00OohacS00?o0000om</dol00000
1?l0000<oldbc@03o`000?oN8MkogR7N00kogR7N00?o0000om0_d?o@;m002?o@;m000ol0003oaSW6
olHiaP02olHiaP03o`000?njAK[o^TFj00Oo^TFj00?o0000oldbcOo=</d01oo=</d00ol0003o]DZe
okE:]@07okE:]@03o`000?ndBkCo]4^d00;o]4^d00?o0000om/TfooK9=/02ooK9=/00ol0003ogR7N
omhQgP0AomhQgP03o`000?oY5^WojAKY00gojAKY00?o0000oll`coo?<<l03oo?<<l00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on<LhooS7><01OoS7><3o`00017ocC;=00?o0000omhQg_oN8Mh03_oN
8Mh00ol0003od2o@om0_d009om0_d004o`000?o6>LKoaSW6o`0000[o^TFj00?o0000oldbcOo=</d0
1oo=</d00ol0003o]DZeokE:]@08okE:]@05o`000?ndBkCo]4^dokA;]?l000003OoK9=/00ol0003o
gR7NomhQgP0AomhQgP?o00003OoY5^T00ol0003occ3?oll`c`0?oll`c`03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_oS7><2o`0000;obcC;00?o0000oldbcOo=</d03oo=</d00ol0003o
gR7NomhQgP0>omhQgP03o`000?o@;m3od2o@00Sod2o@1Ol0000;okY5^P03o`000?o=</gocC;=00Ko
cC;=00?o0000okE:]OneB[D02OneB[D01?l0003o]4^dokA;]?l0000=om/Tf`03o`000?oN8MkogR7N
017ogR7N00?o0000olhac_o><Lh00ol0000:onTFj@Co00003Oo?<<l00ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000omPWf?oH9mSof2OH0_l00005ol/db`03o`000?o=</gocC;=00kocC;=00?o0000omhQ
g_oN8Mh03_oN8Mh00ol0003od2o@om0_d007om0_d003o`000?o@;m3od2o@00?od2o@00?o0000okY5
^_njAKX02?njAKX00ol0003ocC;=oldbc@05oldbc@03o`000?neB[Go]DZe00[o]DZe1Ol0000<om/T
f`03o`000?oN8MkogR7N013ogR7N00?o0000olhac_o><Lh01?o><Lh3o`0000KojAKY00?o0000om`S
g?oL8m`00_oL8m`5o`0000Socc3?00?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oH9mSof2OH00?o
f2OH00?o0000ol/dboo;=</01?o;=</00ol0003ocC;=oldbc@0=oldbc@03o`000?oN8MkogR7N00oo
gR7N00?o0000om0_d?o@;m001?o@;m02o`0000Ood2o@00?o0000okY5^_njAKX01onjAKXEo`0000Go
_D:m00?o0000om/TfooK9=/02?oK9=/3o`00013ogR7N00?o0000olhac_o><Lh02?o><Lh3o`0000;o
jAKY00?o0000om`Sg?oL8m`02?oL8m`5o`0000?occ3?00?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oH9mSof2OH00Cof2OH00?o0000ol/dboo;=</01Oo;=</00ol0003ocC;=oldbc@0;oldbc@Co0000
3ooN8Mh00ol0003od2o@om0_d003om0_d003o`000?o@;m3od2o@00Sod2o@00?o0000okY5^_njAKX0
1?njAKX2o`0000Sod2o@00?o0000olPgb?o8=lP02?o8=lP00ol0003o_D:moke2_@05oke2_@;o0000
1_oK9=/2o`0000?oeRWF00?o0000omhQg_oN8Mh03?oN8Mh00ol0003ocS7>olhacP0<olhacP;o0000
4?oL8m`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003of2OHomPWf005omPWf003o`000?o;=<_obcC;00KobcC;00?o
0000oldbcOo=</d02Oo=</d00ol0003o^dBko`000002om0_d0?o00003?oN8Mh01?l0003od2o@om0_
d?o@;m02o`0000cod2o@00?o0000okY5^_njAKX00_njAKX00ol0003od2o@om0_d008om0_d003o`00
0?o8=lSob3O800Sob3O800?o0000oke2_Onm@[d01onm@[d00ol0003ofbCKom/Tf`02om/Tf`03o`00
0?oF:MKoeRWF00CoeRWF0_l0000;omhQgP03o`000?o><LkocS7>00cocS7>00?o0000om</dol00000
4_oL8m`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003of2OHomPWf006omPWf003o`000?o;=<_obcC;00OobcC;00?o
0000oldbcOo=</d01_o=</d2o`0000;o^dBk00?o0000om0_d?o@;m000oo@;m03o`0000[ogR7N00?o
0000om0_d?l000003oo@;m001?l0003o^TFjo`000?l0000;om0_d003o`000?o8=lSob3O800Sob3O8
00?o0000oke2_Onm@[d02?nm@[d01?l0003ofbCKo`000?l00009omHYeP03o`000?oN8MkogR7N00Oo
gR7N00?o0000olhac_o><Lh03?o><Lh01?l0003odbcCom</dol0000Com`Sg003o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000omPWf?oH9mP01ooH9mP00ol0003obcC;ol/db`08ol/db`03o`000?o=</gocC;=00Co
cC;=00?o0000ok]4^onkA;/00onkA;/00ol0003od2o@om0_d005om0_d0?o00001_oN8Mh4o`00013o
d2o@00?o0000om0_d?o@;m003?o@;m000ol0003ob3O8olPgb007olPgb003o`000?nm@[go_D:m00Wo
_D:m00?o0000omHYe_oF:MH02_oF:MH2o`0000KogR7N00?o0000olhac_o><Lh03?o><Lh00ol0003o
dbcCom</d`02om</d`03o`000?oL8mcog2?L00oog2?L00?o0000omHYe_l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003of2OHomPWf008omPWf003o`000?o;=<_obcC;00WobcC;00Co0000oldbcOo=</go
cC;=0_l00006ok]4^`03o`000?o@;m3od2o@00Sod2o@0ol000000ooN8Mko0000o`000004om@[e003
o`000?o@;m3od2o@00god2o@00?o0000om0_d?o@;m003?o@;m000ol0003ob3O8olPgb007olPgb003
o`000?nm@[go_D:m00Wo_D:m00?o0000omHYe_oF:MH03?oF:MH00ol0003ogR7NomhQgP03o`0000ko
cS7>00?o0000om</dooC;=<00ooC;=<00ol0003og2?Lom`Sg00>om`Sg005o`000?oF:MKoeRWFomHY
e_l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003of2OHomPWf009omPWf003o`000?o;=<_obcC;00[o
bcC;00?o0000oldbcOl000002?nkA;/00ol0003od2o@om0_d00;om0_d003o`000?oD:mCoe2_D00Go
e2_D00?o0000om0_d?o@;m003?o@;m000ol0003od2o@om0_d00<om0_d003o`000?o8=lSob3O800Oo
b3O800?o0000oke2_Onm@[d02?nm@[d2o`0000ooeRWF0_l00002omHYeP03o`000?o><LkocS7>00_o
cS7>00?o0000om</dooC;=<01?oC;=<00ol0003og2?Lom`Sg00=om`Sg003o`000?oF:MKoeRWF00?o
eRWF00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omPWf003o`000?o;=<_obcC;00_obcC;00?o0000ok]4^onkA;/0
1onkA;/00ol0003od2o@om0_d00;om0_d003o`000?oD:mCoe2_D00Koe2_D00?o0000om0_d?o@;m00
2oo@;m02o`0000god2o@00?o0000olPgb?o8=lP01oo8=lP00ol0003o_D:moke2_@07oke2_@04o`00
0?o3?<?o`cc3o`0000koeRWF00?o0000omHYe_oF:MH00_oF:MH00ol0003ocS7>olhacP09olhacP03
o`000?oC;=?odbcC00KodbcC00?o0000om`Sg?oL8m`02ooL8m`00ol0003oeRWFomHYeP05omHYeP04
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000Sof2OH00?o0000ol/dboo;=</02_o;=</2o`0000Wo
^dBk00?o0000om0_d?o@;m002oo@;m000ol0003oe2_Dom@[e007om@[e003o`000?o@;m3od2o@00Wo
d2o@00Co0000okA;]?ndBkCo00003?o@;m000ol0003ob3O8olPgb007olPgb003o`000?nm@[go_D:m
00Ko_D:m00Go0000ol<l`oo3?<?o`cc3o`00000>omHYeP03o`000?oF:MKoeRWF00?oeRWF00?o0000
olhac_o><Lh01oo><Lh00ol0003odbcCom</d`07om</d`03o`000?oL8mcog2?L00[og2?L00?o0000
omHYe_oF:MH01ooF:MH00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006omPWf003o`000?o;=<_obcC;
00WobcC;00Co0000okY5^_njAK[o00002OnkA;/00ol0003od2o@om0_d009om0_d003o`000?oD:mCo
e2_D00Woe2_D00?o0000om0_d?o@;m001oo@;m000ol0003o]4^dokA;]002okA;]003o`000?o@;m3o
d2o@00Wod2o@00?o0000olPgb?o8=lP01oo8=lP00ol0003o_D:moke2_@05oke2_@03o`000?o3?<?o
`cc300?o`cc300?o0000omHYe_oF:MH02_oF:MH00ol0003oeRWFomHYeP05omHYeP03o`000?o><Lko
cS7>00GocS7>00?o0000om</dooC;=<02?oC;=<00ol0003og2?Lom`Sg009om`Sg003o`000?oF:MKo
eRWF00SoeRWF00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oH9mP3o`0000WobcC;00?o0000okY5
^_njAKX00_njAKX00ol0003o^dBkok]4^`06ok]4^`03o`000?o@;m3od2o@00Wod2o@00?o0000om@[
e?oD:m@02_oD:m@00ol0003od2o@om0_d005om0_d003o`000?ndBkCo]4^d00Co]4^d00?o0000om0_
d?o@;m002?o@;m000ol0003ob3O8olPgb007olPgb003o`000?nm@[go_D:m00Co_D:m00?o0000ol<l
`oo3?<<01?o3?<<00ol0003oeRWFomHYeP0:omHYeP03o`000?oF:MKoeRWF00KoeRWF00?o0000olha
c_o><Lh00oo><Lh00ol0003odbcCom</d`09om</d`03o`000?oL8mcog2?L00Sog2?L00?o0000omHY
e_oF:MH02OoF:MH00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003om/Tf`?o00001Oo;=</00ol0003o
^TFjokY5^P03okY5^P03o`000?nkA;_o^dBk00Ko^dBk00?o0000om0_d?o@;m002Oo@;m000ol0003o
e2_Dom@[e00;om@[e003o`000?o@;m3od2o@00?od2o@00?o0000okA;]?ndBk@01_ndBk@00ol0003o
d2o@om0_d008om0_d003o`000?o8=lSob3O800Kob3O800?o0000oke2_Onm@[d00_nm@[d2o`0000So
`cc300?o0000omHYe_oF:MH02OoF:MH00ol0003oeRWFomHYeP07omHYeP05o`000?o><LkocS7>olha
c_l000003OoC;=<00ol0003og2?Lom`Sg006om`Sg003o`000?oF:MKoeRWF00[oeRWF00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oK9=_ofbCK00GofbCK0ol000000oo;=<_o0000okY5^P06okY5^P03
o`000?nkA;_o^dBk00Go^dBk00?o0000om0_d?o@;m002Oo@;m000ol0003oe2_Dom@[e00<om@[e005
o`000?o@;m3od2o@om0_d?l000002_ndBk@00ol0003od2o@om0_d007om0_d003o`000?o8=lSob3O8
00Kob3O800?o0000oke2_Ol000000_l000000ooJ9M[o0000ol<l``07ol<l``03o`000?oF:MKoeRWF
00SoeRWF00?o0000omHYe_oF:MH02OoF:MH00ol0003ocS7>o`00000=om</d`Co00001OoL8m`00ol0
003oeRWFomHYeP0;omHYeP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofbCKom/Tf`08om/Tf`03
o`000?njAK[o^TFj00Oo^TFj00?o0000ok]4^onkA;/01?nkA;/00ol0003od2o@om0_d009om0_d003
o`000?oD:mCoe2_D00goe2_D00?o0000om0_d?l000003?ndBk@:o`0000Oob3O80ol00005omXUfP03
o`000?o3?<?o`cc300Ko`cc300?o0000omHYe_oF:MH01ooF:MH00ol0003oeRWFomHYeP0:omHYeP03
o`000?oC;=?odbcC00_odbcC00?o0000oldbcOo=</d00_o=</d3o`000003om`Sg?l0003oeRWF00_o
eRWF0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000om/TfooK9=/02OoK9=/00ol0003o^TFjokY5^P07okY5^P03o`00
0?nkA;_o^dBk00Go^dBk00?o0000om0_d?o@;m001oo@;m000ol0003oe2_Dom@[e00?om@[e0;o0000
2ondBk@00ol0003oeB[EomDZe@07omDZe@03o`000?o8=lSob3O800;ob3O80ol00008omXUfP03o`00
0?o3?<?o`cc300Ko`cc300?o0000omHYe_oF:MH01ooF:MH00ol0003oeRWFomHYeP0:omHYeP03o`00
0?oC;=?odbcC00[odbcC00?o0000oldbcOo=</d01_o=</d00ol0003oeRWFomHYeP08omHYeP?o0000
0_oO8=l00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000om/TfooK9=/02OoK9=/00ol0003o^TFjokY5
^P08okY5^P03o`000?nkA;_o^dBk00Co^dBk00?o0000om0_d?o@;m001oo@;m000ol0003oe2_Dom@[
e00>om@[e004o`000?nn@Kko_T6no`0000Wo]4^d00?o0000omDZeOoE:]D02OoE:]D01?l0003ob3O8
o`000?l0000<omXUfP03o`000?o3?<?o`cc300Ko`cc300?o0000omHYe_oF:MH01_oF:MH00ol0003o
eRWFomHYeP0;omHYeP03o`000?oC;=?odbcC00OodbcC0_l00009oldbc@03o`000?oF:MKoeRWF00Co
eRWF1?l00006omlPg`03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003ofbCKom/Tf`09om/Tf`03o`00
0?njAK[o^TFj00So^TFj00?o0000ok]4^onkA;/00onkA;/>o`0000goe2_D00?o0000oki1__nn@Kh0
0_nn@Kh00ol0003o]4^dokA;]005okA;]003o`000?oE:]GoeB[E00_oeB[E00?o0000omXUf_oJ9MX0
3?oJ9MX00ol0003o`cc3ol<l``06ol<l``03o`000?oF:MKoeRWF00GoeRWF00?o0000omHYe_oF:MH0
3?oF:MH00ol0003odbcCom</d`06om</d`03o`000?o=</gocC;=00[ocC;=00?o0000omHYe_oF:MH0
0ol0000:omlPg`?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oK9=_ofbCK00_ofbCK00?o0000okY5^_njAKX02?nj
AKX01Ol0003o^dBkok]4^onkA;_o000000_obSG:00?o0000ojEJYOnUFZD00ol00009om@[e003o`00
0?nn@Kko_T6n00Co_T6n00?o0000okA;]?ndBk@00ondBk@00ol0003oeB[EomDZe@0<omDZe@03o`00
0?oJ9M[ofRGJ00gofRGJ00?o0000ol<l`oo3?<<01_o3?<<00ol0003oeRWFomHYeP03omHYeP?o0000
3OoF:MH00ol0003odbcCom</d`05om</d`03o`000?o=</gocC;=00cocC;=0_l0000=omlPg`03o`00
0?oj1O[onPGj00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oK9=_ofbCK00_ofbCK00?o0000okY5^_njAKX02?nj
AKX4o`0000cobSG:00?o0000ojEJYOnUFZD00onUFZD3o`0000Goe2_D00?o0000oki1__nn@Kh01_nn
@Kh01Ol0003o]4^dokA;]?ndBkCo000000ooeB[E00?o0000omXUf_oJ9MX03OoJ9MX00ol0003o`cc3
ol<l``06ol<l``03o`000?oF:MKoeRWF00?o00000oo5>/D00ol0003oeRWFomHYeP0;omHYeP03o`00
0?oC;=?odbcC00?odbcC00?o0000oldbcOo=</d03Oo=</d00ol0003ogb3OomlPg`0;omlPg`03o`00
0?oj1O[onPGj00ConPGj0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000om/TfooK9=/02_oK9=/3o`0000Ko^TFj0ol0
0003oke2_@03o`000?o:=L[obSG:00[obSG:00?o0000ojEJYOnUFZD01_nUFZD3o`000003om@[e?l0
003o_T6n00Wo_T6n00?o0000okA;]?l000004?oE:]D00ol0003ofRGJomXUfP0=omXUfP03o`000?o3
?<?o`cc300Oo`cc30_l00007olDja@03o`000?oF:MKoeRWF00[oeRWF00Co0000om</dooC;=?odbcC
0ol0000?oldbc@03o`000?oO8=oogb3O00_ogb3O00?o0000ooX5n_oj1OX01ooj1OX4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000om/TfooK9=/02_oK
9=/01?l0003obcC;ol/dboo;=</2o`000004okY5^_l0003o0000o`0000Ko_D:m00?o0000olXeb_o:
=LX02_o:=LX00ol0003oYEZUojEJY@09ojEJY@03o`000?nn@Kko_T6n00[o_T6n00?o0000omDZeOoE
:]D03ooE:]D00ol0003ofRGJomXUfP0>omXUfP03o`000?o3?<?o`cc300Ko`cc300?o0000olDjaOo5
>/D01oo5>/D4o`0000SoeRWF00Co0000om</dooC;=?o00000oneB[D2o`0000gocC;=00?o0000omlP
gooO8=l02_oO8=l00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000om/TfooK9=/02OoK9=/00ol0003o
bcC;ol/db`04ol/db`03o`000?nm@[go_D:m00Oo_D:m00?o0000olXeb_o:=LX02Oo:=LX00ol0003o
YEZUojEJY@0:ojEJY@03o`000?nn@Kko_T6n00[o_T6n00?o0000omDZeOoE:]D03ooE:]D00ol0003o
fRGJomXUfP0>omXUfP03o`000?o3?<?o`cc300Go`cc300?o0000olDjaOo5>/D02?o5>/D01?l0003o
cC;=oldbcOo=</d7o`0000;oeRWF0_l00006okE:]@;o00003?o=</d00ol0003ogb3OomlPg`09omlP
g`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003ofbCKom/Tf`08om/Tf`03o`000?o;=<_obcC;00Go
bcC;00?o0000oke2_Onm@[d02?nm@[d00ol0003obSG:olXebP08olXebP03o`000?nUFZGoYEZU00[o
YEZU00?o0000oki1__nn@Kh02onn@Kh00ol0003oeB[EomDZe@0>omDZe@03o`000?oJ9M[ofRGJ00ko
fRGJ1Ol00002ol<l``03o`000?o5>/GoaC[500WoaC[500?o0000oldbcOo=</d02?o=</d3o`0000Wo
]DZe0_l0000:oldbc@03o`000?oO8=oogb3O00Sogb3O00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oK9=_ofbCK00SofbCK00?o0000ol/dboo;=</01oo;=</00ol0003o_D:moke2_@07oke2_@03o`00
0?o:=L[obSG:00SobSG:00?o0000ojEJYOnUFZD02_nUFZD00ol0003o_T6noki1_P0:oki1_P;o0000
3_oE:]D3o`0000gofRGJ0ol00005om/Tf`;o00002oo5>/D00ol0003ocC;=oldbc@0;oldbc@;o0000
2_neB[D2o`0000OocC;=0ol00009omlPg`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:ol/db`03o`00
0?nm@[go_D:m00Oo_D:m00?o0000olXeb_o:=LX02?o:=LX>o`0000Wo_T6n0ol000000on[E:_o0000
omDZe@0:omDZe@?o00000_oM8]d00ol0003ofRGJomXUfP09omXUfP;o00002OoK9=/00ol0003oaC[5
olDja@09olDja@03o`000?o=</gocC;=00_ocC;=00?o0000om</dol000002oneB[D2o`0000CocC;=
00Co0000omhQg_oN8MkogR7N0_l00007omlPg`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003obcC;
ol/db`09ol/db`03o`000?nm@[go_D:m00Ko_D:m00?o0000olXeb_o:=LX02?o:=LX00ol0003o/4n`
ok1?/00:ok1?/003o`000?nn@Kko_T6n00Co_T6n0ol00005oj]DZ`03o`000?oE:]GoeB[E00CoeB[E
1?l00006omdRg@03o`000?oJ9M[ofRGJ00KofRGJ0_l0000;om/Tf`03o`000?o5>/GoaC[500WoaC[5
00?o0000oldbcOo=</d02_o=</d01Ol0003odbcCom</dooC;=?o000000co]DZe0_l000000oo=</go
0000omhQgP05omhQgP03o`000?oO8=oogb3O00?ogb3O00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o;=<_obcC;00SobcC;00?o0000oke2_Onm@[d01_nm@[d00ol0003obSG:olXebP07olXebP03o`00
0?n`Ck3o/4n`00_o/4n`00?o0000oki1__nn@Kh00_nn@Kh2o`0000WoZeB[00?o0000omDZeOoE:]D0
0ol0000;omdRg@03o`000?oJ9M[ofRGJ00;ofRGJ0ol0000>om/Tf`03o`000?o5>/GoaC[500OoaC[5
00?o0000oldbcOo=</d02oo=</d00ol0003odbcCom</d`02om</d`03o`000?neB[Go]DZe00_o]DZe
00?o0000omhQg_oN8Mh01_oN8Mh2o`0000?ogb3O00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;
=<_obcC;00OobcC;00?o0000oke2_Onm@[d01onm@[d00ol0003obSG:olXebP05olXebP?o00003On`
Ck04o`0000_oZeB[0ol0000?omdRg@04o`000?oJ9M[o0000o`00017ofbCK00?o0000olDjaOo5>/D0
1oo5>/D00ol0003ocC;=oldbc@0:oldbc@03o`000?oC;=?odbcC00CodbcC00?o0000okE:]OneB[D0
1oneB[D3o`0000_ogR7N1?l0000=ooX5nP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol/dboo;=</02?o;=</00ol0003o_D:moke2
_@06oke2_@03o`000?o:=L[obSG:00;obSG:0ol00003ol0o`003o`000?n`Ck3o/4n`00[o/4n`00?o
0000oj]DZon[E:/02on[E:/00ol0003o/Tfbo`00000AomdRg@03o`000?oK9=_ofbCK017ofbCK00?o
0000olDjaOo5>/D01oo5>/D00ol0003ocC;=oldbc@0:oldbc@03o`000?oC;=?odbcC00GodbcC00Co
0000okE:]OneB[Go]DZe1Ol00002oklo_`03o`000?oN8MkogR7N00WogR7N00Co0000ooX5n_oj1O[o
nPGj0ol00009ooX5nP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000ol/dboo;=</01oo;=</00ol0003o_D:moke2_@05oke2_@?o0000
00?obSG:o`000?l000001oo0?l000ol0003o/4n`ok1?/008ok1?/0?o00002_n[E:/2o`0000;o/Tfb
00?o0000omdRgOoM8]d03ooM8]d00ol0003ofbCKom/Tf`0Aom/Tf`03o`000?o5>/GoaC[500OoaC[5
00?o0000oldbcOo=</d02Oo=</d00ol0003odbcCom</d`07om</d`?o00001ono?kl00ol0003ogR7N
omhQgP09omhQgP03o`000?oj1O[onPGj00ConPGj0_l00007ooX5nP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000ol/dboo;=</01oo;
=</4o`0000;o_D:m0_l00003olXebP03o`000?o0?l3o`3o000So`3o00_l00006ok1?/0;o00000one
B[D00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?nbCK;o/Tfb00?o/Tfb00?o0000omdRgOoM8]d03_oM
8]d00ol0003ofbCKom/Tf`0Bom/Tf`03o`000?o5>/GoaC[500GoaC[500?o0000oldbcOo=</d02Oo=
</d00ol0003odbcCom</d`08om</d`03o`000?no?koo_cno00Oo_cno00?o0000omhQg_oN8Mh02?oN
8Mh00ol0003onPGjooX5nP07ooX5nP;o00001Ooj1OX00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o;=<_obcC;00CobcC;0_l00004
om`Sg0;o00001Oo:=LX00ol0003o`3o0ol0o`00:ol0o`003o`000?n`Ck3o/4n`00;o/4n`00?o0000
okE:]OneB[D01?neB[D00ol0003oZeB[oj]DZ`04oj]DZ`03o`000?nbCK;o/Tfb00Co/Tfb00?o0000
omdRgOoM8]d03_oM8]d00ol0003ofbCKom/Tf`0Bom/Tf`[o00002_o=</d00ol0003odbcCom</d`08
om</d`03o`000?no?koo_cno00Oo_cno00?o0000omhQg_oN8Mh02?oN8Mh00ol0003onPGjooX5nP09
ooX5nP?o000000?onPGjo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003obcC;ol/dboo;=</2o`0000Oog2?L00?o0000olXeb_o:=LX01?o:=LX0
0ol0003o`3o0ol0o`00:ol0o`004o`000?n`Ck3o0000o`0000So]DZe00Co0000oj]DZon[E:_oZeB[
0_l00007ok9=/P03o`000?oM8]gogB;M00kogB;M00?o0000om/TfooK9=/04_oK9=/00ol0003oc3?<
ol`cc007ol`cc003o`000?o=</gocC;=00KocC;=00?o0000om</dooC;=<02_oC;=<00ol0003o_cno
oklo_`06oklo_`03o`000?oN8MkogR7N00SogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o;
=<_o0000o`0000Wog2?L00?o0000olXeb_o:=LX01?o:=LX00ol0003o`3o0ol0o`00;ol0o`003o`00
0?neB[Go]DZe00Wo]DZe00?o0000oj]DZol000002OnbCK800ol0003ogB;MomdRg@0>omdRg@;o0000
4_oK9=/00ol0003oc3?<ol`cc009ol`cc0;o00001_o=</d00ol0003odbcCom</d`0:om</d`03o`00
0?no?koo_cno00Ko_cno00?o0000omhQg_oN8Mh02?oN8Mh00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om`Sg?oL8m`02OoL8m`00ol0003obSG:olXebP05olXebP03o`000?o0?l3o`3o000[o`3o000?o
0000okE:]OneB[D02_neB[D2o`0000Wo/Tfb00?o0000omdRgOoM8]d03_oM8]d00ol0003odbcCo`00
0002o`0000oofbCK00?o0000ol`cc?o<<l`02oo<<l`00ol0003ocC;=oldbc@03o`0000godbcC00?o
0000oklo_ono?kl01_no?kl00ol0003ogR7NomhQgP07omhQgP03o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003og2?Lom`Sg009om`Sg003o`000?o:=L[obSG:00GobSG:00?o0000ol0o`?o0?l002Oo0?l02
o`0000_o]DZe0_l0000;ok9=/P03o`000?oM8]gogB;M00cogB;M00?o0000om</dooC;=<00ooC;=<3
o`0000cofbCK00?o0000ol`cc?o<<l`03?o<<l`2o`0000;oacS700?o0000om</dooC;=<03?oC;=<0
0ol0003o_cnooklo_`05oklo_`03o`000?oN8MkogR7N00OogR7N00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oL8mcog2?L00[og2?L00?o0000olXeb_o:=LX01_o:=LX00ol0003o`3o0ol0o`007ol0o
`003o`000?ndBkCo000000[o]DZe00Co0000ojQGZ?nXEjSo00002_nbCK800ol0003ogB;MomdRg@0<
omdRg@03o`000?oC;=?odbcC00KodbcC0_l00008om/Tf`;o00003oo<<l`00ol0003oacS7olLha`02
olLha`03o`000?oC;=?odbcC00_odbcC00?o0000oklo_ono?kl01Ono?kl00ol0003ogR7NomhQgP07
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003og2?Lom`Sg00:om`Sg003o`000?o:=L[obSG:
00KobSG:00?o0000ol0o`?o0?l001_o0?l001Ol0003o]4^dokA;]?ndBkCo000000So]DZe00?o0000
ojQGZ?nXEjP00_nXEjP00ol0003o/Tfbok9=/P06ok9=/PCo00003?oM8]d00ol0003odbcCom</d`08
om</d`?o00000_oK9=/3o`000003olXeb_l0003oc3?<00goc3?<00?o0000olLhaoo7><L01?o7><L0
0ol0003odbcCom</d`0:om</d`03o`000?no?koo_cno00Go_cno00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om`Sg?oL8m`02ooL8m`00ol0003obSG:olXebP07olXe
bP03o`000?o0?l3o`3o000?o`3o00_l00005okA;]003o`000?neB[Go]DZe00Co]DZe00?o0000ojQG
Z?nXEjP00onXEjP00ol0003o/Tfbok9=/P05ok9=/P03o`000?o5>/GoaC[500;oaC[50ol00007omdR
g@;o00003_oC;=<2o`0000GobSG:00?o0000ol`cc?o<<l`02_o<<l`00ol0003oacS7olLha`05olLh
a`03o`000?oC;=?odbcC00_odbcC00?o0000oklo_ono?kl01?no?kl00ol0003ogR7NomhQgP06omhQ
gP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003og2?Lom`Sg00;om`Sg003o`000?o:=L[obSG:00Oo
bSG:00?o0000ol0o`?o0?l000_o0?l000ol0003o]4^dokA;]006okA;]003o`000?neB[Go]DZe00;o
]DZe00?o0000ojQGZ?nXEjP01OnXEjP00ol0003o/Tfbok9=/P02ok9=/P;o00002?o5>/D3o`0000;o
gB;M0_l000000oo9=/Wo0000om</d`0=om</d`03o`000?o:=L[obSG:00GobSG:00?o0000ol`cc?o<
<l`02?o<<l`00ol0003oacS7olLha`07olLha`03o`000?oC;=?odbcC00[odbcC00?o0000oklo_ono
?kl01?no?kl00ol0003ogR7NomhQgP06omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003og2?L
om`Sg00<om`Sg003o`000?o:=L[obSG:00SobSG:00Co0000ol0o`?o0?l3o00002OndBk@01Ol0003o
]DZeokE:]OneB[Go000000SoZ5NX00Go0000ok9=/_nbCK;o/Tfbo`00000=olDja@;o00001?o9=/T0
0ol0003odbcCom</d`0;om</d`03o`000?o:=L[obSG:00KobSG:00?o0000ol`cc?o<<l`01oo<<l`0
0ol0003oacS7olLha`08olLha`Co00002?oC;=<00ol0003o_cnooklo_`04oklo_`03o`000?oN8Mko
gR7N00KogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oL8mcog2?L00_og2?L0ol00009olXe
bP03o`000?o0?l3o000000_o]4^d00?o0000okE:]Ol000002_nXEjP00ol0003o/Tfbo`00000?olDj
a@03o`000?o9=/WobCK900;obCK900?o0000om</dooC;=<02ooC;=<00ol0003obSG:olXebP06olXe
bP03o`000?o<<lcoc3?<00Koc3?<00?o0000olLhaoo7><L02Oo7><L01?l0003od2o@om0_d?o@;m07
o`0000;odbcC00?o0000oklo_ono?kl00ono?kl00ol0003ogR7NomhQgP05omhQgP03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oL8mcog2?L00Sog2?L0ol00003ol`cc003o`000?o:=L[obSG:00OobSG:00?o0000okA;
]?ndBk@02ondBk@00ol0003oZ5NXojQGZ00:ojQGZ003o`000?o5>/GoaC[500goaC[500?o0000olTf
bOo9=/T01?o9=/T00ol0003odbcCom</d`09om</d`03o`000?o:=L[obSG:00SobSG:00?o0000ol`c
c?o<<l`00oo<<l`2o`0000coacS700?o0000om0_d?o@;m002?o@;m0<o`0000?ogR7N0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om`Sg?oL8m`01_oL8m`3o`0000Ooc3?<00?o0000olXeb_o:=LX01_o:=LX00ol0003o
]4^dokA;]00;okA;]003o`000?nXEjSoZ5NX00WoZ5NX0_l0000>olDja@03o`000?o9=/WobCK900Go
bCK900?o0000om</dooC;=<02OoC;=<00ol0003obSG:olXebP09olXebP03o`000?o<<lco000000;o
00000_o2?L800ol0003oacS7olLha`08olLha`03o`000?o@;m3od2o@00cod2o@00?o0000onHIi_oV
6NH01_oV6NH3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003og2?Lom`Sg003om`Sg0?o00002oo<<l`00ol0003obSG:
olXebP04olXebP03o`000?ndBkCo]4^d00_o]4^d0ol00007ojQGZ0?o000000?o_T6no`000?o5>/D0
3Oo5>/D00ol0003obCK9olTfb@06olTfb@03o`000?oC;=?odbcC00SodbcC00?o0000olXeb_o:=LX0
2_o:=LX00ol0003o`Sg2ol8m`P04ol8m`P03o`000?o7><OoacS700OoacS700?o0000om0_d?o@;m00
2oo@;m000ol0003oiQWVonHIiP08onHIiP03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om`Sg?l0
003o0000o`0000ooc3?<00?o0000olXeb_o:=LX00oo:=LX>o`0000?o]4^d0_l00002ojQGZ0?o0000
1Onn@Kh00ol0003oaC[5olDja@0:olDja@03o`000?o9=/WobCK900OobCK900?o0000om</dooC;=<0
2?oC;=<00ol0003obSG:olXebP0:olXebP03o`000?o2?L;o`Sg200Go`Sg200?o0000olLhaoo7><L0
1_o7><L00ol0003od2o@om0_d00;om0_d003o`000?oV6NKoiQWV00SoiQWV00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;oc3?<00?o0000olXeb_o:=LX00_o:=LX00ol0003oY5^TojAK
Y00:ojAKY003o`000?ndBkCo]4^d00?o]4^d0_l00009oki1_P03o`000?o5>/GoaC[500WoaC[500?o
0000olTfbOo9=/T02?o9=/T2o`0000SodbcC00?o0000olXeb_o:=LX02Oo:=LX00ol0003o`Sg2ol8m
`P07ol8m`P03o`000?o7><OoacS700CoacS700?o0000om0_d?o@;m002oo@;m000ol0003oiQWVonHI
iP09onHIiP03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oc3?<ol`cc00?ol`cc0?o000000?obSG:
o`000?nTFj@02onTFj@00ol0003o]4^dokA;]004okA;]003o`000?nn@Kko_T6n00Wo_T6n00?o0000
olDjaOo5>/D01oo5>/D00ol0003obCK9olTfb@09olTfb@04o`000?o6>LKo0000o`0000KodbcC00?o
0000olXeb_o:=LX02Oo:=LX00ol0003o`Sg2ol8m`P08ol8m`P03o`000?o7><OoacS700?oacS700?o
0000om0_d?o@;m002oo@;m000ol0003oiQWVonHIiP09onHIiP03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oc3?<ol`cc00<ol`cc0;o00000oo5>/D2o`0000coY5^T00?o0000okA;]?ndBk@01?ndBk@0
0ol0003o_T6noki1_P0:oki1_PWo00002oo9=/T00ol0003oaSW6olHiaP02olHiaP?o00000_oC;=<0
0ol0003obSG:olXebP0:olXebP03o`000?o2?L;o`Sg200Wo`Sg200?o0000olLhaoo7><L00_o7><L0
0ol0003od2o@om0_d00:om0_d003o`000?oV6NKoiQWV00WoiQWV00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o<<l`2o`0000GoaC[500?o0000oki1__l000002_nTFj@00ol0003o]4^dokA;]006okA;
]003o`000?nn@Kko_T6n00Wo_T6n00?o0000oki1__nn@Kh01Onn@Kh00ol0003obCK9olTfb@09olTf
b@03o`000?o6>LKoaSW600GoaSW60ol00009olXebP?o00003Oo2?L801Ol0003oacS7olLhaoo7><Oo
000000cod2o@00?o0000onHIi_oV6NH02OoV6NH00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol`c
c?o<<l`01Oo<<l`2o`0000OoaC[500Co0000oki1__nn@Kko00002OnTFj@00ol0003o]4^dokA;]006
okA;]003o`000?nn@Kko_T6n00So_T6n00?o0000oki1__nn@Kh01onn@Kh00ol0003obCK9olTfb@07
olTfb@03o`000?o6>LKoaSW600SoaSW60ol00002olXebPGo00000_n[E:/00ol0003o`Sg2ol8m`P0<
ol8m`P03o`000?o7><Oo000000cod2o@00?o0000onHIi_oV6NH02_oV6NH00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000ol`cc?o<<l`00_o<<l`2o`0000SoaC[500?o0000oki1__nn@Kh00_nn@Kh5o`00
00CoY5^T00?o0000okA;]?ndBk@01_ndBk@00ol0003o_T6noki1_P08oki1_P03o`000?nn@Kko_T6n
00Oo_T6n00?o0000olTfbOo9=/T01oo9=/T00ol0003oaSW6olHiaP08olHiaP03o`000?n/Djco[5>/
00;o00002?n[E:/00ol0003o`Sg2ol8m`P0<ol8m`PCo00002_o@;m000ol0003oiQWVonHIiP0:onHI
iP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oc3?<o`000?l0000:olDja@03o`000?nn@Kko_T6n
00;o_T6n00?o0000ohMhQon7N8L00_n7N8L4o`0000Wo]4^d00?o0000oki1__nn@Kh02?nn@Kh00ol0
003o_T6noki1_P08oki1_P03o`000?o9=/WobCK900GobCK900?o0000olHia_o6>LH02?o6>LH01Ol0
003o[5>/ojaC[?n/Djco000000[oZeB[0ol0000;ol8m`P04o`000?oK9=_ofbCKom/Tf`Co00001Oo@
;m000ol0003oiQWVonHIiP0;onHIiP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003oaC[5olDja@0:
olDja@03o`000?nn@Kko_T6n00?o_T6n00?o0000ohMhQon7N8L01?n7N8L00ol0003o]4^dokA;]007
okA;]003o`000?nn@Kko_T6n00Ko_T6n0_l0000;oki1_P03o`000?o9=/WobCK900GobCK900?o0000
olHia_o6>LH02?o6>LH00ol0003o[5>/ojaC[002ojaC[003o`000?n[E:_oZeB[00OoZeB[00?o0000
ol4n`Oo1?/401?l00006ol8m`P03o`000?oK9=_ofbCK00KofbCK0ol00002om0_d003o`000?oV6NKo
iQWV00_oiQWV00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o5>/GoaC[500WoaC[500?o0000oki1
__nn@Kh01?nn@Kh00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?ndBkCo]4^d00Oo]4^d00?o0000oki1
__nn@Kh00_nn@Kh3o`000003ol@ka?l0003o_T6n00[o_T6n00?o0000olTfbOo9=/T01Oo9=/T00ol0
003oaSW6olHiaP07olHiaP03o`000?n/Djco[5>/00?o[5>/00?o0000oj]DZon[E:/01on[E:/00ol0
003o`Ck1ol4n`@04ol4n`@?o00000_o2?L800ol0003ofbCKom/Tf`0:om/Tf`;o00003_oV6NH00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000olDjaOo5>/D02Oo5>/D00ol0003o_T6noki1_P04oki1_P03
o`000?n7N8OoQgR700KoQgR70_l00007okA;]003o`000?nn@Kko000000;o00001Oo4>l@00ol0003o
_T6noki1_P08oki1_P?o00001?o9=/T00ol0003oaSW6olHiaP08olHiaP03o`000?n/Djco[5>/00Co
[5>/00?o0000oj]DZon[E:/01_n[E:/00ol0003o`Ck1ol4n`@07ol4n`@;o00003_oK9=/00ol0003o
iQWVonHIiP0;onHIiP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003oaC[5olDja@08olDja@03o`00
0?nn@Kko_T6n00Go_T6n00?o0000ohMhQon7N8L01?n7N8L00ol0003o/Djaok5>/@03o`0000Co]4^d
0_l00008ol@ka003o`000?nn@Kko_T6n00Oo_T6n00Co0000omDZeOoE:]GoeB[E0ol000000oo9=/Wo
0000olHiaP09olHiaP03o`000?n/Djco[5>/00Co[5>/00?o0000oj]DZon[E:/01On[E:/00ol0003o
`Ck1ol4n`@09ol4n`@03o`000?oK9=_ofbCK00gofbCK00?o0000onHIi_oV6NH02_oV6NH00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000olDjaOo5>/D01oo5>/D00ol0003o_T6noki1_P06oki1_P03o`00
0?n7N8OoQgR700?oQgR700?o0000ok5>/OnaC[401?naC[42o`000003okA;]?l0003oa3_400[oa3_4
00?o0000oki1__nn@Kh01Onn@Kh00ol0003oeB[EomDZe@05omDZe@03o`000?o6>LKoaSW600OoaSW6
0ol00007ojaC[003o`000?n[E:_oZeB[00CoZeB[00?o0000ol4n`Oo1?/402Oo1?/400ol0003ofbCK
om/Tf`0=om/Tf`03o`000?oV6NKoiQWV00[oiQWV00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o5
>/GoaC[500GoaC[50ol00009oki1_P05o`000?n7N8OoQgR7ohMhQol000002OnaC[400ol0003oa3_4
ol@ka00;ol@ka003o`000?nn@Kko_T6n00?o_T6n00?o0000omDZeOoE:]D01_oE:]D00ol0003oaSW6
olHiaP06olHiaP05o`000?o7><OoacS7olLhaol000001on/Dj`00ol0003oZeB[oj]DZ`03oj]DZ`03
o`000?o1?/7o`Ck100Wo`Ck100?o0000om/TfooK9=/03_oK9=/00ol0003oiQWVonHIiP09onHIiP03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003oaC[5o`000004o`0000;oebSG00?o0000oki1__nn@Kh0
1onn@Kh01?l0003oQgR7ohMhQol00009ok5>/@;o00003Oo4>l@00ol0003o_T6noki1_P02oki1_P03
o`000?oE:]GoeB[E00SoeB[E00?o0000olHia_o6>LH00oo6>LH2o`0000GoacS700?o0000ojaC[?n/
Dj`01?n/Dj`00ol0003oZeB[oj]DZ`03oj]DZ`03o`000?o1?/7o`Ck100Wo`Ck100?o0000om/TfooK
9=/03_oK9=/00ol0003oiQWVonHIiP09onHIiP03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SoebSG
00?o0000oki1__nn@Kh01_nn@Kh00ol0003oQgR7o`000009ok5>/@04o`000?o;=<_obcC;o`0000go
a3_400Co0000oki1__nn@Kko00003?oE:]D01Ol0003oaSW6olHia_o6>LKo000000SoacS70_l00005
ojaC[003o`000?n[E:_oZeB[00;oZeB[00?o0000ol4n`Oo1?/402Oo1?/400ol0003ofbCKom/Tf`0>
om/Tf`03o`000?oV6NKoiQWV00WoiQWV00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oG:=OoebSG
00OoebSG00?o0000oki1__nn@Kh01onn@Kh00ol0003o/Djaok5>/@07ok5>/@03o`000?o;=<_obcC;
00;obcC;00?o0000ol@ka?o4>l@02_o4>l@00ol0003o_T6no`00000>omDZe@03o`000?o6>LKo0000
00_oacS700?o0000ojaC[?n/Dj`00_n/Dj`01Ol0003oZeB[oj]DZon[E:_o000000co`Ck100?o0000
om/TfooK9=/03_oK9=/3o`0000WoiQWV00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oG:=OoebSG
00WoebSG00?o0000oki1__nn@Kh01_nn@Kh00ol0003o/Djaok5>/@06ok5>/@03o`000?o;=<_obcC;
00?obcC;00?o0000ol@ka?o4>l@02oo4>l@00ol0003oeB[EomDZe@0>omDZe@03o`000?o7><OoacS7
00_oacS70_l00003ojaC[004o`000?n[E:_oZeB[o`0000[o`Ck10ol0000>om/Tf`;o00000ooj1OX2
o`0000OoiQWV00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oG:=OoebSG00[oebSG00?o0000oki1
__nn@Kh01?nn@Kh00ol0003o/Djaok5>/@06ok5>/@03o`000?o;=<_obcC;00GobcC;00?o0000ol@k
a?o4>l@01oo4>l@3o`00017oeB[E00?o0000olLhaoo7><L03Oo7><L01Ol0003o[5>/ojaC[?l0003o
ZeB[00Co00000oo1?/45o`0000;ocC;=00?o0000om/TfooK9=/02_oK9=/2o`0000OonPGj0_l00004
onHIiP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oebSGomLXe`0;omLXe`03o`000?nn@Kko_T6n
00Co_T6n00?o0000ok5>/OnaC[401OnaC[400ol0003obcC;ol/db`06ol/db`03o`000?o4>lCoa3_4
00Coa3_40ol00002ol/db`03o`000?oE:]GoeB[E00ooeB[E0_l0000?olLha`04o`000?n/Djco0000
o`0000Co_D:m0ol00008oldbc@03o`000?oK9=_ofbCK00OofbCK0_l0000;ooX5nP;o00000_oV6NH0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omLXeooG:=L03?oG:=L6o`0000Oo/Dja00?o0000ol/d
boo;=</02?o;=</00ol0003oa3_4ol@ka003o`0000KobcC;00?o0000omDZeOoE:]D03OoE:]D01?l0
003odBkAom4^dOl0000?olLha`03o`000?nm@[go_D:m00Go_D:m00?o0000oldbcOo=</d02?o=</d0
0ol0003ofbCKom/Tf`05om/Tf`03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oG:=L00ol0003o_D:moke2_@04oke2
_@03o`000?naC[7o/Dja00?o/Dja00?o0000ol/dboo;=</02_o;=</2o`0000[obcC;00?o0000omDZ
eOoE:]D02ooE:]D00ol0003odBkAom4^d@02om4^d@03o`000?o7><OoacS700_oacS70_l00007oke2
_@03o`000?o=</gocC;=00WocC;=00?o0000om/TfooK9=/00_oK9=/2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000omLXeooG:=L02ooG:=L00ol0003o_D:moke2_@06oke2_@05o`000?naC[7o/Djaok5>
/Ol000003Oo;=</00ol0003obcC;ol/db`0:ol/db`03o`000?oE:]GoeB[E00WoeB[E00?o0000om4^
dOoA;]401?oA;]400ol0003oacS7olLha`08olLha`;o000000?o[U6^o`000?nm@[d01onm@[d00ol0
003ocC;=oldbc@09oldbc@04o`000?oK9=_o0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oG:=OoebSG
00WoebSG00?o0000oke2_Onm@[d02?nm@[d00ol0003o/Djao`00000=ol/db`03o`000?o;=<_obcC;
00_obcC;00?o0000omDZeOoE:]D02?oE:]D00ol0003odBkAom4^d@06om4^d@03o`000?o7><OoacS7
00GoacS70_l00003ojiA[P03o`000?nm@[go_D:m00Ko_D:m00?o0000oldbcOo=</d02_o=</d00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003oebSGomLXe`07omLXe`03o`000?nm@[go_D:m00[o_D:m00?o0000ol/dboo;
=</03?o;=</00ol0003obcC;ol/db`0<ol/db`03o`000?oE:]GoeB[E00KoeB[E00?o0000om4^dOoA
;]402?oA;]400ol0003oacS7olLha`02olLha`;o00001_n^DJh00ol0003o_D:moke2_@05oke2_@03
o`000?o=</gocC;=00[ocC;=00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oG:=OoebSG00GoebSG
00?o0000oke2_Onm@[d03?nm@[d2o`0000cobcC;00?o0000ol/dboo;=</03Oo;=</00ol0003oeB[E
omDZe@04omDZe@03o`000?oA;]7odBkA00[odBkA00Co0000olLhaol0003o00002?n^DJh00ol0003o
_D:moke2_@06oke2_@03o`000?o=</gocC;=00WocC;=00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oG:=L00ol0003o_D:moke2_@0=oke2_@03o`000?o4>lCo000000;o00002?o;=</00ol0003obcC;
ol/db`0?ol/db`Ko00003_oA;]400ol0003o[U6^ojiA[P08ojiA[P03o`000?nm@[go_D:m00Ko_D:m
00?o0000oldbcOo=</d02Oo=</d00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000om4^dOoA;]7odBkA
0_l0000?oke2_@03o`000?o4>lCoa3_400?oa3_40ol00005ol/db`;o00004?o;=</01_l0003o`Ck1
ol4n`Ol0003o/dbco`0000kodBkA00?o0000ojiA[_n^DJh02On^DJh00ol0003o_D:moke2_@05oke2
_@03o`000?o=</gocC;=00WocC;=00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000om4^dOoA;]400ooA;]400ol0003o
_D:moke2_@0=oke2_@03o`000?o4>lCoa3_400Koa3_40ol000001?o;=<_o0000olDjaOo5>/D3o`00
00cobcC;00Go0000ol4n`Oo1?/7o`Ck1o`000002ok=</`03o`000?oA;]7odBkA00_odBkA00?o0000
ojiA[_n^DJh02On^DJh00ol0003o_D:moke2_@06oke2_@03o`000?o=</gocC;=00SocC;=0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003odBkAom4^d@04om4^d@oo00003?o4>l@00ol0003oaC[5olDja@04olDj
a@?o00002?o;=</00ol0003o`Ck1ol4n`@02ol4n`@05o`000?ncC;?o/dbcok=</ol000003?oA;]40
0ol0003o[U6^ojiA[P09ojiA[P03o`000?nm@[go_D:m00Go_D:m3?l00002omhQgP;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003odBkAom4^d@05om4^d@03o`000?n^DJko[U6^00_o[U6^00?o0000ol@k
a?o4>l@02_o4>l@00ol0003oaC[5olDja@07olDja@;o00001Oo;=</00ol0003o`Ck1ol4n`@03ol4n
`@03o`000?ncC;?o/dbc00;o/dbc00?o0000om4^dOoA;]402OoA;]400ol0003o[U6^ojiA[P0:ojiA
[P03o`000?nm@[go_D:m00?o_D:m00?o0000ojeB[On]DZd02On]DZd00ol0003ogR7NomhQgP02omhQ
gP;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003odBkAom4^d@06om4^d@03o`000?n^DJko[U6^00[o
[U6^00?o0000ol@ka?o4>l@02oo4>l@00ol0003oaC[5olDja@09olDja@?o000000?obcC;o`000?o1
?/401Oo1?/400ol0003o/dbcok=</`03ok=</`03o`000?oA;]7odBkA00SodBkA3_l00003oke2_@;o
00002on]DZd00ol0003ogR7NomhQgP05omhQgP03o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000om4^dOoA;]401OoA;]400ol0003o^DJio`00000;ojiA[P03o`000?o4>lCoa3_400[oa3_4
0_l0000>olDja@03o`000?o1?/7o`Ck100Go`Ck100?o0000ok=</oncC;<00oncC;<00ol0003odBkA
om4^d@08om4^d@03o`000?o4>lCoa3_400_oa3_400?o0000oke2_Ol000003On]DZd00ol0003ogR7N
omhQgP06omhQgP;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oA;]7odBkA00KodBkA00Co
0000okU6^OniA[Wo00002_n^DJh00ol0003oa3_4ol@ka009ol@ka003o`000?o2?L;o000000koaC[5
00?o0000ol4n`Oo1?/401Oo1?/400ol0003o/dbcok=</`04ok=</`03o`000?oA;]7odBkA00KodBkA
00?o0000ol@ka?o4>l@03Oo4>l@00ol0003o[E:]ojeB[@0<ojeB[@03o`000?oN8MkogR7N00SogR7N
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oA;]7odBkA00GodBkA00?o0000okU6^OniA[T00_ni
A[T00ol0003o[U6^ojiA[P06ojiA[P03o`000?o4>lCoa3_400Soa3_40_l00003ol8m`P03o`000?o5
>/GoaC[500_oaC[500?o0000ol4n`Oo1?/401Oo1?/400ol0003o/dbcok=</`05ok=</`03o`000?oA
;]7odBkA00GodBkA00?o0000ol@ka?o4>l@03Oo4>l@00ol0003o[E:]ojeB[@0;ojeB[@03o`000?oN
8MkogR7N00WogR7N00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000
okU6^OniA[T00oniA[T00ol0003o[U6^ojiA[P05ojiA[P03o`000?o4>lCoa3_400Ooa3_400?o0000
ol8m`_o2?L800oo2?L800ol0003oaC[5olDja@0:olDja@03o`000?o1?/7o`Ck100Ko`Ck100?o0000
ok=</oncC;<01_ncC;<00ol0003odBkAom4^d@04om4^d@03o`000?o4>lCoa3_400goa3_43ol0000;
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000okU6^OniA[T01OniA[T00ol0
003o[U6^ojiA[P04ojiA[P03o`000?o4>lCoa3_400Goa3_40_l00006ol8m`P03o`000?o5>/GoaC[5
00WoaC[50_l00008ol4n`@03o`000?ncC;?o/dbc00Ko/dbc1Ol000000ooA;]7o0000ol@ka00?ol@k
a003o`000?nXEjSoZ5NX00_oZ5NX00?o0000omhQg_oN8Mh02OoN8Mh00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000okU6^OniA[T01_niA[T00ol0003o
[U6^ojiA[P04o`0000Koa3_400?o0000ol8m`_o2?L801oo2?L800ol0003oaC[5olDja@05olDja@?o
000000?o^TFjo`000?o1?/401oo1?/400ol0003o/dbcok=</`05ok=</`03o`000?oB;M;odRgB00?o
dRgB0_l0000?ol@ka0;o00003OnXEjP00ol0003ogR7NomhQgP08omhQgP03o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WodBkA00?o0000okU6^OniA[T01oniA[T2o`0000Coe2_D00Co0000ol@ka?o4>lCo
a3_40_l0000:ol8m`P03o`000?o5>/GoaC[500;oaC[50ol00005okY5^P03o`000?o1?/7o`Ck100Go
`Ck100?o0000ok=</oncC;<01?ncC;<00ol0003odRgBom8]dP06om8]dP03o`000?o4>lCoa3_400[o
a3_40_l00002ol8m`P03o`000?nXEjSoZ5NX00[oZ5NX00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000om4^dOoA;]401_oA;]400ol0003o^DJiokU6^@08okU6^@03o`00
0?oD:mCoe2_D00Coe2_D00?o0000ol@ka?l000003?o2?L800ol0003oaC[5o`000002o`0000Wo^TFj
00?o0000ol4n`Oo1?/401?o1?/400ol0003o/dbcok=</`03ok=</`03o`000?oB;M;odRgB00SodRgB
1_l00004ol@ka0;o00001Oo2?L800ol0003oZ5NXojQGZ009ojQGZ003o`000?oN8MkogR7N00SogR7N
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00GodBkA00?o0000okU6^OniA[T01oni
A[T00ol0003oe2_Dom@[e006om@[e003o`000?o2?L;o`Sg200co`Sg200?o0000okY5^_njAKX02_nj
AKX00ol0003o`Ck1ol4n`@04ol4n`@04o`000?ncC;?o/dbcok=</`;o00002ooB;M800ol0003oc3?<
ol`cc003ol`cc0Co00002?o2?L800ol0003oZ5NXojQGZ008ojQGZ003o`000?oN8MkogR7N00OogR7N
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000om4^dOoA;]400ooA;]400ol0003o^DJiokU6^@07okU6^@03o`000?oD
:mCoe2_D00Ooe2_D00?o0000ol8m`_o2?L803?o2?L800ol0003o^TFjokY5^P0;okY5^P03o`000?o1
?/7o`Ck100?o`Ck100Co0000ok=</oncC;?o00003OoB;M800ol0003oc3?<ol`cc006ol`cc003o`00
0?o2?L;o`Sg200Oo`Sg200?o0000ojQGZ?nXEjP01onXEjP00ol0003ogR7NomhQgP06omhQgP04o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oA;]7odBkA00;odBkA00?o0000okU6^OniA[T0
1_niA[T00ol0003oe2_Dom@[e009om@[e003o`000?o2?L;o`Sg200Wo`Sg20_l0000>okY5^P?o0000
0oo1?/400ol0003o/dbco`00000=om8]dP03o`000?o<<lcoc3?<00Ooc3?<00?o0000ol8m`_o2?L80
2?o2?L8:o`0000KogR7N0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000Oo^DJi00?o
0000om@[e?oD:m@02_oD:m@00ol0003o`Sg2ol8m`P06ol8m`P;o000000?o`cc3o`000?njAKX02onj
AKX2o`0000?odRgB1Ol0000>om8]dP03o`000?o<<lcoc3?<00Ooc3?<00?o0000ol8m`_o2?L802?o2
?L800ol0003o^TFjokY5^P06okY5^P03o`000?oN8MkogR7N00?ogR7N00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oeRWFomHYeP03omHYePCo00000_niA[T00ol0003oe2_Dom@[e00;
om@[e003o`000?o2?L;o`Sg200?o`Sg20ol00004ol<l``03o`000?njAK[o^TFj00Oo^TFj0_l00008
om8]dP03o`000?oB;M;odRgB00godRgB00?o0000ol`cc?o<<l`02?o<<l`00ol0003o`Sg2ol8m`P07
ol8m`P03o`000?njAK[o^TFj00Oo^TFj0ol000000ooN8Mko0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oF:MKoeRWF00OoeRWF0_l0000?om@[e003o`000?o2?L;o`Sg200;o00002?o3?<<00ol0
003o^TFjokY5^P05okY5^P03o`000?oB;M;odRgB00SodRgB00?o0000om8]d_oB;M803OoB;M800ol0
003oc3?<ol`cc008ol`cc003o`000?o2?L;o`Sg200Ko`Sg200?o0000okY5^_njAKX02?njAKX01?l0
003ofbCKom/Tfol0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oeRWFomHYeP09omHY
eP03o`000?oD:mCoe2_D00koe2_D0_l0000;ol<l``03o`000?njAK[o^TFj00;o^TFj0_l0000;om8]
dP03o`000?oB;M;odRgB00godRgB00?o0000ol`cc?o<<l`02?o<<l`00ol0003o`Sg2ol8m`P06ol8m
`P03o`000?njAK[o^TFj00Oo^TFj00Go0000om/TfooK9=_ofbCKo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oeRWFomHYeP0:omHYeP03o`000?oD:mCoe2_D00goe2_D0_l0000<ol<l``04o`000?njAK[o0000
o`0000godRgB00?o0000om8]d_oB;M803?oB;M800ol0003oc3?<ol`cc009ol`cc003o`000?o2?L;o
`Sg200Ko`Sg200?o0000okY5^_njAKX01_njAKX00ol0003ofbCKom/Tf`03om/Tf`03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oeRWFomHYeP0:omHYeP03o`000?oD:mCoe2_D00coe2_D00Co0000oj=L
XonSG:?o00003?o3?<<00ol0003odRgBom8]dP0>om8]dP03o`000?oB;M;odRgB00SodRgB1?l0000;
ol`cc003o`000?o2?L;o`Sg200Ko`Sg200?o0000okY5^_njAKX01OnjAKX00ol0003ofbCKom/Tf`04
om/Tf`03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oeRWFomHYeP0;omHYeP03o`000?oD:mCoe2_D
00_oe2_D00?o0000oj=LXonSG:<00_nSG:<00ol0003o`cc3ol<l``09ol<l``03o`000?oB;M;odRgB
00kodRgB00Co0000om8]d_oB;M;odRgB1ol00003om</d`03o`000?o<<lcoc3?<00Woc3?<00?o0000
ol8m`_o2?L801_o2?L800ol0003o^TFjokY5^P04okY5^P03o`000?oK9=_ofbCK00KofbCK00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oF:MKoeRWF00coeRWF00?o0000om@[e?oD:m@02_oD:m@00ol0
003oXebSoj=LX`03oj=LX`03o`000?o3?<?o`cc300So`cc300?o0000om8]d_oB;M803_oB;M84o`00
00_odbcC00?o0000ol`cc?o<<l`02?o<<l`00ol0003o`Sg2ol8m`P05ol8m`P03o`000?njAK[o^TFj
00Go^TFj00?o0000om/TfooK9=/01_oK9=/00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000omHYe_oF
:MH03?oF:MH7o`0000Goe2_D00?o0000oj=LXonSG:<01OnSG:<00ol0003o`cc3ol<l``07ol<l``03
o`000?oB;M;odRgB00kodRgB00?o0000om</dooC;=<03OoC;=<00ol0003oc3?<ol`cc008ol`cc003
o`000?o2?L;o`Sg200Co`Sg200?o0000okY5^_njAKX01?njAKX00ol0003ofbCKom/Tf`07om/Tf`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oeRWFomHYeP0=omHYeP03o`000?oB;M;odRgB00CodRgB
1Ol00009oj=LX`03o`000?o3?<?o`cc300Ko`cc300?o0000om8]d_oB;M803_oB;M800ol0003odbcC
om</d`0=om</d`03o`000?o<<lcoc3?<00Soc3?<00Co0000ol8m`_o2?L;o`Sg21Ol00004okY5^P03
o`000?oK9=_ofbCK00WofbCK1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=omHYeP03o`000?oB;M;odRgB00WodRgB
0_l00009oj=LX`03o`000?o3?<?o`cc300Ko`cc300?o0000om8]d_oB;M803?oB;M800ol0003odbcC
om</d`0?om</d`Ko00001?o<<l`4o`0000GodBkA0_l000000onjAK[o0000om/Tf`0;om/Tf`04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oI9]WofBKIomTVf@?o00002_oF:MH00ol0003o
dRgBom8]dP09om8]dP03o`000?n^DJko000000;o00001onSG:<00ol0003o`cc3ol<l``05ol<l``03
o`000?oB;M;odRgB00SodRgB1Ol0000Aom</d`03o`000?o><LkocS7>00?ocS7>1?l0000;om4^d@03
o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omTVfOoI9]T01OoI9]T2o`0000OoeRWF
00?o0000om8]d_oB;M802_oB;M800ol0003o[U6^ojiA[P02ojiA[P?o00001OnSG:<00ol0003o`cc3
ol<l``04ol<l``04o`000?oB;M;odRgBom8]dPOo00001?o7><L00ol0003odbcCom</d`0>om</d`03
o`000?o><LkocS7>00OocS7>00?o0000om4^dOoA;]402OoA;]400ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003ofBKIomTVf@08omTVf@;o00001?oF:MH00ol0003odRgB
om8]dP0;om8]dP03o`000?n^DJko[U6^00Go[U6^0ol00003oj=LX`04o`000?o3?<?o`cc3ol<l``Ko
00003?o7><L00ol0003odbcCom</d`0=om</d`03o`000?o><LkocS7>00OocS7>00?o0000om4^dOoA
;]402_oA;]400ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omTVf@?o000000?oeRWFo`000?oB;M80
3?oB;M800ol0003o[U6^ojiA[P08ojiA[P?o000000CoXebSo`000?l0003o00000_oC;=<00ol0003o
acS7olLha`0=olLha`03o`000?oC;=?odbcC00codbcC00?o0000olhac_o><Lh02?o><Lh00ol0003o
dBkAom4^d@0;om4^d@03o`000?oK9=_ofbCK00KofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
fBKI00?o0000om8]d_oB;M803?oB;M800ol0003o[U6^ojiA[P0;ojiA[P03o`000?oC;=?odbcC00?o
dbcC00?o0000olLhaoo7><L03?o7><L00ol0003o^4Nho`00000=om</d`03o`000?o><LkocS7>00So
cS7>00?o0000om4^dOoA;]403?oA;]43o`0000GofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oI9]WofBKI00cofBKI00?o0000om8]d_oB;M803?oB;M800ol0003o[U6^ojiA[P0:ojiA[P03o`00
0?oC;=?odbcC00GodbcC00?o0000olLhaoo7><L02_o7><L01?l0003o^4NhokQ7^?nhAkP2o`0000[o
dbcC00?o0000olhac_o><Lh02Oo><Lh00ol0003odBkAom4^d@0<om4^d@03o`000?oQ7^7ohAkQ00?o
000000?ofbCKo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oI9]WofBKI00_ofBKI00?o0000om8]d_oB;M80
3?oB;M800ol0003o[U6^ojiA[P09ojiA[P03o`000?oC;=?odbcC00KodbcC00?o0000olLhaoo7><L0
2Oo7><L00ol0003o^4NhokQ7^002okQ7^003o`000?oA;]7o000000;o00001ooC;=<00ol0003ocS7>
olhacP09olhacP03o`000?oA;]7odBkA00_odBkA00?o0000on4NhOoQ7^401?oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omTVfOoI9]T02ooI9]T00ol0003odRgBom8]dP0;om8]dP03o`000?n^
DJko[U6^00So[U6^00?o0000om</dooC;=<01ooC;=<00ol0003oacS7olLha`08olLha`03o`000?nh
AkSo^4Nh00?o^4Nh00?o0000om4^dOoA;]400_oA;]42o`0000CodbcC00?o0000olhac_o><Lh02_o>
<Lh00ol0003odBkAom4^d@0:om4^d@03o`000?oQ7^7ohAkQ00GohAkQ00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oI9]WofBKI00[ofBKI0ol0000;om8]dPKo00001?n^DJh00ol0003odbcCom</d`08
om</d`03o`000?o7><OoacS700OoacS700?o0000okQ7^?nhAkP00onhAkP00ol0003odBkAom4^d@05
om4^d@?o000000?odbcCo`000?o><Lh02oo><Lh00ol0003odBkAom4^d@09om4^d@03o`000?oQ7^7o
hAkQ00OohAkQ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oI9]WofBKI00WofBKI00?o0000ol0o
`?o0?l001?l00006om8]dP03o`000?o><LkocS7>00CocS7>1?l0000<om</d`03o`000?o7><OoacS7
00GoacS700?o0000okQ7^?nhAkP01?nhAkP00ol0003odBkAom4^d@08om4^d@03o`000?o><LkocS7>
00_ocS7>00?o0000om4^dOoA;]402?oA;]400ol0003ohAkQon4Nh@08on4Nh@Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oI9]WofBKI00OofBKI00?o0000ol0o`?o0?l001Oo0?l03o`0000;odRgB00?o0000olhac_o>
<Lh02?o><Lh00ol0003odbcCom</d`0:om</d`03o`000?o7><OoacS700CoacS700?o0000okQ7^?nh
AkP01OnhAkP00ol0003odBkAom4^d@08om4^d@03o`000?o><LkocS7>00WocS7>1?l00008om4^d@03
o`000?oQ7^7ohAkQ00WohAkQ00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofBKI
omTVf@05omTVf@03o`000?o0?l3o`3o000Wo`3o00_l0000<olhacP03o`000?oC;=?odbcC00WodbcC
00?o0000olLhaoo7><L00oo7><L00ol0003o^4NhokQ7^005okQ7^003o`000?oA;]7odBkA00[odBkA
00?o0000olhac_o><Lh01?o><Lh4o`0000Cocc3?00?o0000om4^dOoA;]401?oA;]400ol0003ohAkQ
on4Nh@0:on4Nh@03o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oI9]WofBKI00?ofBKI00?o0000ol0o`?o0?l002oo0
?l000ol0003ocS7>olhacP0:olhacP03o`000?oC;=?odbcC00WodbcC00?o0000olLhaoo7><L00_o7
><L00ol0003o^4NhokQ7^006okQ7^003o`000?oA;]7odBkA00[odBkA00?o0000olhac_o><Lh01?l0
0009oll`c`Ko00003?oQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omTVfOoI9]WofBKI0_l0
000=ol0o`003o`000?o><LkocS7>00[ocS7>00?o0000om</dooC;=<02OoC;=<01Ol0003oacS7olLh
aoo7><Oo000000Wo^4Nh00?o0000om4^dOoA;]402ooA;]42o`0000gocc3?00?o0000om/TfooK9=/0
0_oK9=/00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ofBKIo`00
0002om0_d0;o00002oo0?l000ol0003ocS7>olhacP0;olhacP03o`000?oC;=?odbcC00WodbcC00?o
0000olLhaol000002OnhAkP00ol0003odBkAom4^d@0<om4^d@03o`000?o?<<oocc3?00cocc3?00?o
0000om/TfooK9=/00ooK9=/00ol0003ohAkQon4Nh@09on4Nh@03o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003od2o@om0_d003om0_d0;o00002_o0?l000ol0003ocS7>olhacP0:olhacP03o`000?oC;=?o
dbcC00SodbcC1Ol00008okQ7^003o`000?oA;]7odBkA00codBkA00?o0000oll`coo?<<l02oo?<<l0
0ol0003ofbCKom/Tf`05om/Tf`03o`000?oQ7^7ohAkQ00SohAkQ00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001oo@;m02o`0000So`3o000?o0000olhac_o><Lh02_o><Lh00ol0003odbcCom</d`07om</
d`03o`000?o9=/WobCK900?obCK90ol00005okQ7^003o`000?oA;]7odBkA00_odBkA00?o0000oll`
coo?<<l03?o?<<l00ol0003ofbCKom/Tf`06om/Tf`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000Wod2o@00?o0000ol0o`?o0?l001Oo0?l02o`0000co
cS7>00?o0000om</dooC;=<01OoC;=<00ol0003obCK9olTfb@07olTfb@?o000000?o^4Nho`000?oA
;]403OoA;]400ol0003occ3?oll`c`0<oll`c`03o`000?oK9=_ofbCK00KofbCK00?o0000on4NhOoQ
7^401_oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?o@;m3od2o@00Ood2o@
0_l00004ol0o`003o`000?no@;oo_d2o00;o00002_o><Lh00ol0003odbcCom</d`03om</d`;o0000
3Oo9=/T2o`0000godBkA0ol0000=oll`c`03o`000?oK9=_ofbCK00OofbCK00?o0000on4NhOoQ7^40
1OoQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?o@;m3od2o@00Sod2o@0_l0
00000oo0?l3o0000okm0_`04okm0_`03o`000?o><LkocS7>00OocS7>00Co0000om</dooC;=?odbcC
0_l00002olHiaP03o`000?o9=/WobCK900cobCK93Ol00003okQ7^003o`000?o?<<oocc3?00[occ3?
00?o0000om/TfooK9=/02?oK9=/01?l0003ohAkQon4NhOoQ7^44o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003od2o@
om0_d009om0_d003o`000?no@;oo_d2o00Go_d2o0_l00008olhacP03o`000?oC;=?o000000GoaSW6
00?o0000olTfbOo9=/T02oo9=/T00ol0003oacS7olLha`09olLha`03o`000?nhAkSo^4Nh00;o^4Nh
0_l00009oll`c`03o`000?oK9=_ofbCK00[ofbCK0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?o@;m3od2o@00Sod2o@00?o0000okm0_ono@;l01ono@;l4o`0000?ocS7>0ol0
0007olHiaP03o`000?o9=/WobCK900[obCK900?o0000olLhaoo7><L02Oo7><L00ol0003o^4NhokQ7
^004okQ7^0;o00001oo?<<l00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?o@;m3od2o@00Ood2o@00?o0000okm0_ono@;l02?no@;l0
1?l0003o`Sg2ol8m`_o2?L83o`0000;o`cc300?o0000olHia_o6>LH01_o6>LH00ol0003obCK9olTf
b@08olTfb@03o`000?o7><OoacS700[oacS700?o0000okQ7^?nhAkP01_nhAkP00ol0003occ3?oll`
c`04oll`c`03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om0_d?o@;m001Oo@;m000ol0003o_d2ookm0_`08okm0_`03o`000?o2?L;o
`Sg200Co`Sg200Go0000ol<l`oo3?<?o`cc3o`000008olHiaP03o`000?o9=/WobCK900OobCK900?o
0000olLhaoo7><L02_o7><L00ol0003o^4NhokQ7^007okQ7^0;o00001?o?<<l00ol0003ofbCKom/T
f`08om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om0_d?o@;m000oo@;m00
0ol0003o_d2ookm0_`08okm0_`03o`000?o2?L;o`Sg200Co`Sg200?o0000ol<l`oo3?<<00_o3?<<0
0ol0003oaSW6olHiaP07olHiaP03o`000?o9=/WobCK900KobCK900?o0000olLhaoo7><L02_o7><L0
0ol0003o^4NhokQ7^009okQ7^005o`000?o?<<oocc3?oll`col000002OoK9=/00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_o_d2o00?o0000ol8m`_o2?L801?o2?L800ol0003o`cc3ol<l``03
ol<l``03o`000?o6>LKoaSW600OoaSW600?o0000olTfbOo9=/T01Oo9=/T00ol0003oacS7olLha`0:
olLha`03o`000?nhAkSo^4Nh00Wo^4Nh1?l00009om/Tf`03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oN8MkogR7N
omhQg_l000002_no@;l00ol0003o`Sg2ol8m`P05ol8m`P03o`000?o3?<?o`cc300?o`cc300?o0000
olHia_o6>LH02?o6>LH00ol0003obCK9olTfb@04olTfb@03o`000?o7><OoacS700WoacS700?o0000
okQ7^?nhAkP02?nhAkP2o`0000?of2OH00?o0000om/TfooK9=/01_oK9=/00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000omhQg_oN8Mh00ooN8Mh00ol0003o_d2ookm0_`06okm0_`03o`000?o2?L;o`Sg2
00Go`Sg200?o0000ol<l`oo3?<<01?o3?<<00ol0003oaSW6olHiaP09olHiaP03o`000?o9=/WobCK9
00;obCK900?o0000olLhaoo7><L02_o7><L00ol0003o^4NhokQ7^006okQ7^0;o00001_oH9mP8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ogR7NomhQgP05omhQgP03o`000?no@;oo_d2o00Go_d2o00?o0000ol8m`_o2
?L801Oo2?L800ol0003o`cc3ol<l``05ol<l``03o`000?o6>LKoaSW600WoaSW600Go0000olTfbOo9
=/WobCK9o`00000<olLha`03o`000?nhAkSo^4Nh00Co^4Nh0_l00008omPWf003o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oN8MkogR7N00OogR7N00?o0000okm0_ono
@;l00ono@;l00ol0003o`Sg2ol8m`P06ol8m`P03o`000?o3?<?o`cc300Go`cc300?o0000olHia_o6
>LH02_o6>LH00ol0003obCK9o`000004o`0000WoacS700?o0000okQ7^?nhAkP00_nhAkP2o`0000[o
f2OH00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ogR7NomhQgP07omhQgP03o`00
0?no@;oo_d2o00;o_d2o00?o0000ol8m`_o2?L801_o2?L800ol0003o`cc3ol<l``07ol<l``;o0000
2oo6>LH00ol0003oacS7olLha`03olLha`Oo00000_o7><L00ol0003o^4NhokQ7^002o`0000_of2OH
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omhQg_oN8Mh02OoN
8Mh01Ol0003o_d2ookm0_ono@;oo000000So`Sg200?o0000ol<l`oo3?<<01oo3?<<00ol0003odbcC
o`000002o`0000SoaSW600?o0000olLhaoo7><L02_o7><L5o`0000gof2OH00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<omhQgP03o`000?no@;oo000000Wo`Sg200?o
0000ol<l`oo3?<<01_o3?<<00ol0003odbcCom</d`03om</d`?o00001?o6>LH00ol0003oacS7olLh
a`0=olLha`03o`000?oH9mSof2OH00gof2OH00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ooj1OX2o`0000_ogR7N00?o0000ol8m`_o2?L801oo2?L800ol0003o`cc3ol<l``07
ol<l``03o`000?oC;=?odbcC00KodbcC0ol000000oo6>LKo0000olLha`0>olLha`03o`000?oH9mSo
f2OH00cof2OH00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00KonPGj0_l00009omhQ
gP03o`000?o2?L;o`Sg200;o`Sg21_l00008ol<l``03o`000?oC;=?odbcC00[odbcC00?o0000olLh
aoo7><L03oo7><L00ol0003of2OHomPWf00:omPWf0;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00So
nPGj0_l00007omhQgPGo00001_oR7N800ol0003o`cc3ol<l``05ol<l``03o`000?oC;=?odbcC00[o
dbcC00?o0000olLhaoo7><L03oo7><L00ol0003of2OHomPWf007omPWf0?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oj1O[onPGj00[onPGj0_l00005omhQgP03o`000?oR7N;ohQgR00WohQgR00?o0000ol<l`oo3
?<<00oo3?<<00ol0003odbcCom</d`0;om</d`03o`000?o7><OoacS700ooacS700?o0000omPWf?oH
9mP01OoH9mP2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5nP0<ooX5nP;o000000?ogR7No`000?l00000
3OoR7N800ol0003o`cc3ol<l``02ol<l``03o`000?oC;=?odbcC00_odbcC5?l00004omPWf0;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooX5n_oj1OX03_oj1OX00ol0003onPGjo`00000>on8MhP04o`000?o3?<?o`cc3o`0000kodbcC
00?o0000on@Ki?oT6n@04?oT6n@00ol0003of2OHo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5
nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000003_oR7N800ol0003o`cc3o`00000>om</d`03o`00
0?oT6nCoi1_T017oi1_T00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00conPGj00?o
0000ooX5n_oj1OX00_oj1OX00ol0003ohQgRon8MhP0=on8MhP03o`000?oC;=?odbcC00WodbcC1Ol0
000Bon@Ki0;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003ohQgRon8MhP0<on8MhP03o`000?oC;=?odbcC00;odbcC1ol00004ooX5nP03o`000?oT6nCo
i1_T00ooi1_T00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003onPGjooX5nP06ooX5
nP03o`000?oR7N;ohQgR00cohQgR1?l0000<ooX5nP03o`000?oT6nCoi1_T00coi1_T0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00Oo
nPGj00?o0000on8Mh_oR7N803?oR7N800ol0003onPGjooX5nP0=ooX5nP03o`000?oT6nCoi1_T00_o
i1_T00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ohQgRon8MhP0:on8MhP03o`000?oj1O[onPGj00konPGj00?o0000on@Ki?oT
6n@02OoT6n@2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP0?ooX5nP03o`000?oT6nCoi1_T00Koi1_T0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooX5n_l0003onPGj00gonPGj3?l0
000AooX5nP?o00001_oT6n@00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooT6n@2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000on@Ki?l000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool01ol00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo000<o`00o`;oool01_l00?l2oooo00?o003o00?oool0o`00ool00?l01_l0
0?l2oooo06go003o0Oooool007;o003o0_ooo`06o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03
o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000<o`00o`;oool01Ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000co003o0_ooo`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo0005o`00o`coool00_l00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1]o`00o`7ooooo001ao`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`05o`00o`coool0
00?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001`o`00o`;oool00_l0
0?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o
0oooo`04o`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool01?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00?o003o00?oool0o`00ool00?l00_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Co
ool0o`00ooooo`3oool01_l00?l00oooo`3o003oo`00o`03o`00o`;oool01?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00?o003o00?oool0o`00ool00?l00_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Co
ool0o`00ooooo`3oool01ol00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Co003o00?oool0o`00ooooo`000_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0007o`00o`;oool00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06go003o0Oooool006oo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00So003o00Coool0
o`00ool00?oo003o0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001_
o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00Wo003o00?oool0
o`00ool00?l00_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001^o`00
o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o003o00Coool0o`00
ooooo`3oool01?l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06go003o0Oooool0
06ko003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`0:o`00o`04oooo0?l00?ooool0
oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06go003o0Oooool006ko003o0_ooo`06o`00
o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l02?l00?l3oooo
00Go003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001]o`00o`7ooooo001]o`00o`?o
ool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Wo003o0_ooo`06o`00o`;o
ool00_l00?l2oooo00Go003o1Oooo`1]o`00o`7ooooo001/o`00o`Koool000?o003ooooo0?ooo`00
1Oooo`03o`00o`Goool09?l00?l2oooo00Oo003o1?ooo`1ho`00o`7ooooo003oo`00obco003o0Ooo
ool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(50) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.979 .021 .979 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.979 .021 .979 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.979 .021 .979 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.978 .022 .978 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.84 .16 .84 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.978 .022 .978 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.831 .169 .831 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.885 .115 .885 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.845 .155 .845 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.785 .215 .785 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.979 .021 .979 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.8 .2 .8 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.758 .242 .758 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.98 .02 .98 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.79 .21 .79 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.768 .232 .768 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.977 .023 .977 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.978 .022 .978 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.818 .182 .818 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.756 .244 .756 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.565 .435 .565 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.662 .338 .662 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.662 .338 .662 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.677 .323 .677 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.841 .159 .841 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.84 .16 .84 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.979 .021 .979 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.69 .31 .69 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.77 .23 .77 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.674 .326 .674 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.804 .196 .804 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.814 .186 .814 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.979 .021 .979 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.802 .198 .802 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.74 .26 .74 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.839 .161 .839 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.824 .176 .824 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.67 .33 .67 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.98 .02 .98 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.874 .126 .874 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.748 .252 .748 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.771 .229 .771 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.743 .257 .743 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.813 .187 .813 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.869 .131 .869 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.707 .293 .707 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.979 .021 .979 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.69 .31 .69 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.623 .377 .623 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.823 .177 .823 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.838 .162 .838 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.699 .301 .699 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.692 .308 .692 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.784 .216 .784 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.979 .021 .979 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.815 .185 .815 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.791 .209 .791 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.846 .154 .846 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.444 .556 .444 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.707 .293 .707 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.786 .214 .786 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.825 .175 .825 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.642 .358 .642 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.571 .429 .571 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.576 .424 .576 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.623 .377 .623 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.799 .201 .799 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.629 .371 .629 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.715 .285 .715 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.722 .278 .722 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.773 .227 .773 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.789 .211 .789 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.762 .238 .762 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.879 .121 .879 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.979 .021 .979 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.643 .357 .643 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.707 .293 .707 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.617 .383 .617 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.978 .022 .978 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.823 .177 .823 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.749 .251 .749 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.567 .433 .567 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.645 .355 .645 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.79 .21 .79 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.709 .291 .709 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.833 .167 .833 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.77 .23 .77 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.586 .414 .586 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.721 .279 .721 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.725 .275 .725 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.688 .312 .688 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.786 .214 .786 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.845 .155 .845 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.798 .202 .798 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.598 .402 .598 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.686 .314 .686 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.793 .207 .793 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.715 .285 .715 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.718 .282 .718 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.806 .194 .806 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.705 .295 .705 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.667 .333 .667 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.634 .366 .634 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.978 .022 .978 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.642 .358 .642 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.746 .254 .746 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.667 .333 .667 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.727 .273 .727 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.782 .218 .782 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.978 .022 .978 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.799 .201 .799 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.757 .243 .757 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.77 .23 .77 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.795 .205 .795 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.719 .281 .719 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.688 .312 .688 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.729 .271 .729 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.738 .262 .738 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.979 .021 .979 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.838 .162 .838 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.774 .226 .774 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.833 .167 .833 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.659 .341 .659 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.813 .187 .813 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.565 .435 .565 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.701 .299 .701 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.698 .302 .698 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.796 .204 .796 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.844 .156 .844 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.639 .361 .639 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.978 .022 .978 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.741 .259 .741 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.741 .259 .741 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.889 .111 .889 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.777 .223 .777 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.73 .27 .73 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.767 .233 .767 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.859 .141 .859 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.648 .352 .648 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.732 .268 .732 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.78 .22 .78 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.886 .114 .886 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.642 .358 .642 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.727 .273 .727 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.776 .224 .776 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.785 .215 .785 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.979 .021 .979 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.683 .317 .683 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.978 .022 .978 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.869 .131 .869 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.817 .183 .817 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.787 .213 .787 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.712 .288 .712 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.668 .332 .668 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.732 .268 .732 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.837 .163 .837 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.808 .192 .808 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.823 .177 .823 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.824 .176 .824 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.761 .239 .761 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.889 .111 .889 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.755 .245 .755 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.713 .287 .713 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.607 .393 .607 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.616 .384 .616 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.718 .282 .718 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.772 .228 .772 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.978 .022 .978 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.853 .147 .853 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.742 .258 .742 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.599 .401 .599 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.797 .203 .797 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.834 .166 .834 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.71 .29 .71 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.978 .022 .978 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.687 .313 .687 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.787 .213 .787 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.849 .151 .849 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.978 .022 .978 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.72 .28 .72 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.75 .25 .75 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.86 .14 .86 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.773 .227 .773 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.706 .294 .706 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.902 .098 .902 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.708 .292 .708 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.841 .159 .841 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.774 .226 .774 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.62 .38 .62 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.602 .398 .602 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.684 .316 .684 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.757 .243 .757 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.878 .122 .878 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.808 .192 .808 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.824 .176 .824 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.8 .2 .8 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.887 .113 .887 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.73 .27 .73 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.978 .022 .978 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.854 .146 .854 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.834 .166 .834 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.863 .137 .863 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.763 .237 .763 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.871 .129 .871 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.818 .182 .818 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.775 .225 .775 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.979 .021 .979 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.788 .212 .788 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.788 .212 .788 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.979 .021 .979 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.891 .109 .891 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.977 .023 .977 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.979 .021 .979 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.866 .134 .866 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.978 .022 .978 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.775 .225 .775 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.979 .021 .979 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.651 .349 .651 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.767 .233 .767 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.701 .299 .701 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.885 .115 .885 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.873 .127 .873 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.805 .195 .805 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.854 .146 .854 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.811 .189 .811 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.84 .16 .84 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.857 .143 .857 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.787 .213 .787 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.782 .218 .782 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.978 .022 .978 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.753 .247 .753 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.83 .17 .83 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.978 .022 .978 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.87 .13 .87 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.888 .112 .888 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.75 .25 .75 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.859 .141 .859 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.881 .119 .881 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.654 .346 .654 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.85 .15 .85 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.978 .022 .978 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.979 .021 .979 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.978 .022 .978 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.979 .021 .979 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.978 .022 .978 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.978 .022 .978 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ofRGJomXUf_l0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000omXUf_oJ9MX00_oJ9MX00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000omXUf_oJ9MX01OoJ9MX00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofRGJomXUfP06omXUfP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000omXUf_oJ9MX02?oJ9MX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oE:]Go0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cofRGJ00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omDZe@03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ogR7NomhQgP05omhQgP03o`000?oJ
9M[ofRGJ00_ofRGJ0ol00003om`Sg003o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omDZeOoE:]D00ooE:]D00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003ogR7NomhQgP06
omhQgP03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000om`Sg?oL8m`01?oL8m`00ol0003onPGjooX5nP0:
ooX5nP04o`000?oN8MkogR7NomhQgP;o00002_oj1OX2o`000003omlPgol0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeB[EomDZe@05omDZe@03o`000?oj1O[o
nPGj00WonPGj00?o0000om0_d?l000002ooj1OX00ol0003ogR7NomhQgP06omhQgP03o`000?oJ9M[o
fRGJ00WofRGJ00?o0000om`Sg?oL8m`01_oL8m`00ol0003onPGjooX5nP08ooX5nP03o`000?oN8Mko
gR7N00CogR7N0_l00005ooX5nP?o00001?oO8=l00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omDZe@03o`000?oj1O[onPGj00OonPGj0_l00003om0_
d003o`000?oj1O[onPGj00OonPGj00?o0000omhQg_oN8Mh01ooN8Mh00ol0003ofRGJomXUfP09omXU
fP03o`000?oL8mcog2?L00Oog2?L00?o0000ooX5n_oj1OX01Ooj1OX2o`0000WogR7N0_l000000ooj
1O[o0000o`000007omlPg`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omDZeOoE
:]D02?oE:]D00ol0003onPGjooX5nP06ooX5nP03o`000?o@;m3od2o@00?od2o@00?o0000ooX5n_oj
1OX01ooj1OX00ol0003ogR7NomhQgP08omhQgP03o`000?oJ9M[ofRGJ00OofRGJ00?o0000om`Sg?oL
8m`02OoL8m`00ol0003onPGjooX5nP03ooX5nP03o`000?oN8MkogR7N00_ogR7N00?o0000omlPgooO
8=l01ooO8=l00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHo`000005ooX5nP;o00002ooE:]D2o`0000KonPGj
00?o0000om0_d?o@;m001Oo@;m000ol0003onPGjooX5nP06ooX5nP03o`000?oN8MkogR7N00SogR7N
00?o0000omXUf_oJ9MX01_oJ9MX00ol0003og2?Lom`Sg00;om`Sg005o`000?oj1O[onPGjooX5n_l0
00003_oN8Mh00ol0003ogb3OomlPg`08omlPg`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oH9mSof2OHomPWf?l0
00000ooj1OX00ol0003oeB[EomDZe@0:omDZe@04o`000?oH9mSof2OHo`0000?onPGj0_l00008om0_
d003o`000?oj1O[onPGj00KonPGj00?o0000omhQg_oN8Mh02OoN8Mh00ol0003ofRGJomXUfP05omXU
fP03o`000?oL8mcog2?L00cog2?L00?o0000ooX5n_l000003ooN8Mh00ol0003ogb3OomlPg`08omlP
g`03o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPWf003omPWf003o`000?oj1O[o000000_o
eB[E0_l00004omPWf003o`000?oj1O[o000000_od2o@00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gR7NomhQgP09omhQgP03o`000?oJ9M[ofRGJ00CofRGJ00?o0000om`Sg?oL8m`03_oL8m`00ol0003o
gR7NomhQgP0>omhQgP03o`000?oO8=oogb3O00Wogb3O00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omPWf?oH9mP0
1?oH9mP00ol0003oeB[EomDZe@09omDZe@03o`000?oH9mSof2OH00Gof2OH00?o0000om0_d?o@;m00
2_o@;m000ol0003onPGjooX5nP05ooX5nP03o`000?oN8MkogR7N00[ogR7N00?o0000omXUf_oJ9MX0
0ooJ9MX00ol0003og2?Lom`Sg00>om`Sg003o`000?oN8MkogR7N00gogR7N00?o0000omlPgooO8=l0
2_oO8=l00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPW
f005omPWf003o`000?oE:]GoeB[E00OoeB[E0_l00008omPWf003o`000?o@;m3od2o@00_od2o@00?o
0000ooX5n_oj1OX01?oj1OX00ol0003ogR7NomhQgP0:omhQgP04o`000?oJ9M[ofRGJomXUfP?o0000
3ooL8m`00ol0003ogR7NomhQgP0>omhQgP03o`000?oO8=oogb3O00[ogb3O00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oH9mSof2OH00Oof2OH00?o0000omDZeOoE:]D01?oE:]D2o`0000_of2OH1?l0
0009om0_d003o`000?oj1O[onPGj00?onPGj00?o0000omhQg_oN8Mh02ooN8Mh01?l0003ofRGJo`00
0?l00003omDZe@;o00003?oL8m`2o`00013ogR7N00?o0000omlPgooO8=l02ooO8=l00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003of2OH
omPWf007omPWf003o`000?oE:]GoeB[E00?oeB[E00?o0000omPWf?oH9mP02ooH9mP01?l0003oeRWF
omHYe_oF:MH5o`0000God2o@00?o0000ooX5n_oj1OX00_oj1OX00ol0003ogR7NomhQgP0<omhQgP03
o`000?oE:]GoeB[E00GoeB[E0_l00008om`Sg0;o00000_o><Lh00ol0003ogR7NomhQgP0=omhQgP03
o`000?oO8=oogb3O00_ogb3O00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003of2OHomPWf009omPWf003o`000?oE:]GoeB[E00;o0000
3OoH9mP00ol0003oeRWFomHYeP07omHYePKo00000_oj1OX4o`0000gogR7N00?o0000omDZeOoE:]D0
1ooE:]D2o`0000Gog2?L00?o0000olhac_o><Lh00oo><Lh00ol0003ogR7NomhQgP0<omhQgP03o`00
0?oO8=oogb3O00cogb3O00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oH9mSof2OH00Wof2OH00?o
0000omDZeOl000003ooH9mP00ol0003oeRWFomHYeP0<omHYeP?o00001?oK9=/3o`0000WogR7N00?o
0000omDZeOoE:]D02_oE:]D2o`000003om`Sg?l0003o000000OocS7>00?o0000omhQg_oN8Mh02ooN
8Mh00ol0003ogb3OomlPg`0<omlPg`03o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oj1O[onPGj00KonPGj00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oH9mSof2OH00_of2OH00?o0000
omPWf?oH9mP03_oH9mP00ol0003oeRWFomHYeP0=omHYeP03o`000?oK9=_ofbCK00KofbCK0ol00005
omhQgP03o`000?oE:]GoeB[E00goeB[E00?o0000olhac_o><Lh02?o><Lh00ol0003ogR7NomhQgP09
omhQgP03o`000?oO8=oogb3O00gogb3O00Co0000ooX5n_oj1O[onPGj1Ol00003on<Lh`03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
omPWf?oH9mP02ooH9mP2o`0000oof2OH00?o0000omHYe_oF:MH03OoF:MH00ol0003ofbCKom/Tf`0:
om/Tf`?o000000?ogR7No`000?oE:]D03ooE:]D00ol0003ocS7>olhacP09olhacP03o`000?oN8Mko
gR7N00SogR7N00?o0000omlPgooO8=l03_oO8=l3o`0000SohacS00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oH9mSof2OH00Sof2OH0ol000000oo9
=/Wo0000omPWf00>omPWf003o`000?oF:MKoeRWF00goeRWF00?o0000om/TfooK9=/03OoK9=/00ol0
003oeB[EomDZe@0?omDZe@03o`000?o><LkocS7>00[ocS7>2ol0000;omlPg`Go00003?oS7><00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02_oj1OX01Ol0003ogb3Oo`000?oj1O[o0000
00Sof2OH0ol00005olTfb@03o`000?oH9mSof2OH00cof2OH00?o0000omHYe_oF:MH03OoF:MH00ol0
003ofbCKom/Tf`0=om/Tf`;o00004?oE:]D00ol0003ocS7>olhacP0:olhacP03o`000?oA;]7odBkA
00OodBkA00?o0000omlPgooO8=l00_oO8=l7o`0000CocS7>00?o0000on<LhooS7><02_oS7><00ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02Ooj1OX01?l0003ogb3OomlPgooO8=l2o`00
00Gof2OH0ol00009olTfb@;o00002ooH9mP00ol0003oeRWFomHYeP0=omHYeP03o`000?oK9=_ofbCK
00gofbCK00Co0000on<LhooS7>?o00003ooE:]D00ol0003ocS7>olhacP09olhacP03o`000?oA;]7o
dBkA00WodBkA1?l0000;olhacP03o`000?oS7>?ohacS00[ohacS00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5
nP03o`000?oj1O[onPGj00SonPGj00?o0000omlPgooO8=l01?oO8=l00ol0003of2OHo`000002o`00
00cobCK900Co0000om8]d_l0003o00002OoH9mP00ol0003oeRWFomHYeP0=omHYeP03o`000?oK9=_o
fbCK00gofbCK00Go0000on<LhooS7>?ohacSo`00000=omDZe@03o`000?o><LkocS7>00[ocS7>00?o
0000om4^dOoA;]402OoA;]400ol0003ocS7>olhacP0<olhacP03o`000?oS7>?ohacS00[ohacS00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000omlPgooO8=l01_oO8=l0
0ol0003obCK9olTfb@0<olTfb@03o`000?oB;M;odRgB00;odRgB0_l00007omPWf003o`000?oF:MKo
eRWF00coeRWF00?o0000om/TfooK9=/03OoK9=/00ol0003ohacSon<Lh`03on<Lh`03o`000?oE:]Go
eB[E00[oeB[E00?o0000olhac_o><Lh02_o><Lh00ol0003odBkAom4^d@09om4^d@03o`000?o><Lko
cS7>00cocS7>00?o0000on<LhooS7><02ooS7><00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5
n_oj1OX01_oj1OX00ol0003ogb3OomlPg`06omlPg`03o`000?o9=/WobCK900_obCK900?o0000om8]
d_oB;M801OoB;M800ol0003of2OHomPWf003omPWf003o`000?oF:MKoeRWF00goeRWF00?o0000om/T
fooK9=/03OoK9=/00ol0003ohacSon<Lh`04on<Lh`03o`000?oE:]GoeB[E00WoeB[E00?o0000olha
c_o><Lh02Oo><Lh00ol0003odBkAom4^d@0:om4^d@03o`000?o><LkocS7>00cocS7>00?o0000on<L
hooS7><02ooS7><00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gb3OomlPg`07omlPg`03o`000?o9=/WobCK900_obCK900?o0000om8]d_oB;M801_oB;M82o`0000?o
f2OH00?o0000omHYe_oF:MH03OoF:MH00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oS7>?ohacS00Ko
hacS00?o0000omDZeOoE:]D02?oE:]D00ol0003ocS7>olhacP09olhacP03o`000?oA;]7odBkA00[o
dBkA00?o0000olhac_o><Lh03?o><Lh00ol0003ohacSon<Lh`0;on<Lh`03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooX5nP03o`00
0?oj1O[onPGj00ConPGj00?o0000omlPgooO8=l02?oO8=l00ol0003obCK9olTfb@0:olTfb@03o`00
0?oB;M;odRgB00WodRgB0_l000000ooH9mSo0000omHYeP0<omHYeP?o00003_oK9=/00ol0003ohacS
on<Lh`07on<Lh`03o`000?oE:]GoeB[E00OoeB[E00?o0000olhac_o><Lh02Oo><Lh00ol0003odBkA
om4^d@0;om4^d@03o`000?o><LkocS7>00cocS7>00?o0000on<LhooS7><02_oS7><00ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000omlPgooO8=l02_oO8=l00ol0003obCK9olTf
b@09olTfb@03o`000?oB;M;odRgB00_odRgB00?o0000omHYe_oF:MH02_oF:MH2o`0000?of2OH00?o
0000om/TfooK9=/02_oK9=/00ol0003ohacSon<Lh`09on<Lh`03o`000?oE:]GoeB[E00KoeB[E00?o
0000olhac_o><Lh02?o><Lh00ol0003odBkAom4^d@0<om4^d@03o`000?o><LkocS7>00cocS7>00?o
0000on<LhooS7><02_oS7><00ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ooj1OX0
0ol0003onPGjooX5nP02ooX5nP03o`000?oO8=oogb3O00_ogb3O00?o0000olTfbOo9=/T02?o9=/T0
0ol0003odRgBom8]dP0<om8]dP03o`000?oF:MKoeRWF00SoeRWF0_l00006omPWf0;o00002_oK9=/0
0ol0003ohacSon<Lh`0:on<Lh`03o`000?oE:]GoeB[E00GoeB[E00?o0000olhac_o><Lh02?o><Lh0
0ol0003odBkAom4^d@0<om4^d@03o`000?o><LkocS7>00cocS7>00?o0000on<LhooS7><02ooS7><0
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?onPGj00Go0000ooX5n_oj1O[onPGjo`00000=
omlPg`03o`000?o9=/WobCK900OobCK900?o0000om8]d_oB;M803_oB;M800ol0003oeRWFomHYeP04
omHYeP?o00002_oH9mP00ol0003ofbCKom/Tf`07om/Tf`03o`000?oS7>?ohacS00_ohacS00?o0000
omDZeOoE:]D00ooE:]D00ol0003ocS7>olhacP09olhacP03o`000?oA;]7odBkA00codBkA00?o0000
olhac_o><Lh03?o><Lh00ol0003ohacSon<Lh`0;on<Lh`;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003ogb3OomlPg`0<omlPg`03o`000?o9=/WobCK900OobCK900?o0000om8]d_oB;M803ooB;M801?l0
003oeRWFomHYe_oF:MH2o`0000kof2OH0_l00006om/Tf`03o`000?oS7>?ohacS00gohacS00?o0000
omDZeOoE:]D00_oE:]D00ol0003ocS7>olhacP08olhacP03o`000?oA;]7odBkA00codBkA0ol0000=
olhacP03o`000?oS7>?ohacS00_ohacS00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00oogb3O00?o0000olTfbOo9=/T01_o9=/T00ol0003odRgBom8]dP0@om8]dPCo00004_oH9mP00ol0
003ofbCKom/Tf`03om/Tf`03o`000?oS7>?ohacS00kohacS00Go0000omDZeOoE:]GoeB[Eo`000005
olhacPOo00003?oA;]401Ol0003oaSW6olHia_o6>LKo000000cocS7>00?o0000on<LhooS7><02?oS
7><3o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000oogb3O00?o0000olTfbOo9=/T01_o9=/T00ol0003odRgBom8]dP0=
om8]dP?o000000CobSG:o`000?l0003o00004ooH9mP2o`0000;ofbCK00?o0000on<LhooS7><04?oS
7><00ol0003oeB[Eo`000006o`0000OohacS00?o0000om4^dOoA;]402?oA;]400ol0003oaSW6olHi
aP03olHiaP;o00002?o><Lh3o`0000KohacS1?l00002on4Nh@03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003odBkAo`000?o=</d3o`0000gogb3O00?o0000olTfbOo9=/T01?o9=/T00ol0003odRgBom8]
dP0;om8]dP?o00000oo:=LX01Ol0003obcC;o`000?o<<lco000001Cof2OH00?o0000om/Tfol00000
4ooS7><00ol0003ohacSon<Lh`0=on<Lh`03o`000?oA;]7odBkA00GodBkA0_l00008olHiaP03o`00
0?o><LkocS7>00Go00000oo?<<l00ol0003ohacSon<Lh`03o`0000OohAkQ00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oA;]7odBkAo`0000CocC;=0ol0000:omlPg`03o`000?o9=/WobCK900?obCK9
00?o0000om8]d_oB;M802OoB;M83o`0000GobSG:00Co0000ol/dboo;=<_o00000_o<<l`00ol0003o
f2OHomPWf00BomPWf003o`000?oS7>?ohacS01;ohacS00?o0000on<LhooS7><03_oS7><00ol0003o
dBkAom4^d@03om4^d@03o`000?o6>LKoaSW600WoaSW60_l00009oll`c`;o00002_oQ7^400ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000om4^dOoA;]7odBkAo`000007oldbc@;o00001ooO8=l5o`0000;o
bCK900?o0000om8]d_oB;M801_oB;M83o`0000SobSG:00Co0000ol/dboo;=<_o00000oo<<l`00ol0
003of2OHomPWf00AomPWf003o`000?oS7>?ohacS017ohacS00?o0000on<LhooS7><04?oS7><01Ol0
003odBkAom4^dOoA;]7o000000coaSW600?o0000oll`coo?<<l02?o?<<l00ol0003ohAkQon4Nh@0:
on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CodBkA00?o0000oldbcOo=</d01oo=</d3o`00
0004omlPgol0003o0000o`0000God2o@0_l00006om8]dP?o00002_o:=LX01Ol0003obcC;ol/dboo;
=<_o000000Coc3?<00?o0000omPWf?oH9mP04?oH9mP00ol0003ohacSon<Lh`0Aon<Lh`03o`000?oS
7>?ohacS017ohacS00?o0000om4^dOl000003Oo6>LH00ol0003occ3?oll`c`08oll`c`03o`000?oQ
7^7ohAkQ00[ohAkQ00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oA;]7odBkA00CodBkA00?o0000
oldbcOo=</d02_o=</d00ol0003od2o@om0_d008om0_d003o`000?oB;M;odRgB00?o00003Oo:=LX0
1Ol0003obcC;ol/dboo;=<_o000000Goc3?<00?o0000omPWf?oH9mP03ooH9mP00ol0003ohacSon<L
h`0Aon<Lh`03o`000?oS7>?ohacS01;ohacS00?o0000olHia_o6>LH03?o6>LH00ol0003occ3?oll`
c`08oll`c`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000om4^dOoA;]401OoA;]40
0ol0003ocC;=oldbc@0:oldbc@03o`000?o@;m3od2o@00Wod2o@0_l0000?olXebP03o`000?o;=<_o
bcC;00;obcC;00?o0000ol`cc?o<<l`01?o<<l`00ol0003of2OHomPWf00=omPWf0?o00004OoS7><0
0ol0003ohacSon<Lh`0Con<Lh`03o`000?o6>LKoaSW600_oaSW600?o0000oll`coo?<<l02Oo?<<l0
0ol0003ohAkQon4Nh@0;on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oA;]40
0ol0003ocC;=oldbc@0:oldbc@03o`000?o@;m3od2o@00Wod2o@00?o0000olXeb_o:=LX03Oo:=LX0
0ol0003obcC;ol/db`03ol/db`03o`000?o<<lcoc3?<00Goc3?<00?o0000omPWf?oH9mP02_oH9mP2
o`0000?ohQgR00?o0000on<LhooS7><03_oS7><00ol0003ohacSon<Lh`0Con<Lh`03o`000?o6>LKo
aSW600_oaSW600?o0000oll`coo?<<l02Oo?<<l00ol0003ohAkQon4Nh@0;on4Nh@03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000om4^dOoA;]401ooA;]42o`0000_ocC;=00?o0000om0_
d?o@;m002oo@;m000ol0003obSG:olXebP0<olXebP03o`000?o;=<_obcC;00?obcC;00?o0000ol`c
c?o<<l`01_o<<l`00ol0003of2OHomPWf007omPWf0;o00001_oR7N82o`0000kohacS00?o0000on<L
hooS7><04ooS7><00ol0003oaSW6olHiaP0;olHiaP03o`000?o?<<oocc3?00Wocc3?00?o0000on4N
hOoQ7^403?oQ7^400ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009om4^
d@03o`000?n@Ki3o000000_ocC;=00?o0000om0_d?o@;m002oo@;m000ol0003obSG:olXebP0;olXe
bP03o`000?o;=<_obcC;00CobcC;00?o0000ol`cc?o<<l`01oo<<l`00ol0003of2OHomPWf005omPW
f003o`000?oR7N;ohQgR00SohQgR00?o0000on<LhooS7><02_oS7><00ol0003ohacSon<Lh`0Don<L
h`03o`000?o6>LKoaSW600_oaSW600?o0000oll`coo?<<l02Oo?<<l00ol0003ohAkQon4Nh@0<on4N
h@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009om4^d@04o`000?n@Ki3oT6n@o`00
00_ocC;=00?o0000om0_d?o@;m002oo@;m000ol0003obSG:olXebP0;olXebP03o`000?o;=<_obcC;
00CobcC;00?o0000ol`cc?o<<l`02?o<<l`00ol0003of2OHomPWf002omPWf0;o00003?oR7N82o`00
00[ohacS00?o0000on<LhooS7><05?oS7><00ol0003oaSW6olHiaP0;olHiaP03o`000?o?<<oocc3?
00Wocc3?00?o0000on4NhOoQ7^403OoQ7^400ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003odBkAom4^d@07om4^d@03
o`000?n@Ki3oT6n@00;oT6n@00?o0000oldbcOo=</d02?o=</d00ol0003od2o@om0_d00<om0_d003
o`000?o:=L[obSG:00WobSG:00?o0000ol/dboo;=</01Oo;=</00ol0003oc3?<ol`cc009ol`cc004
o`000?oH9mSo0000o`00013ohQgR0_l00008on<Lh`03o`000?oS7>?ohacS01CohacS0ol0000;olHi
aP03o`000?o?<<oocc3?00Wocc3?00?o0000on4NhOoQ7^403OoQ7^401?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003odBkAom4^d@06om4^d@03o`000?n@Ki3oT6n@00?oT6n@00?o0000oldb
cOo=</d02?o=</d00ol0003od2o@om0_d00;om0_d0;o00002_o:=LX00ol0003obcC;ol/db`06ol/d
b`03o`000?o<<lcoc3?<00[oc3?<00?o0000on8Mh_oR7N804_oR7N800ol0003ohacSon<Lh`04on<L
h`03o`000?oS7>?ohacS01GohacS00?o0000omdRgOoM8]d01Ol00005olHiaP03o`000?o?<<oocc3?
00[occ3?00?o0000on4NhOoQ7^403_oQ7^43o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkAom4^d@04om4^d@03
o`000?n@Ki3oT6n@00CoT6n@00?o0000oldbcOo=</d01oo=</d00ol0003od2o@om0_d00;om0_d004
o`000?oC;=?odbcCo`0000WobSG:00?o0000ol/dboo;=</01_o;=</00ol0003oc3?<ol`cc00:ol`c
c003o`000?oR7N;ohQgR01?ohQgR0_l00003on<Lh`Co00005?oS7><00ol0003ogB;MomdRg@06omdR
g@Co000000?oaSW6o`000?o?<<l02oo?<<l00ol0003ohAkQon4Nh@0>on4Nh@03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003odBkAom4^d@03om4^d@03o`000?n@Ki3oT6n@00GoT6n@00?o0000oldbcOo=
</d01oo=</d00ol0003od2o@om0_d009om0_d0;o00001?oC;=<00ol0003obSG:olXebP05olXebP03
o`000?o;=<_obcC;00OobcC;00?o0000ol`cc?o<<l`02_o<<l`00ol0003ohQgRon8MhP0Eon8MhP03
o`000?oS7>?o000000CoiQWV0ol0000@on<Lh`03o`000?oM8]gogB;M00_ogB;M0_l0000<oll`c`03
o`000?oQ7^7ohAkQ00cohAkQ0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]400_oA;]400ol0003oT6n@
oi1_T006oi1_T003o`000?o=</gocC;=00OocC;=00?o0000om0_d?o@;m002?o@;m000ol0003odbcC
om</d`05om</d`03o`000?o:=L[obSG:00CobSG:00?o0000ol/dboo;=</01oo;=</00ol0003oc3?<
ol`cc00:ol`cc003o`000?oR7N;ohQgR01KohQgR00?o0000onHIi_oV6NH01_oV6NH3o`0000cohacS
00?o0000omdRgOoM8]d03OoM8]d00ol0003occ3?oll`c`09oll`c`Go00002OoQ7^42o`000003omTV
fOl0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003om4^dOl0003oT6n@00WoT6n@00?o0000oldbcOo=</d01_o=
</d00ol0003od2o@om0_d007om0_d003o`000?oC;=?odbcC00OodbcC00?o0000olXeb_o:=LX00_o:
=LX00ol0003obcC;ol/db`08ol/db`03o`000?o<<lcoc3?<00Woc3?<00?o0000on8Mh_oR7N805ooR
7N800ol0003oiQWVonHIiP09onHIiP?o00002OoS7><00ol0003ogB;MomdRg@0>omdRg@Ko00001?o?
<<l00ol0003o_cnooklo_`03oklo_`Go00000_oQ7^42o`0000CofBKI00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o8=lSob3O8olPgb?l000002on@Ki000ol0003ocC;=oldbc@06oldbc@03o`000?o@
;m3od2o@00God2o@0_l0000;om</d`04o`000?o:=L[obSG:o`0000_obcC;00?o0000ol`cc?o<<l`0
2Oo<<l`00ol0003ohQgRon8MhP0Fon8MhP03o`000?oV6NKoiQWV00goiQWV0ol00005on<Lh`03o`00
0?oM8]gogB;M00oogB;M00?o0000omXUf_oJ9MX00ooJ9MX4o`0000_o_cno0_l00006omTVf@03o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003ob3O8olPgb002olPgb0ko00001_o=</d00ol0003od2o@om0_
d005om0_d003o`000?oC;=?odbcC00codbcC00?o0000olXeb_l000002oo;=</00ol0003oc3?<ol`c
c007ol`cc0?o00006?oR7N800ol0003oiQWVonHIiP0@onHIiP?o000000?ohacSo`000?oM8]d04?oM
8]d00ol0003ofRGJomXUfP07omXUfP03o`000?no?koo_cno00[o_cno00?o0000omTVfOoI9]T01OoI
9]T00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olPgb003o`000?nYEZWoZEJY00_oZEJY0_l00004
oldbc@03o`000?o@;m3od2o@00?od2o@0_l0000@om</d`03o`000?o;=<_obcC;00[obcC;00?o0000
ol`cc?o<<l`00oo<<l`4o`0000;oaSW600?o0000on8Mh_oR7N805OoR7N800ol0003oiQWVonHIiP0D
onHIiP03o`000?oM8]gogB;M013ogB;M00?o0000omXUf_oJ9MX01ooJ9MX00ol0003o_cnooklo_`0:
oklo_`03o`000?oI9]WofBKI00GofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o8=lSob3O8
00Gob3O800?o0000ojUFZOnYEZT03OnYEZT6o`0000?od2o@00?o0000om</dooC;=<04?oC;=<00ol0
003obcC;ol/db`0:ol/db`03o`000?o<<lco000000?o00001oo6>LH00ol0003ohQgRon8MhP0Don8M
hP03o`000?oV6NKoiQWV01CoiQWV00?o0000omdRgOoM8]d03ooM8]d00ol0003ofRGJomXUfP08omXU
fP03o`000?no?koo_cno00[o_cno00?o0000omTVfOoI9]T01OoI9]T00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olPgb?o8=lP01_o8=lP00ol0003oZEJYojUFZ@0=ojUFZ@03o`000?oF:MKoeRWF00?o
eRWF00?o0000om0_d?l000004ooC;=<4o`0000WobcC;0_l0000<olHiaP03o`000?oR7N;ohQgR01?o
hQgR00?o0000onHIi_oV6NH05OoV6NH00ol0003ogB;MomdRg@0>omdRg@03o`000?oJ9M[ofRGJ00So
fRGJ00?o0000oklo_ono?kl02Ono?kl00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o8=lSob3O800Sob3O800?o0000ojUFZOnYEZT02onYEZT00ol0003oeRWFomHYeP05omHYeP03o`00
0?oC;=?odbcC01;odbcC00Co0000ol`cc?o<<lcoc3?<1Ol00003ol/db`03o`000?o6>LKoaSW600go
aSW60ol0000@on8MhP;o00006?oV6NH00ol0003ogB;MomdRg@0=omdRg@03o`000?oJ9M[ofRGJ00Wo
fRGJ00?o0000oklo_ono?kl02Ono?kl00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_ob3O800?o0000ojUFZOnYEZT02_nYEZT00ol0003oeRWFomHYeP06omHYeP03o`00
0?oC;=?odbcC017odbcC00?o0000ol`cc?o<<l`01oo<<l`3o`00013oaSW600?o0000ol@ka?o4>l@0
1Ol00009on8MhP;o000000?ocS7>o`000?oV6NH05ooV6NH00ol0003ogB;MomdRg@0=omdRg@03o`00
0?oJ9M[ofRGJ00WofRGJ00?o0000oklo_ono?kl02?no?kl2o`0000[ofBKI00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oD:mCoe2_D00;oe2_D00?o0000olPgb?o8=lP02Oo8=lP00ol0003oZEJYojUF
Z@0:ojUFZ@03o`000?oF:MKoeRWF00OoeRWF00?o0000om</dooC;=<03ooC;=<00ol0003oc3?<ol`c
c00:ol`cc003o`000?o6>LKoaSW600goaSW600?o0000ol@ka?o4>l@01_o4>l@4o`0000CohQgR00?o
0000olhac_o><Lh00_o><Lh00ol0003oiQWVonHIiP0FonHIiP03o`000?oM8]gogB;M00_ogB;M00?o
0000omXUf_oJ9MX02ooJ9MX00ol0003o_cnooklo_`06oklo_`03o`000?nWF:Oo000000[ofBKI00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oD:mCoe2_D00?oe2_D00?o0000olPgb?o8=lP02?o8=lP=
o`0000[oeRWF00?o0000om</dooC;=<03ooC;=<00ol0003oc3?<ol`cc00;ol`cc003o`000?o6>LKo
aSW600coaSW600?o0000ol@ka?o4>l@02_o4>l@4o`0000GocS7>00?o0000onHIi_oV6NH05_oV6NH0
0ol0003ogB;MomdRg@0:omdRg@03o`000?oJ9M[ofRGJ00cofRGJ00?o0000oklo_ono?kl01?no?kl2
o`0000?oYeRW00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000om@[
e?oD:m@00ooD:m@00ol0003ob3O8olPgb007olPgb003o`000?nYEZWoZEJY00WoZEJY00?o0000omHY
e_oF:MH02OoF:MH00ol0003odbcCom</d`0=om</d`03o`000?o<<lcoc3?<00coc3?<00?o0000olHi
a_o6>LH03?o6>LH00ol0003oa3_4ol@ka00;ol@ka003o`000?nfBKKo000000KocS7>00?o0000onHI
i_oV6NH05_oV6NH00ol0003ogB;MomdRg@09omdRg@03o`000?oJ9M[ofRGJ00cofRGJ00?o0000oklo
_ono?kl00ono?kl00ol0003oYeRWojMHY`03ojMHY`03o`000?oI9]WofBKI00SofBKI00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oD:mCoe2_D00Coe2_D00?o0000olPgb?o8=lP01_o8=lP00ol0003o
ZEJYojUFZ@08ojUFZ@03o`000?oF:MKoeRWF00_oeRWF00?o0000om</dooC;=<02?oC;=<4o`0000oo
c3?<00?o0000olHia_o6>LH02oo6>LH00ol0003oa3_4ol@ka00;ol@ka004o`000?nfBKKo]TVfo`00
00OocS7>00?o0000onHIi_oV6NH05OoV6NH00ol0003ogB;MomdRg@08omdRg@03o`000?oJ9M[ofRGJ
00gofRGJ00?o0000oklo_ono?kl00_no?kl00ol0003oYeRWojMHY`05ojMHY`03o`000?oI9]WofBKI
00OofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oD:mCoe2_D00Goe2_D00?o0000olPgb?o8
=lP01Oo8=lP00ol0003oZEJYojUFZ@08ojUFZ@03o`000?oF:MKoeRWF00_oeRWF00?o0000om</dooC
;=<00ooC;=<5o`0000?oc3?<00?o0000ol`cc?o<<l`03_o<<l`00ol0003oaSW6olHiaP0:olHiaP03
o`000?o4>lCoa3_400[oa3_400Go0000okI9]_nfBKKo]TVfo`000007olhacP03o`000?oV6NKoiQWV
01GoiQWV00?o0000omdRgOoM8]d02?oM8]d00ol0003ofRGJomXUfP0=omXUfP03o`000?no?koo_cno
00;o00002?nWF:L00ol0003ofBKIomTVf@08omTVf@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oe2_Dom@[e005om@[e003o`000?o8=lSob3O800Go
b3O800?o0000ojUFZOnYEZT02?nYEZT00ol0003oeRWFomHYeP0<omHYePGo00002Oo<<l`00ol0003o
c3?<ol`cc00<ol`cc0;o00003?o6>LH00ol0003oa3_4ol@ka00:ol@ka005o`000?nfBKKo]TVfokI9
]_l000002?o><Lh00ol0003oiQWVonHIiP0DonHIiP?o00001ooM8]d00ol0003ofRGJomXUfP0>omXU
fP03o`000?no?koo000000_oYeRW00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000om@[e?oD:m@01OoD:m@00ol0003ob3O8olPgb004olPgb003o`000?nYEZWoZEJY00Oo
ZEJY00?o0000omHYe_oF:MH03?oF:MH01?l0003odRgBom8]d_l0000;ol`cc003o`000?o<<lcoc3?<
00_oc3?<00Co0000okA;]?ndBkCo00002_o6>LH00ol0003oa3_4ol@ka00:ol@ka003o`000?nfBKKo
]TVf00;o]TVf00?o0000olhac_o><Lh01_o><Lh00ol0003oiQWVonHIiP0AonHIiP?o00000ooB;M80
0ol0003ogB;MomdRg@04omdRg@03o`000?oJ9M[ofRGJ00gofRGJ1?l0000;ojMHY`03o`000?oI9]Wo
fBKI00GofBKI00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oD:mCoe2_D00Koe2_D00Co0000olPg
b?o8=lSob3O81?l00008ojUFZ@03o`000?oF:MKoeRWF00_oeRWF00?o0000om8]d_oB;M800_oB;M80
0ol0003oc3?<ol`cc008ol`cc003o`000?o<<lcoc3?<00[oc3?<00?o0000okA;]?ndBk@00_ndBk@0
0ol0003oaSW6olHiaP03olHiaPGo00002oo4>l@00ol0003o]TVfokI9]P03okI9]P03o`000?o><Lko
cS7>00OocS7>00?o0000onHIi_oV6NH03_oV6NH2o`0000OodRgB00?o0000omdRgOoM8]d00_oM8]d0
0ol0003ofRGJomXUfP0=omXUfP03o`000?o0?l3o`3o000;o`3o000?o0000ojMHYonWF:L02OnWF:L0
0ol0003ofBKIomTVf@03omTVf@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oe2_Dom@[e007om@[
e0?o00001?o<<l`00ol0003oZEJYojUFZ@05ojUFZ@03o`000?oF:MKoeRWF00[oeRWF00?o0000om8]
d_oB;M800ooB;M800ol0003oc3?<ol`cc009ol`cc003o`000?o<<lcoc3?<00Soc3?<00?o0000okA;
]?ndBk@01?ndBk@5o`0000CoT6n@00?o0000ol@ka?o4>l@02Oo4>l@00ol0003o]TVfokI9]P03okI9
]P03o`000?o><LkocS7>00SocS7>00?o0000onHIi_oV6NH02_oV6NH3o`0000[odRgB00Go0000omdR
gOoM8]gogB;Mo`00000>omXUfP03o`000?o0?l3o`3o000Co`3o00_l00009ojMHY`03o`000?oI9]Wo
fBKI00;ofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oD:mCoe2_D00Ooe2_D00?o0000ol`c
c?o<<l`01Oo<<l`00ol0003oZEJYojUFZ@03ojUFZ@03o`000?oF:MKoeRWF00[oeRWF00?o0000om8]
d_oB;M801?oB;M800ol0003oc3?<ol`cc009ol`cc003o`000?o<<lcoc3?<00Ooc3?<00?o0000okA;
]?ndBk@01OndBk@00ol0003oT6n@oi1_T007oi1_T003o`000?o4>lCoa3_400Ooa3_400?o0000okI9
]_nfBKH01?nfBKH00ol0003ocS7>olhacP08olhacP03o`000?oV6NKoiQWV00SoiQWV0_l0000>om8]
dPCo00003?oJ9MX2o`0000Wo`3o000?o0000ojMHYonWF:L01onWF:L01?l0003ofBKIomTVfOl0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000om@[e?oD:m@01OoD:m@00ol0003oc3?<ol`cc007ol`cc0;o00000onYEZT00ol0
003oeRWFomHYeP09omHYeP03o`000?oB;M;odRgB00KodRgB00?o0000ol`cc?o<<l`02Oo<<l`00ol0
003oc3?<ol`cc005ol`cc003o`000?ndBkCo]4^d00Ko]4^d00?o0000oi1_T?n@Ki002?n@Ki000ol0
003oa3_4ol@ka006ol@ka003o`000?nfBKKo]TVf00Co]TVf00?o0000olhac_o><Lh02Oo><Lh4o`00
00?oiQWV0ol0000@om8]dP05o`000?oT6nCoi1_Ton@Ki?l000002_oJ9MX00ol0003o`3o0ol0o`00:
ol0o`0Ko00000onWF:L00ol0003ofBKIo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000om@[e?oD:m@01?oD:m@00ol0
003oc3?<ol`cc00:ol`cc004o`000?nYEZWoZEJYo`0000[oeRWF00?o0000om8]d_oB;M801ooB;M80
0ol0003oc3?<ol`cc009ol`cc003o`000?o<<lcoc3?<00Coc3?<00?o0000okA;]?ndBk@01ondBk@0
0ol0003oT6n@oi1_T008oi1_T0;o00001_o4>l@00ol0003o]TVfokI9]P05okI9]P03o`000?o><Lko
cS7>00WocS7>00Co0000olDjaOo5>/GoaC[50ol0000Bom8]dP03o`000?oT6nCoi1_T00?oi1_T0_l0
0006omXUfP;o00003Oo0?l000ol0003ofbCKom/Tf`03om/Tf`Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000om@[e?oD:m@00ooD:m@0
0ol0003oc3?<ol`cc00<ol`cc0;o00002_oF:MH00ol0003odRgBom8]dP08om8]dP03o`000?o<<lco
c3?<00[oc3?<00?o0000ol`cc?o<<l`00_o<<l`00ol0003o]4^dokA;]008okA;]003o`000?n@Ki3o
T6n@00KoT6n@0_l00002ok9=/P03o`000?o4>lCoa3_400;oa3_400?o0000okI9]_nfBKH01_nfBKH0
0ol0003ocS7>olhacP08olhacP03o`000?o5>/GoaC[500CoaC[500?o0000om8]d_oB;M803ooB;M80
0ol0003oi1_Ton@Ki006on@Ki0;o00000ooJ9MX00ol0003o`3o0ol0o`00=ol0o`003o`000?oK9=_o
fbCK00OofbCK0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003oe2_Dom@[e002om@[e003o`000?o<<lcoc3?<
00koc3?<00?o0000omHYe_oF:MH01ooF:MH00ol0003odRgBom8]dP0:om8]dP03o`000?o<<lcoc3?<
00Woc3?<00Go0000ol`cc?o<<lcoc3?<o`00000;okA;]003o`000?n@Ki3oT6n@00CoT6n@0_l00005
ok9=/P05o`000?o4>lCoa3_4ol@ka?l000002?nfBKH00ol0003ocS7>olhacP08olhacP03o`000?o5
>/GoaC[500GoaC[500?o0000om8]d_oB;M803_oB;M800ol0003oi1_Ton@Ki008on@Ki003o`000?oJ
9M[o000000oo`3o000?o0000om/TfooK9=/02?oK9=/01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oD:mCoe2_Do`00017oc3?<00?o0000omHYe_oF:MH01_oF:MH00ol0003odRgB
om8]dP0;om8]dP03o`000?o<<lcoc3?<00Woc3?<00Co0000ol`cc?o<<lco00003?ndBk@00ol0003o
T6n@oi1_T002oi1_T0;o00002?nbCK800ol0003oa3_4o`000009okI9]P03o`000?o><LkocS7>00So
cS7>00?o0000olDjaOo5>/D01Oo5>/D00ol0003odRgBom8]dP0=om8]dP03o`000?oT6nCoi1_T00[o
i1_T00?o0000ol0o`?o0?l003_o0?l000ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000Bol`cc003o`00
0?oF:MKoeRWF00CoeRWF00?o0000om8]d_oB;M803?oB;M800ol0003oc3?<ol`cc00:ol`cc0?o0000
3?ndBk@00ol0003oT6n@oi1_T002o`0000_o/Tfb00?o0000okI9]_nfBKH02?nfBKH00ol0003ocS7>
olhacP07olhacP03o`000?o5>/GoaC[500OoaC[500?o0000om8]d_oB;M803?oB;M800ol0003oi1_T
on@Ki00;on@Ki0;o00003_o0?l000ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N800ooR7N800ol0003oc3?<ol`cc00?ol`cc0?o00000ooF
:MH00ol0003odRgBom8]dP0>om8]dP03o`000?o<<lcoc3?<00Soc3?<00Co0000okU6^OniA[Wo^DJi
0_l0000:okA;]0?o00003OnbCK800ol0003o]TVfokI9]P08okI9]P03o`000?o><LkocS7>00OocS7>
00?o0000olDjaOo5>/D01oo5>/D00ol0003odRgBom8]dP0;om8]dP03o`000?oT6nCoi1_T00coi1_T
00?o0000olPgb?l000000_l0000:ol0o`003o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP04on8MhP03o`000?o<<lcoc3?<00coc3?<0_l0
0003olXebP03o`000?oF:MKo0000017odRgB00?o0000ol`cc?o<<l`01oo<<l`00ol0003o^DJiokU6
^@04okU6^@;o00002?ndBk@00ol0003o/Tfbok9=/P0>ok9=/P;o00002?nfBKH00ol0003ocS7>olha
cP06olhacP03o`000?o5>/GoaC[500WoaC[500?o0000om8]d_oB;M802OoB;M800ol0003oi1_Ton@K
i00=on@Ki003o`000?o8=lSob3O800;ob3O80ol00007ol0o`003o`000?oK9=_ofbCK00OofbCK00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?o<<lco
c3?<00Woc3?<0_l00006olXebP03o`000?oB;M;odRgB013odRgB00?o0000ol`cc?o<<l`01_o<<l`0
0ol0003o^DJiokU6^@07okU6^@03o`000?ndBkCo]4^d00Co]4^d0ol0000>ok9=/P03o`000?nTFjCo
Y5^T00?o00001OnfBKH00ol0003ocS7>olhacP06olhacP03o`000?o5>/GoaC[500[oaC[500?o0000
om8]d_oB;M802?oB;M800ol0003oi1_Ton@Ki00=on@Ki003o`000?o8=lSob3O800Gob3O80ol00004
ol0o`003o`000?oK9=_ofbCK00OofbCK00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ohQgRon8MhP06on8MhP03o`000?o<<lcoc3?<00Goc3?<0ol00008olXebP03o`000?oB;M;odRgB
017odRgB00Co0000ol`cc?o<<lcoc3?<1?l0000;okU6^@;o000000Co]4^do`000?l0003o00000oo1
?/42o`0000_o/Tfb00?o0000ojAKY?nTFj@01?nTFj@2o`0000?o]TVf00?o0000olhac_o><Lh01_o>
<Lh00ol0003oaC[5olDja@0:olDja@03o`000?oB;M;odRgB00OodRgB00?o0000on@Ki?oT6n@03_oT
6n@00ol0003ob3O8olPgb008olPgb0Co00002_oK9=/00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003ohQgRon8MhP07on8MhP03o`000?o<<lcoc3?<00;oc3?<0_l0000<olXebP03o`000?oB;M;o
dRgB013odRgB1?l00003olDja@03o`000?niA[Wo^DJi00_o^DJi00?o0000ol4n`Oo1?/401_o1?/40
0ol0003o/Tfbok9=/P07ok9=/P03o`000?nTFjCoY5^T00OoY5^T3?l0000>olDja@03o`000?oB;M;o
dRgB00KodRgB00?o0000on@Ki?oT6n@03_oT6n@00ol0003ob3O8olPgb00;olPgb003o`000?oK9=_o
fbCK00OofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00WohQgR00Co0000ol`c
c?l0003o00003_o:=LX00ol0003odRgBom8]dP0?om8]dP03o`000?o5>/GoaC[500KoaC[500?o0000
okU6^OniA[T02_niA[T00ol0003o`Ck1ol4n`@07ol4n`@;o00001_nbCK800ol0003oY5^TojAKY008
ojAKY003o`000?oB;M;odRgB00SodRgB00?o0000olDjaOo5>/D03?o5>/D00ol0003odRgBom8]dP05
om8]dP03o`000?oT6nCoi1_T00ooi1_T0_l0000=olPgb003o`000?oK9=_ofbCK00KofbCK00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00[ohQgR00?o0000olXeb_o:=LX03_o:=LX00ol0
003odRgBom8]dP0>om8]dP03o`000?o5>/GoaC[500OoaC[500?o0000okU6^OniA[T02_niA[T00ol0
003o`Ck1ol4n`@09ol4n`@;o00000onbCK800ol0003oY5^TojAKY009ojAKY003o`000?oB;M;odRgB
00WodRgB00?o0000olDjaOo5>/D02_o5>/D4o`0000CodRgB00?o0000on@Ki?oT6n@04?oT6n@01?l0
003obCK9o`000?l0000<olPgb003o`000?oK9=_ofbCK00GofbCK00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?oR7N;ohQgR00[ohQgR00?o0000olXeb_o:=LX03oo:=LX@o`0000[oaC[500?o0000okU6
^OniA[T02OniA[T00ol0003oZUFZo`00000<ol4n`@05o`000?nbCK;o0000ojEJYOl000002_nTFj@0
0ol0003odRgBom8]dP09om8]dP03o`000?o5>/GoaC[500OoaC[50ol00004omLXe`?o000000?odRgB
o`000?oT6n@04OoT6n@01?l0003obCK9olTfbOo9=/T2o`0000_ob3O800?o0000om/TfooK9=/00ooK
9=/00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000on8Mh_oR7N802_oR7N800ol0003obSG:olXebP0?
olXebP03o`000?oF:MKoeRWF00coeRWF00?o0000olDjaOo5>/D02Oo5>/D00ol0003o^DJiokU6^@07
okU6^@04o`000?nZEJ[oZUFZo`0000go`Ck100Go0000ojEJYOnUFZGoYEZUo`000009ojAKY003o`00
0?oB;M;odRgB00[odRgB00?o0000olDjaOo5>/D00oo5>/D3o`0000[oebSG00?o0000on@Ki?oT6n@0
4?oT6n@00ol0003obCK9olTfb@04olTfb@;o00002_o8=lP00ol0003ofbCKom/Tf`04o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000cohQgR00?o0000olXeb_o:=LX03oo:=LX00ol0003oeRWFomHYeP0<omHYeP03o`000?o5
>/GoaC[500WoaC[500?o0000okU6^OniA[T01_niA[T00ol0003oZUFZojYEZP02ojYEZP03o`000?o1
?/7o`Ck100[o`Ck100?o0000ojEJYOnUFZD00_nUFZD00ol0003oY5^TojAKY006ojAKY003o`000?oB
;M;odRgB00[odRgB00?o0000olDjaOo5>/D00ol0000=omLXe`03o`000?oT6nCoi1_T013oi1_T00?o
0000olTfbOo9=/T01_o9=/T2o`0000Wob3O80_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000on8Mh_oR7N802_oR7N800ol0003obSG:olXebP0=olXebP?o00003ooF:MH0
0ol0003oaC[5olDja@08olDja@03o`000?niA[Wo^DJi00Go^DJi00?o0000ojYEZ_nZEJX00onZEJX0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?nUFZGoYEZU00?oYEZU00?o0000ojAKY?nTFj@01OnTFj@0
0ol0003odRgBom8]dP0;om8]dP;o00004OoG:=L00ol0003oi1_Ton@Ki00?on@Ki003o`000?o9=/Wo
bCK900SobCK90_l00007olPgb003o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000on8Mh_oR7N802?oR7N800ol0003obSG:olXebP09olXebPGo00000_o1?/400ol0
003oeRWFomHYeP0=omHYeP03o`000?o5>/GoaC[500WoaC[500?o0000okU6^OniA[T01?niA[T00ol0
003oZUFZojYEZP04ojYEZP03o`000?o1?/7o`Ck100So`Ck100?o0000ojEJYOnUFZD01OnUFZD00ol0
003oY5^TojAKY004ojAKY003o`000?oB;M;odRgB00_odRgB00?o0000omLXeooG:=L04?oG:=L00ol0
003oi1_Ton@Ki00?on@Ki003o`000?o9=/WobCK900[obCK90_l00004olPgb003o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003ohQgRon8MhP07on8MhP03o`000?o:=L[obSG:00CobSG:1Ol00007ol4n`@03
o`000?oF:MKoeRWF00goeRWF00?o0000olDjaOo5>/D02Oo5>/D00ol0003o^DJiokU6^@03okU6^@03
o`000?nZEJ[oZUFZ00GoZUFZ00?o0000ol4n`Oo1?/402?o1?/400ol0003oYEZUojEJY@06ojEJY@03
o`000?nTFjCoY5^T00?oY5^T00?o0000om8]d_oB;M802ooB;M800ol0003oebSGomLXe`0@omLXe`03
o`000?oT6nCoi1_T00ooi1_T00?o0000olTfbOo9=/T03?o9=/T2o`000003olPgb?l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oR7N;ohQgR00OohQgR00?o0000olXeb_l00000
1?l0000<ol4n`@03o`000?oF:MKoeRWF00koeRWF00?o0000olDjaOo5>/D02?o5>/D00ol0003o^DJi
okU6^@02okU6^@03o`000?nZEJ[oZUFZ00OoZUFZ00?o0000ol4n`Oo1?/401oo1?/400ol0003oYEZU
ojEJY@07ojEJY@03o`000?nTFjCoY5^T00;oY5^T00?o0000om8]d_oB;M802ooB;M800ol0003oebSG
omLXe`0AomLXe`03o`000?oT6nCoi1_T00goi1_T00?o0000olTfbOo9=/T03oo9=/T00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N801OoR7N83o`00017o`Ck100?o0000omHYe_oF:MH03_oF
:MH00ol0003oaC[5olDja@09olDja@04o`000?niA[Wo^DJio`0000[oZUFZ00?o0000ol4n`Oo1?/40
1oo1?/400ol0003oYEZUojEJY@08ojEJY@05o`000?nTFjCoY5^TojAKY?l000003OoB;M800ol0003o
ebSGomLXe`0AomLXe`?o00003OoT6n@00ol0003obCK9olTfb@0?olTfb@03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_oR7N82o`0000;o`Sg200?o0000ol4n`Oo1?/403oo1?/400ol0003o
eRWFomHYeP0>omHYeP03o`000?o5>/GoaC[500SoaC[51Ol0000;ojYEZP03o`000?o1?/7o`Ck100Ko
`Ck100?o0000ojEJYOnUFZD02OnUFZD01?l0003oY5^TojAKY?l0000=om8]dP03o`000?oG:=OoebSG
017oebSG00?o0000ol<l`oo3?<<00ol0000:on@Ki0Co00003Oo9=/T00ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000omLXeooG:=OoebSG0_l00005ol8m`P03o`000?o1?/7o`Ck100ko`Ck100?o0000omHY
e_oF:MH03_oF:MH00ol0003oaC[5olDja@07olDja@03o`000?o5>/GoaC[500?oaC[500?o0000ojYE
Z_nZEJX02?nZEJX00ol0003o`Ck1ol4n`@05ol4n`@03o`000?nUFZGoYEZU00[oYEZU1Ol0000<om8]
dP03o`000?oG:=OoebSG013oebSG00?o0000ol<l`oo3?<<01?o3?<<3o`0000Koi1_T00?o0000omLX
eooG:=L00_oG:=L5o`0000SobCK900?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oG:=OoebSG00?o
ebSG00?o0000ol8m`_o2?L801?o2?L800ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oF:MKoeRWF00oo
eRWF00?o0000olDjaOo5>/D01?o5>/D2o`0000OoaC[500?o0000ojYEZ_nZEJX01onZEJXEo`0000Go
[U6^00?o0000om8]d_oB;M802?oB;M83o`00013oebSG00?o0000ol<l`oo3?<<02?o3?<<3o`0000;o
i1_T00?o0000omLXeooG:=L02?oG:=L5o`0000?obCK900?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oG:=OoebSG00CoebSG00?o0000ol8m`_o2?L801Oo2?L800ol0003o`Ck1ol4n`@0;ol4n`@Co0000
3ooF:MH00ol0003oaC[5olDja@03olDja@03o`000?o5>/GoaC[500SoaC[500?o0000ojYEZ_nZEJX0
1?nZEJX2o`0000SoaC[500?o0000ok]4^onkA;/02?nkA;/00ol0003o[U6^ojiA[P05ojiA[P;o0000
1_oB;M82o`0000?oc3?<00?o0000omLXeooG:=L03?oG:=L00ol0003o`cc3ol<l``0<ol<l``;o0000
4?oG:=L3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003oebSGomLXe`05omLXe`03o`000?o2?L;o`Sg200Ko`Sg200?o
0000ol4n`Oo1?/402Oo1?/400ol0003o[5>/o`000002olDja@?o00003?oF:MH01?l0003oaC[5olDj
aOo5>/D2o`0000coaC[500?o0000ojYEZ_nZEJX00_nZEJX00ol0003oaC[5olDja@08olDja@03o`00
0?nkA;_o^dBk00So^dBk00?o0000ojiA[_n^DJh01on^DJh00ol0003odRgBom8]dP02om8]dP03o`00
0?o<<lcoc3?<00Coc3?<0_l0000;omLXe`03o`000?o3?<?o`cc300co`cc300?o0000olTfbOl00000
4_oG:=L00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003oebSGomLXe`06omLXe`03o`000?o2?L;o`Sg200Oo`Sg200?o
0000ol4n`Oo1?/401_o1?/42o`0000;o[5>/00?o0000olDjaOo5>/D00oo5>/D3o`0000[oeRWF00?o
0000olDjaOl000003oo5>/D01?l0003oZUFZo`000?l0000;olDja@03o`000?nkA;_o^dBk00So^dBk
00?o0000ojiA[_n^DJh02?n^DJh01?l0003odRgBo`000?l00009ol`cc003o`000?oG:=OoebSG00Oo
ebSG00?o0000ol<l`oo3?<<03?o3?<<01?l0003obCK9olTfbOl0000ComLXe`03o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000omLXeooG:=L01ooG:=L00ol0003o`Sg2ol8m`P08ol8m`P03o`000?o1?/7o`Ck100Co
`Ck100?o0000ojaC[?n/Dj`00on/Dj`00ol0003oaC[5olDja@05olDja@?o00001_oF:MH4o`00013o
aC[500?o0000olDjaOo5>/D03?o5>/D00ol0003o^dBkok]4^`07ok]4^`03o`000?n^DJko[U6^00Wo
[U6^00?o0000ol`cc?o<<l`02_o<<l`2o`0000KoebSG00?o0000ol<l`oo3?<<03?o3?<<00ol0003o
bCK9olTfb@02olTfb@03o`000?oG:=OoebSG00ooebSG00?o0000om@[e?l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003oebSGomLXe`08omLXe`03o`000?o2?L;o`Sg200Wo`Sg200Co0000ol4n`Oo1?/7o
`Ck10_l00006ojaC[003o`000?o5>/GoaC[500SoaC[50ol000000ooF:MKo0000o`000004olTfb@03
o`000?o5>/GoaC[500goaC[500?o0000olDjaOo5>/D03?o5>/D00ol0003o^dBkok]4^`07ok]4^`03
o`000?n^DJko[U6^00Wo[U6^00?o0000ol`cc?o<<l`03?o<<l`00ol0003oebSGomLXe`03o`0000ko
`cc300?o0000olTfbOo9=/T00oo9=/T00ol0003oebSGomLXe`0>omLXe`05o`000?oD:mCoe2_Dom@[
e?l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003oebSGomLXe`09omLXe`03o`000?o2?L;o`Sg200[o
`Sg200?o0000ol4n`Ol000002?n/Dj`00ol0003oaC[5olDja@0;olDja@03o`000?o9=/WobCK900Go
bCK900?o0000olDjaOo5>/D03?o5>/D00ol0003oaC[5olDja@0<olDja@03o`000?nkA;_o^dBk00Oo
^dBk00?o0000ojiA[_n^DJh02?n^DJh2o`0000ooc3?<0_l00002ol`cc003o`000?o3?<?o`cc300_o
`cc300?o0000olTfbOo9=/T01?o9=/T00ol0003oebSGomLXe`0=omLXe`03o`000?oD:mCoe2_D00?o
e2_D00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omLXe`03o`000?o2?L;o`Sg200_o`Sg200?o0000ojaC[?n/Dj`0
1on/Dj`00ol0003oaC[5olDja@0;olDja@03o`000?o9=/WobCK900KobCK900?o0000olDjaOo5>/D0
2oo5>/D2o`0000goaC[500?o0000ok]4^onkA;/01onkA;/00ol0003o[U6^ojiA[P07ojiA[P04o`00
0?nfBKKo]TVfo`0000koc3?<00?o0000ol`cc?o<<l`00_o<<l`00ol0003o`cc3ol<l``09ol<l``03
o`000?o9=/WobCK900KobCK900?o0000omLXeooG:=L02ooG:=L00ol0003oe2_Dom@[e005om@[e004
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000SoebSG00?o0000ol8m`_o2?L802_o2?L82o`0000Wo
[5>/00?o0000olDjaOo5>/D02oo5>/D00ol0003obCK9olTfb@07olTfb@03o`000?o5>/GoaC[500Wo
aC[500Co0000ojAKY?nTFjCo00003?o5>/D00ol0003o^dBkok]4^`07ok]4^`03o`000?n^DJko[U6^
00Ko[U6^00Go0000okI9]_nfBKKo]TVfo`00000>ol`cc003o`000?o<<lcoc3?<00?oc3?<00?o0000
ol<l`oo3?<<01oo3?<<00ol0003obCK9olTfb@07olTfb@03o`000?oG:=OoebSG00[oebSG00?o0000
om@[e?oD:m@01ooD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006omLXe`03o`000?o2?L;o`Sg2
00Wo`Sg200Co0000ojeB[On]DZgo00002On/Dj`00ol0003oaC[5olDja@09olDja@03o`000?o9=/Wo
bCK900WobCK900?o0000olDjaOo5>/D01oo5>/D00ol0003oY5^TojAKY002ojAKY003o`000?o5>/Go
aC[500WoaC[500?o0000ok]4^onkA;/01onkA;/00ol0003o[U6^ojiA[P05ojiA[P03o`000?nfBKKo
]TVf00?o]TVf00?o0000ol`cc?o<<l`02_o<<l`00ol0003oc3?<ol`cc005ol`cc003o`000?o3?<?o
`cc300Go`cc300?o0000olTfbOo9=/T02?o9=/T00ol0003oebSGomLXe`09omLXe`03o`000?oD:mCo
e2_D00Soe2_D00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oG:=L3o`0000Wo`Sg200?o0000ojeB
[On]DZd00_n]DZd00ol0003o[5>/ojaC[006ojaC[003o`000?o5>/GoaC[500WoaC[500?o0000olTf
bOo9=/T02_o9=/T00ol0003oaC[5olDja@05olDja@03o`000?nTFjCoY5^T00CoY5^T00?o0000olDj
aOo5>/D02?o5>/D00ol0003o^dBkok]4^`07ok]4^`03o`000?n^DJko[U6^00Co[U6^00?o0000okI9
]_nfBKH01?nfBKH00ol0003oc3?<ol`cc00:ol`cc003o`000?o<<lcoc3?<00Koc3?<00?o0000ol<l
`oo3?<<00oo3?<<00ol0003obCK9olTfb@09olTfb@03o`000?oG:=OoebSG00SoebSG00?o0000om@[
e?oD:m@02OoD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003omPWf0?o00001Oo2?L800ol0003o
[E:]ojeB[@03ojeB[@03o`000?n/Djco[5>/00Ko[5>/00?o0000olDjaOo5>/D02Oo5>/D00ol0003o
bCK9olTfb@0;olTfb@03o`000?o5>/GoaC[500?oaC[500?o0000ojAKY?nTFj@01_nTFj@00ol0003o
aC[5olDja@08olDja@03o`000?nkA;_o^dBk00Ko^dBk00?o0000ojiA[_n^DJh00_n^DJh2o`0000So
]TVf00?o0000ol`cc?o<<l`02Oo<<l`00ol0003oc3?<ol`cc007ol`cc005o`000?o3?<?o`cc3ol<l
`ol000003Oo9=/T00ol0003oebSGomLXe`06omLXe`03o`000?oD:mCoe2_D00[oe2_D00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oH9mSof2OH00Gof2OH0ol000000oo2?L;o0000ojeB[@06ojeB[@03
o`000?n/Djco[5>/00Go[5>/00?o0000olDjaOo5>/D02Oo5>/D00ol0003obCK9olTfb@0<olTfb@05
o`000?o5>/GoaC[5olDjaOl000002_nTFj@00ol0003oaC[5olDja@07olDja@03o`000?nkA;_o^dBk
00Ko^dBk00?o0000ojiA[_l000000_l000000ooA;]7o0000okI9]P07okI9]P03o`000?o<<lcoc3?<
00Soc3?<00?o0000ol`cc?o<<l`02Oo<<l`00ol0003o`cc3o`00000=olTfb@Co00001OoG:=L00ol0
003oe2_Dom@[e00;om@[e003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPWf008omPWf003
o`000?n]DZgo[E:]00Oo[E:]00?o0000ojaC[?n/Dj`01?n/Dj`00ol0003oaC[5olDja@09olDja@03
o`000?o9=/WobCK900gobCK900?o0000olDjaOl000003?nTFj@:o`0000Oo^dBk0ol00005om4^d@03
o`000?nfBKKo]TVf00Ko]TVf00?o0000ol`cc?o<<l`01oo<<l`00ol0003oc3?<ol`cc00:ol`cc003
o`000?o9=/WobCK900_obCK900?o0000ol@ka?o4>l@00_o4>l@3o`000003omLXeol0003oe2_D00_o
e2_D0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000omPWf?oH9mP02OoH9mP00ol0003o[E:]ojeB[@07ojeB[@03o`00
0?n/Djco[5>/00Go[5>/00?o0000olDjaOo5>/D01oo5>/D00ol0003obCK9olTfb@0?olTfb@;o0000
2onTFj@00ol0003obcC;ol/db`07ol/db`03o`000?nkA;_o^dBk00;o^dBk0ol00008om4^d@03o`00
0?nfBKKo]TVf00Ko]TVf00?o0000ol`cc?o<<l`01oo<<l`00ol0003oc3?<ol`cc00:ol`cc003o`00
0?o9=/WobCK900[obCK900?o0000ol@ka?o4>l@01_o4>l@00ol0003oe2_Dom@[e008om@[e0?o0000
0_oN8Mh00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000omPWf?oH9mP02OoH9mP00ol0003o[E:]ojeB
[@08ojeB[@03o`000?n/Djco[5>/00Co[5>/00?o0000olDjaOo5>/D01oo5>/D00ol0003obCK9olTf
b@0>olTfb@04o`000?n`Ck3o/4n`o`0000WoY5^T00?o0000ol/dboo;=</02Oo;=</01?l0003o^dBk
o`000?l0000<om4^d@03o`000?nfBKKo]TVf00Ko]TVf00?o0000ol`cc?o<<l`01_o<<l`00ol0003o
c3?<ol`cc00;ol`cc003o`000?o9=/WobCK900OobCK90_l00009ol@ka003o`000?oD:mCoe2_D00Co
e2_D1?l00006omhQgP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003of2OHomPWf009omPWf003o`00
0?n]DZgo[E:]00So[E:]00?o0000ojaC[?n/Dj`00on/Dj`>o`0000gobCK900?o0000ok1?/?n`Ck00
0_n`Ck000ol0003oY5^TojAKY005ojAKY003o`000?o;=<_obcC;00_obcC;00?o0000om4^dOoA;]40
3?oA;]400ol0003o]TVfokI9]P06okI9]P03o`000?o<<lcoc3?<00Goc3?<00?o0000ol`cc?o<<l`0
3?o<<l`00ol0003obCK9olTfb@06olTfb@03o`000?o4>lCoa3_400[oa3_400?o0000om@[e?oD:m@0
0ol0000:omhQgP?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oH9mSof2OH00_of2OH00?o0000ojeB[On]DZd02?n]
DZd01Ol0003o[5>/ojaC[?n/Djco000000_o_T6n00?o0000oi=/TonCK9<00ol00009olTfb@03o`00
0?n`Ck3o/4n`00Co/4n`00?o0000ojAKY?nTFj@00onTFj@00ol0003obcC;ol/db`0<ol/db`03o`00
0?oA;]7odBkA00godBkA00?o0000okI9]_nfBKH01_nfBKH00ol0003oc3?<ol`cc003ol`cc0?o0000
3Oo<<l`00ol0003obCK9olTfb@05olTfb@03o`000?o4>lCoa3_400coa3_40_l0000=omhQgP03o`00
0?oj1O[onPGj00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oH9mSof2OH00_of2OH00?o0000ojeB[On]DZd02?n]
DZd4o`0000co_T6n00?o0000oi=/TonCK9<00onCK9<3o`0000GobCK900?o0000ok1?/?n`Ck001_n`
Ck001Ol0003oY5^TojAKY?nTFjCo000000oobcC;00?o0000om4^dOoA;]403OoA;]400ol0003o]TVf
okI9]P06okI9]P03o`000?o<<lcoc3?<00?o00000onhAkP00ol0003oc3?<ol`cc00;ol`cc003o`00
0?o9=/WobCK900?obCK900?o0000ol@ka?o4>l@03Oo4>l@00ol0003ogR7NomhQgP0;omhQgP03o`00
0?oj1O[onPGj00ConPGj0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000omPWf?oH9mP02_oH9mP3o`0000Ko[E:]0ol0
0003ok1?/003o`000?nn@Kko_T6n00[o_T6n00?o0000oi=/TonCK9<01_nCK9<3o`000003olTfbOl0
003o/4n`00Wo/4n`00?o0000ojAKY?l000004?o;=</00ol0003odBkAom4^d@0=om4^d@03o`000?nf
BKKo]TVf00Oo]TVf0_l00007okQ7^003o`000?o<<lcoc3?<00[oc3?<00Co0000olTfbOo9=/WobCK9
0ol0000?ol@ka003o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX01ooj1OX4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omPWf?oH9mP02_oH
9mP01?l0003oa3_4ol@ka?o4>l@2o`000004ojeB[Ol0003o0000o`0000Ko/4n`00?o0000oki1__nn
@Kh02_nn@Kh00ol0003oTfbCoi=/T`09oi=/T`03o`000?n`Ck3o/4n`00[o/4n`00?o0000ol/dboo;
=</03oo;=</00ol0003odBkAom4^d@0>om4^d@03o`000?nfBKKo]TVf00Ko]TVf00?o0000okQ7^?nh
AkP01onhAkP4o`0000Soc3?<00Co0000olTfbOo9=/Wo00000onVFJH2o`0000goa3_400?o0000omhQ
g_oN8Mh02_oN8Mh00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omPWf?oH9mP02OoH9mP00ol0003o
a3_4ol@ka004ol@ka003o`000?n`Ck3o/4n`00Oo/4n`00?o0000oki1__nn@Kh02Onn@Kh00ol0003o
TfbCoi=/T`0:oi=/T`03o`000?n`Ck3o/4n`00[o/4n`00?o0000ol/dboo;=</03oo;=</00ol0003o
dBkAom4^d@0>om4^d@03o`000?nfBKKo]TVf00Go]TVf00?o0000okQ7^?nhAkP02?nhAkP01?l0003o
`Ck1ol4n`Oo1?/47o`0000;oc3?<0_l00006ojIIYP;o00003?o4>l@00ol0003ogR7NomhQgP09omhQ
gP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003of2OHomPWf008omPWf003o`000?o4>lCoa3_400Go
a3_400?o0000ok1?/?n`Ck002?n`Ck000ol0003o_T6noki1_P08oki1_P03o`000?nCK9?oTfbC00[o
TfbC00?o0000ok1?/?n`Ck002on`Ck000ol0003obcC;ol/db`0>ol/db`03o`000?oA;]7odBkA00ko
dBkA1Ol00002okI9]P03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000ol4n`Oo1?/402?o1?/43o`0000Wo
YUVV0_l0000:ol@ka003o`000?oN8MkogR7N00SogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oH9mSof2OH00Sof2OH00?o0000ol@ka?o4>l@01oo4>l@00ol0003o/4n`ok1?/007ok1?/003o`00
0?nn@Kko_T6n00So_T6n00?o0000oi=/TonCK9<02_nCK9<00ol0003o/4n`ok1?/00:ok1?/0;o0000
3_o;=</3o`0000godBkA0ol00005om8]dP;o00002onhAkP00ol0003o`Ck1ol4n`@0;ol4n`@;o0000
2_nVFJH2o`0000Ooa3_40ol00009omhQgP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:ol@ka003o`00
0?n`Ck3o/4n`00Oo/4n`00?o0000oki1__nn@Kh02?nn@Kh>o`0000Wo/4n`0ol000000onIIYWo0000
ol/db`0:ol/db`?o00000_oE:]D00ol0003odBkAom4^d@09om4^d@;o00002OoB;M800ol0003o^4Nh
okQ7^009okQ7^003o`000?o1?/7o`Ck100_o`Ck100?o0000olTfbOl000002onVFJH2o`0000Coa3_4
00Co0000om/TfooK9=_ofbCK0_l00007omhQgP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003oa3_4
ol@ka009ol@ka003o`000?n`Ck3o/4n`00Ko/4n`00?o0000oki1__nn@Kh02?nn@Kh00ol0003oWf2O
oimPW`0:oimPW`03o`000?n`Ck3o/4n`00Co/4n`0ol00005oiUVV@03o`000?o;=<_obcC;00CobcC;
1?l00006omDZe@03o`000?oA;]7odBkA00KodBkA0_l0000;om8]dP03o`000?nhAkSo^4Nh00Wo^4Nh
00?o0000ol4n`Oo1?/402_o1?/401Ol0003obCK9olTfbOo9=/Wo000000coYUVV0_l000000oo4>lCo
0000om/Tf`05om/Tf`03o`000?oN8MkogR7N00?ogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o4>lCoa3_400Soa3_400?o0000ok1?/?n`Ck001_n`Ck000ol0003o_T6noki1_P07oki1_P03o`00
0?nOH9ooWf2O00_oWf2O00?o0000ok1?/?n`Ck000_n`Ck02o`0000WoVFJI00?o0000ol/dboo;=</0
0ol0000;omDZe@03o`000?oA;]7odBkA00;odBkA0ol0000>om8]dP03o`000?nhAkSo^4Nh00Oo^4Nh
00?o0000ol4n`Oo1?/402oo1?/400ol0003obCK9olTfb@02olTfb@03o`000?nVFJKoYUVV00_oYUVV
00?o0000om/TfooK9=/01_oK9=/2o`0000?ogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o4
>lCoa3_400Ooa3_400?o0000ok1?/?n`Ck001on`Ck000ol0003o_T6noki1_P05oki1_P?o00003OnO
H9l4o`0000_oVFJI0ol0000?omDZe@04o`000?oA;]7o0000o`00017odRgB00?o0000okQ7^?nhAkP0
1onhAkP00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o9=/WobCK900CobCK900?o0000ojIIY_nVFJH0
1onVFJH3o`0000_ofbCK1?l0000=ooX5nP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol@ka?o4>l@02?o4>l@00ol0003o/4n`ok1?
/006ok1?/003o`000?nn@Kko_T6n00;o_T6n0ol00003ok9=/P03o`000?nOH9ooWf2O00[oWf2O00?o
0000oiUVVOnIIYT02onIIYT00ol0003oXUfRo`00000AomDZe@03o`000?oB;M;odRgB017odRgB00?o
0000okQ7^?nhAkP01onhAkP00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o9=/WobCK900GobCK900Co
0000ojIIY_nVFJKoYUVV1Ol00002ok=</`03o`000?oK9=_ofbCK00WofbCK00Co0000ooX5n_oj1O[o
nPGj0ol00009ooX5nP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000ol@ka?o4>l@01oo4>l@00ol0003o/4n`ok1?/005ok1?/0?o0000
00?o_T6no`000?l000001onbCK800ol0003oWf2OoimPW`08oimPW`?o00002_nIIYT2o`0000;oXUfR
00?o0000omDZeOoE:]D03ooE:]D00ol0003odRgBom8]dP0Aom8]dP03o`000?nhAkSo^4Nh00Oo^4Nh
00?o0000ol4n`Oo1?/402Oo1?/400ol0003obCK9olTfb@07olTfb@?o00001oncC;<00ol0003ofbCK
om/Tf`09om/Tf`03o`000?oj1O[onPGj00ConPGj0_l00007ooX5nP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000ol@ka?o4>l@01oo4
>l@4o`0000;o/4n`0_l00003okm0_`03o`000?nbCK;o/Tfb00So/Tfb0_l00006oimPW`;o00000onU
FZD00ol0003oVFJIoiUVV@06oiUVV@03o`000?nRGJ;oXUfR00?oXUfR00?o0000omDZeOoE:]D03_oE
:]D00ol0003odRgBom8]dP0Bom8]dP03o`000?nhAkSo^4Nh00Go^4Nh00?o0000ol4n`Oo1?/402Oo1
?/400ol0003obCK9olTfb@08olTfb@03o`000?ncC;?o/dbc00Oo/dbc00?o0000om/TfooK9=/02?oK
9=/00ol0003onPGjooX5nP07ooX5nP;o00001Ooj1OX00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o4>lCoa3_400Coa3_40_l00004
omLXe`;o00001Ono@;l00ol0003o/Tfbok9=/P0:ok9=/P03o`000?nOH9ooWf2O00;oWf2O00?o0000
ojEJYOnUFZD01?nUFZD00ol0003oVFJIoiUVV@04oiUVV@03o`000?nRGJ;oXUfR00CoXUfR00?o0000
omDZeOoE:]D03_oE:]D00ol0003odRgBom8]dP0Bom8]dP[o00002_o1?/400ol0003obCK9olTfb@08
olTfb@03o`000?ncC;?o/dbc00Oo/dbc00?o0000om/TfooK9=/02?oK9=/00ol0003onPGjooX5nP09
ooX5nP?o000000?onPGjo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003oa3_4ol@ka?o4>l@2o`0000OoebSG00?o0000okm0_ono@;l01?no@;l0
0ol0003o/Tfbok9=/P0:ok9=/P04o`000?nOH9oo0000o`0000SoYEZU00Co0000oiUVVOnIIYWoVFJI
0_l00007oj9MXP03o`000?oE:]GoeB[E00koeB[E00?o0000om8]d_oB;M804_oB;M800ol0003o_cno
oklo_`07oklo_`03o`000?o1?/7o`Ck100Ko`Ck100?o0000olTfbOo9=/T02_o9=/T00ol0003o/dbc
ok=</`06ok=</`03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o4
>lCo0000o`0000WoebSG00?o0000okm0_ono@;l01?no@;l00ol0003o/Tfbok9=/P0;ok9=/P03o`00
0?nUFZGoYEZU00WoYEZU00?o0000oiUVVOl000002OnRGJ800ol0003oeB[EomDZe@0>omDZe@;o0000
4_oB;M800ol0003o_cnooklo_`09oklo_`;o00001_o1?/400ol0003obCK9olTfb@0:olTfb@03o`00
0?ncC;?o/dbc00Ko/dbc00?o0000om/TfooK9=/02?oK9=/00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000omLXeooG:=L02OoG:=L00ol0003o_d2ookm0_`05okm0_`03o`000?nbCK;o/Tfb00[o/Tfb00?o
0000ojEJYOnUFZD02_nUFZD2o`0000WoXUfR00?o0000omDZeOoE:]D03_oE:]D00ol0003obCK9o`00
0002o`0000oodRgB00?o0000oklo_ono?kl02ono?kl00ol0003o`Ck1ol4n`@03o`0000gobCK900?o
0000ok=</oncC;<01_ncC;<00ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003oebSGomLXe`09omLXe`03o`000?no@;oo_d2o00Go_d2o00?o0000ok9=/_nbCK802OnbCK82
o`0000_oYEZU0_l0000;oj9MXP03o`000?oE:]GoeB[E00coeB[E00?o0000olTfbOo9=/T00oo9=/T3
o`0000codRgB00?o0000oklo_ono?kl03?no?kl2o`0000;o^TFj00?o0000olTfbOo9=/T03?o9=/T0
0ol0003o/dbcok=</`05ok=</`03o`000?oK9=_ofbCK00OofbCK00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oG:=OoebSG00[oebSG00?o0000okm0_ono@;l01_no@;l00ol0003o/Tfbok9=/P07ok9=
/P03o`000?nTFjCo000000[oYEZU00Co0000oiIYU_nFJIKo00002_nRGJ800ol0003oeB[EomDZe@0<
omDZe@03o`000?o9=/WobCK900KobCK90_l00008om8]dP;o00003ono?kl00ol0003o^TFjokY5^P02
okY5^P03o`000?o9=/WobCK900_obCK900?o0000ok=</oncC;<01OncC;<00ol0003ofbCKom/Tf`07
om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oebSGomLXe`0:omLXe`03o`000?no@;oo_d2o
00Ko_d2o00?o0000ok9=/_nbCK801_nbCK801Ol0003oY5^TojAKY?nTFjCo000000SoYEZU00?o0000
oiIYU_nFJIH00_nFJIH00ol0003oXUfRoj9MXP06oj9MXPCo00003?oE:]D00ol0003obCK9olTfb@08
olTfb@?o00000_oB;M83o`000003oke2_Ol0003o_cno00go_cno00?o0000okY5^_njAKX01?njAKX0
0ol0003obCK9olTfb@0:olTfb@03o`000?ncC;?o/dbc00Go/dbc00?o0000om/TfooK9=/01_oK9=/0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000omLXeooG:=L02ooG:=L00ol0003o_d2ookm0_`07okm0
_`03o`000?nbCK;o/Tfb00?o/Tfb0_l00005ojAKY003o`000?nUFZGoYEZU00CoYEZU00?o0000oiIY
U_nFJIH00onFJIH00ol0003oXUfRoj9MXP05oj9MXP03o`000?nhAkSo^4Nh00;o^4Nh0ol00007omDZ
e@;o00003_o9=/T2o`0000Go_D:m00?o0000oklo_ono?kl02_no?kl00ol0003o^TFjokY5^P05okY5
^P03o`000?o9=/WobCK900_obCK900?o0000ok=</oncC;<01?ncC;<00ol0003ofbCKom/Tf`06om/T
f`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oebSGomLXe`0;omLXe`03o`000?no@;oo_d2o00Oo
_d2o00?o0000ok9=/_nbCK800_nbCK800ol0003oY5^TojAKY006ojAKY003o`000?nUFZGoYEZU00;o
YEZU00?o0000oiIYU_nFJIH01OnFJIH00ol0003oXUfRoj9MXP02oj9MXP;o00002?nhAkP3o`0000;o
eB[E0_l000000onm@[go0000olTfb@0=olTfb@03o`000?nm@[go_D:m00Go_D:m00?o0000oklo_ono
?kl02?no?kl00ol0003o^TFjokY5^P07okY5^P03o`000?o9=/WobCK900[obCK900?o0000ok=</onc
C;<01?ncC;<00ol0003ofbCKom/Tf`06om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSG
omLXe`0<omLXe`03o`000?no@;oo_d2o00So_d2o00Co0000ok9=/_nbCK;o00002OnTFj@01Ol0003o
YEZUojEJYOnUFZGo000000SoUVVF00Go0000oj9MX_nRGJ;oXUfRo`00000=okQ7^0;o00001?nm@[d0
0ol0003obCK9olTfb@0;olTfb@03o`000?nm@[go_D:m00Ko_D:m00?o0000oklo_ono?kl01ono?kl0
0ol0003o^TFjokY5^P08okY5^PCo00002?o9=/T00ol0003o/dbcok=</`04ok=</`03o`000?oK9=_o
fbCK00KofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oG:=OoebSG00_oebSG0ol00009okm0
_`03o`000?nbCK;o000000_oY5^T00?o0000ojEJYOl000002_nFJIH00ol0003oXUfRo`00000?okQ7
^003o`000?nm@[go_D:m00;o_D:m00?o0000olTfbOo9=/T02oo9=/T00ol0003o_D:moke2_@06oke2
_@03o`000?no?koo_cno00Ko_cno00?o0000okY5^_njAKX02OnjAKX01?l0003oaSW6olHia_o6>LH7
o`0000;obCK900?o0000ok=</oncC;<00oncC;<00ol0003ofbCKom/Tf`05om/Tf`03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oG:=OoebSG00SoebSG0ol00003olDja@03o`000?no@;oo_d2o00Oo_d2o00?o0000ojAK
Y?nTFj@02onTFj@00ol0003oUVVFoiIYUP0:oiIYUP03o`000?nhAkSo^4Nh00go^4Nh00?o0000oke2
_Onm@[d01?nm@[d00ol0003obCK9olTfb@09olTfb@03o`000?nm@[go_D:m00So_D:m00?o0000oklo
_ono?kl00ono?kl2o`0000co^TFj00?o0000olHia_o6>LH02?o6>LH<o`0000?ofbCK0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000omLXeooG:=L01_oG:=L3o`0000OoaC[500?o0000okm0_ono@;l01_no@;l00ol0003o
Y5^TojAKY00;ojAKY003o`000?nFJIKoUVVF00WoUVVF0_l0000>okQ7^003o`000?nm@[go_D:m00Go
_D:m00?o0000olTfbOo9=/T02Oo9=/T00ol0003o_D:moke2_@09oke2_@03o`000?no?koo000000;o
00000_neB[D00ol0003o^TFjokY5^P08okY5^P03o`000?o6>LKoaSW600coaSW600?o0000on8Mh_oR
7N801_oR7N83o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003oebSGomLXe`03omLXe`?o00002oo5>/D00ol0003o_d2o
okm0_`04okm0_`03o`000?nTFjCoY5^T00_oY5^T0ol00007oiIYUP?o000000?o[e2_o`000?nhAkP0
3OnhAkP00ol0003o_D:moke2_@06oke2_@03o`000?o9=/WobCK900SobCK900?o0000oke2_Onm@[d0
2_nm@[d00ol0003o]DZeokE:]@04okE:]@03o`000?njAK[o^TFj00Oo^TFj00?o0000olHia_o6>LH0
2oo6>LH00ol0003ohQgRon8MhP08on8MhP03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004omLXeol0
003o0000o`0000ooaC[500?o0000okm0_ono@;l00ono@;l>o`0000?oY5^T0_l00002oiIYUP?o0000
1On_D:l00ol0003o^4NhokQ7^00:okQ7^003o`000?nm@[go_D:m00Oo_D:m00?o0000olTfbOo9=/T0
2?o9=/T00ol0003o_D:moke2_@0:oke2_@03o`000?neB[Go]DZe00Go]DZe00?o0000okY5^_njAKX0
1_njAKX00ol0003oaSW6olHiaP0;olHiaP03o`000?oR7N;ohQgR00SohQgR00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;oaC[500?o0000okm0_ono@;l00_no@;l00ol0003oTVfBoi9]
TP0:oi9]TP03o`000?nTFjCoY5^T00?oY5^T0_l00009ojm@[`03o`000?nhAkSo^4Nh00Wo^4Nh00?o
0000oke2_Onm@[d02?nm@[d2o`0000SobCK900?o0000oke2_Onm@[d02Onm@[d00ol0003o]DZeokE:
]@07okE:]@03o`000?njAK[o^TFj00Co^TFj00?o0000olHia_o6>LH02oo6>LH00ol0003ohQgRon8M
hP09on8MhP03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oaC[5olDja@0?olDja@?o000000?o_d2o
o`000?nBKI802onBKI800ol0003oY5^TojAKY004ojAKY003o`000?n_D:oo[e2_00Wo[e2_00?o0000
okQ7^?nhAkP01onhAkP00ol0003o_D:moke2_@09oke2_@04o`000?njAK[o0000o`0000KobCK900?o
0000oke2_Onm@[d02Onm@[d00ol0003o]DZeokE:]@08okE:]@03o`000?njAK[o^TFj00?o^TFj00?o
0000olHia_o6>LH02oo6>LH00ol0003ohQgRon8MhP09on8MhP03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oaC[5olDja@0<olDja@;o00000onm@[d2o`0000coTVfB00?o0000ojAKY?nTFj@01?nTFj@0
0ol0003o[e2_ojm@[`0:ojm@[`Wo00002onm@[d00ol0003o^TFjokY5^P02okY5^P?o00000_o9=/T0
0ol0003o_D:moke2_@0:oke2_@03o`000?neB[Go]DZe00Wo]DZe00?o0000okY5^_njAKX00_njAKX0
0ol0003oaSW6olHiaP0:olHiaP03o`000?oR7N;ohQgR00WohQgR00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o5>/D2o`0000Go_D:m00?o0000ok5>/Ol000002_nBKI800ol0003oY5^TojAKY006ojAK
Y003o`000?n_D:oo[e2_00Wo[e2_00?o0000ok1?/?n`Ck001On`Ck000ol0003o_D:moke2_@09oke2
_@03o`000?njAK[o^TFj00Go^TFj0ol00009oke2_@?o00003OneB[D01Ol0003o^TFjokY5^_njAK[o
000000coaSW600?o0000on8Mh_oR7N802OoR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000olDj
aOo5>/D01Oo5>/D2o`0000Oo_D:m00Co0000ok5>/OnaC[7o00002OnBKI800ol0003oY5^TojAKY006
ojAKY003o`000?n_D:oo[e2_00So[e2_00?o0000ok1?/?n`Ck001on`Ck000ol0003o_D:moke2_@07
oke2_@03o`000?njAK[o^TFj00So^TFj0ol00002oke2_@Go00000_nIIYT00ol0003o]DZeokE:]@0<
okE:]@03o`000?njAK[o000000coaSW600?o0000on8Mh_oR7N802_oR7N800ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000olDjaOo5>/D00_o5>/D2o`0000So_D:m00?o0000ok5>/OnaC[400_naC[45o`00
00CoTVfB00?o0000ojAKY?nTFj@01_nTFj@00ol0003o[e2_ojm@[`08ojm@[`03o`000?n`Ck3o/4n`
00Oo/4n`00?o0000oke2_Onm@[d01onm@[d00ol0003o^TFjokY5^P08okY5^P03o`000?nKI9_oVfBK
00;o00002?nIIYT00ol0003o]DZeokE:]@0<okE:]@Co00002_o6>LH00ol0003ohQgRon8MhP0:on8M
hP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oaC[5o`000?l0000:oke2_@03o`000?naC[7o/Dja
00;o/Dja00?o0000og6>LOmaSW400_maSW44o`0000WoY5^T00?o0000ojm@[on_D:l02?n_D:l00ol0
003o/4n`ok1?/008ok1?/003o`000?nm@[go_D:m00Go_D:m00?o0000okY5^_njAKX02?njAKX01Ol0
003oVfBKoi]TVonKI9_o000000[oVFJI0ol0000;okE:]@04o`000?oE:]GoeB[EomDZe@Co00001Oo6
>LH00ol0003ohQgRon8MhP0;on8MhP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o_D:moke2_@0:
oke2_@03o`000?naC[7o/Dja00?o/Dja00?o0000og6>LOmaSW401?maSW400ol0003oY5^TojAKY007
ojAKY003o`000?n_D:oo[e2_00Ko[e2_0_l0000;ok1?/003o`000?nm@[go_D:m00Go_D:m00?o0000
okY5^_njAKX02?njAKX00ol0003oVfBKoi]TV`02oi]TV`03o`000?nIIYWoVFJI00OoVFJI00?o0000
okA;]?ndBk@01?l00006okE:]@03o`000?oE:]GoeB[E00KoeB[E0ol00002olHiaP03o`000?oR7N;o
hQgR00_ohQgR00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nm@[go_D:m00Wo_D:m00?o0000ok5>
/OnaC[401?naC[400ol0003oLHiaog6>L@05og6>L@03o`000?nTFjCoY5^T00OoY5^T00?o0000ojm@
[on_D:l00_n_D:l3o`000003okM8]ol0003o/4n`00[o/4n`00?o0000oke2_Onm@[d01Onm@[d00ol0
003o^TFjokY5^P07okY5^P03o`000?nKI9_oVfBK00?oVfBK00?o0000oiUVVOnIIYT01onIIYT00ol0
003o]4^dokA;]004okA;]0?o00000_neB[D00ol0003oeB[EomDZe@0:omDZe@;o00003_oR7N800ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000oke2_Onm@[d02Onm@[d00ol0003o/Djaok5>/@04ok5>/@03
o`000?maSW7oLHia00KoLHia0_l00007ojAKY003o`000?n_D:oo000000;o00001OngB;L00ol0003o
/4n`ok1?/008ok1?/0?o00001?nm@[d00ol0003o^TFjokY5^P08okY5^P03o`000?nKI9_oVfBK00Co
VfBK00?o0000oiUVVOnIIYT01_nIIYT00ol0003o]4^dokA;]007okA;]0;o00003_oE:]D00ol0003o
hQgRon8MhP0;on8MhP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o_D:moke2_@08oke2_@03o`00
0?naC[7o/Dja00Go/Dja00?o0000og6>LOmaSW401?maSW400ol0003oXEjQoj5NX@03o`0000CoY5^T
0_l00008okM8]`03o`000?n`Ck3o/4n`00Oo/4n`00Co0000ol/dboo;=<_obcC;0ol000000onm@[go
0000okY5^P09okY5^P03o`000?nKI9_oVfBK00CoVfBK00?o0000oiUVVOnIIYT01OnIIYT00ol0003o
]4^dokA;]009okA;]003o`000?oE:]GoeB[E00goeB[E00?o0000on8Mh_oR7N802_oR7N800ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000oke2_Onm@[d01onm@[d00ol0003o/Djaok5>/@06ok5>/@03o`00
0?maSW7oLHia00?oLHia00?o0000oj5NXOnQGZ401?nQGZ42o`000003ojAKY?l0003o]dRg00[o]dRg
00?o0000ok1?/?n`Ck001On`Ck000ol0003obcC;ol/db`05ol/db`03o`000?njAK[o^TFj00Oo^TFj
0ol00007oi]TV`03o`000?nIIYWoVFJI00CoVFJI00?o0000okA;]?ndBk@02OndBk@00ol0003oeB[E
omDZe@0=omDZe@03o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nm
@[go_D:m00Go_D:m0ol00009ok5>/@05o`000?maSW7oLHiaog6>LOl000002OnQGZ400ol0003o]dRg
okM8]`0;okM8]`03o`000?n`Ck3o/4n`00?o/4n`00?o0000ol/dboo;=</01_o;=</00ol0003o^TFj
okY5^P06okY5^P05o`000?nkA;_o^dBkok]4^ol000001onKI9/00ol0003oVFJIoiUVV@03oiUVV@03
o`000?ndBkCo]4^d00Wo]4^d00?o0000omDZeOoE:]D03_oE:]D00ol0003ohQgRon8MhP09on8MhP03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o_D:mo`000004o`0000;odRgB00?o0000ok5>/OnaC[40
1onaC[401?l0003oLHiaog6>LOl00009oj5NX@;o00003OngB;L00ol0003o/4n`ok1?/002ok1?/003
o`000?o;=<_obcC;00SobcC;00?o0000okY5^_njAKX00onjAKX2o`0000Go^dBk00?o0000oi]TVonK
I9/01?nKI9/00ol0003oVFJIoiUVV@03oiUVV@03o`000?ndBkCo]4^d00Wo]4^d00?o0000omDZeOoE
:]D03_oE:]D00ol0003ohQgRon8MhP09on8MhP03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SodRgB
00?o0000ok5>/OnaC[401_naC[400ol0003oLHiao`000009oj5NX@04o`000?no@;oo_d2oo`0000go
]dRg00Co0000ok1?/?n`Ck3o00003?o;=</01Ol0003o^TFjokY5^_njAK[o000000So^dBk0_l00005
oi]TV`03o`000?nIIYWoVFJI00;oVFJI00?o0000okA;]?ndBk@02OndBk@00ol0003oeB[EomDZe@0>
omDZe@03o`000?oR7N;ohQgR00WohQgR00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oB;M;odRgB
00OodRgB00?o0000ok5>/OnaC[401onaC[400ol0003oXEjQoj5NX@07oj5NX@03o`000?no@;oo_d2o
00;o_d2o00?o0000okM8]ongB;L02_ngB;L00ol0003o/4n`o`00000>ol/db`03o`000?njAK[o0000
00_o^dBk00?o0000oi]TVonKI9/00_nKI9/01Ol0003oVFJIoiUVVOnIIYWo000000co]4^d00?o0000
omDZeOoE:]D03_oE:]D3o`0000WohQgR00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oB;M;odRgB
00WodRgB00?o0000ok5>/OnaC[401_naC[400ol0003oXEjQoj5NX@06oj5NX@03o`000?no@;oo_d2o
00?o_d2o00?o0000okM8]ongB;L02ongB;L00ol0003obcC;ol/db`0>ol/db`03o`000?nkA;_o^dBk
00_o^dBk0_l00003oi]TV`04o`000?nIIYWoVFJIo`0000[o]4^d0ol0000>omDZe@;o00000ooj1OX2
o`0000OohQgR00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oB;M;odRgB00[odRgB00?o0000ok5>
/OnaC[401?naC[400ol0003oXEjQoj5NX@06oj5NX@03o`000?no@;oo_d2o00Go_d2o00?o0000okM8
]ongB;L01ongB;L3o`00017obcC;00?o0000ok]4^onkA;/03OnkA;/01Ol0003oVfBKoi]TVol0003o
VFJI00Co00000ondBk@5o`0000;oaSW600?o0000omDZeOoE:]D02_oE:]D2o`0000OonPGj0_l00004
on8MhP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odRgBom8]dP0;om8]dP03o`000?naC[7o/Dja
00Co/Dja00?o0000oj5NXOnQGZ401OnQGZ400ol0003o_d2ookm0_`06okm0_`03o`000?ngB;Oo]dRg
00Co]dRg0ol00002oki1_P03o`000?o;=<_obcC;00oobcC;0_l0000?ok]4^`04o`000?nKI9_o0000
o`0000Co[e2_0ol00008olHiaP03o`000?oE:]GoeB[E00OoeB[E0_l0000;ooX5nP;o00000_oR7N80
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om8]d_oB;M803?oB;M86o`0000OoXEjQ00?o0000okm0
_ono@;l02?no@;l00ol0003o]dRgokM8]`03o`0000Ko_T6n00?o0000ol/dboo;=</03Oo;=</01?l0
003oaSW6olHia_l0000?ok]4^`03o`000?n_D:oo[e2_00Go[e2_00?o0000olHia_o6>LH02?o6>LH0
0ol0003oeB[EomDZe@05omDZe@03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oB;M800ol0003o/4n`ok1?/004ok1?
/003o`000?nQGZ7oXEjQ00?oXEjQ00?o0000okm0_ono@;l02_no@;l2o`0000[o_T6n00?o0000ol/d
boo;=</02oo;=</00ol0003oaSW6olHiaP02olHiaP03o`000?nkA;_o^dBk00_o^dBk0_l00007ojm@
[`03o`000?o6>LKoaSW600WoaSW600?o0000omDZeOoE:]D00_oE:]D2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om8]d_oB;M802ooB;M800ol0003o/4n`ok1?/006ok1?/005o`000?nQGZ7oXEjQoj5N
XOl000003Ono@;l00ol0003o_T6noki1_P0:oki1_P03o`000?o;=<_obcC;00WobcC;00?o0000olHi
a_o6>LH01?o6>LH00ol0003o^dBkok]4^`08ok]4^`;o000000?oWF:Mo`000?n_D:l01on_D:l00ol0
003oaSW6olHiaP09olHiaP04o`000?oE:]Go0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oB;M;odRgB
00WodRgB00?o0000ok1?/?n`Ck002?n`Ck000ol0003oXEjQo`00000=okm0_`03o`000?nn@Kko_T6n
00_o_T6n00?o0000ol/dboo;=</02?o;=</00ol0003oaSW6olHiaP06olHiaP03o`000?nkA;_o^dBk
00Go^dBk0_l00003oieRW@03o`000?n_D:oo[e2_00Ko[e2_00?o0000olHia_o6>LH02_o6>LH00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003odRgBom8]dP07om8]dP03o`000?n`Ck3o/4n`00[o/4n`00?o0000okm0_ono
@;l03?no@;l00ol0003o_T6noki1_P0<oki1_P03o`000?o;=<_obcC;00KobcC;00?o0000olHia_o6
>LH02?o6>LH00ol0003o^dBkok]4^`02ok]4^`;o00001_nMHYd00ol0003o[e2_ojm@[`05ojm@[`03
o`000?o6>LKoaSW600[oaSW600?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oB;M;odRgB00GodRgB
00?o0000ok1?/?n`Ck003?n`Ck02o`0000co_d2o00?o0000oki1__nn@Kh03Onn@Kh00ol0003obcC;
ol/db`04ol/db`03o`000?o6>LKoaSW600[oaSW600Co0000ok]4^ol0003o00002?nMHYd00ol0003o
[e2_ojm@[`06ojm@[`03o`000?o6>LKoaSW600WoaSW600?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oB;M800ol0003o/4n`ok1?/00=ok1?/003o`000?ngB;Oo000000;o00002?no@;l00ol0003o_T6n
oki1_P0?oki1_PKo00003_o6>LH00ol0003oWF:MoieRW@08oieRW@03o`000?n_D:oo[e2_00Ko[e2_
00?o0000olHia_o6>LH02Oo6>LH00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000oldbcOo=</gocC;=
0_l0000?ok1?/003o`000?ngB;Oo]dRg00?o]dRg0ol00005okm0_`;o00004?nn@Kh01_l0003o/dbc
ok=</ol0003oXebSo`0000koaSW600?o0000oieRWOnMHYd02OnMHYd00ol0003o[e2_ojm@[`05ojm@
[`03o`000?o6>LKoaSW600WoaSW600?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000oldbcOo=</d00oo=</d00ol0003o
/4n`ok1?/00=ok1?/003o`000?ngB;Oo]dRg00Ko]dRg0ol000001?no@;oo0000okM8]ongB;L3o`00
00co_T6n00Go0000ok=</oncC;?o/dbco`000002oj=LX`03o`000?o6>LKoaSW600_oaSW600?o0000
oieRWOnMHYd02OnMHYd00ol0003o[e2_ojm@[`06ojm@[`03o`000?o6>LKoaSW600SoaSW60_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003ocC;=oldbc@04oldbc@oo00003?ngB;L00ol0003o]dRgokM8]`04okM8
]`?o00002?nn@Kh00ol0003o/dbcok=</`02ok=</`05o`000?nSG:?oXebSoj=LXol000003?o6>LH0
0ol0003oWF:MoieRW@09oieRW@03o`000?n_D:oo[e2_00Go[e2_3?l00002om`Sg0;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003ocC;=oldbc@05oldbc@03o`000?nOH9ooWf2O00_oWf2O00?o0000okM8
]ongB;L02_ngB;L00ol0003o]dRgokM8]`07okM8]`;o00001Onn@Kh00ol0003o/dbcok=</`03ok=<
/`03o`000?nSG:?oXebS00;oXebS00?o0000olHia_o6>LH02Oo6>LH00ol0003oWF:MoieRW@0:oieR
W@03o`000?n_D:oo[e2_00?o[e2_00?o0000oiiQW_nNHIh02OnNHIh00ol0003og2?Lom`Sg002om`S
g0;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ocC;=oldbc@06oldbc@03o`000?nOH9ooWf2O00[o
Wf2O00?o0000okM8]ongB;L02ongB;L00ol0003o]dRgokM8]`09okM8]`?o000000?o_T6no`000?nc
C;<01OncC;<00ol0003oXebSoj=LX`03oj=LX`03o`000?o6>LKoaSW600SoaSW63_l00003ojm@[`;o
00002onNHIh00ol0003og2?Lom`Sg005om`Sg003o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000oldbcOo=</d01Oo=</d00ol0003oZeB[o`00000;oimPW`03o`000?ngB;Oo]dRg00[o]dRg
0_l0000>okM8]`03o`000?ncC;?o/dbc00Go/dbc00?o0000oj=LXonSG:<00onSG:<00ol0003oaSW6
olHiaP08olHiaP03o`000?ngB;Oo]dRg00_o]dRg00?o0000ojm@[ol000003OnNHIh00ol0003og2?L
om`Sg006om`Sg0;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o=</gocC;=00KocC;=00Co
0000oj]DZon[E:_o00002_nOH9l00ol0003o]dRgokM8]`09okM8]`03o`000?ndBkCo000000ko]dRg
00?o0000ok=</oncC;<01OncC;<00ol0003oXebSoj=LX`04oj=LX`03o`000?o6>LKoaSW600KoaSW6
00?o0000okM8]ongB;L03OngB;L00ol0003oWV6NoiiQWP0<oiiQWP03o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o=</gocC;=00GocC;=00?o0000oj]DZon[E:/00_n[
E:/00ol0003oWf2OoimPW`06oimPW`03o`000?ngB;Oo]dRg00So]dRg0_l00003okA;]003o`000?ng
B;Oo]dRg00_o]dRg00?o0000ok=</oncC;<01OncC;<00ol0003oXebSoj=LX`05oj=LX`03o`000?o6
>LKoaSW600GoaSW600?o0000okM8]ongB;L03OngB;L00ol0003oWV6NoiiQWP0;oiiQWP03o`000?oL
8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o=</gocC;=00KocC;=00?o0000
oj]DZon[E:/00on[E:/00ol0003oWf2OoimPW`05oimPW`03o`000?ngB;Oo]dRg00Oo]dRg00?o0000
okA;]?ndBk@00ondBk@00ol0003o]dRgokM8]`0:okM8]`03o`000?ncC;?o/dbc00Ko/dbc00?o0000
oj=LXonSG:<01_nSG:<00ol0003oaSW6olHiaP04olHiaP03o`000?ngB;Oo]dRg00go]dRg3ol0000;
om`Sg003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o=</gocC;=00KocC;=00?o0000oj]DZon[E:/01On[E:/00ol0
003oWf2OoimPW`04oimPW`03o`000?ngB;Oo]dRg00Go]dRg0_l00006okA;]003o`000?ngB;Oo]dRg
00Wo]dRg0_l00008ok=</`03o`000?nSG:?oXebS00KoXebS1Ol000000oo6>LKo0000okM8]`0?okM8
]`03o`000?nJII[oVVFJ00_oVVFJ00?o0000om`Sg?oL8m`02OoL8m`00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o=</gocC;=00KocC;=00?o0000oj]DZon[E:/01_n[E:/00ol0003o
Wf2OoimPW`04o`0000Ko]dRg00?o0000okA;]?ndBk@01ondBk@00ol0003o]dRgokM8]`05okM8]`?o
000000?oZUFZo`000?ncC;<01oncC;<00ol0003oXebSoj=LX`05oj=LX`03o`000?o7><OoacS700?o
acS70_l0000?okM8]`;o00003OnJIIX00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WocC;=00?o0000oj]DZon[E:/01on[E:/2o`0000CobSG:00Co0000okM8]ongB;Oo
]dRg0_l0000:okA;]003o`000?ngB;Oo]dRg00;o]dRg0ol00005ojYEZP03o`000?ncC;?o/dbc00Go
/dbc00?o0000oj=LXonSG:<01?nSG:<00ol0003oacS7olLha`06olLha`03o`000?ngB;Oo]dRg00[o
]dRg0_l00002okE:]@03o`000?nJII[oVVFJ00[oVVFJ00?o0000om`Sg?oL8m`02?oL8m`00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000oldbcOo=</d01_o=</d00ol0003oZeB[oj]DZ`08oj]DZ`03o`00
0?o:=L[obSG:00CobSG:00?o0000okM8]ol000003?ndBk@00ol0003o]dRgo`000002o`0000WoZUFZ
00?o0000ok=</oncC;<01?ncC;<00ol0003oXebSoj=LX`03oj=LX`03o`000?o7><OoacS700SoacS7
1_l00004okM8]`;o00001OneB[D00ol0003oVVFJoiYUVP09oiYUVP03o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o=</gocC;=00GocC;=00?o0000oj]DZon[E:/01on[
E:/00ol0003obSG:olXebP06olXebP03o`000?ndBkCo]4^d00co]4^d00?o0000ojYEZ_nZEJX02_nZ
EJX00ol0003o/dbcok=</`04ok=</`04o`000?nSG:?oXebSoj=LX`;o00002oo7><L00ol0003o`Ck1
ol4n`@03ol4n`@Co00002?neB[D00ol0003oVVFJoiYUVP08oiYUVP03o`000?oL8mcog2?L00Oog2?L
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000oldbcOo=</d00oo=</d00ol0003oZeB[oj]DZ`07oj]DZ`03o`000?o:
=L[obSG:00OobSG:00?o0000okA;]?ndBk@03?ndBk@00ol0003oZUFZojYEZP0;ojYEZP03o`000?nc
C;?o/dbc00?o/dbc00Co0000oj=LXonSG:?o00003Oo7><L00ol0003o`Ck1ol4n`@06ol4n`@03o`00
0?neB[Go]DZe00Oo]DZe00?o0000oiYUV_nJIIX01onJIIX00ol0003og2?Lom`Sg006om`Sg004o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o=</gocC;=00;ocC;=00?o0000oj]DZon[E:/0
1_n[E:/00ol0003obSG:olXebP09olXebP03o`000?ndBkCo]4^d00Wo]4^d0_l0000>ojYEZP?o0000
0oncC;<00ol0003oXebSo`00000=olLha`03o`000?o1?/7o`Ck100Oo`Ck100?o0000okE:]OneB[D0
2?neB[D:o`0000Kog2?L0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoZeB[00?o
0000olXeb_o:=LX02_o:=LX00ol0003o]4^dokA;]006okA;]0;o000000?o]DZeo`000?nZEJX02onZ
EJX2o`0000?ob3O81Ol0000>olLha`03o`000?o1?/7o`Ck100Oo`Ck100?o0000okE:]OneB[D02?ne
B[D00ol0003o[e2_ojm@[`06ojm@[`03o`000?oL8mcog2?L00?og2?L00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003od2o@om0_d003om0_d0Co00000_n[E:/00ol0003obSG:olXebP0;
olXebP03o`000?ndBkCo]4^d00?o]4^d0ol00004okE:]@03o`000?nZEJ[oZUFZ00OoZUFZ0_l00008
olPgb003o`000?o7><OoacS700goacS700?o0000ol4n`Oo1?/402?o1?/400ol0003o]DZeokE:]@07
okE:]@03o`000?n_D:oo[e2_00Oo[e2_0ol000000ooL8mco0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o@;m3od2o@00Ood2o@0_l0000?olXebP03o`000?ndBkCo]4^d00;o00002?neB[D00ol0
003oZUFZojYEZP05ojYEZP03o`000?o8=lSob3O800Sob3O800?o0000olLhaoo7><L03Oo7><L00ol0
003o`Ck1ol4n`@08ol4n`@03o`000?neB[Go]DZe00Ko]DZe00?o0000ojm@[on_D:l02?n_D:l01?l0
003ofRGJomXUf_l0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003od2o@om0_d009om0_
d003o`000?o:=L[obSG:00kobSG:0_l0000;okE:]@03o`000?nZEJ[oZUFZ00;oZUFZ0_l0000;olPg
b003o`000?o7><OoacS700goacS700?o0000ol4n`Oo1?/402?o1?/400ol0003o]DZeokE:]@06okE:
]@03o`000?n_D:oo[e2_00Oo[e2_00Go0000omXUf_oJ9M[ofRGJo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003od2o@om0_d00:om0_d003o`000?o:=L[obSG:00gobSG:0_l0000<okE:]@04o`000?nZEJ[o0000
o`0000gob3O800?o0000olLhaoo7><L03?o7><L00ol0003o`Ck1ol4n`@09ol4n`@03o`000?neB[Go
]DZe00Ko]DZe00?o0000ojm@[on_D:l01_n_D:l00ol0003ofRGJomXUfP03omXUfP03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003od2o@om0_d00:om0_d003o`000?o:=L[obSG:00cobSG:00Co0000oi5^
TOnAKY7o00003?neB[D00ol0003ob3O8olPgb00>olPgb003o`000?o7><OoacS700SoacS71?l0000;
ol4n`@03o`000?neB[Go]DZe00Ko]DZe00?o0000ojm@[on_D:l01On_D:l00ol0003ofRGJomXUfP04
omXUfP03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003od2o@om0_d00;om0_d003o`000?o:=L[obSG:
00_obSG:00?o0000oi5^TOnAKY400_nAKY400ol0003o]DZeokE:]@09okE:]@03o`000?o8=lSob3O8
00kob3O800Co0000olLhaoo7><OoacS71ol00003olPgb003o`000?o1?/7o`Ck100Wo`Ck100?o0000
okE:]OneB[D01_neB[D00ol0003o[e2_ojm@[`04ojm@[`03o`000?oJ9M[ofRGJ00KofRGJ00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o@;m3od2o@00cod2o@00?o0000olXeb_o:=LX02_o:=LX00ol0
003oTFjAoi5^T@03oi5^T@03o`000?neB[Go]DZe00So]DZe00?o0000olPgb?o8=lP03_o8=lP4o`00
00_ob3O800?o0000ol4n`Oo1?/402?o1?/400ol0003o]DZeokE:]@05okE:]@03o`000?n_D:oo[e2_
00Go[e2_00?o0000omXUf_oJ9MX01_oJ9MX00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000om0_d?o@
;m003?o@;m07o`0000GobSG:00?o0000oi5^TOnAKY401OnAKY400ol0003o]DZeokE:]@07okE:]@03
o`000?o8=lSob3O800kob3O800?o0000olPgb?o8=lP03Oo8=lP00ol0003o`Ck1ol4n`@08ol4n`@03
o`000?neB[Go]DZe00Co]DZe00?o0000ojm@[on_D:l01?n_D:l00ol0003ofRGJomXUfP07omXUfP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003od2o@om0_d00=om0_d003o`000?o8=lSob3O800Cob3O8
1Ol00009oi5^T@03o`000?neB[Go]DZe00Ko]DZe00?o0000olPgb?o8=lP03_o8=lP00ol0003ob3O8
olPgb00=olPgb003o`000?o1?/7o`Ck100So`Ck100Co0000okE:]OneB[Go]DZe1Ol00004ojm@[`03
o`000?oJ9M[ofRGJ00WofRGJ1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=om0_d003o`000?o8=lSob3O800Wob3O8
0_l00009oi5^T@03o`000?neB[Go]DZe00Ko]DZe00?o0000olPgb?o8=lP03?o8=lP00ol0003ob3O8
olPgb00?olPgb0Ko00001?o1?/44o`0000GobCK90_l000000on_D:oo0000omXUfP0;omXUfP04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oG:=OoebSGomLXe`?o00002_o@;m000ol0003o
b3O8olPgb009olPgb003o`000?nMHYgo000000;o00001onAKY400ol0003o]DZeokE:]@05okE:]@03
o`000?o8=lSob3O800Sob3O81Ol0000AolPgb003o`000?o2?L;o`Sg200?o`Sg21?l0000;olTfb@03
o`000?oJ9M[ofRGJ00[ofRGJ00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omLXeooG:=L01OoG:=L2o`0000Ood2o@
00?o0000olPgb?o8=lP02_o8=lP00ol0003oWF:MoieRW@02oieRW@?o00001OnAKY400ol0003o]DZe
okE:]@04okE:]@04o`000?o8=lSob3O8olPgb0Oo00001?njAKX00ol0003ob3O8olPgb00>olPgb003
o`000?o2?L;o`Sg200Oo`Sg200?o0000olTfbOo9=/T02Oo9=/T00ol0003ofRGJomXUfP09omXUfP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oebSGomLXe`08omLXe`;o00001?o@;m000ol0003ob3O8
olPgb00;olPgb003o`000?nMHYgoWF:M00GoWF:M0ol00003oi5^T@04o`000?neB[Go]DZeokE:]@Ko
00003?njAKX00ol0003ob3O8olPgb00=olPgb003o`000?o2?L;o`Sg200Oo`Sg200?o0000olTfbOo9
=/T02_o9=/T00ol0003ofRGJomXUfP08omXUfP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omLXe`?o000000?od2o@o`000?o8=lP0
3?o8=lP00ol0003oWF:MoieRW@08oieRW@?o000000CoTFjAo`000?l0003o00000_o9=/T00ol0003o
^TFjokY5^P0=okY5^P03o`000?o8=lSob3O800cob3O800?o0000ol8m`_o2?L802?o2?L800ol0003o
bCK9olTfb@0;olTfb@03o`000?oJ9M[ofRGJ00KofRGJ00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
ebSG00?o0000olPgb?o8=lP03?o8=lP00ol0003oWF:MoieRW@0;oieRW@03o`000?o9=/WobCK900?o
bCK900?o0000okY5^_njAKX03?njAKX00ol0003oZ5NXo`00000=olPgb003o`000?o2?L;o`Sg200So
`Sg200?o0000olTfbOo9=/T03?o9=/T3o`0000GofRGJ00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oG:=OoebSG00coebSG00?o0000olPgb?o8=lP03?o8=lP00ol0003oWF:MoieRW@0:oieRW@03o`00
0?o9=/WobCK900GobCK900?o0000okY5^_njAKX02_njAKX01?l0003oZ5NXojQGZ?nXEjP2o`0000[o
b3O800?o0000ol8m`_o2?L802Oo2?L800ol0003obCK9olTfb@0<olTfb@03o`000?oP7n3oh1oP00?o
000000?ofRGJo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000olPgb?o8=lP0
3?o8=lP00ol0003oWF:MoieRW@09oieRW@03o`000?o9=/WobCK900KobCK900?o0000okY5^_njAKX0
2OnjAKX00ol0003oZ5NXojQGZ002ojQGZ003o`000?o6>LKo000000;o00001oo8=lP00ol0003o`Sg2
ol8m`P09ol8m`P03o`000?o9=/WobCK900_obCK900?o0000on0Oh?oP7n001?oP7n000ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omLXeooG:=L02ooG:=L00ol0003ob3O8olPgb00;olPgb003o`000?nM
HYgoWF:M00SoWF:M00?o0000olTfbOo9=/T01oo9=/T00ol0003o^TFjokY5^P08okY5^P03o`000?nX
EjSoZ5NX00?oZ5NX00?o0000olHia_o6>LH00_o6>LH2o`0000Cob3O800?o0000ol8m`_o2?L802_o2
?L800ol0003obCK9olTfb@0:olTfb@03o`000?oP7n3oh1oP00Goh1oP00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oG:=OoebSG00[oebSG0ol0000;olPgb0Ko00001?nMHYd00ol0003obCK9olTfb@08
olTfb@03o`000?njAK[o^TFj00Oo^TFj00?o0000ojQGZ?nXEjP00onXEjP00ol0003oaSW6olHiaP05
olHiaP?o000000?ob3O8o`000?o2?L802oo2?L800ol0003obCK9olTfb@09olTfb@03o`000?oP7n3o
h1oP00Ooh1oP00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oG:=OoebSG00WoebSG00?o0000okA;
]?ndBk@01?l00006olPgb003o`000?o3?<?o`cc300Co`cc31?l0000<olTfb@03o`000?njAK[o^TFj
00Go^TFj00?o0000ojQGZ?nXEjP01?nXEjP00ol0003oaSW6olHiaP08olHiaP03o`000?o2?L;o`Sg2
00_o`Sg200?o0000olTfbOo9=/T02?o9=/T00ol0003oh1oPon0Oh008on0Oh0Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oG:=OoebSG00OoebSG00?o0000okA;]?ndBk@01OndBk@3o`0000;ob3O800?o0000ol<l`oo3
?<<02?o3?<<00ol0003obCK9olTfb@0:olTfb@03o`000?njAK[o^TFj00Co^TFj00?o0000ojQGZ?nX
EjP01OnXEjP00ol0003oaSW6olHiaP08olHiaP03o`000?o2?L;o`Sg200Wo`Sg21?l00008olTfb@03
o`000?oP7n3oh1oP00Woh1oP00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSG
omLXe`05omLXe`03o`000?ndBkCo]4^d00Wo]4^d0_l0000<ol<l``03o`000?o9=/WobCK900WobCK9
00?o0000okY5^_njAKX00onjAKX00ol0003oZ5NXojQGZ005ojQGZ003o`000?o6>LKoaSW600[oaSW6
00?o0000ol8m`_o2?L801?o2?L84o`0000CoaC[500?o0000olTfbOo9=/T01?o9=/T00ol0003oh1oP
on0Oh00:on0Oh003o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oG:=OoebSG00?oebSG00?o0000okA;]?ndBk@02ond
Bk@00ol0003o`cc3ol<l``0:ol<l``03o`000?o9=/WobCK900WobCK900?o0000okY5^_njAKX00_nj
AKX00ol0003oZ5NXojQGZ006ojQGZ003o`000?o6>LKoaSW600[oaSW600?o0000ol8m`_o2?L801?l0
0009olDja@Ko00003?oP7n000ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omLXeooG:=OoebSG0_l0
000=okA;]003o`000?o3?<?o`cc300[o`cc300?o0000olTfbOo9=/T02Oo9=/T01Ol0003o^TFjokY5
^_njAK[o000000WoZ5NX00?o0000olHia_o6>LH02oo6>LH2o`0000goaC[500?o0000omTVfOoI9]T0
0_oI9]T00ol0003oh1oPon0Oh00:on0Oh003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oebSGo`00
0002om0_d0;o00002ondBk@00ol0003o`cc3ol<l``0;ol<l``03o`000?o9=/WobCK900WobCK900?o
0000okY5^_l000002OnXEjP00ol0003oaSW6olHiaP0<olHiaP03o`000?o5>/GoaC[500coaC[500?o
0000omTVfOoI9]T00ooI9]T00ol0003oh1oPon0Oh009on0Oh003o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003od2o@om0_d003om0_d0;o00002_ndBk@00ol0003o`cc3ol<l``0:ol<l``03o`000?o9=/Wo
bCK900SobCK91Ol00008ojQGZ003o`000?o6>LKoaSW600coaSW600?o0000olDjaOo5>/D02oo5>/D0
0ol0003ofBKIomTVf@05omTVf@03o`000?oP7n3oh1oP00Soh1oP00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001oo@;m02o`0000So]4^d00?o0000ol<l`oo3?<<02_o3?<<00ol0003obCK9olTfb@07olTf
b@03o`000?nl@kco_4>l00?o_4>l0ol00005ojQGZ003o`000?o6>LKoaSW600_oaSW600?o0000olDj
aOo5>/D03?o5>/D00ol0003ofBKIomTVf@06omTVf@03o`000?oP7n3oh1oP00Ooh1oP00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000Wod2o@00?o0000okA;]?ndBk@01OndBk@2o`0000co
`cc300?o0000olTfbOo9=/T01Oo9=/T00ol0003o_4>loka3_007oka3_0?o000000?oZ5NXo`000?o6
>LH03Oo6>LH00ol0003oaC[5olDja@0<olDja@03o`000?oI9]WofBKI00KofBKI00?o0000on0Oh?oP
7n001_oP7n000ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?o@;m3od2o@00Ood2o@
0_l00004okA;]003o`000?ndBkCo]4^d00;o00002_o3?<<00ol0003obCK9olTfb@03olTfb@;o0000
3Onl@k`2o`0000goaSW60ol0000=olDja@03o`000?oI9]WofBKI00OofBKI00?o0000on0Oh?oP7n00
1OoP7n000ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?o@;m3od2o@00Sod2o@0_l0
00000ondBkCo0000okA;]004okA;]003o`000?o3?<?o`cc300Oo`cc300Co0000olTfbOo9=/WobCK9
0_l00002okY5^P03o`000?nl@kco_4>l00co_4>l3Ol00003oj]DZ`03o`000?o5>/GoaC[500[oaC[5
00?o0000omTVfOoI9]T02?oI9]T01?l0003oh1oPon0Oh?oP7n04o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003od2o@
om0_d009om0_d003o`000?ndBkCo]4^d00Go]4^d0_l00008ol<l``03o`000?o9=/Wo000000Go^TFj
00?o0000oka3_?nl@k`02onl@k`00ol0003o^TFjokY5^P09okY5^P03o`000?n[E:_oZeB[00;oZeB[
0_l00009olDja@03o`000?oI9]WofBKI00[ofBKI0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?o@;m3od2o@00Sod2o@00?o0000okA;]?ndBk@01ondBk@4o`0000?o`cc30ol0
0007okY5^P03o`000?nl@kco_4>l00[o_4>l00?o0000okY5^_njAKX02OnjAKX00ol0003oZeB[oj]D
Z`04oj]DZ`;o00001oo5>/D00ol0003ofBKIomTVf@0:omTVf@03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?o@;m3od2o@00Ood2o@00?o0000okA;]?ndBk@02?ndBk@0
1?l0003o^4NhokQ7^?nhAkP3o`0000;o^4Nh00?o0000okY5^_njAKX01_njAKX00ol0003o_4>loka3
_008oka3_003o`000?njAK[o^TFj00[o^TFj00?o0000oj]DZon[E:/01_n[E:/00ol0003oaC[5olDj
a@04olDja@03o`000?oI9]WofBKI00WofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om0_d?o@;m001Oo@;m000ol0003o]4^dokA;]008okA;]003o`000?nhAkSo
^4Nh00Co^4Nh00Go0000okQ7^?nhAkSo^4Nho`000008okY5^P03o`000?nl@kco_4>l00Oo_4>l00?o
0000okY5^_njAKX02_njAKX00ol0003oZeB[oj]DZ`07oj]DZ`;o00001?o5>/D00ol0003ofBKIomTV
f@08omTVf@03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om0_d?o@;m000oo@;m00
0ol0003o]4^dokA;]008okA;]003o`000?nhAkSo^4Nh00Co^4Nh00?o0000okQ7^?nhAkP00_nhAkP0
0ol0003o^TFjokY5^P07okY5^P03o`000?nl@kco_4>l00Ko_4>l00?o0000okY5^_njAKX02_njAKX0
0ol0003oZeB[oj]DZ`09oj]DZ`05o`000?o5>/GoaC[5olDjaOl000002OoI9]T00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_o]4^d00?o0000okQ7^?nhAkP01?nhAkP00ol0003o^4NhokQ7^003
okQ7^003o`000?njAK[o^TFj00Oo^TFj00?o0000oka3_?nl@k`01Onl@k`00ol0003o^TFjokY5^P0:
okY5^P03o`000?n[E:_oZeB[00WoZeB[1?l00009omTVf@03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oN8MkogR7N
omhQg_l000002_ndBk@00ol0003o^4NhokQ7^005okQ7^003o`000?nhAkSo^4Nh00?o^4Nh00?o0000
okY5^_njAKX02?njAKX00ol0003o_4>loka3_004oka3_003o`000?njAK[o^TFj00Wo^TFj00?o0000
oj]DZon[E:/02?n[E:/2o`0000?oeRWF00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000omhQg_oN8Mh00ooN8Mh00ol0003o]4^dokA;]006okA;]003o`000?nhAkSo^4Nh
00Go^4Nh00?o0000okQ7^?nhAkP01?nhAkP00ol0003o^TFjokY5^P09okY5^P03o`000?nl@kco_4>l
00;o_4>l00?o0000okY5^_njAKX02_njAKX00ol0003oZeB[oj]DZ`06oj]DZ`;o00001_oF:MH8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ogR7NomhQgP05omhQgP03o`000?ndBkCo]4^d00Go]4^d00?o0000okQ7^?nh
AkP01OnhAkP00ol0003o^4NhokQ7^005okQ7^003o`000?njAK[o^TFj00Wo^TFj00Go0000oka3_?nl
@kco_4>lo`00000<okY5^P03o`000?n[E:_oZeB[00CoZeB[0_l00008omHYeP03o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oN8MkogR7N00OogR7N00?o0000okA;]?nd
Bk@00ondBk@00ol0003o^4NhokQ7^006okQ7^003o`000?nhAkSo^4Nh00Go^4Nh00?o0000okY5^_nj
AKX02_njAKX00ol0003o_4>lo`000004o`0000Wo^TFj00?o0000oj]DZon[E:/00_n[E:/2o`0000[o
eRWF00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ogR7NomhQgP07omhQgP03o`00
0?ndBkCo]4^d00;o]4^d00?o0000okQ7^?nhAkP01_nhAkP00ol0003o^4NhokQ7^007okQ7^0;o0000
2onjAKX00ol0003o_D:moke2_@03oke2_@Oo00000_njAKX00ol0003oZeB[oj]DZ`02o`0000_oeRWF
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omhQg_oN8Mh02OoN
8Mh01Ol0003o]4^dokA;]?ndBkCo000000So^4Nh00?o0000okQ7^?nhAkP01onhAkP00ol0003ocS7>
o`000002o`0000So^TFj00?o0000oke2_Onm@[d02_nm@[d5o`0000goeRWF00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<omhQgP03o`000?ndBkCo000000Wo^4Nh00?o
0000okQ7^?nhAkP01_nhAkP00ol0003ocS7>olhacP03olhacP?o00001?njAKX00ol0003o_D:moke2
_@0=oke2_@03o`000?oF:MKoeRWF00goeRWF00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ooj1OX2o`0000_ogR7N00?o0000okQ7^?nhAkP01onhAkP00ol0003o^4NhokQ7^007
okQ7^003o`000?o><LkocS7>00KocS7>0ol000000onjAK[o0000oke2_@0>oke2_@03o`000?oF:MKo
eRWF00coeRWF00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00KonPGj0_l00009omhQ
gP03o`000?nhAkSo^4Nh00;o^4Nh1_l00008okQ7^003o`000?o><LkocS7>00[ocS7>00?o0000oke2
_Onm@[d03onm@[d00ol0003oeRWFomHYeP0:omHYeP;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00So
nPGj0_l00007omhQgPGo00001_oQ7^400ol0003o^4NhokQ7^005okQ7^003o`000?o><LkocS7>00[o
cS7>00?o0000oke2_Onm@[d03onm@[d00ol0003oeRWFomHYeP07omHYeP?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oj1O[onPGj00[onPGj0_l00005omhQgP03o`000?oQ7^7ohAkQ00WohAkQ00?o0000okQ7^?nh
AkP00onhAkP00ol0003ocS7>olhacP0;olhacP03o`000?nm@[go_D:m00oo_D:m00?o0000omHYe_oF
:MH01OoF:MH2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5nP0<ooX5nP;o000000?ogR7No`000?l00000
3OoQ7^400ol0003o^4NhokQ7^002okQ7^003o`000?o><LkocS7>00_ocS7>5?l00004omHYeP;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooX5n_oj1OX03_oj1OX00ol0003onPGjo`00000>on4Nh@04o`000?nhAkSo^4Nho`0000kocS7>
00?o0000on<LhooS7><04?oS7><00ol0003oeRWFo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5
nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000003_oQ7^400ol0003o^4Nho`00000>olhacP03o`00
0?oS7>?ohacS017ohacS00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00conPGj00?o
0000ooX5n_oj1OX00_oj1OX00ol0003ohAkQon4Nh@0=on4Nh@03o`000?o><LkocS7>00WocS7>1Ol0
000Bon<Lh`;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003ohAkQon4Nh@0<on4Nh@03o`000?o><LkocS7>00;ocS7>1ol00004ooX5nP03o`000?oS7>?o
hacS00oohacS00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003onPGjooX5nP06ooX5
nP03o`000?oQ7^7ohAkQ00cohAkQ1?l0000<ooX5nP03o`000?oS7>?ohacS00cohacS0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00Oo
nPGj00?o0000on4NhOoQ7^403?oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?oS7>?ohacS00_o
hacS00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00konPGj00?o0000on<LhooS
7><02OoS7><2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000on4NhOoQ7^402_oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?oS7>?ohacS00KohacS0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooX5n_l0003onPGj00gonPGj3?l0
000AooX5nP?o00001_oS7><00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooS7><2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000on<Lhol000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Koool02Ol00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0006o`00o`?oool00ol00?l2oooo00Ko003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Ko003o0_ooo`1]o`00o`7ooooo001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04
o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`003Ol00?l2
oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2oooo06go003o0Oooool0077o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000>o`00o`03oooo0?l00?oo003o
00;o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1]o`00o`7ooooo001ao`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000ko003o0_ooo`03o`00o`03oooo0?l00?oo003o00Co
003o00?oool0o`00ool00?l01Ol00?l2oooo06go003o0Oooool0077o003o0_ooo`000ol00?ooool0
o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`05o`00o`Coool0
0_l00?l2oooo00ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06go003o0Oooool0073o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00go003o0oooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0<o`00o`?oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo000:o`00o`Goool00ol00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool01ol00?l6
oooo00Go003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_ooo`05o`00
o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01ol00?l4oooo00Oo003o0_ooo`06o`00
o`;oool01_l00?l2oooo06go003o0Oooool006ko003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool02?l00?l00oooo`3o003oo`00o`07o`00o`;oool01_l00?l00oooo`3o
003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
6?l00?l2oooo00So003o00?oool0o`00ool00?l02?l00?l2oooo00Co003o0_ooo`07o`00o`;oool0
KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_oo
o`000olb</co003oo`00o`05o`00o`03oooo0?l00?oo003o00So003o0_ooo`04o`00o`;oool01_l0
0?l00olb</coool0oooo001]o`00o`7ooooo001]o`00o`?oool01Ol00?l3oooo00Oo003o00?oool0
o`00ool00?l05_l00?l5oooo00Ko003o1_ooo`05o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1]
o`00o`7ooooo001/o`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08Ol00?l7oooo
00Go003o1?ooo`1ho`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(60) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.98 .02 .98 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.979 .021 .979 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.979 .021 .979 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.979 .021 .979 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.842 .158 .842 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.978 .022 .978 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.833 .167 .833 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.884 .116 .884 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.84 .16 .84 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.774 .226 .774 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.98 .02 .98 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.773 .227 .773 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.731 .269 .731 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.98 .02 .98 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.757 .243 .757 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.75 .25 .75 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.977 .023 .977 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.978 .022 .978 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.819 .181 .819 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.714 .286 .714 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.526 .474 .526 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.614 .386 .614 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.613 .387 .613 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.634 .366 .634 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.829 .171 .829 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.835 .165 .835 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.98 .02 .98 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.644 .356 .644 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.749 .251 .749 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.622 .378 .622 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.796 .204 .796 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.797 .203 .797 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.979 .021 .979 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.772 .228 .772 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.717 .283 .717 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.81 .19 .81 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.814 .186 .814 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.625 .375 .625 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.98 .02 .98 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.87 .13 .87 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.709 .291 .709 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.73 .27 .73 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.698 .302 .698 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.817 .183 .817 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.873 .127 .873 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.673 .327 .673 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.979 .021 .979 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.646 .354 .646 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.571 .429 .571 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.791 .209 .791 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.808 .192 .808 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.647 .353 .647 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.647 .353 .647 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.749 .251 .749 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.979 .021 .979 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.784 .216 .784 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.755 .245 .755 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.845 .155 .845 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.371 .629 .371 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.681 .319 .681 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.756 .244 .756 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.792 .208 .792 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.584 .416 .584 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.511 .489 .511 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.51 .49 .51 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.561 .439 .561 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.762 .238 .762 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.57 .43 .57 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.667 .333 .667 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.694 .306 .694 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.732 .268 .732 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.75 .25 .75 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.723 .277 .723 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.879 .121 .879 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.979 .021 .979 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.585 .415 .585 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.656 .344 .656 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.556 .444 .556 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.979 .021 .979 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.791 .209 .791 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.704 .296 .704 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.501 .499 .501 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.586 .414 .586 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.753 .247 .753 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.658 .342 .658 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.833 .167 .833 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.728 .272 .728 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.52 .48 .52 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.685 .315 .685 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.677 .323 .677 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.635 .365 .635 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.748 .252 .748 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.833 .167 .833 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.761 .239 .761 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.534 .466 .534 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.633 .367 .633 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.755 .245 .755 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.666 .334 .666 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.668 .332 .668 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.795 .205 .795 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.654 .346 .654 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.611 .389 .611 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.574 .426 .574 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.978 .022 .978 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.583 .417 .583 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.701 .299 .701 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.611 .389 .611 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.685 .315 .685 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.742 .258 .742 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.978 .022 .978 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.762 .238 .762 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.713 .287 .713 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.729 .271 .729 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.757 .243 .757 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.67 .33 .67 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.635 .365 .635 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.682 .318 .682 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.693 .307 .693 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.979 .021 .979 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.812 .188 .812 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.733 .267 .733 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.802 .198 .802 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.602 .398 .602 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.815 .185 .815 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.498 .502 .498 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.649 .351 .649 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.646 .354 .646 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.758 .242 .758 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.816 .184 .816 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.58 .42 .58 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.978 .022 .978 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.695 .305 .695 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.712 .288 .712 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.89 .11 .89 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.737 .263 .737 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.685 .315 .685 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.724 .276 .724 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.846 .154 .846 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.59 .41 .59 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.685 .315 .685 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.74 .26 .74 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.864 .136 .864 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.583 .417 .583 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.679 .321 .679 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.735 .265 .735 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.746 .254 .746 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.979 .021 .979 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.629 .371 .629 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.979 .021 .979 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.864 .136 .864 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.783 .217 .783 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.748 .252 .748 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.662 .338 .662 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.624 .376 .624 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.684 .316 .684 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.836 .164 .836 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.772 .228 .772 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.79 .21 .79 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.791 .209 .791 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.72 .28 .72 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.869 .131 .869 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.712 .288 .712 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.663 .337 .663 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.544 .456 .544 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.555 .445 .555 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.671 .329 .671 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.74 .26 .74 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.979 .021 .979 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.85 .15 .85 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.697 .303 .697 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.537 .463 .537 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.76 .24 .76 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.809 .191 .809 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.664 .336 .664 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.979 .021 .979 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.637 .363 .637 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.761 .239 .761 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.848 .152 .848 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.979 .021 .979 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.671 .329 .671 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.706 .294 .706 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.856 .144 .856 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.732 .268 .732 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.66 .34 .66 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.883 .117 .883 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.659 .341 .659 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.811 .189 .811 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.756 .244 .756 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.578 .422 .578 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.557 .443 .557 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.651 .349 .651 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.714 .286 .714 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.88 .12 .88 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.778 .222 .778 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.791 .209 .791 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.763 .237 .763 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.865 .135 .865 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.684 .316 .684 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.979 .021 .979 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.854 .146 .854 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.814 .186 .814 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.862 .138 .862 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.721 .279 .721 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.864 .136 .864 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.789 .211 .789 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.737 .263 .737 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.98 .02 .98 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.751 .249 .751 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.75 .25 .75 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.979 .021 .979 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.871 .129 .871 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.977 .023 .977 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.979 .021 .979 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.84 .16 .84 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.978 .022 .978 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.736 .264 .736 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.979 .021 .979 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.601 .399 .601 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.741 .259 .741 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.658 .342 .658 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.874 .126 .874 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.865 .135 .865 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.775 .225 .775 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.827 .173 .827 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.781 .219 .781 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.823 .177 .823 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.849 .151 .849 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.771 .229 .771 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.768 .232 .768 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.978 .022 .978 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.719 .281 .719 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.829 .171 .829 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.978 .022 .978 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.871 .129 .871 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.885 .115 .885 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.715 .285 .715 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.858 .142 .858 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.874 .126 .874 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.62 .38 .62 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.98 .02 .98 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.846 .154 .846 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.979 .021 .979 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.979 .021 .979 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.979 .021 .979 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.979 .021 .979 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.979 .021 .979 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ofBKIomTVfOl0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000omTVfOoI9]T00_oI9]T00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oI9]WofBKI00?ofBKI00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000omTVfOoI9]T01OoI9]T00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofBKIomTVf@06omTVf@03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oE:]Go0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cofBKI00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omDZe@03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ogB;MomdRg@05omdRg@03o`000?oI
9]WofBKI00_ofBKI0ol00003om/Tf`03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omDZeOoE:]D00ooE:]D00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003ogB;MomdRg@06
omdRg@03o`000?oI9]WofBKI00[ofBKI00?o0000om/TfooK9=/01?oK9=/00ol0003onPGjooX5nP0:
ooX5nP04o`000?oM8]gogB;MomdRg@;o00002_oj1OX2o`000003omdRgOl0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeB[EomDZe@05omDZe@03o`000?oj1O[o
nPGj00WonPGj00?o0000om0_d?l000002ooj1OX00ol0003ogB;MomdRg@06omdRg@03o`000?oI9]Wo
fBKI00WofBKI00?o0000om/TfooK9=/01_oK9=/00ol0003onPGjooX5nP08ooX5nP03o`000?oM8]go
gB;M00CogB;M0_l00005ooX5nP?o00001?oM8]d00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omDZe@03o`000?oj1O[onPGj00OonPGj0_l00003om0_
d003o`000?oj1O[onPGj00OonPGj00?o0000omdRgOoM8]d01ooM8]d00ol0003ofBKIomTVf@09omTV
f@03o`000?oK9=_ofbCK00OofbCK00?o0000ooX5n_oj1OX01Ooj1OX2o`0000WogB;M0_l000000ooj
1O[o0000o`000007omdRg@03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omDZeOoE
:]D02?oE:]D00ol0003onPGjooX5nP06ooX5nP03o`000?o@;m3od2o@00?od2o@00?o0000ooX5n_oj
1OX01ooj1OX00ol0003ogB;MomdRg@08omdRg@03o`000?oI9]WofBKI00OofBKI00?o0000om/TfooK
9=/02OoK9=/00ol0003onPGjooX5nP03ooX5nP03o`000?oM8]gogB;M00_ogB;M00?o0000omdRgOoM
8]d01ooM8]d00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHo`000005ooX5nP;o00002ooE:]D2o`0000KonPGj
00?o0000om0_d?o@;m001Oo@;m000ol0003onPGjooX5nP06ooX5nP03o`000?oM8]gogB;M00SogB;M
00?o0000omTVfOoI9]T01_oI9]T00ol0003ofbCKom/Tf`0;om/Tf`05o`000?oj1O[onPGjooX5n_l0
00003_oM8]d00ol0003ogB;MomdRg@08omdRg@03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oH9mSof2OHomPWf?l0
00000ooj1OX00ol0003oeB[EomDZe@0:omDZe@04o`000?oE:]GoeB[Eo`0000?onPGj0_l00008om0_
d003o`000?oj1O[onPGj00KonPGj00?o0000omdRgOoM8]d02OoM8]d00ol0003ofBKIomTVf@05omTV
f@03o`000?oK9=_ofbCK00cofbCK00?o0000ooX5n_l000003ooM8]d00ol0003ogB;MomdRg@08omdR
g@03o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPWf003omPWf003o`000?oj1O[o000000_o
eB[E0_l00004omDZe@03o`000?oj1O[o000000_od2o@00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gB;MomdRg@09omdRg@03o`000?oI9]WofBKI00CofBKI00?o0000om/TfooK9=/03_oK9=/00ol0003o
gB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00WogB;M00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omPWf?oH9mP0
1?oH9mP00ol0003oeB[EomDZe@09omDZe@03o`000?oE:]GoeB[E00GoeB[E00?o0000om0_d?o@;m00
2_o@;m000ol0003onPGjooX5nP05ooX5nP03o`000?oM8]gogB;M00[ogB;M00?o0000omTVfOoI9]T0
0ooI9]T00ol0003ofbCKom/Tf`0>om/Tf`03o`000?oM8]gogB;M00gogB;M00?o0000omdRgOoM8]d0
2_oM8]d00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPW
f005omPWf003o`000?oE:]GoeB[E00OoeB[E0_l00008omDZe@03o`000?o@;m3od2o@00_od2o@00?o
0000ooX5n_oj1OX01?oj1OX00ol0003ogB;MomdRg@0:omdRg@04o`000?oI9]WofBKIomTVf@?o0000
3ooK9=/00ol0003ogB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00[ogB;M00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oH9mSof2OH00Oof2OH00?o0000omDZeOoE:]D01?oE:]D2o`0000_oeB[E1?l0
0009om0_d003o`000?oj1O[onPGj00?onPGj00?o0000omdRgOoM8]d02ooM8]d01?l0003ofBKIo`00
0?l00003oll`c`;o00003?oK9=/2o`00013ogB;M00?o0000omdRgOoM8]d02ooM8]d00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003of2OH
omPWf007omPWf003o`000?oE:]GoeB[E00?oeB[E00?o0000omDZeOoE:]D02ooE:]D01?l0003occ3?
oll`coo?<<l5o`0000God2o@00?o0000ooX5n_oj1OX00_oj1OX00ol0003ogB;MomdRg@0<omdRg@03
o`000?o?<<oocc3?00Gocc3?0_l00008om/Tf`;o00000_o7><L00ol0003ogB;MomdRg@0=omdRg@03
o`000?oM8]gogB;M00_ogB;M00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003of2OHomPWf009omPWf003o`000?oE:]GoeB[E00;o0000
3OoE:]D00ol0003occ3?oll`c`07oll`c`Ko00000_oj1OX4o`0000gogB;M00?o0000oll`coo?<<l0
1oo?<<l2o`0000GofbCK00?o0000olLhaoo7><L00oo7><L00ol0003ogB;MomdRg@0<omdRg@03o`00
0?oM8]gogB;M00cogB;M00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oH9mSof2OH00Wof2OH00?o
0000omDZeOl000003ooE:]D00ol0003occ3?oll`c`0<oll`c`?o00001?oH9mP3o`0000WogB;M00?o
0000oll`coo?<<l02_o?<<l2o`000003om/Tfol0003o000000OoacS700?o0000omdRgOoM8]d02ooM
8]d00ol0003ogB;MomdRg@0<omdRg@03o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oj1O[onPGj00KonPGj00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oH9mSof2OH00_of2OH00?o0000
omDZeOoE:]D03_oE:]D00ol0003occ3?oll`c`0=oll`c`03o`000?oH9mSof2OH00Kof2OH0ol00005
omdRg@03o`000?o?<<oocc3?00gocc3?00?o0000olLhaoo7><L02?o7><L00ol0003ogB;MomdRg@09
omdRg@03o`000?oM8]gogB;M00gogB;M00Co0000ooX5n_oj1O[onPGj1Ol00003on8MhP03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
omPWf?oH9mP02ooH9mP2o`0000ooeB[E00?o0000oll`coo?<<l03Oo?<<l00ol0003of2OHomPWf00:
omPWf0?o000000?ogB;Mo`000?o?<<l03oo?<<l00ol0003oacS7olLha`09olLha`03o`000?oM8]go
gB;M00SogB;M00?o0000omdRgOoM8]d03_oM8]d3o`0000SohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oH9mSof2OH00Sof2OH0ol000000oo1
?/7o0000omDZe@0>omDZe@03o`000?o?<<oocc3?00gocc3?00?o0000omPWf?oH9mP03OoH9mP00ol0
003occ3?oll`c`0?oll`c`03o`000?o7><OoacS700[oacS72ol0000;omdRg@Go00003?oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02_oj1OX01Ol0003ogR7No`000?oj1O[o0000
00Sof2OH0ol00005ol4n`@03o`000?oE:]GoeB[E00coeB[E00?o0000oll`coo?<<l03Oo?<<l00ol0
003of2OHomPWf00=omPWf0;o00004?o?<<l00ol0003oacS7olLha`0:olLha`03o`000?o9=/WobCK9
00OobCK900?o0000omdRgOoM8]d00_oM8]d7o`0000CoaSW600?o0000on8Mh_oR7N802_oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX02Ooj1OX01?l0003ogR7NomhQg_oN8Mh2o`00
00Gof2OH0ol00009ol4n`@;o00002ooE:]D00ol0003occ3?oll`c`0=oll`c`03o`000?oH9mSof2OH
00gof2OH00Co0000omhQg_oN8Mko00003oo?<<l00ol0003oacS7olLha`09olLha`03o`000?o9=/Wo
bCK900WobCK91?l0000;olHiaP03o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5
nP03o`000?oj1O[onPGj00SonPGj00?o0000omhQg_oN8Mh01?oN8Mh00ol0003of2OHo`000002o`00
00co`Ck100Co0000olXeb_l0003o00002OoE:]D00ol0003occ3?oll`c`0=oll`c`03o`000?oH9mSo
f2OH00gof2OH00Go0000omhQg_oN8MkogR7No`00000=oll`c`03o`000?o7><OoacS700[oacS700?o
0000olTfbOo9=/T02Oo9=/T00ol0003oaSW6olHiaP0<olHiaP03o`000?oR7N;ohQgR00[ohQgR00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003o`Ck1ol4n`@0<ol4n`@03o`000?o:=L[obSG:00;obSG:0_l00007omDZe@03o`000?o?<<oo
cc3?00cocc3?00?o0000omPWf?oH9mP03OoH9mP00ol0003ogR7NomhQgP03omhQgP03o`000?o?<<oo
cc3?00[occ3?00?o0000olLhaoo7><L02_o7><L00ol0003obCK9olTfb@09olTfb@03o`000?o6>LKo
aSW600coaSW600?o0000on8Mh_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5
n_oj1OX01_oj1OX00ol0003ogR7NomhQgP06omhQgP03o`000?o1?/7o`Ck100_o`Ck100?o0000olXe
b_o:=LX01Oo:=LX00ol0003oeB[EomDZe@03omDZe@03o`000?o?<<oocc3?00gocc3?00?o0000omPW
f?oH9mP03OoH9mP00ol0003ogR7NomhQgP04omhQgP03o`000?o?<<oocc3?00Wocc3?00?o0000olLh
aoo7><L02Oo7><L00ol0003obCK9olTfb@0:olTfb@03o`000?o6>LKoaSW600coaSW600?o0000on8M
h_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oj1O[onPGj00_onPGj00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gR7NomhQgP07omhQgP03o`000?o1?/7o`Ck100_o`Ck100?o0000olXeb_o:=LX01_o:=LX2o`0000?o
eB[E00?o0000oll`coo?<<l03Oo?<<l00ol0003of2OHomPWf00<omPWf003o`000?oN8MkogR7N00Ko
gR7N00?o0000oll`coo?<<l02?o?<<l00ol0003oacS7olLha`09olLha`03o`000?o9=/WobCK900[o
bCK900?o0000olHia_o6>LH03?o6>LH00ol0003ohQgRon8MhP0;on8MhP03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooX5nP03o`00
0?oj1O[onPGj00ConPGj00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o`Ck1ol4n`@0:ol4n`@03o`00
0?o:=L[obSG:00WobSG:0_l000000ooE:]Go0000oll`c`0<oll`c`?o00003_oH9mP00ol0003ogR7N
omhQgP07omhQgP03o`000?o?<<oocc3?00Oocc3?00?o0000olLhaoo7><L02Oo7><L00ol0003obCK9
olTfb@0;olTfb@03o`000?o6>LKoaSW600coaSW600?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000omhQg_oN8Mh02_oN8Mh00ol0003o`Ck1ol4n
`@09ol4n`@03o`000?o:=L[obSG:00_obSG:00?o0000oll`coo?<<l02_o?<<l2o`0000?od2o@00?o
0000omPWf?oH9mP02_oH9mP00ol0003ogR7NomhQgP09omhQgP03o`000?o?<<oocc3?00Kocc3?00?o
0000olLhaoo7><L02?o7><L00ol0003obCK9olTfb@0<olTfb@03o`000?o6>LKoaSW600coaSW600?o
0000on8Mh_oR7N802_oR7N800ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ooj1OX0
0ol0003onPGjooX5nP02ooX5nP03o`000?oN8MkogR7N00_ogR7N00?o0000ol4n`Oo1?/402?o1?/40
0ol0003obSG:olXebP0<olXebP03o`000?o?<<oocc3?00Socc3?0_l00006om0_d0;o00002_oH9mP0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o?<<oocc3?00Gocc3?00?o0000olLhaoo7><L02?o7><L0
0ol0003obCK9olTfb@0<olTfb@03o`000?o6>LKoaSW600coaSW600?o0000on8Mh_oR7N802ooR7N80
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?onPGj00Go0000ooX5n_oj1O[onPGjo`00000=
omhQgP03o`000?o1?/7o`Ck100Oo`Ck100?o0000olXeb_o:=LX03_o:=LX00ol0003occ3?oll`c`04
oll`c`?o00002_o@;m000ol0003of2OHomPWf007omPWf003o`000?oN8MkogR7N00_ogR7N00?o0000
oll`coo?<<l00oo?<<l00ol0003oacS7olLha`09olLha`03o`000?o9=/WobCK900cobCK900?o0000
olHia_o6>LH03?o6>LH00ol0003ohQgRon8MhP0;on8MhP;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003ogR7NomhQgP0<omhQgP03o`000?o1?/7o`Ck100Oo`Ck100?o0000olXeb_o:=LX03oo:=LX01?l0
003occ3?oll`coo?<<l2o`0000kod2o@0_l00006omPWf003o`000?oN8MkogR7N00gogR7N00?o0000
oll`coo?<<l00_o?<<l00ol0003oacS7olLha`08olLha`03o`000?o9=/WobCK900cobCK90ol0000=
olHiaP03o`000?oR7N;ohQgR00_ohQgR00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00oogR7N00?o0000ol4n`Oo1?/401_o1?/400ol0003obSG:olXebP0@olXebPCo00004_o@;m000ol0
003of2OHomPWf003omPWf003o`000?oN8MkogR7N00kogR7N00Go0000oll`coo?<<oocc3?o`000005
olLha`Oo00003?o9=/T01Ol0003o_4>loka3_?nl@kco000000coaSW600?o0000on8Mh_oR7N802?oR
7N83o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000oogR7N00?o0000ol4n`Oo1?/401_o1?/400ol0003obSG:olXebP0=
olXebP?o000000Co`3o0o`000?l0003o00004oo@;m02o`0000;of2OH00?o0000omhQg_oN8Mh04?oN
8Mh00ol0003occ3?o`000006o`0000OogB;M00?o0000olTfbOo9=/T02?o9=/T00ol0003o_4>loka3
_003oka3_0;o00002?o6>LH3o`0000KohQgR1?l00002omlPg`03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003odBkAo`000?o5>/D3o`0000gogR7N00?o0000ol4n`Oo1?/401?o1?/400ol0003obSG:olXe
bP0;olXebP?o00000oo0?l001Ol0003o`Ck1o`000?o3?<?o000001Cod2o@00?o0000omPWf?l00000
4ooN8Mh00ol0003ogB;MomdRg@0=omdRg@03o`000?o9=/WobCK900GobCK90_l00008oka3_003o`00
0?o6>LKoaSW600Go00000oo7><L00ol0003ohQgRon8MhP03o`0000Oogb3O00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oA;]7odBkAo`0000CoaC[50ol0000:omhQgP03o`000?o1?/7o`Ck100?o`Ck1
00?o0000olXeb_o:=LX02Oo:=LX3o`0000Go`3o000Co0000ol4n`Oo1?/7o00000_o3?<<00ol0003o
d2o@om0_d00Bom0_d003o`000?oN8MkogR7N01;ogR7N00?o0000omdRgOoM8]d03_oM8]d00ol0003o
bCK9olTfb@03olTfb@03o`000?nl@kco_4>l00Wo_4>l0_l00009olLha`;o00002_oO8=l00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000om4^dOoA;]7odBkAo`000007olDja@;o00001ooN8Mh5o`0000;o
`Ck100?o0000olXeb_o:=LX01_o:=LX3o`0000So`3o000Co0000ol4n`Oo1?/7o00000oo3?<<00ol0
003od2o@om0_d00Aom0_d003o`000?oN8MkogR7N017ogR7N00?o0000omdRgOoM8]d04?oM8]d01Ol0
003obCK9olTfbOo9=/Wo000000co_4>l00?o0000olLhaoo7><L02?o7><L00ol0003ogb3OomlPg`0:
omlPg`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CodBkA00?o0000olDjaOo5>/D01oo5>/D3o`00
0004omhQg_l0003o0000o`0000Gob3O80_l00006olXebP?o00002_o0?l001Ol0003o`Ck1ol4n`Oo1
?/7o000000Co`cc300?o0000om0_d?o@;m004?o@;m000ol0003ogR7NomhQgP0AomhQgP03o`000?oM
8]gogB;M017ogB;M00?o0000olTfbOl000003Onl@k`00ol0003oacS7olLha`08olLha`03o`000?oO
8=oogb3O00[ogb3O00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oA;]7odBkA00CodBkA00?o0000
olDjaOo5>/D02_o5>/D00ol0003ob3O8olPgb008olPgb003o`000?o:=L[obSG:00?o00003Oo0?l00
1Ol0003o`Ck1ol4n`Oo1?/7o000000Go`cc300?o0000om0_d?o@;m003oo@;m000ol0003ogR7NomhQ
gP0AomhQgP03o`000?oM8]gogB;M01;ogB;M00?o0000oka3_?nl@k`03?nl@k`00ol0003oacS7olLh
a`08olLha`03o`000?oO8=oogb3O00_ogb3O00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000om4^dOoA;]401OoA;]40
0ol0003oaC[5olDja@0:olDja@03o`000?o8=lSob3O800Wob3O80_l0000?ol0o`003o`000?o1?/7o
`Ck100;o`Ck100?o0000ol<l`oo3?<<01?o3?<<00ol0003od2o@om0_d00=om0_d0?o00004OoN8Mh0
0ol0003ogB;MomdRg@0ComdRg@03o`000?nl@kco_4>l00_o_4>l00?o0000olLhaoo7><L02Oo7><L0
0ol0003ogb3OomlPg`0;omlPg`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oA;]40
0ol0003oaC[5olDja@0:olDja@03o`000?o8=lSob3O800Wob3O800?o0000ol0o`?o0?l003Oo0?l00
0ol0003o`Ck1ol4n`@03ol4n`@03o`000?o3?<?o`cc300Go`cc300?o0000om0_d?o@;m002_o@;m02
o`0000?ogB;M00?o0000omhQg_oN8Mh03_oN8Mh00ol0003ogB;MomdRg@0ComdRg@03o`000?nl@kco
_4>l00_o_4>l00?o0000olLhaoo7><L02Oo7><L00ol0003ogb3OomlPg`0;omlPg`03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000om4^dOoA;]401ooA;]42o`0000_oaC[500?o0000olPg
b?o8=lP02oo8=lP00ol0003o`3o0ol0o`00<ol0o`003o`000?o1?/7o`Ck100?o`Ck100?o0000ol<l
`oo3?<<01_o3?<<00ol0003od2o@om0_d007om0_d0;o00001_oM8]d2o`0000kogR7N00?o0000omdR
gOoM8]d04ooM8]d00ol0003o_4>loka3_00;oka3_003o`000?o7><OoacS700WoacS700?o0000omlP
gooO8=l03?oO8=l00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009om4^
d@03o`000?n6NHKo000000_oaC[500?o0000olPgb?o8=lP02oo8=lP00ol0003o`3o0ol0o`00;ol0o
`003o`000?o1?/7o`Ck100Co`Ck100?o0000ol<l`oo3?<<01oo3?<<00ol0003od2o@om0_d005om0_
d003o`000?oM8]gogB;M00SogB;M00?o0000omhQg_oN8Mh02_oN8Mh00ol0003ogB;MomdRg@0DomdR
g@03o`000?nl@kco_4>l00_o_4>l00?o0000olLhaoo7><L02Oo7><L00ol0003ogb3OomlPg`0<omlP
g`03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009om4^d@04o`000?n6NHKoQWV6o`00
00_oaC[500?o0000olPgb?o8=lP02oo8=lP00ol0003o`3o0ol0o`00;ol0o`003o`000?o1?/7o`Ck1
00Co`Ck100?o0000ol<l`oo3?<<02?o3?<<00ol0003od2o@om0_d002om0_d0;o00003?oM8]d2o`00
00[ogR7N00?o0000omdRgOoM8]d05?oM8]d00ol0003o_4>loka3_00;oka3_003o`000?o7><OoacS7
00WoacS700?o0000omlPgooO8=l03OoO8=l00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003odBkAom4^d@07om4^d@03
o`000?n6NHKoQWV600;oQWV600?o0000olDjaOo5>/D02?o5>/D00ol0003ob3O8olPgb00<olPgb003
o`000?o0?l3o`3o000Wo`3o000?o0000ol4n`Oo1?/401Oo1?/400ol0003o`cc3ol<l``09ol<l``04
o`000?o@;m3o0000o`00013ogB;M0_l00008omhQgP03o`000?oM8]gogB;M01CogB;M0ol0000;oka3
_003o`000?o7><OoacS700WoacS700?o0000omlPgooO8=l03OoO8=l01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003odBkAom4^d@06om4^d@03o`000?n6NHKoQWV600?oQWV600?o0000olDj
aOo5>/D02?o5>/D00ol0003ob3O8olPgb00;olPgb0;o00002_o0?l000ol0003o`Ck1ol4n`@06ol4n
`@03o`000?o3?<?o`cc300[o`cc300?o0000omdRgOoM8]d04_oM8]d00ol0003ogR7NomhQgP04omhQ
gP03o`000?oM8]gogB;M01GogB;M00?o0000omLXeooG:=L01Ol00005oka3_003o`000?o7><OoacS7
00[oacS700?o0000omlPgooO8=l03_oO8=l3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkAom4^d@04om4^d@03
o`000?n6NHKoQWV600CoQWV600?o0000olDjaOo5>/D01oo5>/D00ol0003ob3O8olPgb00;olPgb004
o`000?o:=L[obSG:o`0000Wo`3o000?o0000ol4n`Oo1?/401_o1?/400ol0003o`cc3ol<l``0:ol<l
``03o`000?oM8]gogB;M01?ogB;M0_l00003omhQgPCo00005?oM8]d00ol0003oebSGomLXe`06omLX
e`Co000000?o_4>lo`000?o7><L02oo7><L00ol0003ogb3OomlPg`0>omlPg`03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003odBkAom4^d@03om4^d@03o`000?n6NHKoQWV600GoQWV600?o0000olDjaOo5
>/D01oo5>/D00ol0003ob3O8olPgb009olPgb0;o00001?o:=LX00ol0003o`3o0ol0o`005ol0o`003
o`000?o1?/7o`Ck100Oo`Ck100?o0000ol<l`oo3?<<02_o3?<<00ol0003ogB;MomdRg@0EomdRg@03
o`000?oN8Mko000000CohQgR0ol0000@omdRg@03o`000?oG:=OoebSG00_oebSG0_l0000<olLha`03
o`000?oO8=oogb3O00cogb3O0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]400_oA;]400ol0003oQWV6
ohIiQP06ohIiQP03o`000?o5>/GoaC[500OoaC[500?o0000olPgb?o8=lP02?o8=lP00ol0003obSG:
olXebP05olXebP03o`000?o0?l3o`3o000Co`3o000?o0000ol4n`Oo1?/401oo1?/400ol0003o`cc3
ol<l``0:ol<l``03o`000?oM8]gogB;M01KogB;M00?o0000on8Mh_oR7N801_oR7N83o`0000cogB;M
00?o0000omLXeooG:=L03OoG:=L00ol0003oacS7olLha`09olLha`Go00002OoO8=l2o`000003omPW
f?l0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003om4^dOl0003oQWV600WoQWV600?o0000olDjaOo5>/D01_o5
>/D00ol0003ob3O8olPgb007olPgb003o`000?o:=L[obSG:00OobSG:00?o0000ol0o`?o0?l000_o0
?l000ol0003o`Ck1ol4n`@08ol4n`@03o`000?o3?<?o`cc300Wo`cc300?o0000omdRgOoM8]d05ooM
8]d00ol0003ohQgRon8MhP09on8MhP?o00002OoM8]d00ol0003oebSGomLXe`0>omLXe`Ko00001?o7
><L00ol0003o]dRgokM8]`03okM8]`Go00000_oO8=l2o`0000Cof2OH00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o6>LKoaSW6olHia_l000002on6NHH00ol0003oaC[5olDja@06olDja@03o`000?o8
=lSob3O800Gob3O80_l0000;olXebP04o`000?o0?l3o`3o0o`0000_o`Ck100?o0000ol<l`oo3?<<0
2Oo3?<<00ol0003ogB;MomdRg@0FomdRg@03o`000?oR7N;ohQgR00gohQgR0ol00005omdRg@03o`00
0?oG:=OoebSG00ooebSG00?o0000om</dooC;=<00ooC;=<4o`0000_o]dRg0_l00006omPWf003o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oaSW6olHiaP02olHiaPko00001_o5>/D00ol0003ob3O8olPg
b005olPgb003o`000?o:=L[obSG:00cobSG:00?o0000ol0o`?l000002oo1?/400ol0003o`cc3ol<l
``07ol<l``?o00006?oM8]d00ol0003ohQgRon8MhP0@on8MhP?o000000?ogB;Mo`000?oG:=L04?oG
:=L00ol0003odbcCom</d`07om</d`03o`000?ngB;Oo]dRg00[o]dRg00?o0000omPWf?oH9mP01OoH
9mP00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olHiaP03o`000?nMHYgoWF:M00_oWF:M0_l00004
olDja@03o`000?o8=lSob3O800?ob3O80_l0000@olXebP03o`000?o1?/7o`Ck100[o`Ck100?o0000
ol<l`oo3?<<00oo3?<<4o`0000;o^dBk00?o0000omdRgOoM8]d05OoM8]d00ol0003ohQgRon8MhP0D
on8MhP03o`000?oG:=OoebSG013oebSG00?o0000om</dooC;=<01ooC;=<00ol0003o]dRgokM8]`0:
okM8]`03o`000?oH9mSof2OH00Gof2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o6>LKoaSW6
00GoaSW600?o0000oieRWOnMHYd03OnMHYd6o`0000?ob3O800?o0000olXeb_o:=LX04?o:=LX00ol0
003o`Ck1ol4n`@0:ol4n`@03o`000?o3?<?o000000?o00001onkA;/00ol0003ogB;MomdRg@0DomdR
g@03o`000?oR7N;ohQgR01CohQgR00?o0000omLXeooG:=L03ooG:=L00ol0003odbcCom</d`08om</
d`03o`000?ngB;Oo]dRg00[o]dRg00?o0000omPWf?oH9mP01OoH9mP00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olHia_o6>LH01_o6>LH00ol0003oWF:MoieRW@0=oieRW@03o`000?o?<<oocc3?00?o
cc3?00?o0000olPgb?l000004oo:=LX4o`0000Wo`Ck10_l0000<ok]4^`03o`000?oM8]gogB;M01?o
gB;M00?o0000on8Mh_oR7N805OoR7N800ol0003oebSGomLXe`0>omLXe`03o`000?oC;=?odbcC00So
dbcC00?o0000okM8]ongB;L02OngB;L00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o6>LKoaSW600SoaSW600?o0000oieRWOnMHYd02onMHYd00ol0003occ3?oll`c`05oll`c`03o`00
0?o:=L[obSG:01;obSG:00Co0000ol8m`_o2?L;o`Sg21Ol00003ol4n`@03o`000?nkA;_o^dBk00go
^dBk0ol0000@omdRg@;o00006?oR7N800ol0003oebSGomLXe`0=omLXe`03o`000?oC;=?odbcC00Wo
dbcC00?o0000okM8]ongB;L02OngB;L00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_oaSW600?o0000oieRWOnMHYd02_nMHYd00ol0003occ3?oll`c`06oll`c`03o`00
0?o:=L[obSG:017obSG:00?o0000ol8m`_o2?L801oo2?L83o`00013o^dBk00?o0000okU6^OniA[T0
1Ol00009omdRg@;o000000?oaC[5o`000?oR7N805ooR7N800ol0003oebSGomLXe`0=omLXe`03o`00
0?oC;=?odbcC00WodbcC00?o0000okM8]ongB;L02?ngB;L2o`0000[of2OH00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oE:]GoeB[E00;oeB[E00?o0000olHia_o6>LH02Oo6>LH00ol0003oWF:MoieR
W@0:oieRW@03o`000?o?<<oocc3?00Oocc3?00?o0000olXeb_o:=LX03oo:=LX00ol0003o`Sg2ol8m
`P0:ol8m`P03o`000?nkA;_o^dBk00go^dBk00?o0000okU6^OniA[T01_niA[T4o`0000CogB;M00?o
0000olDjaOo5>/D00_o5>/D00ol0003ohQgRon8MhP0Fon8MhP03o`000?oG:=OoebSG00_oebSG00?o
0000om</dooC;=<02ooC;=<00ol0003o]dRgokM8]`06okM8]`03o`000?nNHIko000000[of2OH00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000olHia_o6>LH02?o6>LH=
o`0000[occ3?00?o0000olXeb_o:=LX03oo:=LX00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?nkA;_o
^dBk00co^dBk00?o0000okU6^OniA[T02_niA[T4o`0000GoaC[500?o0000on8Mh_oR7N805_oR7N80
0ol0003oebSGomLXe`0:omLXe`03o`000?oC;=?odbcC00codbcC00?o0000okM8]ongB;L01?ngB;L2
o`0000?oWV6N00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omDZ
eOoE:]D00ooE:]D00ol0003oaSW6olHiaP07olHiaP03o`000?nLHicoW6>L00WoW6>L00?o0000oll`
coo?<<l02Oo?<<l00ol0003obSG:olXebP0=olXebP03o`000?o2?L;o`Sg200co`Sg200?o0000ok]4
^onkA;/03?nkA;/00ol0003o^DJiokU6^@0;okU6^@03o`000?nYEZWo000000KoaC[500?o0000on8M
h_oR7N805_oR7N800ol0003oebSGomLXe`09omLXe`03o`000?oC;=?odbcC00codbcC00?o0000okM8
]ongB;L00ongB;L00ol0003oWV6NoiiQWP03oiiQWP03o`000?oH9mSof2OH00Sof2OH00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00CoeB[E00?o0000olHia_o6>LH01_o6>LH00ol0003o
W6>LoiaSW008oiaSW003o`000?o?<<oocc3?00_occ3?00?o0000olXeb_o:=LX02?o:=LX4o`0000oo
`Sg200?o0000ok]4^onkA;/02onkA;/00ol0003o^DJiokU6^@0;okU6^@04o`000?nYEZWoZEJYo`00
00OoaC[500?o0000on8Mh_oR7N805OoR7N800ol0003oebSGomLXe`08omLXe`03o`000?oC;=?odbcC
00godbcC00?o0000okM8]ongB;L00_ngB;L00ol0003oWV6NoiiQWP05oiiQWP03o`000?oH9mSof2OH
00Oof2OH00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00GoeB[E00?o0000olHia_o6
>LH01Oo6>LH00ol0003oW6>LoiaSW008oiaSW003o`000?o?<<oocc3?00_occ3?00?o0000olXeb_o:
=LX00oo:=LX5o`0000?o`cc300?o0000ol8m`_o2?L803_o2?L800ol0003o^dBkok]4^`0:ok]4^`03
o`000?niA[Wo^DJi00[o^DJi00Go0000ojUFZOnYEZWoZEJYo`000007olDja@03o`000?oR7N;ohQgR
01GohQgR00?o0000omLXeooG:=L02?oG:=L00ol0003odbcCom</d`0=om</d`03o`000?ngB;Oo]dRg
00;o00002?nNHIh00ol0003of2OHomPWf008omPWf0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oeB[EomDZe@05omDZe@03o`000?o6>LKoaSW600Go
aSW600?o0000oiaSW?nLHi`02?nLHi`00ol0003occ3?oll`c`0<oll`c`Go00002Oo3?<<00ol0003o
`Sg2ol8m`P0<ol8m`P;o00003?nkA;/00ol0003o^DJiokU6^@0:okU6^@05o`000?nYEZWoZEJYojUF
ZOl000002?o5>/D00ol0003ohQgRon8MhP0Don8MhP?o00001ooG:=L00ol0003odbcCom</d`0>om</
d`03o`000?ngB;Oo000000_oWV6N00?o0000omPWf?oH9mP01_oH9mP00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000omDZeOoE:]D01OoE:]D00ol0003oaSW6olHiaP04olHiaP03o`000?nLHicoW6>L00Oo
W6>L00?o0000oll`coo?<<l03?o?<<l01?l0003obSG:olXeb_l0000;ol<l``03o`000?o2?L;o`Sg2
00_o`Sg200Co0000ojMHYonWF:Oo00002_nkA;/00ol0003o^DJiokU6^@0:okU6^@03o`000?nYEZWo
ZEJY00;oZEJY00?o0000olDjaOo5>/D01_o5>/D00ol0003ohQgRon8MhP0Aon8MhP?o00000oo:=LX0
0ol0003oebSGomLXe`04omLXe`03o`000?oC;=?odbcC00godbcC1?l0000;oiiQWP03o`000?oH9mSo
f2OH00Gof2OH00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oE:]GoeB[E00KoeB[E00Co0000olHi
a_o6>LKoaSW61?l00008oiaSW003o`000?o?<<oocc3?00_occ3?00?o0000olXeb_o:=LX00_o:=LX0
0ol0003o`cc3ol<l``08ol<l``03o`000?o2?L;o`Sg200[o`Sg200?o0000ojMHYonWF:L00_nWF:L0
0ol0003o^dBkok]4^`03ok]4^`Go00002oniA[T00ol0003oZEJYojUFZ@03ojUFZ@03o`000?o5>/Go
aC[500OoaC[500?o0000on8Mh_oR7N803_oR7N82o`0000OobSG:00?o0000omLXeooG:=L00_oG:=L0
0ol0003odbcCom</d`0=om</d`03o`000?nhAkSo^4Nh00;o^4Nh00?o0000oiiQW_nNHIh02OnNHIh0
0ol0003of2OHomPWf003omPWf003o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oeB[EomDZe@07omDZ
e@?o00001?o5>/D00ol0003oW6>LoiaSW005oiaSW003o`000?o?<<oocc3?00[occ3?00?o0000olXe
b_o:=LX00oo:=LX00ol0003o`cc3ol<l``09ol<l``03o`000?o2?L;o`Sg200So`Sg200?o0000ojMH
YonWF:L01?nWF:L5o`0000CoOh1o00?o0000okU6^OniA[T02OniA[T00ol0003oZEJYojUFZ@03ojUF
Z@03o`000?o5>/GoaC[500SoaC[500?o0000on8Mh_oR7N802_oR7N83o`0000[obSG:00Go0000omLX
eooG:=OoebSGo`00000>om</d`03o`000?nhAkSo^4Nh00Co^4Nh0_l00009oiiQWP03o`000?oH9mSo
f2OH00;of2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oE:]GoeB[E00OoeB[E00?o0000olDj
aOo5>/D01Oo5>/D00ol0003oW6>LoiaSW003oiaSW003o`000?o?<<oocc3?00[occ3?00?o0000olXe
b_o:=LX01?o:=LX00ol0003o`cc3ol<l``09ol<l``03o`000?o2?L;o`Sg200Oo`Sg200?o0000ojMH
YonWF:L01OnWF:L00ol0003oOh1oogn0O`07ogn0O`03o`000?niA[Wo^DJi00Oo^DJi00?o0000ojUF
ZOnYEZT01?nYEZT00ol0003oaC[5olDja@08olDja@03o`000?oR7N;ohQgR00SohQgR0_l0000>olXe
bPCo00003?oC;=<2o`0000Wo^4Nh00?o0000oiiQW_nNHIh01onNHIh01?l0003of2OHomPWf?l0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000omDZeOoE:]D01OoE:]D00ol0003oaC[5olDja@07olDja@;o00000onLHi`00ol0
003occ3?oll`c`09oll`c`03o`000?o:=L[obSG:00KobSG:00?o0000ol<l`oo3?<<02Oo3?<<00ol0
003o`Sg2ol8m`P05ol8m`P03o`000?nWF:OoYeRW00KoYeRW00?o0000ogn0OomoP7l02?moP7l00ol0
003o^DJiokU6^@06okU6^@03o`000?nYEZWoZEJY00CoZEJY00?o0000olDjaOo5>/D02Oo5>/D4o`00
00?ohQgR0ol0000@olXebP05o`000?oN8MkogR7NomhQg_l000002_oC;=<00ol0003o^4NhokQ7^00:
okQ7^0Ko00000onNHIh00ol0003of2OHo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000omDZeOoE:]D01?oE:]D00ol0
003oaC[5olDja@0:olDja@04o`000?nLHicoW6>Lo`0000[occ3?00?o0000olXeb_o:=LX01oo:=LX0
0ol0003o`cc3ol<l``09ol<l``03o`000?o2?L;o`Sg200Co`Sg200?o0000ojMHYonWF:L01onWF:L0
0ol0003oOh1oogn0O`08ogn0O`;o00001_niA[T00ol0003oZEJYojUFZ@05ojUFZ@03o`000?o5>/Go
aC[500WoaC[500Co0000ok]4^onkA;_o^dBk0ol0000BolXebP03o`000?oN8MkogR7N00?ogR7N0_l0
0006om</d`;o00003OnhAkP00ol0003ofbCKom/Tf`03om/Tf`Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000omDZeOoE:]D00ooE:]D0
0ol0003oaC[5olDja@0<olDja@;o00002_o?<<l00ol0003obSG:olXebP08olXebP03o`000?o3?<?o
`cc300[o`cc300?o0000ol8m`_o2?L800_o2?L800ol0003oYeRWojMHY`08ojMHY`03o`000?moP7oo
Oh1o00KoOh1o0_l00002ojEJY@03o`000?niA[Wo^DJi00;o^DJi00?o0000ojUFZOnYEZT01_nYEZT0
0ol0003oaC[5olDja@08olDja@03o`000?nkA;_o^dBk00Co^dBk00?o0000olXeb_o:=LX03oo:=LX0
0ol0003ogR7NomhQgP06omhQgP;o00000ooC;=<00ol0003o^4NhokQ7^00=okQ7^003o`000?oK9=_o
fbCK00OofbCK0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003oeB[EomDZe@02omDZe@03o`000?o5>/GoaC[5
00koaC[500?o0000oll`coo?<<l01oo?<<l00ol0003obSG:olXebP0:olXebP03o`000?o3?<?o`cc3
00Wo`cc300Go0000ol8m`_o2?L;o`Sg2o`00000;ojMHY`03o`000?moP7ooOh1o00CoOh1o0_l00005
ojEJY@05o`000?niA[Wo^DJiokU6^Ol000002?nYEZT00ol0003oaC[5olDja@08olDja@03o`000?nk
A;_o^dBk00Go^dBk00?o0000olXeb_o:=LX03_o:=LX00ol0003ogR7NomhQgP08omhQgP03o`000?oC
;=?o000000oo^4Nh00?o0000om/TfooK9=/02?oK9=/01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oE:]GoeB[Eo`00017oaC[500?o0000oll`coo?<<l01_o?<<l00ol0003obSG:
olXebP0;olXebP03o`000?o3?<?o`cc300Wo`cc300Co0000ol8m`_o2?L;o00003?nWF:L00ol0003o
Oh1oogn0O`02ogn0O`;o00002?nUFZD00ol0003o^DJio`000009ojUFZ@03o`000?o5>/GoaC[500So
aC[500?o0000ok]4^onkA;/01OnkA;/00ol0003obSG:olXebP0=olXebP03o`000?oN8MkogR7N00[o
gR7N00?o0000okQ7^?nhAkP03_nhAkP00ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000BolDja@03o`00
0?o?<<oocc3?00Cocc3?00?o0000olXeb_o:=LX03?o:=LX00ol0003o`cc3ol<l``0:ol<l``?o0000
3?nWF:L00ol0003oOh1oogn0O`02o`0000_oYEZU00?o0000ojUFZOnYEZT02?nYEZT00ol0003oaC[5
olDja@07olDja@03o`000?nkA;_o^dBk00Oo^dBk00?o0000olXeb_o:=LX03?o:=LX00ol0003ogR7N
omhQgP0;omhQgP;o00003_nhAkP00ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N800ooR7N800ol0003oaC[5olDja@0?olDja@?o00000oo?
<<l00ol0003obSG:olXebP0>olXebP03o`000?o3?<?o`cc300So`cc300Co0000ojeB[On]DZgo[E:]
0_l0000:ojMHY`?o00003OnUFZD00ol0003oZEJYojUFZ@08ojUFZ@03o`000?o5>/GoaC[500OoaC[5
00?o0000ok]4^onkA;/01onkA;/00ol0003obSG:olXebP0;olXebP03o`000?oN8MkogR7N00cogR7N
00?o0000ol@ka?l000000_l0000:okQ7^003o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP04on8MhP03o`000?o5>/GoaC[500coaC[50_l0
0003ol4n`@03o`000?o?<<oo0000017obSG:00?o0000ol<l`oo3?<<01oo3?<<00ol0003o[E:]ojeB
[@04ojeB[@;o00002?nWF:L00ol0003oYEZUojEJY@0>ojEJY@;o00002?nYEZT00ol0003oaC[5olDj
a@06olDja@03o`000?nkA;_o^dBk00Wo^dBk00?o0000olXeb_o:=LX02Oo:=LX00ol0003ogR7NomhQ
gP0=omhQgP03o`000?o4>lCoa3_400;oa3_40ol00007okQ7^003o`000?oK9=_ofbCK00OofbCK00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?o5>/Go
aC[500WoaC[50_l00006ol4n`@03o`000?o:=L[obSG:013obSG:00?o0000ol<l`oo3?<<01_o3?<<0
0ol0003o[E:]ojeB[@07ojeB[@03o`000?nWF:OoYeRW00CoYeRW0ol0000>ojEJY@03o`000?nEJYGo
UFZE00?o00001OnYEZT00ol0003oaC[5olDja@06olDja@03o`000?nkA;_o^dBk00[o^dBk00?o0000
olXeb_o:=LX02?o:=LX00ol0003ogR7NomhQgP0=omhQgP03o`000?o4>lCoa3_400Goa3_40ol00004
okQ7^003o`000?oK9=_ofbCK00OofbCK00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ohQgRon8MhP06on8MhP03o`000?o5>/GoaC[500GoaC[50ol00008ol4n`@03o`000?o:=L[obSG:
017obSG:00Co0000ol<l`oo3?<?o`cc31?l0000;ojeB[@;o000000CoYeRWo`000?l0003o00000onf
BKH2o`0000_oYEZU00?o0000oiEZUOnEJYD01?nEJYD2o`0000?oZEJY00?o0000olDjaOo5>/D01_o5
>/D00ol0003o^dBkok]4^`0:ok]4^`03o`000?o:=L[obSG:00OobSG:00?o0000omhQg_oN8Mh03_oN
8Mh00ol0003oa3_4ol@ka008ol@ka0Co00002_oK9=/00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003ohQgRon8MhP07on8MhP03o`000?o5>/GoaC[500;oaC[50_l0000<ol4n`@03o`000?o:=L[o
bSG:013obSG:1?l00003ok]4^`03o`000?n]DZgo[E:]00_o[E:]00?o0000okI9]_nfBKH01_nfBKH0
0ol0003oYEZUojEJY@07ojEJY@03o`000?nEJYGoUFZE00OoUFZE3?l0000>ok]4^`03o`000?o:=L[o
bSG:00KobSG:00?o0000omhQg_oN8Mh03_oN8Mh00ol0003oa3_4ol@ka00;ol@ka003o`000?oK9=_o
fbCK00OofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00WohQgR00Co0000olDj
aOl0003o00003_o1?/400ol0003obSG:olXebP0?olXebP03o`000?nkA;_o^dBk00Ko^dBk00?o0000
ojeB[On]DZd02_n]DZd00ol0003o]TVfokI9]P07okI9]P;o00001_nUFZD00ol0003oUFZEoiEZU@08
oiEZU@03o`000?o:=L[obSG:00SobSG:00?o0000ok]4^onkA;/03?nkA;/00ol0003obSG:olXebP05
olXebP03o`000?oN8MkogR7N00oogR7N0_l0000=ol@ka003o`000?oK9=_ofbCK00KofbCK00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00[ohQgR00?o0000ol4n`Oo1?/403_o1?/400ol0
003obSG:olXebP0>olXebP03o`000?nkA;_o^dBk00Oo^dBk00?o0000ojeB[On]DZd02_n]DZd00ol0
003o]TVfokI9]P09okI9]P;o00000onUFZD00ol0003oUFZEoiEZU@09oiEZU@03o`000?o:=L[obSG:
00WobSG:00?o0000ok]4^onkA;/02_nkA;/4o`0000CobSG:00?o0000omhQg_oN8Mh04?oN8Mh01?l0
003oaC[5o`000?l0000<ol@ka003o`000?oK9=_ofbCK00GofbCK00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?oR7N;ohQgR00[ohQgR00?o0000ol4n`Oo1?/403oo1?/4@o`0000[o^dBk00?o0000ojeB
[On]DZd02On]DZd00ol0003oW6>Lo`00000<okI9]P05o`000?nUFZGo0000oiMXUol000002_nEJYD0
0ol0003obSG:olXebP09olXebP03o`000?nkA;_o^dBk00Oo^dBk0ol00004oll`c`?o000000?obSG:
o`000?oN8Mh04OoN8Mh01?l0003oaC[5olDjaOo5>/D2o`0000_oa3_400?o0000om/TfooK9=/00ooK
9=/00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000on8Mh_oR7N802_oR7N800ol0003o`Ck1ol4n`@0?
ol4n`@03o`000?o><LkocS7>00cocS7>00?o0000ok]4^onkA;/02OnkA;/00ol0003o[E:]ojeB[@07
ojeB[@04o`000?nLHicoW6>Lo`0000go]TVf00Go0000oiMXUonGJ9OoUfRGo`000009oiEZU@03o`00
0?o:=L[obSG:00[obSG:00?o0000ok]4^onkA;/00onkA;/3o`0000[occ3?00?o0000omhQg_oN8Mh0
4?oN8Mh00ol0003oaC[5olDja@04olDja@;o00002_o4>l@00ol0003ofbCKom/Tf`04o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000cohQgR00?o0000ol4n`Oo1?/403oo1?/400ol0003ocS7>olhacP0<olhacP03o`000?nk
A;_o^dBk00Wo^dBk00?o0000ojeB[On]DZd01_n]DZd00ol0003oW6>LoiaSW002oiaSW003o`000?nf
BKKo]TVf00[o]TVf00?o0000oiMXUonGJ9L00_nGJ9L00ol0003oUFZEoiEZU@06oiEZU@03o`000?o:
=L[obSG:00[obSG:00?o0000ok]4^onkA;/00ol0000=oll`c`03o`000?oN8MkogR7N013ogR7N00?o
0000olDjaOo5>/D01_o5>/D2o`0000Woa3_40_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000on8Mh_oR7N802_oR7N800ol0003o`Ck1ol4n`@0=ol4n`@?o00003oo><Lh0
0ol0003o^dBkok]4^`08ok]4^`03o`000?n]DZgo[E:]00Go[E:]00?o0000oiaSW?nLHi`00onLHi`0
0ol0003o]TVfokI9]P0:okI9]P03o`000?nGJ9OoUfRG00?oUfRG00?o0000oiEZUOnEJYD01OnEJYD0
0ol0003obSG:olXebP0;olXebP;o00004Oo?<<l00ol0003ogR7NomhQgP0?omhQgP03o`000?o5>/Go
aC[500SoaC[50_l00007ol@ka003o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000on8Mh_oR7N802?oR7N800ol0003o`Ck1ol4n`@09ol4n`@Go00000_nfBKH00ol0
003ocS7>olhacP0=olhacP03o`000?nkA;_o^dBk00Wo^dBk00?o0000ojeB[On]DZd01?n]DZd00ol0
003oW6>LoiaSW004oiaSW003o`000?nfBKKo]TVf00So]TVf00?o0000oiMXUonGJ9L01OnGJ9L00ol0
003oUFZEoiEZU@04oiEZU@03o`000?o:=L[obSG:00_obSG:00?o0000oll`coo?<<l04?o?<<l00ol0
003ogR7NomhQgP0?omhQgP03o`000?o5>/GoaC[500[oaC[50_l00004ol@ka003o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003ohQgRon8MhP07on8MhP03o`000?o1?/7o`Ck100Co`Ck11Ol00007okI9]P03
o`000?o><LkocS7>00gocS7>00?o0000ok]4^onkA;/02OnkA;/00ol0003o[E:]ojeB[@03ojeB[@03
o`000?nLHicoW6>L00GoW6>L00?o0000okI9]_nfBKH02?nfBKH00ol0003oUfRGoiMXU`06oiMXU`03
o`000?nEJYGoUFZE00?oUFZE00?o0000olXeb_o:=LX02oo:=LX00ol0003occ3?oll`c`0@oll`c`03
o`000?oN8MkogR7N00oogR7N00?o0000olDjaOo5>/D03?o5>/D2o`000003ol@ka?l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oR7N;ohQgR00OohQgR00?o0000ol4n`Ol00000
1?l0000<okI9]P03o`000?o><LkocS7>00kocS7>00?o0000ok]4^onkA;/02?nkA;/00ol0003o[E:]
ojeB[@02ojeB[@03o`000?nLHicoW6>L00OoW6>L00?o0000okI9]_nfBKH01onfBKH00ol0003oUfRG
oiMXU`07oiMXU`03o`000?nEJYGoUFZE00;oUFZE00?o0000olXeb_o:=LX02oo:=LX00ol0003occ3?
oll`c`0Aoll`c`03o`000?oN8MkogR7N00gogR7N00?o0000olDjaOo5>/D03oo5>/D00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N801OoR7N83o`00017o]TVf00?o0000olhac_o><Lh03_o>
<Lh00ol0003o^dBkok]4^`09ok]4^`04o`000?n]DZgo[E:]o`0000[oW6>L00?o0000okI9]_nfBKH0
1onfBKH00ol0003oUfRGoiMXU`08oiMXU`05o`000?nEJYGoUFZEoiEZUOl000003Oo:=LX00ol0003o
cc3?oll`c`0Aoll`c`?o00003OoN8Mh00ol0003oaC[5olDja@0?olDja@03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_oR7N82o`0000;o^dBk00?o0000okI9]_nfBKH03onfBKH00ol0003o
cS7>olhacP0>olhacP03o`000?nkA;_o^dBk00So^dBk1Ol0000;oiaSW003o`000?nfBKKo]TVf00Ko
]TVf00?o0000oiMXUonGJ9L02OnGJ9L01?l0003oUFZEoiEZUOl0000=olXebP03o`000?o?<<oocc3?
017occ3?00?o0000okQ7^?nhAkP00ol0000:omhQgPCo00003Oo5>/D00ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000omLXeooG:=OoebSG0_l00005ok]4^`03o`000?nfBKKo]TVf00ko]TVf00?o0000olha
c_o><Lh03_o><Lh00ol0003o^dBkok]4^`07ok]4^`03o`000?njAK[o^TFj00?o^TFj00?o0000oiaS
W?nLHi`02?nLHi`00ol0003o]TVfokI9]P05okI9]P03o`000?nGJ9OoUfRG00[oUfRG1Ol0000<olXe
bP03o`000?o?<<oocc3?013occ3?00?o0000okQ7^?nhAkP01?nhAkP3o`0000KogR7N00?o0000om8]
d_oB;M800_oB;M85o`0000SoaC[500?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oG:=OoebSG00?o
ebSG00?o0000ok]4^onkA;/01?nkA;/00ol0003o]TVfokI9]P0=okI9]P03o`000?o><LkocS7>00oo
cS7>00?o0000ok]4^onkA;/01?nkA;/2o`0000Oo^TFj00?o0000oiaSW?nLHi`01onLHi`Eo`0000Go
XEjQ00?o0000olXeb_o:=LX02?o:=LX3o`00013occ3?00?o0000okQ7^?nhAkP02?nhAkP3o`0000;o
gR7N00?o0000om8]d_oB;M802?oB;M85o`0000?oaC[500?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oG:=OoebSG00CoebSG00?o0000ok]4^onkA;/01OnkA;/00ol0003o]TVfokI9]P0;okI9]PCo0000
3oo><Lh00ol0003o^dBkok]4^`03ok]4^`03o`000?njAK[o^TFj00So^TFj00?o0000oiaSW?nLHi`0
1?nLHi`2o`0000So^TFj00?o0000ojm@[on_D:l02?n_D:l00ol0003oXEjQoj5NX@05oj5NX@;o0000
1_o:=LX2o`0000?o`Sg200?o0000oll`coo?<<l03?o?<<l00ol0003o^4NhokQ7^00<okQ7^0;o0000
4?oB;M83o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003oebSGomLXe`05omLXe`03o`000?nkA;_o^dBk00Ko^dBk00?o
0000okI9]_nfBKH02OnfBKH00ol0003oWf2Oo`000002okY5^P?o00003?o><Lh01?l0003o^dBkok]4
^onkA;/2o`0000co^TFj00?o0000oiaSW?nLHi`00_nLHi`00ol0003o^TFjokY5^P08okY5^P03o`00
0?n_D:oo[e2_00So[e2_00?o0000oj5NXOnQGZ401onQGZ400ol0003obSG:olXebP02olXebP03o`00
0?o2?L;o`Sg200Co`Sg20_l0000;oll`c`03o`000?nhAkSo^4Nh00co^4Nh00?o0000ol0o`?l00000
4_oB;M800ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003oebSGomLXe`06omLXe`03o`000?nkA;_o^dBk00Oo^dBk00?o
0000okI9]_nfBKH01_nfBKH2o`0000;oWf2O00?o0000okY5^_njAKX00onjAKX3o`0000[ocS7>00?o
0000ok]4^ol000003onjAKX01?l0003oW6>Lo`000?l0000;okY5^P03o`000?n_D:oo[e2_00So[e2_
00?o0000oj5NXOnQGZ402?nQGZ401?l0003obSG:o`000?l00009ol8m`P03o`000?o?<<oocc3?00Oo
cc3?00?o0000okQ7^?nhAkP03?nhAkP01?l0003o`3o0ol0o`?l0000Com8]dP03o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000omLXeooG:=L01ooG:=L00ol0003o^dBkok]4^`08ok]4^`03o`000?nfBKKo]TVf00Co
]TVf00?o0000oimPWonOH9l00onOH9l00ol0003o^TFjokY5^P05okY5^P?o00001_o><Lh4o`00013o
^TFj00?o0000okY5^_njAKX03?njAKX00ol0003o[e2_ojm@[`07ojm@[`03o`000?nQGZ7oXEjQ00Wo
XEjQ00?o0000ol8m`_o2?L802_o2?L82o`0000Kocc3?00?o0000okQ7^?nhAkP03?nhAkP00ol0003o
`3o0ol0o`002ol0o`003o`000?oB;M;odRgB00oodRgB00?o0000om@[e?l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003oebSGomLXe`08omLXe`03o`000?nkA;_o^dBk00Wo^dBk00Co0000okI9]_nfBKKo
]TVf0_l00006oimPW`03o`000?njAK[o^TFj00So^TFj0ol000000oo><Lko0000o`000004oklo_`03
o`000?njAK[o^TFj00go^TFj00?o0000okY5^_njAKX03?njAKX00ol0003o[e2_ojm@[`07ojm@[`03
o`000?nQGZ7oXEjQ00WoXEjQ00?o0000ol8m`_o2?L803?o2?L800ol0003occ3?oll`c`03o`0000ko
^4Nh00?o0000ol0o`?o0?l000oo0?l000ol0003odRgBom8]dP0>om8]dP05o`000?oD:mCoe2_Dom@[
e?l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003oebSGomLXe`09omLXe`03o`000?nkA;_o^dBk00[o
^dBk00?o0000okI9]_l000002?nOH9l00ol0003o^TFjokY5^P0;okY5^P03o`000?no?koo_cno00Go
_cno00?o0000okY5^_njAKX03?njAKX00ol0003o^TFjokY5^P0<okY5^P03o`000?n_D:oo[e2_00Oo
[e2_00?o0000oj5NXOnQGZ402?nQGZ42o`0000oo`Sg20_l00002ol<l``03o`000?nhAkSo^4Nh00_o
^4Nh00?o0000ol0o`?o0?l001?o0?l000ol0003odRgBom8]dP0=om8]dP03o`000?oD:mCoe2_D00?o
e2_D00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omLXe`03o`000?nkA;_o^dBk00_o^dBk00?o0000oimPWonOH9l0
1onOH9l00ol0003o^TFjokY5^P0;okY5^P03o`000?no?koo_cno00Ko_cno00?o0000okY5^_njAKX0
2onjAKX2o`0000go^TFj00?o0000ojm@[on_D:l01on_D:l00ol0003oXEjQoj5NX@07oj5NX@04o`00
0?nYEZWoZEJYo`0000ko`Sg200?o0000ol<l`oo3?<<00_o3?<<00ol0003o^4NhokQ7^009okQ7^003
o`000?o0?l3o`3o000Ko`3o000?o0000om8]d_oB;M802ooB;M800ol0003oe2_Dom@[e005om@[e004
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000SoebSG00?o0000ok]4^onkA;/02_nkA;/2o`0000Wo
Wf2O00?o0000okY5^_njAKX02onjAKX00ol0003o_cnooklo_`07oklo_`03o`000?njAK[o^TFj00Wo
^TFj00Co0000oiEZUOnEJYGo00003?njAKX00ol0003o[e2_ojm@[`07ojm@[`03o`000?nQGZ7oXEjQ
00KoXEjQ00Go0000ojUFZOnYEZWoZEJYo`00000>ol8m`P03o`000?o3?<?o`cc300?o`cc300?o0000
okQ7^?nhAkP01onhAkP00ol0003o`3o0ol0o`007ol0o`003o`000?oB;M;odRgB00[odRgB00?o0000
om@[e?oD:m@01ooD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006omLXe`03o`000?nkA;_o^dBk
00Wo^dBk00Co0000oj9MX_nRGJ;o00002OnOH9l00ol0003o^TFjokY5^P09okY5^P03o`000?no?koo
_cno00Wo_cno00?o0000okY5^_njAKX01onjAKX00ol0003oUFZEoiEZU@02oiEZU@03o`000?njAK[o
^TFj00Wo^TFj00?o0000ojm@[on_D:l01on_D:l00ol0003oXEjQoj5NX@05oj5NX@03o`000?nYEZWo
ZEJY00?oZEJY00?o0000ol8m`_o2?L802_o2?L800ol0003o`cc3ol<l``05ol<l``03o`000?nhAkSo
^4Nh00Go^4Nh00?o0000ol0o`?o0?l002?o0?l000ol0003odRgBom8]dP09om8]dP03o`000?oD:mCo
e2_D00Soe2_D00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oG:=L3o`0000Wo^dBk00?o0000oj9M
X_nRGJ800_nRGJ800ol0003oWf2OoimPW`06oimPW`03o`000?njAK[o^TFj00Wo^TFj00?o0000oklo
_ono?kl02_no?kl00ol0003o^TFjokY5^P05okY5^P03o`000?nEJYGoUFZE00CoUFZE00?o0000okY5
^_njAKX02?njAKX00ol0003o[e2_ojm@[`07ojm@[`03o`000?nQGZ7oXEjQ00CoXEjQ00?o0000ojUF
ZOnYEZT01?nYEZT00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?o3?<?o`cc300Ko`cc300?o0000okQ7
^?nhAkP00onhAkP00ol0003o`3o0ol0o`009ol0o`003o`000?oB;M;odRgB00SodRgB00?o0000om@[
e?oD:m@02OoD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003omLXe`?o00001OnkA;/00ol0003o
XUfRoj9MXP03oj9MXP03o`000?nOH9ooWf2O00KoWf2O00?o0000okY5^_njAKX02OnjAKX00ol0003o
_cnooklo_`0;oklo_`03o`000?njAK[o^TFj00?o^TFj00?o0000oiEZUOnEJYD01_nEJYD00ol0003o
^TFjokY5^P08okY5^P03o`000?n_D:oo[e2_00Ko[e2_00?o0000oj5NXOnQGZ400_nQGZ42o`0000So
ZEJY00?o0000ol8m`_o2?L802Oo2?L800ol0003o`cc3ol<l``07ol<l``05o`000?nhAkSo^4NhokQ7
^?l000003Oo0?l000ol0003odRgBom8]dP06om8]dP03o`000?oD:mCoe2_D00[oe2_D00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oG:=OoebSG00GoebSG0ol000000onkA;_o0000oj9MXP06oj9MXP03
o`000?nOH9ooWf2O00GoWf2O00?o0000okY5^_njAKX02OnjAKX00ol0003o_cnooklo_`0<oklo_`05
o`000?njAK[o^TFjokY5^_l000002_nEJYD00ol0003o^TFjokY5^P07okY5^P03o`000?n_D:oo[e2_
00Ko[e2_00?o0000oj5NXOl000000_l000000oo8=lSo0000ojUFZ@07ojUFZ@03o`000?o2?L;o`Sg2
00So`Sg200?o0000ol<l`oo3?<<02Oo3?<<00ol0003o^4Nho`00000=ol0o`0Co00001OoB;M800ol0
003oe2_Dom@[e00;om@[e003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSGomLXe`08omLXe`03
o`000?nRGJ;oXUfR00OoXUfR00?o0000oimPWonOH9l01?nOH9l00ol0003o^TFjokY5^P09okY5^P03
o`000?no?koo_cno00go_cno00?o0000okY5^_l000003?nEJYD:o`0000Oo[e2_0ol00005olPgb003
o`000?nYEZWoZEJY00KoZEJY00?o0000ol8m`_o2?L801oo2?L800ol0003o`cc3ol<l``0:ol<l``03
o`000?o0?l3o`3o000_o`3o000?o0000oke2_Onm@[d00_nm@[d3o`000003om8]d_l0003oe2_D00_o
e2_D0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000omLXeooG:=L02OoG:=L00ol0003oXUfRoj9MXP07oj9MXP03o`00
0?nOH9ooWf2O00GoWf2O00?o0000okY5^_njAKX01onjAKX00ol0003o_cnooklo_`0?oklo_`;o0000
2onEJYD00ol0003o`Ck1ol4n`@07ol4n`@03o`000?n_D:oo[e2_00;o[e2_0ol00008olPgb003o`00
0?nYEZWoZEJY00KoZEJY00?o0000ol8m`_o2?L801oo2?L800ol0003o`cc3ol<l``0:ol<l``03o`00
0?o0?l3o`3o000[o`3o000?o0000oke2_Onm@[d01_nm@[d00ol0003oe2_Dom@[e008om@[e0?o0000
0_oN8Mh00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000omLXeooG:=L02OoG:=L00ol0003oXUfRoj9M
XP08oj9MXP03o`000?nOH9ooWf2O00CoWf2O00?o0000okY5^_njAKX01onjAKX00ol0003o_cnooklo
_`0>oklo_`04o`000?nRGJ;oXUfRo`0000WoUFZE00?o0000ol4n`Oo1?/402Oo1?/401?l0003o[e2_
o`000?l0000<olPgb003o`000?nYEZWoZEJY00KoZEJY00?o0000ol8m`_o2?L801_o2?L800ol0003o
`cc3ol<l``0;ol<l``03o`000?o0?l3o`3o000Oo`3o00_l00009oke2_@03o`000?oD:mCoe2_D00Co
e2_D1?l00006omhQgP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003oebSGomLXe`09omLXe`03o`00
0?nRGJ;oXUfR00SoXUfR00?o0000oimPWonOH9l00onOH9l>o`0000go_cno00?o0000oj9MX_nRGJ80
0_nRGJ800ol0003oUFZEoiEZU@05oiEZU@03o`000?o1?/7o`Ck100_o`Ck100?o0000olPgb?o8=lP0
3?o8=lP00ol0003oZEJYojUFZ@06ojUFZ@03o`000?o2?L;o`Sg200Go`Sg200?o0000ol<l`oo3?<<0
3?o3?<<00ol0003o`3o0ol0o`006ol0o`003o`000?nm@[go_D:m00[o_D:m00?o0000om@[e?oD:m@0
0ol0000:omhQgP?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000oj9MX_nRGJ802?nR
GJ801Ol0003oWf2OoimPWonOH9oo000000_o/Tfb00?o0000oh9mP_n2OH800ol00009oklo_`03o`00
0?nRGJ;oXUfR00CoXUfR00?o0000oiEZUOnEJYD00onEJYD00ol0003o`Ck1ol4n`@0<ol4n`@03o`00
0?o8=lSob3O800gob3O800?o0000ojUFZOnYEZT01_nYEZT00ol0003o`Sg2ol8m`P03ol8m`P?o0000
3Oo3?<<00ol0003o`3o0ol0o`005ol0o`003o`000?nm@[go_D:m00co_D:m0_l0000=omhQgP03o`00
0?oj1O[onPGj00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000oj9MX_nRGJ802?nR
GJ84o`0000co/Tfb00?o0000oh9mP_n2OH800on2OH83o`0000Go_cno00?o0000oj9MX_nRGJ801_nR
GJ801Ol0003oUFZEoiEZUOnEJYGo000000oo`Ck100?o0000olPgb?o8=lP03Oo8=lP00ol0003oZEJY
ojUFZ@06ojUFZ@03o`000?o2?L;o`Sg200?o00000on[E:/00ol0003o`cc3ol<l``0;ol<l``03o`00
0?o0?l3o`3o000?o`3o000?o0000oke2_Onm@[d03Onm@[d00ol0003ogR7NomhQgP0;omhQgP03o`00
0?oj1O[onPGj00ConPGj0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000omLXeooG:=L02_oG:=L3o`0000KoXUfR0ol0
0003ojAKY003o`000?nbCK;o/Tfb00[o/Tfb00?o0000oh9mP_n2OH801_n2OH83o`000003oklo_ol0
003oXUfR00WoXUfR00?o0000oiEZUOl000004?o1?/400ol0003ob3O8olPgb00=olPgb003o`000?nY
EZWoZEJY00OoZEJY0_l00007oj]DZ`03o`000?o3?<?o`cc300[o`cc300Co0000ol0o`?o0?l3o`3o0
0ol0000?oke2_@03o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX01ooj1OX4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omLXeooG:=L02_oG
:=L01?l0003o_cnooklo_ono?kl2o`000004oj9MX_l0003o0000o`0000KoY5^T00?o0000ok9=/_nb
CK802_nbCK800ol0003oPWf2oh9mPP09oh9mPP03o`000?nRGJ;oXUfR00[oXUfR00?o0000ol4n`Oo1
?/403oo1?/400ol0003ob3O8olPgb00>olPgb003o`000?nYEZWoZEJY00KoZEJY00?o0000oj]DZon[
E:/01on[E:/4o`0000So`cc300Co0000ol0o`?o0?l3o00000onIIYT2o`0000go_D:m00?o0000omhQ
g_oN8Mh02_oN8Mh00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omLXeooG:=L02OoG:=L00ol0003o
_cnooklo_`04oklo_`03o`000?nTFjCoY5^T00OoY5^T00?o0000ok9=/_nbCK802OnbCK800ol0003o
PWf2oh9mPP0:oh9mPP03o`000?nRGJ;oXUfR00[oXUfR00?o0000ol4n`Oo1?/403oo1?/400ol0003o
b3O8olPgb00>olPgb003o`000?nYEZWoZEJY00GoZEJY00?o0000oj]DZon[E:/02?n[E:/01?l0003o
]TVfokI9]_nfBKH7o`0000;o`cc30_l00006oiUVV@;o00003?nm@[d00ol0003ogR7NomhQgP09omhQ
gP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oebSGomLXe`08omLXe`03o`000?no?koo_cno00Go
_cno00?o0000ojAKY?nTFj@02?nTFj@00ol0003o/Tfbok9=/P08ok9=/P03o`000?n2OH;oPWf200[o
PWf200?o0000oj9MX_nRGJ802onRGJ800ol0003o`Ck1ol4n`@0>ol4n`@03o`000?o8=lSob3O800ko
b3O81Ol00002ojUFZ@03o`000?n[E:_oZeB[00WoZeB[00?o0000okI9]_nfBKH02?nfBKH3o`0000Wo
VFJI0_l0000:oke2_@03o`000?oN8MkogR7N00SogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oG:=OoebSG00SoebSG00?o0000oklo_ono?kl01ono?kl00ol0003oY5^TojAKY007ojAKY003o`00
0?nbCK;o/Tfb00So/Tfb00?o0000oh9mP_n2OH802_n2OH800ol0003oXUfRoj9MXP0:oj9MXP;o0000
3_o1?/43o`0000gob3O80ol00005olXebP;o00002on[E:/00ol0003o]TVfokI9]P0;okI9]P;o0000
2_nIIYT2o`0000Oo_D:m0ol00009omhQgP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:oklo_`03o`00
0?nTFjCoY5^T00OoY5^T00?o0000ok9=/_nbCK802?nbCK8>o`0000WoXUfR0ol000000on8MhSo0000
ol4n`@0:ol4n`@?o00000_o=</d00ol0003ob3O8olPgb009olPgb0;o00002Oo:=LX00ol0003oZeB[
oj]DZ`09oj]DZ`03o`000?nfBKKo]TVf00_o]TVf00?o0000oklo_ol000002onIIYT2o`0000Co_D:m
00Co0000omTVfOoI9]WofBKI0_l00007omhQgP03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003o_cno
oklo_`09oklo_`03o`000?nTFjCoY5^T00KoY5^T00?o0000ok9=/_nbCK802?nbCK800ol0003oSg2?
ohm`S`0:ohm`S`03o`000?nRGJ;oXUfR00CoXUfR0ol00005ohQgR003o`000?o1?/7o`Ck100Co`Ck1
1?l00006oldbc@03o`000?o8=lSob3O800Kob3O80_l0000;olXebP03o`000?n[E:_oZeB[00WoZeB[
00?o0000okI9]_nfBKH02_nfBKH01Ol0003o_cnooklo_ono?koo000000coVFJI0_l000000onm@[go
0000omTVf@05omTVf@03o`000?oN8MkogR7N00?ogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?no?koo_cno00So_cno00?o0000ojAKY?nTFj@01_nTFj@00ol0003o/Tfbok9=/P07ok9=/P03o`00
0?n?L8ooSg2?00_oSg2?00?o0000oj9MX_nRGJ800_nRGJ82o`0000WoR7N800?o0000ol4n`Oo1?/40
0ol0000;oldbc@03o`000?o8=lSob3O800;ob3O80ol0000>olXebP03o`000?n[E:_oZeB[00OoZeB[
00?o0000okI9]_nfBKH02onfBKH00ol0003o_cnooklo_`02oklo_`03o`000?nIIYWoVFJI00_oVFJI
00?o0000omTVfOoI9]T01_oI9]T2o`0000?ogR7N00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?no
?koo_cno00Oo_cno00?o0000ojAKY?nTFj@01onTFj@00ol0003o/Tfbok9=/P05ok9=/P?o00003On?
L8l4o`0000_oR7N80ol0000?oldbc@04o`000?o8=lSo0000o`00017obSG:00?o0000oj]DZon[E:/0
1on[E:/00ol0003o]TVfokI9]P0:okI9]P03o`000?no?koo_cno00Co_cno00?o0000oiUVVOnIIYT0
1onIIYT3o`0000_ofBKI1?l0000=ooX5nP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oklo_ono?kl02?no?kl00ol0003oY5^TojAK
Y006ojAKY003o`000?nbCK;o/Tfb00;o/Tfb0ol00003ojEJY@03o`000?n?L8ooSg2?00[oSg2?00?o
0000ohQgR?n8MhP02on8MhP00ol0003oTVfBo`00000Aoldbc@03o`000?o:=L[obSG:017obSG:00?o
0000oj]DZon[E:/01on[E:/00ol0003o]TVfokI9]P0:okI9]P03o`000?no?koo_cno00Go_cno00Co
0000oiUVVOnIIYWoVFJI1Ol00002ojQGZ003o`000?oI9]WofBKI00WofBKI00Co0000ooX5n_oj1O[o
nPGj0ol00009ooX5nP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oklo_ono?kl01ono?kl00ol0003oY5^TojAKY005ojAKY0?o0000
00?o/Tfbo`000?l000001onUFZD00ol0003oSg2?ohm`S`08ohm`S`?o00002_n8MhP2o`0000;oTVfB
00?o0000oldbcOo=</d03oo=</d00ol0003obSG:olXebP0AolXebP03o`000?n[E:_oZeB[00OoZeB[
00?o0000okI9]_nfBKH02OnfBKH00ol0003o_cnooklo_`07oklo_`?o00001onXEjP00ol0003ofBKI
omTVf@09omTVf@03o`000?oj1O[onPGj00ConPGj0_l00007ooX5nP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oklo_ono?kl01ono
?kl4o`0000;oY5^T0_l00003okE:]@03o`000?nUFZGoYEZU00SoYEZU0_l00006ohm`S`;o00000onF
JIH00ol0003oR7N8ohQgR006ohQgR003o`000?nBKI;oTVfB00?oTVfB00?o0000oldbcOo=</d03_o=
</d00ol0003obSG:olXebP0BolXebP03o`000?n[E:_oZeB[00GoZeB[00?o0000okI9]_nfBKH02Onf
BKH00ol0003o_cnooklo_`08oklo_`03o`000?nXEjSoZ5NX00OoZ5NX00?o0000omTVfOoI9]T02?oI
9]T00ol0003onPGjooX5nP07ooX5nP;o00001Ooj1OX00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?no?koo_cno00Co_cno0_l00004
om@[e0;o00001OneB[D00ol0003oYEZUojEJY@0:ojEJY@03o`000?n?L8ooSg2?00;oSg2?00?o0000
oiIYU_nFJIH01?nFJIH00ol0003oR7N8ohQgR004ohQgR003o`000?nBKI;oTVfB00CoTVfB00?o0000
oldbcOo=</d03_o=</d00ol0003obSG:olXebP0BolXebP[o00002_nfBKH00ol0003o_cnooklo_`08
oklo_`03o`000?nXEjSoZ5NX00OoZ5NX00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP09
ooX5nP?o000000?onPGjo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_cnooklo_ono?kl2o`0000Ooe2_D00?o0000okE:]OneB[D01?neB[D0
0ol0003oYEZUojEJY@0:ojEJY@04o`000?n?L8oo0000o`0000SoUVVF00Co0000ohQgR?n8MhSoR7N8
0_l00007oi9]TP03o`000?o=</gocC;=00kocC;=00?o0000olXeb_o:=LX04_o:=LX00ol0003o]4^d
okA;]007okA;]003o`000?nfBKKo]TVf00Ko]TVf00?o0000oklo_ono?kl02_no?kl00ol0003oZ5NX
ojQGZ006ojQGZ003o`000?oI9]WofBKI00SofBKI00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?no
?koo0000o`0000Woe2_D00?o0000okE:]OneB[D01?neB[D00ol0003oYEZUojEJY@0;ojEJY@03o`00
0?nFJIKoUVVF00WoUVVF00?o0000ohQgR?l000002OnBKI800ol0003ocC;=oldbc@0>oldbc@;o0000
4_o:=LX00ol0003o]4^dokA;]009okA;]0;o00001_nfBKH00ol0003o_cnooklo_`0:oklo_`03o`00
0?nXEjSoZ5NX00KoZ5NX00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om@[e?oD:m@02OoD:m@00ol0003o]DZeokE:]@05okE:]@03o`000?nUFZGoYEZU00[oYEZU00?o
0000oiIYU_nFJIH02_nFJIH2o`0000WoTVfB00?o0000oldbcOo=</d03_o=</d00ol0003o_d2oo`00
0002o`0000oobSG:00?o0000okA;]?ndBk@02ondBk@00ol0003o]TVfokI9]P03o`0000go_cno00?o
0000ojQGZ?nXEjP01_nXEjP00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003oe2_Dom@[e009om@[e003o`000?neB[Go]DZe00Go]DZe00?o0000ojEJYOnUFZD02OnUFZD2
o`0000_oUVVF0_l0000;oi9]TP03o`000?o=</gocC;=00cocC;=00?o0000okm0_ono@;l00ono@;l3
o`0000cobSG:00?o0000okA;]?ndBk@03?ndBk@2o`0000;o[e2_00?o0000oklo_ono?kl03?no?kl0
0ol0003oZ5NXojQGZ005ojQGZ003o`000?oI9]WofBKI00OofBKI00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oD:mCoe2_D00[oe2_D00?o0000okE:]OneB[D01_neB[D00ol0003oYEZUojEJY@07ojEJ
Y@03o`000?nEJYGo000000[oUVVF00Co0000ohEjQOn5NXGo00002_nBKI800ol0003ocC;=oldbc@0<
oldbc@03o`000?no@;oo_d2o00Ko_d2o0_l00008olXebP;o00003ondBk@00ol0003o[e2_ojm@[`02
ojm@[`03o`000?no?koo_cno00_o_cno00?o0000ojQGZ?nXEjP01OnXEjP00ol0003ofBKIomTVf@07
omTVf@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oe2_Dom@[e00:om@[e003o`000?neB[Go]DZe
00Ko]DZe00?o0000ojEJYOnUFZD01_nUFZD01Ol0003oUFZEoiEZUOnEJYGo000000SoUVVF00?o0000
ohEjQOn5NXD00_n5NXD00ol0003oTVfBoi9]TP06oi9]TPCo00003?o=</d00ol0003o_d2ookm0_`08
okm0_`?o00000_o:=LX3o`000003ok9=/_l0003o]4^d00go]4^d00?o0000ojm@[on_D:l01?n_D:l0
0ol0003o_cnooklo_`0:oklo_`03o`000?nXEjSoZ5NX00GoZ5NX00?o0000omTVfOoI9]T01_oI9]T0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om@[e?oD:m@02ooD:m@00ol0003o]DZeokE:]@07okE:
]@03o`000?nUFZGoYEZU00?oYEZU0_l00005oiEZU@03o`000?nFJIKoUVVF00CoUVVF00?o0000ohEj
QOn5NXD00on5NXD00ol0003oTVfBoi9]TP05oi9]TP03o`000?n[E:_oZeB[00;oZeB[0ol00007oldb
c@;o00003_no@;l2o`0000Go/Tfb00?o0000okA;]?ndBk@02_ndBk@00ol0003o[e2_ojm@[`05ojm@
[`03o`000?no?koo_cno00_o_cno00?o0000ojQGZ?nXEjP01?nXEjP00ol0003ofBKIomTVf@06omTV
f@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oe2_Dom@[e00;om@[e003o`000?neB[Go]DZe00Oo
]DZe00?o0000ojEJYOnUFZD00_nUFZD00ol0003oUFZEoiEZU@06oiEZU@03o`000?nFJIKoUVVF00;o
UVVF00?o0000ohEjQOn5NXD01On5NXD00ol0003oTVfBoi9]TP02oi9]TP;o00002?n[E:/3o`0000;o
cC;=0_l000000onaC[7o0000okm0_`0=okm0_`03o`000?nbCK;o/Tfb00Go/Tfb00?o0000okA;]?nd
Bk@02?ndBk@00ol0003o[e2_ojm@[`07ojm@[`03o`000?no?koo_cno00[o_cno00?o0000ojQGZ?nX
EjP01?nXEjP00ol0003ofBKIomTVf@06omTVf@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oe2_D
om@[e00<om@[e003o`000?neB[Go]DZe00So]DZe00Co0000ojEJYOnUFZGo00002OnEJYD01Ol0003o
UVVFoiIYU_nFJIKo000000SoQGZ500Go0000oi9]T_nBKI;oTVfBo`00000=oj]DZ`;o00001?naC[40
0ol0003o_d2ookm0_`0;okm0_`03o`000?nbCK;o/Tfb00Ko/Tfb00?o0000okA;]?ndBk@01ondBk@0
0ol0003o[e2_ojm@[`08ojm@[`Co00002?no?kl00ol0003oZ5NXojQGZ004ojQGZ003o`000?oI9]Wo
fBKI00KofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oD:mCoe2_D00_oe2_D0ol00009okE:
]@03o`000?nUFZGo000000_oUFZE00?o0000oiIYU_l000002_n5NXD00ol0003oTVfBo`00000?oj]D
Z`03o`000?naC[7o/Dja00;o/Dja00?o0000okm0_ono@;l02ono@;l00ol0003o/Tfbok9=/P06ok9=
/P03o`000?ndBkCo]4^d00Ko]4^d00?o0000ojm@[on_D:l02On_D:l01?l0003o_4>loka3_?nl@k`7
o`0000;o_cno00?o0000ojQGZ?nXEjP00onXEjP00ol0003ofBKIomTVf@05omTVf@03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oD:mCoe2_D00Soe2_D0ol00003okm0_`03o`000?neB[Go]DZe00Oo]DZe00?o0000oiEZ
UOnEJYD02onEJYD00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?n[E:_oZeB[00goZeB[00?o0000ok5>
/OnaC[401?naC[400ol0003o_d2ookm0_`09okm0_`03o`000?nbCK;o/Tfb00So/Tfb00?o0000okA;
]?ndBk@00ondBk@2o`0000co[e2_00?o0000oka3_?nl@k`02?nl@k`<o`0000?ofBKI0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om@[e?oD:m@01_oD:m@3o`0000Oo_d2o00?o0000okE:]OneB[D01_neB[D00ol0003o
UFZEoiEZU@0;oiEZU@03o`000?n5NXGoQGZ500WoQGZ50_l0000>oj]DZ`03o`000?naC[7o/Dja00Go
/Dja00?o0000okm0_ono@;l02Ono@;l00ol0003o/Tfbok9=/P09ok9=/P03o`000?ndBkCo000000;o
00000_nXEjP00ol0003o[e2_ojm@[`08ojm@[`03o`000?nl@kco_4>l00co_4>l00?o0000omlPgooO
8=l01_oO8=l3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003oe2_Dom@[e003om@[e0?o00002ono@;l00ol0003o]DZe
okE:]@04okE:]@03o`000?nEJYGoUFZE00_oUFZE0ol00007ohEjQ@?o000000?oXUfRo`000?n[E:/0
3On[E:/00ol0003o/Djaok5>/@06ok5>/@03o`000?no@;oo_d2o00So_d2o00?o0000ok9=/_nbCK80
2_nbCK800ol0003oZ5NXojQGZ004ojQGZ003o`000?n_D:oo[e2_00Oo[e2_00?o0000oka3_?nl@k`0
2onl@k`00ol0003ogb3OomlPg`08omlPg`03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om@[e?l0
003o0000o`0000oo_d2o00?o0000okE:]OneB[D00oneB[D>o`0000?oUFZE0_l00002ohEjQ@?o0000
1OnRGJ800ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?naC[7o/Dja00Oo/Dja00?o0000okm0_ono@;l0
2?no@;l00ol0003o/Tfbok9=/P0:ok9=/P03o`000?nXEjSoZ5NX00GoZ5NX00?o0000ojm@[on_D:l0
1_n_D:l00ol0003o_4>loka3_00;oka3_003o`000?oO8=oogb3O00Sogb3O00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o_d2o00?o0000okE:]OneB[D00_neB[D00ol0003oPWf2oh9m
PP0:oh9mPP03o`000?nEJYGoUFZE00?oUFZE0_l00009oj9MXP03o`000?n[E:_oZeB[00WoZeB[00?o
0000ok5>/OnaC[402?naC[42o`0000So_d2o00?o0000ok9=/_nbCK802OnbCK800ol0003oZ5NXojQG
Z007ojQGZ003o`000?n_D:oo[e2_00Co[e2_00?o0000oka3_?nl@k`02onl@k`00ol0003ogb3OomlP
g`09omlPg`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o_d2ookm0_`0?okm0_`?o000000?o]DZe
o`000?n2OH802on2OH800ol0003oUFZEoiEZU@04oiEZU@03o`000?nRGJ;oXUfR00WoXUfR00?o0000
oj]DZon[E:/01on[E:/00ol0003o/Djaok5>/@09ok5>/@04o`000?n]DZgo0000o`0000Ko_d2o00?o
0000ok9=/_nbCK802OnbCK800ol0003oZ5NXojQGZ008ojQGZ003o`000?n_D:oo[e2_00?o[e2_00?o
0000oka3_?nl@k`02onl@k`00ol0003ogb3OomlPg`09omlPg`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o_d2ookm0_`0<okm0_`;o00000ongB;L2o`0000coPWf200?o0000oiEZUOnEJYD01?nEJYD0
0ol0003oXUfRoj9MXP0:oj9MXPWo00002onaC[400ol0003o[E:]ojeB[@02ojeB[@?o00000_no@;l0
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?nXEjSoZ5NX00WoZ5NX00?o0000ojm@[on_D:l00_n_D:l0
0ol0003o_4>loka3_00:oka3_003o`000?oO8=oogb3O00Wogb3O00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_no@;l2o`0000Go]dRg00?o0000ojEJYOl000002_n2OH800ol0003oUFZEoiEZU@06oiEZ
U@03o`000?nRGJ;oXUfR00WoXUfR00?o0000oj9MX_nRGJ801OnRGJ800ol0003o/Djaok5>/@09ok5>
/@03o`000?n]DZgo[E:]00Go[E:]0ol00009ok9=/P?o00003OnXEjP01Ol0003o[e2_ojm@[on_D:oo
000000co_4>l00?o0000omlPgooO8=l02OoO8=l00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000okm0
_ono@;l01Ono@;l2o`0000Oo]dRg00Co0000ojEJYOnUFZGo00002On2OH800ol0003oUFZEoiEZU@06
oiEZU@03o`000?nRGJ;oXUfR00SoXUfR00?o0000oj9MX_nRGJ801onRGJ800ol0003o/Djaok5>/@07
ok5>/@03o`000?n]DZgo[E:]00So[E:]0ol00002ok9=/PGo00000_n9MXT00ol0003oZ5NXojQGZ00<
ojQGZ003o`000?n_D:oo000000co_4>l00?o0000omlPgooO8=l02_oO8=l00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000okm0_ono@;l00_no@;l2o`0000So]dRg00?o0000ojEJYOnUFZD00_nUFZD5o`00
00CoPWf200?o0000oiEZUOnEJYD01_nEJYD00ol0003oXUfRoj9MXP08oj9MXP03o`000?nRGJ;oXUfR
00OoXUfR00?o0000ok5>/OnaC[401onaC[400ol0003o[E:]ojeB[@08ojeB[@03o`000?n;M8_oRgB;
00;o00002?n9MXT00ol0003oZ5NXojQGZ00<ojQGZ0Co00002_nl@k`00ol0003ogb3OomlPg`0:omlP
g`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o_d2oo`000?l0000:okM8]`03o`000?nUFZGoYEZU
00;oYEZU00?o0000oejQG_mNXEh00_mNXEh4o`0000WoUFZE00?o0000oj9MX_nRGJ802?nRGJ800ol0
003oXUfRoj9MXP08oj9MXP03o`000?naC[7o/Dja00Go/Dja00?o0000ojeB[On]DZd02?n]DZd01Ol0
003oRgB;oh]dRon;M8_o000000[oRGJ90ol0000;ojQGZ004o`000?o@;m3od2o@om0_d0Co00001Onl
@k`00ol0003ogb3OomlPg`0;omlPg`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o]dRgokM8]`0:
okM8]`03o`000?nUFZGoYEZU00?oYEZU00?o0000oejQG_mNXEh01?mNXEh00ol0003oUFZEoiEZU@07
oiEZU@03o`000?nRGJ;oXUfR00KoXUfR0_l0000;oj9MXP03o`000?naC[7o/Dja00Go/Dja00?o0000
ojeB[On]DZd02?n]DZd00ol0003oRgB;oh]dR`02oh]dR`03o`000?n9MXWoRGJ900OoRGJ900?o0000
ojQGZ?nXEjP01?l00006ojQGZ003o`000?o@;m3od2o@00Kod2o@0ol00002oka3_003o`000?oO8=oo
gb3O00_ogb3O00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?ngB;Oo]dRg00Wo]dRg00?o0000ojEJ
YOnUFZD01?nUFZD00ol0003oGZ5NoejQGP05oejQGP03o`000?nEJYGoUFZE00OoUFZE00?o0000oj9M
X_nRGJ800_nRGJ83o`000003ojYEZ_l0003oXUfR00[oXUfR00?o0000ok5>/OnaC[401OnaC[400ol0
003o[E:]ojeB[@07ojeB[@03o`000?n;M8_oRgB;00?oRgB;00?o0000ohUfROn9MXT01on9MXT00ol0
003oZ5NXojQGZ004ojQGZ0?o00000_nXEjP00ol0003od2o@om0_d00:om0_d0;o00003_oO8=l00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000okM8]ongB;L02OngB;L00ol0003oYEZUojEJY@04ojEJY@03
o`000?mNXEkoGZ5N00KoGZ5N0_l00007oiEZU@03o`000?nRGJ;o000000;o00001OnZEJX00ol0003o
XUfRoj9MXP08oj9MXP?o00001?naC[400ol0003o[E:]ojeB[@08ojeB[@03o`000?n;M8_oRgB;00Co
RgB;00?o0000ohUfROn9MXT01_n9MXT00ol0003oZ5NXojQGZ007ojQGZ0;o00003_o@;m000ol0003o
gb3OomlPg`0;omlPg`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]dRgokM8]`08okM8]`03o`00
0?nUFZGoYEZU00GoYEZU00?o0000oejQG_mNXEh01?mNXEh00ol0003oTFjAoi5^T@03o`0000CoUFZE
0_l00008ojYEZP03o`000?nRGJ;oXUfR00OoXUfR00Co0000ol8m`_o2?L;o`Sg20ol000000onaC[7o
0000ojeB[@09ojeB[@03o`000?n;M8_oRgB;00CoRgB;00?o0000ohUfROn9MXT01On9MXT00ol0003o
Z5NXojQGZ009ojQGZ003o`000?o@;m3od2o@00god2o@00?o0000omlPgooO8=l02_oO8=l00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000okM8]ongB;L01ongB;L00ol0003oYEZUojEJY@06ojEJY@03o`00
0?mNXEkoGZ5N00?oGZ5N00?o0000oi5^TOnAKY401?nAKY42o`000003oiEZUOl0003oZUFZ00[oZUFZ
00?o0000oj9MX_nRGJ801OnRGJ800ol0003o`Sg2ol8m`P05ol8m`P03o`000?n]DZgo[E:]00Oo[E:]
0ol00007oh]dR`03o`000?n9MXWoRGJ900CoRGJ900?o0000ojQGZ?nXEjP02OnXEjP00ol0003od2o@
om0_d00=om0_d003o`000?oO8=oogb3O00[ogb3O00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?ng
B;Oo]dRg00Go]dRg0ol00009ojEJY@05o`000?mNXEkoGZ5NoejQG_l000002OnAKY400ol0003oZUFZ
ojYEZP0;ojYEZP03o`000?nRGJ;oXUfR00?oXUfR00?o0000ol8m`_o2?L801_o2?L800ol0003o[E:]
ojeB[@06ojeB[@05o`000?n_D:oo[e2_ojm@[ol000001on;M8/00ol0003oRGJ9ohUfR@03ohUfR@03
o`000?nXEjSoZ5NX00WoZ5NX00?o0000om0_d?o@;m003_o@;m000ol0003ogb3OomlPg`09omlPg`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]dRgo`000004o`0000;od2o@00?o0000ojEJYOnUFZD0
1onUFZD01?l0003oGZ5NoejQG_l00009oi5^T@;o00003OnZEJX00ol0003oXUfRoj9MXP02oj9MXP03
o`000?o2?L;o`Sg200So`Sg200?o0000ojeB[On]DZd00on]DZd2o`0000Go[e2_00?o0000oh]dRon;
M8/01?n;M8/00ol0003oRGJ9ohUfR@03ohUfR@03o`000?nXEjSoZ5NX00WoZ5NX00?o0000om0_d?o@
;m003_o@;m000ol0003ogb3OomlPg`09omlPg`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Sod2o@
00?o0000ojEJYOnUFZD01_nUFZD00ol0003oGZ5No`000009oi5^T@04o`000?ndBkCo]4^do`0000go
ZUFZ00Co0000oj9MX_nRGJ;o00003?o2?L801Ol0003o[E:]ojeB[On]DZgo000000So[e2_0_l00005
oh]dR`03o`000?n9MXWoRGJ900;oRGJ900?o0000ojQGZ?nXEjP02OnXEjP00ol0003od2o@om0_d00>
om0_d003o`000?oO8=oogb3O00Wogb3O00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@;m3od2o@
00Ood2o@00?o0000ojEJYOnUFZD01onUFZD00ol0003oTFjAoi5^T@07oi5^T@03o`000?ndBkCo]4^d
00;o]4^d00?o0000ojYEZ_nZEJX02_nZEJX00ol0003oXUfRo`00000>ol8m`P03o`000?n]DZgo0000
00_o[e2_00?o0000oh]dRon;M8/00_n;M8/01Ol0003oRGJ9ohUfROn9MXWo000000coZ5NX00?o0000
om0_d?o@;m003_o@;m03o`0000Wogb3O00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o@;m3od2o@
00Wod2o@00?o0000ojEJYOnUFZD01_nUFZD00ol0003oTFjAoi5^T@06oi5^T@03o`000?ndBkCo]4^d
00?o]4^d00?o0000ojYEZ_nZEJX02onZEJX00ol0003o`Sg2ol8m`P0>ol8m`P03o`000?n_D:oo[e2_
00_o[e2_0_l00003oh]dR`04o`000?n9MXWoRGJ9o`0000[oZ5NX0ol0000>om0_d0;o00000ooj1OX2
o`0000Oogb3O00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o@;m3od2o@00[od2o@00?o0000ojEJ
YOnUFZD01?nUFZD00ol0003oTFjAoi5^T@06oi5^T@03o`000?ndBkCo]4^d00Go]4^d00?o0000ojYE
Z_nZEJX01onZEJX3o`00017o`Sg200?o0000ojm@[on_D:l03On_D:l01Ol0003oRgB;oh]dRol0003o
RGJ900Co00000onXEjP5o`0000;o`Ck100?o0000om0_d?o@;m002_o@;m02o`0000OonPGj0_l00004
omlPg`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003od2o@om0_d00;om0_d003o`000?nUFZGoYEZU
00CoYEZU00?o0000oi5^TOnAKY401OnAKY400ol0003o]4^dokA;]006okA;]003o`000?nZEJ[oZUFZ
00CoZUFZ0ol00002ok=</`03o`000?o2?L;o`Sg200oo`Sg20_l0000?ojm@[`04o`000?n;M8_o0000
o`0000CoXebS0ol00008ol4n`@03o`000?o@;m3od2o@00Ood2o@0_l0000;ooX5nP;o00000_oO8=l0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om0_d?o@;m003?o@;m06o`0000OoTFjA00?o0000okA;
]?ndBk@02?ndBk@00ol0003oZUFZojYEZP03o`0000Ko/dbc00?o0000ol8m`_o2?L803Oo2?L801?l0
003o_4>loka3_?l0000?ojm@[`03o`000?nSG:?oXebS00GoXebS00?o0000ol4n`Oo1?/402?o1?/40
0ol0003od2o@om0_d005om0_d003o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o@;m000ol0003oYEZUojEJY@04ojEJ
Y@03o`000?nAKY7oTFjA00?oTFjA00?o0000okA;]?ndBk@02_ndBk@2o`0000[o/dbc00?o0000ol8m
`_o2?L802oo2?L800ol0003o_4>loka3_002oka3_003o`000?n_D:oo[e2_00_o[e2_0_l00007oj=L
X`03o`000?o1?/7o`Ck100Wo`Ck100?o0000om0_d?o@;m000_o@;m02o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om0_d?o@;m002oo@;m000ol0003oYEZUojEJY@06ojEJY@05o`000?nAKY7oTFjAoi5^
TOl000003OndBk@00ol0003o/dbcok=</`0:ok=</`03o`000?o2?L;o`Sg200Wo`Sg200?o0000oka3
_?nl@k`01?nl@k`00ol0003o[e2_ojm@[`08ojm@[`;o000000?oSW6>o`000?nSG:<01onSG:<00ol0
003o`Ck1ol4n`@09ol4n`@04o`000?o@;m3o0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?o@;m3od2o@
00Wod2o@00?o0000ojEJYOnUFZD02?nUFZD00ol0003oTFjAo`00000=okA;]003o`000?ncC;?o/dbc
00_o/dbc00?o0000ol8m`_o2?L802?o2?L800ol0003o_4>loka3_006oka3_003o`000?n_D:oo[e2_
00Go[e2_0_l00003ohiaSP03o`000?nSG:?oXebS00KoXebS00?o0000ol4n`Oo1?/402_o1?/400ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003od2o@om0_d007om0_d003o`000?nUFZGoYEZU00[oYEZU00?o0000okA;]?nd
Bk@03?ndBk@00ol0003o/dbcok=</`0<ok=</`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oka3_?nl
@k`02?nl@k`00ol0003o[e2_ojm@[`02ojm@[`;o00001_n>LHh00ol0003oXebSoj=LX`05oj=LX`03
o`000?o1?/7o`Ck100[o`Ck100?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@;m3od2o@00God2o@
00?o0000ojEJYOnUFZD03?nUFZD2o`0000co]4^d00?o0000ok=</oncC;<03OncC;<00ol0003o`Sg2
ol8m`P04ol8m`P03o`000?nl@kco_4>l00[o_4>l00Co0000ojm@[ol0003o00002?n>LHh00ol0003o
XebSoj=LX`06oj=LX`03o`000?o1?/7o`Ck100Wo`Ck100?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_o@;m000ol0003oYEZUojEJY@0=ojEJY@03o`000?nZEJ[o000000;o00002?ndBk@00ol0003o/dbc
ok=</`0?ok=</`Ko00003_nl@k`00ol0003oSW6>ohiaSP08ohiaSP03o`000?nSG:?oXebS00KoXebS
00?o0000ol4n`Oo1?/402Oo1?/400ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000ol/dboo;=<_obcC;
0_l0000?ojEJY@03o`000?nZEJ[oZUFZ00?oZUFZ0ol00005okA;]0;o00004?ncC;<01_l0003oYUVV
ojIIY_l0003oU6^Do`0000ko_4>l00?o0000ohiaS_n>LHh02On>LHh00ol0003oXebSoj=LX`05oj=L
X`03o`000?o1?/7o`Ck100Wo`Ck100?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000ol/dboo;=</00oo;=</00ol0003o
YEZUojEJY@0=ojEJY@03o`000?nZEJ[oZUFZ00KoZUFZ0ol000001?ndBkCo0000oj]DZon[E:/3o`00
00co/dbc00Go0000ojIIY_nVFJKoYUVVo`000002oiA[U003o`000?nl@kco_4>l00_o_4>l00?o0000
ohiaS_n>LHh02On>LHh00ol0003oXebSoj=LX`06oj=LX`03o`000?o1?/7o`Ck100So`Ck10_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003obcC;ol/db`04ol/db`oo00003?nZEJX00ol0003oZeB[oj]DZ`04oj]D
Z`?o00002?ncC;<00ol0003oYUVVojIIYP02ojIIYP05o`000?nDJiCoU6^DoiA[U?l000003?nl@k`0
0ol0003oSW6>ohiaSP09ohiaSP03o`000?nSG:?oXebS00GoXebS3?l00002om`Sg0;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003obcC;ol/db`05ol/db`03o`000?nBKI;oTVfB00_oTVfB00?o0000ojYE
Z_nZEJX02_nZEJX00ol0003oZeB[oj]DZ`07oj]DZ`;o00001OncC;<00ol0003oYUVVojIIYP03ojII
YP03o`000?nDJiCoU6^D00;oU6^D00?o0000oka3_?nl@k`02Onl@k`00ol0003oSW6>ohiaSP0:ohia
SP03o`000?nSG:?oXebS00?oXebS00?o0000oi=/TonCK9<02OnCK9<00ol0003og2?Lom`Sg002om`S
g0;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003obcC;ol/db`06ol/db`03o`000?nBKI;oTVfB00[o
TVfB00?o0000ojYEZ_nZEJX02onZEJX00ol0003oZeB[oj]DZ`09oj]DZ`?o000000?o/dbco`000?nV
FJH01OnVFJH00ol0003oU6^DoiA[U003oiA[U003o`000?nl@kco_4>l00So_4>l3_l00003oj=LX`;o
00002onCK9<00ol0003og2?Lom`Sg005om`Sg003o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000ol/dboo;=</01Oo;=</00ol0003oWenOo`00000;oi9]TP03o`000?nZEJ[oZUFZ00[oZUFZ
0_l0000>oj]DZ`03o`000?nVFJKoYUVV00GoYUVV00?o0000oiA[U?nDJi@00onDJi@00ol0003o_4>l
oka3_008oka3_003o`000?n[E:_oZeB[00_oZeB[00?o0000oj=LXol000003OnCK9<00ol0003og2?L
om`Sg006om`Sg0;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00KobcC;00Co
0000oimOWonOGioo00002_nBKI800ol0003oZUFZojYEZP09ojYEZP03o`000?nWF:Oo000000koZeB[
00?o0000ojIIY_nVFJH01OnVFJH00ol0003oU6^DoiA[U004oiA[U003o`000?nl@kco_4>l00Ko_4>l
00?o0000oj]DZon[E:/03On[E:/00ol0003oTfbCoi=/T`0<oi=/T`03o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000oimOWonOGil00_nO
Gil00ol0003oTVfBoi9]TP06oi9]TP03o`000?nZEJ[oZUFZ00SoZUFZ0_l00003ojMHY`03o`000?n[
E:_oZeB[00_oZeB[00?o0000ojIIY_nVFJH01OnVFJH00ol0003oU6^DoiA[U005oiA[U003o`000?nl
@kco_4>l00Go_4>l00?o0000oj]DZon[E:/03On[E:/00ol0003oTfbCoi=/T`0;oi=/T`03o`000?oL
8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000
oimOWonOGil00onOGil00ol0003oTVfBoi9]TP05oi9]TP03o`000?nZEJ[oZUFZ00OoZUFZ00?o0000
ojMHYonWF:L00onWF:L00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?nVFJKoYUVV00KoYUVV00?o0000
oiA[U?nDJi@01_nDJi@00ol0003o_4>loka3_004oka3_003o`000?n[E:_oZeB[00goZeB[3ol0000;
om`Sg003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000oimOWonOGil01OnOGil00ol0
003oTVfBoi9]TP04oi9]TP03o`000?nZEJ[oZUFZ00GoZUFZ0_l00006ojMHY`03o`000?n[E:_oZeB[
00WoZeB[0_l00008ojIIYP03o`000?nDJiCoU6^D00KoU6^D1Ol000000onl@kco0000oj]DZ`0?oj]D
Z`03o`000?n>LHkoSW6>00_oSW6>00?o0000om`Sg?oL8m`02OoL8m`00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000oimOWonOGil01_nOGil00ol0003o
TVfBoi9]TP04o`0000KoZUFZ00?o0000ojMHYonWF:L01onWF:L00ol0003oZeB[oj]DZ`05oj]DZ`?o
000000?oW6>Lo`000?nVFJH01onVFJH00ol0003oU6^DoiA[U005oiA[U003o`000?nm@[go_D:m00?o
_D:m0_l0000?oj]DZ`;o00003On>LHh00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WobcC;00?o0000oimOWonOGil01onOGil2o`0000Co`Ck100Co0000ojYEZ_nZEJ[o
ZUFZ0_l0000:ojMHY`03o`000?n[E:_oZeB[00;oZeB[0ol00005oiaSW003o`000?nVFJKoYUVV00Go
YUVV00?o0000oiA[U?nDJi@01?nDJi@00ol0003o_D:moke2_@06oke2_@03o`000?n[E:_oZeB[00[o
ZeB[0_l00002ojUFZ@03o`000?n>LHkoSW6>00[oSW6>00?o0000om`Sg?oL8m`02?oL8m`00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000ol/dboo;=</01_o;=</00ol0003oWenOoimOW`08oimOW`03o`00
0?o1?/7o`Ck100Co`Ck100?o0000ojYEZ_l000003?nWF:L00ol0003oZeB[o`000002o`0000WoW6>L
00?o0000ojIIY_nVFJH01?nVFJH00ol0003oU6^DoiA[U003oiA[U003o`000?nm@[go_D:m00So_D:m
1_l00004oj]DZ`;o00001OnYEZT00ol0003oSW6>ohiaSP09ohiaSP03o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000oimOWonOGil01onO
Gil00ol0003o`Ck1ol4n`@06ol4n`@03o`000?nWF:OoYeRW00coYeRW00?o0000oiaSW?nLHi`02_nL
Hi`00ol0003oYUVVojIIYP04ojIIYP04o`000?nDJiCoU6^DoiA[U0;o00002onm@[d00ol0003o]TVf
okI9]P03okI9]PCo00002?nYEZT00ol0003oSW6>ohiaSP08ohiaSP03o`000?oL8mcog2?L00Oog2?L
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000ol/dboo;=</00oo;=</00ol0003oWenOoimOW`07oimOW`03o`000?o1
?/7o`Ck100Oo`Ck100?o0000ojMHYonWF:L03?nWF:L00ol0003oW6>LoiaSW00;oiaSW003o`000?nV
FJKoYUVV00?oYUVV00Co0000oiA[U?nDJiCo00003Onm@[d00ol0003o]TVfokI9]P06okI9]P03o`00
0?nYEZWoZEJY00OoZEJY00?o0000ohiaS_n>LHh01on>LHh00ol0003og2?Lom`Sg006om`Sg004o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00;obcC;00?o0000oimOWonOGil0
1_nOGil00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nWF:OoYeRW00WoYeRW0_l0000>oiaSW0?o0000
0onVFJH00ol0003oU6^Do`00000=oke2_@03o`000?nfBKKo]TVf00Oo]TVf00?o0000ojUFZOnYEZT0
2?nYEZT:o`0000Kog2?L0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoWenO00?o
0000ol4n`Oo1?/402_o1?/400ol0003oYeRWojMHY`06ojMHY`;o000000?oZ5NXo`000?nLHi`02onL
Hi`2o`0000?o_D:m1Ol0000>oke2_@03o`000?nfBKKo]TVf00Oo]TVf00?o0000ojUFZOnYEZT02?nY
EZT00ol0003oYUVVojIIYP06ojIIYP03o`000?oL8mcog2?L00?og2?L00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oc3?<ol`cc003ol`cc0Co00000_nOGil00ol0003o`Ck1ol4n`@0;
ol4n`@03o`000?nWF:OoYeRW00?oYeRW0ol00004ojQGZ003o`000?nLHicoW6>L00OoW6>L0_l00008
oke2_@03o`000?nm@[go_D:m00go_D:m00?o0000okI9]_nfBKH02?nfBKH00ol0003oZEJYojUFZ@07
ojUFZ@03o`000?nVFJKoYUVV00OoYUVV0ol000000ooL8mco0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o<<lcoc3?<00Ooc3?<0_l0000?ol4n`@03o`000?nWF:OoYeRW00;o00002?nXEjP00ol0
003oW6>LoiaSW005oiaSW003o`000?nm@[go_D:m00So_D:m00?o0000oke2_Onm@[d03Onm@[d00ol0
003o]TVfokI9]P08okI9]P03o`000?nYEZWoZEJY00KoZEJY00?o0000ojIIY_nVFJH02?nVFJH01?l0
003ofRGJomXUf_l0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oc3?<ol`cc009ol`c
c003o`000?o1?/7o`Ck100ko`Ck10_l0000;ojQGZ003o`000?nLHicoW6>L00;oW6>L0_l0000;oke2
_@03o`000?nm@[go_D:m00go_D:m00?o0000okI9]_nfBKH02?nfBKH00ol0003oZEJYojUFZ@06ojUF
Z@03o`000?nVFJKoYUVV00OoYUVV00Go0000omXUf_oJ9M[ofRGJo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oc3?<ol`cc00:ol`cc003o`000?o1?/7o`Ck100go`Ck10_l0000<ojQGZ004o`000?nLHico0000
o`0000go_D:m00?o0000oke2_Onm@[d03?nm@[d00ol0003o]TVfokI9]P09okI9]P03o`000?nYEZWo
ZEJY00KoZEJY00?o0000ojIIY_nVFJH01_nVFJH00ol0003ofRGJomXUfP03omXUfP03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oc3?<ol`cc00:ol`cc003o`000?o1?/7o`Ck100co`Ck100Co0000oh1o
P?n0Oh3o00003?nXEjP00ol0003o_D:moke2_@0>oke2_@03o`000?nm@[go_D:m00So_D:m1?l0000;
okI9]P03o`000?nYEZWoZEJY00KoZEJY00?o0000ojIIY_nVFJH01OnVFJH00ol0003ofRGJomXUfP04
omXUfP03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oc3?<ol`cc00;ol`cc003o`000?o1?/7o`Ck1
00_o`Ck100?o0000oh1oP?n0Oh000_n0Oh000ol0003oZ5NXojQGZ009ojQGZ003o`000?nm@[go_D:m
00ko_D:m00Co0000oke2_Onm@[go_D:m1ol00003oki1_P03o`000?nfBKKo]TVf00Wo]TVf00?o0000
ojUFZOnYEZT01_nYEZT00ol0003oYUVVojIIYP04ojIIYP03o`000?oJ9M[ofRGJ00KofRGJ00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o<<lcoc3?<00coc3?<00?o0000ol4n`Oo1?/402_o1?/400ol0
003oP7n0oh1oP003oh1oP003o`000?nXEjSoZ5NX00SoZ5NX00?o0000oke2_Onm@[d03_nm@[d4o`00
00_o_T6n00?o0000okI9]_nfBKH02?nfBKH00ol0003oZEJYojUFZ@05ojUFZ@03o`000?nVFJKoYUVV
00GoYUVV00?o0000omXUf_oJ9MX01_oJ9MX00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol`cc?o<
<l`03?o<<l`7o`0000Go`Ck100?o0000oh1oP?n0Oh001On0Oh000ol0003oZ5NXojQGZ007ojQGZ003
o`000?nm@[go_D:m00ko_D:m00?o0000oki1__nn@Kh03Onn@Kh00ol0003o]TVfokI9]P08okI9]P03
o`000?nYEZWoZEJY00CoZEJY00?o0000ojIIY_nVFJH01?nVFJH00ol0003ofRGJomXUfP07omXUfP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oc3?<ol`cc00=ol`cc003o`000?no@;oo_d2o00Co_d2o
1Ol00009oh1oP003o`000?nXEjSoZ5NX00KoZ5NX00?o0000oke2_Onm@[d03_nm@[d00ol0003o_T6n
oki1_P0=oki1_P03o`000?nfBKKo]TVf00So]TVf00Co0000ojUFZOnYEZWoZEJY1Ol00004ojIIYP03
o`000?oJ9M[ofRGJ00WofRGJ1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=ol`cc003o`000?no@;oo_d2o00Wo_d2o
0_l00009oh1oP003o`000?nXEjSoZ5NX00KoZ5NX00?o0000oke2_Onm@[d03?nm@[d00ol0003o_T6n
oki1_P0?oki1_PKo00001?nfBKH4o`0000Go`Sg20_l000000onVFJKo0000omXUfP0;omXUfP04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oE:]GoeB[EomDZe@?o00002_o<<l`00ol0003o
_d2ookm0_`09okm0_`03o`000?n>LHko000000;o00001on0Oh000ol0003oZ5NXojQGZ005ojQGZ003
o`000?nm@[go_D:m00So_D:m1Ol0000Aoki1_P03o`000?nhAkSo^4Nh00?o^4Nh1?l0000;ol8m`P03
o`000?oJ9M[ofRGJ00[ofRGJ00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omDZeOoE:]D01OoE:]D2o`0000Ooc3?<
00?o0000okm0_ono@;l02_no@;l00ol0003oSW6>ohiaSP02ohiaSP?o00001On0Oh000ol0003oZ5NX
ojQGZ004ojQGZ004o`000?nm@[go_D:moke2_@Oo00001?n^DJh00ol0003o_T6noki1_P0>oki1_P03
o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ol8m`_o2?L802Oo2?L800ol0003ofRGJomXUfP09omXUfP03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oeB[EomDZe@08omDZe@;o00001?o<<l`00ol0003o_d2o
okm0_`0;okm0_`03o`000?n>LHkoSW6>00GoSW6>0ol00003oh1oP004o`000?nXEjSoZ5NXojQGZ0Ko
00003?n^DJh00ol0003o_T6noki1_P0=oki1_P03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ol8m`_o2
?L802_o2?L800ol0003ofRGJomXUfP08omXUfP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omDZe@?o000000?oc3?<o`000?no@;l0
3?no@;l00ol0003oSW6>ohiaSP08ohiaSP?o000000CoP7n0o`000?l0003o00000_no@;l00ol0003o
[U6^ojiA[P0=ojiA[P03o`000?nn@Kko_T6n00co_T6n00?o0000okQ7^?nhAkP02?nhAkP00ol0003o
`Sg2ol8m`P0;ol8m`P03o`000?oJ9M[ofRGJ00KofRGJ00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
eB[E00?o0000okm0_ono@;l03?no@;l00ol0003oSW6>ohiaSP0;ohiaSP03o`000?no@;oo_d2o00?o
_d2o00?o0000ojiA[_n^DJh03?n^DJh00ol0003oVVFJo`00000=oki1_P03o`000?nhAkSo^4Nh00So
^4Nh00?o0000ol8m`_o2?L803?o2?L83o`0000GofRGJ00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oE:]GoeB[E00coeB[E00?o0000okm0_ono@;l03?no@;l00ol0003oSW6>ohiaSP0:ohiaSP03o`00
0?no@;oo_d2o00Go_d2o00?o0000ojiA[_n^DJh02_n^DJh01?l0003oVVFJoiYUV_nJIIX2o`0000[o
_T6n00?o0000okQ7^?nhAkP02OnhAkP00ol0003o`Sg2ol8m`P0<ol8m`P03o`000?oQ7^7ohAkQ00?o
000000?ofRGJo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oE:]GoeB[E00_oeB[E00?o0000okm0_ono@;l0
3?no@;l00ol0003oSW6>ohiaSP09ohiaSP03o`000?no@;oo_d2o00Ko_d2o00?o0000ojiA[_n^DJh0
2On^DJh00ol0003oVVFJoiYUVP02oiYUVP03o`000?nl@kco000000;o00001onn@Kh00ol0003o^4Nh
okQ7^009okQ7^003o`000?o2?L;o`Sg200_o`Sg200?o0000on4NhOoQ7^401?oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omDZeOoE:]D02ooE:]D00ol0003o_d2ookm0_`0;okm0_`03o`000?n>
LHkoSW6>00SoSW6>00?o0000okm0_ono@;l01ono@;l00ol0003o[U6^ojiA[P08ojiA[P03o`000?nJ
II[oVVFJ00?oVVFJ00?o0000oka3_?nl@k`00_nl@k`2o`0000Co_T6n00?o0000okQ7^?nhAkP02_nh
AkP00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?oQ7^7ohAkQ00GohAkQ00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oE:]GoeB[E00[oeB[E0ol0000;okm0_`Ko00001?n>LHh00ol0003o_d2ookm0_`08
okm0_`03o`000?n^DJko[U6^00Oo[U6^00?o0000oiYUV_nJIIX00onJIIX00ol0003o_4>loka3_005
oka3_0?o000000?o_T6no`000?nhAkP02onhAkP00ol0003o`Sg2ol8m`P09ol8m`P03o`000?oQ7^7o
hAkQ00OohAkQ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oE:]GoeB[E00WoeB[E00?o0000ojaC
[?n/Dj`01?l00006okm0_`03o`000?niA[Wo^DJi00Co^DJi1?l0000<okm0_`03o`000?n^DJko[U6^
00Go[U6^00?o0000oiYUV_nJIIX01?nJIIX00ol0003o_4>loka3_008oka3_003o`000?nhAkSo^4Nh
00_o^4Nh00?o0000ol8m`_o2?L802?o2?L800ol0003ohAkQon4Nh@08on4Nh@Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oE:]GoeB[E00OoeB[E00?o0000ojaC[?n/Dj`01On/Dj`3o`0000;o_d2o00?o0000okU6^Oni
A[T02?niA[T00ol0003o_d2ookm0_`0:okm0_`03o`000?n^DJko[U6^00Co[U6^00?o0000oiYUV_nJ
IIX01OnJIIX00ol0003o_4>loka3_008oka3_003o`000?nhAkSo^4Nh00Wo^4Nh1?l00008ol8m`P03
o`000?oQ7^7ohAkQ00WohAkQ00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeB[E
omDZe@05omDZe@03o`000?n/Djco[5>/00Wo[5>/0_l0000<okU6^@03o`000?no@;oo_d2o00Wo_d2o
00?o0000ojiA[_n^DJh00on^DJh00ol0003oVVFJoiYUVP05oiYUVP03o`000?nl@kco_4>l00[o_4>l
00?o0000okQ7^?nhAkP01?nhAkP4o`0000Co_D:m00?o0000ol8m`_o2?L801?o2?L800ol0003ohAkQ
on4Nh@0:on4Nh@03o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000ojaC[?n/Dj`02on/
Dj`00ol0003o^DJiokU6^@0:okU6^@03o`000?no@;oo_d2o00Wo_d2o00?o0000ojiA[_n^DJh00_n^
DJh00ol0003oVVFJoiYUVP06oiYUVP03o`000?nl@kco_4>l00[o_4>l00?o0000okQ7^?nhAkP01?l0
0009oke2_@Ko00003?oQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omDZeOoE:]GoeB[E0_l0
000=ojaC[003o`000?niA[Wo^DJi00[o^DJi00?o0000okm0_ono@;l02Ono@;l01Ol0003o[U6^ojiA
[_n^DJko000000WoVVFJ00?o0000oka3_?nl@k`02onl@k`2o`0000go_D:m00?o0000omTVfOoI9]T0
0_oI9]T00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oeB[Eo`00
0002om4^d@;o00002on/Dj`00ol0003o^DJiokU6^@0;okU6^@03o`000?no@;oo_d2o00Wo_d2o00?o
0000ojiA[_l000002OnJIIX00ol0003o_4>loka3_00<oka3_003o`000?nm@[go_D:m00co_D:m00?o
0000omTVfOoI9]T00ooI9]T00ol0003ohAkQon4Nh@09on4Nh@03o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003odBkAom4^d@03om4^d@;o00002_n/Dj`00ol0003o^DJiokU6^@0:okU6^@03o`000?no@;oo
_d2o00So_d2o1Ol00008oiYUVP03o`000?nl@kco_4>l00co_4>l00?o0000oke2_Onm@[d02onm@[d0
0ol0003ofBKIomTVf@05omTVf@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooA;]42o`0000So[5>/00?o0000okU6^OniA[T02_niA[T00ol0003o_d2ookm0_`07okm0
_`03o`000?naC[7o/Dja00?o/Dja0ol00005oiYUVP03o`000?nl@kco_4>l00_o_4>l00?o0000oke2
_Onm@[d03?nm@[d00ol0003ofBKIomTVf@06omTVf@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000WodBkA00?o0000ojaC[?n/Dj`01On/Dj`2o`0000co
^DJi00?o0000okm0_ono@;l01Ono@;l00ol0003o/Djaok5>/@07ok5>/@?o000000?oVVFJo`000?nl
@k`03Onl@k`00ol0003o_D:moke2_@0<oke2_@03o`000?oI9]WofBKI00KofBKI00?o0000on4NhOoQ
7^401_oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?oA;]7odBkA00OodBkA
0_l00004ojaC[003o`000?n^DJko[U6^00;o00002_niA[T00ol0003o_d2ookm0_`03okm0_`;o0000
3OnaC[42o`0000go_4>l0ol0000=oke2_@03o`000?oI9]WofBKI00OofBKI00?o0000on4NhOoQ7^40
1OoQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?oA;]7odBkA00SodBkA0_l0
00000on/Djco0000ojiA[P04ojiA[P03o`000?niA[Wo^DJi00Oo^DJi00Co0000okm0_ono@;oo_d2o
0_l00002ojm@[`03o`000?naC[7o/Dja00co/Dja3Ol00003oimPW`03o`000?nm@[go_D:m00[o_D:m
00?o0000omTVfOoI9]T02?oI9]T01?l0003ohAkQon4NhOoQ7^44o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003odBkA
om4^d@09om4^d@03o`000?n^DJko[U6^00Go[U6^0_l00008okU6^@03o`000?no@;oo000000Go[e2_
00?o0000ok5>/OnaC[402onaC[400ol0003o[e2_ojm@[`09ojm@[`03o`000?nOH9ooWf2O00;oWf2O
0_l00009oke2_@03o`000?oI9]WofBKI00[ofBKI0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?oA;]7odBkA00SodBkA00?o0000ojiA[_n^DJh01on^DJh4o`0000?o^DJi0ol0
0007ojm@[`03o`000?naC[7o/Dja00[o/Dja00?o0000ojm@[on_D:l02On_D:l00ol0003oWf2OoimP
W`04oimPW`;o00001onm@[d00ol0003ofBKIomTVf@0:omTVf@03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00OodBkA00?o0000ojiA[_n^DJh02?n^DJh0
1?l0003o/Djaok5>/OnaC[43o`0000;o[e2_00?o0000ojm@[on_D:l01_n_D:l00ol0003o/Djaok5>
/@08ok5>/@03o`000?n_D:oo[e2_00[o[e2_00?o0000oimPWonOH9l01_nOH9l00ol0003o_D:moke2
_@04oke2_@03o`000?oI9]WofBKI00WofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om4^dOoA;]401OoA;]400ol0003o[U6^ojiA[P08ojiA[P03o`000?naC[7o
/Dja00Co/Dja00Go0000ojm@[on_D:oo[e2_o`000008ojm@[`03o`000?naC[7o/Dja00Oo/Dja00?o
0000ojm@[on_D:l02_n_D:l00ol0003oWf2OoimPW`07oimPW`;o00001?nm@[d00ol0003ofBKIomTV
f@08omTVf@03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]400ooA;]40
0ol0003o[U6^ojiA[P08ojiA[P03o`000?naC[7o/Dja00Co/Dja00?o0000ojm@[on_D:l00_n_D:l0
0ol0003o[e2_ojm@[`07ojm@[`03o`000?naC[7o/Dja00Ko/Dja00?o0000ojm@[on_D:l02_n_D:l0
0ol0003oWf2OoimPW`09oimPW`05o`000?nm@[go_D:moke2_Ol000002OoI9]T00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_o[U6^00?o0000ok5>/OnaC[401?naC[400ol0003o[e2_ojm@[`03
ojm@[`03o`000?n_D:oo[e2_00Oo[e2_00?o0000ok5>/OnaC[401OnaC[400ol0003o[e2_ojm@[`0:
ojm@[`03o`000?nOH9ooWf2O00WoWf2O1?l00009omTVf@03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oO8=oogb3O
omlPgol000002_n^DJh00ol0003o/Djaok5>/@05ok5>/@03o`000?n_D:oo[e2_00?o[e2_00?o0000
ojm@[on_D:l02?n_D:l00ol0003o/Djaok5>/@04ok5>/@03o`000?n_D:oo[e2_00Wo[e2_00?o0000
oimPWonOH9l02?nOH9l2o`0000?oeRWF00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000omlPgooO8=l00ooO8=l00ol0003o[U6^ojiA[P06ojiA[P03o`000?naC[7o/Dja
00Go/Dja00?o0000ojm@[on_D:l01?n_D:l00ol0003o[e2_ojm@[`09ojm@[`03o`000?naC[7o/Dja
00;o/Dja00?o0000ojm@[on_D:l02_n_D:l00ol0003oWf2OoimPW`06oimPW`;o00001_oF:MH8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ogb3OomlPg`05omlPg`03o`000?n^DJko[U6^00Go[U6^00?o0000ok5>/Ona
C[401OnaC[400ol0003o[e2_ojm@[`05ojm@[`03o`000?n_D:oo[e2_00Wo[e2_00Go0000ok5>/Ona
C[7o/Djao`00000<ojm@[`03o`000?nOH9ooWf2O00CoWf2O0_l00008omHYeP03o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oO8=oogb3O00Oogb3O00?o0000ojiA[_n^
DJh00on^DJh00ol0003o/Djaok5>/@06ok5>/@03o`000?n_D:oo[e2_00Go[e2_00?o0000ojm@[on_
D:l02_n_D:l00ol0003o/Djao`000004o`0000Wo[e2_00?o0000oimPWonOH9l00_nOH9l2o`0000[o
eRWF00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ogb3OomlPg`07omlPg`03o`00
0?n^DJko[U6^00;o[U6^00?o0000ok5>/OnaC[401_naC[400ol0003o[e2_ojm@[`07ojm@[`;o0000
2on_D:l00ol0003o]TVfokI9]P03okI9]POo00000_n_D:l00ol0003oWf2OoimPW`02o`0000_oeRWF
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omlPgooO8=l02OoO
8=l01Ol0003o[U6^ojiA[_n^DJko000000So/Dja00?o0000ojm@[on_D:l01on_D:l00ol0003obcC;
o`000002o`0000So[e2_00?o0000okI9]_nfBKH02_nfBKH5o`0000goeRWF00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<omlPg`03o`000?n^DJko000000Wo/Dja00?o
0000ojm@[on_D:l01_n_D:l00ol0003obcC;ol/db`03ol/db`?o00001?n_D:l00ol0003o]TVfokI9
]P0=okI9]P03o`000?oF:MKoeRWF00goeRWF00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ooj1OX2o`0000_ogb3O00?o0000ok5>/OnaC[401onaC[400ol0003o[e2_ojm@[`07
ojm@[`03o`000?o;=<_obcC;00KobcC;0ol000000on_D:oo0000okI9]P0>okI9]P03o`000?oF:MKo
eRWF00coeRWF00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00KonPGj0_l00009omlP
g`03o`000?naC[7o/Dja00;o/Dja1_l00008ojm@[`03o`000?o;=<_obcC;00[obcC;00?o0000okI9
]_nfBKH03onfBKH00ol0003oeRWFomHYeP0:omHYeP;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00So
nPGj0_l00007omlPg`Go00001_oQ7^400ol0003o[e2_ojm@[`05ojm@[`03o`000?o;=<_obcC;00[o
bcC;00?o0000okI9]_nfBKH03onfBKH00ol0003oeRWFomHYeP07omHYeP?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oj1O[onPGj00[onPGj0_l00005omlPg`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000ojm@[on_
D:l00on_D:l00ol0003obcC;ol/db`0;ol/db`03o`000?nfBKKo]TVf00oo]TVf00?o0000omHYe_oF
:MH01OoF:MH2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5nP0<ooX5nP;o000000?ogb3Oo`000?l00000
3OoQ7^400ol0003o[e2_ojm@[`02ojm@[`03o`000?o;=<_obcC;00_obcC;5?l00004omHYeP;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooX5n_oj1OX03_oj1OX00ol0003onPGjo`00000>on4Nh@04o`000?n_D:oo[e2_o`0000kobcC;
00?o0000on<LhooS7><04?oS7><00ol0003oeRWFo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003onPGjooX5
nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000003_oQ7^400ol0003o[e2_o`00000>ol/db`03o`00
0?oS7>?ohacS017ohacS00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oj1O[onPGj00conPGj00?o
0000ooX5n_oj1OX00_oj1OX00ol0003ohAkQon4Nh@0=on4Nh@03o`000?o;=<_obcC;00WobcC;1Ol0
000Bon<Lh`;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003ohAkQon4Nh@0<on4Nh@03o`000?o;=<_obcC;00;obcC;1ol00004ooX5nP03o`000?oS7>?o
hacS00oohacS00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003onPGjooX5nP06ooX5
nP03o`000?oQ7^7ohAkQ00cohAkQ1?l0000<ooX5nP03o`000?oS7>?ohacS00cohacS0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00Oo
nPGj00?o0000on4NhOoQ7^403?oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?oS7>?ohacS00_o
hacS00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00konPGj00?o0000on<LhooS
7><02OoS7><2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000on4NhOoQ7^402_oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?oS7>?ohacS00KohacS0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooX5n_l0003onPGj00gonPGj3?l0
000AooX5nP?o00001_oS7><00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooS7><2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000on<Lhol000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool02?l00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0008o`00o`;oool00ol00?l2oooo00Go003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Ko003o0_ooo`1]o`00o`7ooooo001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04
o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`001ol00?l2
oooo00Go003o00?oool0o`00ool00?l00_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1
ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00Oo003o0_ooo`05o`00o`;oool00ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06go003o0Oooool0077o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`001_l00?l2oooo00Ko
003o0_ooo`03o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06go
003o0Oooool0077o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
KOl00?l1ooooo`00L?l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
1_l00?l2oooo00Go003o0oooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`06o`00o`?oool0
0ol00?l3oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`001_l00?l2oooo0003o`00oooo
o`3oool000?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool01ol00?l00oooo`3o003oo`00o`08o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1]o`00o`7ooooo001_o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00Oo003o0_ooo`09o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00
o`7ooooo001^o`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00So
003o00?oool0o`00ool00?l01ol00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06go
003o0Oooool006ko003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`08o`00o`;oool0
2Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_oo
o`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`06o`00o`;oool02?l0
0?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?ooo`3oool006go003o0Oooool006go003o0oooo`05
o`00o`?oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`Goool02?l00?l2oooo00Oo003o0_ooo`02
o`00o`;oool01Ol00?l5oooo06go003o0Oooool006co003o1_ooo`000ol00?ooool0oooo0005oooo
00?o003o1Oooo`0Uo`00o`?oool01Ol00?l4oooo07So003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(70) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.98 .02 .98 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.98 .02 .98 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.98 .02 .98 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.979 .021 .979 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.847 .153 .847 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.979 .021 .979 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.838 .162 .838 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.886 .114 .886 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.838 .162 .838 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.77 .23 .77 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.98 .02 .98 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.753 .247 .753 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.711 .289 .711 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.981 .019 .981 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.728 .272 .728 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.739 .261 .739 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.977 .023 .977 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.978 .022 .978 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.823 .177 .823 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.675 .325 .675 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.505 .495 .505 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.574 .426 .574 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.572 .428 .572 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.6 .4 .6 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.822 .178 .822 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.834 .166 .834 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.98 .02 .98 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.606 .394 .606 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.736 .264 .736 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.576 .424 .576 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.794 .206 .794 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.786 .214 .786 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.98 .02 .98 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.748 .252 .748 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.703 .297 .703 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.782 .218 .782 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.81 .19 .81 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.589 .411 .589 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.981 .019 .981 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.869 .131 .869 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.674 .326 .674 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.69 .31 .69 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.655 .345 .655 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.825 .175 .825 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.877 .123 .877 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.649 .351 .649 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.98 .02 .98 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.609 .391 .609 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.528 .472 .528 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.759 .241 .759 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.778 .222 .778 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.599 .401 .599 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.608 .392 .608 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.718 .282 .718 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.98 .02 .98 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.755 .245 .755 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.721 .279 .721 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.847 .153 .847 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.309 .691 .309 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.666 .334 .666 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.733 .267 .733 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.761 .239 .761 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.53 .47 .53 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.459 .541 .459 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.45 .55 .45 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.504 .496 .504 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.726 .274 .726 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.517 .483 .517 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.622 .378 .622 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.678 .322 .678 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.693 .307 .693 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.713 .287 .713 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.688 .312 .688 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.88 .12 .88 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.98 .02 .98 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.531 .469 .531 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.608 .392 .608 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.502 .498 .502 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.979 .021 .979 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.762 .238 .762 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.662 .338 .662 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.443 .557 .443 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.531 .469 .531 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.716 .284 .716 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.611 .389 .611 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.837 .163 .837 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.688 .312 .688 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.46 .54 .46 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.657 .343 .657 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.631 .369 .631 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.584 .416 .584 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.712 .288 .712 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.826 .174 .826 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.725 .275 .725 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.476 .524 .476 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.582 .418 .582 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.72 .28 .72 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.618 .382 .618 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.622 .378 .622 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.792 .208 .792 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.605 .395 .605 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.558 .442 .558 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.518 .482 .518 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.979 .021 .979 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.528 .472 .528 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.657 .343 .657 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.558 .442 .558 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.648 .352 .648 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.703 .297 .703 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.979 .021 .979 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.726 .274 .726 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.671 .329 .671 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.689 .311 .689 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.721 .279 .721 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.623 .377 .623 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.584 .416 .584 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.636 .364 .636 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.651 .349 .651 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.98 .02 .98 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.789 .211 .789 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.694 .306 .694 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.771 .229 .771 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.549 .451 .549 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.82 .18 .82 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.437 .563 .437 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.6 .4 .6 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.597 .403 .597 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.722 .278 .722 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.789 .211 .789 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.524 .476 .524 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.979 .021 .979 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.651 .349 .651 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.691 .309 .691 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.893 .107 .893 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.7 .3 .7 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.643 .357 .643 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.684 .316 .684 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.838 .162 .838 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.535 .465 .535 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.64 .36 .64 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.701 .299 .701 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.843 .157 .843 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.528 .472 .528 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.633 .367 .633 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.696 .304 .696 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.709 .291 .709 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.98 .02 .98 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.579 .421 .579 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.979 .021 .979 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.862 .138 .862 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.75 .25 .75 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.711 .289 .711 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.615 .385 .615 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.59 .41 .59 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.639 .361 .639 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.839 .161 .839 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.738 .262 .738 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.757 .243 .757 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.759 .241 .759 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.682 .318 .682 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.851 .149 .851 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.672 .328 .672 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.616 .384 .616 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.487 .513 .487 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.498 .502 .498 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.627 .373 .627 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.715 .285 .715 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.979 .021 .979 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.851 .149 .851 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.653 .347 .653 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.48 .52 .48 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.724 .276 .724 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.788 .212 .788 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.622 .378 .622 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.979 .021 .979 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.592 .408 .592 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.742 .258 .742 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.85 .15 .85 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.979 .021 .979 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.625 .375 .625 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.664 .336 .664 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.854 .146 .854 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.692 .308 .692 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.619 .381 .619 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.864 .136 .864 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.615 .385 .615 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.782 .218 .782 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.745 .255 .745 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.547 .453 .547 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.524 .476 .524 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.63 .37 .63 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.673 .327 .673 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.882 .118 .882 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.752 .248 .752 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.76 .24 .76 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.728 .272 .728 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.845 .155 .845 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.642 .358 .642 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.979 .021 .979 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.856 .144 .856 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.798 .202 .798 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.863 .137 .863 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.681 .319 .681 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.86 .14 .86 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.762 .238 .762 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.703 .297 .703 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.98 .02 .98 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.718 .282 .718 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.714 .286 .714 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.98 .02 .98 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.852 .148 .852 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.977 .023 .977 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.98 .02 .98 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.816 .184 .816 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.979 .021 .979 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.699 .301 .699 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.98 .02 .98 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.559 .441 .559 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.723 .277 .723 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.622 .378 .622 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.866 .134 .866 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.861 .139 .861 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.749 .251 .749 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.801 .199 .801 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.755 .245 .755 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.811 .189 .811 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.846 .154 .846 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.761 .239 .761 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.761 .239 .761 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.978 .022 .978 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.691 .309 .691 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.832 .168 .832 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.979 .021 .979 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.875 .125 .875 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.884 .116 .884 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.686 .314 .686 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.861 .139 .861 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.87 .13 .87 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.599 .401 .599 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.981 .019 .981 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.846 .154 .846 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.98 .02 .98 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.979 .021 .979 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.98 .02 .98 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.979 .021 .979 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.979 .021 .979 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ofBKIomTVfOl0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000omTVfOoI9]T00_oI9]T00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oI9]WofBKI00?ofBKI00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000omTVfOoI9]T01OoI9]T00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofBKIomTVf@06omTVf@03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oF:MKo0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cofBKI00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omHYeP03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003og2?Lom`Sg005om`Sg003o`000?oI
9]WofBKI00_ofBKI0ol00003omXUfP03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omHYe_oF:MH00ooF:MH00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003og2?Lom`Sg006
om`Sg003o`000?oI9]WofBKI00[ofBKI00?o0000omXUf_oJ9MX01?oJ9MX00ol0003onPGjooX5nP0:
ooX5nP04o`000?oL8mcog2?Lom`Sg0;o00002_oj1OX2o`000003om`Sg?l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeRWFomHYeP05omHYeP03o`000?oj1O[o
nPGj00WonPGj00?o0000om4^dOl000002ooj1OX00ol0003og2?Lom`Sg006om`Sg003o`000?oI9]Wo
fBKI00WofBKI00?o0000omXUf_oJ9MX01_oJ9MX00ol0003onPGjooX5nP08ooX5nP03o`000?oL8mco
g2?L00Cog2?L0_l00005ooX5nP?o00001?oL8m`00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omHYeP03o`000?oj1O[onPGj00OonPGj0_l00003om4^
d@03o`000?oj1O[onPGj00OonPGj00?o0000om`Sg?oL8m`01ooL8m`00ol0003ofBKIomTVf@09omTV
f@03o`000?oJ9M[ofRGJ00OofRGJ00?o0000ooX5n_oj1OX01Ooj1OX2o`0000Wog2?L0_l000000ooj
1O[o0000o`000007om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omHYe_oF
:MH02?oF:MH00ol0003onPGjooX5nP06ooX5nP03o`000?oA;]7odBkA00?odBkA00?o0000ooX5n_oj
1OX01ooj1OX00ol0003og2?Lom`Sg008om`Sg003o`000?oI9]WofBKI00OofBKI00?o0000omXUf_oJ
9MX02OoJ9MX00ol0003onPGjooX5nP03ooX5nP03o`000?oL8mcog2?L00_og2?L00?o0000om`Sg?oL
8m`01ooL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHo`000005ooX5nP;o00002ooF:MH2o`0000KonPGj
00?o0000om4^dOoA;]401OoA;]400ol0003onPGjooX5nP06ooX5nP03o`000?oL8mcog2?L00Sog2?L
00?o0000omTVfOoI9]T01_oI9]T00ol0003ofRGJomXUfP0;omXUfP05o`000?oj1O[onPGjooX5n_l0
00003_oL8m`00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oH9mSof2OHomPWf?l0
00000ooj1OX00ol0003oeRWFomHYeP0:omHYeP04o`000?oC;=?odbcCo`0000?onPGj0_l00008om4^
d@03o`000?oj1O[onPGj00KonPGj00?o0000om`Sg?oL8m`02OoL8m`00ol0003ofBKIomTVf@05omTV
f@03o`000?oJ9M[ofRGJ00cofRGJ00?o0000ooX5n_l000003ooL8m`00ol0003og2?Lom`Sg008om`S
g003o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPWf003omPWf003o`000?oj1O[o000000_o
eRWF0_l00004om</d`03o`000?oj1O[o000000_odBkA00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
g2?Lom`Sg009om`Sg003o`000?oI9]WofBKI00CofBKI00?o0000omXUf_oJ9MX03_oJ9MX00ol0003o
g2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omPWf?oH9mP0
1?oH9mP00ol0003oeRWFomHYeP09omHYeP03o`000?oC;=?odbcC00GodbcC00?o0000om4^dOoA;]40
2_oA;]400ol0003onPGjooX5nP05ooX5nP03o`000?oL8mcog2?L00[og2?L00?o0000omTVfOoI9]T0
0ooI9]T00ol0003ofRGJomXUfP0>omXUfP03o`000?oL8mcog2?L00gog2?L00?o0000om`Sg?oL8m`0
2_oL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPW
f005omPWf003o`000?oF:MKoeRWF00OoeRWF0_l00008om</d`03o`000?oA;]7odBkA00_odBkA00?o
0000ooX5n_oj1OX01?oj1OX00ol0003og2?Lom`Sg00:om`Sg004o`000?oI9]WofBKIomTVf@?o0000
3ooJ9MX00ol0003og2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oj1OX00ol0003onPGjooX5
nP09ooX5nP03o`000?oH9mSof2OH00Oof2OH00?o0000omHYe_oF:MH01?oF:MH2o`0000_odbcC1?l0
0009om4^d@03o`000?oj1O[onPGj00?onPGj00?o0000om`Sg?oL8m`02ooL8m`01?l0003ofBKIo`00
0?l00003olTfb@;o00003?oJ9MX2o`00013og2?L00?o0000om`Sg?oL8m`02ooL8m`00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX02?oj1OX00ol0003of2OH
omPWf007omPWf003o`000?oF:MKoeRWF00?oeRWF00?o0000om</dooC;=<02ooC;=<01?l0003obCK9
olTfbOo9=/T5o`0000GodBkA00?o0000ooX5n_oj1OX00_oj1OX00ol0003og2?Lom`Sg00<om`Sg003
o`000?o9=/WobCK900GobCK90_l00008omXUfP;o00000_o0?l000ol0003og2?Lom`Sg00=om`Sg003
o`000?oL8mcog2?L00_og2?L00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[onPGj
00?o0000ooX5n_oj1OX01ooj1OX00ol0003of2OHomPWf009omPWf003o`000?oF:MKoeRWF00;o0000
3OoC;=<00ol0003obCK9olTfb@07olTfb@Ko00000_oj1OX4o`0000gog2?L00?o0000olTfbOo9=/T0
1oo9=/T2o`0000GofRGJ00?o0000ol0o`?o0?l000oo0?l000ol0003og2?Lom`Sg00<om`Sg003o`00
0?oL8mcog2?L00cog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?oH9mSof2OH00Wof2OH00?o
0000omHYe_l000003ooC;=<00ol0003obCK9olTfb@0<olTfb@?o00001?oF:MH3o`0000Wog2?L00?o
0000olTfbOo9=/T02_o9=/T2o`000003omXUf_l0003o000000Oo`3o000?o0000om`Sg?oL8m`02ooL
8m`00ol0003og2?Lom`Sg00<om`Sg003o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oH9mSof2OH00_of2OH00?o0000
om</dooC;=<03_oC;=<00ol0003obCK9olTfb@0=olTfb@03o`000?oF:MKoeRWF00KoeRWF0ol00005
om`Sg003o`000?o9=/WobCK900gobCK900?o0000ol0o`?o0?l002?o0?l000ol0003og2?Lom`Sg009
om`Sg003o`000?oL8mcog2?L00gog2?L00Co0000ooX5n_oj1O[onPGj1Ol00003on8MhP03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00?onPGj00?o0000
omPWf?oH9mP02ooH9mP2o`0000oodbcC00?o0000olTfbOo9=/T03Oo9=/T00ol0003oeRWFomHYeP0:
omHYeP?o000000?og2?Lo`000?o9=/T03oo9=/T00ol0003o`3o0ol0o`009ol0o`003o`000?oL8mco
g2?L00Sog2?L00?o0000om`Sg?oL8m`03_oL8m`3o`0000SohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oj1O[onPGj00[onPGj0_l00003ooX5nP03o`000?oH9mSof2OH00Sof2OH0ol000000onk
A;_o0000om</d`0>om</d`03o`000?o9=/WobCK900gobCK900?o0000omHYe_oF:MH03OoF:MH00ol0
003obCK9olTfb@0?olTfb@03o`000?o0?l3o`3o000[o`3o02ol0000;om`Sg0Go00003?oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5n_oj1OX02_oj1OX01Ol0003ogR7No`000?oj1O[o0000
00Sof2OH0ol00005ok]4^`03o`000?oC;=?odbcC00codbcC00?o0000olTfbOo9=/T03Oo9=/T00ol0
003oeRWFomHYeP0=omHYeP;o00004?o9=/T00ol0003o`3o0ol0o`00:ol0o`003o`000?o3?<?o`cc3
00Oo`cc300?o0000om`Sg?oL8m`00_oL8m`7o`0000Co_d2o00?o0000on8Mh_oR7N802_oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5n_oj1OX02Ooj1OX01?l0003ogR7NomhQg_oN8Mh2o`00
00Gof2OH0ol00009ok]4^`;o00002ooC;=<00ol0003obCK9olTfb@0=olTfb@03o`000?oF:MKoeRWF
00goeRWF00Co0000omTVfOoI9]Wo00003oo9=/T00ol0003o`3o0ol0o`009ol0o`003o`000?o3?<?o
`cc300Wo`cc31?l0000;okm0_`03o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?oj1O[onPGj00SonPGj00?o0000omhQg_oN8Mh01?oN8Mh00ol0003of2OHo`000002o`00
00co^dBk00Co0000ol<l`ol0003o00002OoC;=<00ol0003obCK9olTfb@0=olTfb@03o`000?oF:MKo
eRWF00goeRWF00Go0000omTVfOoI9]WofBKIo`00000=olTfb@03o`000?o0?l3o`3o000[o`3o000?o
0000ol<l`oo3?<<02Oo3?<<00ol0003o_d2ookm0_`0<okm0_`03o`000?oR7N;ohQgR00[ohQgR00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oj1O[onPGj00OonPGj00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003o^dBkok]4^`0<ok]4^`03o`000?o3?<?o`cc300;o`cc30_l00007om</d`03o`000?o9=/Wo
bCK900cobCK900?o0000omHYe_oF:MH03OoF:MH00ol0003ofBKIomTVf@03omTVf@03o`000?o9=/Wo
bCK900[obCK900?o0000ol0o`?o0?l002_o0?l000ol0003o`cc3ol<l``09ol<l``03o`000?no@;oo
_d2o00co_d2o00?o0000on8Mh_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooX5
n_oj1OX01_oj1OX00ol0003ogR7NomhQgP06omhQgP03o`000?nkA;_o^dBk00_o^dBk00?o0000ol<l
`oo3?<<01Oo3?<<00ol0003odbcCom</d`03om</d`03o`000?o9=/WobCK900gobCK900?o0000omHY
e_oF:MH03OoF:MH00ol0003ofBKIomTVf@04omTVf@03o`000?o9=/WobCK900WobCK900?o0000ol0o
`?o0?l002Oo0?l000ol0003o`cc3ol<l``0:ol<l``03o`000?no@;oo_d2o00co_d2o00?o0000on8M
h_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gR7NomhQgP07omhQgP03o`000?nkA;_o^dBk00_o^dBk00?o0000ol<l`oo3?<<01_o3?<<2o`0000?o
dbcC00?o0000olTfbOo9=/T03Oo9=/T00ol0003oeRWFomHYeP0<omHYeP03o`000?oI9]WofBKI00Ko
fBKI00?o0000olTfbOo9=/T02?o9=/T00ol0003o`3o0ol0o`009ol0o`003o`000?o3?<?o`cc300[o
`cc300?o0000okm0_ono@;l03?no@;l00ol0003ohQgRon8MhP0;on8MhP03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?oj1O[onPGj00ConPGj00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o^dBkok]4^`0:ok]4^`03o`00
0?o3?<?o`cc300Wo`cc30_l000000ooC;=?o0000olTfb@0<olTfb@?o00003_oF:MH00ol0003ofBKI
omTVf@07omTVf@03o`000?o9=/WobCK900OobCK900?o0000ol0o`?o0?l002Oo0?l000ol0003o`cc3
ol<l``0;ol<l``03o`000?no@;oo_d2o00co_d2o00?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooX5n_oj1OX00ol0
0008oo/4n`03o`000?oj1O[onPGj00?onPGj00?o0000omhQg_oN8Mh02_oN8Mh00ol0003o^dBkok]4
^`09ok]4^`03o`000?o3?<?o`cc300_o`cc300?o0000olTfbOo9=/T02_o9=/T2o`0000?obCK900?o
0000omHYe_oF:MH02_oF:MH00ol0003ofBKIomTVf@09omTVf@03o`000?o9=/WobCK900KobCK900?o
0000ol0o`?o0?l002?o0?l000ol0003o`cc3ol<l``0<ol<l``03o`000?no@;oo_d2o00co_d2o00?o
0000on8Mh_oR7N802_oR7N800ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP04ooX5nP?o00001Ook1?/0
0ol0003onPGjooX5nP02ooX5nP03o`000?oN8MkogR7N00_ogR7N00?o0000ok]4^onkA;/02?nkA;/0
0ol0003o`cc3ol<l``0<ol<l``03o`000?o9=/WobCK900SobCK90_l00006olTfb@;o00002_oF:MH0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o9=/WobCK900GobCK900?o0000ol0o`?o0?l002?o0?l00
0ol0003o`cc3ol<l``0<ol<l``03o`000?no@;oo_d2o00co_d2o00?o0000on8Mh_oR7N802ooR7N80
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX02?oj1OX3o`0000?on`Ck00Go0000ooX5n_oj1O[onPGjo`00000=
omhQgP03o`000?nkA;_o^dBk00Oo^dBk00?o0000ol<l`oo3?<<03_o3?<<00ol0003obCK9olTfb@04
olTfb@?o00002_o9=/T00ol0003oeRWFomHYeP07omHYeP03o`000?oI9]WofBKI00_ofBKI00?o0000
olTfbOo9=/T00oo9=/T00ol0003o`3o0ol0o`009ol0o`003o`000?o3?<?o`cc300co`cc300?o0000
okm0_ono@;l03?no@;l00ol0003ohQgRon8MhP0;on8MhP;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0<ooX5nPCo00000_oj1OX00ol0
003ogR7NomhQgP0<omhQgP03o`000?nkA;_o^dBk00Oo^dBk00?o0000ol<l`oo3?<<03oo3?<<01?l0
003obCK9olTfbOo9=/T2o`0000kobCK90_l00006omHYeP03o`000?oI9]WofBKI00gofBKI00?o0000
olTfbOo9=/T00_o9=/T00ol0003o`3o0ol0o`008ol0o`003o`000?o3?<?o`cc300co`cc30ol0000=
okm0_`03o`000?oR7N;ohQgR00_ohQgR00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oj1O[o0000
00oogR7N00?o0000ok]4^onkA;/01_nkA;/00ol0003o`cc3ol<l``0@ol<l``Co00004_o9=/T00ol0
003oeRWFomHYeP03omHYeP03o`000?oI9]WofBKI00kofBKI00Go0000olTfbOo9=/WobCK9o`000005
ol0o`0Oo00003?o3?<<01Ol0003o/Tfbok9=/_nbCK;o000000co_d2o00?o0000on8Mh_oR7N802?oR
7N83o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooX5n_oj1OX04?oj1OX3o`0000oogR7N00?o0000ok]4^onkA;/01_nkA;/00ol0003o`cc3ol<l``0=
ol<l``?o000000Co]dRgo`000?l0003o00004oo9=/T2o`0000;oeRWF00?o0000omTVfOoI9]T04?oI
9]T00ol0003obCK9o`000006o`0000Oof2OH00?o0000ol<l`oo3?<<02?o3?<<00ol0003o/Tfbok9=
/P03ok9=/P;o00002?no@;l3o`0000KohQgR1?l00002omhQgP03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX03ooj1OX0
1?l0003odRgBo`000?no@;l3o`0000gogR7N00?o0000ok]4^onkA;/01?nkA;/00ol0003o`cc3ol<l
``0;ol<l``?o00000ongB;L01Ol0003o^4Nho`000?niA[Wo000001CobCK900?o0000omHYe_l00000
4ooI9]T00ol0003of2OHomPWf00=omPWf003o`000?o3?<?o`cc300Go`cc30_l00008ok9=/P03o`00
0?no@;oo_d2o00Go00000oo1?/400ol0003ohQgRon8MhP03o`0000OogR7N00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003onPGjooX5
nP0>ooX5nP04o`000?oB;M;odRgBo`0000Co_d2o0ol0000:omhQgP03o`000?nkA;_o^dBk00?o^dBk
00?o0000ol<l`oo3?<<02Oo3?<<3o`0000Go]dRg00Co0000okQ7^?nhAkSo00000_niA[T00ol0003o
bCK9olTfb@0BolTfb@03o`000?oI9]WofBKI01;ofBKI00?o0000omPWf?oH9mP03_oH9mP00ol0003o
`cc3ol<l``03ol<l``03o`000?nbCK;o/Tfb00Wo/Tfb0_l00009ol4n`@;o00002_oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oj1O[onPGj00konPGj00Go0000om8]d_oB;M;odRgBo`000007okm0_`;o00001ooN8Mh5o`0000;o
^dBk00?o0000ol<l`oo3?<<01_o3?<<3o`0000So]dRg00Co0000okQ7^?nhAkSo00000oniA[T00ol0
003obCK9olTfb@0AolTfb@03o`000?oI9]WofBKI017ofBKI00?o0000omPWf?oH9mP04?oH9mP01Ol0
003o`cc3ol<l`oo3?<?o000000co/Tfb00?o0000ol4n`Oo1?/402?o1?/400ol0003ogR7NomhQgP0:
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooX5n_oj1OX03?oj1OX2o`0000CodRgB00?o0000okm0_ono@;l01ono@;l3o`00
0004omhQg_l0003o0000o`0000Go`Ck10_l00006ol<l``?o00002_ngB;L01Ol0003o^4NhokQ7^?nh
AkSo000000Co^DJi00?o0000olTfbOo9=/T04?o9=/T00ol0003ofBKIomTVf@0AomTVf@03o`000?oH
9mSof2OH017of2OH00?o0000ol<l`ol000003OnbCK800ol0003o`Ck1ol4n`@08ol4n`@03o`000?oN
8MkogR7N00[ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oB;M;odRgB00CodRgB00?o0000
okm0_ono@;l02_no@;l00ol0003o`Ck1ol4n`@08ol4n`@03o`000?o3?<?o`cc300?o00003OngB;L0
1Ol0003o^4NhokQ7^?nhAkSo000000Go^DJi00?o0000olTfbOo9=/T03oo9=/T00ol0003ofBKIomTV
f@0AomTVf@03o`000?oH9mSof2OH01;of2OH00?o0000ok9=/_nbCK803?nbCK800ol0003o`Ck1ol4n
`@08ol4n`@03o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_onPGj00?o0000om8]d_oB;M801OoB;M80
0ol0003o_d2ookm0_`0:okm0_`03o`000?o1?/7o`Ck100Wo`Ck10_l0000?okM8]`03o`000?nhAkSo
^4Nh00;o^4Nh00?o0000okU6^OniA[T01?niA[T00ol0003obCK9olTfb@0=olTfb@?o00004OoI9]T0
0ol0003of2OHomPWf00ComPWf003o`000?nbCK;o/Tfb00_o/Tfb00?o0000ol4n`Oo1?/402Oo1?/40
0ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008ooX5nP;o00002?oB;M80
0ol0003o_d2ookm0_`0:okm0_`03o`000?o1?/7o`Ck100Wo`Ck100?o0000okM8]ongB;L03OngB;L0
0ol0003o^4NhokQ7^003okQ7^003o`000?niA[Wo^DJi00Go^DJi00?o0000olTfbOo9=/T02_o9=/T2
o`0000?oebSG00?o0000omTVfOoI9]T03_oI9]T00ol0003of2OHomPWf00ComPWf003o`000?nbCK;o
/Tfb00_o/Tfb00?o0000ol4n`Oo1?/402Oo1?/400ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000GonPGj00?o0000om8]d_oB;M801ooB;M82o`0000_o_d2o00?o0000ol4n
`Oo1?/402oo1?/400ol0003o]dRgokM8]`0<okM8]`03o`000?nhAkSo^4Nh00?o^4Nh00?o0000okU6
^OniA[T01_niA[T00ol0003obCK9olTfb@07olTfb@;o00001_oG:=L2o`0000kofBKI00?o0000omPW
f?oH9mP04ooH9mP00ol0003o/Tfbok9=/P0;ok9=/P03o`000?o1?/7o`Ck100Wo`Ck100?o0000omhQ
g_oN8Mh03?oN8Mh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000ooX5n_oj1O[onPGjo`000009om8]
dP03o`000?n1OX7o000000_o_d2o00?o0000ol4n`Oo1?/402oo1?/400ol0003o]dRgokM8]`0;okM8
]`03o`000?nhAkSo^4Nh00Co^4Nh00?o0000okU6^OniA[T01oniA[T00ol0003obCK9olTfb@05olTf
b@03o`000?oG:=OoebSG00SoebSG00?o0000omTVfOoI9]T02_oI9]T00ol0003of2OHomPWf00DomPW
f003o`000?nbCK;o/Tfb00_o/Tfb00?o0000ol4n`Oo1?/402Oo1?/400ol0003ogR7NomhQgP0<omhQ
gP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjo`000009om8]dP04o`000?n1OX7oPGj1o`00
00_o_d2o00?o0000ol4n`Oo1?/402oo1?/400ol0003o]dRgokM8]`0;okM8]`03o`000?nhAkSo^4Nh
00Co^4Nh00?o0000okU6^OniA[T02?niA[T00ol0003obCK9olTfb@02olTfb@;o00003?oG:=L2o`00
00[ofBKI00?o0000omPWf?oH9mP05?oH9mP00ol0003o/Tfbok9=/P0;ok9=/P03o`000?o1?/7o`Ck1
00Wo`Ck100?o0000omhQg_oN8Mh03OoN8Mh00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003odRgBom8]dP07om8]dP03
o`000?n1OX7oPGj100;oPGj100?o0000okm0_ono@;l02?no@;l00ol0003o`Ck1ol4n`@0<ol4n`@03
o`000?ngB;Oo]dRg00Wo]dRg00?o0000okQ7^?nhAkP01OnhAkP00ol0003o^DJiokU6^@09okU6^@04
o`000?o9=/Wo0000o`00013oebSG0_l00008omTVf@03o`000?oH9mSof2OH01Cof2OH0ol0000;ok9=
/P03o`000?o1?/7o`Ck100Wo`Ck100?o0000omhQg_oN8Mh03OoN8Mh01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003odRgBom8]dP06om8]dP03o`000?n1OX7oPGj100?oPGj100?o0000okm0
_ono@;l02?no@;l00ol0003o`Ck1ol4n`@0;ol4n`@;o00002_ngB;L00ol0003o^4NhokQ7^006okQ7
^003o`000?niA[Wo^DJi00[o^DJi00?o0000omLXeooG:=L04_oG:=L00ol0003ofBKIomTVf@04omTV
f@03o`000?oH9mSof2OH01Gof2OH00?o0000om0_d?o@;m001Ol00005ok9=/P03o`000?o1?/7o`Ck1
00[o`Ck100?o0000omhQg_oN8Mh03_oN8Mh3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odRgBom8]dP04om8]dP03
o`000?n1OX7oPGj100CoPGj100?o0000okm0_ono@;l01ono@;l00ol0003o`Ck1ol4n`@0;ol4n`@04
o`000?o2?L;o`Sg2o`0000Wo]dRg00?o0000okQ7^?nhAkP01_nhAkP00ol0003o^DJiokU6^@0:okU6
^@03o`000?oG:=OoebSG01?oebSG0_l00003omTVf@Co00005?oH9mP00ol0003od2o@om0_d006om0_
d0Co000000?o/Tfbo`000?o1?/402oo1?/400ol0003ogR7NomhQgP0>omhQgP03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003odRgBom8]dP03om8]dP03o`000?n1OX7oPGj100GoPGj100?o0000okm0_ono
@;l01ono@;l00ol0003o`Ck1ol4n`@09ol4n`@;o00001?o2?L800ol0003o]dRgokM8]`05okM8]`03
o`000?nhAkSo^4Nh00Oo^4Nh00?o0000okU6^OniA[T02_niA[T00ol0003oebSGomLXe`0EomLXe`03
o`000?oI9]Wo000000CogB;M0ol0000@omPWf003o`000?o@;m3od2o@00_od2o@0_l0000<ol4n`@03
o`000?oN8MkogR7N00cogR7N0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000om8]d_oB;M800_oB;M800ol0003oPGj1
oh5nP@06oh5nP@03o`000?no@;oo_d2o00Oo_d2o00?o0000ol4n`Oo1?/402?o1?/400ol0003o`Sg2
ol8m`P05ol8m`P03o`000?ngB;Oo]dRg00Co]dRg00?o0000okQ7^?nhAkP01onhAkP00ol0003o^DJi
okU6^@0:okU6^@03o`000?oG:=OoebSG01KoebSG00?o0000omdRgOoM8]d01_oM8]d3o`0000cof2OH
00?o0000om0_d?o@;m003Oo@;m000ol0003o`Ck1ol4n`@09ol4n`@Go00002OoN8Mh2o`000003omPW
f?l0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003om8]d_l0003oPGj100WoPGj100?o0000okm0_ono@;l01_no
@;l00ol0003o`Ck1ol4n`@07ol4n`@03o`000?o2?L;o`Sg200Oo`Sg200?o0000okM8]ongB;L00_ng
B;L00ol0003o^4NhokQ7^008okQ7^003o`000?niA[Wo^DJi00Wo^DJi00?o0000omLXeooG:=L05ooG
:=L00ol0003ogB;MomdRg@09omdRg@?o00002OoH9mP00ol0003od2o@om0_d00>om0_d0Ko00001?o1
?/400ol0003o[e2_ojm@[`03ojm@[`Go00000_oN8Mh2o`0000Cof2OH00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o5>/GoaC[5olDjaOl000002on1OX400ol0003o_d2ookm0_`06okm0_`03o`000?o1
?/7o`Ck100Go`Ck10_l0000;ol8m`P04o`000?ngB;Oo]dRgo`0000_o^4Nh00?o0000okU6^OniA[T0
2OniA[T00ol0003oebSGomLXe`0FomLXe`03o`000?oM8]gogB;M00gogB;M0ol00005omPWf003o`00
0?o@;m3od2o@00ood2o@00?o0000oldbcOo=</d00oo=</d4o`0000_o[e2_0_l00006omPWf003o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oaC[5olDja@02olDja@ko00001_no@;l00ol0003o`Ck1ol4n
`@05ol4n`@03o`000?o2?L;o`Sg200co`Sg200?o0000okM8]ol000002onhAkP00ol0003o^DJiokU6
^@07okU6^@?o00006?oG:=L00ol0003ogB;MomdRg@0@omdRg@?o000000?of2OHo`000?o@;m004?o@
;m000ol0003ocC;=oldbc@07oldbc@03o`000?n_D:oo[e2_00[o[e2_00?o0000omPWf?oH9mP01OoH
9mP00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olDja@03o`000?nBKI;oTVfB00_oTVfB0_l00004
okm0_`03o`000?o1?/7o`Ck100?o`Ck10_l0000@ol8m`P03o`000?nhAkSo^4Nh00[o^4Nh00?o0000
okU6^OniA[T00oniA[T4o`0000;o/Dja00?o0000omLXeooG:=L05OoG:=L00ol0003ogB;MomdRg@0D
omdRg@03o`000?o@;m3od2o@013od2o@00?o0000oldbcOo=</d01oo=</d00ol0003o[e2_ojm@[`0:
ojm@[`03o`000?oH9mSof2OH00Gof2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o5>/GoaC[5
00GoaC[500?o0000oi9]T_nBKI803OnBKI86o`0000?o`Ck100?o0000ol8m`_o2?L804?o2?L800ol0
003o^4NhokQ7^00:okQ7^003o`000?niA[Wo000000?o00001onaC[400ol0003oebSGomLXe`0DomLX
e`03o`000?oM8]gogB;M01CogB;M00?o0000om0_d?o@;m003oo@;m000ol0003ocC;=oldbc@08oldb
c@03o`000?n_D:oo[e2_00[o[e2_00?o0000omPWf?oH9mP01OoH9mP00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olDjaOo5>/D01_o5>/D00ol0003oTVfBoi9]TP0=oi9]TP03o`000?o8=lSob3O800?o
b3O800?o0000ol4n`Ol000004oo2?L84o`0000Wo^4Nh0_l0000<ok5>/@03o`000?oG:=OoebSG01?o
ebSG00?o0000omdRgOoM8]d05OoM8]d00ol0003od2o@om0_d00>om0_d003o`000?o=</gocC;=00So
cC;=00?o0000ojm@[on_D:l02On_D:l00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o5>/GoaC[500SoaC[500?o0000oi9]T_nBKI802onBKI800ol0003ob3O8olPgb005olPgb003o`00
0?o2?L;o`Sg201;o`Sg200Co0000okU6^OniA[Wo^DJi1Ol00003okQ7^003o`000?naC[7o/Dja00go
/Dja0ol0000@omLXe`;o00006?oM8]d00ol0003od2o@om0_d00=om0_d003o`000?o=</gocC;=00Wo
cC;=00?o0000ojm@[on_D:l02On_D:l00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooX5n_oj1OX0
0_oj1OX6o`0000_oaC[500?o0000oi9]T_nBKI802_nBKI800ol0003ob3O8olPgb006olPgb003o`00
0?o2?L;o`Sg2017o`Sg200?o0000okU6^OniA[T01oniA[T3o`00013o/Dja00?o0000ojm@[on_D:l0
1Ol00009omLXe`;o000000?o_4>lo`000?oM8]d05ooM8]d00ol0003od2o@om0_d00=om0_d003o`00
0?o=</gocC;=00WocC;=00?o0000ojm@[on_D:l02?n_D:l2o`0000[of2OH00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003onPGjooX5
nP03ooX5nP03o`000?oF:MKoeRWF00;oeRWF00?o0000olDjaOo5>/D02Oo5>/D00ol0003oTVfBoi9]
TP0:oi9]TP03o`000?o8=lSob3O800Oob3O800?o0000ol8m`_o2?L803oo2?L800ol0003o^DJiokU6
^@0:okU6^@03o`000?naC[7o/Dja00go/Dja00?o0000ojm@[on_D:l01_n_D:l4o`0000CoebSG00?o
0000oka3_?nl@k`00_nl@k`00ol0003ogB;MomdRg@0FomdRg@03o`000?o@;m3od2o@00_od2o@00?o
0000oldbcOo=</d02oo=</d00ol0003o[e2_ojm@[`06ojm@[`03o`000?nIIYWo000000[of2OH00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003onPGjooX5nP04ooX5nP03o`000?oF:MKoeRWF00?oeRWF00?o0000olDjaOo5>/D02?o5>/D=
o`0000[ob3O800?o0000ol8m`_o2?L803oo2?L800ol0003o^DJiokU6^@0;okU6^@03o`000?naC[7o
/Dja00co/Dja00?o0000ojm@[on_D:l02_n_D:l4o`0000Go_4>l00?o0000omdRgOoM8]d05_oM8]d0
0ol0003od2o@om0_d00:om0_d003o`000?o=</gocC;=00cocC;=00?o0000ojm@[on_D:l01?n_D:l2
o`0000?oVFJI00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omHY
e_oF:MH00ooF:MH00ol0003oaC[5olDja@07olDja@03o`000?nBKI;oTVfB00WoTVfB00?o0000olPg
b?o8=lP02Oo8=lP00ol0003o`Sg2ol8m`P0=ol8m`P03o`000?niA[Wo^DJi00co^DJi00?o0000ok5>
/OnaC[403?naC[400ol0003o[e2_ojm@[`0;ojm@[`03o`000?nMHYgo000000Ko_4>l00?o0000omdR
gOoM8]d05_oM8]d00ol0003od2o@om0_d009om0_d003o`000?o=</gocC;=00cocC;=00?o0000ojm@
[on_D:l00on_D:l00ol0003oVFJIoiUVV@03oiUVV@03o`000?oH9mSof2OH00Sof2OH00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
nPGjooX5nP06ooX5nP03o`000?oF:MKoeRWF00CoeRWF00?o0000olDjaOo5>/D01_o5>/D00ol0003o
TVfBoi9]TP08oi9]TP03o`000?o8=lSob3O800_ob3O800?o0000ol8m`_o2?L802?o2?L84o`0000oo
^DJi00?o0000ok5>/OnaC[402onaC[400ol0003o[e2_ojm@[`0;ojm@[`04o`000?nMHYgoWF:Mo`00
00Oo_4>l00?o0000omdRgOoM8]d05OoM8]d00ol0003od2o@om0_d008om0_d003o`000?o=</gocC;=
00gocC;=00?o0000ojm@[on_D:l00_n_D:l00ol0003oVFJIoiUVV@05oiUVV@03o`000?oH9mSof2OH
00Oof2OH00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003onPGjooX5nP06ooX5nP03o`000?oF:MKoeRWF00GoeRWF00?o0000olDjaOo5
>/D01Oo5>/D00ol0003oTVfBoi9]TP08oi9]TP03o`000?o8=lSob3O800_ob3O800?o0000ol8m`_o2
?L800oo2?L85o`0000?o^DJi00?o0000okU6^OniA[T03_niA[T00ol0003o/Djaok5>/@0:ok5>/@03
o`000?n_D:oo[e2_00[o[e2_00Go0000oieRWOnMHYgoWF:Mo`000007oka3_003o`000?oM8]gogB;M
01GogB;M00?o0000om0_d?o@;m002?o@;m000ol0003ocC;=oldbc@0=oldbc@03o`000?n_D:oo[e2_
00;o00002?nIIYT00ol0003of2OHomPWf008omPWf0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oeRWFomHYeP05omHYeP03o`000?o5>/GoaC[500Go
aC[500?o0000oi9]T_nBKI802?nBKI800ol0003ob3O8olPgb00<olPgb0Go00002OniA[T00ol0003o
^DJiokU6^@0<okU6^@;o00003?naC[400ol0003o[e2_ojm@[`0:ojm@[`05o`000?nMHYgoWF:MoieR
WOl000002?nl@k`00ol0003ogB;MomdRg@0DomdRg@?o00001oo@;m000ol0003ocC;=oldbc@0>oldb
c@03o`000?n_D:oo000000_oVFJI00?o0000omPWf?oH9mP01_oH9mP00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00So
nPGj00?o0000omHYe_oF:MH01OoF:MH00ol0003oaC[5olDja@04olDja@03o`000?nBKI;oTVfB00Oo
TVfB00?o0000olPgb?o8=lP03?o8=lP01?l0003o`Sg2ol8m`_l0000;okU6^@03o`000?niA[Wo^DJi
00_o^DJi00Co0000oiYUV_nJII[o00002_naC[400ol0003o[e2_ojm@[`0:ojm@[`03o`000?nMHYgo
WF:M00;oWF:M00?o0000oka3_?nl@k`01_nl@k`00ol0003ogB;MomdRg@0AomdRg@?o00000oo2?L80
0ol0003od2o@om0_d004om0_d003o`000?o=</gocC;=00gocC;=1?l0000;oiUVV@03o`000?oH9mSo
f2OH00Gof2OH00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oF:MKoeRWF00KoeRWF00Co0000olDj
aOo5>/GoaC[51?l00008oi9]TP03o`000?o8=lSob3O800_ob3O800?o0000ol8m`_o2?L800_o2?L80
0ol0003o^DJiokU6^@08okU6^@03o`000?niA[Wo^DJi00[o^DJi00?o0000oiYUV_nJIIX00_nJIIX0
0ol0003o/Djaok5>/@03ok5>/@Go00002on_D:l00ol0003oWF:MoieRW@03oieRW@03o`000?nl@kco
_4>l00Oo_4>l00?o0000omdRgOoM8]d03_oM8]d2o`0000Oo`Sg200?o0000om0_d?o@;m000_o@;m00
0ol0003ocC;=oldbc@0=oldbc@03o`000?n`Ck3o/4n`00;o/4n`00?o0000oiUVVOnIIYT02OnIIYT0
0ol0003of2OHomPWf003omPWf003o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oeRWFomHYeP07omHY
eP?o00001?o0?l000ol0003oTVfBoi9]TP05oi9]TP03o`000?o8=lSob3O800[ob3O800?o0000ol8m
`_o2?L800oo2?L800ol0003o^DJiokU6^@09okU6^@03o`000?niA[Wo^DJi00So^DJi00?o0000oiYU
V_nJIIX01?nJIIX5o`0000CoKi1_00?o0000ojm@[on_D:l02On_D:l00ol0003oWF:MoieRW@03oieR
W@03o`000?nl@kco_4>l00So_4>l00?o0000omdRgOoM8]d02_oM8]d3o`0000[o`Sg200Go0000om0_
d?o@;m3od2o@o`00000>oldbc@03o`000?n`Ck3o/4n`00Co/4n`0_l00009oiUVV@03o`000?oH9mSo
f2OH00;of2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oF:MKoeRWF00OoeRWF00?o0000ol0o
`?o0?l001Oo0?l000ol0003oTVfBoi9]TP03oi9]TP03o`000?o8=lSob3O800[ob3O800?o0000ol8m
`_o2?L801?o2?L800ol0003o^DJiokU6^@09okU6^@03o`000?niA[Wo^DJi00Oo^DJi00?o0000oiYU
V_nJIIX01OnJIIX00ol0003oKi1_ofn@K`07ofn@K`03o`000?n_D:oo[e2_00Oo[e2_00?o0000oieR
WOnMHYd01?nMHYd00ol0003o_4>loka3_008oka3_003o`000?oM8]gogB;M00SogB;M0_l0000>ol8m
`PCo00003?o=</d2o`0000Wo/4n`00?o0000oiUVVOnIIYT01onIIYT01?l0003of2OHomPWf?l0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oj1O[onPGj
00[onPGj00?o0000omHYe_oF:MH01OoF:MH00ol0003o`3o0ol0o`007ol0o`0;o00000onBKI800ol0
003ob3O8olPgb009olPgb003o`000?o2?L;o`Sg200Ko`Sg200?o0000okU6^OniA[T02OniA[T00ol0
003o^DJiokU6^@05okU6^@03o`000?nJII[oVVFJ00KoVVFJ00?o0000ofn@Kom_T6l02?m_T6l00ol0
003o[e2_ojm@[`06ojm@[`03o`000?nMHYgoWF:M00CoWF:M00?o0000oka3_?nl@k`02Onl@k`4o`00
00?ogB;M0ol0000@ol8m`P05o`000?oJ9M[ofRGJomXUf_l000002_o=</d00ol0003o/4n`ok1?/00:
ok1?/0Ko00000onIIYT00ol0003of2OHo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oj1O[onPGj00WonPGj00?o0000omHYe_oF:MH01?oF:MH00ol0
003o`3o0ol0o`00:ol0o`004o`000?nBKI;oTVfBo`0000[ob3O800?o0000ol8m`_o2?L801oo2?L80
0ol0003o^DJiokU6^@09okU6^@03o`000?niA[Wo^DJi00Co^DJi00?o0000oiYUV_nJIIX01onJIIX0
0ol0003oKi1_ofn@K`08ofn@K`;o00001_n_D:l00ol0003oWF:MoieRW@05oieRW@03o`000?nl@kco
_4>l00Wo_4>l00Co0000ok5>/OnaC[7o/Dja0ol0000Bol8m`P03o`000?oJ9M[ofRGJ00?ofRGJ0_l0
0006oldbc@;o00003On`Ck000ol0003og2?Lom`Sg003om`Sg0Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[onPGj00?o0000omHYe_oF:MH00ooF:MH0
0ol0003o`3o0ol0o`00<ol0o`0;o00002_o8=lP00ol0003o`Sg2ol8m`P08ol8m`P03o`000?niA[Wo
^DJi00[o^DJi00?o0000okU6^OniA[T00_niA[T00ol0003oVVFJoiYUVP08oiYUVP03o`000?m_T6oo
Ki1_00KoKi1_0_l00002oiQWV003o`000?n_D:oo[e2_00;o[e2_00?o0000oieRWOnMHYd01_nMHYd0
0ol0003o_4>loka3_008oka3_003o`000?naC[7o/Dja00Co/Dja00?o0000ol8m`_o2?L803oo2?L80
0ol0003ofRGJomXUfP06omXUfP;o00000oo=</d00ol0003o/4n`ok1?/00=ok1?/003o`000?oL8mco
g2?L00Oog2?L0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oj1O[onPGj00?o00001ooj1OX00ol0003oeRWFomHYeP02omHYeP03o`000?o0?l3o`3o0
00ko`3o000?o0000olPgb?o8=lP01oo8=lP00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?niA[Wo^DJi
00Wo^DJi00Go0000okU6^OniA[Wo^DJio`00000;oiYUVP03o`000?m_T6ooKi1_00CoKi1_0_l00005
oiQWV005o`000?n_D:oo[e2_ojm@[ol000002?nMHYd00ol0003o_4>loka3_008oka3_003o`000?na
C[7o/Dja00Go/Dja00?o0000ol8m`_o2?L803_o2?L800ol0003ofRGJomXUfP08omXUfP03o`000?o=
</go000000oo/4n`00?o0000om`Sg?oL8m`02?oL8m`01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00ConPGj0ol0
0005ooX5nP04o`000?oF:MKoeRWFo`00017o`3o000?o0000olPgb?o8=lP01_o8=lP00ol0003o`Sg2
ol8m`P0;ol8m`P03o`000?niA[Wo^DJi00Wo^DJi00Co0000okU6^OniA[Wo00003?nJIIX00ol0003o
Ki1_ofn@K`02ofn@K`;o00002?nHIiP00ol0003o[e2_o`000009oieRW@03o`000?nl@kco_4>l00So
_4>l00?o0000ok5>/OnaC[401OnaC[400ol0003o`Sg2ol8m`P0=ol8m`P03o`000?oJ9M[ofRGJ00[o
fRGJ00?o0000ok1?/?n`Ck003_n`Ck000ol0003og2?Lom`Sg007om`Sg003o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003onPGjooX5nP08ooX5nP?o000000?onPGjo`000?l000000ol0000Bol0o`003o`00
0?o8=lSob3O800Cob3O800?o0000ol8m`_o2?L803?o2?L800ol0003o^DJiokU6^@0:okU6^@?o0000
3?nJIIX00ol0003oKi1_ofn@K`02o`0000_oV6NH00?o0000oieRWOnMHYd02?nMHYd00ol0003o_4>l
oka3_007oka3_003o`000?naC[7o/Dja00Oo/Dja00?o0000ol8m`_o2?L803?o2?L800ol0003ofRGJ
omXUfP0;omXUfP;o00003_n`Ck000ol0003og2?Lom`Sg007om`Sg003o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N800ooR7N800ol0003o`3o0ol0o`00?ol0o`0?o00000oo8
=lP00ol0003o`Sg2ol8m`P0>ol8m`P03o`000?niA[Wo^DJi00So^DJi00Co0000oj5NXOnQGZ7oXEjQ
0_l0000:oiYUVP?o00003OnHIiP00ol0003oWF:MoieRW@08oieRW@03o`000?nl@kco_4>l00Oo_4>l
00?o0000ok5>/OnaC[401onaC[400ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oJ9M[ofRGJ00cofRGJ
00?o0000ol8m`_l000000_l0000:ok1?/003o`000?oL8mcog2?L00Sog2?L00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP04on8MhP03o`000?o0?l3o`3o000co`3o00_l0
0003okY5^P03o`000?o8=lSo0000017o`Sg200?o0000okU6^OniA[T01oniA[T00ol0003oXEjQoj5N
X@04oj5NX@;o00002?nJIIX00ol0003oV6NHoiQWV00>oiQWV0;o00002?nMHYd00ol0003o_4>loka3
_006oka3_003o`000?naC[7o/Dja00Wo/Dja00?o0000ol8m`_o2?L802Oo2?L800ol0003ofRGJomXU
fP0=omXUfP03o`000?o2?L;o`Sg200;o`Sg20ol00007ok1?/003o`000?oL8mcog2?L00Oog2?L00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?o0?l3o
`3o000Wo`3o00_l00006okY5^P03o`000?o2?L;o`Sg2013o`Sg200?o0000okU6^OniA[T01_niA[T0
0ol0003oXEjQoj5NX@07oj5NX@03o`000?nJII[oVVFJ00CoVVFJ0ol0000>oiQWV003o`000?n7N8Oo
QgR700?o00001OnMHYd00ol0003o_4>loka3_006oka3_003o`000?naC[7o/Dja00[o/Dja00?o0000
ol8m`_o2?L802?o2?L800ol0003ofRGJomXUfP0=omXUfP03o`000?o2?L;o`Sg200Go`Sg20ol00004
ok1?/003o`000?oL8mcog2?L00Oog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ohQgRon8MhP06on8MhP03o`000?o0?l3o`3o000Go`3o00ol00008okY5^P03o`000?o2?L;o`Sg2
017o`Sg200Co0000okU6^OniA[Wo^DJi1?l0000;oj5NX@;o000000CoVVFJo`000?l0003o00000on[
E:/2o`0000_oV6NH00?o0000ohMhQon7N8L01?n7N8L2o`0000?oWF:M00?o0000oka3_?nl@k`01_nl
@k`00ol0003o/Djaok5>/@0:ok5>/@03o`000?o2?L;o`Sg200Oo`Sg200?o0000omXUf_oJ9MX03_oJ
9MX00ol0003o`Sg2ol8m`P08ol8m`PCo00002_oL8m`00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003ohQgRon8MhP07on8MhP03o`000?o0?l3o`3o000;o`3o00_l0000<okY5^P03o`000?o2?L;o
`Sg2013o`Sg21?l00003ok5>/@03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000oj]DZon[E:/01_n[E:/0
0ol0003oV6NHoiQWV007oiQWV003o`000?n7N8OoQgR700OoQgR73?l0000>ok5>/@03o`000?o2?L;o
`Sg200Ko`Sg200?o0000omXUf_oJ9MX03_oJ9MX00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oL8mco
g2?L00Oog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00WohQgR00Co0000ol0o
`?l0003o00003_njAKX00ol0003o`Sg2ol8m`P0?ol8m`P03o`000?naC[7o/Dja00Ko/Dja00?o0000
oj5NXOnQGZ402_nQGZ400ol0003oZeB[oj]DZ`07oj]DZ`;o00001_nHIiP00ol0003oQgR7ohMhQ`08
ohMhQ`03o`000?o1?/7o`Ck100So`Ck100?o0000ok5>/OnaC[403?naC[400ol0003o`Sg2ol8m`P05
ol8m`P03o`000?oJ9M[ofRGJ00oofRGJ0_l0000=ol8m`P03o`000?oL8mcog2?L00Kog2?L00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oR7N;ohQgR00[ohQgR00?o0000okY5^_njAKX03_njAKX00ol0
003o`Sg2ol8m`P0>ol8m`P03o`000?naC[7o/Dja00Oo/Dja00?o0000oj5NXOnQGZ402_nQGZ400ol0
003oZeB[oj]DZ`09oj]DZ`;o00000onHIiP00ol0003oQgR7ohMhQ`09ohMhQ`03o`000?o1?/7o`Ck1
00Wo`Ck100?o0000ok5>/OnaC[402_naC[44o`0000Co`Sg200?o0000omXUf_oJ9MX04?oJ9MX01?l0
003o`Sg2o`000?l0000<ol8m`P03o`000?oL8mcog2?L00Gog2?L00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003onPGjooX5nP0<ooX5
nP03o`000?oR7N;ohQgR00[ohQgR00?o0000okY5^_njAKX03onjAKX@o`0000[o/Dja00?o0000oj5N
XOnQGZ402OnQGZ400ol0003oSW6>o`00000<oj]DZ`05o`000?nHIiSo0000ohQgR?l000002_n7N8L0
0ol0003o`Ck1ol4n`@09ol4n`@03o`000?naC[7o/Dja00Oo/Dja0ol00004olPgb0?o000000?o`Sg2
o`000?oJ9MX04OoJ9MX01?l0003o`Sg2ol8m`_o2?L82o`0000_o`Sg200?o0000om`Sg?oL8m`00ooL
8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oj1O[onPGj00conPGj00?o0000on8Mh_oR7N802_oR7N800ol0003o^TFjokY5^P0?
okY5^P03o`000?o7><OoacS700coacS700?o0000ok5>/OnaC[402OnaC[400ol0003oXEjQoj5NX@07
oj5NX@04o`000?n>LHkoSW6>o`0000goZeB[00Go0000ohQgR?n8MhSoR7N8o`000009ohMhQ`03o`00
0?o1?/7o`Ck100[o`Ck100?o0000ok5>/OnaC[400onaC[43o`0000[ob3O800?o0000omXUf_oJ9MX0
4?oJ9MX00ol0003o`Sg2ol8m`P04ol8m`P;o00002_o2?L800ol0003og2?Lom`Sg004o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooX5n_oj1OX02_oj
1OX3o`0000cohQgR00?o0000okY5^_njAKX03onjAKX00ol0003oacS7olLha`0<olLha`03o`000?na
C[7o/Dja00Wo/Dja00?o0000oj5NXOnQGZ401_nQGZ400ol0003oSW6>ohiaSP02ohiaSP03o`000?n[
E:_oZeB[00[oZeB[00?o0000ohQgR?n8MhP00_n8MhP00ol0003oQgR7ohMhQ`06ohMhQ`03o`000?o1
?/7o`Ck100[o`Ck100?o0000ok5>/OnaC[400ol0000=olPgb003o`000?oJ9M[ofRGJ013ofRGJ00?o
0000ol8m`_o2?L801_o2?L82o`0000Wo`Sg20_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooX5n_oj1OX01Ooj1OX4
o`0000;onPGj00?o0000on8Mh_oR7N802_oR7N800ol0003o^TFjokY5^P0=okY5^P?o00003oo7><L0
0ol0003o/Djaok5>/@08ok5>/@03o`000?nQGZ7oXEjQ00GoXEjQ00?o0000ohiaS_n>LHh00on>LHh0
0ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?n8MhSoR7N800?oR7N800?o0000ohMhQon7N8L01On7N8L0
0ol0003o`Ck1ol4n`@0;ol4n`@;o00004Oo8=lP00ol0003ofRGJomXUfP0?omXUfP03o`000?o2?L;o
`Sg200So`Sg20_l00007ol8m`P03o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003onPGjooX5nP04o`00
00OonPGj00?o0000on8Mh_oR7N802?oR7N800ol0003o^TFjokY5^P09okY5^PGo00000_n/Dj`00ol0
003oacS7olLha`0=olLha`03o`000?naC[7o/Dja00Wo/Dja00?o0000oj5NXOnQGZ401?nQGZ400ol0
003oSW6>ohiaSP04ohiaSP03o`000?n[E:_oZeB[00SoZeB[00?o0000ohQgR?n8MhP01On8MhP00ol0
003oQgR7ohMhQ`04ohMhQ`03o`000?o1?/7o`Ck100_o`Ck100?o0000olPgb?o8=lP04?o8=lP00ol0
003ofRGJomXUfP0?omXUfP03o`000?o2?L;o`Sg200[o`Sg20_l00004ol8m`P03o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oj1OX00ol0003ohQgRon8MhP07on8MhP03o`000?njAK[o^TFj00Co^TFj1Ol00007ojaC[003
o`000?o7><OoacS700goacS700?o0000ok5>/OnaC[402OnaC[400ol0003oXEjQoj5NX@03oj5NX@03
o`000?n>LHkoSW6>00GoSW6>00?o0000oj]DZon[E:/02?n[E:/00ol0003oR7N8ohQgR006ohQgR003
o`000?n7N8OoQgR700?oQgR700?o0000ol4n`Oo1?/402oo1?/400ol0003ob3O8olPgb00@olPgb003
o`000?oJ9M[ofRGJ00oofRGJ00?o0000ol8m`_o2?L803?o2?L82o`000003ol8m`_l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oR7N;ohQgR00OohQgR00?o0000okY5^_l00000
1?l0000<ojaC[003o`000?o7><OoacS700koacS700?o0000ok5>/OnaC[402?naC[400ol0003oXEjQ
oj5NX@02oj5NX@03o`000?n>LHkoSW6>00OoSW6>00?o0000oj]DZon[E:/01on[E:/00ol0003oR7N8
ohQgR007ohQgR003o`000?n7N8OoQgR700;oQgR700?o0000ol4n`Oo1?/402oo1?/400ol0003ob3O8
olPgb00AolPgb003o`000?oJ9M[ofRGJ00gofRGJ00?o0000ol8m`_o2?L803oo2?L800ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj
1O[onPGj00conPGj00?o0000on8Mh_oR7N801OoR7N83o`00017o[5>/00?o0000olLhaoo7><L03_o7
><L00ol0003o/Djaok5>/@09ok5>/@04o`000?nQGZ7oXEjQo`0000[oSW6>00?o0000oj]DZon[E:/0
1on[E:/00ol0003oR7N8ohQgR008ohQgR005o`000?n7N8OoQgR7ohMhQol000003Oo1?/400ol0003o
b3O8olPgb00AolPgb0?o00003OoJ9MX00ol0003o`Sg2ol8m`P0?ol8m`P03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
nPGjooX5nP0=ooX5nP?o00000_oR7N82o`0000;o]TVf00?o0000ojaC[?n/Dj`03on/Dj`00ol0003o
acS7olLha`0>olLha`03o`000?naC[7o/Dja00So/Dja1Ol0000;ohiaSP03o`000?n[E:_oZeB[00Ko
ZeB[00?o0000ohQgR?n8MhP02On8MhP01?l0003oQgR7ohMhQol0000=ol4n`@03o`000?o8=lSob3O8
017ob3O800?o0000ojiA[_n^DJh00ol0000:omXUfPCo00003Oo2?L800ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oj1O[onPGj00co
nPGj00Co0000omPWf?oH9mSof2OH0_l00005okI9]P03o`000?n/Djco[5>/00ko[5>/00?o0000olLh
aoo7><L03_o7><L00ol0003o/Djaok5>/@07ok5>/@03o`000?n`Ck3o/4n`00?o/4n`00?o0000ohia
S_n>LHh02?n>LHh00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?n8MhSoR7N800[oR7N81Ol0000<ol4n
`@03o`000?o8=lSob3O8013ob3O800?o0000ojiA[_n^DJh01?n^DJh3o`0000KofRGJ00?o0000oll`
coo?<<l00_o?<<l5o`0000So`Sg200?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oH9mSof2OH00?o
f2OH00?o0000okI9]_nfBKH01?nfBKH00ol0003o[5>/ojaC[00=ojaC[003o`000?o7><OoacS700oo
acS700?o0000ok5>/OnaC[401?naC[42o`0000Oo/4n`00?o0000ohiaS_n>LHh01on>LHhEo`0000Go
U6^D00?o0000ol4n`Oo1?/402?o1?/43o`00013ob3O800?o0000ojiA[_n^DJh02?n^DJh3o`0000;o
fRGJ00?o0000oll`coo?<<l02?o?<<l5o`0000?o`Sg200?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003onPGjooX5nP0:ooX5nP03o`00
0?oH9mSof2OH00Cof2OH00?o0000okI9]_nfBKH01OnfBKH00ol0003o[5>/ojaC[00;ojaC[0Co0000
3oo7><L00ol0003o/Djaok5>/@03ok5>/@03o`000?n`Ck3o/4n`00So/4n`00?o0000ohiaS_n>LHh0
1?n>LHh2o`0000So/4n`00?o0000oj=LXonSG:<02?nSG:<00ol0003oU6^DoiA[U005oiA[U0;o0000
1_o1?/42o`0000?o^DJi00?o0000olPgb?o8=lP03?o8=lP00ol0003o[U6^ojiA[P0<ojiA[P;o0000
4?o?<<l3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003of2OHomPWf005omPWf003o`000?nfBKKo]TVf00Ko]TVf00?o
0000ojaC[?n/Dj`02On/Dj`00ol0003oTfbCo`000002ok1?/0?o00003?o7><L01?l0003o/Djaok5>
/OnaC[42o`0000co/4n`00?o0000ohiaS_n>LHh00_n>LHh00ol0003o/4n`ok1?/008ok1?/003o`00
0?nSG:?oXebS00SoXebS00?o0000oiA[U?nDJi@01onDJi@00ol0003o`Ck1ol4n`@02ol4n`@03o`00
0?niA[Wo^DJi00Co^DJi0_l0000;olPgb003o`000?n^DJko[U6^00co[U6^00?o0000okM8]ol00000
4_o?<<l00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooX5n_oj1OX02?oj1OX00ol0003of2OHomPWf006omPWf003o`000?nfBKKo]TVf00Oo]TVf00?o
0000ojaC[?n/Dj`01_n/Dj`2o`0000;oTfbC00?o0000ok1?/?n`Ck000on`Ck03o`0000[oacS700?o
0000ok5>/Ol000003on`Ck001?l0003oSW6>o`000?l0000;ok1?/003o`000?nSG:?oXebS00SoXebS
00?o0000oiA[U?nDJi@02?nDJi@01?l0003o`Ck1o`000?l00009okU6^@03o`000?o8=lSob3O800Oo
b3O800?o0000ojiA[_n^DJh03?n^DJh01?l0003o]dRgokM8]ol0000Coll`c`03o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
nPGj00?o0000omPWf?oH9mP01ooH9mP00ol0003o]TVfokI9]P08okI9]P03o`000?n/Djco[5>/00Co
[5>/00?o0000oi=/TonCK9<00onCK9<00ol0003o/4n`ok1?/005ok1?/0?o00001_o7><L4o`00013o
/4n`00?o0000ok1?/?n`Ck003?n`Ck000ol0003oXebSoj=LX`07oj=LX`03o`000?nDJiCoU6^D00Wo
U6^D00?o0000okU6^OniA[T02_niA[T2o`0000Kob3O800?o0000ojiA[_n^DJh03?n^DJh00ol0003o
]dRgokM8]`02okM8]`03o`000?o?<<oocc3?00oocc3?00?o0000om@[e?l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooX5n_oj1OX0
1?oj1OX00ol0003of2OHomPWf008omPWf003o`000?nfBKKo]TVf00Wo]TVf00Co0000ojaC[?n/Djco
[5>/0_l00006oi=/T`03o`000?n`Ck3o/4n`00So/4n`0ol000000oo7><Oo0000o`000004okI9]P03
o`000?n`Ck3o/4n`00go/4n`00?o0000ok1?/?n`Ck003?n`Ck000ol0003oXebSoj=LX`07oj=LX`03
o`000?nDJiCoU6^D00WoU6^D00?o0000okU6^OniA[T03?niA[T00ol0003ob3O8olPgb003o`0000ko
[U6^00?o0000okM8]ongB;L00ongB;L00ol0003occ3?oll`c`0>oll`c`05o`000?oD:mCoe2_Dom@[
e?l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooX5n_oj1OX00_oj1OX00ol0003of2OHomPWf009omPWf003o`000?nfBKKo]TVf00[o
]TVf00?o0000ojaC[?l000002?nCK9<00ol0003o/4n`ok1?/00;ok1?/003o`000?nfBKKo]TVf00Go
]TVf00?o0000ok1?/?n`Ck003?n`Ck000ol0003o/4n`ok1?/00<ok1?/003o`000?nSG:?oXebS00Oo
XebS00?o0000oiA[U?nDJi@02?nDJi@2o`0000oo^DJi0_l00002okY5^P03o`000?n^DJko[U6^00_o
[U6^00?o0000okM8]ongB;L01?ngB;L00ol0003occ3?oll`c`0=oll`c`03o`000?oD:mCoe2_D00?o
e2_D00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omPWf003o`000?nfBKKo]TVf00_o]TVf00?o0000oi=/TonCK9<0
1onCK9<00ol0003o/4n`ok1?/00;ok1?/003o`000?nfBKKo]TVf00Ko]TVf00?o0000ok1?/?n`Ck00
2on`Ck02o`0000go/4n`00?o0000oj=LXonSG:<01onSG:<00ol0003oU6^DoiA[U007oiA[U004o`00
0?nMHYgoWF:Mo`0000ko^DJi00?o0000okY5^_njAKX00_njAKX00ol0003o[U6^ojiA[P09ojiA[P03
o`000?ngB;Oo]dRg00Ko]dRg00?o0000oll`coo?<<l02oo?<<l00ol0003oe2_Dom@[e005om@[e004
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000Sof2OH00?o0000okI9]_nfBKH02_nfBKH2o`0000Wo
TfbC00?o0000ok1?/?n`Ck002on`Ck000ol0003o]TVfokI9]P07okI9]P03o`000?n`Ck3o/4n`00Wo
/4n`00Co0000ohMhQon7N8Oo00003?n`Ck000ol0003oXebSoj=LX`07oj=LX`03o`000?nDJiCoU6^D
00KoU6^D00Go0000oieRWOnMHYgoWF:Mo`00000>okU6^@03o`000?njAK[o^TFj00?o^TFj00?o0000
ojiA[_n^DJh01on^DJh00ol0003o]dRgokM8]`07okM8]`03o`000?o?<<oocc3?00[occ3?00?o0000
om@[e?oD:m@01ooD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006omPWf003o`000?nfBKKo]TVf
00Wo]TVf00Co0000oiUVVOnIIYWo00002OnCK9<00ol0003o/4n`ok1?/009ok1?/003o`000?nfBKKo
]TVf00Wo]TVf00?o0000ok1?/?n`Ck001on`Ck000ol0003oQgR7ohMhQ`02ohMhQ`03o`000?n`Ck3o
/4n`00Wo/4n`00?o0000oj=LXonSG:<01onSG:<00ol0003oU6^DoiA[U005oiA[U003o`000?nMHYgo
WF:M00?oWF:M00?o0000okU6^OniA[T02_niA[T00ol0003o^TFjokY5^P05okY5^P03o`000?n^DJko
[U6^00Go[U6^00?o0000okM8]ongB;L02?ngB;L00ol0003occ3?oll`c`09oll`c`03o`000?oD:mCo
e2_D00Soe2_D00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oH9mP3o`0000Wo]TVf00?o0000oiUV
VOnIIYT00_nIIYT00ol0003oTfbCoi=/T`06oi=/T`03o`000?n`Ck3o/4n`00Wo/4n`00?o0000okI9
]_nfBKH02_nfBKH00ol0003o/4n`ok1?/005ok1?/003o`000?n7N8OoQgR700CoQgR700?o0000ok1?
/?n`Ck002?n`Ck000ol0003oXebSoj=LX`07oj=LX`03o`000?nDJiCoU6^D00CoU6^D00?o0000oieR
WOnMHYd01?nMHYd00ol0003o^DJiokU6^@0:okU6^@03o`000?njAK[o^TFj00Ko^TFj00?o0000ojiA
[_n^DJh00on^DJh00ol0003o]dRgokM8]`09okM8]`03o`000?o?<<oocc3?00Socc3?00?o0000om@[
e?oD:m@02OoD:m@00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003omHYeP?o00001OnfBKH00ol0003o
VFJIoiUVV@03oiUVV@03o`000?nCK9?oTfbC00KoTfbC00?o0000ok1?/?n`Ck002On`Ck000ol0003o
]TVfokI9]P0;okI9]P03o`000?n`Ck3o/4n`00?o/4n`00?o0000ohMhQon7N8L01_n7N8L00ol0003o
/4n`ok1?/008ok1?/003o`000?nSG:?oXebS00KoXebS00?o0000oiA[U?nDJi@00_nDJi@2o`0000So
WF:M00?o0000okU6^OniA[T02OniA[T00ol0003o^TFjokY5^P07okY5^P05o`000?n^DJko[U6^ojiA
[_l000003OngB;L00ol0003occ3?oll`c`06oll`c`03o`000?oD:mCoe2_D00[oe2_D00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oF:MKoeRWF00GoeRWF0ol000000onfBKKo0000oiUVV@06oiUVV@03
o`000?nCK9?oTfbC00GoTfbC00?o0000ok1?/?n`Ck002On`Ck000ol0003o]TVfokI9]P0<okI9]P05
o`000?n`Ck3o/4n`ok1?/?l000002_n7N8L00ol0003o/4n`ok1?/007ok1?/003o`000?nSG:?oXebS
00KoXebS00?o0000oiA[U?l000000_l000000ono?koo0000oieRW@07oieRW@03o`000?niA[Wo^DJi
00So^DJi00?o0000okY5^_njAKX02OnjAKX00ol0003o[U6^o`00000=okM8]`Co00001Oo?<<l00ol0
003oe2_Dom@[e00;om@[e003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeRWFomHYeP08omHYeP03
o`000?nIIYWoVFJI00OoVFJI00?o0000oi=/TonCK9<01?nCK9<00ol0003o/4n`ok1?/009ok1?/003
o`000?nfBKKo]TVf00go]TVf00?o0000ok1?/?l000003?n7N8L:o`0000OoXebS0ol00005oklo_`03
o`000?nMHYgoWF:M00KoWF:M00?o0000okU6^OniA[T01oniA[T00ol0003o^TFjokY5^P0:okY5^P03
o`000?ngB;Oo]dRg00_o]dRg00?o0000okU6^OniA[T00_niA[T3o`000003oll`col0003oe2_D00_o
e2_D0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000omHYe_oF:MH02OoF:MH00ol0003oVFJIoiUVV@07oiUVV@03o`00
0?nCK9?oTfbC00GoTfbC00?o0000ok1?/?n`Ck001on`Ck000ol0003o]TVfokI9]P0?okI9]P;o0000
2on7N8L00ol0003o^4NhokQ7^007okQ7^003o`000?nSG:?oXebS00;oXebS0ol00008oklo_`03o`00
0?nMHYgoWF:M00KoWF:M00?o0000okU6^OniA[T01oniA[T00ol0003o^TFjokY5^P0:okY5^P03o`00
0?ngB;Oo]dRg00[o]dRg00?o0000okU6^OniA[T01_niA[T00ol0003oe2_Dom@[e008om@[e0?o0000
0_oO7ml00ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000omHYe_oF:MH02OoF:MH00ol0003oVFJIoiUV
V@08oiUVV@03o`000?nCK9?oTfbC00CoTfbC00?o0000ok1?/?n`Ck001on`Ck000ol0003o]TVfokI9
]P0>okI9]P04o`000?nEJYGoUFZEo`0000WoQgR700?o0000okQ7^?nhAkP02OnhAkP01?l0003oXebS
o`000?l0000<oklo_`03o`000?nMHYgoWF:M00KoWF:M00?o0000okU6^OniA[T01_niA[T00ol0003o
^TFjokY5^P0;okY5^P03o`000?ngB;Oo]dRg00Oo]dRg0_l00009okU6^@03o`000?oD:mCoe2_D00Co
e2_D1?l00006omlOg`03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003oeRWFomHYeP09omHYeP03o`00
0?nIIYWoVFJI00SoVFJI00?o0000oi=/TonCK9<00onCK9<>o`0000go]TVf00?o0000oiEZUOnEJYD0
0_nEJYD00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?nhAkSo^4Nh00_o^4Nh00?o0000oklo_ono?kl0
3?no?kl00ol0003oWF:MoieRW@06oieRW@03o`000?niA[Wo^DJi00Go^DJi00?o0000okY5^_njAKX0
3?njAKX00ol0003o]dRgokM8]`06okM8]`03o`000?niA[Wo^DJi00[o^DJi00?o0000om@[e?oD:m@0
0ol0000:omlOg`?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oF:MKoeRWF00_oeRWF00?o0000oiUVVOnIIYT02?nI
IYT01Ol0003oTfbCoi=/TonCK9?o000000_oYeRW00?o0000og><LomcS7<00ol00009okI9]P03o`00
0?nEJYGoUFZE00CoUFZE00?o0000ohMhQon7N8L00on7N8L00ol0003o^4NhokQ7^00<okQ7^003o`00
0?no?koo_cno00go_cno00?o0000oieRWOnMHYd01_nMHYd00ol0003o^DJiokU6^@03okU6^@?o0000
3OnjAKX00ol0003o]dRgokM8]`05okM8]`03o`000?niA[Wo^DJi00co^DJi0_l0000=omlOg`03o`00
0?ok1?_on`Ck00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oF:MKoeRWF00_oeRWF00?o0000oiUVVOnIIYT02?nI
IYT4o`0000coYeRW00?o0000og><LomcS7<00omcS7<3o`0000Go]TVf00?o0000oiEZUOnEJYD01_nE
JYD01Ol0003oQgR7ohMhQon7N8Oo000000oo^4Nh00?o0000oklo_ono?kl03Ono?kl00ol0003oWF:M
oieRW@06oieRW@03o`000?niA[Wo^DJi00?o00000onOGil00ol0003o^TFjokY5^P0;okY5^P03o`00
0?ngB;Oo]dRg00?o]dRg00?o0000okU6^OniA[T03OniA[T00ol0003ogaoOomlOg`0;omlOg`03o`00
0?ok1?_on`Ck00Con`Ck0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000omHYe_oF:MH02_oF:MH3o`0000KoVFJI0ol0
0003oi]TV`03o`000?nWF:OoYeRW00[oYeRW00?o0000og><LomcS7<01_mcS7<3o`000003okI9]_l0
003oUFZE00WoUFZE00?o0000ohMhQol000004?nhAkP00ol0003o_cnooklo_`0=oklo_`03o`000?nM
HYgoWF:M00OoWF:M0_l00007oimOW`03o`000?njAK[o^TFj00[o^TFj00Co0000okM8]ongB;Oo]dRg
0ol0000?okU6^@03o`000?oO7moogaoO00_ogaoO00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omHYe_oF:MH02_oF
:MH01?l0003o_D:moke2_Onm@[d2o`000004oiUVVOl0003o0000o`0000KoVfBK00?o0000ojMHYonW
F:L02_nWF:L00ol0003oLhacog><L`09og><L`03o`000?nEJYGoUFZE00[oUFZE00?o0000okQ7^?nh
AkP03onhAkP00ol0003o_cnooklo_`0>oklo_`03o`000?nMHYgoWF:M00KoWF:M00?o0000oimOWonO
Gil01onOGil4o`0000So^TFj00Co0000okM8]ongB;Oo00000on?L8l2o`0000go^DJi00?o0000omlO
gooO7ml02_oO7ml00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omHYe_oF:MH02OoF:MH00ol0003o
_D:moke2_@04oke2_@03o`000?nKI9_oVfBK00OoVfBK00?o0000ojMHYonWF:L02OnWF:L00ol0003o
Lhacog><L`0:og><L`03o`000?nEJYGoUFZE00[oUFZE00?o0000okQ7^?nhAkP03onhAkP00ol0003o
_cnooklo_`0>oklo_`03o`000?nMHYgoWF:M00GoWF:M00?o0000oimOWonOGil02?nOGil01?l0003o
[5>/ojaC[?n/Dj`7o`0000;o^TFj0_l00006ohm`S`;o00003?niA[T00ol0003ogaoOomlOg`09omlO
g`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oeRWFomHYeP08omHYeP03o`000?nm@[go_D:m00Go
_D:m00?o0000oi]TVonKI9/02?nKI9/00ol0003oYeRWojMHY`08ojMHY`03o`000?mcS7?oLhac00[o
Lhac00?o0000oiEZUOnEJYD02onEJYD00ol0003o^4NhokQ7^00>okQ7^003o`000?no?koo_cno00ko
_cno1Ol00002oieRW@03o`000?nOGiooWenO00WoWenO00?o0000ojaC[?n/Dj`02?n/Dj`3o`0000Wo
Sg2?0_l0000:okU6^@03o`000?oO7moogaoO00SogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oF:MKoeRWF00SoeRWF00?o0000oke2_Onm@[d01onm@[d00ol0003oVfBKoi]TV`07oi]TV`03o`00
0?nWF:OoYeRW00SoYeRW00?o0000og><LomcS7<02_mcS7<00ol0003oUFZEoiEZU@0:oiEZU@;o0000
3_nhAkP3o`0000go_cno0ol00005ol8m`P;o00002onOGil00ol0003o[5>/ojaC[00;ojaC[0;o0000
2_n?L8l2o`0000Oo^DJi0ol00009omlOg`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:oke2_@03o`00
0?nKI9_oVfBK00OoVfBK00?o0000ojMHYonWF:L02?nWF:L>o`0000WoUFZE0ol000000omiQWWo0000
okQ7^00:okQ7^0?o00000_o5>/D00ol0003o_cnooklo_`09oklo_`;o00002Oo2?L800ol0003oWenO
oimOW`09oimOW`03o`000?n/Djco[5>/00_o[5>/00?o0000okI9]_l000002on?L8l2o`0000Co^DJi
00Co0000omPWf?oH9mSof2OH0_l00007omlOg`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003o_D:m
oke2_@09oke2_@03o`000?nKI9_oVfBK00KoVfBK00?o0000ojMHYonWF:L02?nWF:L00ol0003oPGj1
oh5nP@0:oh5nP@03o`000?nEJYGoUFZE00CoUFZE0ol00005ogV6N@03o`000?nhAkSo^4Nh00Co^4Nh
1?l00006olDja@03o`000?no?koo_cno00Ko_cno0_l0000;ol8m`P03o`000?nOGiooWenO00WoWenO
00?o0000ojaC[?n/Dj`02_n/Dj`01Ol0003o]TVfokI9]_nfBKKo000000coSg2?0_l000000oniA[Wo
0000omPWf005omPWf003o`000?oO7moogaoO00?ogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?nm@[go_D:m00So_D:m00?o0000oi]TVonKI9/01_nKI9/00ol0003oYeRWojMHY`07ojMHY`03o`00
0?n1OX7oPGj100_oPGj100?o0000oiEZUOnEJYD00_nEJYD2o`0000WoNHIi00?o0000okQ7^?nhAkP0
0ol0000;olDja@03o`000?no?koo_cno00;o_cno0ol0000>ol8m`P03o`000?nOGiooWenO00OoWenO
00?o0000ojaC[?n/Dj`02on/Dj`00ol0003o]TVfokI9]P02okI9]P03o`000?n?L8ooSg2?00_oSg2?
00?o0000omPWf?oH9mP01_oH9mP2o`0000?ogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?nm
@[go_D:m00Oo_D:m00?o0000oi]TVonKI9/01onKI9/00ol0003oYeRWojMHY`05ojMHY`?o00003On1
OX44o`0000_oNHIi0ol0000?olDja@04o`000?no?koo0000o`00017o`Sg200?o0000oimOWonOGil0
1onOGil00ol0003o[5>/ojaC[00:ojaC[003o`000?nfBKKo]TVf00Co]TVf00?o0000ohm`Son?L8l0
1on?L8l3o`0000_of2OH1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oke2_Onm@[d02?nm@[d00ol0003oVfBKoi]T
V`06oi]TV`03o`000?nWF:OoYeRW00;oYeRW0ol00003oiUVV@03o`000?n1OX7oPGj100[oPGj100?o
0000ogV6NOmiQWT02omiQWT00ol0003oQ7^4o`00000AolDja@03o`000?o2?L;o`Sg2017o`Sg200?o
0000oimOWonOGil01onOGil00ol0003o[5>/ojaC[00:ojaC[003o`000?nfBKKo]TVf00Go]TVf00Co
0000ohm`Son?L8ooSg2?1Ol00002oimPW`03o`000?oH9mSof2OH00Wof2OH00Co0000ooX5n_oj1O[o
nPGj0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oke2_Onm@[d01onm@[d00ol0003oVfBKoi]TV`05oi]TV`?o0000
00?oYeRWo`000?l000001onIIYT00ol0003oPGj1oh5nP@08oh5nP@?o00002_miQWT2o`0000;oQ7^4
00?o0000olDjaOo5>/D03oo5>/D00ol0003o`Sg2ol8m`P0Aol8m`P03o`000?nOGiooWenO00OoWenO
00?o0000ojaC[?n/Dj`02On/Dj`00ol0003o]TVfokI9]P07okI9]P?o00001onOH9l00ol0003of2OH
omPWf009omPWf003o`000?oj1O[onPGj00ConPGj0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oke2_Onm@[d01onm
@[d4o`0000;oVfBK0_l00003ojaC[003o`000?nIIYWoVFJI00SoVFJI0_l00006oh5nP@;o00000on7
N8L00ol0003oNHIiogV6N@06ogV6N@03o`000?n4NhCoQ7^400?oQ7^400?o0000olDjaOo5>/D03_o5
>/D00ol0003o`Sg2ol8m`P0Bol8m`P03o`000?nOGiooWenO00GoWenO00?o0000ojaC[?n/Dj`02On/
Dj`00ol0003o]TVfokI9]P08okI9]P03o`000?nOH9ooWf2O00OoWf2O00?o0000omPWf?oH9mP02?oH
9mP00ol0003onPGjooX5nP07ooX5nP;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?nm@[go_D:m00Co_D:m0_l00004
om8]dP;o00001On/Dj`00ol0003oVFJIoiUVV@0:oiUVV@03o`000?n1OX7oPGj100;oPGj100?o0000
ohMhQon7N8L01?n7N8L00ol0003oNHIiogV6N@04ogV6N@03o`000?n4NhCoQ7^400CoQ7^400?o0000
olDjaOo5>/D03_o5>/D00ol0003o`Sg2ol8m`P0Bol8m`P[o00002_n/Dj`00ol0003o]TVfokI9]P08
okI9]P03o`000?nOH9ooWf2O00OoWf2O00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP09
ooX5nP?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_D:moke2_Onm@[d2o`0000OodRgB00?o0000ojaC[?n/Dj`01?n/Dj`0
0ol0003oVFJIoiUVV@0:oiUVV@04o`000?n1OX7o0000o`0000SoQgR700Co0000ogV6NOmiQWWoNHIi
0_l00007ohAkQ003o`000?o5>/GoaC[500koaC[500?o0000ol8m`_o2?L804_o2?L800ol0003oZEJY
ojUFZ@07ojUFZ@03o`000?n/Djco[5>/00Ko[5>/00?o0000okI9]_nfBKH02_nfBKH00ol0003oWf2O
oimPW`06oimPW`03o`000?oH9mSof2OH00Sof2OH00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?nm
@[go0000o`0000WodRgB00?o0000ojaC[?n/Dj`01?n/Dj`00ol0003oVFJIoiUVV@0;oiUVV@03o`00
0?n7N8OoQgR700WoQgR700?o0000ogV6NOl000002On4Nh@00ol0003oaC[5olDja@0>olDja@;o0000
4_o2?L800ol0003oZEJYojUFZ@09ojUFZ@;o00001_n/Dj`00ol0003o]TVfokI9]P0:okI9]P03o`00
0?nOH9ooWf2O00KoWf2O00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om8]d_oB;M802OoB;M800ol0003o[5>/ojaC[005ojaC[003o`000?nIIYWoVFJI00[oVFJI00?o
0000ohMhQon7N8L02_n7N8L2o`0000WoQ7^400?o0000olDjaOo5>/D03_o5>/D00ol0003o]TVfo`00
0002o`0000oo`Sg200?o0000ojUFZOnYEZT02onYEZT00ol0003o[5>/ojaC[003o`0000go]TVf00?o
0000oimPWonOH9l01_nOH9l00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odRgBom8]dP09om8]dP03o`000?n/Djco[5>/00Go[5>/00?o0000oiUVVOnIIYT02OnIIYT2
o`0000_oQgR70_l0000;ohAkQ003o`000?o5>/GoaC[500coaC[500?o0000okI9]_nfBKH00onfBKH3
o`0000co`Sg200?o0000ojUFZOnYEZT03?nYEZT2o`0000;oY5^T00?o0000okI9]_nfBKH03?nfBKH0
0ol0003oWf2OoimPW`05oimPW`03o`000?oH9mSof2OH00Oof2OH00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oB;M;odRgB00[odRgB00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003oVFJIoiUVV@07oiUV
V@03o`000?n7N8Oo000000[oQgR700Co0000ogF:MOmeRWGo00002_n4Nh@00ol0003oaC[5olDja@0<
olDja@03o`000?nfBKKo]TVf00Ko]TVf0_l00008ol8m`P;o00003onYEZT00ol0003oY5^TojAKY002
ojAKY003o`000?nfBKKo]TVf00_o]TVf00?o0000oimPWonOH9l01OnOH9l00ol0003of2OHomPWf007
omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odRgBom8]dP0:om8]dP03o`000?n/Djco[5>/
00Ko[5>/00?o0000oiUVVOnIIYT01_nIIYT01Ol0003oQgR7ohMhQon7N8Oo000000SoQgR700?o0000
ogF:MOmeRWD00_meRWD00ol0003oQ7^4ohAkQ006ohAkQ0Co00003?o5>/D00ol0003o]TVfokI9]P08
okI9]P?o00000_o2?L83o`000003ojMHYol0003oZEJY00goZEJY00?o0000ojAKY?nTFj@01?nTFj@0
0ol0003o]TVfokI9]P0:okI9]P03o`000?nOH9ooWf2O00GoWf2O00?o0000omPWf?oH9mP01_oH9mP0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om8]d_oB;M802ooB;M800ol0003o[5>/ojaC[007ojaC
[003o`000?nIIYWoVFJI00?oVFJI0_l00005ohMhQ`03o`000?n7N8OoQgR700CoQgR700?o0000ogF:
MOmeRWD00omeRWD00ol0003oQ7^4ohAkQ005ohAkQ003o`000?nOH9ooWf2O00;oWf2O0ol00007olDj
a@;o00003_nfBKH2o`0000GoYeRW00?o0000ojUFZOnYEZT02_nYEZT00ol0003oY5^TojAKY005ojAK
Y003o`000?nfBKKo]TVf00_o]TVf00?o0000oimPWonOH9l01?nOH9l00ol0003of2OHomPWf006omPW
f003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odRgBom8]dP0;om8]dP03o`000?n/Djco[5>/00Oo
[5>/00?o0000oiUVVOnIIYT00_nIIYT00ol0003oQgR7ohMhQ`06ohMhQ`03o`000?n7N8OoQgR700;o
QgR700?o0000ogF:MOmeRWD01OmeRWD00ol0003oQ7^4ohAkQ002ohAkQ0;o00002?nOH9l3o`0000;o
aC[50_l000000onVFJKo0000okI9]P0=okI9]P03o`000?nWF:OoYeRW00GoYeRW00?o0000ojUFZOnY
EZT02?nYEZT00ol0003oY5^TojAKY007ojAKY003o`000?nfBKKo]TVf00[o]TVf00?o0000oimPWonO
H9l01?nOH9l00ol0003of2OHomPWf006omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odRgB
om8]dP0<om8]dP03o`000?n/Djco[5>/00So[5>/00Co0000oiUVVOnIIYWo00002On7N8L01Ol0003o
QgR7ohMhQon7N8Oo000000SoMHYe00Go0000ohAkQ?n4NhCoQ7^4o`00000=oimPW`;o00001?nVFJH0
0ol0003o]TVfokI9]P0;okI9]P03o`000?nWF:OoYeRW00KoYeRW00?o0000ojUFZOnYEZT01onYEZT0
0ol0003oY5^TojAKY008ojAKY0Co00002?nfBKH00ol0003oWf2OoimPW`04oimPW`03o`000?oH9mSo
f2OH00Kof2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oB;M;odRgB00_odRgB0ol00009ojaC
[003o`000?nIIYWo000000_oQgR700?o0000ohMhQol000002_meRWD00ol0003oQ7^4o`00000?oimP
W`03o`000?nVFJKoYUVV00;oYUVV00?o0000okI9]_nfBKH02onfBKH00ol0003oYeRWojMHY`06ojMH
Y`03o`000?nYEZWoZEJY00KoZEJY00?o0000ojAKY?nTFj@02OnTFj@01?l0003o/dbcok=</oncC;<7
o`0000;o]TVf00?o0000oimPWonOH9l00onOH9l00ol0003of2OHomPWf005omPWf003o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oB;M;odRgB00SodRgB0ol00003oka3_003o`000?n/Djco[5>/00Oo[5>/00?o0000ohMh
Qon7N8L02on7N8L00ol0003oMHYeogF:M@0:ogF:M@03o`000?nOH9ooWf2O00goWf2O00?o0000ojII
Y_nVFJH01?nVFJH00ol0003o]TVfokI9]P09okI9]P03o`000?nWF:OoYeRW00SoYeRW00?o0000ojUF
ZOnYEZT00onYEZT2o`0000coY5^T00?o0000ok=</oncC;<02?ncC;<<o`0000?of2OH0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om8]d_oB;M801_oB;M83o`0000Oo_4>l00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003o
QgR7ohMhQ`0;ohMhQ`03o`000?meRWGoMHYe00WoMHYe0_l0000>oimPW`03o`000?nVFJKoYUVV00Go
YUVV00?o0000okI9]_nfBKH02OnfBKH00ol0003oYeRWojMHY`09ojMHY`03o`000?nYEZWo000000;o
00000_nMHYd00ol0003oY5^TojAKY008ojAKY003o`000?ncC;?o/dbc00co/dbc00?o0000omdRgOoM
8]d01_oM8]d3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odRgBom8]dP03om8]dP?o00002onl@k`00ol0003o[5>/
ojaC[004ojaC[003o`000?n7N8OoQgR700_oQgR70ol00007ogF:M@?o000000?oU6^Do`000?nOH9l0
3OnOH9l00ol0003oYUVVojIIYP06ojIIYP03o`000?nfBKKo]TVf00So]TVf00?o0000ojMHYonWF:L0
2_nWF:L00ol0003oWF:MoieRW@04oieRW@03o`000?nTFjCoY5^T00OoY5^T00?o0000ok=</oncC;<0
2oncC;<00ol0003ogB;MomdRg@08omdRg@03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om8]d_l0
003o0000o`0000oo_4>l00?o0000ojaC[?n/Dj`00on/Dj`>o`0000?oQgR70_l00002ogF:M@?o0000
1OnDJi@00ol0003oWf2OoimPW`0:oimPW`03o`000?nVFJKoYUVV00OoYUVV00?o0000okI9]_nfBKH0
2?nfBKH00ol0003oYeRWojMHY`0:ojMHY`03o`000?nMHYgoWF:M00GoWF:M00?o0000ojAKY?nTFj@0
1_nTFj@00ol0003o/dbcok=</`0;ok=</`03o`000?oM8]gogB;M00SogB;M00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o_4>l00?o0000ojaC[?n/Dj`00_n/Dj`00ol0003oMHYeogF:
M@0:ogF:M@03o`000?n7N8OoQgR700?oQgR70_l00009oiA[U003o`000?nOH9ooWf2O00WoWf2O00?o
0000ojIIY_nVFJH02?nVFJH2o`0000So]TVf00?o0000ojMHYonWF:L02OnWF:L00ol0003oWF:MoieR
W@07oieRW@03o`000?nTFjCoY5^T00CoY5^T00?o0000ok=</oncC;<02oncC;<00ol0003ogB;MomdR
g@09omdRg@03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o_4>loka3_00?oka3_0?o000000?o[5>/
o`000?meRWD02omeRWD00ol0003oQgR7ohMhQ`04ohMhQ`03o`000?nDJiCoU6^D00WoU6^D00?o0000
oimPWonOH9l01onOH9l00ol0003oYUVVojIIYP09ojIIYP04o`000?nRGJ;o0000o`0000Ko]TVf00?o
0000ojMHYonWF:L02OnWF:L00ol0003oWF:MoieRW@08oieRW@03o`000?nTFjCoY5^T00?oY5^T00?o
0000ok=</oncC;<02oncC;<00ol0003ogB;MomdRg@09omdRg@03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o_4>loka3_00<oka3_0;o00000oncC;<2o`0000coMHYe00?o0000ohMhQon7N8L01?n7N8L0
0ol0003oU6^DoiA[U00:oiA[U0Wo00002onVFJH00ol0003oXUfRoj9MXP02oj9MXP?o00000_nfBKH0
0ol0003oYeRWojMHY`0:ojMHY`03o`000?nMHYgoWF:M00WoWF:M00?o0000ojAKY?nTFj@00_nTFj@0
0ol0003o/dbcok=</`0:ok=</`03o`000?oM8]gogB;M00WogB;M00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_nl@k`2o`0000Go/dbc00?o0000oi]TVol000002_meRWD00ol0003oQgR7ohMhQ`06ohMh
Q`03o`000?nDJiCoU6^D00WoU6^D00?o0000oiEZUOnEJYD01OnEJYD00ol0003oYUVVojIIYP09ojII
YP03o`000?nRGJ;oXUfR00GoXUfR0ol00009ojMHY`?o00003OnMHYd01Ol0003oY5^TojAKY?nTFjCo
000000co/dbc00?o0000omdRgOoM8]d02OoM8]d00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000oka3
_?nl@k`01Onl@k`2o`0000Oo/dbc00Co0000oi]TVonKI9_o00002OmeRWD00ol0003oQgR7ohMhQ`06
ohMhQ`03o`000?nDJiCoU6^D00SoU6^D00?o0000oiEZUOnEJYD01onEJYD00ol0003oYUVVojIIYP07
ojIIYP03o`000?nRGJ;oXUfR00SoXUfR0ol00002ojMHY`Go00000_mjQGX00ol0003oWF:MoieRW@0<
oieRW@03o`000?nTFjCo000000co/dbc00?o0000omdRgOoM8]d02_oM8]d00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000oka3_?nl@k`00_nl@k`2o`0000So/dbc00?o0000oi]TVonKI9/00_nKI9/5o`00
00CoMHYe00?o0000ohMhQon7N8L01_n7N8L00ol0003oU6^DoiA[U008oiA[U003o`000?nEJYGoUFZE
00OoUFZE00?o0000ojIIY_nVFJH01onVFJH00ol0003oXUfRoj9MXP08oj9MXP03o`000?mlPgcoO8=l
00;o00002?mjQGX00ol0003oWF:MoieRW@0<oieRW@Co00002_ncC;<00ol0003ogB;MomdRg@0:omdR
g@03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o_4>lo`000?l0000:ok=</`03o`000?nKI9_oVfBK
00;oVfBK00?o0000odn`Com?/4l00_m?/4l4o`0000WoQgR700?o0000oiA[U?nDJi@02?nDJi@00ol0
003oUFZEoiEZU@08oiEZU@03o`000?nVFJKoYUVV00GoYUVV00?o0000oj9MX_nRGJ802?nRGJ801Ol0
003oO8=logb3O?mlPgco000000[oNXEj0ol0000;oieRW@04o`000?o<<lcoc3?<ol`cc0Co00001Onc
C;<00ol0003ogB;MomdRg@0;omdRg@03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o/dbcok=</`0:
ok=</`03o`000?nKI9_oVfBK00?oVfBK00?o0000odn`Com?/4l01?m?/4l00ol0003oQgR7ohMhQ`07
ohMhQ`03o`000?nDJiCoU6^D00KoU6^D0_l0000;oiEZU@03o`000?nVFJKoYUVV00GoYUVV00?o0000
oj9MX_nRGJ802?nRGJ800ol0003oO8=logb3O002ogb3O003o`000?mjQG[oNXEj00OoNXEj00?o0000
oiiQW_nNHIh01?l00006oieRW@03o`000?o<<lcoc3?<00Koc3?<0ol00002ok=</`03o`000?oM8]go
gB;M00_ogB;M00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?ncC;?o/dbc00Wo/dbc00?o0000oi]T
VonKI9/01?nKI9/00ol0003oCk1?odn`C`05odn`C`03o`000?n7N8OoQgR700OoQgR700?o0000oiA[
U?nDJi@00_nDJi@3o`000003oiiQW_l0003oUFZE00[oUFZE00?o0000ojIIY_nVFJH01OnVFJH00ol0
003oXUfRoj9MXP07oj9MXP03o`000?mlPgcoO8=l00?oO8=l00?o0000ogZ5N_mjQGX01omjQGX00ol0
003oWV6NoiiQWP04oiiQWP?o00000_nMHYd00ol0003oc3?<ol`cc00:ol`cc0;o00003_oM8]d00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok=</oncC;<02OncC;<00ol0003oVfBKoi]TV`04oi]TV`03
o`000?m?/4ooCk1?00KoCk1?0_l00007ohMhQ`03o`000?nDJiCo000000;o00001OnNHIh00ol0003o
UFZEoiEZU@08oiEZU@?o00001?nVFJH00ol0003oXUfRoj9MXP08oj9MXP03o`000?mlPgcoO8=l00Co
O8=l00?o0000ogZ5N_mjQGX01_mjQGX00ol0003oWV6NoiiQWP07oiiQWP;o00003_o<<l`00ol0003o
gB;MomdRg@0;omdRg@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/dbcok=</`08ok=</`03o`00
0?nKI9_oVfBK00GoVfBK00?o0000odn`Com?/4l01?m?/4l00ol0003oQ7^4ohAkQ003o`0000CoQgR7
0_l00008oiiQWP03o`000?nEJYGoUFZE00OoUFZE00Co0000okQ7^?nhAkSo^4Nh0ol000000onVFJKo
0000oj9MXP09oj9MXP03o`000?mlPgcoO8=l00CoO8=l00?o0000ogZ5N_mjQGX01OmjQGX00ol0003o
WV6NoiiQWP09oiiQWP03o`000?o<<lcoc3?<00goc3?<00?o0000omdRgOoM8]d02_oM8]d00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok=</oncC;<01oncC;<00ol0003oVfBKoi]TV`06oi]TV`03o`00
0?m?/4ooCk1?00?oCk1?00?o0000ohAkQ?n4Nh@01?n4Nh@2o`000003ohMhQol0003oWV6N00[oWV6N
00?o0000oiEZUOnEJYD01OnEJYD00ol0003o^4NhokQ7^005okQ7^003o`000?nRGJ;oXUfR00OoXUfR
0ol00007ogb3O003o`000?mjQG[oNXEj00CoNXEj00?o0000oiiQW_nNHIh02OnNHIh00ol0003oc3?<
ol`cc00=ol`cc003o`000?oM8]gogB;M00[ogB;M00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nc
C;?o/dbc00Go/dbc0ol00009oi]TV`05o`000?m?/4ooCk1?odn`Col000002On4Nh@00ol0003oWV6N
oiiQWP0;oiiQWP03o`000?nEJYGoUFZE00?oUFZE00?o0000okQ7^?nhAkP01_nhAkP00ol0003oXUfR
oj9MXP06oj9MXP05o`000?nSG:?oXebSoj=LXol000001omlPg`00ol0003oNXEjogZ5NP03ogZ5NP03
o`000?nNHIkoWV6N00WoWV6N00?o0000ol`cc?o<<l`03_o<<l`00ol0003ogB;MomdRg@09omdRg@03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/dbco`000004o`0000;occ3?00?o0000oi]TVonKI9/0
1onKI9/01?l0003oCk1?odn`Col00009ohAkQ0;o00003OnNHIh00ol0003oUFZEoiEZU@02oiEZU@03
o`000?nhAkSo^4Nh00So^4Nh00?o0000oj9MX_nRGJ800onRGJ82o`0000GoXebS00?o0000ogb3O?ml
Pg`01?mlPg`00ol0003oNXEjogZ5NP03ogZ5NP03o`000?nNHIkoWV6N00WoWV6N00?o0000ol`cc?o<
<l`03_o<<l`00ol0003ogB;MomdRg@09omdRg@03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Socc3?
00?o0000oi]TVonKI9/01_nKI9/00ol0003oCk1?o`000009ohAkQ004o`000?nYEZWoZEJYo`0000go
WV6N00Co0000oiEZUOnEJYGo00003?nhAkP01Ol0003oXUfRoj9MX_nRGJ;o000000SoXebS0_l00005
ogb3O003o`000?mjQG[oNXEj00;oNXEj00?o0000oiiQW_nNHIh02OnNHIh00ol0003oc3?<ol`cc00>
ol`cc003o`000?oM8]gogB;M00WogB;M00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?
00Oocc3?00?o0000oi]TVonKI9/01onKI9/00ol0003oQ7^4ohAkQ007ohAkQ003o`000?nYEZWoZEJY
00;oZEJY00?o0000oiiQW_nNHIh02_nNHIh00ol0003oUFZEo`00000>okQ7^003o`000?nRGJ;o0000
00_oXebS00?o0000ogb3O?mlPg`00_mlPg`01Ol0003oNXEjogZ5N_mjQG[o000000coWV6N00?o0000
ol`cc?o<<l`03_o<<l`3o`0000WogB;M00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000oi]TVonKI9/01_nKI9/00ol0003oQ7^4ohAkQ006ohAkQ003o`000?nYEZWoZEJY
00?oZEJY00?o0000oiiQW_nNHIh02onNHIh00ol0003o^4NhokQ7^00>okQ7^003o`000?nSG:?oXebS
00_oXebS0_l00003ogb3O004o`000?mjQG[oNXEjo`0000[oWV6N0ol0000>ol`cc0;o00000ooj1OX2
o`0000OogB;M00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?00[occ3?00?o0000oi]T
VonKI9/01?nKI9/00ol0003oQ7^4ohAkQ006ohAkQ003o`000?nYEZWoZEJY00GoZEJY00?o0000oiiQ
W_nNHIh01onNHIh3o`00017o^4Nh00?o0000oj=LXonSG:<03OnSG:<01Ol0003oO8=logb3O?l0003o
NXEj00Co00000onNHIh5o`0000;o_T6n00?o0000ol`cc?o<<l`02_o<<l`2o`0000OonPGj0_l00004
omdRg@03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003occ3?oll`c`0;oll`c`03o`000?nKI9_oVfBK
00CoVfBK00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003oZEJYojUFZ@06ojUFZ@03o`000?nNHIkoWV6N
00CoWV6N0ol00002ojQGZ003o`000?nhAkSo^4Nh00oo^4Nh0_l0000?oj=LX`04o`000?mlPgco0000
o`0000CoUfRG0ol00008oki1_P03o`000?o<<lcoc3?<00Ooc3?<0_l0000;ooX5nP;o00000_oM8]d0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000oll`coo?<<l03?o?<<l6o`0000OoQ7^400?o0000ojUF
ZOnYEZT02?nYEZT00ol0003oWV6NoiiQWP03o`0000KoZ5NX00?o0000okQ7^?nhAkP03OnhAkP01?l0
003o/Tfbok9=/_l0000?oj=LX`03o`000?nGJ9OoUfRG00GoUfRG00?o0000oki1__nn@Kh02?nn@Kh0
0ol0003oc3?<ol`cc005ol`cc003o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o?<<l00ol0003oVfBKoi]TV`04oi]T
V`03o`000?n4NhCoQ7^400?oQ7^400?o0000ojUFZOnYEZT02_nYEZT2o`0000[oZ5NX00?o0000okQ7
^?nhAkP02onhAkP00ol0003o/Tfbok9=/P02ok9=/P03o`000?nSG:?oXebS00_oXebS0_l00007oiMX
U`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ol`cc?o<<l`00_o<<l`2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000oll`coo?<<l02oo?<<l00ol0003oVfBKoi]TV`06oi]TV`05o`000?n4NhCoQ7^4ohAk
Q?l000003OnYEZT00ol0003oZ5NXojQGZ00:ojQGZ003o`000?nhAkSo^4Nh00Wo^4Nh00?o0000ok9=
/_nbCK801?nbCK800ol0003oXebSoj=LX`08oj=LX`;o000000?oOh1oo`000?nGJ9L01onGJ9L00ol0
003o_T6noki1_P09oki1_P04o`000?o<<lco0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000oi]TVonKI9/02?nKI9/00ol0003oQ7^4o`00000=ojUFZ@03o`000?nXEjSoZ5NX
00_oZ5NX00?o0000okQ7^?nhAkP02?nhAkP00ol0003o/Tfbok9=/P06ok9=/P03o`000?nSG:?oXebS
00GoXebS0_l00003ogn0O`03o`000?nGJ9OoUfRG00KoUfRG00?o0000oki1__nn@Kh02_nn@Kh00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003occ3?oll`c`07oll`c`03o`000?nKI9_oVfBK00[oVfBK00?o0000ojUFZOnY
EZT03?nYEZT00ol0003oZ5NXojQGZ00<ojQGZ003o`000?nhAkSo^4Nh00Ko^4Nh00?o0000ok9=/_nb
CK802?nbCK800ol0003oXebSoj=LX`02oj=LX`;o00001_moP7l00ol0003oUfRGoiMXU`05oiMXU`03
o`000?nn@Kko_T6n00[o_T6n00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?00Gocc3?
00?o0000oi]TVonKI9/03?nKI9/2o`0000coZEJY00?o0000ojQGZ?nXEjP03OnXEjP00ol0003o^4Nh
okQ7^004okQ7^003o`000?nbCK;o/Tfb00[o/Tfb00Co0000oj=LXol0003o00002?moP7l00ol0003o
UfRGoiMXU`06oiMXU`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_o?<<l00ol0003oVfBKoi]TV`0=oi]TV`03o`000?nOH9oo000000;o00002?nYEZT00ol0003oZ5NX
ojQGZ00?ojQGZ0Ko00003_nbCK800ol0003oOh1oogn0O`08ogn0O`03o`000?nGJ9OoUfRG00KoUfRG
00?o0000oki1__nn@Kh02Onn@Kh00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000ol/dboo;=<_obcC;
0_l0000?oi]TV`03o`000?nOH9ooWf2O00?oWf2O0ol00005ojUFZ@;o00004?nXEjP01_l0003oVFJI
oiUVVOl0003oQWV6o`0000ko/Tfb00?o0000ogn0OomoP7l02OmoP7l00ol0003oUfRGoiMXU`05oiMX
U`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000ol/dboo;=</00oo;=</00ol0003o
VfBKoi]TV`0=oi]TV`03o`000?nOH9ooWf2O00KoWf2O0ol000001?nYEZWo0000oimPWonOH9l3o`00
00coZ5NX00Go0000oiUVVOnIIYWoVFJIo`000002ohIiQP03o`000?nbCK;o/Tfb00_o/Tfb00?o0000
ogn0OomoP7l02OmoP7l00ol0003oUfRGoiMXU`06oiMXU`03o`000?nn@Kko_T6n00So_T6n0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003obcC;ol/db`04ol/db`oo00003?nOH9l00ol0003oWf2OoimPW`04oimP
W`?o00002?nXEjP00ol0003oVFJIoiUVV@02oiUVV@05o`000?n6NHKoQWV6ohIiQ_l000003?nbCK80
0ol0003oOh1oogn0O`09ogn0O`03o`000?nGJ9OoUfRG00GoUfRG3?l00002om`Sg0;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003obcC;ol/db`05ol/db`03o`000?n7N8OoQgR700_oQgR700?o0000oimP
WonOH9l02_nOH9l00ol0003oWf2OoimPW`07oimPW`;o00001OnXEjP00ol0003oVFJIoiUVV@03oiUV
V@03o`000?n6NHKoQWV600;oQWV600?o0000ok9=/_nbCK802OnbCK800ol0003oOh1oogn0O`0:ogn0
O`03o`000?nGJ9OoUfRG00?oUfRG00?o0000ohacS?n<Lh`02On<Lh`00ol0003og2?Lom`Sg002om`S
g0;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003obcC;ol/db`06ol/db`03o`000?n7N8OoQgR700[o
QgR700?o0000oimPWonOH9l02onOH9l00ol0003oWf2OoimPW`09oimPW`?o000000?oZ5NXo`000?nI
IYT01OnIIYT00ol0003oQWV6ohIiQP03ohIiQP03o`000?nbCK;o/Tfb00So/Tfb3_l00003oiMXU`;o
00002on<Lh`00ol0003og2?Lom`Sg005om`Sg003o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000ol/dboo;=</01Oo;=</00ol0003oUVVFo`00000;ohMhQ`03o`000?nOH9ooWf2O00[oWf2O
0_l0000>oimPW`03o`000?nIIYWoVFJI00GoVFJI00?o0000ohIiQ_n6NHH00on6NHH00ol0003o/Tfb
ok9=/P08ok9=/P03o`000?nPGj3oX5nP00_oX5nP00?o0000oiMXUol000003On<Lh`00ol0003og2?L
om`Sg006om`Sg0;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00KobcC;00Co
0000oiIYU_nFJIKo00002_n7N8L00ol0003oWf2OoimPW`09oimPW`03o`000?nKI9_o000000koWf2O
00?o0000oiUVVOnIIYT01OnIIYT00ol0003oQWV6ohIiQP04ohIiQP03o`000?nbCK;o/Tfb00Ko/Tfb
00?o0000oj1OX?nPGj003OnPGj000ol0003oS7><ohacS00<ohacS003o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000oiIYU_nFJIH00_nF
JIH00ol0003oQgR7ohMhQ`06ohMhQ`03o`000?nOH9ooWf2O00SoWf2O0_l00003oi]TV`03o`000?nO
H9ooWf2O00_oWf2O00?o0000oiUVVOnIIYT01OnIIYT00ol0003oQWV6ohIiQP05ohIiQP03o`000?nb
CK;o/Tfb00Go/Tfb00?o0000oj1OX?nPGj003OnPGj000ol0003oS7><ohacS00;ohacS003o`000?oL
8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000
oiIYU_nFJIH00onFJIH00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?nOH9ooWf2O00OoWf2O00?o0000
oi]TVonKI9/00onKI9/00ol0003oWf2OoimPW`0:oimPW`03o`000?nIIYWoVFJI00KoVFJI00?o0000
ohIiQ_n6NHH01_n6NHH00ol0003o/Tfbok9=/P04ok9=/P03o`000?nPGj3oX5nP00goX5nP3ol0000;
om`Sg003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000oiIYU_nFJIH01OnFJIH00ol0
003oQgR7ohMhQ`04ohMhQ`03o`000?nOH9ooWf2O00GoWf2O0_l00006oi]TV`03o`000?nOH9ooWf2O
00WoWf2O0_l00008oiUVV@03o`000?n6NHKoQWV600KoQWV61Ol000000onbCK;o0000oj1OX00?oj1O
X003o`000?n6NHKoQWV600_oQWV600?o0000om`Sg?oL8m`02OoL8m`00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000oiIYU_nFJIH01_nFJIH00ol0003o
QgR7ohMhQ`04o`0000KoWf2O00?o0000oi]TVonKI9/01onKI9/00ol0003oWf2OoimPW`05oimPW`?o
000000?oSW6>o`000?nIIYT01onIIYT00ol0003oQWV6ohIiQP05ohIiQP03o`000?ncC;?o/dbc00?o
/dbc0_l0000?oj1OX0;o00003On6NHH00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WobcC;00?o0000oiIYU_nFJIH01onFJIH2o`0000Co^4Nh00Co0000oimPWonOH9oo
Wf2O0_l0000:oi]TV`03o`000?nOH9ooWf2O00;oWf2O0ol00005ohiaSP03o`000?nIIYWoVFJI00Go
VFJI00?o0000ohIiQ_n6NHH01?n6NHH00ol0003o/dbcok=</`06ok=</`03o`000?nPGj3oX5nP00[o
X5nP0_l00002oimPW`03o`000?n6NHKoQWV600[oQWV600?o0000om`Sg?oL8m`02?oL8m`00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000ol/dboo;=</01_o;=</00ol0003oUVVFoiIYUP08oiIYUP03o`00
0?nhAkSo^4Nh00Co^4Nh00?o0000oimPWol000003?nKI9/00ol0003oWf2Oo`000002o`0000WoSW6>
00?o0000oiUVVOnIIYT01?nIIYT00ol0003oQWV6ohIiQP03ohIiQP03o`000?ncC;?o/dbc00So/dbc
1_l00004oj1OX0;o00001OnOH9l00ol0003oQWV6ohIiQP09ohIiQP03o`000?oL8mcog2?L00Sog2?L
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000oiIYU_nFJIH01onF
JIH00ol0003o^4NhokQ7^006okQ7^003o`000?nKI9_oVfBK00coVfBK00?o0000ohiaS_n>LHh02_n>
LHh00ol0003oVFJIoiUVV@04oiUVV@04o`000?n6NHKoQWV6ohIiQP;o00002oncC;<00ol0003o[5>/
ojaC[003ojaC[0Co00002?nOH9l00ol0003oQWV6ohIiQP08ohIiQP03o`000?oL8mcog2?L00Oog2?L
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000ol/dboo;=</00oo;=</00ol0003oUVVFoiIYUP07oiIYUP03o`000?nh
AkSo^4Nh00Oo^4Nh00?o0000oi]TVonKI9/03?nKI9/00ol0003oSW6>ohiaSP0;ohiaSP03o`000?nI
IYWoVFJI00?oVFJI00Co0000ohIiQ_n6NHKo00003OncC;<00ol0003o[5>/ojaC[006ojaC[003o`00
0?nOH9ooWf2O00OoWf2O00?o0000ohIiQ_n6NHH01on6NHH00ol0003og2?Lom`Sg006om`Sg004o`00
0?oj1O[onPGjooX5nP;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00;obcC;00?o0000oiIYU_nFJIH0
1_nFJIH00ol0003o^4NhokQ7^009okQ7^003o`000?nKI9_oVfBK00WoVfBK0_l0000>ohiaSP?o0000
0onIIYT00ol0003oQWV6o`00000=ok=</`03o`000?n/Djco[5>/00Oo[5>/00?o0000oimPWonOH9l0
2?nOH9l:o`0000Kog2?L0_l00006ooX5nP03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoUVVF00?o
0000okQ7^?nhAkP02_nhAkP00ol0003oVfBKoi]TV`06oi]TV`;o000000?oW6>Lo`000?n>LHh02on>
LHh2o`0000?o/dbc1Ol0000>ok=</`03o`000?n/Djco[5>/00Oo[5>/00?o0000oimPWonOH9l02?nO
H9l00ol0003oXEjQoj5NX@06oj5NX@03o`000?oL8mcog2?L00?og2?L00?o0000ooX5n_oj1OX01ooj
1OX2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003obCK9olTfb@03olTfb@Co00000_nFJIH00ol0003o^4NhokQ7^00;
okQ7^003o`000?nKI9_oVfBK00?oVfBK0ol00004oiaSW003o`000?n>LHkoSW6>00OoSW6>0_l00008
ok=</`03o`000?ncC;?o/dbc00go/dbc00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003oWf2OoimPW`07
oimPW`03o`000?nQGZ7oXEjQ00OoXEjQ0ol000000ooL8mco0000ooX5nP0;ooX5nP;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o9=/WobCK900OobCK90_l0000?okQ7^003o`000?nKI9_oVfBK00;o00002?nLHi`00ol0
003oSW6>ohiaSP05ohiaSP03o`000?ncC;?o/dbc00So/dbc00?o0000ok=</oncC;<03OncC;<00ol0
003o[5>/ojaC[008ojaC[003o`000?nOH9ooWf2O00KoWf2O00?o0000oj5NXOnQGZ402?nQGZ401?l0
003ofbCKom/Tfol0000?ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003obCK9olTfb@09olTf
b@03o`000?nhAkSo^4Nh00ko^4Nh0_l0000;oiaSW003o`000?n>LHkoSW6>00;oSW6>0_l0000;ok=<
/`03o`000?ncC;?o/dbc00go/dbc00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003oWf2OoimPW`06oimP
W`03o`000?nQGZ7oXEjQ00OoXEjQ00Go0000om/TfooK9=_ofbCKo`00000@ooX5nP;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003obCK9olTfb@0:olTfb@03o`000?nhAkSo^4Nh00go^4Nh0_l0000<oiaSW004o`000?n>LHko0000
o`0000go/dbc00?o0000ok=</oncC;<03?ncC;<00ol0003o[5>/ojaC[009ojaC[003o`000?nOH9oo
Wf2O00KoWf2O00?o0000oj5NXOnQGZ401_nQGZ400ol0003ofbCKom/Tf`03om/Tf`03o`000?oj1O[o
nPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003obCK9olTfb@0:olTfb@03o`000?nhAkSo^4Nh00co^4Nh00Co0000og6>
LOmaSW7o00003?nLHi`00ol0003o/dbcok=</`0>ok=</`03o`000?ncC;?o/dbc00So/dbc1?l0000;
ojaC[003o`000?nOH9ooWf2O00KoWf2O00?o0000oj5NXOnQGZ401OnQGZ400ol0003ofbCKom/Tf`04
om/Tf`03o`000?oj1O[onPGj00oonPGj00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003obCK9olTfb@0;olTfb@03o`000?nhAkSo^4Nh
00_o^4Nh00?o0000og6>LOmaSW400_maSW400ol0003oW6>LoiaSW009oiaSW003o`000?ncC;?o/dbc
00ko/dbc00Co0000ok=</oncC;?o/dbc1ol00003okE:]@03o`000?n/Djco[5>/00Wo[5>/00?o0000
oimPWonOH9l01_nOH9l00ol0003oXEjQoj5NX@04oj5NX@03o`000?oK9=_ofbCK00KofbCK00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o9=/WobCK900cobCK900?o0000okQ7^?nhAkP02_nhAkP00ol0
003oLHiaog6>L@03og6>L@03o`000?nLHicoW6>L00SoW6>L00?o0000ok=</oncC;<03_ncC;<4o`00
00_o]DZe00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003oWf2OoimPW`05oimPW`03o`000?nQGZ7oXEjQ
00GoXEjQ00?o0000om/TfooK9=/01_oK9=/00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olTfbOo9
=/T03?o9=/T7o`0000Go^4Nh00?o0000og6>LOmaSW401OmaSW400ol0003oW6>LoiaSW007oiaSW003
o`000?ncC;?o/dbc00ko/dbc00?o0000okE:]OneB[D03OneB[D00ol0003o[5>/ojaC[008ojaC[003
o`000?nOH9ooWf2O00CoWf2O00?o0000oj5NXOnQGZ401?nQGZ400ol0003ofbCKom/Tf`07om/Tf`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003obCK9olTfb@0=olTfb@03o`000?ngB;Oo]dRg00Co]dRg
1Ol00009og6>L@03o`000?nLHicoW6>L00KoW6>L00?o0000ok=</oncC;<03_ncC;<00ol0003o]DZe
okE:]@0=okE:]@03o`000?n/Djco[5>/00So[5>/00Co0000oimPWonOH9ooWf2O1Ol00004oj5NX@03
o`000?oK9=_ofbCK00WofbCK1?l0000:ooX5nP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olTfb@03o`000?ngB;Oo]dRg00Wo]dRg
0_l00009og6>L@03o`000?nLHicoW6>L00KoW6>L00?o0000ok=</oncC;<03?ncC;<00ol0003o]DZe
okE:]@0?okE:]@Ko00001?n/Dj`4o`0000Go_D:m0_l000000onQGZ7o0000om/Tf`0;om/Tf`04o`00
0?oj1O[onPGjooX5nPOo00000ooj1OX00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oE:]GoeB[EomDZe@?o00002_o9=/T00ol0003o
]dRgokM8]`09okM8]`03o`000?n0Oh3o000000;o00001omaSW400ol0003oW6>LoiaSW005oiaSW003
o`000?ncC;?o/dbc00So/dbc1Ol0000AokE:]@03o`000?n^DJko[U6^00?o[U6^1?l0000;oke2_@03
o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omDZeOoE:]D01OoE:]D2o`0000OobCK9
00?o0000okM8]ongB;L02_ngB;L00ol0003oP7n0oh1oP002oh1oP0?o00001OmaSW400ol0003oW6>L
oiaSW004oiaSW004o`000?ncC;?o/dbcok=</`Oo00001?nRGJ800ol0003o]DZeokE:]@0>okE:]@03
o`000?n^DJko[U6^00Oo[U6^00?o0000oke2_Onm@[d02Onm@[d00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oeB[EomDZe@08omDZe@;o00001?o9=/T00ol0003o]dRg
okM8]`0;okM8]`03o`000?n0Oh3oP7n000GoP7n00ol00003og6>L@04o`000?nLHicoW6>LoiaSW0Ko
00003?nRGJ800ol0003o]DZeokE:]@0=okE:]@03o`000?n^DJko[U6^00Oo[U6^00?o0000oke2_Onm
@[d02_nm@[d00ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omDZe@?o000000?obCK9o`000?ngB;L0
3?ngB;L00ol0003oP7n0oh1oP008oh1oP0?o000000CoLHiao`000?l0003o00000_nfBKH00ol0003o
XUfRoj9MXP0=oj9MXP03o`000?neB[Go]DZe00co]DZe00?o0000ojiA[_n^DJh02?n^DJh00ol0003o
_D:moke2_@0;oke2_@03o`000?oK9=_ofbCK00KofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
eB[E00?o0000okM8]ongB;L03?ngB;L00ol0003oP7n0oh1oP00;oh1oP003o`000?nfBKKo]TVf00?o
]TVf00?o0000oj9MX_nRGJ803?nRGJ800ol0003oS7><o`00000=okE:]@03o`000?n^DJko[U6^00So
[U6^00?o0000oke2_Onm@[d03?nm@[d3o`0000GofbCK00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oE:]GoeB[E00coeB[E00?o0000okM8]ongB;L03?ngB;L00ol0003oP7n0oh1oP00:oh1oP003o`00
0?nfBKKo]TVf00Go]TVf00?o0000oj9MX_nRGJ802_nRGJ801?l0003oS7><ohacS?n<Lh`2o`0000[o
]DZe00?o0000ojiA[_n^DJh02On^DJh00ol0003o_D:moke2_@0<oke2_@03o`000?oQ7^7ohAkQ00?o
000000?ofbCKo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oE:]GoeB[E00_oeB[E00?o0000okM8]ongB;L0
3?ngB;L00ol0003oP7n0oh1oP009oh1oP003o`000?nfBKKo]TVf00Ko]TVf00?o0000oj9MX_nRGJ80
2OnRGJ800ol0003oS7><ohacS002ohacS003o`000?ncC;?o000000;o00001oneB[D00ol0003o[U6^
ojiA[P09ojiA[P03o`000?nm@[go_D:m00_o_D:m00?o0000on4NhOoQ7^401?oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omDZeOoE:]D02ooE:]D00ol0003o]dRgokM8]`0;okM8]`03o`000?n0
Oh3oP7n000SoP7n000?o0000okI9]_nfBKH01onfBKH00ol0003oXUfRoj9MXP08oj9MXP03o`000?n<
LhcoS7><00?oS7><00?o0000ok=</oncC;<00_ncC;<2o`0000Co]DZe00?o0000ojiA[_n^DJh02_n^
DJh00ol0003o_D:moke2_@0:oke2_@03o`000?oQ7^7ohAkQ00GohAkQ00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oE:]GoeB[E00[oeB[E0ol0000;okM8]`Ko00001?n0Oh000ol0003o]TVfokI9]P08
okI9]P03o`000?nRGJ;oXUfR00OoXUfR00?o0000ohacS?n<Lh`00on<Lh`00ol0003o/dbcok=</`05
ok=</`?o000000?o]DZeo`000?n^DJh02on^DJh00ol0003o_D:moke2_@09oke2_@03o`000?oQ7^7o
hAkQ00OohAkQ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oE:]GoeB[E00WoeB[E00?o0000ojII
Y_nVFJH01?l00006okM8]`03o`000?n`Ck3o/4n`00Co/4n`1?l0000<okI9]P03o`000?nRGJ;oXUfR
00GoXUfR00?o0000ohacS?n<Lh`01?n<Lh`00ol0003o/dbcok=</`08ok=</`03o`000?n^DJko[U6^
00_o[U6^00?o0000oke2_Onm@[d02?nm@[d00ol0003ohAkQon4Nh@08on4Nh@Go00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oE:]GoeB[E00OoeB[E00?o0000ojIIY_nVFJH01OnVFJH3o`0000;o]dRg00?o0000ok1?/?n`
Ck002?n`Ck000ol0003o]TVfokI9]P0:okI9]P03o`000?nRGJ;oXUfR00CoXUfR00?o0000ohacS?n<
Lh`01On<Lh`00ol0003o/dbcok=</`08ok=</`03o`000?n^DJko[U6^00Wo[U6^1?l00008oke2_@03
o`000?oQ7^7ohAkQ00WohAkQ00?o0000ooX5n_oj1OX00_oj1OX7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeB[E
omDZe@05omDZe@03o`000?nVFJKoYUVV00WoYUVV0_l0000<ok1?/003o`000?nfBKKo]TVf00Wo]TVf
00?o0000oj9MX_nRGJ800onRGJ800ol0003oS7><ohacS005ohacS003o`000?ncC;?o/dbc00[o/dbc
00?o0000ojiA[_n^DJh01?n^DJh4o`0000Co]dRg00?o0000oke2_Onm@[d01?nm@[d00ol0003ohAkQ
on4Nh@0:on4Nh@03o`000?oj1O[onPGj00WonPGj0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000ojIIY_nVFJH02onV
FJH00ol0003o/4n`ok1?/00:ok1?/003o`000?nfBKKo]TVf00Wo]TVf00?o0000oj9MX_nRGJ800_nR
GJ800ol0003oS7><ohacS006ohacS003o`000?ncC;?o/dbc00[o/dbc00?o0000ojiA[_n^DJh01?l0
0009okM8]`Ko00003?oQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omDZeOoE:]GoeB[E0_l0
000=ojIIYP03o`000?n`Ck3o/4n`00[o/4n`00?o0000okI9]_nfBKH02OnfBKH01Ol0003oXUfRoj9M
X_nRGJ;o000000WoS7><00?o0000ok=</oncC;<02oncC;<2o`0000go]dRg00?o0000omTVfOoI9]T0
0_oI9]T00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oeB[Eo`00
0002om</d`;o00002onVFJH00ol0003o/4n`ok1?/00;ok1?/003o`000?nfBKKo]TVf00Wo]TVf00?o
0000oj9MX_l000002On<Lh`00ol0003o/dbcok=</`0<ok=</`03o`000?ngB;Oo]dRg00co]dRg00?o
0000omTVfOoI9]T00ooI9]T00ol0003ohAkQon4Nh@09on4Nh@03o`000?oj1O[onPGj00gonPGj00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003odbcCom</d`03om</d`;o00002_nVFJH00ol0003o/4n`ok1?/00:ok1?/003o`000?nfBKKo
]TVf00So]TVf1Ol00008ohacS003o`000?ncC;?o/dbc00co/dbc00?o0000okM8]ongB;L02ongB;L0
0ol0003ofBKIomTVf@05omTVf@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooC;=<2o`0000SoYUVV00?o0000ok1?/?n`Ck002_n`Ck000ol0003o]TVfokI9]P07okI9
]P03o`000?nVFJKoYUVV00?oYUVV0ol00005ohacS003o`000?ncC;?o/dbc00_o/dbc00?o0000okM8
]ongB;L03?ngB;L00ol0003ofBKIomTVf@06omTVf@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000WodbcC00?o0000ojIIY_nVFJH01OnVFJH2o`0000co
/4n`00?o0000okI9]_nfBKH01OnfBKH00ol0003oYUVVojIIYP07ojIIYP?o000000?oS7><o`000?nc
C;<03OncC;<00ol0003o]dRgokM8]`0<okM8]`03o`000?oI9]WofBKI00KofBKI00?o0000on4NhOoQ
7^401_oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?oC;=?odbcC00OodbcC
0_l00004ojIIYP03o`000?nZEJ[oZUFZ00;o00002_n`Ck000ol0003o]TVfokI9]P03okI9]P;o0000
3OnVFJH2o`0000go/dbc0ol0000=okM8]`03o`000?oI9]WofBKI00OofBKI00?o0000on4NhOoQ7^40
1OoQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?oC;=?odbcC00SodbcC0_l0
00000onVFJKo0000ojYEZP04ojYEZP03o`000?n`Ck3o/4n`00Oo/4n`00Co0000okI9]_nfBKKo]TVf
0_l00002ojEJY@03o`000?nVFJKoYUVV00coYUVV3Ol00003oiMXU`03o`000?ngB;Oo]dRg00[o]dRg
00?o0000omTVfOoI9]T02?oI9]T01?l0003ohAkQon4NhOoQ7^44o`0000konPGj00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003odbcC
om</d`09om</d`03o`000?nZEJ[oZUFZ00GoZUFZ0_l00008ok1?/003o`000?nfBKKo000000GoYEZU
00?o0000ojIIY_nVFJH02onVFJH00ol0003oY5^TojAKY009ojAKY003o`000?nGJ9OoUfRG00;oUfRG
0_l00009okM8]`03o`000?oI9]WofBKI00[ofBKI0ol00004ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?oC;=?odbcC00SodbcC00?o0000ojYEZ_nZEJX01onZEJX4o`0000?o/4n`0ol0
0007ojEJY@03o`000?nVFJKoYUVV00[oYUVV00?o0000ojAKY?nTFj@02OnTFj@00ol0003oUfRGoiMX
U`04oiMXU`;o00001ongB;L00ol0003ofBKIomTVf@0:omTVf@03o`000?oj1O[onPGj00GonPGj00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oC;=?odbcC00OodbcC00?o0000ojYEZ_nZEJX02?nZEJX0
1?l0003o[E:]ojeB[On]DZd3o`0000;oZ5NX00?o0000ojEJYOnUFZD01_nUFZD00ol0003oYUVVojII
YP08ojIIYP03o`000?nTFjCoY5^T00[oY5^T00?o0000oiMXUonGJ9L01_nGJ9L00ol0003o]dRgokM8
]`04okM8]`03o`000?oI9]WofBKI00WofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5
nP07ooX5nP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000om</dooC;=<01OoC;=<00ol0003oZUFZojYEZP08ojYEZP03o`000?n]DZgo
[E:]00Co[E:]00Go0000ojQGZ?nXEjSoZ5NXo`000008ojEJY@03o`000?nVFJKoYUVV00OoYUVV00?o
0000ojAKY?nTFj@02_nTFj@00ol0003oUfRGoiMXU`07oiMXU`;o00001?ngB;L00ol0003ofBKIomTV
f@08omTVf@03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX01?oj1OX2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000om</dooC;=<00ooC;=<0
0ol0003oZUFZojYEZP08ojYEZP03o`000?n]DZgo[E:]00Co[E:]00?o0000ojQGZ?nXEjP00_nXEjP0
0ol0003oYEZUojEJY@07ojEJY@03o`000?nVFJKoYUVV00KoYUVV00?o0000ojAKY?nTFj@02_nTFj@0
0ol0003oUfRGoiMXU`09oiMXU`05o`000?ngB;Oo]dRgokM8]ol000002OoI9]T00ol0003onPGjooX5
nP0;ooX5nP03o`000?oj1O[onPGj00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_oZUFZ00?o0000ojeB[On]DZd01?n]DZd00ol0003oZ5NXojQGZ003
ojQGZ003o`000?nUFZGoYEZU00OoYEZU00?o0000ojIIY_nVFJH01OnVFJH00ol0003oY5^TojAKY00:
ojAKY003o`000?nGJ9OoUfRG00WoUfRG1?l00009omTVf@03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oP7n3oh1oP
on0Oh?l000002_nZEJX00ol0003o[E:]ojeB[@05ojeB[@03o`000?nXEjSoZ5NX00?oZ5NX00?o0000
ojEJYOnUFZD02?nUFZD00ol0003oYUVVojIIYP04ojIIYP03o`000?nTFjCoY5^T00WoY5^T00?o0000
oiMXUonGJ9L02?nGJ9L2o`0000?oeRWF00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000on0Oh?oP7n000ooP7n000ol0003oZUFZojYEZP06ojYEZP03o`000?n]DZgo[E:]
00Go[E:]00?o0000ojQGZ?nXEjP01?nXEjP00ol0003oYEZUojEJY@09ojEJY@03o`000?nVFJKoYUVV
00;oYUVV00?o0000ojAKY?nTFj@02_nTFj@00ol0003oUfRGoiMXU`06oiMXU`;o00001_oF:MH8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003oh1oPon0Oh005on0Oh003o`000?nZEJ[oZUFZ00GoZUFZ00?o0000ojeB[On]
DZd01On]DZd00ol0003oZ5NXojQGZ005ojQGZ003o`000?nUFZGoYEZU00WoYEZU00Go0000ojIIY_nV
FJKoYUVVo`00000<ojAKY003o`000?nGJ9OoUfRG00CoUfRG0_l00008omHYeP03o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oP7n3oh1oP00Ooh1oP00?o0000ojYEZ_nZ
EJX00onZEJX00ol0003o[E:]ojeB[@06ojeB[@03o`000?nXEjSoZ5NX00GoZ5NX00?o0000ojEJYOnU
FZD02_nUFZD00ol0003oYUVVo`000004o`0000WoY5^T00?o0000oiMXUonGJ9L00_nGJ9L2o`0000[o
eRWF00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003oh1oPon0Oh007on0Oh003o`00
0?nZEJ[oZUFZ00;oZUFZ00?o0000ojeB[On]DZd01_n]DZd00ol0003oZ5NXojQGZ007ojQGZ0;o0000
2onUFZD00ol0003o/4n`ok1?/003ok1?/0Oo00000_nTFj@00ol0003oUfRGoiMXU`02o`0000_oeRWF
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000on0Oh?oP7n002OoP
7n001Ol0003oZUFZojYEZ_nZEJ[o000000So[E:]00?o0000ojQGZ?nXEjP01onXEjP00ol0003obSG:
o`000002o`0000SoYEZU00?o0000ok1?/?n`Ck002_n`Ck05o`0000goeRWF00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<on0Oh003o`000?nZEJ[o000000Wo[E:]00?o
0000ojQGZ?nXEjP01_nXEjP00ol0003obSG:olXebP03olXebP?o00001?nUFZD00ol0003o/4n`ok1?
/00=ok1?/003o`000?oF:MKoeRWF00goeRWF00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ook1?/2o`0000_oh1oP00?o0000ojeB[On]DZd01on]DZd00ol0003oZ5NXojQGZ007
ojQGZ003o`000?o:=L[obSG:00KobSG:0ol000000onUFZGo0000ok1?/00>ok1?/003o`000?oF:MKo
eRWF00coeRWF00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009on0O
h003o`000?n]DZgo[E:]00;o[E:]1_l00008ojQGZ003o`000?o:=L[obSG:00[obSG:00?o0000ok1?
/?n`Ck003on`Ck000ol0003oeRWFomHYeP0:omHYeP;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007on0Oh0Go00001_oQ7^400ol0003oZ5NXojQGZ005ojQGZ003o`000?o:=L[obSG:00[o
bSG:00?o0000ok1?/?n`Ck003on`Ck000ol0003oeRWFomHYeP07omHYeP?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005on0Oh003o`000?oQ7^7ohAkQ00WohAkQ00?o0000ojQGZ?nX
EjP00onXEjP00ol0003obSG:olXebP0;olXebP03o`000?n`Ck3o/4n`00oo/4n`00?o0000omHYe_oF
:MH01OoF:MH2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?oh1oPo`000?l00000
3OoQ7^400ol0003oZ5NXojQGZ002ojQGZ003o`000?o:=L[obSG:00_obSG:5?l00004omHYeP;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003onPGjo`00000>on4Nh@04o`000?nXEjSoZ5NXo`0000kobSG:
00?o0000on@Ki?oT6n@04?oT6n@00ol0003oeRWFo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?oj1O[onPGjooX5n_l000003_oQ7^400ol0003oZ5NXo`00000>olXebP03o`00
0?oT6nCoi1_T017oi1_T00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000ooX5n_oj1OX00_oj1OX00ol0003ohAkQon4Nh@0=on4Nh@03o`000?o:=L[obSG:00WobSG:1Ol0
000Bon@Ki0;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5n_oj1OX01?oj1OX0
0ol0003ohAkQon4Nh@0<on4Nh@03o`000?o:=L[obSG:00;obSG:1ol00004ooX5nP03o`000?oT6nCo
i1_T00ooi1_T00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003onPGjooX5nP06ooX5
nP03o`000?oQ7^7ohAkQ00cohAkQ1?l0000<ooX5nP03o`000?oT6nCoi1_T00coi1_T0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?oj1O[onPGj00Oo
nPGj00?o0000on4NhOoQ7^403?oQ7^400ol0003onPGjooX5nP0=ooX5nP03o`000?oT6nCoi1_T00_o
i1_T00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ohAkQon4Nh@0:on4Nh@03o`000?oj1O[onPGj00konPGj00?o0000on@Ki?oT
6n@02OoT6n@2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?oj1O[onPGj00[onPGj00?o0000on4NhOoQ7^402_oQ7^400ol0003onPGj
ooX5nP0?ooX5nP03o`000?oT6nCoi1_T00Koi1_T0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003onPGj00gonPGj3?l0
000AooX5nP?o00001_oT6n@00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooT6n@2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oj1O[o
nPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000on@Ki?l000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oj1O[onPGj00[o
nPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009ooX5nP03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooX5n_oj1OX00ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooX5
nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0:o`00o`03oooo0?l00?oo003o00So003o1?ooo`09o`00o`;oool0
KOl00?l1ooooo`00L_l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l00oooo`3o003oo`00o`07o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0KOl00?l1ooooo`00L_l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o00?oool0o`00ool00?l01_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1
ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00_o003o00?oool0o`00ool00?l01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06go003o0Oooool0077o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`002ol00?l00oooo`3o
003oo`00o`05o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06go
003o0Oooool0077o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00_o003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00co003o00?oool0o`00ool00?l00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
KOl00?l1ooooo`00L?l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
3?l00?l00oooo`3o003oo`00o`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0<o`00o`03oooo
0?l00?oo003o00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00
o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001_o`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003o
oooo0?l00?l00_ooo`0=o`00o`03oooo0?l00?oo003o00;o003o0_ooo`06o`00o`;oool01_l00?l2
oooo06go003o0Oooool006oo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00
o`;oool03Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00
o`7ooooo001^o`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00ko
003o00Coool0o`00ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1]o`00
o`7ooooo001^o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01Ol00?l00oooo`3o
003oo`00o`06o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01ol00?l2oooo06go
003o0Oooool006ko003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool0
00?o<S;<o`00ool00?l00ol00?l00oooo`3o003oo`00o`05o`00o`03oooo0?l00?oo003o00;o003o
0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001]o`00o`7ooooo001]o`00o`?oool01Ol0
0?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00?o003o2_ooo`04o`00o`;oool00_l0
0?l2oooo00Go003o1Oooo`1]o`00o`7ooooo001/o`00o`Koool000?o003ooooo0?ooo`001Oooo`03
o`00o`Goool07_l00?l:oooo00Go003o1?ooo`1ho`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(80) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.981 .019 .981 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.981 .019 .981 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.981 .019 .981 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.98 .02 .98 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.853 .147 .853 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.979 .021 .979 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.845 .155 .845 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.888 .112 .888 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.84 .16 .84 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.77 .23 .77 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.981 .019 .981 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.739 .261 .739 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.699 .301 .699 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.978 .022 .978 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.982 .018 .982 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.704 .296 .704 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.735 .265 .735 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.977 .023 .977 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.979 .021 .979 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.98 .02 .98 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.83 .17 .83 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.639 .361 .639 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.498 .502 .498 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.542 .458 .542 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.539 .461 .539 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.576 .424 .576 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.818 .182 .818 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.836 .164 .836 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.981 .019 .981 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.574 .426 .574 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.73 .27 .73 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.535 .465 .535 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.796 .204 .796 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.779 .221 .779 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.98 .02 .98 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.728 .272 .728 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.695 .305 .695 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.756 .244 .756 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.809 .191 .809 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.561 .439 .561 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.982 .018 .982 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.87 .13 .87 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.644 .356 .644 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.653 .347 .653 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.615 .385 .615 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.834 .166 .834 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.883 .117 .883 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.635 .365 .635 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.98 .02 .98 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.58 .42 .58 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.494 .506 .494 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.729 .271 .729 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.75 .25 .75 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.554 .446 .554 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.576 .424 .576 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.692 .308 .692 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.981 .019 .981 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.73 .27 .73 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.69 .31 .69 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.85 .15 .85 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.258 .742 .258 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.66 .34 .66 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.716 .284 .716 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.73 .27 .73 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.481 .519 .481 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.415 .585 .415 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.394 .606 .394 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.452 .548 .452 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.692 .308 .692 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.47 .53 .47 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.58 .42 .58 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.671 .329 .671 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.655 .345 .655 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.677 .323 .677 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.658 .342 .658 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.883 .117 .883 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.98 .02 .98 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.481 .519 .481 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.564 .436 .564 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.453 .547 .453 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.98 .02 .98 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.736 .264 .736 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.622 .378 .622 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.392 .608 .392 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.48 .52 .48 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.681 .319 .681 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.565 .435 .565 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.843 .157 .843 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.65 .35 .65 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.406 .594 .406 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.638 .362 .638 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.587 .413 .587 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.537 .463 .537 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.678 .322 .678 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.822 .178 .822 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.69 .31 .69 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.421 .579 .421 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.534 .466 .534 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.686 .314 .686 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.574 .426 .574 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.577 .423 .577 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.792 .208 .792 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.559 .441 .559 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.509 .491 .509 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.465 .535 .465 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.979 .021 .979 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.476 .524 .476 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.616 .384 .616 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.509 .491 .509 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.617 .383 .617 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.666 .334 .666 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.979 .021 .979 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.692 .308 .692 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.631 .369 .631 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.65 .35 .65 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.685 .315 .685 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.578 .422 .578 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.537 .463 .537 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.593 .407 .593 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.613 .387 .613 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.98 .02 .98 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.77 .23 .77 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.656 .344 .656 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.741 .259 .741 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.5 .5 .5 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.827 .173 .827 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.381 .619 .381 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.554 .446 .554 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.55 .45 .55 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.686 .314 .686 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.764 .236 .764 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.473 .527 .473 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.98 .02 .98 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.609 .391 .609 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.678 .322 .678 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.896 .104 .896 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.665 .335 .665 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.605 .395 .605 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.645 .355 .645 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.833 .167 .833 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.484 .516 .484 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.597 .403 .597 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.664 .336 .664 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.822 .178 .822 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.477 .523 .477 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.589 .411 .589 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.658 .342 .658 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.673 .327 .673 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.98 .02 .98 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.531 .469 .531 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.98 .02 .98 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.862 .138 .862 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.717 .283 .717 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.674 .326 .674 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.57 .43 .57 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.564 .436 .564 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.597 .403 .597 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.843 .157 .843 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.704 .296 .704 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.726 .274 .726 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.727 .273 .727 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.646 .354 .646 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.833 .167 .833 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.635 .365 .635 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.571 .429 .571 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.435 .565 .435 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.447 .553 .447 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.587 .413 .587 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.696 .304 .696 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.98 .02 .98 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.853 .147 .853 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.612 .388 .612 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.429 .571 .429 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.689 .311 .689 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.771 .229 .771 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.586 .414 .586 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.98 .02 .98 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.553 .447 .553 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.731 .269 .731 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.853 .147 .853 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.98 .02 .98 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.581 .419 .581 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.623 .377 .623 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.855 .145 .855 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.655 .345 .655 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.584 .416 .584 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.846 .154 .846 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.574 .426 .574 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.753 .247 .753 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.74 .26 .74 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.528 .472 .528 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.504 .496 .504 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.62 .38 .62 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.635 .365 .635 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.886 .114 .886 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.73 .27 .73 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.729 .271 .729 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.694 .306 .694 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.98 .02 .98 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.825 .175 .825 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.603 .397 .603 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.98 .02 .98 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.86 .14 .86 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.786 .214 .786 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.866 .134 .866 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.643 .357 .643 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.86 .14 .86 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.739 .261 .739 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.673 .327 .673 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.981 .019 .981 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.687 .313 .687 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.68 .32 .68 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.98 .02 .98 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.835 .165 .835 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.978 .022 .978 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.981 .019 .981 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.792 .208 .792 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.979 .021 .979 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.664 .336 .664 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.98 .02 .98 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.525 .475 .525 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.712 .288 .712 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.593 .407 .593 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.862 .138 .862 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.86 .14 .86 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.727 .273 .727 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.776 .224 .776 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.732 .268 .732 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.804 .196 .804 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.845 .155 .845 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.757 .243 .757 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.759 .241 .759 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.979 .021 .979 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.67 .33 .67 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.836 .164 .836 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.979 .021 .979 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.879 .121 .879 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.884 .116 .884 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.665 .335 .665 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.864 .136 .864 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.869 .131 .869 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.59 .41 .59 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.979 .021 .979 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.981 .019 .981 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.848 .152 .848 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.98 .02 .98 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.98 .02 .98 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.979 .021 .979 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.98 .02 .98 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.979 .021 .979 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.98 .02 .98 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ofRGJomXUf_l0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000omXUf_oJ9MX00_oJ9MX00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000omXUf_oJ9MX01OoJ9MX00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofRGJomXUfP06omXUfP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000omXUf_oJ9MX02?oJ9MX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oG:=Oo0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cofRGJ00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omLXe`03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003og2?Lom`Sg005om`Sg003o`000?oJ
9M[ofRGJ00_ofRGJ0ol00003omXUfP03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omLXeooG:=L00ooG:=L00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003og2?Lom`Sg006
om`Sg003o`000?oJ9M[ofRGJ00[ofRGJ00?o0000omXUf_oJ9MX01?oJ9MX00ol0003onPGjooX5nP0:
ooX5nP04o`000?oL8mcog2?Lom`Sg0;o00002_oj1OX2o`000003om`Sg?l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSGomLXe`05omLXe`03o`000?oj1O[o
nPGj00WonPGj00?o0000om</dol000002ooj1OX00ol0003og2?Lom`Sg006om`Sg003o`000?oJ9M[o
fRGJ00WofRGJ00?o0000omXUf_oJ9MX01_oJ9MX00ol0003onPGjooX5nP08ooX5nP03o`000?oL8mco
g2?L00Cog2?L0_l00005ooX5nP?o00001?oL8m`00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003onPGjooX5nP09ooX5
nP03o`000?oj1O[onPGj00SonPGj0_l00008omLXe`03o`000?oj1O[onPGj00OonPGj0_l00003om</
d`03o`000?oj1O[onPGj00OonPGj00?o0000om`Sg?oL8m`01ooL8m`00ol0003ofRGJomXUfP09omXU
fP03o`000?oJ9M[ofRGJ00OofRGJ00?o0000ooX5n_oj1OX01Ooj1OX2o`0000Wog2?L0_l000000ooj
1O[o0000o`000007om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooX5n_oj1OX02_oj1OX2o`0000SonPGj00?o0000omLXeooG
:=L02?oG:=L00ol0003onPGjooX5nP06ooX5nP03o`000?oC;=?odbcC00?odbcC00?o0000ooX5n_oj
1OX01ooj1OX00ol0003og2?Lom`Sg008om`Sg003o`000?oJ9M[ofRGJ00OofRGJ00?o0000omXUf_oJ
9MX02OoJ9MX00ol0003onPGjooX5nP03ooX5nP03o`000?oL8mcog2?L00_og2?L00?o0000om`Sg?oL
8m`01ooL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofBKIo`000005ooX5nP;o00002ooG:=L2o`0000KonPGj
00?o0000om</dooC;=<01OoC;=<00ol0003onPGjooX5nP06ooX5nP03o`000?oL8mcog2?L00Sog2?L
00?o0000omXUf_oJ9MX01_oJ9MX00ol0003ofRGJomXUfP0;omXUfP05o`000?oj1O[onPGjooX5n_l0
00003_oL8m`00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003onPGjooX5nP0;ooX5nP05o`000?oI9]WofBKIomTVfOl0
00000ooj1OX00ol0003oebSGomLXe`0:omLXe`04o`000?oB;M;odRgBo`0000?onPGj0_l00008om</
d`03o`000?oj1O[onPGj00KonPGj00?o0000om`Sg?oL8m`02OoL8m`00ol0003ofRGJomXUfP05omXU
fP03o`000?oJ9M[ofRGJ00cofRGJ00?o0000ooX5n_l000003ooL8m`00ol0003og2?Lom`Sg008om`S
g003o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofBKIomTVf@03omTVf@03o`000?oj1O[o000000_o
ebSG0_l00004om8]dP03o`000?oj1O[o000000_odbcC00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
g2?Lom`Sg009om`Sg003o`000?oJ9M[ofRGJ00CofRGJ00?o0000omXUf_oJ9MX03_oJ9MX00ol0003o
g2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000konPGj00?o0000omTVfOoI9]T0
1?oI9]T00ol0003oebSGomLXe`09omLXe`03o`000?oB;M;odRgB00GodRgB00?o0000om</dooC;=<0
2_oC;=<00ol0003onPGjooX5nP05ooX5nP03o`000?oL8mcog2?L00[og2?L00?o0000omXUf_oJ9MX0
0ooJ9MX00ol0003ofRGJomXUfP0>omXUfP03o`000?oL8mcog2?L00gog2?L00?o0000om`Sg?oL8m`0
2_oL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofBKIomTV
f@05omTVf@03o`000?oG:=OoebSG00OoebSG0_l00008om8]dP03o`000?oC;=?odbcC00_odbcC00?o
0000ooX5n_oj1OX01?oj1OX00ol0003og2?Lom`Sg00:om`Sg004o`000?oJ9M[ofRGJomXUfP?o0000
3ooJ9MX00ol0003og2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003onPGjooX5
nP09ooX5nP03o`000?oI9]WofBKI00OofBKI00?o0000omLXeooG:=L01?oG:=L2o`0000_odRgB1?l0
0009om</d`03o`000?oj1O[onPGj00?onPGj00?o0000om`Sg?oL8m`02ooL8m`01?l0003ofRGJo`00
0?l00003olDja@;o00003?oJ9MX2o`00013og2?L00?o0000om`Sg?oL8m`02ooL8m`00ol0003onPGj
ooX5nP0=ooX5nP04o`000?oj1O[onPGjooX5nP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000ooX5n_oj1OX02?oj1OX00ol0003ofBKI
omTVf@07omTVf@03o`000?oG:=OoebSG00?oebSG00?o0000om8]d_oB;M802ooB;M801?l0003oaC[5
olDjaOo5>/D5o`0000GodbcC00?o0000ooX5n_oj1OX00_oj1OX00ol0003og2?Lom`Sg00<om`Sg003
o`000?o5>/GoaC[500GoaC[50_l00008omXUfP;o00000_njAKX00ol0003og2?Lom`Sg00=om`Sg003
o`000?oL8mcog2?L00_og2?L00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP05ooX5nP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[on`Ck
00?o0000ooX5n_oj1OX01ooj1OX00ol0003ofBKIomTVf@09omTVf@03o`000?oG:=OoebSG00;o0000
3OoB;M800ol0003oaC[5olDja@07olDja@Ko00000_oj1OX4o`0000gog2?L00?o0000olDjaOo5>/D0
1oo5>/D2o`0000GofRGJ00?o0000okY5^_njAKX00onjAKX00ol0003og2?Lom`Sg00<om`Sg003o`00
0?oL8mcog2?L00cog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP09ooX5nP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003onPGjooX5nP06ooX5nP03o`000?oI9]WofBKI00WofBKI00?o
0000omLXeol000003ooB;M800ol0003oaC[5olDja@0<olDja@?o00001?oE:]D3o`0000Wog2?L00?o
0000olDjaOo5>/D02_o5>/D2o`000003omXUf_l0003o000000Oo^TFj00?o0000om`Sg?oL8m`02ooL
8m`00ol0003og2?Lom`Sg00<om`Sg003o`000?oj1O[onPGj00KonPGj1?l0000<ooX5nP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo/4nook1?/02Ook1?/00ol0003onPGjooX5nP05ooX5nP03o`000?oI9]WofBKI00_ofBKI00?o0000
om8]d_oB;M803_oB;M800ol0003oaC[5olDja@0=olDja@03o`000?oE:]GoeB[E00KoeB[E0ol00005
om`Sg003o`000?o5>/GoaC[500goaC[500?o0000okY5^_njAKX02?njAKX00ol0003og2?Lom`Sg009
om`Sg003o`000?oL8mcog2?L00gog2?L00Co0000ooX5n_oj1O[onPGj1Ol00003on8MhP03o`000?oj
1O[onPGj00_onPGj00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oj1O[onPGj00?onPGj00?o0000
omTVfOoI9]T02ooI9]T2o`0000oodRgB00?o0000olDjaOo5>/D03Oo5>/D00ol0003oeB[EomDZe@0:
omDZe@?o000000?og2?Lo`000?o5>/D03oo5>/D00ol0003o^TFjokY5^P09okY5^P03o`000?oL8mco
g2?L00Sog2?L00?o0000om`Sg?oL8m`03_oL8m`3o`0000SohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00[on`Ck0_l00003ooX5nP03o`000?oI9]WofBKI00SofBKI0ol000000ong
B;Oo0000om8]dP0>om8]dP03o`000?o5>/GoaC[500goaC[500?o0000omDZeOoE:]D03OoE:]D00ol0
003oaC[5olDja@0?olDja@03o`000?njAK[o^TFj00[o^TFj2ol0000;om`Sg0Go00003?oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02_ok1?/01Ol0003ogR7No`000?oj1O[o0000
00SofBKI0ol00005okM8]`03o`000?oB;M;odRgB00codRgB00?o0000olDjaOo5>/D03Oo5>/D00ol0
003oeB[EomDZe@0=omDZe@;o00004?o5>/D00ol0003o^TFjokY5^P0:okY5^P03o`000?nm@[go_D:m
00Oo_D:m00?o0000om`Sg?oL8m`00_oL8m`7o`0000Co^TFj00?o0000on8Mh_oR7N802_oR7N800ol0
003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02Ook1?/01?l0003ogR7NomhQg_oN8Mh2o`00
00GofBKI0ol00009okM8]`;o00002ooB;M800ol0003oaC[5olDja@0=olDja@03o`000?oE:]GoeB[E
00goeB[E00Co0000omDZeOoE:]Go00003oo5>/D00ol0003o^TFjokY5^P09okY5^P03o`000?nm@[go
_D:m00Wo_D:m1?l0000;okY5^P03o`000?oR7N;ohQgR00[ohQgR00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?ok1?_on`Ck00Son`Ck00?o0000omhQg_oN8Mh01?oN8Mh00ol0003ofBKIo`000002o`00
00co]dRg00Co0000oka3_?l0003o00002OoB;M800ol0003oaC[5olDja@0=olDja@03o`000?oE:]Go
eB[E00goeB[E00Go0000omDZeOoE:]GoeB[Eo`00000=olDja@03o`000?njAK[o^TFj00[o^TFj00?o
0000oke2_Onm@[d02Onm@[d00ol0003o^TFjokY5^P0<okY5^P03o`000?oR7N;ohQgR00[ohQgR00?o
0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003o]dRgokM8]`0<okM8]`03o`000?nl@kco_4>l00;o_4>l0_l00007om8]dP03o`000?o5>/Go
aC[500coaC[500?o0000omDZeOoE:]D03OoE:]D00ol0003oeB[EomDZe@03omDZe@03o`000?o5>/Go
aC[500[oaC[500?o0000okY5^_njAKX02_njAKX00ol0003o_D:moke2_@09oke2_@03o`000?njAK[o
^TFj00co^TFj00?o0000on8Mh_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4
nook1?/01_ok1?/00ol0003ogR7NomhQgP06omhQgP03o`000?ngB;Oo]dRg00_o]dRg00?o0000oka3
_?nl@k`01Onl@k`00ol0003odRgBom8]dP03om8]dP03o`000?o5>/GoaC[500goaC[500?o0000omDZ
eOoE:]D03OoE:]D00ol0003oeB[EomDZe@04omDZe@03o`000?o5>/GoaC[500WoaC[500?o0000okY5
^_njAKX02OnjAKX00ol0003o_D:moke2_@0:oke2_@03o`000?njAK[o^TFj00co^TFj00?o0000on8M
h_oR7N802ooR7N800ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook1?/01Ook1?/00ol0003o
gR7NomhQgP07omhQgP03o`000?ngB;Oo]dRg00_o]dRg00?o0000oka3_?nl@k`01_nl@k`2o`0000?o
dRgB00?o0000olDjaOo5>/D03Oo5>/D00ol0003oeB[EomDZe@0<omDZe@03o`000?oE:]GoeB[E00Ko
eB[E00?o0000olDjaOo5>/D02?o5>/D00ol0003o^TFjokY5^P09okY5^P03o`000?nm@[go_D:m00[o
_D:m00?o0000okY5^_njAKX03?njAKX00ol0003ohQgRon8MhP0;on8MhP03o`000?oj1O[onPGj00[o
nPGj00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?ok1?_on`Ck00Con`Ck00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o]dRgokM8]`0:okM8]`03o`00
0?nl@kco_4>l00Wo_4>l0_l000000ooB;M;o0000olDja@0<olDja@?o00003_oE:]D00ol0003oeB[E
omDZe@07omDZe@03o`000?o5>/GoaC[500OoaC[500?o0000okY5^_njAKX02OnjAKX00ol0003o_D:m
oke2_@0;oke2_@03o`000?njAK[o^TFj00co^TFj00?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP08ooX5nP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000omhQg_oN8Mh02_oN8Mh00ol0003o]dRgokM8
]`09okM8]`03o`000?nl@kco_4>l00_o_4>l00?o0000olDjaOo5>/D02_o5>/D2o`0000?o`cc300?o
0000omDZeOoE:]D02_oE:]D00ol0003oeB[EomDZe@09omDZe@03o`000?o5>/GoaC[500KoaC[500?o
0000okY5^_njAKX02?njAKX00ol0003o_D:moke2_@0<oke2_@03o`000?njAK[o^TFj00co^TFj00?o
0000on8Mh_oR7N802_oR7N800ol0003onPGjooX5nP04ooX5nPCo00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ook1?/0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000okM8]ongB;L02?ngB;L0
0ol0003o_4>loka3_00<oka3_003o`000?o5>/GoaC[500SoaC[50_l00006ol<l``;o00002_oE:]D0
0ol0003oeB[EomDZe@0:omDZe@03o`000?o5>/GoaC[500GoaC[500?o0000okY5^_njAKX02?njAKX0
0ol0003o_D:moke2_@0<oke2_@03o`000?njAK[o^TFj00co^TFj00?o0000on8Mh_oR7N802ooR7N80
0ol0003onPGjo`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?on`Ck00Go0000oo/4nook1?_on`Cko`00000=
omhQgP03o`000?ngB;Oo]dRg00Oo]dRg00?o0000oka3_?nl@k`03_nl@k`00ol0003oaC[5olDja@04
olDja@?o00002_o3?<<00ol0003oeB[EomDZe@07omDZe@03o`000?oE:]GoeB[E00_oeB[E00?o0000
olDjaOo5>/D00oo5>/D00ol0003o^TFjokY5^P09okY5^P03o`000?nm@[go_D:m00co_D:m00?o0000
okY5^_njAKX03?njAKX00ol0003ohQgRon8MhP0;on8MhP;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003ogR7NomhQgP0<omhQgP03o`000?ngB;Oo]dRg00Oo]dRg00?o0000oka3_?nl@k`03onl@k`01?l0
003oaC[5olDjaOo5>/D2o`0000ko`cc30_l00006omDZe@03o`000?oE:]GoeB[E00goeB[E00?o0000
olDjaOo5>/D00_o5>/D00ol0003o^TFjokY5^P08okY5^P03o`000?nm@[go_D:m00co_D:m0ol0000=
okY5^P03o`000?oR7N;ohQgR00_ohQgR00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oogR7N00?o0000okM8]ongB;L01_ngB;L00ol0003o_4>loka3_00@oka3_0Co00004_o3?<<00ol0
003oeB[EomDZe@03omDZe@03o`000?oE:]GoeB[E00koeB[E00Go0000olDjaOo5>/GoaC[5o`000005
okY5^POo00003?nm@[d01Ol0003oZEJYojUFZOnYEZWo000000co^TFj00?o0000on8Mh_oR7N802?oR
7N83o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oogR7N00?o0000okM8]ongB;L01_ngB;L00ol0003o_4>loka3_00=
oka3_0?o000000Co[U6^o`000?l0003o00004oo3?<<2o`0000;oeB[E00?o0000omDZeOoE:]D04?oE
:]D00ol0003oaC[5o`000006o`0000OodbcC00?o0000oke2_Onm@[d02?nm@[d00ol0003oZEJYojUF
Z@03ojUFZ@;o00002?njAKX3o`0000KohQgR1?l00002omhQgP03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003oe2_Do`000?njAKX3o`0000gogR7N00?o0000okM8]ongB;L01?ngB;L00ol0003o_4>loka3
_00;oka3_0?o00000on^DJh01Ol0003o[e2_o`000?naC[7o000001Co`cc300?o0000omDZeOl00000
4ooE:]D00ol0003odbcCom</d`0=om</d`03o`000?nm@[go_D:m00Go_D:m0_l00008ojUFZ@03o`00
0?njAK[o^TFj00Go00000onkA;/00ol0003ohQgRon8MhP03o`0000OogR7N00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oD:mCoe2_Do`0000Co^TFj0ol0000:omhQgP03o`000?ngB;Oo]dRg00?o]dRg
00?o0000oka3_?nl@k`02Onl@k`3o`0000Go[U6^00Co0000ojm@[on_D:oo00000_naC[400ol0003o
`cc3ol<l``0Bol<l``03o`000?oE:]GoeB[E01;oeB[E00?o0000om</dooC;=<03_oC;=<00ol0003o
_D:moke2_@03oke2_@03o`000?nYEZWoZEJY00WoZEJY0_l00009ok]4^`;o00002_oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000om@[e?oD:mCoe2_Do`000007okY5^P;o00001ooN8Mh5o`0000;o
]dRg00?o0000oka3_?nl@k`01_nl@k`3o`0000So[U6^00Co0000ojm@[on_D:oo00000onaC[400ol0
003o`cc3ol<l``0Aol<l``03o`000?oE:]GoeB[E017oeB[E00?o0000om</dooC;=<04?oC;=<01Ol0
003o_D:moke2_Onm@[go000000coZEJY00?o0000ok]4^onkA;/02?nkA;/00ol0003ogR7NomhQgP0:
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000Coe2_D00?o0000okY5^_njAKX01onjAKX3o`00
0004omhQg_l0003o0000o`0000Go^TFj0_l00006oka3_0?o00002_n^DJh01Ol0003o[e2_ojm@[on_
D:oo000000Co/Dja00?o0000ol<l`oo3?<<04?o3?<<00ol0003oeB[EomDZe@0AomDZe@03o`000?oC
;=?odbcC017odbcC00?o0000oke2_Ol000003OnYEZT00ol0003o^dBkok]4^`08ok]4^`03o`000?oN
8MkogR7N00[ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oD:mCoe2_D00Coe2_D00?o0000
okY5^_njAKX02_njAKX00ol0003o^TFjokY5^P08okY5^P03o`000?nl@kco_4>l00?o00003On^DJh0
1Ol0003o[e2_ojm@[on_D:oo000000Go/Dja00?o0000ol<l`oo3?<<03oo3?<<00ol0003oeB[EomDZ
e@0AomDZe@03o`000?oC;=?odbcC01;odbcC00?o0000ojUFZOnYEZT03?nYEZT00ol0003o^dBkok]4
^`08ok]4^`03o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000om@[e?oD:m@01OoD:m@0
0ol0003o^TFjokY5^P0:okY5^P03o`000?njAK[o^TFj00Wo^TFj0_l0000?ojiA[P03o`000?n_D:oo
[e2_00;o[e2_00?o0000ok5>/OnaC[401?naC[400ol0003o`cc3ol<l``0=ol<l``?o00004OoE:]D0
0ol0003odbcCom</d`0Com</d`03o`000?nYEZWoZEJY00_oZEJY00?o0000ok]4^onkA;/02OnkA;/0
0ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008oo/4n`;o00002?oD:m@0
0ol0003o^TFjokY5^P0:okY5^P03o`000?njAK[o^TFj00Wo^TFj00?o0000ojiA[_n^DJh03On^DJh0
0ol0003o[e2_ojm@[`03ojm@[`03o`000?naC[7o/Dja00Go/Dja00?o0000ol<l`oo3?<<02_o3?<<2
o`0000?odRgB00?o0000omDZeOoE:]D03_oE:]D00ol0003odbcCom</d`0Com</d`03o`000?nYEZWo
ZEJY00_oZEJY00?o0000ok]4^onkA;/02OnkA;/00ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000Gon`Ck00?o0000om@[e?oD:m@01ooD:m@2o`0000_o^TFj00?o0000okY5
^_njAKX02onjAKX00ol0003o[U6^ojiA[P0<ojiA[P03o`000?n_D:oo[e2_00?o[e2_00?o0000ok5>
/OnaC[401_naC[400ol0003o`cc3ol<l``07ol<l``;o00001_oB;M82o`0000koeB[E00?o0000om</
dooC;=<04ooC;=<00ol0003oZEJYojUFZ@0;ojUFZ@03o`000?nkA;_o^dBk00Wo^dBk00?o0000omhQ
g_oN8Mh03?oN8Mh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000oo/4nook1?_on`Cko`000009om@[
e003o`000?moP7oo000000_o^TFj00?o0000okY5^_njAKX02onjAKX00ol0003o[U6^ojiA[P0;ojiA
[P03o`000?n_D:oo[e2_00Co[e2_00?o0000ok5>/OnaC[401onaC[400ol0003o`cc3ol<l``05ol<l
``03o`000?oB;M;odRgB00SodRgB00?o0000omDZeOoE:]D02_oE:]D00ol0003odbcCom</d`0Dom</
d`03o`000?nYEZWoZEJY00_oZEJY00?o0000ok]4^onkA;/02OnkA;/00ol0003ogR7NomhQgP0<omhQ
gP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003on`Cko`000009om@[e004o`000?moP7ooOh1oo`00
00_o^TFj00?o0000okY5^_njAKX02onjAKX00ol0003o[U6^ojiA[P0;ojiA[P03o`000?n_D:oo[e2_
00Co[e2_00?o0000ok5>/OnaC[402?naC[400ol0003o`cc3ol<l``02ol<l``;o00003?oB;M82o`00
00[oeB[E00?o0000om</dooC;=<05?oC;=<00ol0003oZEJYojUFZ@0;ojUFZ@03o`000?nkA;_o^dBk
00Wo^dBk00?o0000omhQg_oN8Mh03OoN8Mh00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oe2_Dom@[e007om@[e003
o`000?moP7ooOh1o00;oOh1o00?o0000okY5^_njAKX02?njAKX00ol0003o^TFjokY5^P0<okY5^P03
o`000?n^DJko[U6^00Wo[U6^00?o0000ojm@[on_D:l01On_D:l00ol0003o/Djaok5>/@09ok5>/@04
o`000?o3?<?o0000o`00013odRgB0_l00008omDZe@03o`000?oC;=?odbcC01CodbcC0ol0000;ojUF
Z@03o`000?nkA;_o^dBk00Wo^dBk00?o0000omhQg_oN8Mh03OoN8Mh01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oe2_Dom@[e006om@[e003o`000?moP7ooOh1o00?oOh1o00?o0000okY5
^_njAKX02?njAKX00ol0003o^TFjokY5^P0;okY5^P;o00002_n^DJh00ol0003o[e2_ojm@[`06ojm@
[`03o`000?naC[7o/Dja00[o/Dja00?o0000om8]d_oB;M804_oB;M800ol0003oeB[EomDZe@04omDZ
e@03o`000?oC;=?odbcC01GodbcC00?o0000olXeb_o:=LX01Ol00005ojUFZ@03o`000?nkA;_o^dBk
00[o^dBk00?o0000omhQg_oN8Mh03_oN8Mh3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oe2_Dom@[e004om@[e003
o`000?moP7ooOh1o00CoOh1o00?o0000okY5^_njAKX01onjAKX00ol0003o^TFjokY5^P0;okY5^P04
o`000?njAK[o^TFjo`0000Wo[U6^00?o0000ojm@[on_D:l01_n_D:l00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oB;M;odRgB01?odRgB0_l00003omDZe@Co00005?oC;=<00ol0003obSG:olXebP06olXe
bPCo000000?oZEJYo`000?nkA;/02onkA;/00ol0003ogR7NomhQgP0>omhQgP03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003oe2_Dom@[e003om@[e003o`000?moP7ooOh1o00GoOh1o00?o0000okY5^_nj
AKX01onjAKX00ol0003o^TFjokY5^P09okY5^P;o00001?njAKX00ol0003o[U6^ojiA[P05ojiA[P03
o`000?n_D:oo[e2_00Oo[e2_00?o0000ok5>/OnaC[402_naC[400ol0003odRgBom8]dP0Eom8]dP03
o`000?oE:]Go000000Cof2OH0ol0000@om</d`03o`000?o:=L[obSG:00_obSG:0_l0000<ok]4^`03
o`000?oN8MkogR7N00cogR7N0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000om@[e?oD:m@00_oD:m@00ol0003oOh1o
ogn0O`06ogn0O`03o`000?njAK[o^TFj00Oo^TFj00?o0000okY5^_njAKX02?njAKX00ol0003o^TFj
okY5^P05okY5^P03o`000?n^DJko[U6^00Co[U6^00?o0000ojm@[on_D:l01on_D:l00ol0003o/Dja
ok5>/@0:ok5>/@03o`000?oB;M;odRgB01KodRgB00?o0000omPWf?oH9mP01_oH9mP3o`0000codbcC
00?o0000olXeb_o:=LX03Oo:=LX00ol0003o^dBkok]4^`09ok]4^`Go00002OoN8Mh2o`000003omTV
fOl0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003om@[e?l0003oOh1o00WoOh1o00?o0000okY5^_njAKX01_nj
AKX00ol0003o^TFjokY5^P07okY5^P03o`000?njAK[o^TFj00Oo^TFj00?o0000ojiA[_n^DJh00_n^
DJh00ol0003o[e2_ojm@[`08ojm@[`03o`000?naC[7o/Dja00Wo/Dja00?o0000om8]d_oB;M805ooB
;M800ol0003of2OHomPWf009omPWf0?o00002OoC;=<00ol0003obSG:olXebP0>olXebPKo00001?nk
A;/00ol0003oZUFZojYEZP03ojYEZPGo00000_oN8Mh2o`0000CofBKI00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o5>/GoaC[5olDjaOl000002omoP7l00ol0003o^TFjokY5^P06okY5^P03o`000?nj
AK[o^TFj00Go^TFj0_l0000;okY5^P04o`000?n^DJko[U6^o`0000_o[e2_00?o0000ok5>/OnaC[40
2OnaC[400ol0003odRgBom8]dP0Fom8]dP03o`000?oH9mSof2OH00gof2OH0ol00005om</d`03o`00
0?o:=L[obSG:00oobSG:00?o0000olHia_o6>LH00oo6>LH4o`0000_oZUFZ0_l00006omTVf@03o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oaC[5olDja@02olDja@ko00001_njAKX00ol0003o^TFjokY5
^P05okY5^P03o`000?njAK[o^TFj00co^TFj00?o0000ojiA[_l000002on_D:l00ol0003o/Djaok5>
/@07ok5>/@?o00006?oB;M800ol0003of2OHomPWf00@omPWf0?o000000?odbcCo`000?o:=LX04?o:
=LX00ol0003oaSW6olHiaP07olHiaP03o`000?nZEJ[oZUFZ00[oZUFZ00?o0000omTVfOoI9]T01OoI
9]T00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olDja@03o`000?n:MH[oRWF:00_oRWF:0_l00004
okY5^P03o`000?njAK[o^TFj00?o^TFj0_l0000@okY5^P03o`000?n_D:oo[e2_00[o[e2_00?o0000
ok5>/OnaC[400onaC[44o`0000;oYeRW00?o0000om8]d_oB;M805OoB;M800ol0003of2OHomPWf00D
omPWf003o`000?o:=L[obSG:013obSG:00?o0000olHia_o6>LH01oo6>LH00ol0003oZUFZojYEZP0:
ojYEZP03o`000?oI9]WofBKI00GofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o5>/GoaC[5
00GoaC[500?o0000ohYeR_n:MHX03On:MHX6o`0000?o^TFj00?o0000okY5^_njAKX04?njAKX00ol0
003o[e2_ojm@[`0:ojm@[`03o`000?naC[7o000000?o00001onWF:L00ol0003odRgBom8]dP0Dom8]
dP03o`000?oH9mSof2OH01Cof2OH00?o0000olXeb_o:=LX03oo:=LX00ol0003oaSW6olHiaP08olHi
aP03o`000?nZEJ[oZUFZ00[oZUFZ00?o0000omTVfOoI9]T01OoI9]T00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olDjaOo5>/D01_o5>/D00ol0003oRWF:ohYeRP0=ohYeRP03o`000?o1?/7o`Ck100?o
`Ck100?o0000okY5^_l000004onjAKX4o`0000Wo[e2_0_l0000<ojMHY`03o`000?oB;M;odRgB01?o
dRgB00?o0000omPWf?oH9mP05OoH9mP00ol0003obSG:olXebP0>olXebP03o`000?o6>LKoaSW600So
aSW600?o0000ojYEZ_nZEJX02OnZEJX00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o5>/GoaC[500SoaC[500?o0000ohYeR_n:MHX02on:MHX00ol0003o`Ck1ol4n`@05ol4n`@03o`00
0?njAK[o^TFj01;o^TFj00Co0000ok1?/?n`Ck3o/4n`1Ol00003ojm@[`03o`000?nWF:OoYeRW00go
YeRW0ol0000@om8]dP;o00006?oH9mP00ol0003obSG:olXebP0=olXebP03o`000?o6>LKoaSW600Wo
aSW600?o0000ojYEZ_nZEJX02OnZEJX00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_oaC[500?o0000ohYeR_n:MHX02_n:MHX00ol0003o`Ck1ol4n`@06ol4n`@03o`00
0?njAK[o^TFj017o^TFj00?o0000ok1?/?n`Ck001on`Ck03o`00013oYeRW00?o0000ojEJYOnUFZD0
1Ol00009om8]dP;o000000?o]4^do`000?oH9mP05ooH9mP00ol0003obSG:olXebP0=olXebP03o`00
0?o6>LKoaSW600WoaSW600?o0000ojYEZ_nZEJX02?nZEJX2o`0000[ofBKI00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oH9mSof2OH00;of2OH00?o0000olDjaOo5>/D02Oo5>/D00ol0003oRWF:ohYe
RP0:ohYeRP03o`000?o1?/7o`Ck100Oo`Ck100?o0000okY5^_njAKX03onjAKX00ol0003o/4n`ok1?
/00:ok1?/003o`000?nWF:OoYeRW00goYeRW00?o0000ojEJYOnUFZD01_nUFZD4o`0000CodRgB00?o
0000okA;]?ndBk@00_ndBk@00ol0003of2OHomPWf00FomPWf003o`000?o:=L[obSG:00_obSG:00?o
0000olHia_o6>LH02oo6>LH00ol0003oZUFZojYEZP06ojYEZP03o`000?nGJ9Oo000000[ofBKI00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oH9mSof2OH00?of2OH00?o0000olDjaOo5>/D02?o5>/D=
o`0000[o`Ck100?o0000okY5^_njAKX03onjAKX00ol0003o/4n`ok1?/00;ok1?/003o`000?nWF:Oo
YeRW00coYeRW00?o0000ojEJYOnUFZD02_nUFZD4o`0000Go]4^d00?o0000omPWf?oH9mP05_oH9mP0
0ol0003obSG:olXebP0:olXebP03o`000?o6>LKoaSW600coaSW600?o0000ojYEZ_nZEJX01?nZEJX2
o`0000?oUfRG00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omPW
f?oH9mP00ooH9mP00ol0003oaC[5olDja@07olDja@03o`000?n9MXWoRGJ900WoRGJ900?o0000ol4n
`Oo1?/402Oo1?/400ol0003o^TFjokY5^P0=okY5^P03o`000?n`Ck3o/4n`00co/4n`00?o0000ojMH
YonWF:L03?nWF:L00ol0003oYEZUojEJY@0;ojEJY@03o`000?nAKY7o000000Ko]4^d00?o0000omPW
f?oH9mP05_oH9mP00ol0003obSG:olXebP09olXebP03o`000?o6>LKoaSW600coaSW600?o0000ojYE
Z_nZEJX00onZEJX00ol0003oUfRGoiMXU`03oiMXU`03o`000?oI9]WofBKI00SofBKI00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oH9mSof2OH00Cof2OH00?o0000olDjaOo5>/D01_o5>/D00ol0003o
RGJ9ohUfR@08ohUfR@03o`000?o1?/7o`Ck100_o`Ck100?o0000okY5^_njAKX02?njAKX4o`0000oo
/4n`00?o0000ojMHYonWF:L02onWF:L00ol0003oYEZUojEJY@0;ojEJY@04o`000?nAKY7oTFjAo`00
00Oo]4^d00?o0000omPWf?oH9mP05OoH9mP00ol0003obSG:olXebP08olXebP03o`000?o6>LKoaSW6
00goaSW600?o0000ojYEZ_nZEJX00_nZEJX00ol0003oUfRGoiMXU`05oiMXU`03o`000?oI9]WofBKI
00OofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oH9mSof2OH00Gof2OH00?o0000olDjaOo5
>/D01Oo5>/D00ol0003oRGJ9ohUfR@08ohUfR@03o`000?o1?/7o`Ck100_o`Ck100?o0000okY5^_nj
AKX00onjAKX5o`0000?o/Dja00?o0000ok1?/?n`Ck003_n`Ck000ol0003oYeRWojMHY`0:ojMHY`03
o`000?nUFZGoYEZU00[oYEZU00Go0000oi5^TOnAKY7oTFjAo`000007okA;]003o`000?oH9mSof2OH
01Gof2OH00?o0000olXeb_o:=LX02?o:=LX00ol0003oaSW6olHiaP0=olHiaP03o`000?nZEJ[oZUFZ
00;o00002?nGJ9L00ol0003ofBKIomTVf@08omTVf@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003of2OHomPWf005omPWf003o`000?o5>/GoaC[500Go
aC[500?o0000ohUfROn9MXT02?n9MXT00ol0003o`Ck1ol4n`@0<ol4n`@Go00002OnaC[400ol0003o
/4n`ok1?/00<ok1?/0;o00003?nWF:L00ol0003oYEZUojEJY@0:ojEJY@05o`000?nAKY7oTFjAoi5^
TOl000002?ndBk@00ol0003of2OHomPWf00DomPWf0?o00001oo:=LX00ol0003oaSW6olHiaP0>olHi
aP03o`000?nZEJ[o000000_oUfRG00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000omPWf?oH9mP01OoH9mP00ol0003oaC[5olDja@04olDja@03o`000?n9MXWoRGJ900Oo
RGJ900?o0000ol4n`Oo1?/403?o1?/401?l0003o^TFjokY5^_l0000;ok5>/@03o`000?n`Ck3o/4n`
00_o/4n`00Co0000ohm`Son?L8oo00002_nWF:L00ol0003oYEZUojEJY@0:ojEJY@03o`000?nAKY7o
TFjA00;oTFjA00?o0000okA;]?ndBk@01_ndBk@00ol0003of2OHomPWf00AomPWf0?o00000onjAKX0
0ol0003obSG:olXebP04olXebP03o`000?o6>LKoaSW600goaSW61?l0000;oiMXU`03o`000?oI9]Wo
fBKI00GofBKI00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oH9mSof2OH00Kof2OH00Co0000olDj
aOo5>/GoaC[51?l00008ohUfR@03o`000?o1?/7o`Ck100_o`Ck100?o0000okY5^_njAKX00_njAKX0
0ol0003o/Djaok5>/@08ok5>/@03o`000?n`Ck3o/4n`00[o/4n`00?o0000ohm`Son?L8l00_n?L8l0
0ol0003oYeRWojMHY`03ojMHY`Go00002onUFZD00ol0003oTFjAoi5^T@03oi5^T@03o`000?ndBkCo
]4^d00Oo]4^d00?o0000omPWf?oH9mP03_oH9mP2o`0000Oo^TFj00?o0000olXeb_o:=LX00_o:=LX0
0ol0003oaSW6olHiaP0=olHiaP03o`000?n[E:_oZeB[00;oZeB[00?o0000oiMXUonGJ9L02OnGJ9L0
0ol0003ofBKIomTVf@03omTVf@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003of2OHomPWf007omPW
f0?o00001?nm@[d00ol0003oRGJ9ohUfR@05ohUfR@03o`000?o1?/7o`Ck100[o`Ck100?o0000okY5
^_njAKX00onjAKX00ol0003o/Djaok5>/@09ok5>/@03o`000?n`Ck3o/4n`00So/4n`00?o0000ohm`
Son?L8l01?n?L8l5o`0000CoHIiQ00?o0000ojEJYOnUFZD02OnUFZD00ol0003oTFjAoi5^T@03oi5^
T@03o`000?ndBkCo]4^d00So]4^d00?o0000omPWf?oH9mP02_oH9mP3o`0000[o^TFj00Go0000olXe
b_o:=L[obSG:o`00000>olHiaP03o`000?n[E:_oZeB[00CoZeB[0_l00009oiMXU`03o`000?oI9]Wo
fBKI00;ofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oH9mSof2OH00Oof2OH00?o0000oke2
_Onm@[d01Onm@[d00ol0003oRGJ9ohUfR@03ohUfR@03o`000?o1?/7o`Ck100[o`Ck100?o0000okY5
^_njAKX01?njAKX00ol0003o/Djaok5>/@09ok5>/@03o`000?n`Ck3o/4n`00Oo/4n`00?o0000ohm`
Son?L8l01On?L8l00ol0003oHIiQof6NH@07of6NH@03o`000?nUFZGoYEZU00OoYEZU00?o0000oi5^
TOnAKY401?nAKY400ol0003o]4^dokA;]008okA;]003o`000?oH9mSof2OH00Sof2OH0_l0000>okY5
^PCo00003?o6>LH2o`0000WoZeB[00?o0000oiMXUonGJ9L01onGJ9L01?l0003ofBKIomTVfOl0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omPWf?oH9mP01OoH9mP00ol0003o_D:moke2_@07oke2_@;o00000on9MXT00ol0
003o`Ck1ol4n`@09ol4n`@03o`000?njAK[o^TFj00Ko^TFj00?o0000ok5>/OnaC[402OnaC[400ol0
003o/4n`ok1?/005ok1?/003o`000?n?L8ooSg2?00KoSg2?00?o0000of6NHOmQWV402?mQWV400ol0
003oYEZUojEJY@06ojEJY@03o`000?nAKY7oTFjA00CoTFjA00?o0000okA;]?ndBk@02OndBk@4o`00
00?of2OH0ol0000@okY5^P05o`000?oE:]GoeB[EomDZeOl000002_o6>LH00ol0003oZeB[oj]DZ`0:
oj]DZ`Ko00000onGJ9L00ol0003ofBKIo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000omPWf?oH9mP01?oH9mP00ol0
003o_D:moke2_@0:oke2_@04o`000?n9MXWoRGJ9o`0000[o`Ck100?o0000okY5^_njAKX01onjAKX0
0ol0003o/Djaok5>/@09ok5>/@03o`000?n`Ck3o/4n`00Co/4n`00?o0000ohm`Son?L8l01on?L8l0
0ol0003oHIiQof6NH@08of6NH@;o00001_nUFZD00ol0003oTFjAoi5^T@05oi5^T@03o`000?ndBkCo
]4^d00Wo]4^d00Co0000ojMHYonWF:OoYeRW0ol0000BokY5^P03o`000?oE:]GoeB[E00?oeB[E0_l0
0006olHiaP;o00003On[E:/00ol0003ogB;MomdRg@03omdRg@Go00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000omPWf?oH9mP00ooH9mP0
0ol0003o_D:moke2_@0<oke2_@;o00002_o1?/400ol0003o^TFjokY5^P08okY5^P03o`000?naC[7o
/Dja00[o/Dja00?o0000ok1?/?n`Ck000_n`Ck000ol0003oSg2?ohm`S`08ohm`S`03o`000?mQWV7o
HIiQ00KoHIiQ0_l00002ohacS003o`000?nUFZGoYEZU00;oYEZU00?o0000oi5^TOnAKY401_nAKY40
0ol0003o]4^dokA;]008okA;]003o`000?nWF:OoYeRW00CoYeRW00?o0000okY5^_njAKX03onjAKX0
0ol0003oeB[EomDZe@06omDZe@;o00000oo6>LH00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?oM8]go
gB;M00OogB;M0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003of2OHomPWf002omPWf003o`000?nm@[go_D:m
00ko_D:m00?o0000ol4n`Oo1?/401oo1?/400ol0003o^TFjokY5^P0:okY5^P03o`000?naC[7o/Dja
00Wo/Dja00Go0000ok1?/?n`Ck3o/4n`o`00000;ohm`S`03o`000?mQWV7oHIiQ00CoHIiQ0_l00005
ohacS005o`000?nUFZGoYEZUojEJYOl000002?nAKY400ol0003o]4^dokA;]008okA;]003o`000?nW
F:OoYeRW00GoYeRW00?o0000okY5^_njAKX03_njAKX00ol0003oeB[EomDZe@08omDZe@03o`000?o6
>LKo000000ooZeB[00?o0000omdRgOoM8]d02?oM8]d01?l0003onPGjo`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oH9mSof2OHo`00017o_D:m00?o0000ol4n`Oo1?/401_o1?/400ol0003o^TFj
okY5^P0;okY5^P03o`000?naC[7o/Dja00Wo/Dja00Co0000ok1?/?n`Ck3o00003?n?L8l00ol0003o
HIiQof6NH@02of6NH@;o00002?n<Lh`00ol0003oYEZUo`000009oi5^T@03o`000?ndBkCo]4^d00So
]4^d00?o0000ojMHYonWF:L01OnWF:L00ol0003o^TFjokY5^P0=okY5^P03o`000?oE:]GoeB[E00[o
eB[E00?o0000oj]DZon[E:/03_n[E:/00ol0003ogB;MomdRg@07omdRg@03o`000?oj1O[onPGj00;o
nPGj00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000Boke2_@03o`00
0?o1?/7o`Ck100Co`Ck100?o0000okY5^_njAKX03?njAKX00ol0003o/Djaok5>/@0:ok5>/@?o0000
3?n?L8l00ol0003oHIiQof6NH@02o`0000_oS7><00?o0000oi5^TOnAKY402?nAKY400ol0003o]4^d
okA;]007okA;]003o`000?nWF:OoYeRW00OoYeRW00?o0000okY5^_njAKX03?njAKX00ol0003oeB[E
omDZe@0;omDZe@;o00003_n[E:/00ol0003ogB;MomdRg@07omdRg@03o`000?oj1O[onPGj00?onPGj
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000on<LhooS7><00ooS7><00ol0003o_D:moke2_@0?oke2_@?o00000oo1
?/400ol0003o^TFjokY5^P0>okY5^P03o`000?naC[7o/Dja00So/Dja00Co0000oiIYU_nFJIKoUVVF
0_l0000:ohm`S`?o00003On<Lh`00ol0003oTFjAoi5^T@08oi5^T@03o`000?ndBkCo]4^d00Oo]4^d
00?o0000ojMHYonWF:L01onWF:L00ol0003o^TFjokY5^P0;okY5^P03o`000?oE:]GoeB[E00coeB[E
00?o0000ol8m`_l000000_l0000:oj]DZ`03o`000?oM8]gogB;M00SogB;M00?o0000ooX5n_oj1OX0
1Ooj1OX2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003ohacSon<Lh`04on<Lh`03o`000?nm@[go_D:m00co_D:m0_l0
0003okA;]003o`000?o1?/7o0000017o^TFj00?o0000ok5>/OnaC[401onaC[400ol0003oUVVFoiIY
UP04oiIYUP;o00002?n?L8l00ol0003oS7><ohacS00>ohacS0;o00002?nAKY400ol0003o]4^dokA;
]006okA;]003o`000?nWF:OoYeRW00WoYeRW00?o0000okY5^_njAKX02OnjAKX00ol0003oeB[EomDZ
e@0=omDZe@03o`000?o2?L;o`Sg200;o`Sg20ol00007oj]DZ`03o`000?oM8]gogB;M00OogB;M00?o
0000ooX5n_oj1OX02?oj1OX2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003ohacSon<Lh`05on<Lh`03o`000?nm@[go
_D:m00Wo_D:m0_l00006okA;]003o`000?njAK[o^TFj013o^TFj00?o0000ok5>/OnaC[401_naC[40
0ol0003oUVVFoiIYUP07oiIYUP03o`000?n?L8ooSg2?00CoSg2?0ol0000>ohacS003o`000?mjQG[o
NXEj00?o00001OnAKY400ol0003o]4^dokA;]006okA;]003o`000?nWF:OoYeRW00[oYeRW00?o0000
okY5^_njAKX02?njAKX00ol0003oeB[EomDZe@0=omDZe@03o`000?o2?L;o`Sg200Go`Sg20ol00004
oj]DZ`03o`000?oM8]gogB;M00OogB;M00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003ohacSon<Lh`06on<Lh`03o`000?nm@[go_D:m00Go_D:m0ol00008okA;]003o`000?njAK[o^TFj
017o^TFj00Co0000ok5>/OnaC[7o/Dja1?l0000;oiIYUP;o000000CoSg2?o`000?l0003o00000onQ
GZ42o`0000_oS7><00?o0000ogZ5N_mjQGX01?mjQGX2o`0000?oTFjA00?o0000okA;]?ndBk@01_nd
Bk@00ol0003oYeRWojMHY`0:ojMHY`03o`000?njAK[o^TFj00Oo^TFj00?o0000omDZeOoE:]D03_oE
:]D00ol0003o`Sg2ol8m`P08ol8m`PCo00002_oM8]d00ol0003onPGjooX5nP0;ooX5nP;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ohacSon<Lh`07on<Lh`03o`000?nm@[go_D:m00;o_D:m0_l0000<okA;]003o`000?njAK[o
^TFj013o^TFj1?l00003ojMHY`03o`000?nFJIKoUVVF00_oUVVF00?o0000oj5NXOnQGZ401_nQGZ40
0ol0003oS7><ohacS007ohacS003o`000?mjQG[oNXEj00OoNXEj3?l0000>ojMHY`03o`000?njAK[o
^TFj00Ko^TFj00?o0000omDZeOoE:]D03_oE:]D00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oM8]go
gB;M00OogB;M00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oS7>?ohacS00WohacS00Co0000oke2
_Ol0003o00003_ndBk@00ol0003o^TFjokY5^P0?okY5^P03o`000?nWF:OoYeRW00KoYeRW00?o0000
oiIYU_nFJIH02_nFJIH00ol0003oXEjQoj5NX@07oj5NX@;o00001_n<Lh`00ol0003oNXEjogZ5NP08
ogZ5NP03o`000?niA[Wo^DJi00So^DJi00?o0000ojMHYonWF:L03?nWF:L00ol0003o^TFjokY5^P05
okY5^P03o`000?oE:]GoeB[E00ooeB[E0_l0000=ol8m`P03o`000?oM8]gogB;M00KogB;M00?o0000
ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oS7>?ohacS00[ohacS00?o0000okA;]?ndBk@03_ndBk@00ol0
003o^TFjokY5^P0>okY5^P03o`000?nWF:OoYeRW00OoYeRW00?o0000oiIYU_nFJIH02_nFJIH00ol0
003oXEjQoj5NX@09oj5NX@;o00000on<Lh`00ol0003oNXEjogZ5NP09ogZ5NP03o`000?niA[Wo^DJi
00Wo^DJi00?o0000ojMHYonWF:L02_nWF:L4o`0000Co^TFj00?o0000omDZeOoE:]D04?oE:]D01?l0
003o`Ck1o`000?l0000<ol8m`P03o`000?oM8]gogB;M00GogB;M00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oS7>?ohacS00[ohacS00?o0000okA;]?ndBk@03ondBk@@o`0000[oYeRW00?o0000oiIY
U_nFJIH02OnFJIH00ol0003oPWf2o`00000<oj5NX@05o`000?n<Lhco0000og^4Nol000002_mjQGX0
0ol0003o^DJiokU6^@09okU6^@03o`000?nWF:OoYeRW00OoYeRW0ol00004ol0o`0?o000000?o^TFj
o`000?oE:]D04OoE:]D01?l0003o`Ck1ol4n`Oo1?/42o`0000_o`Sg200?o0000omdRgOoM8]d00ooM
8]d00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on<LhooS7><02_oS7><00ol0003o]4^dokA;]00?
okA;]003o`000?no?koo_cno00co_cno00?o0000ojMHYonWF:L02OnWF:L00ol0003oUVVFoiIYUP07
oiIYUP04o`000?n2OH;oPWf2o`0000goXEjQ00Go0000og^4NomkQ7_oNhAko`000009ogZ5NP03o`00
0?niA[Wo^DJi00[o^DJi00?o0000ojMHYonWF:L00onWF:L3o`0000[o`3o000?o0000omDZeOoE:]D0
4?oE:]D00ol0003o`Ck1ol4n`@04ol4n`@;o00002_o2?L800ol0003ogB;MomdRg@04o`0000oonPGj
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000cohacS00?o0000okA;]?ndBk@03ondBk@00ol0003o_cnooklo_`0<oklo_`03o`000?nW
F:OoYeRW00WoYeRW00?o0000oiIYU_nFJIH01_nFJIH00ol0003oPWf2oh9mPP02oh9mPP03o`000?nQ
GZ7oXEjQ00[oXEjQ00?o0000og^4NomkQ7/00_mkQ7/00ol0003oNXEjogZ5NP06ogZ5NP03o`000?ni
A[Wo^DJi00[o^DJi00?o0000ojMHYonWF:L00ol0000=ol0o`003o`000?oE:]GoeB[E013oeB[E00?o
0000ol4n`Oo1?/401_o1?/42o`0000Wo`Sg20_l00004ooX5nP03o`000?oj1O[onPGj00_onPGj00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000on<LhooS7><02_oS7><00ol0003o]4^dokA;]00=okA;]0?o00003ono?kl0
0ol0003oYeRWojMHY`08ojMHY`03o`000?nFJIKoUVVF00GoUVVF00?o0000oh9mP_n2OH800on2OH80
0ol0003oXEjQoj5NX@0:oj5NX@03o`000?mkQ7_oNhAk00?oNhAk00?o0000ogZ5N_mjQGX01OmjQGX0
0ol0003o^DJiokU6^@0;okU6^@;o00004Oo0?l000ol0003oeB[EomDZe@0?omDZe@03o`000?o1?/7o
`Ck100So`Ck10_l00007ol8m`P03o`000?oj1O[onPGj00ConPGj00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000on<LhooS7><02?oS7><00ol0003o]4^dokA;]009okA;]0Go00000_nSG:<00ol0
003o_cnooklo_`0=oklo_`03o`000?nWF:OoYeRW00WoYeRW00?o0000oiIYU_nFJIH01?nFJIH00ol0
003oPWf2oh9mPP04oh9mPP03o`000?nQGZ7oXEjQ00SoXEjQ00?o0000og^4NomkQ7/01OmkQ7/00ol0
003oNXEjogZ5NP04ogZ5NP03o`000?niA[Wo^DJi00_o^DJi00?o0000ol0o`?o0?l004?o0?l000ol0
003oeB[EomDZe@0?omDZe@03o`000?o1?/7o`Ck100[o`Ck10_l00004ol8m`P03o`000?oj1O[onPGj
00KonPGj0_l0000:ooX5nP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003ohacSon<Lh`07on<Lh`03o`000?ndBkCo]4^d00Co]4^d1Ol00007oj=LX`03
o`000?no?koo_cno00go_cno00?o0000ojMHYonWF:L02OnWF:L00ol0003oUVVFoiIYUP03oiIYUP03
o`000?n2OH;oPWf200GoPWf200?o0000oj5NXOnQGZ402?nQGZ400ol0003oNhAkog^4N`06og^4N`03
o`000?mjQG[oNXEj00?oNXEj00?o0000okU6^OniA[T02oniA[T00ol0003o`3o0ol0o`00@ol0o`003
o`000?oE:]GoeB[E00ooeB[E00?o0000ol4n`Oo1?/403?o1?/42o`000003ol8m`_l0003onPGj00[o
nPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oS7>?ohacS00OohacS00?o0000okA;]?l00000
1?l0000<oj=LX`03o`000?no?koo_cno00ko_cno00?o0000ojMHYonWF:L02?nWF:L00ol0003oUVVF
oiIYUP02oiIYUP03o`000?n2OH;oPWf200OoPWf200?o0000oj5NXOnQGZ401onQGZ400ol0003oNhAk
og^4N`07og^4N`03o`000?mjQG[oNXEj00;oNXEj00?o0000okU6^OniA[T02oniA[T00ol0003o`3o0
ol0o`00Aol0o`003o`000?oE:]GoeB[E00goeB[E00?o0000ol4n`Oo1?/403oo1?/400ol0003onPGj
ooX5nP0;ooX5nP;o00001Ooj1OX2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000on<LhooS7><01OoS7><3o`00017oXebS00?o0000oklo_ono?kl03_no
?kl00ol0003oYeRWojMHY`09ojMHY`04o`000?nFJIKoUVVFo`0000[oPWf200?o0000oj5NXOnQGZ40
1onQGZ400ol0003oNhAkog^4N`08og^4N`05o`000?mjQG[oNXEjogZ5N_l000003OniA[T00ol0003o
`3o0ol0o`00Aol0o`0?o00003OoE:]D00ol0003o`Ck1ol4n`@0?ol4n`@03o`000?oj1O[onPGj00go
nPGj00Go0000ooX5n_oj1O[onPGjo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oS7><2o`0000;o/Tfb00?o0000oj=LXonSG:<03onSG:<00ol0003o
_cnooklo_`0>oklo_`03o`000?nWF:OoYeRW00SoYeRW1Ol0000;oh9mPP03o`000?nQGZ7oXEjQ00Ko
XEjQ00?o0000og^4NomkQ7/02OmkQ7/01?l0003oNXEjogZ5N_l0000=okU6^@03o`000?o0?l3o`3o0
017o`3o000?o0000ojAKY?nTFj@00ol0000:omDZe@Co00003Oo1?/400ol0003onPGjooX5nP0?ooX5
nP03o`000?oj1O[o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000omXUf_oJ9M[ofRGJ0_l00005ok9=/P03o`000?nSG:?oXebS00koXebS00?o0000oklo
_ono?kl03_no?kl00ol0003oYeRWojMHY`07ojMHY`03o`000?nVFJKoYUVV00?oYUVV00?o0000oh9m
P_n2OH802?n2OH800ol0003oXEjQoj5NX@05oj5NX@03o`000?mkQ7_oNhAk00[oNhAk1Ol0000<okU6
^@03o`000?o0?l3o`3o0013o`3o000?o0000ojAKY?nTFj@01?nTFj@3o`0000KoeB[E00?o0000oldb
cOo=</d00_o=</d5o`0000So`Ck100?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oJ9M[ofRGJ00?o
fRGJ00?o0000ok9=/_nbCK801?nbCK800ol0003oXebSoj=LX`0=oj=LX`03o`000?no?koo_cno00oo
_cno00?o0000ojMHYonWF:L01?nWF:L2o`0000OoYUVV00?o0000oh9mP_n2OH801on2OH8Eo`0000Go
QgR700?o0000okU6^OniA[T02?niA[T3o`00013o`3o000?o0000ojAKY?nTFj@02?nTFj@3o`0000;o
eB[E00?o0000oldbcOo=</d02?o=</d5o`0000?o`Ck100?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oJ9M[ofRGJ00CofRGJ00?o0000ok9=/_nbCK801OnbCK800ol0003oXebSoj=LX`0;oj=LX`Co0000
3ono?kl00ol0003oYeRWojMHY`03ojMHY`03o`000?nVFJKoYUVV00SoYUVV00?o0000oh9mP_n2OH80
1?n2OH82o`0000SoYUVV00?o0000oiQWV?nHIiP02?nHIiP00ol0003oQgR7ohMhQ`05ohMhQ`;o0000
1_niA[T2o`0000?o/4n`00?o0000ol0o`?o0?l003?o0?l000ol0003oY5^TojAKY00<ojAKY0;o0000
4?o=</d3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003ofRGJomXUfP05omXUfP03o`000?nbCK;o/Tfb00Ko/Tfb00?o
0000oj=LXonSG:<02OnSG:<00ol0003oR7N8o`000002ojMHY`?o00003?no?kl01?l0003oYeRWojMH
YonWF:L2o`0000coYUVV00?o0000oh9mP_n2OH800_n2OH800ol0003oYUVVojIIYP08ojIIYP03o`00
0?nHIiSoV6NH00SoV6NH00?o0000ohMhQon7N8L01on7N8L00ol0003o^DJiokU6^@02okU6^@03o`00
0?n`Ck3o/4n`00Co/4n`0_l0000;ol0o`003o`000?nTFjCoY5^T00coY5^T00?o0000ojm@[ol00000
4_o=</d00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003ofRGJomXUfP06omXUfP03o`000?nbCK;o/Tfb00Oo/Tfb00?o
0000oj=LXonSG:<01_nSG:<2o`0000;oR7N800?o0000ojMHYonWF:L00onWF:L3o`0000[o_cno00?o
0000ojMHYol000003onVFJH01?l0003oPWf2o`000?l0000;ojIIYP03o`000?nHIiSoV6NH00SoV6NH
00?o0000ohMhQon7N8L02?n7N8L01?l0003o^DJio`000?l00009ok1?/003o`000?o0?l3o`3o000Oo
`3o000?o0000ojAKY?nTFj@03?nTFj@01?l0003o[e2_ojm@[ol0000Coldbc@03o`000?oj1O[onPGj
00conPGj0ol000000ooj1O[o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000omXUf_oJ9MX01ooJ9MX00ol0003o/Tfbok9=/P08ok9=/P03o`000?nSG:?oXebS00Co
XebS00?o0000ohQgR?n8MhP00on8MhP00ol0003oYeRWojMHY`05ojMHY`?o00001_no?kl4o`00013o
YUVV00?o0000ojIIY_nVFJH03?nVFJH00ol0003oV6NHoiQWV007oiQWV003o`000?n7N8OoQgR700Wo
QgR700?o0000ok1?/?n`Ck002_n`Ck02o`0000Ko`3o000?o0000ojAKY?nTFj@03?nTFj@00ol0003o
[e2_ojm@[`02ojm@[`03o`000?o=</gocC;=00oocC;=00?o0000omHYe_l000002ooj1OX2o`0000Co
nPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003ofRGJomXUfP08omXUfP03o`000?nbCK;o/Tfb00Wo/Tfb00Co0000oj=LXonSG:?o
XebS0_l00006ohQgR003o`000?nWF:OoYeRW00SoYeRW0ol000000ono?koo0000o`000004ojeB[@03
o`000?nVFJKoYUVV00goYUVV00?o0000ojIIY_nVFJH03?nVFJH00ol0003oV6NHoiQWV007oiQWV003
o`000?n7N8OoQgR700WoQgR700?o0000ok1?/?n`Ck003?n`Ck000ol0003o`3o0ol0o`003o`0000ko
Y5^T00?o0000ojm@[on_D:l00on_D:l00ol0003ocC;=oldbc@0>oldbc@05o`000?oF:MKoeRWFomHY
e_l000002?oj1OX2o`0000OonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003ofRGJomXUfP09omXUfP03o`000?nbCK;o/Tfb00[o
/Tfb00?o0000oj=LXol000002?n8MhP00ol0003oYeRWojMHY`0;ojMHY`03o`000?n]DZgo[E:]00Go
[E:]00?o0000ojIIY_nVFJH03?nVFJH00ol0003oYUVVojIIYP0<ojIIYP03o`000?nHIiSoV6NH00Oo
V6NH00?o0000ohMhQon7N8L02?n7N8L2o`0000oo/4n`0_l00002ok5>/@03o`000?nTFjCoY5^T00_o
Y5^T00?o0000ojm@[on_D:l01?n_D:l00ol0003ocC;=oldbc@0=oldbc@03o`000?oF:MKoeRWF00?o
eRWF00?o0000ooX5n_oj1OX00_oj1OX3o`0000WonPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omXUfP03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ohQgR?n8MhP0
1on8MhP00ol0003oYeRWojMHY`0;ojMHY`03o`000?n]DZgo[E:]00Ko[E:]00?o0000ojIIY_nVFJH0
2onVFJH2o`0000goYUVV00?o0000oiQWV?nHIiP01onHIiP00ol0003oQgR7ohMhQ`07ohMhQ`04o`00
0?nBKI;oTVfBo`0000ko/4n`00?o0000ok5>/OnaC[400_naC[400ol0003oY5^TojAKY009ojAKY003
o`000?n_D:oo[e2_00Ko[e2_00?o0000oldbcOo=</d02oo=</d00ol0003oeRWFomHYeP05omHYeP04
o`000?oj1O[o0000o`0000conPGj00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooX5n_oj1OX00_oj1OX3o`0000SofRGJ00?o0000ok9=/_nbCK802_nbCK82o`0000Wo
R7N800?o0000ojMHYonWF:L02onWF:L00ol0003o[E:]ojeB[@07ojeB[@03o`000?nVFJKoYUVV00Wo
YUVV00Co0000ogV6NOmiQWWo00003?nVFJH00ol0003oV6NHoiQWV007oiQWV003o`000?n7N8OoQgR7
00KoQgR700Go0000oi9]T_nBKI;oTVfBo`00000>ok1?/003o`000?naC[7o/Dja00?o/Dja00?o0000
ojAKY?nTFj@01onTFj@00ol0003o[e2_ojm@[`07ojm@[`03o`000?o=</gocC;=00[ocC;=00?o0000
omHYe_oF:MH01ooF:MH00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00GonPGj0_l00006omXUfP03o`000?nbCK;o/Tfb
00Wo/Tfb00Co0000oi=/TonCK9?o00002On8MhP00ol0003oYeRWojMHY`09ojMHY`03o`000?n]DZgo
[E:]00Wo[E:]00?o0000ojIIY_nVFJH01onVFJH00ol0003oNHIiogV6N@02ogV6N@03o`000?nVFJKo
YUVV00WoYUVV00?o0000oiQWV?nHIiP01onHIiP00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?nBKI;o
TVfB00?oTVfB00?o0000ok1?/?n`Ck002_n`Ck000ol0003o/Djaok5>/@05ok5>/@03o`000?nTFjCo
Y5^T00GoY5^T00?o0000ojm@[on_D:l02?n_D:l00ol0003ocC;=oldbc@09oldbc@03o`000?oF:MKo
eRWF00SoeRWF00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003onPGjooX5nP07ooX5nP?o00000_oJ9MX3o`0000Wo/Tfb00?o0000oi=/
TonCK9<00_nCK9<00ol0003oR7N8ohQgR006ohQgR003o`000?nWF:OoYeRW00WoYeRW00?o0000ojeB
[On]DZd02_n]DZd00ol0003oYUVVojIIYP05ojIIYP03o`000?miQWWoNHIi00CoNHIi00?o0000ojII
Y_nVFJH02?nVFJH00ol0003oV6NHoiQWV007oiQWV003o`000?n7N8OoQgR700CoQgR700?o0000oi9]
T_nBKI801?nBKI800ol0003o/4n`ok1?/00:ok1?/003o`000?naC[7o/Dja00Ko/Dja00?o0000ojAK
Y?nTFj@00onTFj@00ol0003o[e2_ojm@[`09ojm@[`03o`000?o=</gocC;=00SocC;=00?o0000omHY
e_oF:MH02OoF:MH00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oj1O[onPGj00[onPGj0_l00003omLXe`?o00001OnbCK800ol0003o
TfbCoi=/T`03oi=/T`03o`000?n8MhSoR7N800KoR7N800?o0000ojMHYonWF:L02OnWF:L00ol0003o
[E:]ojeB[@0;ojeB[@03o`000?nVFJKoYUVV00?oYUVV00?o0000ogV6NOmiQWT01_miQWT00ol0003o
YUVVojIIYP08ojIIYP03o`000?nHIiSoV6NH00KoV6NH00?o0000ohMhQon7N8L00_n7N8L2o`0000So
TVfB00?o0000ok1?/?n`Ck002On`Ck000ol0003o/Djaok5>/@07ok5>/@05o`000?nTFjCoY5^TojAK
Y?l000003On_D:l00ol0003ocC;=oldbc@06oldbc@03o`000?oF:MKoeRWF00[oeRWF00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
nPGjooX5nP0:ooX5nP03o`000?oG:=OoebSG00GoebSG0ol000000onbCK;o0000oi=/T`06oi=/T`03
o`000?n8MhSoR7N800GoR7N800?o0000ojMHYonWF:L02OnWF:L00ol0003o[E:]ojeB[@0<ojeB[@05
o`000?nVFJKoYUVVojIIY_l000002_miQWT00ol0003oYUVVojIIYP07ojIIYP03o`000?nHIiSoV6NH
00KoV6NH00?o0000ohMhQol000000_l000000ongB;Oo0000oi9]TP07oi9]TP03o`000?n`Ck3o/4n`
00So/4n`00?o0000ok5>/OnaC[402OnaC[400ol0003oY5^To`00000=ojm@[`Co00001Oo=</d00ol0
003oeRWFomHYeP0;omHYeP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSGomLXe`08omLXe`03
o`000?nCK9?oTfbC00OoTfbC00?o0000ohQgR?n8MhP01?n8MhP00ol0003oYeRWojMHY`09ojMHY`03
o`000?n]DZgo[E:]00go[E:]00?o0000ojIIY_l000003?miQWT:o`0000OoV6NH0ol00005okM8]`03
o`000?nBKI;oTVfB00KoTVfB00?o0000ok1?/?n`Ck001on`Ck000ol0003o/Djaok5>/@0:ok5>/@03
o`000?n_D:oo[e2_00_o[e2_00?o0000okI9]_nfBKH00_nfBKH3o`000003oldbcOl0003oeRWF00_o
eRWF0ol0000>ooX5nP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oj1O[onPGj00[onPGj00?o0000omLXeooG:=L02OoG:=L00ol0003oTfbCoi=/T`07oi=/T`03o`00
0?n8MhSoR7N800GoR7N800?o0000ojMHYonWF:L01onWF:L00ol0003o[E:]ojeB[@0?ojeB[@;o0000
2omiQWT00ol0003o[e2_ojm@[`07ojm@[`03o`000?nHIiSoV6NH00;oV6NH0ol00008okM8]`03o`00
0?nBKI;oTVfB00KoTVfB00?o0000ok1?/?n`Ck001on`Ck000ol0003o/Djaok5>/@0:ok5>/@03o`00
0?n_D:oo[e2_00[o[e2_00?o0000okI9]_nfBKH01_nfBKH00ol0003oeRWFomHYeP08omHYeP?o0000
0_oQ7^400ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oj1O[onPGj00[onPGj00?o0000omLXeooG:=L02OoG:=L00ol0003oTfbCoi=/
T`08oi=/T`03o`000?n8MhSoR7N800CoR7N800?o0000ojMHYonWF:L01onWF:L00ol0003o[E:]ojeB
[@0>ojeB[@04o`000?n9MXWoRGJ9o`0000WoNHIi00?o0000ojm@[on_D:l02On_D:l01?l0003oV6NH
o`000?l0000<okM8]`03o`000?nBKI;oTVfB00KoTVfB00?o0000ok1?/?n`Ck001_n`Ck000ol0003o
/Djaok5>/@0;ok5>/@03o`000?n_D:oo[e2_00Oo[e2_0_l00009okI9]P03o`000?oF:MKoeRWF00Co
eRWF1?l00006on4Nh@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooX5n_oj1OX02_oj1OX00ol0003oebSGomLXe`09omLXe`03o`00
0?nCK9?oTfbC00SoTfbC00?o0000ohQgR?n8MhP00on8MhP>o`0000go[E:]00?o0000ohUfROn9MXT0
0_n9MXT00ol0003oNHIiogV6N@05ogV6N@03o`000?n_D:oo[e2_00_o[e2_00?o0000okM8]ongB;L0
3?ngB;L00ol0003oTVfBoi9]TP06oi9]TP03o`000?n`Ck3o/4n`00Go/4n`00?o0000ok5>/OnaC[40
3?naC[400ol0003o[e2_ojm@[`06ojm@[`03o`000?nfBKKo]TVf00[o]TVf00?o0000omHYe_oF:MH0
0ol0000:on4Nh@?o00002_oj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000oi=/TonCK9<02?nC
K9<01Ol0003oR7N8ohQgR?n8MhSo000000_oWF:M00?o0000ofBKI?mTVf@00ol00009ojeB[@03o`00
0?n9MXWoRGJ900CoRGJ900?o0000ogV6NOmiQWT00omiQWT00ol0003o[e2_ojm@[`0<ojm@[`03o`00
0?ngB;Oo]dRg00go]dRg00?o0000oi9]T_nBKI801_nBKI800ol0003o/4n`ok1?/003ok1?/0?o0000
3OnaC[400ol0003o[e2_ojm@[`05ojm@[`03o`000?nfBKKo]TVf00co]TVf0_l0000=on4Nh@03o`00
0?ok1?_on`Ck00?o00001ooj1OX00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003onPGjooX5nP09ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000oi=/TonCK9<02?nC
K9<4o`0000coWF:M00?o0000ofBKI?mTVf@00omTVf@3o`0000Go[E:]00?o0000ohUfROn9MXT01_n9
MXT01Ol0003oNHIiogV6NOmiQWWo000000oo[e2_00?o0000okM8]ongB;L03OngB;L00ol0003oTVfB
oi9]TP06oi9]TP03o`000?n`Ck3o/4n`00?o00000onDJi@00ol0003o/Djaok5>/@0;ok5>/@03o`00
0?n_D:oo[e2_00?o[e2_00?o0000okI9]_nfBKH03OnfBKH00ol0003ohAkQon4Nh@0;on4Nh@03o`00
0?ok1?_on`Ck00Con`Ck0ol00004ooX5nP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oj1O[onPGj00SonPGj00?o0000omLXeooG:=L02_oG:=L3o`0000KoTfbC0ol0
0003oi9]TP03o`000?nMHYgoWF:M00[oWF:M00?o0000ofBKI?mTVf@01_mTVf@3o`000003ojeB[Ol0
003oRGJ900WoRGJ900?o0000ogV6NOl000004?n_D:l00ol0003o]dRgokM8]`0=okM8]`03o`000?nB
KI;oTVfB00OoTVfB0_l00007oiA[U003o`000?naC[7o/Dja00[o/Dja00Co0000ojm@[on_D:oo[e2_
0ol0000?okI9]P03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000omLXeooG:=L02_oG
:=L01?l0003o_4>loka3_?nl@k`2o`000004oi=/Tol0003o0000o`0000KoTVfB00?o0000oieRWOnM
HYd02_nMHYd00ol0003oI9]TofBKI009ofBKI003o`000?n9MXWoRGJ900[oRGJ900?o0000ojm@[on_
D:l03on_D:l00ol0003o]dRgokM8]`0>okM8]`03o`000?nBKI;oTVfB00KoTVfB00?o0000oiA[U?nD
Ji@01onDJi@4o`0000So/Dja00Co0000ojm@[on_D:oo00000on6NHH2o`0000go]TVf00?o0000on4N
hOoQ7^402_oQ7^400ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oj1O[onPGj00GonPGj00?o0000omLXeooG:=L02OoG:=L00ol0003o
_4>loka3_004oka3_003o`000?nBKI;oTVfB00OoTVfB00?o0000oieRWOnMHYd02OnMHYd00ol0003o
I9]TofBKI00:ofBKI003o`000?n9MXWoRGJ900[oRGJ900?o0000ojm@[on_D:l03on_D:l00ol0003o
]dRgokM8]`0>okM8]`03o`000?nBKI;oTVfB00GoTVfB00?o0000oiA[U?nDJi@02?nDJi@01?l0003o
XUfRoj9MX_nRGJ87o`0000;o/Dja0_l00006ohIiQP;o00003?nfBKH00ol0003ohAkQon4Nh@09on4N
h@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oebSGomLXe`08omLXe`03o`000?nl@kco_4>l00Go
_4>l00?o0000oi9]T_nBKI802?nBKI800ol0003oWF:MoieRW@08oieRW@03o`000?mTVfCoI9]T00[o
I9]T00?o0000ohUfROn9MXT02on9MXT00ol0003o[e2_ojm@[`0>ojm@[`03o`000?ngB;Oo]dRg00ko
]dRg1Ol00002oi9]TP03o`000?nDJiCoU6^D00WoU6^D00?o0000oj9MX_nRGJ802?nRGJ83o`0000Wo
QWV60_l0000:okI9]P03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oG:=OoebSG00SoebSG00?o0000oka3_?nl@k`01onl@k`00ol0003oTVfBoi9]TP07oi9]TP03o`00
0?nMHYgoWF:M00SoWF:M00?o0000ofBKI?mTVf@02_mTVf@00ol0003oRGJ9ohUfR@0:ohUfR@;o0000
3_n_D:l3o`0000go]dRg0ol00005okY5^P;o00002onDJi@00ol0003oXUfRoj9MXP0;oj9MXP;o0000
2_n6NHH2o`0000Oo]TVf0ol00009on4Nh@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooX5n_oj1O[onPGj3?l0000:oka3_003o`00
0?nBKI;oTVfB00OoTVfB00?o0000oieRWOnMHYd02?nMHYd>o`0000WoRGJ90ol000000om[U6_o0000
ojm@[`0:ojm@[`?o00000_nm@[d00ol0003o]dRgokM8]`09okM8]`;o00002OnjAKX00ol0003oU6^D
oiA[U009oiA[U003o`000?nRGJ;oXUfR00_oXUfR00?o0000ojiA[_l000002on6NHH2o`0000Co]TVf
00Co0000omPWf?oH9mSof2OH0_l00007on4Nh@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooX5n_l000002ooj1OX00ol0003o_4>l
oka3_009oka3_003o`000?nBKI;oTVfB00KoTVfB00?o0000oieRWOnMHYd02?nMHYd00ol0003oLhac
og><L`0:og><L`03o`000?n9MXWoRGJ900CoRGJ90ol00005of^DJ`03o`000?n_D:oo[e2_00Co[e2_
1?l00006oke2_@03o`000?ngB;Oo]dRg00Ko]dRg0_l0000;okY5^P03o`000?nDJiCoU6^D00WoU6^D
00?o0000oj9MX_nRGJ802_nRGJ801Ol0003o[U6^ojiA[_n^DJko000000coQWV60_l000000onfBKKo
0000omPWf005omPWf003o`000?oQ7^7ohAkQ00?ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?nl@kco_4>l00So_4>l00?o0000oi9]T_nBKI801_nBKI800ol0003oWF:MoieRW@07oieRW@03o`00
0?mcS7?oLhac00_oLhac00?o0000ohUfROn9MXT00_n9MXT2o`0000WoJiA[00?o0000ojm@[on_D:l0
0ol0000;oke2_@03o`000?ngB;Oo]dRg00;o]dRg0ol0000>okY5^P03o`000?nDJiCoU6^D00OoU6^D
00?o0000oj9MX_nRGJ802onRGJ800ol0003o[U6^ojiA[P02ojiA[P03o`000?n6NHKoQWV600_oQWV6
00?o0000omPWf?oH9mP01_oH9mP2o`0000?ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?nl
@kco_4>l00Oo_4>l00?o0000oi9]T_nBKI801onBKI800ol0003oWF:MoieRW@05oieRW@?o00003Omc
S7<4o`0000_oJiA[0ol0000?oke2_@04o`000?ngB;Oo0000o`00017o^TFj00?o0000oiA[U?nDJi@0
1onDJi@00ol0003oXUfRoj9MXP0:oj9MXP03o`000?n^DJko[U6^00Co[U6^00?o0000ohIiQ_n6NHH0
1on6NHH3o`0000_of2OH1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oka3_?nl@k`02?nl@k`00ol0003oTVfBoi9]
TP06oi9]TP03o`000?nMHYgoWF:M00;oWF:M0ol00003ohebS@03o`000?mcS7?oLhac00[oLhac00?o
0000of^DJom[U6/02om[U6/00ol0003oMhQgo`00000Aoke2_@03o`000?njAK[o^TFj017o^TFj00?o
0000oiA[U?nDJi@01onDJi@00ol0003oXUfRoj9MXP0:oj9MXP03o`000?n^DJko[U6^00Go[U6^00Co
0000ohIiQ_n6NHKoQWV61Ol00002oiMXU`03o`000?oH9mSof2OH00Wof2OH00Co0000ooX5n_oj1O[o
nPGj0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oka3_?nl@k`01onl@k`00ol0003oTVfBoi9]TP05oi9]TP?o0000
00?oWF:Mo`000?l000001on=LXd00ol0003oLhacog><L`08og><L`?o00002_m[U6/2o`0000;oMhQg
00?o0000oke2_Onm@[d03onm@[d00ol0003o^TFjokY5^P0AokY5^P03o`000?nDJiCoU6^D00OoU6^D
00?o0000oj9MX_nRGJ802OnRGJ800ol0003o[U6^ojiA[P07ojiA[P?o00001onGJ9L00ol0003of2OH
omPWf009omPWf003o`000?oj1O[onPGj00ConPGj0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oka3_?nl@k`01onl
@k`4o`0000;oTVfB0_l00003ojAKY003o`000?n=LXgoSG:=00SoSG:=0_l00006og><L`;o00000omj
QGX00ol0003oJiA[of^DJ`06of^DJ`03o`000?mgR7OoMhQg00?oMhQg00?o0000oke2_Onm@[d03_nm
@[d00ol0003o^TFjokY5^P0BokY5^P03o`000?nDJiCoU6^D00GoU6^D00?o0000oj9MX_nRGJ802OnR
GJ800ol0003o[U6^ojiA[P08ojiA[P03o`000?nGJ9OoUfRG00OoUfRG00?o0000omPWf?oH9mP02?oH
9mP00ol0003onPGjooX5nP07ooX5nP;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?nl@kco_4>l00Co_4>l0_l00004
om4^d@;o00001OnTFj@00ol0003oSG:=ohebS@0:ohebS@03o`000?mcS7?oLhac00;oLhac00?o0000
ogZ5N_mjQGX01?mjQGX00ol0003oJiA[of^DJ`04of^DJ`03o`000?mgR7OoMhQg00CoMhQg00?o0000
oke2_Onm@[d03_nm@[d00ol0003o^TFjokY5^P0BokY5^P[o00002_nRGJ800ol0003o[U6^ojiA[P08
ojiA[P03o`000?nGJ9OoUfRG00OoUfRG00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP09
ooX5nP?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_4>loka3_?nl@k`2o`0000OodBkA00?o0000ojAKY?nTFj@01?nTFj@0
0ol0003oSG:=ohebS@0:ohebS@04o`000?mcS7?o0000o`0000SoNXEj00Co0000of^DJom[U6_oJiA[
0_l00007ogN8M`03o`000?nm@[go_D:m00ko_D:m00?o0000okY5^_njAKX04_njAKX00ol0003oWf2O
oimPW`07oimPW`03o`000?nRGJ;oXUfR00KoXUfR00?o0000ojiA[_n^DJh02_n^DJh00ol0003oUfRG
oiMXU`06oiMXU`03o`000?oH9mSof2OH00Sof2OH00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?nl
@kco0000o`0000WodBkA00?o0000ojAKY?nTFj@01?nTFj@00ol0003oSG:=ohebS@0;ohebS@03o`00
0?mjQG[oNXEj00WoNXEj00?o0000of^DJol000002OmgR7L00ol0003o_D:moke2_@0>oke2_@;o0000
4_njAKX00ol0003oWf2OoimPW`09oimPW`;o00001_nRGJ800ol0003o[U6^ojiA[P0:ojiA[P03o`00
0?nGJ9OoUfRG00KoUfRG00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om4^dOoA;]402OoA;]400ol0003oY5^TojAKY005ojAKY003o`000?n=LXgoSG:=00[oSG:=00?o
0000ogZ5N_mjQGX02_mjQGX2o`0000WoMhQg00?o0000oke2_Onm@[d03_nm@[d00ol0003o[5>/o`00
0002o`0000oo^TFj00?o0000oimPWonOH9l02onOH9l00ol0003oXUfRoj9MXP03o`0000go[U6^00?o
0000oiMXUonGJ9L01_nGJ9L00ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odBkAom4^d@09om4^d@03o`000?nTFjCoY5^T00GoY5^T00?o0000ohebSOn=LXd02On=LXd2
o`0000_oNXEj0_l0000;ogN8M`03o`000?nm@[go_D:m00co_D:m00?o0000ojaC[?n/Dj`00on/Dj`3
o`0000co^TFj00?o0000oimPWonOH9l03?nOH9l2o`0000;oVVFJ00?o0000ojiA[_n^DJh03?n^DJh0
0ol0003oUfRGoiMXU`05oiMXU`03o`000?oH9mSof2OH00Oof2OH00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oA;]7odBkA00[odBkA00?o0000ojAKY?nTFj@01_nTFj@00ol0003oSG:=ohebS@07oheb
S@03o`000?mkQ7_o000000[oNXEj00Co0000ofNHIomWV6Oo00002_mgR7L00ol0003o_D:moke2_@0<
oke2_@03o`000?n/Djco[5>/00Ko[5>/0_l00008okY5^P;o00003onOH9l00ol0003oVVFJoiYUVP02
oiYUVP03o`000?n^DJko[U6^00_o[U6^00?o0000oiMXUonGJ9L01OnGJ9L00ol0003of2OHomPWf007
omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odBkAom4^d@0:om4^d@03o`000?nTFjCoY5^T
00KoY5^T00?o0000ohebSOn=LXd01_n=LXd01Ol0003oNhAkog^4NomkQ7_o000000SoNXEj00?o0000
ofNHIomWV6L00_mWV6L00ol0003oMhQgogN8M`06ogN8M`Co00003?nm@[d00ol0003o[5>/ojaC[008
ojaC[0?o00000_njAKX3o`000003oiaSW?l0003oWf2O00goWf2O00?o0000oiYUV_nJIIX01?nJIIX0
0ol0003o[U6^ojiA[P0:ojiA[P03o`000?nGJ9OoUfRG00GoUfRG00?o0000omPWf?oH9mP01_oH9mP0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]402ooA;]400ol0003oY5^TojAKY007ojAK
Y003o`000?n=LXgoSG:=00?oSG:=0_l00005og^4N`03o`000?mjQG[oNXEj00CoNXEj00?o0000ofNH
IomWV6L00omWV6L00ol0003oMhQgogN8M`05ogN8M`03o`000?nCK9?oTfbC00;oTfbC0ol00007oke2
_@;o00003_n/Dj`2o`0000GoW6>L00?o0000oimPWonOH9l02_nOH9l00ol0003oVVFJoiYUVP05oiYU
VP03o`000?n^DJko[U6^00_o[U6^00?o0000oiMXUonGJ9L01?nGJ9L00ol0003of2OHomPWf006omPW
f003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odBkAom4^d@0;om4^d@03o`000?nTFjCoY5^T00Oo
Y5^T00?o0000ohebSOn=LXd00_n=LXd00ol0003oNhAkog^4N`06og^4N`03o`000?mjQG[oNXEj00;o
NXEj00?o0000ofNHIomWV6L01OmWV6L00ol0003oMhQgogN8M`02ogN8M`;o00002?nCK9<3o`0000;o
_D:m0_l000000onKI9_o0000ojaC[00=ojaC[003o`000?nLHicoW6>L00GoW6>L00?o0000oimPWonO
H9l02?nOH9l00ol0003oVVFJoiYUVP07oiYUVP03o`000?n^DJko[U6^00[o[U6^00?o0000oiMXUonG
J9L01?nGJ9L00ol0003of2OHomPWf006omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkA
om4^d@0<om4^d@03o`000?nTFjCoY5^T00SoY5^T00Co0000ohebSOn=LXgo00002OmkQ7/01Ol0003o
NXEjogZ5N_mjQG[o000000SoIiQW00Go0000ogN8MomgR7OoMhQgo`00000=oi=/T`;o00001?nKI9/0
0ol0003o[5>/ojaC[00;ojaC[003o`000?nLHicoW6>L00KoW6>L00?o0000oimPWonOH9l01onOH9l0
0ol0003oVVFJoiYUVP08oiYUVPCo00002?n^DJh00ol0003oUfRGoiMXU`04oiMXU`03o`000?oH9mSo
f2OH00Kof2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00_odBkA0ol00009ojAK
Y003o`000?n=LXgo000000_oNhAk00?o0000ogZ5N_l000002_mWV6L00ol0003oMhQgo`00000?oi=/
T`03o`000?nKI9_oVfBK00;oVfBK00?o0000ojaC[?n/Dj`02on/Dj`00ol0003oW6>LoiaSW006oiaS
W003o`000?nOH9ooWf2O00KoWf2O00?o0000oiYUV_nJIIX02OnJIIX01?l0003o[5>/ojaC[?n/Dj`7
o`0000;o[U6^00?o0000oiMXUonGJ9L00onGJ9L00ol0003of2OHomPWf005omPWf003o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oA;]7odBkA00SodBkA0ol00003okY5^P03o`000?nTFjCoY5^T00OoY5^T00?o0000og^4
NomkQ7/02omkQ7/00ol0003oIiQWofNHI`0:ofNHI`03o`000?nCK9?oTfbC00goTfbC00?o0000oi]T
VonKI9/01?nKI9/00ol0003o[5>/ojaC[009ojaC[003o`000?nLHicoW6>L00SoW6>L00?o0000oimP
WonOH9l00onOH9l2o`0000coVVFJ00?o0000ojaC[?n/Dj`02?n/Dj`<o`0000?of2OH0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om4^dOoA;]401_oA;]43o`0000Oo^TFj00?o0000ojAKY?nTFj@01_nTFj@00ol0003o
NhAkog^4N`0;og^4N`03o`000?mWV6OoIiQW00WoIiQW0_l0000>oi=/T`03o`000?nKI9_oVfBK00Go
VfBK00?o0000ojaC[?n/Dj`02On/Dj`00ol0003oW6>LoiaSW009oiaSW003o`000?nOH9oo000000;o
00000_nBKI800ol0003oVVFJoiYUVP08oiYUVP03o`000?n/Djco[5>/00co[5>/00?o0000om`Sg?oL
8m`01_oL8m`3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odBkAom4^d@03om4^d@?o00002onjAKX00ol0003oY5^T
ojAKY004ojAKY003o`000?mkQ7_oNhAk00_oNhAk0ol00007ofNHI`?o000000?oR7N8o`000?nCK9<0
3OnCK9<00ol0003oVfBKoi]TV`06oi]TV`03o`000?n/Djco[5>/00So[5>/00?o0000oiaSW?nLHi`0
2_nLHi`00ol0003oTVfBoi9]TP04oi9]TP03o`000?nJII[oVVFJ00OoVVFJ00?o0000ojaC[?n/Dj`0
2on/Dj`00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om4^dOl0
003o0000o`0000oo^TFj00?o0000ojAKY?nTFj@00onTFj@>o`0000?oNhAk0_l00002ofNHI`?o0000
1On8MhP00ol0003oTfbCoi=/T`0:oi=/T`03o`000?nKI9_oVfBK00OoVfBK00?o0000ojaC[?n/Dj`0
2?n/Dj`00ol0003oW6>LoiaSW00:oiaSW003o`000?nBKI;oTVfB00GoTVfB00?o0000oiYUV_nJIIX0
1_nJIIX00ol0003o[5>/ojaC[00;ojaC[003o`000?oL8mcog2?L00Sog2?L00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o^TFj00?o0000ojAKY?nTFj@00_nTFj@00ol0003oJYEZofZE
JP0:ofZEJP03o`000?mkQ7_oNhAk00?oNhAk0_l00009ohQgR003o`000?nCK9?oTfbC00WoTfbC00?o
0000oi]TVonKI9/02?nKI9/2o`0000So[5>/00?o0000oiaSW?nLHi`02OnLHi`00ol0003oTVfBoi9]
TP07oi9]TP03o`000?nJII[oVVFJ00CoVVFJ00?o0000ojaC[?n/Dj`02on/Dj`00ol0003og2?Lom`S
g009om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o^TFjokY5^P0?okY5^P?o000000?oY5^T
o`000?mZUFX02omZUFX00ol0003oNhAkog^4N`04og^4N`03o`000?n8MhSoR7N800WoR7N800?o0000
oi=/TonCK9<01onCK9<00ol0003oVfBKoi]TV`09oi]TV`04o`000?nFJIKo0000o`0000Ko[5>/00?o
0000oiaSW?nLHi`02OnLHi`00ol0003oTVfBoi9]TP08oi9]TP03o`000?nJII[oVVFJ00?oVVFJ00?o
0000ojaC[?n/Dj`02on/Dj`00ol0003og2?Lom`Sg009om`Sg003o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o^TFjokY5^P0<okY5^P;o00000onaC[42o`0000coJYEZ00?o0000og^4NomkQ7/01?mkQ7/0
0ol0003oR7N8ohQgR00:ohQgR0Wo00002onKI9/00ol0003oUVVFoiIYUP02oiIYUP?o00000_n/Dj`0
0ol0003oW6>LoiaSW00:oiaSW003o`000?nBKI;oTVfB00WoTVfB00?o0000oiYUV_nJIIX00_nJIIX0
0ol0003o[5>/ojaC[00:ojaC[003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_njAKX2o`0000Go/Dja00?o0000oi=/Tol000002_mZUFX00ol0003oNhAkog^4N`06og^4
N`03o`000?n8MhSoR7N800WoR7N800?o0000ohUfROn9MXT01On9MXT00ol0003oVfBKoi]TV`09oi]T
V`03o`000?nFJIKoUVVF00GoUVVF0ol00009oiaSW0?o00003OnBKI801Ol0003oVVFJoiYUV_nJII[o
000000co[5>/00?o0000om`Sg?oL8m`02OoL8m`00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000okY5
^_njAKX01OnjAKX2o`0000Oo/Dja00Co0000oi=/TonCK9?o00002OmZUFX00ol0003oNhAkog^4N`06
og^4N`03o`000?n8MhSoR7N800SoR7N800?o0000ohUfROn9MXT01on9MXT00ol0003oVfBKoi]TV`07
oi]TV`03o`000?nFJIKoUVVF00SoUVVF0ol00002oiaSW0Go00000_m]TVd00ol0003oTVfBoi9]TP0<
oi9]TP03o`000?nJII[o000000co[5>/00?o0000om`Sg?oL8m`02_oL8m`00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000okY5^_njAKX00_njAKX2o`0000So/Dja00?o0000oi=/TonCK9<00_nCK9<5o`00
00CoJYEZ00?o0000og^4NomkQ7/01_mkQ7/00ol0003oR7N8ohQgR008ohQgR003o`000?n9MXWoRGJ9
00OoRGJ900?o0000oi]TVonKI9/01onKI9/00ol0003oUVVFoiIYUP08oiIYUP03o`000?m_T6ooKi1_
00;o00002?m]TVd00ol0003oTVfBoi9]TP0<oi9]TPCo00002_n/Dj`00ol0003og2?Lom`Sg00:om`S
g003o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o^TFjo`000?l0000:ok5>/@03o`000?nCK9?oTfbC
00;oTfbC00?o0000od:m@_m2_D800_m2_D84o`0000WoNhAk00?o0000ohQgR?n8MhP02?n8MhP00ol0
003oRGJ9ohUfR@08ohUfR@03o`000?nKI9_oVfBK00GoVfBK00?o0000oiIYU_nFJIH02?nFJIH01Ol0
003oKi1_ofn@Kom_T6oo000000[oKI9]0ol0000;oi9]TP04o`000?o9=/WobCK9olTfb@Co00001On/
Dj`00ol0003og2?Lom`Sg00;om`Sg003o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o/Djaok5>/@0:
ok5>/@03o`000?nCK9?oTfbC00?oTfbC00?o0000od:m@_m2_D801?m2_D800ol0003oNhAkog^4N`07
og^4N`03o`000?n8MhSoR7N800KoR7N80_l0000;ohUfR@03o`000?nKI9_oVfBK00GoVfBK00?o0000
oiIYU_nFJIH02?nFJIH00ol0003oKi1_ofn@K`02ofn@K`03o`000?m]TVgoKI9]00OoKI9]00?o0000
oiEZUOnEJYD01?l00006oi9]TP03o`000?o9=/WobCK900KobCK90ol00002ojaC[003o`000?oL8mco
g2?L00_og2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?naC[7o/Dja00Wo/Dja00?o0000oi=/
TonCK9<01?nCK9<00ol0003o@[e2od:m@P05od:m@P03o`000?mkQ7_oNhAk00OoNhAk00?o0000ohQg
R?n8MhP00_n8MhP3o`000003oi9]T_l0003oRGJ900[oRGJ900?o0000oi]TVonKI9/01OnKI9/00ol0
003oUVVFoiIYUP07oiIYUP03o`000?m_T6ooKi1_00?oKi1_00?o0000offBKOm]TVd01om]TVd00ol0
003oUFZEoiEZU@04oiEZU@?o00000_nBKI800ol0003obCK9olTfb@0:olTfb@;o00003_oL8m`00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok5>/OnaC[402OnaC[400ol0003oTfbCoi=/T`04oi=/T`03
o`000?m2_D;o@[e200Ko@[e20_l00007og^4N`03o`000?n8MhSo000000;o00001OnBKI800ol0003o
RGJ9ohUfR@08ohUfR@?o00001?nKI9/00ol0003oUVVFoiIYUP08oiIYUP03o`000?m_T6ooKi1_00Co
Ki1_00?o0000offBKOm]TVd01_m]TVd00ol0003oUFZEoiEZU@07oiEZU@;o00003_o9=/T00ol0003o
g2?Lom`Sg00;om`Sg003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djaok5>/@08ok5>/@03o`00
0?nCK9?oTfbC00GoTfbC00?o0000od:m@_m2_D801?m2_D800ol0003oN8MhogR7N003o`0000CoNhAk
0_l00008oi9]TP03o`000?n9MXWoRGJ900OoRGJ900Co0000ojm@[on_D:oo[e2_0ol000000onKI9_o
0000oiIYUP09oiIYUP03o`000?m_T6ooKi1_00CoKi1_00?o0000offBKOm]TVd01Om]TVd00ol0003o
UFZEoiEZU@09oiEZU@03o`000?o9=/WobCK900gobCK900?o0000om`Sg?oL8m`02_oL8m`00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok5>/OnaC[401onaC[400ol0003oTfbCoi=/T`06oi=/T`03o`00
0?m2_D;o@[e200?o@[e200?o0000ogR7N?mhQgP01?mhQgP2o`000003og^4Nol0003oTVfB00[oTVfB
00?o0000ohUfROn9MXT01On9MXT00ol0003o[e2_ojm@[`05ojm@[`03o`000?nFJIKoUVVF00OoUVVF
0ol00007ofn@K`03o`000?m]TVgoKI9]00CoKI9]00?o0000oiEZUOnEJYD02OnEJYD00ol0003obCK9
olTfb@0=olTfb@03o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?na
C[7o/Dja00Go/Dja0ol00009oi=/T`05o`000?m2_D;o@[e2od:m@_l000002OmhQgP00ol0003oTVfB
oi9]TP0;oi9]TP03o`000?n9MXWoRGJ900?oRGJ900?o0000ojm@[on_D:l01_n_D:l00ol0003oUVVF
oiIYUP06oiIYUP05o`000?nHIiSoV6NHoiQWV?l000001om_T6l00ol0003oKI9]offBK@03offBK@03
o`000?nEJYGoUFZE00WoUFZE00?o0000olTfbOo9=/T03_o9=/T00ol0003og2?Lom`Sg009om`Sg003
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djao`000004o`0000;occ3?00?o0000oi=/TonCK9<0
1onCK9<01?l0003o@[e2od:m@_l00009ogR7N0;o00003OnBKI800ol0003oRGJ9ohUfR@02ohUfR@03
o`000?n_D:oo[e2_00So[e2_00?o0000oiIYU_nFJIH00onFJIH2o`0000GoV6NH00?o0000ofn@Kom_
T6l01?m_T6l00ol0003oKI9]offBK@03offBK@03o`000?nEJYGoUFZE00WoUFZE00?o0000olTfbOo9
=/T03_o9=/T00ol0003og2?Lom`Sg009om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Socc3?
00?o0000oi=/TonCK9<01_nCK9<00ol0003o@[e2o`000009ogR7N004o`000?nOH9ooWf2Oo`0000go
TVfB00Co0000ohUfROn9MXWo00003?n_D:l01Ol0003oUVVFoiIYU_nFJIKo000000SoV6NH0_l00005
ofn@K`03o`000?m]TVgoKI9]00;oKI9]00?o0000oiEZUOnEJYD02OnEJYD00ol0003obCK9olTfb@0>
olTfb@03o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?
00Oocc3?00?o0000oi=/TonCK9<01onCK9<00ol0003oN8MhogR7N007ogR7N003o`000?nOH9ooWf2O
00;oWf2O00?o0000oi9]T_nBKI802_nBKI800ol0003oRGJ9o`00000>ojm@[`03o`000?nFJIKo0000
00_oV6NH00?o0000ofn@Kom_T6l00_m_T6l01Ol0003oKI9]offBKOm]TVgo000000coUFZE00?o0000
olTfbOo9=/T03_o9=/T3o`0000Wog2?L00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000oi=/TonCK9<01_nCK9<00ol0003oN8MhogR7N006ogR7N003o`000?nOH9ooWf2O
00?oWf2O00?o0000oi9]T_nBKI802onBKI800ol0003o[e2_ojm@[`0>ojm@[`03o`000?nHIiSoV6NH
00_oV6NH0_l00003ofn@K`04o`000?m]TVgoKI9]o`0000[oUFZE0ol0000>olTfb@;o00000ooj1OX2
o`0000Oog2?L00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?00[occ3?00?o0000oi=/
TonCK9<01?nCK9<00ol0003oN8MhogR7N006ogR7N003o`000?nOH9ooWf2O00GoWf2O00?o0000oi9]
T_nBKI801onBKI83o`00017o[e2_00?o0000oiQWV?nHIiP03OnHIiP01Ol0003oKi1_ofn@Kol0003o
KI9]00Co00000onEJYD5o`0000;o_D:m00?o0000olTfbOo9=/T02_o9=/T2o`0000OonPGj0_l00004
om`Sg003o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003occ3?oll`c`0;oll`c`03o`000?nCK9?oTfbC
00CoTfbC00?o0000ogR7N?mhQgP01OmhQgP00ol0003oWf2OoimPW`06oimPW`03o`000?nBKI;oTVfB
00CoTVfB0ol00002oieRW@03o`000?n_D:oo[e2_00oo[e2_0_l0000?oiQWV004o`000?m_T6oo0000
o`0000CoSG:=0ol00008oke2_@03o`000?o9=/WobCK900OobCK90_l0000;ooX5nP;o00000_oL8m`0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000oll`coo?<<l03?o?<<l6o`0000OoN8Mh00?o0000oimP
WonOH9l02?nOH9l00ol0003oTVfBoi9]TP03o`0000KoWF:M00?o0000ojm@[on_D:l03On_D:l01?l0
003oZ5NXojQGZ?l0000?oiQWV003o`000?n=LXgoSG:=00GoSG:=00?o0000oke2_Onm@[d02?nm@[d0
0ol0003obCK9olTfb@05olTfb@03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o?<<l00ol0003oU6^DoiA[U004oiA[
U003o`000?mhQgSoN8Mh00?oN8Mh00?o0000oimPWonOH9l02_nOH9l2o`0000[oWF:M00?o0000ojm@
[on_D:l02on_D:l00ol0003oZ5NXojQGZ002ojQGZ003o`000?nHIiSoV6NH00_oV6NH0_l00007oheb
S@03o`000?nm@[go_D:m00Wo_D:m00?o0000olTfbOo9=/T00_o9=/T2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000oll`coo?<<l02oo?<<l00ol0003oU6^DoiA[U006oiA[U005o`000?mhQgSoN8MhogR7
N?l000003OnOH9l00ol0003oWF:MoieRW@0:oieRW@03o`000?n_D:oo[e2_00Wo[e2_00?o0000ojQG
Z?nXEjP01?nXEjP00ol0003oV6NHoiQWV008oiQWV0;o000000?oLXebo`000?n=LXd01on=LXd00ol0
003o_D:moke2_@09oke2_@04o`000?o9=/Wo0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000oiA[U?nDJi@02?nDJi@00ol0003oN8Mho`00000=oimPW`03o`000?nMHYgoWF:M
00_oWF:M00?o0000ojm@[on_D:l02?n_D:l00ol0003oZ5NXojQGZ006ojQGZ003o`000?nHIiSoV6NH
00GoV6NH0_l00003og:=LP03o`000?n=LXgoSG:=00KoSG:=00?o0000oke2_Onm@[d02_nm@[d00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003occ3?oll`c`07oll`c`03o`000?nDJiCoU6^D00[oU6^D00?o0000oimPWonO
H9l03?nOH9l00ol0003oWF:MoieRW@0<oieRW@03o`000?n_D:oo[e2_00Ko[e2_00?o0000ojQGZ?nX
EjP02?nXEjP00ol0003oV6NHoiQWV002oiQWV0;o00001_mbSG800ol0003oSG:=ohebS@05ohebS@03
o`000?nm@[go_D:m00[o_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?00Gocc3?
00?o0000oiA[U?nDJi@03?nDJi@2o`0000coWf2O00?o0000oieRWOnMHYd03OnMHYd00ol0003o[e2_
ojm@[`04ojm@[`03o`000?nXEjSoZ5NX00[oZ5NX00Co0000oiQWV?l0003o00002?mbSG800ol0003o
SG:=ohebS@06ohebS@03o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_o?<<l00ol0003oU6^DoiA[U00=oiA[U003o`000?nDJiCo000000;o00002?nOH9l00ol0003oWF:M
oieRW@0?oieRW@Ko00003_nXEjP00ol0003oLXebog:=LP08og:=LP03o`000?n=LXgoSG:=00KoSG:=
00?o0000oke2_Onm@[d02Onm@[d00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000ol/dboo;=<_obcC;
0_l0000?oiA[U003o`000?nDJiCoU6^D00?oU6^D0ol00005oimPW`;o00004?nMHYd01_l0003oSG:=
ohebSOl0003oNHIio`0000koZ5NX00?o0000og:=L_mbSG802OmbSG800ol0003oSG:=ohebS@05oheb
S@03o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000ol/dboo;=</00oo;=</00ol0003o
U6^DoiA[U00=oiA[U003o`000?nDJiCoU6^D00KoU6^D0ol000001?nOH9oo0000oi=/TonCK9<3o`00
00coWF:M00Go0000ohebSOn=LXgoSG:=o`000002ogV6N@03o`000?nXEjSoZ5NX00_oZ5NX00?o0000
og:=L_mbSG802OmbSG800ol0003oSG:=ohebS@06ohebS@03o`000?nm@[go_D:m00So_D:m0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003obcC;ol/db`04ol/db`oo00003?nDJi@00ol0003oTfbCoi=/T`04oi=/
T`?o00002?nMHYd00ol0003oSG:=ohebS@02ohebS@05o`000?miQWWoNHIiogV6NOl000003?nXEjP0
0ol0003oLXebog:=LP09og:=LP03o`000?n=LXgoSG:=00GoSG:=3?l00002omdRg@;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003obcC;ol/db`05ol/db`03o`000?mnPGkoOX5n00_oOX5n00?o0000oiA[
U?nDJi@02_nDJi@00ol0003oTfbCoi=/T`07oi=/T`;o00001OnMHYd00ol0003oSG:=ohebS@03oheb
S@03o`000?miQWWoNHIi00;oNHIi00?o0000ojQGZ?nXEjP02OnXEjP00ol0003oLXebog:=LP0:og:=
LP03o`000?n=LXgoSG:=00?oSG:=00?o0000ohMhQon7N8L02On7N8L00ol0003ogB;MomdRg@02omdR
g@;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003obcC;ol/db`06ol/db`03o`000?mnPGkoOX5n00[o
OX5n00?o0000oiA[U?nDJi@02onDJi@00ol0003oTfbCoi=/T`09oi=/T`?o000000?oWF:Mo`000?n=
LXd01On=LXd00ol0003oNHIiogV6N@03ogV6N@03o`000?nXEjSoZ5NX00SoZ5NX3_l00003ohebS@;o
00002on7N8L00ol0003ogB;MomdRg@05omdRg@03o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000ol/dboo;=</01Oo;=</00ol0003oSg2?o`00000;ogj1OP03o`000?nDJiCoU6^D00[oU6^D
0_l0000>oi=/T`03o`000?n=LXgoSG:=00GoSG:=00?o0000ogV6NOmiQWT00omiQWT00ol0003oZ5NX
ojQGZ008ojQGZ003o`000?nFJIKoUVVF00_oUVVF00?o0000ohebSOl000003On7N8L00ol0003ogB;M
omdRg@06omdRg@;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00KobcC;00Co
0000ohm`Son?L8oo00002_mnPGh00ol0003oU6^DoiA[U009oiA[U003o`000?n@Ki3o000000koTfbC
00?o0000ohebSOn=LXd01On=LXd00ol0003oNHIiogV6N@04ogV6N@03o`000?nXEjSoZ5NX00KoZ5NX
00?o0000oiIYU_nFJIH03OnFJIH00ol0003oQgR7ohMhQ`0<ohMhQ`03o`000?oM8]gogB;M00SogB;M
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000ohm`Son?L8l00_n?
L8l00ol0003oOX5nogj1OP06ogj1OP03o`000?nDJiCoU6^D00SoU6^D0_l00003oi1_T003o`000?nC
K9?oTfbC00_oTfbC00?o0000ohebSOn=LXd01On=LXd00ol0003oNHIiogV6N@05ogV6N@03o`000?nX
EjSoZ5NX00GoZ5NX00?o0000oiIYU_nFJIH03OnFJIH00ol0003oQgR7ohMhQ`0;ohMhQ`03o`000?oM
8]gogB;M00WogB;M00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000
ohm`Son?L8l00on?L8l00ol0003oOX5nogj1OP05ogj1OP03o`000?nDJiCoU6^D00OoU6^D00?o0000
oi1_T?n@Ki000on@Ki000ol0003oTfbCoi=/T`0:oi=/T`03o`000?n=LXgoSG:=00KoSG:=00?o0000
ogV6NOmiQWT01_miQWT00ol0003oZ5NXojQGZ004ojQGZ003o`000?nFJIKoUVVF00goUVVF3ol0000;
omdRg@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000ohm`Son?L8l01On?L8l00ol0
003oOX5nogj1OP04ogj1OP03o`000?nDJiCoU6^D00GoU6^D0_l00006oi1_T003o`000?nCK9?oTfbC
00WoTfbC0_l00008ohebS@03o`000?miQWWoNHIi00KoNHIi1Ol000000onXEjSo0000oiIYUP0?oiIY
UP03o`000?n1OX7oPGj100_oPGj100?o0000omdRgOoM8]d02OoM8]d00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o;=<_obcC;00KobcC;00?o0000ohm`Son?L8l01_n?L8l00ol0003o
OX5nogj1OP04o`0000KoU6^D00?o0000oi1_T?n@Ki001on@Ki000ol0003oTfbCoi=/T`05oi=/T`?o
000000?oPWf2o`000?n=LXd01on=LXd00ol0003oNHIiogV6N@05ogV6N@03o`000?nYEZWoZEJY00?o
ZEJY0_l0000?oiIYUP;o00003On1OX400ol0003ogB;MomdRg@08omdRg@03o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WobcC;00?o0000ohm`Son?L8l01on?L8l2o`0000Co/4n`00Co0000oiA[U?nDJiCo
U6^D0_l0000:oi1_T003o`000?nCK9?oTfbC00;oTfbC0ol00005oh9mPP03o`000?n=LXgoSG:=00Go
SG:=00?o0000ogV6NOmiQWT01?miQWT00ol0003oZEJYojUFZ@06ojUFZ@03o`000?nFJIKoUVVF00[o
UVVF0_l00002oiIYUP03o`000?n1OX7oPGj100[oPGj100?o0000omdRgOoM8]d02?oM8]d00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000ol/dboo;=</01_o;=</00ol0003oSg2?ohm`S`08ohm`S`03o`00
0?n`Ck3o/4n`00Co/4n`00?o0000oiA[U?l000003?n@Ki000ol0003oTfbCo`000002o`0000WoPWf2
00?o0000ohebSOn=LXd01?n=LXd00ol0003oNHIiogV6N@03ogV6N@03o`000?nYEZWoZEJY00SoZEJY
1_l00004oiIYUP;o00001OnFJIH00ol0003oPGj1oh5nP@09oh5nP@03o`000?oM8]gogB;M00SogB;M
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o;=<_obcC;00GobcC;00?o0000ohm`Son?L8l01on?
L8l00ol0003o/4n`ok1?/006ok1?/003o`000?n@Ki3oT6n@00coT6n@00?o0000oh9mP_n2OH802_n2
OH800ol0003oSG:=ohebS@04ohebS@04o`000?miQWWoNHIiogV6N@;o00002onYEZT00ol0003oXUfR
oj9MXP03oj9MXPCo00002?nFJIH00ol0003oPGj1oh5nP@08oh5nP@03o`000?oM8]gogB;M00OogB;M
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000ol/dboo;=</00oo;=</00ol0003oSg2?ohm`S`07ohm`S`03o`000?n`
Ck3o/4n`00Oo/4n`00?o0000oi1_T?n@Ki003?n@Ki000ol0003oPWf2oh9mPP0;oh9mPP03o`000?n=
LXgoSG:=00?oSG:=00Co0000ogV6NOmiQWWo00003OnYEZT00ol0003oXUfRoj9MXP06oj9MXP03o`00
0?nFJIKoUVVF00OoUVVF00?o0000oh5nPOn1OX401on1OX400ol0003ogB;MomdRg@06omdRg@04o`00
0?ok1?_on`Ckoo/4n`;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o;=<_obcC;00;obcC;00?o0000ohm`Son?L8l0
1_n?L8l00ol0003o/4n`ok1?/009ok1?/003o`000?n@Ki3oT6n@00WoT6n@0_l0000>oh9mPP?o0000
0on=LXd00ol0003oNHIio`00000=ojUFZ@03o`000?nRGJ;oXUfR00OoXUfR00?o0000oiIYU_nFJIH0
2?nFJIH:o`0000KogB;M0_l00006oo/4n`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoSg2?00?o
0000ok1?/?n`Ck002_n`Ck000ol0003oT6n@oi1_T006oi1_T0;o000000?oT6n@o`000?n2OH802on2
OH82o`0000?oZUFZ1Ol0000>ojUFZ@03o`000?nRGJ;oXUfR00OoXUfR00?o0000oiIYU_nFJIH02?nF
JIH00ol0003oWV6NoiiQWP06oiiQWP03o`000?oM8]gogB;M00?ogB;M00?o0000oo/4nook1?/01ook
1?/2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oacS7olLha`03olLha`Co00000_n?L8l00ol0003o/4n`ok1?/00;
ok1?/003o`000?n@Ki3oT6n@00?oT6n@0ol00004oi1_T003o`000?n2OH;oPWf200OoPWf20_l00008
ojYEZP03o`000?nYEZWoZEJY00goZEJY00?o0000oj9MX_nRGJ802?nRGJ800ol0003oUVVFoiIYUP07
oiIYUP03o`000?nNHIkoWV6N00OoWV6N0ol000000ooM8]go0000oo/4n`0;oo/4n`;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o7><OoacS700OoacS70_l0000?ok1?/003o`000?n@Ki3oT6n@00;o00002?n@Ki000ol0
003oPWf2oh9mPP05oh9mPP03o`000?nZEJ[oZUFZ00SoZUFZ00?o0000ojUFZOnYEZT03OnYEZT00ol0
003oXUfRoj9MXP08oj9MXP03o`000?nFJIKoUVVF00KoUVVF00?o0000oiiQW_nNHIh02?nNHIh01?l0
003og2?Lom`Sg?l0000?oo/4n`03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oacS7olLha`09olLh
a`03o`000?n`Ck3o/4n`00ko/4n`0_l0000;oi1_T003o`000?n2OH;oPWf200;oPWf20_l0000;ojYE
ZP03o`000?nYEZWoZEJY00goZEJY00?o0000oj9MX_nRGJ802?nRGJ800ol0003oUVVFoiIYUP06oiIY
UP03o`000?nNHIkoWV6N00OoWV6N00Go0000om`Sg?oL8mcog2?Lo`00000@oo/4n`;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oacS7olLha`0:olLha`03o`000?n`Ck3o/4n`00go/4n`0_l0000<oi1_T004o`000?n2OH;o0000
o`0000goZUFZ00?o0000ojUFZOnYEZT03?nYEZT00ol0003oXUfRoj9MXP09oj9MXP03o`000?nFJIKo
UVVF00KoUVVF00?o0000oiiQW_nNHIh01_nNHIh00ol0003og2?Lom`Sg003om`Sg003o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oacS7olLha`0:olLha`03o`000?n`Ck3o/4n`00co/4n`00Co0000ofBK
I?mTVfCo00003?n@Ki000ol0003oZUFZojYEZP0>ojYEZP03o`000?nYEZWoZEJY00SoZEJY1?l0000;
oj9MXP03o`000?nFJIKoUVVF00KoUVVF00?o0000oiiQW_nNHIh01OnNHIh00ol0003og2?Lom`Sg004
om`Sg003o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oacS7olLha`0;olLha`03o`000?n`Ck3o/4n`
00_o/4n`00?o0000ofBKI?mTVf@00_mTVf@00ol0003oT6n@oi1_T009oi1_T003o`000?nZEJ[oZUFZ
00koZUFZ00Co0000ojUFZOnYEZWoZEJY1ol00003ojaC[003o`000?nRGJ;oXUfR00WoXUfR00?o0000
oiIYU_nFJIH01_nFJIH00ol0003oWV6NoiiQWP04oiiQWP03o`000?oL8mcog2?L00Kog2?L00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o7><OoacS700coacS700?o0000ok1?/?n`Ck002_n`Ck000ol0
003oI9]TofBKI003ofBKI003o`000?n@Ki3oT6n@00SoT6n@00?o0000ojYEZ_nZEJX03_nZEJX4o`00
00_o[5>/00?o0000oj9MX_nRGJ802?nRGJ800ol0003oUVVFoiIYUP05oiIYUP03o`000?nNHIkoWV6N
00GoWV6N00?o0000om`Sg?oL8m`01_oL8m`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olLhaoo7
><L03?o7><L7o`0000Go/4n`00?o0000ofBKI?mTVf@01OmTVf@00ol0003oT6n@oi1_T007oi1_T003
o`000?nZEJ[oZUFZ00koZUFZ00?o0000ojaC[?n/Dj`03On/Dj`00ol0003oXUfRoj9MXP08oj9MXP03
o`000?nFJIKoUVVF00CoUVVF00?o0000oiiQW_nNHIh01?nNHIh00ol0003og2?Lom`Sg007om`Sg003
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oacS7olLha`0=olLha`03o`000?naC[7o/Dja00Co/Dja
1Ol00009ofBKI003o`000?n@Ki3oT6n@00KoT6n@00?o0000ojYEZ_nZEJX03_nZEJX00ol0003o[5>/
ojaC[00=ojaC[003o`000?nRGJ;oXUfR00SoXUfR00Co0000oiIYU_nFJIKoUVVF1Ol00004oiiQWP03
o`000?oL8mcog2?L00Wog2?L1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olLha`03o`000?naC[7o/Dja00Wo/Dja
0_l00009ofBKI003o`000?n@Ki3oT6n@00KoT6n@00?o0000ojYEZ_nZEJX03?nZEJX00ol0003o[5>/
ojaC[00?ojaC[0Ko00001?nRGJ84o`0000Go^dBk0_l000000onNHIko0000om`Sg00;om`Sg004o`00
0?oj1O[onPGjooX5nPOo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oF:MKoeRWFomHYeP?o00002_o7><L00ol0003o
/Djaok5>/@09ok5>/@03o`000?mcS7?o000000;o00001omTVf@00ol0003oT6n@oi1_T005oi1_T003
o`000?nZEJ[oZUFZ00SoZUFZ1Ol0000AojaC[003o`000?nUFZGoYEZU00?oYEZU1?l0000;ok]4^`03
o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX02Ooj1OX3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omHYe_oF:MH01OoF:MH2o`0000OoacS7
00?o0000ok5>/OnaC[402_naC[400ol0003oLhacog><L`02og><L`?o00001OmTVf@00ol0003oT6n@
oi1_T004oi1_T004o`000?nZEJ[oZUFZojYEZPOo00001?nGJ9L00ol0003o[5>/ojaC[00>ojaC[003
o`000?nUFZGoYEZU00OoYEZU00?o0000ok]4^onkA;/02OnkA;/00ol0003og2?Lom`Sg009om`Sg003
o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oeRWFomHYeP08omHYeP;o00001?o7><L00ol0003o/Dja
ok5>/@0;ok5>/@03o`000?mcS7?oLhac00GoLhac0ol00003ofBKI004o`000?n@Ki3oT6n@oi1_T0Ko
00003?nGJ9L00ol0003o[5>/ojaC[00=ojaC[003o`000?nUFZGoYEZU00OoYEZU00?o0000ok]4^onk
A;/02_nkA;/00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omHYeP?o000000?oacS7o`000?naC[40
3?naC[400ol0003oLhacog><L`08og><L`?o000000CoI9]To`000?l0003o00000_n]DZd00ol0003o
UfRGoiMXU`0=oiMXU`03o`000?n/Djco[5>/00co[5>/00?o0000ojEJYOnUFZD02?nUFZD00ol0003o
^dBkok]4^`0;ok]4^`03o`000?oL8mcog2?L00Kog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
eRWF00?o0000ok5>/OnaC[403?naC[400ol0003oLhacog><L`0;og><L`03o`000?n]DZgo[E:]00?o
[E:]00?o0000oiMXUonGJ9L03?nGJ9L00ol0003oOgmoo`00000=ojaC[003o`000?nUFZGoYEZU00So
YEZU00?o0000ok]4^onkA;/03?nkA;/3o`0000Gog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oF:MKoeRWF00coeRWF00?o0000ok5>/OnaC[403?naC[400ol0003oLhacog><L`0:og><L`03o`00
0?n]DZgo[E:]00Go[E:]00?o0000oiMXUonGJ9L02_nGJ9L01?l0003oOgmoogmoOomoOgl2o`0000[o
[5>/00?o0000ojEJYOnUFZD02OnUFZD00ol0003o^dBkok]4^`0<ok]4^`03o`000?oR7N;ohQgR00?o
000000?og2?Lo`000?oj1OX03ooj1OX00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oF:MKoeRWF00_oeRWF00?o0000ok5>/OnaC[40
3?naC[400ol0003oLhacog><L`09og><L`03o`000?n]DZgo[E:]00Ko[E:]00?o0000oiMXUonGJ9L0
2OnGJ9L00ol0003oOgmoogmoO`02ogmoO`03o`000?nZEJ[o000000;o00001on/Dj`00ol0003oYEZU
ojEJY@09ojEJY@03o`000?nkA;_o^dBk00_o^dBk00?o0000on8Mh_oR7N801?oR7N800ol0003onPGj
ooX5nP0?ooX5nP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omHYe_oF:MH02ooF:MH00ol0003o/Djaok5>/@0;ok5>/@03o`000?mc
S7?oLhac00SoLhac00?o0000ojeB[On]DZd01on]DZd00ol0003oUfRGoiMXU`08oiMXU`03o`000?mo
OgooOgmo00?oOgmo00?o0000ojYEZ_nZEJX00_nZEJX2o`0000Co[5>/00?o0000ojEJYOnUFZD02_nU
FZD00ol0003o^dBkok]4^`0:ok]4^`03o`000?oR7N;ohQgR00GohQgR00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oF:MKoeRWF00[oeRWF0ol0000;ok5>/@Ko00001?mcS7<00ol0003o[E:]ojeB[@08
ojeB[@03o`000?nGJ9OoUfRG00OoUfRG00?o0000ogmoOomoOgl00omoOgl00ol0003oZUFZojYEZP05
ojYEZP?o000000?o[5>/o`000?nUFZD02onUFZD00ol0003o^dBkok]4^`09ok]4^`03o`000?oR7N;o
hQgR00OohQgR00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oF:MKoeRWF00WoeRWF00?o0000oj9M
X_nRGJ801?l00006ok5>/@03o`000?nXEjSoZ5NX00CoZ5NX1?l0000<ojeB[@03o`000?nGJ9OoUfRG
00GoUfRG00?o0000ogmoOomoOgl01?moOgl00ol0003oZUFZojYEZP08ojYEZP03o`000?nUFZGoYEZU
00_oYEZU00?o0000ok]4^onkA;/02?nkA;/00ol0003ohQgRon8MhP08on8MhPGo00002_oj1OX00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oF:MKoeRWF00OoeRWF00?o0000oj9MX_nRGJ801OnRGJ83o`0000;o/Dja00?o0000ojQGZ?nX
EjP02?nXEjP00ol0003o[E:]ojeB[@0:ojeB[@03o`000?nGJ9OoUfRG00CoUfRG00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oZUFZojYEZP08ojYEZP03o`000?nUFZGoYEZU00WoYEZU1?l00008ok]4^`03
o`000?oR7N;ohQgR00WohQgR00?o0000oo/4nook1?/00_ok1?/7o`0000?onPGj00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeRWF
omHYeP05omHYeP03o`000?nRGJ;oXUfR00WoXUfR0_l0000<ojQGZ003o`000?n]DZgo[E:]00Wo[E:]
00?o0000oiMXUonGJ9L00onGJ9L00ol0003oOgmoogmoO`05ogmoO`03o`000?nZEJ[oZUFZ00[oZUFZ
00?o0000ojEJYOnUFZD01?nUFZD4o`0000Co/Tfb00?o0000ok]4^onkA;/01?nkA;/00ol0003ohQgR
on8MhP0:on8MhP03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oF:MKoeRWF00?oeRWF00?o0000oj9MX_nRGJ802onR
GJ800ol0003oZ5NXojQGZ00:ojQGZ003o`000?n]DZgo[E:]00Wo[E:]00?o0000oiMXUonGJ9L00_nG
J9L00ol0003oOgmoogmoO`06ogmoO`03o`000?nZEJ[oZUFZ00[oZUFZ00?o0000ojEJYOnUFZD01?l0
0009ok9=/PKo00003?oR7N800ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omHYe_oF:MKoeRWF0_l0
000=oj9MXP03o`000?nXEjSoZ5NX00[oZ5NX00?o0000ojeB[On]DZd02On]DZd01Ol0003oUfRGoiMX
UonGJ9Oo000000WoOgmo00?o0000ojYEZ_nZEJX02onZEJX2o`0000go/Tfb00?o0000omXUf_oJ9MX0
0_oJ9MX00ol0003ohQgRon8MhP0:on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oeRWFo`00
0002omDZe@;o00002onRGJ800ol0003oZ5NXojQGZ00;ojQGZ003o`000?n]DZgo[E:]00Wo[E:]00?o
0000oiMXUol000002OmoOgl00ol0003oZUFZojYEZP0<ojYEZP03o`000?nbCK;o/Tfb00co/Tfb00?o
0000omXUf_oJ9MX00ooJ9MX00ol0003ohQgRon8MhP09on8MhP03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003oeB[EomDZe@03omDZe@;o00002_nRGJ800ol0003oZ5NXojQGZ00:ojQGZ003o`000?n]DZgo
[E:]00So[E:]1Ol00008ogmoO`03o`000?nZEJ[oZUFZ00coZUFZ00?o0000ok9=/_nbCK802onbCK80
0ol0003ofRGJomXUfP05omXUfP03o`000?oR7N;ohQgR00SohQgR00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooE:]D2o`0000SoXUfR00?o0000ojQGZ?nXEjP02_nXEjP00ol0003o[E:]ojeB[@07ojeB
[@03o`000?nLHicoW6>L00?oW6>L0ol00005ogmoO`03o`000?nZEJ[oZUFZ00_oZUFZ00?o0000ok9=
/_nbCK803?nbCK800ol0003ofRGJomXUfP06omXUfP03o`000?oR7N;ohQgR00OohQgR00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oj1O[o000000WoeB[E00?o0000oj9MX_nRGJ801OnRGJ82o`0000co
Z5NX00?o0000ojeB[On]DZd01On]DZd00ol0003oW6>LoiaSW007oiaSW0?o000000?oOgmoo`000?nZ
EJX03OnZEJX00ol0003o/Tfbok9=/P0<ok9=/P03o`000?oJ9M[ofRGJ00KofRGJ00?o0000on8Mh_oR
7N801_oR7N800ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003ooX5nP03o`000?oE:]GoeB[E00OoeB[E
0_l00004oj9MXP03o`000?nXEjSoZ5NX00;o00002_nXEjP00ol0003o[E:]ojeB[@03ojeB[@;o0000
3OnLHi`2o`0000goZUFZ0ol0000=ok9=/P03o`000?oJ9M[ofRGJ00OofRGJ00?o0000on8Mh_oR7N80
1OoR7N800ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003onPGjooX5nP04ooX5nP03o`000?oE:]GoeB[E00SoeB[E0_l0
00000onRGJ;o0000ojQGZ004ojQGZ003o`000?nXEjSoZ5NX00OoZ5NX00Co0000ojeB[On]DZgo[E:]
0_l00002oieRW@03o`000?nLHicoW6>L00coW6>L3Ol00003oi1_T003o`000?nbCK;o/Tfb00[o/Tfb
00?o0000omXUf_oJ9MX02?oJ9MX01?l0003ohQgRon8Mh_oR7N84o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?oj1OX00ol0003oeB[E
omDZe@09omDZe@03o`000?nXEjSoZ5NX00GoZ5NX0_l00008ojQGZ003o`000?n]DZgo000000GoWF:M
00?o0000oiaSW?nLHi`02onLHi`00ol0003oVVFJoiYUVP09oiYUVP03o`000?n@Ki3oT6n@00;oT6n@
0_l00009ok9=/P03o`000?oJ9M[ofRGJ00[ofRGJ0ol00004ooX5nP03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000ooX5
nP0:ooX5nP03o`000?oE:]GoeB[E00SoeB[E00?o0000ojQGZ?nXEjP01onXEjP4o`0000?oZ5NX0ol0
0007oieRW@03o`000?nLHicoW6>L00[oW6>L00?o0000oiYUV_nJIIX02OnJIIX00ol0003oT6n@oi1_
T004oi1_T0;o00001onbCK800ol0003ofRGJomXUfP0:omXUfP03o`000?oj1O[onPGj00GonPGj00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003onPGjooX5nP0:ooX5nP03o`000?oE:]GoeB[E00OoeB[E00?o0000ojQGZ?nXEjP02?nXEjP0
1?l0003oZeB[oj]DZon[E:/3o`0000;oXebS00?o0000oieRWOnMHYd01_nMHYd00ol0003oW6>LoiaS
W008oiaSW003o`000?nJII[oVVFJ00[oVVFJ00?o0000oi1_T?n@Ki001_n@Ki000ol0003o/Tfbok9=
/P04ok9=/P03o`000?oJ9M[ofRGJ00WofRGJ00?o0000ooX5n_oj1OX01ooj1OX00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[o
nPGj00_onPGj00?o0000omDZeOoE:]D01OoE:]D00ol0003oZ5NXojQGZ008ojQGZ003o`000?n[E:_o
ZeB[00CoZeB[00Go0000oj=LXonSG:?oXebSo`000008oieRW@03o`000?nLHicoW6>L00OoW6>L00?o
0000oiYUV_nJIIX02_nJIIX00ol0003oT6n@oi1_T007oi1_T0;o00001?nbCK800ol0003ofRGJomXU
fP08omXUfP03o`000?oj1O[onPGj00WonPGj00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oj1O[onPGj00conPGj00?o0000omDZeOoE:]D00ooE:]D0
0ol0003oZ5NXojQGZ008ojQGZ003o`000?n[E:_oZeB[00CoZeB[00?o0000oj=LXonSG:<00_nSG:<0
0ol0003oWF:MoieRW@07oieRW@03o`000?nLHicoW6>L00KoW6>L00?o0000oiYUV_nJIIX02_nJIIX0
0ol0003oT6n@oi1_T009oi1_T005o`000?nbCK;o/Tfbok9=/_l000002OoJ9MX00ol0003onPGjooX5
nP0;ooX5nP03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooX5n_oj1OX03Ooj1OX5o`0000_oZ5NX00?o0000oj]DZon[E:/01?n[E:/00ol0003oXebSoj=LX`03
oj=LX`03o`000?nMHYgoWF:M00OoWF:M00?o0000oiaSW?nLHi`01OnLHi`00ol0003oVVFJoiYUVP0:
oiYUVP03o`000?n@Ki3oT6n@00WoT6n@1?l00009omXUfP03o`000?oj1O[onPGj00gonPGj0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003onPGjooX5nP0<ooX5nP05o`000?oR7N;ohQgR
on8Mh_l000002_nXEjP00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?nSG:?oXebS00?oXebS00?o0000
oieRWOnMHYd02?nMHYd00ol0003oW6>LoiaSW004oiaSW003o`000?nJII[oVVFJ00WoVVFJ00?o0000
oi1_T?n@Ki002?n@Ki02o`0000?oebSG00?o0000omXUf_oJ9MX01_oJ9MX00ol0003onPGjooX5nP0>
ooX5nP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oj1O[onPGj
00_onPGj00?o0000on8Mh_oR7N800ooR7N800ol0003oZ5NXojQGZ006ojQGZ003o`000?n[E:_oZeB[
00GoZeB[00?o0000oj=LXonSG:<01?nSG:<00ol0003oWF:MoieRW@09oieRW@03o`000?nLHicoW6>L
00;oW6>L00?o0000oiYUV_nJIIX02_nJIIX00ol0003oT6n@oi1_T006oi1_T0;o00001_oG:=L8o`00
017onPGj00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ohQgRon8MhP05on8MhP03o`000?nXEjSoZ5NX00GoZ5NX00?o0000oj]DZon[
E:/01On[E:/00ol0003oXebSoj=LX`05oj=LX`03o`000?nMHYgoWF:M00WoWF:M00Go0000oiaSW?nL
HicoW6>Lo`00000<oiYUVP03o`000?n@Ki3oT6n@00CoT6n@0_l00008omLXe`03o`000?oj1O[onPGj
00ConPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003onPGjooX5nP09ooX5nP03o`000?oR7N;ohQgR00OohQgR00?o0000ojQGZ?nX
EjP00onXEjP00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?nSG:?oXebS00GoXebS00?o0000oieRWOnM
HYd02_nMHYd00ol0003oW6>Lo`000004o`0000WoVVFJ00?o0000oi1_T?n@Ki000_n@Ki02o`0000[o
ebSG00?o0000ooX5n_oj1OX01Ooj1OX00ol0003onPGjooX5nP0<ooX5nP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ohQgRon8MhP07on8MhP03o`00
0?nXEjSoZ5NX00;oZ5NX00?o0000oj]DZon[E:/01_n[E:/00ol0003oXebSoj=LX`07oj=LX`;o0000
2onMHYd00ol0003o[E:]ojeB[@03ojeB[@Oo00000_nJIIX00ol0003oT6n@oi1_T002o`0000_oebSG
00?o0000ooX5n_oj1OX01ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oj1O[onPGj00KonPGj00?o0000on8Mh_oR7N802OoR
7N801Ol0003oZ5NXojQGZ?nXEjSo000000SoZeB[00?o0000oj=LXonSG:<01onSG:<00ol0003obSG:
o`000002o`0000SoWF:M00?o0000ojeB[On]DZd02_n]DZd5o`0000goebSG00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oj1O[onPGj00?onPGj0ol0000<on8MhP03o`000?nXEjSo000000WoZeB[00?o
0000oj=LXonSG:<01_nSG:<00ol0003obSG:olXebP03olXebP?o00001?nMHYd00ol0003o[E:]ojeB
[@0=ojeB[@03o`000?oG:=OoebSG00goebSG00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5
nP06ooX5nP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oj1O[o
000000;o00000ook1?/2o`0000_ohQgR00?o0000oj]DZon[E:/01on[E:/00ol0003oXebSoj=LX`07
oj=LX`03o`000?o:=L[obSG:00KobSG:0ol000000onMHYgo0000ojeB[@0>ojeB[@03o`000?oG:=Oo
ebSG00coebSG00?o0000ooX5n_oj1OX02_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009on8M
hP03o`000?n[E:_oZeB[00;oZeB[1_l00008oj=LX`03o`000?o:=L[obSG:00[obSG:00?o0000ojeB
[On]DZd03on]DZd00ol0003oebSGomLXe`0:omLXe`;o00003Ooj1OX00ol0003onPGjooX5nP03ooX5
nP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007on8MhPGo00001_oR7N800ol0003oXebSoj=LX`05oj=LX`03o`000?o:=L[obSG:00[o
bSG:00?o0000ojeB[On]DZd03on]DZd00ol0003oebSGomLXe`07omLXe`?o000000?onPGjo`000?oj
1OX03Ooj1OX01Ol0003onPGjooX5n_oj1O[o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005on8MhP03o`000?oR7N;ohQgR00WohQgR00?o0000oj=LXonS
G:<00onSG:<00ol0003obSG:olXebP0;olXebP03o`000?n]DZgo[E:]00oo[E:]00?o0000omLXeooG
:=L01OoG:=L2o`0000GonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?ohQgRo`000?l00000
3OoR7N800ol0003oXebSoj=LX`02oj=LX`03o`000?o:=L[obSG:00_obSG:5?l00004omLXe`;o0000
2?oj1OX00ol0003onPGjooX5nP0;ooX5nP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003on`Cko`00000>on8MhP04o`000?nSG:?oXebSo`0000kobSG:
00?o0000onDJiOoU6^D04?oU6^D00ol0003oebSGo`000002o`0000[onPGj00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000003_oR7N800ol0003oXebSo`00000>olXebP03o`00
0?oU6^GoiA[U017oiA[U00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00_ok1?/00ol0003ohQgRon8MhP0=on8MhP03o`000?o:=L[obSG:00WobSG:1Ol0
000BonDJi@;o00003ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/01?ok1?/0
0ol0003ohQgRon8MhP0<on8MhP03o`000?o:=L[obSG:00;obSG:1ol00004ooX5nP03o`000?oU6^Go
iA[U00ooiA[U00?o0000ooX5n_l000004?oj1OX00ol0003onPGjooX5nP03ooX5nP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oR7N;ohQgR00cohQgR1?l0000<ooX5nP03o`000?oU6^GoiA[U00coiA[U0_l00003ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000ooX5n_oj1OX00_oj1OX00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on8Mh_oR7N803?oR7N800ol0003onPGjooX5nP0=ooX5nP03o`000?oU6^GoiA[U00_o
iA[U00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5nP04o`000?oj1O[onPGjo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/02Ook1?/00ol0003ohQgRon8MhP0:on8MhP03o`000?oj1O[onPGj00konPGj00?o0000onDJiOoU
6^D02OoU6^D2o`0000OonPGj00?o0000ooX5n_oj1OX03Ooj1OX3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP0?ooX5nP03o`000?oU6^GoiA[U00KoiA[U0_l0000:ooX5nP03o`000?oj1O[onPGj00_onPGj
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003on`Ck00gon`Ck3?l0
000AooX5nP?o00001_oU6^D00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00WonPGj0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003onPGjooX5nP0>ooX5nP05o`000?oj1O[onPGjooX5n_l000000ooU6^D2o`0000konPGj00?o
0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0=ooX5nP03o`000?oj1O[o
nPGj00?onPGj00?o0000onDJiOl000004Ooj1OX00ol0003onPGjooX5nP04ooX5nP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oj1O[onPGj00[onPGj00?o0000ooX5
n_oj1OX02ooj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj013onPGj00?o0000ooX5
n_oj1OX00ooj1OX00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00Ko
nPGj00?o0000ooX5n_oj1OX04Ooj1OX5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?oj1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP08ooX5nP03o`00
0?oj1O[onPGj013onPGj00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5
nP07ooX5nP;o00002ooj1OX00ol0003onPGjooX5nP0?ooX5nP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[o
nPGj00GonPGj00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0=ooX5
nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooj1OX00ol0003o
nPGjooX5nP03ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000ooX5n_oj1OX02ooj1OX2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003onPGjooX5nP09ooX5nP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003onPGjooX5nP0>ooX5nP04o`000?oj1O[onPGjo`0001?onPGj
1Ol00004ooX5nP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0<ooX5nPCo00004ooj1OX2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oj1OX3o`0000;o003o0_l0000B
ooX5nP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooX5nP?o00001ol00?l2o`0000konPGj0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_onPGj00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003onPGj
ooX5nP07ooX5nP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooX5nPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01ol00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0007o`00o`;oool01?l00?l2oooo00Go003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Ko003o0_ooo`1]o`00o`7ooooo001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04
o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`001_l00?l2
oooo00Ko003o0_ooo`03o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1]o`00o`7ooooo001ao`00
o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00
o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`001_l00?l2oooo
00Ko003o0_ooo`03o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0KOl00?l1oooo
o`00LOl00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo00?o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00
LOl00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool01_l00?l2oooo00Go003o0oooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001`o`00o`;oool00_l00?l01?ooo`3o003oo`00
ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool0
1ol00?l2oooo00?o003o0oooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`08o`00o`03oooo
0?l00?oo003o00?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l0
0?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool02Ol00?l4oooo00Go003o
0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006oo003o0_ooo`04o`00o`03oooo0?l0
0?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l4oooo00Ko003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06go003o0Oooool006oo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00Oo003o0oooo`02
o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo
00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`?oool01?l00?l2oooo
00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06go003o0Oooool006ko003o0oooo`05o`00o`?o
ool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo00Ko003o0_ooo`02o`00o`;o
ool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00ol00?l2oooo00Co003o
0_ooo`07o`00o`;oool0KOl00?l1ooooo`00K_l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o0_ooo`000olb</co003oo`00o`03o`00o`;oool01_l00?l2oooo00?o003o0_oo
o`04o`00o`;oool01_l00?l00olb</coool0oooo001]o`00o`7ooooo001]o`00o`?oool01Ol00?l3
oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Co003o0_ooo`04o`00o`;oool01Ol00?l2
oooo00;o003o0_ooo`05o`00o`Goool0KOl00?l1ooooo`00K?l00?l6oooo0003o`00ooooo`3oool0
00Goool00ol00?l5oooo027o003o1Oooo`07o`00o`Coool0N?l00?l1ooooo`00ool00?l/o`00o`7o
oooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.9063 0 ]
[.5 1.04444 43.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(90) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
138.875 23.000 moveto
(D) show
146.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.981 .019 .981 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.981 .019 .981 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.981 .019 .981 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.981 .019 .981 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.86 .14 .86 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.98 .02 .98 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.852 .148 .852 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.892 .108 .892 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.842 .158 .842 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.978 .022 .978 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.774 .226 .774 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.981 .019 .981 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.73 .27 .73 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.693 .307 .693 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.982 .018 .982 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.685 .315 .685 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.736 .264 .736 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.978 .022 .978 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.979 .021 .979 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.98 .02 .98 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.837 .163 .837 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.606 .394 .606 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.503 .497 .503 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.519 .481 .519 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.514 .486 .514 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.561 .439 .561 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.817 .183 .817 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.84 .16 .84 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.982 .018 .982 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.55 .45 .55 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.728 .272 .728 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.5 .5 .5 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.8 .2 .8 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.776 .224 .776 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.981 .019 .981 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.714 .286 .714 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.693 .307 .693 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.732 .268 .732 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.81 .19 .81 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.541 .459 .541 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.983 .017 .983 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.871 .129 .871 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.619 .381 .619 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.617 .383 .617 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.579 .421 .579 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.843 .157 .843 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.888 .112 .888 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.629 .371 .629 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.981 .019 .981 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.557 .443 .557 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.469 .531 .469 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.7 .3 .7 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.722 .278 .722 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.512 .488 .512 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.55 .45 .55 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.671 .329 .671 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.981 .019 .981 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.708 .292 .708 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.662 .338 .662 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.855 .145 .855 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.216 .784 .216 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.662 .338 .662 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.704 .296 .704 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.701 .299 .701 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.437 .563 .437 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.38 .62 .38 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.344 .656 .344 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.404 .596 .404 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.658 .342 .658 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.428 .572 .428 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.542 .458 .542 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.671 .329 .671 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.618 .382 .618 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.642 .358 .642 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.633 .367 .633 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.886 .114 .886 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.981 .019 .981 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.436 .564 .436 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.522 .478 .522 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.411 .589 .411 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.98 .02 .98 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.712 .288 .712 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.585 .415 .585 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.347 .653 .347 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.433 .567 .433 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.649 .351 .649 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.523 .477 .523 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.849 .151 .849 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.612 .388 .612 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.356 .644 .356 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.626 .374 .626 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.545 .455 .545 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.492 .508 .492 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.646 .354 .646 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.822 .178 .822 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.656 .344 .656 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.372 .628 .372 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.489 .511 .489 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.653 .347 .653 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.531 .469 .531 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.536 .464 .536 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.795 .205 .795 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.516 .484 .516 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.463 .537 .463 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.417 .583 .417 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.98 .02 .98 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.429 .571 .429 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.576 .424 .576 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.463 .537 .463 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.592 .408 .592 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.631 .369 .631 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.98 .02 .98 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.659 .341 .659 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.592 .408 .592 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.613 .387 .613 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.651 .349 .651 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.536 .464 .536 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.492 .508 .492 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.553 .447 .553 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.578 .422 .578 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.981 .019 .981 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.754 .246 .754 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.62 .38 .62 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.712 .288 .712 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.455 .545 .455 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.835 .165 .835 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.331 .669 .331 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.511 .489 .511 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.507 .493 .507 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.652 .348 .652 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.74 .26 .74 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.425 .575 .425 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.98 .02 .98 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.569 .431 .569 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.672 .328 .672 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.899 .101 .899 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.633 .367 .633 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.572 .428 .572 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.608 .392 .608 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.83 .17 .83 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.437 .563 .437 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.556 .444 .556 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.628 .372 .628 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.801 .199 .801 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.429 .571 .429 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.548 .452 .548 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.622 .378 .622 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.638 .362 .638 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.981 .019 .981 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.486 .514 .486 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.98 .02 .98 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.864 .136 .864 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.686 .314 .686 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.639 .361 .639 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.527 .473 .527 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.547 .453 .547 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.557 .443 .557 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.848 .152 .848 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.672 .328 .672 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.695 .305 .695 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.697 .303 .697 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.615 .385 .615 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.817 .183 .817 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.601 .399 .601 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.528 .472 .528 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.387 .613 .387 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.401 .599 .401 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.552 .448 .552 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.684 .316 .684 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.981 .019 .981 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.857 .143 .857 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.572 .428 .572 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.384 .616 .384 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.655 .345 .655 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.759 .241 .759 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.557 .443 .557 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.98 .02 .98 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.518 .482 .518 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.724 .276 .724 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.858 .142 .858 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.981 .019 .981 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.54 .46 .54 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.585 .415 .585 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.857 .143 .857 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.618 .382 .618 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.554 .446 .554 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.828 .172 .828 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.537 .463 .537 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.726 .274 .726 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.739 .261 .739 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.519 .481 .519 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.494 .506 .494 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.619 .381 .619 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.598 .402 .598 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.89 .11 .89 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.713 .287 .713 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.7 .3 .7 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.662 .338 .662 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.981 .019 .981 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.805 .195 .805 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.567 .433 .567 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.98 .02 .98 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.865 .135 .865 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.777 .223 .777 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.87 .13 .87 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.607 .393 .607 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.86 .14 .86 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.72 .28 .72 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.647 .353 .647 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.981 .019 .981 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.66 .34 .66 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.648 .352 .648 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.981 .019 .981 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.819 .181 .819 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.978 .022 .978 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.982 .018 .982 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.769 .231 .769 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.98 .02 .98 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.633 .367 .633 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.98 .02 .98 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.5 .5 .5 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.707 .293 .707 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.572 .428 .572 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.859 .141 .859 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.86 .14 .86 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.71 .29 .71 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.753 .247 .753 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.715 .285 .715 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.799 .201 .799 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.846 .154 .846 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.757 .243 .757 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.76 .24 .76 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.979 .021 .979 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.655 .345 .655 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.842 .158 .842 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.98 .02 .98 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.884 .116 .884 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.886 .114 .886 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.65 .35 .65 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.869 .131 .869 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.869 .131 .869 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.591 .409 .591 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.98 .02 .98 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.978 .022 .978 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.982 .018 .982 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.851 .149 .851 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.981 .019 .981 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.981 .019 .981 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.98 .02 .98 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.981 .019 .981 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.98 .02 .98 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.98 .02 .98 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003onPGjooX5nP05ooX5nPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooj1OX3o`000003o`00ool0003onPGj00konPGj00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oj1O[onPGj00gonPGj00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oj1O[onPGj013onPGj0ol00005ooX5nP03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003onPGjooX5nP0?ooX5nP03
o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oj1O[onPGj013onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGj
ooX5nP07ooX5nP03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?onPGj0_l0000@ooX5nP03o`000?oj1O[onPGj00OonPGj00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooX5nP?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?oj1O[onPGjooX5n_l000004Ooj
1OX01?l0003ofbCKom/Tfol0000>ooX5nP03o`000?oj1O[onPGj00WonPGj00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooX5nP?o000000?o003oo`000?oj1OX03ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?oj
1O[onPGj00gonPGj00?o0000om/TfooK9=/00_oK9=/00ol0003onPGjooX5nP0;ooX5nP03o`000?oj
1O[onPGj00WonPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooX5nP03o`000?oj1O[onPGj00konPGj00?o0000
ooX5n_oj1OX01?oj1OX00ol0003onPGjooX5nP0<ooX5nP03o`000?oK9=_ofbCK00?ofbCK00?o0000
ooX5n_oj1OX02Ooj1OX00ol0003onPGjooX5nP0:ooX5nP03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oj1O[onPGj
00konPGj00?o0000ooX5n_oj1OX03_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj
00[onPGj00?o0000om/TfooK9=/01OoK9=/00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj
00_onPGj00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003onPGjooX5nP0>ooX5nP03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ofbCKom/Tf`06om/Tf`03
o`000?oj1O[onPGj00KonPGj00?o0000ooX5n_oj1OX03?oj1OX00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003onPGj
ooX5nP0>ooX5nP;o00004?oj1OX00ol0003onPGjooX5nP07ooX5nP03o`000?oj1O[onPGj00OonPGj
00?o0000om/TfooK9=/02?oK9=/00ol0003onPGjooX5nP05ooX5nP03o`000?oj1O[onPGj00conPGj
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oI9]Wo0000013onPGj00?o0000ooX5n_oj1OX02?oj
1OX9o`0000cofbCK00Co0000ooX5n_oj1O[onPGj0ol0000@ooX5nP03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oj1O[onPGj00conPGj0_l00003omTVf@03o`000?oj
1O[onPGj00conPGj00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ogB;MomdRg@05omdRg@03o`000?oK
9=_ofbCK00_ofbCK0ol00003om/Tf`03o`000?oj1O[onPGj00conPGj0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000konPGj00?o0000
omTVfOoI9]T00ooI9]T00ol0003onPGjooX5nP0;ooX5nP;o00002ooj1OX00ol0003ogB;MomdRg@06
omdRg@03o`000?oK9=_ofbCK00[ofbCK00?o0000om/TfooK9=/01?oK9=/00ol0003onPGjooX5nP0:
ooX5nP04o`000?oL8mcog2?Lom`Sg0;o00002_oj1OX2o`000003om`Sg?l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000ooX5n_oj1OX02ooj1OX00ol0003ofBKIomTVf@05omTVf@03o`000?oj1O[o
nPGj00WonPGj00?o0000omDZeOl000002ooj1OX00ol0003ogB;MomdRg@06omdRg@03o`000?oK9=_o
fbCK00WofbCK00?o0000om/TfooK9=/01_oK9=/00ol0003onPGjooX5nP08ooX5nP03o`000?oL8mco
g2?L00Cog2?L0_l00005ooX5nP?o00001?oL8m`00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oj1O[onPGj00SonPGj0_l00008omTVf@03o`000?oj1O[onPGj00OonPGj0_l00003omDZ
e@03o`000?oj1O[onPGj00OonPGj00?o0000omdRgOoM8]d01ooM8]d00ol0003ofbCKom/Tf`09om/T
f`03o`000?oK9=_ofbCK00OofbCK00?o0000ooX5n_oj1OX01Ooj1OX2o`0000Wog2?L0_l000000ooj
1O[o0000o`000007om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000SonPGj00?o0000omTVfOoI
9]T02?oI9]T00ol0003onPGjooX5nP06ooX5nP03o`000?oE:]GoeB[E00?oeB[E00?o0000ooX5n_oj
1OX01ooj1OX00ol0003ogB;MomdRg@08omdRg@03o`000?oK9=_ofbCK00OofbCK00?o0000om/TfooK
9=/02OoK9=/00ol0003onPGjooX5nP03ooX5nP03o`000?oL8mcog2?L00_og2?L00?o0000om`Sg?oL
8m`01ooL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJo`000005ooX5nP;o00002ooI9]T2o`0000KonPGj
00?o0000omDZeOoE:]D01OoE:]D00ol0003onPGjooX5nP06ooX5nP03o`000?oM8]gogB;M00SogB;M
00?o0000om/TfooK9=/01_oK9=/00ol0003ofbCKom/Tf`0;om/Tf`05o`000?oj1O[onPGjooX5n_l0
00003_oL8m`00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oJ9M[ofRGJomXUf_l0
00000ooj1OX00ol0003ofBKIomTVf@0:omTVf@04o`000?oB;M;odRgBo`0000?onPGj0_l00008omDZ
e@03o`000?oj1O[onPGj00KonPGj00?o0000omdRgOoM8]d02OoM8]d00ol0003ofbCKom/Tf`05om/T
f`03o`000?oK9=_ofbCK00cofbCK00?o0000ooX5n_l000003ooL8m`00ol0003og2?Lom`Sg008om`S
g003o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJomXUfP03omXUfP03o`000?oj1O[o000000_o
fBKI0_l00004om8]dP03o`000?oj1O[o000000_oeB[E00?o0000ooX5n_oj1OX01Ooj1OX00ol0003o
gB;MomdRg@09omdRg@03o`000?oK9=_ofbCK00CofbCK00?o0000om/TfooK9=/03_oK9=/00ol0003o
g2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000omXUf_oJ9MX0
1?oJ9MX00ol0003ofBKIomTVf@09omTVf@03o`000?oB;M;odRgB00GodRgB00?o0000omDZeOoE:]D0
2_oE:]D00ol0003onPGjooX5nP05ooX5nP03o`000?oM8]gogB;M00[ogB;M00?o0000om/TfooK9=/0
0ooK9=/00ol0003ofbCKom/Tf`0>om/Tf`03o`000?oL8mcog2?L00gog2?L00?o0000om`Sg?oL8m`0
2_oL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJomXU
fP05omXUfP03o`000?oI9]WofBKI00OofBKI0_l00008om8]dP03o`000?oE:]GoeB[E00_oeB[E00?o
0000ooX5n_oj1OX01?oj1OX00ol0003ogB;MomdRg@0:omdRg@04o`000?oK9=_ofbCKom/Tf`?o0000
3ooK9=/00ol0003og2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oJ9M[ofRGJ00OofRGJ00?o0000omTVfOoI9]T01?oI9]T2o`0000_odRgB1?l0
0009omDZe@03o`000?oj1O[onPGj00?onPGj00?o0000omdRgOoM8]d02ooM8]d01?l0003ofbCKo`00
0?l00003ol8m`P;o00003?oK9=/2o`00013og2?L00?o0000om`Sg?oL8m`02ooL8m`00ol0003onPGj
ooX5nP0=ooX5nP04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003ofRGJ
omXUfP07omXUfP03o`000?oI9]WofBKI00?ofBKI00?o0000om8]d_oB;M802ooB;M801?l0003o`Ck1
ol4n`Oo1?/45o`0000GoeB[E00?o0000ooX5n_oj1OX00_oj1OX00ol0003ogB;MomdRg@0<omdRg@03
o`000?o2?L;o`Sg200Go`Sg20_l00008om/Tf`;o00000_nfBKH00ol0003og2?Lom`Sg00=om`Sg003
o`000?oL8mcog2?L00_og2?L00?o0000ooX5n_oj1OX03?oj1OX00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003ofRGJomXUfP09omXUfP03o`000?oI9]WofBKI00;o0000
3OoB;M800ol0003o`Ck1ol4n`@07ol4n`@Ko00000_oj1OX4o`0000gogB;M00?o0000ol8m`_o2?L80
1oo2?L82o`0000GofbCK00?o0000okI9]_nfBKH00onfBKH00ol0003og2?Lom`Sg00<om`Sg003o`00
0?oL8mcog2?L00cog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oJ9M[ofRGJ00WofRGJ00?o
0000omTVfOl000003ooB;M800ol0003o`Ck1ol4n`@0<ol4n`@?o00001?oD:m@3o`0000WogB;M00?o
0000ol8m`_o2?L802_o2?L82o`000003om/Tfol0003o000000Oo]TVf00?o0000om`Sg?oL8m`02ooL
8m`00ol0003og2?Lom`Sg00<om`Sg003o`000?oj1O[onPGj00KonPGj1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000
om8]d_oB;M803_oB;M800ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oD:mCoe2_D00Koe2_D0ol00005
omdRg@03o`000?o2?L;o`Sg200go`Sg200?o0000okI9]_nfBKH02?nfBKH00ol0003og2?Lom`Sg009
om`Sg003o`000?oL8mcog2?L00gog2?L00Co0000ooX5n_oj1O[onPGj1Ol00003on8MhP03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
omXUf_oJ9MX02ooJ9MX2o`0000oodRgB00?o0000ol4n`Oo1?/403Oo1?/400ol0003oe2_Dom@[e00:
om@[e0?o000000?ogB;Mo`000?o2?L803oo2?L800ol0003o]TVfokI9]P09okI9]P03o`000?oL8mco
g2?L00Sog2?L00?o0000om`Sg?oL8m`03_oL8m`3o`0000SohQgR00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oJ9M[ofRGJ00SofRGJ0ol000000ond
BkCo0000om8]dP0>om8]dP03o`000?o1?/7o`Ck100go`Ck100?o0000om@[e?oD:m@03OoD:m@00ol0
003o`Sg2ol8m`P0?ol8m`P03o`000?nfBKKo]TVf00[o]TVf2ol0000;om`Sg0Go00003?oR7N800ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02_ok1?/01Ol0003ogR7No`000?ok1?_o0000
00SofRGJ0ol00005okA;]003o`000?oB;M;odRgB00codRgB00?o0000ol4n`Oo1?/403Oo1?/400ol0
003oe2_Dom@[e00=om@[e0;o00004?o2?L800ol0003o]TVfokI9]P0:okI9]P03o`000?nhAkSo^4Nh
00Oo^4Nh00?o0000om`Sg?oL8m`00_oL8m`7o`0000Co]DZe00?o0000on8Mh_oR7N802_oR7N800ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02Ook1?/01?l0003ogR7NomhQg_oN8Mh2o`00
00GofRGJ0ol00009okA;]0;o00002ooB;M800ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oD:mCoe2_D
00goe2_D00Co0000om4^dOoA;]7o00003oo2?L800ol0003o]TVfokI9]P09okI9]P03o`000?nhAkSo
^4Nh00Wo^4Nh1?l0000;okE:]@03o`000?oR7N;ohQgR00[ohQgR00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?ok1?_on`Ck00Son`Ck00?o0000omhQg_oN8Mh01?oN8Mh00ol0003ofRGJo`000002o`00
00co]4^d00Co0000okI9]_l0003o00002OoB;M800ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oD:mCo
e2_D00goe2_D00Go0000om4^dOoA;]7odBkAo`00000=ol8m`P03o`000?nfBKKo]TVf00[o]TVf00?o
0000okQ7^?nhAkP02OnhAkP00ol0003o]DZeokE:]@0<okE:]@03o`000?oR7N;ohQgR00[ohQgR00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003o]4^dokA;]00<okA;]003o`000?nfBKKo]TVf00;o]TVf0_l00007om8]dP03o`000?o1?/7o
`Ck100co`Ck100?o0000om@[e?oD:m@03OoD:m@00ol0003odBkAom4^d@03om4^d@03o`000?o2?L;o
`Sg200[o`Sg200?o0000okI9]_nfBKH02_nfBKH00ol0003o^4NhokQ7^009okQ7^003o`000?neB[Go
]DZe00co]DZe00?o0000on8Mh_oR7N802ooR7N800ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4
nook1?/01_ok1?/00ol0003ogR7NomhQgP06omhQgP03o`000?ndBkCo]4^d00_o]4^d00?o0000okI9
]_nfBKH01OnfBKH00ol0003odRgBom8]dP03om8]dP03o`000?o1?/7o`Ck100go`Ck100?o0000om@[
e?oD:m@03OoD:m@00ol0003odBkAom4^d@04om4^d@03o`000?o2?L;o`Sg200Wo`Sg200?o0000okI9
]_nfBKH02OnfBKH00ol0003o^4NhokQ7^00:okQ7^003o`000?neB[Go]DZe00co]DZe00?o0000on8M
h_oR7N802ooR7N800ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook1?/01Ook1?/00ol0003o
gR7NomhQgP07omhQgP03o`000?ndBkCo]4^d00_o]4^d00?o0000okI9]_nfBKH01_nfBKH2o`0000?o
dRgB00?o0000ol4n`Oo1?/403Oo1?/400ol0003oe2_Dom@[e00<om@[e003o`000?oA;]7odBkA00Ko
dBkA00?o0000ol8m`_o2?L802?o2?L800ol0003o]TVfokI9]P09okI9]P03o`000?nhAkSo^4Nh00[o
^4Nh00?o0000okE:]OneB[D03?neB[D00ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?ok1?_on`Ck00Con`Ck00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o]4^dokA;]00:okA;]003o`00
0?nfBKKo]TVf00Wo]TVf0_l000000ooB;M;o0000ol4n`@0<ol4n`@?o00003_oD:m@00ol0003odBkA
om4^d@07om4^d@03o`000?o2?L;o`Sg200Oo`Sg200?o0000okI9]_nfBKH02OnfBKH00ol0003o^4Nh
okQ7^00;okQ7^003o`000?neB[Go]DZe00co]DZe00?o0000on8Mh_oR7N802_oR7N800ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000omhQg_oN8Mh02_oN8Mh00ol0003o]4^dokA;
]009okA;]003o`000?nfBKKo]TVf00_o]TVf00?o0000ol4n`Oo1?/402_o1?/42o`0000?o_D:m00?o
0000om@[e?oD:m@02_oD:m@00ol0003odBkAom4^d@09om4^d@03o`000?o2?L;o`Sg200Ko`Sg200?o
0000okI9]_nfBKH02?nfBKH00ol0003o^4NhokQ7^00<okQ7^003o`000?neB[Go]DZe00co]DZe00?o
0000on8Mh_oR7N802_oR7N800ol0003on`Ckoo/4n`04oo/4n`Co00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ook1?/0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000okA;]?ndBk@02?ndBk@0
0ol0003o]TVfokI9]P0<okI9]P03o`000?o1?/7o`Ck100So`Ck10_l00006oke2_@;o00002_oD:m@0
0ol0003odBkAom4^d@0:om4^d@03o`000?o2?L;o`Sg200Go`Sg200?o0000okI9]_nfBKH02?nfBKH0
0ol0003o^4NhokQ7^00<okQ7^003o`000?neB[Go]DZe00co]DZe00?o0000on8Mh_oR7N802ooR7N80
0ol0003on`Cko`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?on`Ck00Go0000oo/4nook1?_on`Cko`00000=
omhQgP03o`000?ndBkCo]4^d00Oo]4^d00?o0000okI9]_nfBKH03_nfBKH00ol0003o`Ck1ol4n`@04
ol4n`@?o00002_nm@[d00ol0003oe2_Dom@[e007om@[e003o`000?oA;]7odBkA00_odBkA00?o0000
ol8m`_o2?L800oo2?L800ol0003o]TVfokI9]P09okI9]P03o`000?nhAkSo^4Nh00co^4Nh00?o0000
okE:]OneB[D03?neB[D00ol0003ohQgRon8MhP0;on8MhP;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003ogR7NomhQgP0<omhQgP03o`000?ndBkCo]4^d00Oo]4^d00?o0000okI9]_nfBKH03onfBKH01?l0
003o`Ck1ol4n`Oo1?/42o`0000ko_D:m0_l00006om@[e003o`000?oA;]7odBkA00godBkA00?o0000
ol8m`_o2?L800_o2?L800ol0003o]TVfokI9]P08okI9]P03o`000?nhAkSo^4Nh00co^4Nh0ol0000=
okE:]@03o`000?oR7N;ohQgR00_ohQgR00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oogR7N00?o0000okA;]?ndBk@01_ndBk@00ol0003o]TVfokI9]P0@okI9]PCo00004_nm@[d00ol0
003oe2_Dom@[e003om@[e003o`000?oA;]7odBkA00kodBkA00Go0000ol8m`_o2?L;o`Sg2o`000005
okI9]POo00003?nhAkP01Ol0003oXUfRoj9MX_nRGJ;o000000co]DZe00?o0000on8Mh_oR7N802?oR
7N83o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oogR7N00?o0000okA;]?ndBk@01_ndBk@00ol0003o]TVfokI9]P0=
okI9]P?o000000CoYUVVo`000?l0003o00004onm@[d2o`0000;oe2_D00?o0000om4^dOoA;]404?oA
;]400ol0003o`Sg2o`000006o`0000OocS7>00?o0000okQ7^?nhAkP02?nhAkP00ol0003oXUfRoj9M
XP03oj9MXP;o00002?neB[D3o`0000KohQgR1?l00002omhQgP03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003oeRWFo`000?nfBKH3o`0000gogR7N00?o0000okA;]?ndBk@01?ndBk@00ol0003o]TVfokI9
]P0;okI9]P?o00000onVFJH01Ol0003oYeRWo`000?nXEjSo000001Co_D:m00?o0000om@[e?l00000
4ooA;]400ol0003ocS7>olhacP0=olhacP03o`000?nhAkSo^4Nh00Go^4Nh0_l00008oj9MXP03o`00
0?neB[Go]DZe00Go00000ongB;L00ol0003ohQgRon8MhP03o`0000OogR7N00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oF:MKoeRWFo`0000Co]TVf0ol0000:omhQgP03o`000?ndBkCo]4^d00?o]4^d
00?o0000okI9]_nfBKH02OnfBKH3o`0000GoYUVV00Co0000ojMHYonWF:Oo00000_nXEjP00ol0003o
_D:moke2_@0Boke2_@03o`000?oA;]7odBkA01;odBkA00?o0000olhac_o><Lh03_o><Lh00ol0003o
^4NhokQ7^003okQ7^003o`000?nRGJ;oXUfR00WoXUfR0_l00009okM8]`;o00002_oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000omHYe_oF:MKoeRWFo`000007okI9]P;o00001ooN8Mh5o`0000;o
]4^d00?o0000okI9]_nfBKH01_nfBKH3o`0000SoYUVV00Co0000ojMHYonWF:Oo00000onXEjP00ol0
003o_D:moke2_@0Aoke2_@03o`000?oA;]7odBkA017odBkA00?o0000olhac_o><Lh04?o><Lh01Ol0
003o^4NhokQ7^?nhAkSo000000coXUfR00?o0000okM8]ongB;L02?ngB;L00ol0003ogR7NomhQgP0:
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000CoeRWF00?o0000okI9]_nfBKH01onfBKH3o`00
0004omhQg_l0003o0000o`0000Go]DZe0_l00006okI9]P?o00002_nVFJH01Ol0003oYeRWojMHYonW
F:Oo000000CoZ5NX00?o0000oke2_Onm@[d04?nm@[d00ol0003odBkAom4^d@0Aom4^d@03o`000?o>
<LkocS7>017ocS7>00?o0000okQ7^?l000003OnRGJ800ol0003o]dRgokM8]`08okM8]`03o`000?oN
8MkogR7N00[ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oF:MKoeRWF00CoeRWF00?o0000
okI9]_nfBKH02_nfBKH00ol0003o]DZeokE:]@08okE:]@03o`000?nfBKKo]TVf00?o00003OnVFJH0
1Ol0003oYeRWojMHYonWF:Oo000000GoZ5NX00?o0000oke2_Onm@[d03onm@[d00ol0003odBkAom4^
d@0Aom4^d@03o`000?o><LkocS7>01;ocS7>00?o0000oj9MX_nRGJ803?nRGJ800ol0003o]dRgokM8
]`08okM8]`03o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000omHYe_oF:MH01OoF:MH0
0ol0003o]TVfokI9]P0:okI9]P03o`000?neB[Go]DZe00Wo]DZe0_l0000?ojIIYP03o`000?nWF:Oo
YeRW00;oYeRW00?o0000ojQGZ?nXEjP01?nXEjP00ol0003o_D:moke2_@0=oke2_@?o00004OoA;]40
0ol0003ocS7>olhacP0ColhacP03o`000?nRGJ;oXUfR00_oXUfR00?o0000okM8]ongB;L02OngB;L0
0ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008oo/4n`;o00002?oF:MH0
0ol0003o]TVfokI9]P0:okI9]P03o`000?neB[Go]DZe00Wo]DZe00?o0000ojIIY_nVFJH03OnVFJH0
0ol0003oYeRWojMHY`03ojMHY`03o`000?nXEjSoZ5NX00GoZ5NX00?o0000oke2_Onm@[d02_nm@[d2
o`0000?ocC;=00?o0000om4^dOoA;]403_oA;]400ol0003ocS7>olhacP0ColhacP03o`000?nRGJ;o
XUfR00_oXUfR00?o0000okM8]ongB;L02OngB;L00ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000Gon`Ck00?o0000omHYe_oF:MH01ooF:MH2o`0000_o]TVf00?o0000okE:
]OneB[D02oneB[D00ol0003oYUVVojIIYP0<ojIIYP03o`000?nWF:OoYeRW00?oYeRW00?o0000ojQG
Z?nXEjP01_nXEjP00ol0003o_D:moke2_@07oke2_@;o00001_o=</d2o`0000kodBkA00?o0000olha
c_o><Lh04oo><Lh00ol0003oXUfRoj9MXP0;oj9MXP03o`000?ngB;Oo]dRg00Wo]dRg00?o0000omhQ
g_oN8Mh03?oN8Mh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000oo/4nook1?_on`Cko`000009omHY
eP03o`000?n0Oh3o000000_o]TVf00?o0000okE:]OneB[D02oneB[D00ol0003oYUVVojIIYP0;ojII
YP03o`000?nWF:OoYeRW00CoYeRW00?o0000ojQGZ?nXEjP01onXEjP00ol0003o_D:moke2_@05oke2
_@03o`000?o=</gocC;=00SocC;=00?o0000om4^dOoA;]402_oA;]400ol0003ocS7>olhacP0Dolha
cP03o`000?nRGJ;oXUfR00_oXUfR00?o0000okM8]ongB;L02OngB;L00ol0003ogR7NomhQgP0<omhQ
gP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003on`Cko`000009omHYeP04o`000?n0Oh3oP7n0o`00
00_o]TVf00?o0000okE:]OneB[D02oneB[D00ol0003oYUVVojIIYP0;ojIIYP03o`000?nWF:OoYeRW
00CoYeRW00?o0000ojQGZ?nXEjP02?nXEjP00ol0003o_D:moke2_@02oke2_@;o00003?o=</d2o`00
00[odBkA00?o0000olhac_o><Lh05?o><Lh00ol0003oXUfRoj9MXP0;oj9MXP03o`000?ngB;Oo]dRg
00Wo]dRg00?o0000omhQg_oN8Mh03OoN8Mh00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oeRWFomHYeP07omHYeP03
o`000?n0Oh3oP7n000;oP7n000?o0000okI9]_nfBKH02?nfBKH00ol0003o]DZeokE:]@0<okE:]@03
o`000?nVFJKoYUVV00WoYUVV00?o0000ojMHYonWF:L01OnWF:L00ol0003oZ5NXojQGZ009ojQGZ004
o`000?nm@[go0000o`00013ocC;=0_l00008om4^d@03o`000?o><LkocS7>01CocS7>0ol0000;oj9M
XP03o`000?ngB;Oo]dRg00Wo]dRg00?o0000omhQg_oN8Mh03OoN8Mh01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oeRWFomHYeP06omHYeP03o`000?n0Oh3oP7n000?oP7n000?o0000okI9
]_nfBKH02?nfBKH00ol0003o]DZeokE:]@0;okE:]@;o00002_nVFJH00ol0003oYeRWojMHY`06ojMH
Y`03o`000?nXEjSoZ5NX00[oZ5NX00?o0000oldbcOo=</d04_o=</d00ol0003odBkAom4^d@04om4^
d@03o`000?o><LkocS7>01GocS7>00?o0000ol@ka?o4>l@01Ol00005oj9MXP03o`000?ngB;Oo]dRg
00[o]dRg00?o0000omhQg_oN8Mh03_oN8Mh3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeRWFomHYeP04omHYeP03
o`000?n0Oh3oP7n000CoP7n000?o0000okI9]_nfBKH01onfBKH00ol0003o]DZeokE:]@0;okE:]@04
o`000?ncC;?o/dbco`0000WoYUVV00?o0000ojMHYonWF:L01_nWF:L00ol0003oZ5NXojQGZ00:ojQG
Z003o`000?o=</gocC;=01?ocC;=0_l00003om4^d@Co00005?o><Lh00ol0003oa3_4ol@ka006ol@k
a0Co000000?oXUfRo`000?ngB;L02ongB;L00ol0003ogR7NomhQgP0>omhQgP03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003oeRWFomHYeP03omHYeP03o`000?n0Oh3oP7n000GoP7n000?o0000okI9]_nf
BKH01onfBKH00ol0003o]DZeokE:]@09okE:]@;o00001?ncC;<00ol0003oYUVVojIIYP05ojIIYP03
o`000?nWF:OoYeRW00OoYeRW00?o0000ojQGZ?nXEjP02_nXEjP00ol0003ocC;=oldbc@0Eoldbc@03
o`000?oA;]7o000000CodbcC0ol0000@olhacP03o`000?o4>lCoa3_400_oa3_40_l0000<okM8]`03
o`000?oN8MkogR7N00cogR7N0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000omHYe_oF:MH00_oF:MH00ol0003oP7n0
oh1oP006oh1oP003o`000?nfBKKo]TVf00Oo]TVf00?o0000okE:]OneB[D02?neB[D00ol0003o/dbc
ok=</`05ok=</`03o`000?nVFJKoYUVV00CoYUVV00?o0000ojMHYonWF:L01onWF:L00ol0003oZ5NX
ojQGZ00:ojQGZ003o`000?o=</gocC;=01KocC;=00?o0000om</dooC;=<01_oC;=<3o`0000cocS7>
00?o0000ol@ka?o4>l@03Oo4>l@00ol0003o]dRgokM8]`09okM8]`Go00002OoN8Mh2o`000003omTV
fOl0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003omHYe_l0003oP7n000WoP7n000?o0000okI9]_nfBKH01_nf
BKH00ol0003o]DZeokE:]@07okE:]@03o`000?ncC;?o/dbc00Oo/dbc00?o0000ojIIY_nVFJH00_nV
FJH00ol0003oYeRWojMHY`08ojMHY`03o`000?nXEjSoZ5NX00WoZ5NX00?o0000oldbcOo=</d05oo=
</d00ol0003odbcCom</d`09om</d`?o00002Oo><Lh00ol0003oa3_4ol@ka00>ol@ka0Ko00001?ng
B;L00ol0003oYUVVojIIYP03ojIIYPGo00000_oN8Mh2o`0000CofBKI00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o6>LKoaSW6olHia_l000002on0Oh000ol0003o]TVfokI9]P06okI9]P03o`000?ne
B[Go]DZe00Go]DZe0_l0000;ok=</`04o`000?nVFJKoYUVVo`0000_oYeRW00?o0000ojQGZ?nXEjP0
2OnXEjP00ol0003ocC;=oldbc@0Foldbc@03o`000?oC;=?odbcC00godbcC0ol00005olhacP03o`00
0?o4>lCoa3_400ooa3_400?o0000ol0o`?o0?l000oo0?l04o`0000_oYUVV0_l00006omTVf@03o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oaSW6olHiaP02olHiaPko00001_nfBKH00ol0003o]DZeokE:
]@05okE:]@03o`000?ncC;?o/dbc00co/dbc00?o0000ojIIY_l000002onWF:L00ol0003oZ5NXojQG
Z007ojQGZ0?o00006?o=</d00ol0003odbcCom</d`0@om</d`?o000000?ocS7>o`000?o4>l@04?o4
>l@00ol0003o`3o0ol0o`007ol0o`003o`000?nVFJKoYUVV00[oYUVV00?o0000omTVfOoI9]T01OoI
9]T00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olHiaP03o`000?n4NhCoQ7^400_oQ7^40_l00004
okI9]P03o`000?neB[Go]DZe00?o]DZe0_l0000@ok=</`03o`000?nWF:OoYeRW00[oYeRW00?o0000
ojQGZ?nXEjP00onXEjP4o`0000;oWV6N00?o0000oldbcOo=</d05Oo=</d00ol0003odbcCom</d`0D
om</d`03o`000?o4>lCoa3_4013oa3_400?o0000ol0o`?o0?l001oo0?l000ol0003oYUVVojIIYP0:
ojIIYP03o`000?oI9]WofBKI00GofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o6>LKoaSW6
00GoaSW600?o0000ohAkQ?n4Nh@03On4Nh@6o`0000?o]DZe00?o0000ok=</oncC;<04?ncC;<00ol0
003oYeRWojMHY`0:ojMHY`03o`000?nXEjSo000000?o00001onNHIh00ol0003ocC;=oldbc@0Doldb
c@03o`000?oC;=?odbcC01CodbcC00?o0000ol@ka?o4>l@03oo4>l@00ol0003o`3o0ol0o`008ol0o
`003o`000?nVFJKoYUVV00[oYUVV00?o0000omTVfOoI9]T01OoI9]T00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olHia_o6>LH01_o6>LH00ol0003oQ7^4ohAkQ00=ohAkQ003o`000?nkA;_o^dBk00?o
^dBk00?o0000okE:]Ol000004oncC;<4o`0000WoYeRW0_l0000<oiiQWP03o`000?o=</gocC;=01?o
cC;=00?o0000om</dooC;=<05OoC;=<00ol0003oa3_4ol@ka00>ol@ka003o`000?o0?l3o`3o000So
`3o000?o0000ojIIY_nVFJH02OnVFJH00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o6>LKoaSW600SoaSW600?o0000ohAkQ?n4Nh@02on4Nh@00ol0003o^dBkok]4^`05ok]4^`03o`00
0?ncC;?o/dbc01;o/dbc00Co0000ojMHYonWF:OoYeRW1Ol00003ojMHY`03o`000?nNHIkoWV6N00go
WV6N0ol0000@oldbc@;o00006?oC;=<00ol0003oa3_4ol@ka00=ol@ka003o`000?o0?l3o`3o000Wo
`3o000?o0000ojIIY_nVFJH02OnVFJH00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_oaSW600?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003o^dBkok]4^`06ok]4^`03o`00
0?ncC;?o/dbc017o/dbc00?o0000ojMHYonWF:L01onWF:L3o`00013oWV6N00?o0000oi]TVonKI9/0
1Ol00009oldbc@;o000000?o[5>/o`000?oC;=<05ooC;=<00ol0003oa3_4ol@ka00=ol@ka003o`00
0?o0?l3o`3o000Wo`3o000?o0000ojIIY_nVFJH02?nVFJH2o`0000[ofBKI00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oJ9M[ofRGJ00;ofRGJ00?o0000olHia_o6>LH02Oo6>LH00ol0003oQ7^4ohAk
Q00:ohAkQ003o`000?nkA;_o^dBk00Oo^dBk00?o0000ok=</oncC;<03oncC;<00ol0003oYeRWojMH
Y`0:ojMHY`03o`000?nNHIkoWV6N00goWV6N00?o0000oi]TVonKI9/01_nKI9/4o`0000CocC;=00?o
0000ojaC[?n/Dj`00_n/Dj`00ol0003odbcCom</d`0Fom</d`03o`000?o4>lCoa3_400_oa3_400?o
0000ol0o`?o0?l002oo0?l000ol0003oYUVVojIIYP06ojIIYP03o`000?nGJ9Oo000000[ofBKI00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000olHia_o6>LH02?o6>LH=
o`0000[o^dBk00?o0000ok=</oncC;<03oncC;<00ol0003oYeRWojMHY`0;ojMHY`03o`000?nNHIko
WV6N00coWV6N00?o0000oi]TVonKI9/02_nKI9/4o`0000Go[5>/00?o0000om</dooC;=<05_oC;=<0
0ol0003oa3_4ol@ka00:ol@ka003o`000?o0?l3o`3o000co`3o000?o0000ojIIY_nVFJH01?nVFJH2
o`0000?oUfRG00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omXU
f_oJ9MX00ooJ9MX00ol0003oaSW6olHiaP07olHiaP03o`000?n3O8?oPgb300WoPgb300?o0000ok]4
^onkA;/02OnkA;/00ol0003o/dbcok=</`0=ok=</`03o`000?nWF:OoYeRW00coYeRW00?o0000oiiQ
W_nNHIh03?nNHIh00ol0003oVfBKoi]TV`0;oi]TV`03o`000?n6NHKo000000Ko[5>/00?o0000om</
dooC;=<05_oC;=<00ol0003oa3_4ol@ka009ol@ka003o`000?o0?l3o`3o000co`3o000?o0000ojII
Y_nVFJH00onVFJH00ol0003oUfRGoiMXU`03oiMXU`03o`000?oI9]WofBKI00SofBKI00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oJ9M[ofRGJ00CofRGJ00?o0000olHia_o6>LH01_o6>LH00ol0003o
Pgb3oh=lP`08oh=lP`03o`000?nkA;_o^dBk00_o^dBk00?o0000ok=</oncC;<02?ncC;<4o`0000oo
YeRW00?o0000oiiQW_nNHIh02onNHIh00ol0003oVfBKoi]TV`0;oi]TV`04o`000?n6NHKoQWV6o`00
00Oo[5>/00?o0000om</dooC;=<05OoC;=<00ol0003oa3_4ol@ka008ol@ka003o`000?o0?l3o`3o0
00go`3o000?o0000ojIIY_nVFJH00_nVFJH00ol0003oUfRGoiMXU`05oiMXU`03o`000?oI9]WofBKI
00OofBKI00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000olHia_o6
>LH01Oo6>LH00ol0003oPgb3oh=lP`08oh=lP`03o`000?nkA;_o^dBk00_o^dBk00?o0000ok=</onc
C;<00oncC;<5o`0000?oZ5NX00?o0000ojMHYonWF:L03_nWF:L00ol0003oWV6NoiiQWP0:oiiQWP03
o`000?nKI9_oVfBK00[oVfBK00Go0000ohIiQ_n6NHKoQWV6o`000007ojaC[003o`000?oC;=?odbcC
01GodbcC00?o0000ol@ka?o4>l@02?o4>l@00ol0003o`3o0ol0o`00=ol0o`003o`000?nVFJKoYUVV
00;o00002?nGJ9L00ol0003ofBKIomTVf@08omTVf@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003ofRGJomXUfP05omXUfP03o`000?o6>LKoaSW600Go
aSW600?o0000oh=lPon3O8<02?n3O8<00ol0003o^dBkok]4^`0<ok]4^`Go00002OnXEjP00ol0003o
YeRWojMHY`0<ojMHY`;o00003?nNHIh00ol0003oVfBKoi]TV`0:oi]TV`05o`000?n6NHKoQWV6ohIi
Q_l000002?n/Dj`00ol0003odbcCom</d`0Dom</d`?o00001oo4>l@00ol0003o`3o0ol0o`00>ol0o
`003o`000?nVFJKo000000_oUfRG00?o0000omTVfOoI9]T01_oI9]T00ol0003onPGjooX5nP06ooX5
nP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000omXUf_oJ9MX01OoJ9MX00ol0003oaSW6olHiaP04olHiaP03o`000?n3O8?oPgb300Oo
Pgb300?o0000ok]4^onkA;/03?nkA;/01?l0003o/dbcok=</ol0000;ojQGZ003o`000?nWF:OoYeRW
00_oYeRW00Co0000ohAkQ?n4NhCo00002_nNHIh00ol0003oVfBKoi]TV`0:oi]TV`03o`000?n6NHKo
QWV600;oQWV600?o0000ojaC[?n/Dj`01_n/Dj`00ol0003odbcCom</d`0Aom</d`?o00000oncC;<0
0ol0003oa3_4ol@ka004ol@ka003o`000?o0?l3o`3o000go`3o01?l0000;oiMXU`03o`000?oI9]Wo
fBKI00GofBKI00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oJ9M[ofRGJ00KofRGJ00Co0000olHi
a_o6>LKoaSW61?l00008oh=lP`03o`000?nkA;_o^dBk00_o^dBk00?o0000ok=</oncC;<00_ncC;<0
0ol0003oZ5NXojQGZ008ojQGZ003o`000?nWF:OoYeRW00[oYeRW00?o0000ohAkQ?n4Nh@00_n4Nh@0
0ol0003oWV6NoiiQWP03oiiQWPGo00002onKI9/00ol0003oQWV6ohIiQP03ohIiQP03o`000?n/Djco
[5>/00Oo[5>/00?o0000om</dooC;=<03_oC;=<2o`0000Oo/dbc00?o0000ol@ka?o4>l@00_o4>l@0
0ol0003o`3o0ol0o`00=ol0o`003o`000?nWF:OoYeRW00;oYeRW00?o0000oiMXUonGJ9L02OnGJ9L0
0ol0003ofBKIomTVf@03omTVf@03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003ofRGJomXUfP07omXU
fP?o00001?njAKX00ol0003oPgb3oh=lP`05oh=lP`03o`000?nkA;_o^dBk00[o^dBk00?o0000ok=<
/oncC;<00oncC;<00ol0003oZ5NXojQGZ009ojQGZ003o`000?nWF:OoYeRW00SoYeRW00?o0000ohAk
Q?n4Nh@01?n4Nh@5o`0000CoE:]D00?o0000oi]TVonKI9/02OnKI9/00ol0003oQWV6ohIiQP03ohIi
QP03o`000?n/Djco[5>/00So[5>/00?o0000om</dooC;=<02_oC;=<3o`0000[o/dbc00Go0000ol@k
a?o4>lCoa3_4o`00000>ol0o`003o`000?nWF:OoYeRW00CoYeRW0_l00009oiMXU`03o`000?oI9]Wo
fBKI00;ofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oJ9M[ofRGJ00OofRGJ00?o0000okY5
^_njAKX01OnjAKX00ol0003oPgb3oh=lP`03oh=lP`03o`000?nkA;_o^dBk00[o^dBk00?o0000ok=<
/oncC;<01?ncC;<00ol0003oZ5NXojQGZ009ojQGZ003o`000?nWF:OoYeRW00OoYeRW00?o0000ohAk
Q?n4Nh@01On4Nh@00ol0003oE:]DoeB[E007oeB[E003o`000?nKI9_oVfBK00OoVfBK00?o0000ohIi
Q_n6NHH01?n6NHH00ol0003o[5>/ojaC[008ojaC[003o`000?oC;=?odbcC00SodbcC0_l0000>ok=<
/`Co00003?o0?l02o`0000WoYeRW00?o0000oiMXUonGJ9L01onGJ9L01?l0003ofBKIomTVfOl0000?
ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omXUf_oJ9MX01OoJ9MX00ol0003o^TFjokY5^P07okY5^P;o00000on3O8<00ol0
003o^dBkok]4^`09ok]4^`03o`000?ncC;?o/dbc00Ko/dbc00?o0000ojQGZ?nXEjP02OnXEjP00ol0
003oYeRWojMHY`05ojMHY`03o`000?n4NhCoQ7^400KoQ7^400?o0000oeB[E?mDZe@02?mDZe@00ol0
003oVfBKoi]TV`06oi]TV`03o`000?n6NHKoQWV600CoQWV600?o0000ojaC[?n/Dj`02On/Dj`4o`00
00?odbcC0ol0000@ok=</`05o`000?oA;]7odBkAom4^dOl000002_o0?l000ol0003oYeRWojMHY`0:
ojMHY`Ko00000onGJ9L00ol0003ofBKIo`00000@ooX5nP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000omXUf_oJ9MX01?oJ9MX00ol0
003o^TFjokY5^P0:okY5^P04o`000?n3O8?oPgb3o`0000[o^dBk00?o0000ok=</oncC;<01oncC;<0
0ol0003oZ5NXojQGZ009ojQGZ003o`000?nWF:OoYeRW00CoYeRW00?o0000ohAkQ?n4Nh@01on4Nh@0
0ol0003oE:]DoeB[E008oeB[E0;o00001_nKI9/00ol0003oQWV6ohIiQP05ohIiQP03o`000?n/Djco
[5>/00Wo[5>/00Co0000oiiQW_nNHIkoWV6N0ol0000Bok=</`03o`000?oA;]7odBkA00?odBkA0_l0
0006ol0o`0;o00003OnWF:L00ol0003ogR7NomhQgP03omhQgPGo00004Ooj1OX00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000omXUf_oJ9MX00ooJ9MX0
0ol0003o^TFjokY5^P0<okY5^P;o00002_nkA;/00ol0003o/dbcok=</`08ok=</`03o`000?nXEjSo
Z5NX00[oZ5NX00?o0000ojMHYonWF:L00_nWF:L00ol0003oQ7^4ohAkQ008ohAkQ003o`000?mDZeCo
E:]D00KoE:]D0_l00002oh5nP@03o`000?nKI9_oVfBK00;oVfBK00?o0000ohIiQ_n6NHH01_n6NHH0
0ol0003o[5>/ojaC[008ojaC[003o`000?nNHIkoWV6N00CoWV6N00?o0000ok=</oncC;<03oncC;<0
0ol0003odBkAom4^d@06om4^d@;o00000oo0?l000ol0003oYeRWojMHY`0=ojMHY`03o`000?oN8Mko
gR7N00OogR7N0_l0000@ooX5nP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003ofRGJomXUfP02omXUfP03o`000?njAK[o^TFj
00ko^TFj00?o0000ok]4^onkA;/01onkA;/00ol0003o/dbcok=</`0:ok=</`03o`000?nXEjSoZ5NX
00WoZ5NX00Go0000ojMHYonWF:OoYeRWo`00000;ohAkQ003o`000?mDZeCoE:]D00CoE:]D0_l00005
oh5nP@05o`000?nKI9_oVfBKoi]TVol000002?n6NHH00ol0003o[5>/ojaC[008ojaC[003o`000?nN
HIkoWV6N00GoWV6N00?o0000ok=</oncC;<03_ncC;<00ol0003odBkAom4^d@08om4^d@03o`000?o0
?l3o000000ooYeRW00?o0000omhQg_oN8Mh02?oN8Mh01?l0003on`Cko`000?l0000>ooX5nP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oJ9M[ofRGJo`00017o^TFj00?o0000ok]4^onkA;/01_nkA;/00ol0003o/dbc
ok=</`0;ok=</`03o`000?nXEjSoZ5NX00WoZ5NX00Co0000ojMHYonWF:Oo00003?n4Nh@00ol0003o
E:]DoeB[E002oeB[E0;o00002?n1OX400ol0003oVfBKo`000009ohIiQP03o`000?n/Djco[5>/00So
[5>/00?o0000oiiQW_nNHIh01OnNHIh00ol0003o/dbcok=</`0=ok=</`03o`000?oA;]7odBkA00[o
dBkA00?o0000ojMHYonWF:L03_nWF:L00ol0003ogR7NomhQgP07omhQgP03o`000?ok1?_on`Ck00;o
n`Ck00?o0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000BokY5^P03o`00
0?nkA;_o^dBk00Co^dBk00?o0000ok=</oncC;<03?ncC;<00ol0003oZ5NXojQGZ00:ojQGZ0?o0000
3?n4Nh@00ol0003oE:]DoeB[E002o`0000_oPGj100?o0000ohIiQ_n6NHH02?n6NHH00ol0003o[5>/
ojaC[007ojaC[003o`000?nNHIkoWV6N00OoWV6N00?o0000ok=</oncC;<03?ncC;<00ol0003odBkA
om4^d@0;om4^d@;o00003_nWF:L00ol0003ogR7NomhQgP07omhQgP03o`000?ok1?_on`Ck00?on`Ck
0_l0000:ooX5nP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000on@Ki?oT6n@00ooT6n@00ol0003o^TFjokY5^P0?okY5^P?o00000onk
A;/00ol0003o/dbcok=</`0>ok=</`03o`000?nXEjSoZ5NX00SoZ5NX00Co0000oh]dRon;M8_oRgB;
0_l0000:ohAkQ0?o00003On1OX400ol0003oQWV6ohIiQP08ohIiQP03o`000?n/Djco[5>/00Oo[5>/
00?o0000oiiQW_nNHIh01onNHIh00ol0003o/dbcok=</`0;ok=</`03o`000?oA;]7odBkA00codBkA
00?o0000ol8m`_l000000_l0000:ojMHY`03o`000?oN8MkogR7N00SogR7N00?o0000oo/4nook1?/0
1Ook1?/2o`0000SonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oi1_Ton@Ki004on@Ki003o`000?njAK[o^TFj00co^TFj0_l0
0003ojm@[`03o`000?nkA;_o0000017o/dbc00?o0000ojQGZ?nXEjP01onXEjP00ol0003oRgB;oh]d
R`04oh]dR`;o00002?n4Nh@00ol0003oPGj1oh5nP@0>oh5nP@;o00002?n6NHH00ol0003o[5>/ojaC
[006ojaC[003o`000?nNHIkoWV6N00WoWV6N00?o0000ok=</oncC;<02OncC;<00ol0003odBkAom4^
d@0=om4^d@03o`000?o2?L;o`Sg200;o`Sg20ol00007ojMHY`03o`000?oN8MkogR7N00OogR7N00?o
0000oo/4nook1?/02?ok1?/2o`0000KonPGj00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oi1_Ton@Ki005on@Ki003o`000?njAK[o
^TFj00Wo^TFj0_l00006ojm@[`03o`000?ncC;?o/dbc013o/dbc00?o0000ojQGZ?nXEjP01_nXEjP0
0ol0003oRgB;oh]dR`07oh]dR`03o`000?n4NhCoQ7^400CoQ7^40ol0000>oh5nP@03o`000?m]TVgo
KI9]00?o00001On6NHH00ol0003o[5>/ojaC[006ojaC[003o`000?nNHIkoWV6N00[oWV6N00?o0000
ok=</oncC;<02?ncC;<00ol0003odBkAom4^d@0=om4^d@03o`000?o2?L;o`Sg200Go`Sg20ol00004
ojMHY`03o`000?oN8MkogR7N00OogR7N00?o0000oo/4nook1?/02_ok1?/00ol0003onPGjooX5nP02
ooX5nP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oi1_Ton@Ki006on@Ki003o`000?njAK[o^TFj00Go^TFj0ol00008ojm@[`03o`000?ncC;?o/dbc
017o/dbc00Co0000ojQGZ?nXEjSoZ5NX1?l0000;oh]dR`;o000000CoQ7^4o`000?l0003o00000onG
J9L2o`0000_oPGj100?o0000offBKOm]TVd01?m]TVd2o`0000?oQWV600?o0000ojaC[?n/Dj`01_n/
Dj`00ol0003oWV6NoiiQWP0:oiiQWP03o`000?ncC;?o/dbc00Oo/dbc00?o0000om4^dOoA;]403_oA
;]400ol0003o`Sg2ol8m`P08ol8m`PCo00002_oN8Mh00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
nPGjo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oi1_Ton@Ki007on@Ki003o`000?njAK[o^TFj00;o^TFj0_l0000<ojm@[`03o`000?ncC;?o
/dbc013o/dbc1?l00003oiiQWP03o`000?n;M8_oRgB;00_oRgB;00?o0000oiMXUonGJ9L01_nGJ9L0
0ol0003oPGj1oh5nP@07oh5nP@03o`000?m]TVgoKI9]00OoKI9]3?l0000>oiiQWP03o`000?ncC;?o
/dbc00Ko/dbc00?o0000om4^dOoA;]403_oA;]400ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oN8Mko
gR7N00OogR7N00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oT6nCoi1_T00Woi1_T00Co0000okY5
^_l0003o00003_n_D:l00ol0003o/dbcok=</`0?ok=</`03o`000?nNHIkoWV6N00KoWV6N00?o0000
oh]dRon;M8/02_n;M8/00ol0003oUfRGoiMXU`07oiMXU`;o00001_n1OX400ol0003oKI9]offBK@08
offBK@03o`000?naC[7o/Dja00So/Dja00?o0000oiiQW_nNHIh03?nNHIh00ol0003o/dbcok=</`05
ok=</`03o`000?oA;]7odBkA00oodBkA0_l0000=ol8m`P03o`000?oN8MkogR7N00KogR7N00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oT6nCoi1_T00[oi1_T00?o0000ojm@[on_D:l03_n_D:l00ol0
003o/dbcok=</`0>ok=</`03o`000?nNHIkoWV6N00OoWV6N00?o0000oh]dRon;M8/02_n;M8/00ol0
003oUfRGoiMXU`09oiMXU`;o00000on1OX400ol0003oKI9]offBK@09offBK@03o`000?naC[7o/Dja
00Wo/Dja00?o0000oiiQW_nNHIh02_nNHIh4o`0000Co/dbc00?o0000om4^dOoA;]404?oA;]401?l0
003o`Ck1o`000?l0000<ol8m`P03o`000?oN8MkogR7N00GogR7N00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oT6nCoi1_T00[oi1_T00?o0000ojm@[on_D:l03on_D:l@o`0000[oWV6N00?o0000oh]d
Ron;M8/02On;M8/00ol0003oMXUfo`00000<oiMXU`05o`000?n1OX7o0000ofn@Kol000002_m]TVd0
0ol0003o/Djaok5>/@09ok5>/@03o`000?nNHIkoWV6N00OoWV6N0ol00004okU6^@?o000000?o/dbc
o`000?oA;]404OoA;]401?l0003o`Ck1ol4n`Oo1?/42o`0000_o`Sg200?o0000omhQg_oN8Mh00ooN
8Mh00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on@Ki?oT6n@02_oT6n@00ol0003o[e2_ojm@[`0?
ojm@[`03o`000?nhAkSo^4Nh00co^4Nh00?o0000oiiQW_nNHIh02OnNHIh00ol0003oRgB;oh]dR`07
oh]dR`04o`000?mfRGKoMXUfo`0000goUfRG00Go0000ofn@Kom_T6ooKi1_o`000009offBK@03o`00
0?naC[7o/Dja00[o/Dja00?o0000oiiQW_nNHIh00onNHIh3o`0000[o^DJi00?o0000om4^dOoA;]40
4?oA;]400ol0003o`Ck1ol4n`@04ol4n`@;o00002_o2?L800ol0003ogR7NomhQgP04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coi1_T00?o0000ojm@[on_D:l03on_D:l00ol0003o^4NhokQ7^00<okQ7^003o`000?nN
HIkoWV6N00WoWV6N00?o0000oh]dRon;M8/01_n;M8/00ol0003oMXUfogJ9MP02ogJ9MP03o`000?nG
J9OoUfRG00[oUfRG00?o0000ofn@Kom_T6l00_m_T6l00ol0003oKI9]offBK@06offBK@03o`000?na
C[7o/Dja00[o/Dja00?o0000oiiQW_nNHIh00ol0000=okU6^@03o`000?oA;]7odBkA013odBkA00?o
0000ol4n`Oo1?/401_o1?/42o`0000Wo`Sg20_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000on@Ki?oT6n@02_oT6n@00ol0003o[e2_ojm@[`0=ojm@[`?o00003onhAkP0
0ol0003oWV6NoiiQWP08oiiQWP03o`000?n;M8_oRgB;00GoRgB;00?o0000ogJ9M_mfRGH00omfRGH0
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?m_T6ooKi1_00?oKi1_00?o0000offBKOm]TVd01Om]TVd0
0ol0003o/Djaok5>/@0;ok5>/@;o00004OniA[T00ol0003odBkAom4^d@0?om4^d@03o`000?o1?/7o
`Ck100So`Ck10_l00007ol8m`P03o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000on@Ki?oT6n@02?oT6n@00ol0003o[e2_ojm@[`09ojm@[`Go00000_nKI9/00ol0
003o^4NhokQ7^00=okQ7^003o`000?nNHIkoWV6N00WoWV6N00?o0000oh]dRon;M8/01?n;M8/00ol0
003oMXUfogJ9MP04ogJ9MP03o`000?nGJ9OoUfRG00SoUfRG00?o0000ofn@Kom_T6l01Om_T6l00ol0
003oKI9]offBK@04offBK@03o`000?naC[7o/Dja00_o/Dja00?o0000okU6^OniA[T04?niA[T00ol0
003odBkAom4^d@0?om4^d@03o`000?o1?/7o`Ck100[o`Ck10_l00004ol8m`P03o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003oi1_Ton@Ki007on@Ki003o`000?n_D:oo[e2_00Co[e2_1Ol00007oi]TV`03
o`000?nhAkSo^4Nh00go^4Nh00?o0000oiiQW_nNHIh02OnNHIh00ol0003oRgB;oh]dR`03oh]dR`03
o`000?mfRGKoMXUf00GoMXUf00?o0000oiMXUonGJ9L02?nGJ9L00ol0003oKi1_ofn@K`06ofn@K`03
o`000?m]TVgoKI9]00?oKI9]00?o0000ok5>/OnaC[402onaC[400ol0003o^DJiokU6^@0@okU6^@03
o`000?oA;]7odBkA00oodBkA00?o0000ol4n`Oo1?/403?o1?/42o`000003ol8m`_l0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oT6nCoi1_T00Ooi1_T00?o0000ojm@[ol00000
1?l0000<oi]TV`03o`000?nhAkSo^4Nh00ko^4Nh00?o0000oiiQW_nNHIh02?nNHIh00ol0003oRgB;
oh]dR`02oh]dR`03o`000?mfRGKoMXUf00OoMXUf00?o0000oiMXUonGJ9L01onGJ9L00ol0003oKi1_
ofn@K`07ofn@K`03o`000?m]TVgoKI9]00;oKI9]00?o0000ok5>/OnaC[402onaC[400ol0003o^DJi
okU6^@0AokU6^@03o`000?oA;]7odBkA00godBkA00?o0000ol4n`Oo1?/403oo1?/400ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000on@Ki?oT6n@01OoT6n@3o`00017oVfBK00?o0000okQ7^?nhAkP03_nh
AkP00ol0003oWV6NoiiQWP09oiiQWP04o`000?n;M8_oRgB;o`0000[oMXUf00?o0000oiMXUonGJ9L0
1onGJ9L00ol0003oKi1_ofn@K`08ofn@K`05o`000?m]TVgoKI9]offBKOl000003OnaC[400ol0003o
^DJiokU6^@0AokU6^@?o00003OoA;]400ol0003o`Ck1ol4n`@0?ol4n`@03o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oT6n@2o`0000;o/Dja00?o0000oi]TVonKI9/03onKI9/00ol0003o
^4NhokQ7^00>okQ7^003o`000?nNHIkoWV6N00SoWV6N1Ol0000;ogJ9MP03o`000?nGJ9OoUfRG00Ko
UfRG00?o0000ofn@Kom_T6l02Om_T6l01?l0003oKI9]offBKOl0000=ok5>/@03o`000?niA[Wo^DJi
017o^DJi00?o0000oi]TVonKI9/00ol0000:om4^d@Co00003Oo1?/400ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000om`Sg?oL8mcog2?L0_l00005ok5>/@03o`000?nKI9_oVfBK00koVfBK00?o0000okQ7
^?nhAkP03_nhAkP00ol0003oWV6NoiiQWP07oiiQWP03o`000?nLHicoW6>L00?oW6>L00?o0000ogJ9
M_mfRGH02?mfRGH00ol0003oUfRGoiMXU`05oiMXU`03o`000?m_T6ooKi1_00[oKi1_1Ol0000<ok5>
/@03o`000?niA[Wo^DJi013o^DJi00?o0000oi]TVonKI9/01?nKI9/3o`0000KodBkA00?o0000ol`c
c?o<<l`00_o<<l`5o`0000So`Ck100?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oL8mcog2?L00?o
g2?L00?o0000ok5>/OnaC[401?naC[400ol0003oVfBKoi]TV`0=oi]TV`03o`000?nhAkSo^4Nh00oo
^4Nh00?o0000oiiQW_nNHIh01?nNHIh2o`0000OoW6>L00?o0000ogJ9M_mfRGH01omfRGHEo`0000Go
O8=l00?o0000ok5>/OnaC[402?naC[43o`00013o^DJi00?o0000oi]TVonKI9/02?nKI9/3o`0000;o
dBkA00?o0000ol`cc?o<<l`02?o<<l`5o`0000?o`Ck100?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oL8mcog2?L00Cog2?L00?o0000ok5>/OnaC[401OnaC[400ol0003oVfBKoi]TV`0;oi]TV`Co0000
3onhAkP00ol0003oWV6NoiiQWP03oiiQWP03o`000?nLHicoW6>L00SoW6>L00?o0000ogJ9M_mfRGH0
1?mfRGH2o`0000SoW6>L00?o0000ohiaS_n>LHh02?n>LHh00ol0003oO8=logb3O005ogb3O0;o0000
1_naC[42o`0000?oYeRW00?o0000okU6^OniA[T03?niA[T00ol0003oVfBKoi]TV`0<oi]TV`;o0000
4?o<<l`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003og2?Lom`Sg005om`Sg003o`000?naC[7o/Dja00Ko/Dja00?o
0000oi]TVonKI9/02OnKI9/00ol0003oOgmoo`000002oieRW@?o00003?nhAkP01?l0003oWV6NoiiQ
W_nNHIh2o`0000coW6>L00?o0000ogJ9M_mfRGH00_mfRGH00ol0003oW6>LoiaSW008oiaSW003o`00
0?n>LHkoSW6>00SoSW6>00?o0000ogb3O?mlPg`01omlPg`00ol0003o/Djaok5>/@02ok5>/@03o`00
0?nWF:OoYeRW00CoYeRW0_l0000;okU6^@03o`000?nKI9_oVfBK00coVfBK00?o0000ojQGZ?l00000
4_o<<l`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003og2?Lom`Sg006om`Sg003o`000?naC[7o/Dja00Oo/Dja00?o
0000oi]TVonKI9/01_nKI9/2o`0000;oOgmo00?o0000oieRWOnMHYd00onMHYd3o`0000[o^4Nh00?o
0000oiiQW_l000003onLHi`01?l0003oMXUfo`000?l0000;oiaSW003o`000?n>LHkoSW6>00SoSW6>
00?o0000ogb3O?mlPg`02?mlPg`01?l0003o/Djao`000?l00009ojMHY`03o`000?niA[Wo^DJi00Oo
^DJi00?o0000oi]TVonKI9/03?nKI9/01?l0003oZ5NXojQGZ?l0000Col`cc003o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000om`Sg?oL8m`01ooL8m`00ol0003o/Djaok5>/@08ok5>/@03o`000?nKI9_oVfBK00Co
VfBK00?o0000ogmoOomoOgl00omoOgl00ol0003oWF:MoieRW@05oieRW@?o00001_nhAkP4o`00013o
W6>L00?o0000oiaSW?nLHi`03?nLHi`00ol0003oSW6>ohiaSP07ohiaSP03o`000?mlPgcoO8=l00Wo
O8=l00?o0000ojMHYonWF:L02_nWF:L2o`0000Ko^DJi00?o0000oi]TVonKI9/03?nKI9/00ol0003o
Z5NXojQGZ002ojQGZ003o`000?o<<lcoc3?<00ooc3?<00?o0000omLXeol000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003og2?Lom`Sg008om`Sg003o`000?naC[7o/Dja00Wo/Dja00Co0000oi]TVonKI9_o
VfBK0_l00006ogmoO`03o`000?nMHYgoWF:M00SoWF:M0ol000000onhAkSo0000o`000004ojAKY003
o`000?nLHicoW6>L00goW6>L00?o0000oiaSW?nLHi`03?nLHi`00ol0003oSW6>ohiaSP07ohiaSP03
o`000?mlPgcoO8=l00WoO8=l00?o0000ojMHYonWF:L03?nWF:L00ol0003o^DJiokU6^@03o`0000ko
VfBK00?o0000ojQGZ?nXEjP00onXEjP00ol0003oc3?<ol`cc00>ol`cc005o`000?oG:=OoebSGomLX
eol000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003og2?Lom`Sg009om`Sg003o`000?naC[7o/Dja00[o
/Dja00?o0000oi]TVol000002?moOgl00ol0003oWF:MoieRW@0;oieRW@03o`000?nTFjCoY5^T00Go
Y5^T00?o0000oiaSW?nLHi`03?nLHi`00ol0003oW6>LoiaSW00<oiaSW003o`000?n>LHkoSW6>00Oo
SW6>00?o0000ogb3O?mlPg`02?mlPg`2o`0000ooYeRW0_l00002ojUFZ@03o`000?nKI9_oVfBK00_o
VfBK00?o0000ojQGZ?nXEjP01?nXEjP00ol0003oc3?<ol`cc00=ol`cc003o`000?oG:=OoebSG00?o
ebSG00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;om`Sg003o`000?naC[7o/Dja00_o/Dja00?o0000ogmoOomoOgl0
1omoOgl00ol0003oWF:MoieRW@0;oieRW@03o`000?nTFjCoY5^T00KoY5^T00?o0000oiaSW?nLHi`0
2onLHi`2o`0000goW6>L00?o0000ohiaS_n>LHh01on>LHh00ol0003oO8=logb3O007ogb3O004o`00
0?n7N8OoQgR7o`0000koYeRW00?o0000ojUFZOnYEZT00_nYEZT00ol0003oVfBKoi]TV`09oi]TV`03
o`000?nXEjSoZ5NX00KoZ5NX00?o0000ol`cc?o<<l`02oo<<l`00ol0003oebSGomLXe`05omLXe`04
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000Sog2?L00?o0000ok5>/OnaC[402_naC[42o`0000Wo
Ogmo00?o0000oieRWOnMHYd02onMHYd00ol0003oY5^TojAKY007ojAKY003o`000?nLHicoW6>L00Wo
W6>L00Co0000offBKOm]TVgo00003?nLHi`00ol0003oSW6>ohiaSP07ohiaSP03o`000?mlPgcoO8=l
00KoO8=l00Go0000ohMhQon7N8OoQgR7o`00000>ojMHY`03o`000?nYEZWoZEJY00?oZEJY00?o0000
oi]TVonKI9/01onKI9/00ol0003oZ5NXojQGZ007ojQGZ003o`000?o<<lcoc3?<00[oc3?<00?o0000
omLXeooG:=L01ooG:=L00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006om`Sg003o`000?naC[7o/Dja
00Wo/Dja00Co0000ohm`Son?L8oo00002OmoOgl00ol0003oWF:MoieRW@09oieRW@03o`000?nTFjCo
Y5^T00WoY5^T00?o0000oiaSW?nLHi`01onLHi`00ol0003oKI9]offBK@02offBK@03o`000?nLHico
W6>L00WoW6>L00?o0000ohiaS_n>LHh01on>LHh00ol0003oO8=logb3O005ogb3O003o`000?n7N8Oo
QgR700?oQgR700?o0000ojMHYonWF:L02_nWF:L00ol0003oZEJYojUFZ@05ojUFZ@03o`000?nKI9_o
VfBK00GoVfBK00?o0000ojQGZ?nXEjP02?nXEjP00ol0003oc3?<ol`cc009ol`cc003o`000?oG:=Oo
ebSG00SoebSG00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oL8m`3o`0000Wo/Dja00?o0000ohm`
Son?L8l00_n?L8l00ol0003oOgmoogmoO`06ogmoO`03o`000?nMHYgoWF:M00WoWF:M00?o0000ojAK
Y?nTFj@02_nTFj@00ol0003oW6>LoiaSW005oiaSW003o`000?m]TVgoKI9]00CoKI9]00?o0000oiaS
W?nLHi`02?nLHi`00ol0003oSW6>ohiaSP07ohiaSP03o`000?mlPgcoO8=l00CoO8=l00?o0000ohMh
Qon7N8L01?n7N8L00ol0003oYeRWojMHY`0:ojMHY`03o`000?nYEZWoZEJY00KoZEJY00?o0000oi]T
VonKI9/00onKI9/00ol0003oZ5NXojQGZ009ojQGZ003o`000?o<<lcoc3?<00Soc3?<00?o0000omLX
eooG:=L02OoG:=L00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omLXe`?o00001OnaC[400ol0003o
Sg2?ohm`S`03ohm`S`03o`000?moOgooOgmo00KoOgmo00?o0000oieRWOnMHYd02OnMHYd00ol0003o
Y5^TojAKY00;ojAKY003o`000?nLHicoW6>L00?oW6>L00?o0000offBKOm]TVd01_m]TVd00ol0003o
W6>LoiaSW008oiaSW003o`000?n>LHkoSW6>00KoSW6>00?o0000ogb3O?mlPg`00_mlPg`2o`0000So
QgR700?o0000ojMHYonWF:L02OnWF:L00ol0003oZEJYojUFZ@07ojUFZ@05o`000?nKI9_oVfBKoi]T
Vol000003OnXEjP00ol0003oc3?<ol`cc006ol`cc003o`000?oG:=OoebSG00[oebSG00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oG:=OoebSG00GoebSG0ol000000onaC[7o0000ohm`S`06ohm`S`03
o`000?moOgooOgmo00GoOgmo00?o0000oieRWOnMHYd02OnMHYd00ol0003oY5^TojAKY00<ojAKY005
o`000?nLHicoW6>LoiaSW?l000002_m]TVd00ol0003oW6>LoiaSW007oiaSW003o`000?n>LHkoSW6>
00KoSW6>00?o0000ogb3O?l000000_l000000on_D:oo0000ohMhQ`07ohMhQ`03o`000?nWF:OoYeRW
00SoYeRW00?o0000ojUFZOnYEZT02OnYEZT00ol0003oVfBKo`00000=ojQGZ0Co00001Oo<<l`00ol0
003oebSGomLXe`0;omLXe`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003oebSGomLXe`08omLXe`03
o`000?n?L8ooSg2?00OoSg2?00?o0000ogmoOomoOgl01?moOgl00ol0003oWF:MoieRW@09oieRW@03
o`000?nTFjCoY5^T00goY5^T00?o0000oiaSW?l000003?m]TVd:o`0000OoSW6>0ol00005ojm@[`03
o`000?n7N8OoQgR700KoQgR700?o0000ojMHYonWF:L01onWF:L00ol0003oZEJYojUFZ@0:ojUFZ@03
o`000?nXEjSoZ5NX00_oZ5NX00?o0000okA;]?ndBk@00_ndBk@3o`000003ol`cc?l0003oebSG00_o
ebSG0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omLXeooG:=L02OoG:=L00ol0003oSg2?ohm`S`07ohm`S`03o`00
0?moOgooOgmo00GoOgmo00?o0000oieRWOnMHYd01onMHYd00ol0003oY5^TojAKY00?ojAKY0;o0000
2om]TVd00ol0003oYUVVojIIYP07ojIIYP03o`000?n>LHkoSW6>00;oSW6>0ol00008ojm@[`03o`00
0?n7N8OoQgR700KoQgR700?o0000ojMHYonWF:L01onWF:L00ol0003oZEJYojUFZ@0:ojUFZ@03o`00
0?nXEjSoZ5NX00[oZ5NX00?o0000okA;]?ndBk@01_ndBk@00ol0003oebSGomLXe`08omLXe`?o0000
0_oR7N800ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omLXeooG:=L02OoG:=L00ol0003oSg2?ohm`
S`08ohm`S`03o`000?moOgooOgmo00CoOgmo00?o0000oieRWOnMHYd01onMHYd00ol0003oY5^TojAK
Y00>ojAKY004o`000?mmPWgoOH9mo`0000WoKI9]00?o0000ojIIY_nVFJH02OnVFJH01?l0003oSW6>
o`000?l0000<ojm@[`03o`000?n7N8OoQgR700KoQgR700?o0000ojMHYonWF:L01_nWF:L00ol0003o
ZEJYojUFZ@0;ojUFZ@03o`000?nXEjSoZ5NX00OoZ5NX0_l00009okA;]003o`000?oG:=OoebSG00Co
ebSG1?l00006on8MhP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003oebSGomLXe`09omLXe`03o`00
0?n?L8ooSg2?00SoSg2?00?o0000ogmoOomoOgl00omoOgl>o`0000goY5^T00?o0000ogf2OOmmPWd0
0_mmPWd00ol0003oKI9]offBK@05offBK@03o`000?nVFJKoYUVV00_oYUVV00?o0000ojm@[on_D:l0
3?n_D:l00ol0003oQgR7ohMhQ`06ohMhQ`03o`000?nWF:OoYeRW00GoYeRW00?o0000ojUFZOnYEZT0
3?nYEZT00ol0003oZ5NXojQGZ006ojQGZ003o`000?ndBkCo]4^d00[o]4^d00?o0000omLXeooG:=L0
0ol0000:on8MhP?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oG:=OoebSG00_oebSG00?o0000ohm`Son?L8l02?n?
L8l01Ol0003oOgmoogmoOomoOgoo000000_oU6^D00?o0000oeRWF?mHYeP00ol00009ojAKY003o`00
0?mmPWgoOH9m00CoOH9m00?o0000offBKOm]TVd00om]TVd00ol0003oYUVVojIIYP0<ojIIYP03o`00
0?n_D:oo[e2_00go[e2_00?o0000ohMhQon7N8L01_n7N8L00ol0003oYeRWojMHY`03ojMHY`?o0000
3OnYEZT00ol0003oZ5NXojQGZ005ojQGZ003o`000?ndBkCo]4^d00co]4^d0_l0000=on8MhP03o`00
0?ok1?_on`Ck00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oG:=OoebSG00_oebSG00?o0000ohm`Son?L8l02?n?
L8l4o`0000coU6^D00?o0000oeRWF?mHYeP00omHYeP3o`0000GoY5^T00?o0000ogf2OOmmPWd01_mm
PWd01Ol0003oKI9]offBKOm]TVgo000000ooYUVV00?o0000ojm@[on_D:l03On_D:l00ol0003oQgR7
ohMhQ`06ohMhQ`03o`000?nWF:OoYeRW00?o00000on:MHX00ol0003oZEJYojUFZ@0;ojUFZ@03o`00
0?nXEjSoZ5NX00?oZ5NX00?o0000okA;]?ndBk@03OndBk@00ol0003ohQgRon8MhP0;on8MhP03o`00
0?ok1?_on`Ck00Con`Ck0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omLXeooG:=L02_oG:=L3o`0000KoSg2?0ol0
0003ohacS003o`000?nDJiCoU6^D00[oU6^D00?o0000oeRWF?mHYeP01_mHYeP3o`000003ojAKY?l0
003oOH9m00WoOH9m00?o0000offBKOl000004?nVFJH00ol0003o[e2_ojm@[`0=ojm@[`03o`000?n7
N8OoQgR700OoQgR70_l00007ohYeRP03o`000?nYEZWoZEJY00[oZEJY00Co0000ojQGZ?nXEjSoZ5NX
0ol0000?okA;]003o`000?oR7N;ohQgR00_ohQgR00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omLXeooG:=L02_oG
:=L01?l0003o_4>loka3_?nl@k`2o`000004ohm`Sol0003o0000o`0000KoS7><00?o0000oiA[U?nD
Ji@02_nDJi@00ol0003oF:MHoeRWF009oeRWF003o`000?mmPWgoOH9m00[oOH9m00?o0000ojIIY_nV
FJH03onVFJH00ol0003o[e2_ojm@[`0>ojm@[`03o`000?n7N8OoQgR700KoQgR700?o0000ohYeR_n:
MHX01on:MHX4o`0000SoZEJY00Co0000ojQGZ?nXEjSo00000omoOgl2o`0000go]4^d00?o0000on8M
h_oR7N802_oR7N800ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omLXeooG:=L02OoG:=L00ol0003o
_4>loka3_004oka3_003o`000?n<LhcoS7><00OoS7><00?o0000oiA[U?nDJi@02OnDJi@00ol0003o
F:MHoeRWF00:oeRWF003o`000?mmPWgoOH9m00[oOH9m00?o0000ojIIY_nVFJH03onVFJH00ol0003o
[e2_ojm@[`0>ojm@[`03o`000?n7N8OoQgR700GoQgR700?o0000ohYeR_n:MHX02?n:MHX01?l0003o
VFJIoiUVVOnIIYT7o`0000;oZEJY0_l00006ogmoO`;o00003?ndBk@00ol0003ohQgRon8MhP09on8M
hP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003oebSGomLXe`08omLXe`03o`000?nl@kco_4>l00Go
_4>l00?o0000ohacS?n<Lh`02?n<Lh`00ol0003oU6^DoiA[U008oiA[U003o`000?mHYeSoF:MH00[o
F:MH00?o0000ogf2OOmmPWd02ommPWd00ol0003oYUVVojIIYP0>ojIIYP03o`000?n_D:oo[e2_00ko
[e2_1Ol00002ohMhQ`03o`000?n:MH[oRWF:00WoRWF:00?o0000oiUVVOnIIYT02?nIIYT3o`0000Wo
Ogmo0_l0000:okA;]003o`000?oR7N;ohQgR00SohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oG:=OoebSG00SoebSG00?o0000oka3_?nl@k`01onl@k`00ol0003oS7><ohacS007ohacS003o`00
0?nDJiCoU6^D00SoU6^D00?o0000oeRWF?mHYeP02_mHYeP00ol0003oOH9mogf2O@0:ogf2O@;o0000
3_nVFJH3o`0000go[e2_0ol00005ok9=/P;o00002on:MHX00ol0003oVFJIoiUVV@0;oiUVV@;o0000
2_moOgl2o`0000Oo]4^d0ol00009on8MhP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:oka3_003o`00
0?n<LhcoS7><00OoS7><00?o0000oiA[U?nDJi@02?nDJi@>o`0000WoOH9m0ol000000omOX5oo0000
ojIIYP0:ojIIYP?o00000_nfBKH00ol0003o[e2_ojm@[`09ojm@[`;o00002OnbCK800ol0003oRWF:
ohYeRP09ohYeRP03o`000?nIIYWoVFJI00_oVFJI00?o0000ojEJYOl000002omoOgl2o`0000Co]4^d
00Co0000omPWf?oH9mSof2OH0_l00007on8MhP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003o_4>l
oka3_009oka3_003o`000?n<LhcoS7><00KoS7><00?o0000oiA[U?nDJi@02?nDJi@00ol0003oIiQW
ofNHI`0:ofNHI`03o`000?mmPWgoOH9m00CoOH9m0ol00005oenPG`03o`000?nVFJKoYUVV00CoYUVV
1?l00006okI9]P03o`000?n_D:oo[e2_00Ko[e2_0_l0000;ok9=/P03o`000?n:MH[oRWF:00WoRWF:
00?o0000oiUVVOnIIYT02_nIIYT01Ol0003oYEZUojEJYOnUFZGo000000coOgmo0_l000000ondBkCo
0000omPWf005omPWf003o`000?oR7N;ohQgR00?ohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?nl@kco_4>l00So_4>l00?o0000ohacS?n<Lh`01_n<Lh`00ol0003oU6^DoiA[U007oiA[U003o`00
0?mWV6OoIiQW00_oIiQW00?o0000ogf2OOmmPWd00_mmPWd2o`0000WoGj1O00?o0000ojIIY_nVFJH0
0ol0000;okI9]P03o`000?n_D:oo[e2_00;o[e2_0ol0000>ok9=/P03o`000?n:MH[oRWF:00OoRWF:
00?o0000oiUVVOnIIYT02onIIYT00ol0003oYEZUojEJY@02ojEJY@03o`000?moOgooOgmo00_oOgmo
00?o0000omPWf?oH9mP01_oH9mP2o`0000?ohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?nl
@kco_4>l00Oo_4>l00?o0000ohacS?n<Lh`01on<Lh`00ol0003oU6^DoiA[U005oiA[U0?o00003OmW
V6L4o`0000_oGj1O0ol0000?okI9]P04o`000?n_D:oo0000o`00017o/Tfb00?o0000ohYeR_n:MHX0
1on:MHX00ol0003oVFJIoiUVV@0:oiUVV@03o`000?nUFZGoYEZU00CoYEZU00?o0000ogmoOomoOgl0
1omoOgl3o`0000_of2OH1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oka3_?nl@k`02?nl@k`00ol0003oS7><ohac
S006ohacS003o`000?nDJiCoU6^D00;oU6^D0ol00003oh=lP`03o`000?mWV6OoIiQW00[oIiQW00?o
0000oenPGomOX5l02omOX5l00ol0003oJYEZo`00000AokI9]P03o`000?nbCK;o/Tfb017o/Tfb00?o
0000ohYeR_n:MHX01on:MHX00ol0003oVFJIoiUVV@0:oiUVV@03o`000?nUFZGoYEZU00GoYEZU00Co
0000ogmoOomoOgooOgmo1Ol00002oi9]TP03o`000?oH9mSof2OH00Wof2OH00Co0000ooX5n_oj1O[o
nPGj0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oka3_?nl@k`01onl@k`00ol0003oS7><ohacS005ohacS0?o0000
00?oU6^Do`000?l000001on3O8<00ol0003oIiQWofNHI`08ofNHI`?o00002_mOX5l2o`0000;oJYEZ
00?o0000okI9]_nfBKH03onfBKH00ol0003o/Tfbok9=/P0Aok9=/P03o`000?n:MH[oRWF:00OoRWF:
00?o0000oiUVVOnIIYT02OnIIYT00ol0003oYEZUojEJY@07ojEJY@?o00001onBKI800ol0003of2OH
omPWf009omPWf003o`000?oj1O[onPGj00ConPGj0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oka3_?nl@k`01onl
@k`4o`0000;oS7><0_l00003oiiQWP03o`000?n3O8?oPgb300SoPgb30_l00006ofNHI`;o00000om^
TFh00ol0003oGj1OoenPG`06oenPG`03o`000?mZUF[oJYEZ00?oJYEZ00?o0000okI9]_nfBKH03_nf
BKH00ol0003o/Tfbok9=/P0Bok9=/P03o`000?n:MH[oRWF:00GoRWF:00?o0000oiUVVOnIIYT02OnI
IYT00ol0003oYEZUojEJY@08ojEJY@03o`000?nBKI;oTVfB00OoTVfB00?o0000omPWf?oH9mP02?oH
9mP00ol0003onPGjooX5nP07ooX5nP;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?nl@kco_4>l00Co_4>l0_l00004
om4^d@;o00001OnNHIh00ol0003oPgb3oh=lP`0:oh=lP`03o`000?mWV6OoIiQW00;oIiQW00?o0000
ofjAK_m^TFh01?m^TFh00ol0003oGj1OoenPG`04oenPG`03o`000?mZUF[oJYEZ00CoJYEZ00?o0000
okI9]_nfBKH03_nfBKH00ol0003o/Tfbok9=/P0Bok9=/P[o00002_nIIYT00ol0003oYEZUojEJY@08
ojEJY@03o`000?nBKI;oTVfB00OoTVfB00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP09
ooX5nP?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_4>loka3_?nl@k`2o`0000OodBkA00?o0000oiiQW_nNHIh01?nNHIh0
0ol0003oPgb3oh=lP`0:oh=lP`04o`000?mWV6Oo0000o`0000SoKY5^00Co0000oenPGomOX5ooGj1O
0_l00007ofZEJP03o`000?nfBKKo]TVf00ko]TVf00?o0000ok9=/_nbCK804_nbCK800ol0003oUFZE
oiEZU@07oiEZU@03o`000?nIIYWoVFJI00KoVFJI00?o0000ojEJYOnUFZD02_nUFZD00ol0003oTVfB
oi9]TP06oi9]TP03o`000?oH9mSof2OH00Sof2OH00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?nl
@kco0000o`0000WodBkA00?o0000oiiQW_nNHIh01?nNHIh00ol0003oPgb3oh=lP`0;oh=lP`03o`00
0?m^TFkoKY5^00WoKY5^00?o0000oenPGol000002OmZUFX00ol0003o]TVfokI9]P0>okI9]P;o0000
4_nbCK800ol0003oUFZEoiEZU@09oiEZU@;o00001_nIIYT00ol0003oYEZUojEJY@0:ojEJY@03o`00
0?nBKI;oTVfB00KoTVfB00?o0000omPWf?oH9mP02?oH9mP00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om4^dOoA;]402OoA;]400ol0003oWV6NoiiQWP05oiiQWP03o`000?n3O8?oPgb300[oPgb300?o
0000ofjAK_m^TFh02_m^TFh2o`0000WoJYEZ00?o0000okI9]_nfBKH03_nfBKH00ol0003oXebSo`00
0002o`0000oo/Tfb00?o0000oiEZUOnEJYD02onEJYD00ol0003oVFJIoiUVV@03o`0000goYEZU00?o
0000oi9]T_nBKI801_nBKI800ol0003of2OHomPWf007omPWf003o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odBkAom4^d@09om4^d@03o`000?nNHIkoWV6N00GoWV6N00?o0000oh=lPon3O8<02On3O8<2
o`0000_oKY5^0_l0000;ofZEJP03o`000?nfBKKo]TVf00co]TVf00?o0000oj=LXonSG:<00onSG:<3
o`0000co/Tfb00?o0000oiEZUOnEJYD03?nEJYD2o`0000;oTFjA00?o0000ojEJYOnUFZD03?nUFZD0
0ol0003oTVfBoi9]TP05oi9]TP03o`000?oH9mSof2OH00Oof2OH00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oA;]7odBkA00[odBkA00?o0000oiiQW_nNHIh01_nNHIh00ol0003oPgb3oh=lP`07oh=l
P`03o`000?m_T6oo000000[oKY5^00Co0000oe^TFomKY5_o00002_mZUFX00ol0003o]TVfokI9]P0<
okI9]P03o`000?nSG:?oXebS00KoXebS0_l00008ok9=/P;o00003onEJYD00ol0003oTFjAoi5^T@02
oi5^T@03o`000?nUFZGoYEZU00_oYEZU00?o0000oi9]T_nBKI801OnBKI800ol0003of2OHomPWf007
omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odBkAom4^d@0:om4^d@03o`000?nNHIkoWV6N
00KoWV6N00?o0000oh=lPon3O8<01_n3O8<01Ol0003oKi1_ofn@Kom_T6oo000000SoKY5^00?o0000
oe^TFomKY5/00_mKY5/00ol0003oJYEZofZEJP06ofZEJPCo00003?nfBKH00ol0003oXebSoj=LX`08
oj=LX`?o00000_nbCK83o`000003oi9]T_l0003oUFZE00goUFZE00?o0000oi5^TOnAKY401?nAKY40
0ol0003oYEZUojEJY@0:ojEJY@03o`000?nBKI;oTVfB00GoTVfB00?o0000omPWf?oH9mP01_oH9mP0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]402ooA;]400ol0003oWV6NoiiQWP07oiiQ
WP03o`000?n3O8?oPgb300?oPgb30_l00005ofn@K`03o`000?m^TFkoKY5^00CoKY5^00?o0000oe^T
FomKY5/00omKY5/00ol0003oJYEZofZEJP05ofZEJP03o`000?n9MXWoRGJ900;oRGJ90ol00007okI9
]P;o00003_nSG:<2o`0000GoTVfB00?o0000oiEZUOnEJYD02_nEJYD00ol0003oTFjAoi5^T@05oi5^
T@03o`000?nUFZGoYEZU00_oYEZU00?o0000oi9]T_nBKI801?nBKI800ol0003of2OHomPWf006omPW
f003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odBkAom4^d@0;om4^d@03o`000?nNHIkoWV6N00Oo
WV6N00?o0000oh=lPon3O8<00_n3O8<00ol0003oKi1_ofn@K`06ofn@K`03o`000?m^TFkoKY5^00;o
KY5^00?o0000oe^TFomKY5/01OmKY5/00ol0003oJYEZofZEJP02ofZEJP;o00002?n9MXT3o`0000;o
]TVf0_l000000onAKY7o0000oj=LX`0=oj=LX`03o`000?nBKI;oTVfB00GoTVfB00?o0000oiEZUOnE
JYD02?nEJYD00ol0003oTFjAoi5^T@07oi5^T@03o`000?nUFZGoYEZU00[oYEZU00?o0000oi9]T_nB
KI801?nBKI800ol0003of2OHomPWf006omPWf003o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkA
om4^d@0<om4^d@03o`000?nNHIkoWV6N00SoWV6N00Co0000oh=lPon3O8?o00002Om_T6l01Ol0003o
KY5^ofjAK_m^TFko000000SoFjAK00Go0000ofZEJ_mZUF[oJYEZo`00000=ohUfR@;o00001?nAKY40
0ol0003oXebSoj=LX`0;oj=LX`03o`000?nBKI;oTVfB00KoTVfB00?o0000oiEZUOnEJYD01onEJYD0
0ol0003oTFjAoi5^T@08oi5^T@Co00002?nUFZD00ol0003oTVfBoi9]TP04oi9]TP03o`000?oH9mSo
f2OH00Kof2OH00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00_odBkA0ol00009oiiQ
WP03o`000?n3O8?o000000_oKi1_00?o0000ofjAK_l000002_mKY5/00ol0003oJYEZo`00000?ohUf
R@03o`000?nAKY7oTFjA00;oTFjA00?o0000oj=LXonSG:<02onSG:<00ol0003oTVfBoi9]TP06oi9]
TP03o`000?nEJYGoUFZE00KoUFZE00?o0000oi5^TOnAKY402OnAKY401?l0003oYEZUojEJYOnUFZD7
o`0000;oYEZU00?o0000oi9]T_nBKI800onBKI800ol0003of2OHomPWf005omPWf003o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oA;]7odBkA00SodBkA0ol00003okY5^P03o`000?nNHIkoWV6N00OoWV6N00?o0000ofn@
Kom_T6l02om_T6l00ol0003oFjAKoe^TF`0:oe^TF`03o`000?n9MXWoRGJ900goRGJ900?o0000oi5^
TOnAKY401?nAKY400ol0003oXebSoj=LX`09oj=LX`03o`000?nBKI;oTVfB00SoTVfB00?o0000oiEZ
UOnEJYD00onEJYD2o`0000coTFjA00?o0000ojEJYOnUFZD02?nUFZD<o`0000?of2OH0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om4^dOoA;]401_oA;]43o`0000Oo^TFj00?o0000oiiQW_nNHIh01_nNHIh00ol0003o
Ki1_ofn@K`0;ofn@K`03o`000?mKY5_oFjAK00WoFjAK0_l0000>ohUfR@03o`000?nAKY7oTFjA00Go
TFjA00?o0000oj=LXonSG:<02OnSG:<00ol0003oTVfBoi9]TP09oi9]TP03o`000?nEJYGo000000;o
00000_n9MXT00ol0003oTFjAoi5^T@08oi5^T@03o`000?nUFZGoYEZU00coYEZU00?o0000om/TfooK
9=/01_oK9=/3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odBkAom4^d@03om4^d@?o00002onjAKX00ol0003oWV6N
oiiQWP04oiiQWP03o`000?m_T6ooKi1_00_oKi1_0ol00007oe^TF`?o000000?oOH9mo`000?n9MXT0
3On9MXT00ol0003oTFjAoi5^T@06oi5^T@03o`000?nSG:?oXebS00SoXebS00?o0000oi9]T_nBKI80
2_nBKI800ol0003oRGJ9ohUfR@04ohUfR@03o`000?nAKY7oTFjA00OoTFjA00?o0000ojEJYOnUFZD0
2onUFZD00ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om4^dOl0
003o0000o`0000oo^TFj00?o0000oiiQW_nNHIh00onNHIh>o`0000?oKi1_0_l00002oe^TF`?o0000
1OmmPWd00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?nAKY7oTFjA00OoTFjA00?o0000oj=LXonSG:<0
2?nSG:<00ol0003oTVfBoi9]TP0:oi9]TP03o`000?n9MXWoRGJ900GoRGJ900?o0000oi5^TOnAKY40
1_nAKY400ol0003oYEZUojEJY@0;ojEJY@03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o^TFj00?o0000oiiQW_nNHIh00_nNHIh00ol0003oHIiQof6N
H@0:of6NH@03o`000?m_T6ooKi1_00?oKi1_0_l00009ogf2O@03o`000?n9MXWoRGJ900WoRGJ900?o
0000oi5^TOnAKY402?nAKY42o`0000SoXebS00?o0000oi9]T_nBKI802OnBKI800ol0003oRGJ9ohUf
R@07ohUfR@03o`000?nAKY7oTFjA00CoTFjA00?o0000ojEJYOnUFZD02onUFZD00ol0003ofbCKom/T
f`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o^TFjokY5^P0?okY5^P?o000000?oWV6N
o`000?mQWV402omQWV400ol0003oKi1_ofn@K`04ofn@K`03o`000?mmPWgoOH9m00WoOH9m00?o0000
ohUfROn9MXT01on9MXT00ol0003oTFjAoi5^T@09oi5^T@04o`000?n<Lhco0000o`0000KoXebS00?o
0000oi9]T_nBKI802OnBKI800ol0003oRGJ9ohUfR@08ohUfR@03o`000?nAKY7oTFjA00?oTFjA00?o
0000ojEJYOnUFZD02onUFZD00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o^TFjokY5^P0<okY5^P;o00000onaC[42o`0000coHIiQ00?o0000ofn@Kom_T6l01?m_T6l0
0ol0003oOH9mogf2O@0:ogf2O@Wo00002onAKY400ol0003oS7><ohacS002ohacS0?o00000_nSG:<0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?n9MXWoRGJ900WoRGJ900?o0000oi5^TOnAKY400_nAKY40
0ol0003oYEZUojEJY@0:ojEJY@03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_njAKX2o`0000Go/Dja00?o0000ohacS?l000002_mQWV400ol0003oKi1_ofn@K`06ofn@
K`03o`000?mmPWgoOH9m00WoOH9m00?o0000ogf2OOmmPWd01OmmPWd00ol0003oTFjAoi5^T@09oi5^
T@03o`000?n<LhcoS7><00GoS7><0ol00009oi9]TP?o00003On9MXT01Ol0003oTFjAoi5^TOnAKY7o
000000coYEZU00?o0000om/TfooK9=/02OoK9=/00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000okY5
^_njAKX01OnjAKX2o`0000Oo/Dja00Co0000ohacS?n<Lhco00002OmQWV400ol0003oKi1_ofn@K`06
ofn@K`03o`000?mmPWgoOH9m00SoOH9m00?o0000ogf2OOmmPWd01ommPWd00ol0003oTFjAoi5^T@07
oi5^T@03o`000?n<LhcoS7><00SoS7><0ol00002oi9]TPGo00000_mRWF800ol0003oRGJ9ohUfR@0<
ohUfR@03o`000?nAKY7o000000coYEZU00?o0000om/TfooK9=/02_oK9=/00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000okY5^_njAKX00_njAKX2o`0000So/Dja00?o0000ohacS?n<Lh`00_n<Lh`5o`00
00CoHIiQ00?o0000ofn@Kom_T6l01_m_T6l00ol0003oOH9mogf2O@08ogf2O@03o`000?mmPWgoOH9m
00OoOH9m00?o0000oi5^TOnAKY401onAKY400ol0003oS7><ohacS008ohacS003o`000?mSW6?oHiaS
00;o00002?mRWF800ol0003oRGJ9ohUfR@0<ohUfR@Co00002_nUFZD00ol0003ofbCKom/Tf`0:om/T
f`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o^TFjo`000?l0000:ok5>/@03o`000?n<LhcoS7><
00;oS7><00?o0000ocO8=olgb3L00_lgb3L4o`0000WoKi1_00?o0000ogf2OOmmPWd02?mmPWd00ol0
003oOH9mogf2O@08ogf2O@03o`000?nAKY7oTFjA00GoTFjA00?o0000ohacS?n<Lh`02?n<Lh`01Ol0
003oHiaSof>LHomSW6?o000000[oHYeR0ol0000;ohUfR@04o`000?o6>LKoaSW6olHiaPCo00001OnU
FZD00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o/Djaok5>/@0:
ok5>/@03o`000?n<LhcoS7><00?oS7><00?o0000ocO8=olgb3L01?lgb3L00ol0003oKi1_ofn@K`07
ofn@K`03o`000?mmPWgoOH9m00KoOH9m0_l0000;ogf2O@03o`000?nAKY7oTFjA00GoTFjA00?o0000
ohacS?n<Lh`02?n<Lh`00ol0003oHiaSof>LH`02of>LH`03o`000?mRWF;oHYeR00OoHYeR00?o0000
ohebSOn=LXd01?l00006ohUfR@03o`000?o6>LKoaSW600KoaSW60ol00002ojEJY@03o`000?oK9=_o
fbCK00_ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?naC[7o/Dja00Wo/Dja00?o0000ohac
S?n<Lh`01?n<Lh`00ol0003o=lPgocO8=`05ocO8=`03o`000?m_T6ooKi1_00OoKi1_00?o0000ogf2
OOmmPWd00_mmPWd3o`000003ohMhQol0003oOH9m00[oOH9m00?o0000oi5^TOnAKY401OnAKY400ol0
003oS7><ohacS007ohacS003o`000?mSW6?oHiaS00?oHiaS00?o0000of:MH_mRWF801omRWF800ol0
003oSG:=ohebS@04ohebS@?o00000_n9MXT00ol0003oaSW6olHiaP0:olHiaP;o00003_oK9=/00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok5>/OnaC[402OnaC[400ol0003oS7><ohacS004ohacS003
o`000?lgb3Oo=lPg00Ko=lPg0_l00007ofn@K`03o`000?mmPWgo000000;o00001On7N8L00ol0003o
OH9mogf2O@08ogf2O@?o00001?nAKY400ol0003oS7><ohacS008ohacS003o`000?mSW6?oHiaS00Co
HiaS00?o0000of:MH_mRWF801_mRWF800ol0003oSG:=ohebS@07ohebS@;o00003_o6>LH00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djaok5>/@08ok5>/@03o`00
0?n<LhcoS7><00GoS7><00?o0000ocO8=olgb3L01?lgb3L00ol0003oKI9]offBK@03o`0000CoKi1_
0_l00008ohMhQ`03o`000?mmPWgoOH9m00OoOH9m00Co0000ojIIY_nVFJKoYUVV0ol000000onAKY7o
0000ohacS009ohacS003o`000?mSW6?oHiaS00CoHiaS00?o0000of:MH_mRWF801OmRWF800ol0003o
SG:=ohebS@09ohebS@03o`000?o6>LKoaSW600goaSW600?o0000om/TfooK9=/02_oK9=/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok5>/OnaC[401onaC[400ol0003oS7><ohacS006ohacS003o`00
0?lgb3Oo=lPg00?o=lPg00?o0000offBKOm]TVd01?m]TVd2o`000003ofn@Kol0003oQgR700[oQgR7
00?o0000ogf2OOmmPWd01OmmPWd00ol0003oYUVVojIIYP05ojIIYP03o`000?n<LhcoS7><00OoS7><
0ol00007of>LH`03o`000?mRWF;oHYeR00CoHYeR00?o0000ohebSOn=LXd02On=LXd00ol0003oaSW6
olHiaP0=olHiaP03o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?na
C[7o/Dja00Go/Dja0ol00009ohacS005o`000?lgb3Oo=lPgocO8=ol000002Om]TVd00ol0003oQgR7
ohMhQ`0;ohMhQ`03o`000?mmPWgoOH9m00?oOH9m00?o0000ojIIY_nVFJH01_nVFJH00ol0003oS7><
ohacS006ohacS005o`000?n>LHkoSW6>ohiaS_l000001omSW6<00ol0003oHYeRof:MHP03of:MHP03
o`000?n=LXgoSG:=00WoSG:=00?o0000olHia_o6>LH03_o6>LH00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djao`000004o`0000;occ3?00?o0000ohacS?n<Lh`0
1on<Lh`01?l0003o=lPgocO8=ol00009offBK@;o00003On7N8L00ol0003oOH9mogf2O@02ogf2O@03
o`000?nVFJKoYUVV00SoYUVV00?o0000ohacS?n<Lh`00on<Lh`2o`0000GoSW6>00?o0000of>LHomS
W6<01?mSW6<00ol0003oHYeRof:MHP03of:MHP03o`000?n=LXgoSG:=00WoSG:=00?o0000olHia_o6
>LH03_o6>LH00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Socc3?
00?o0000ohacS?n<Lh`01_n<Lh`00ol0003o=lPgo`000009offBK@04o`000?nEJYGoUFZEo`0000go
QgR700Co0000ogf2OOmmPWgo00003?nVFJH01Ol0003oS7><ohacS?n<Lhco000000SoSW6>0_l00005
of>LH`03o`000?mRWF;oHYeR00;oHYeR00?o0000ohebSOn=LXd02On=LXd00ol0003oaSW6olHiaP0>
olHiaP03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?
00Oocc3?00?o0000ohacS?n<Lh`01on<Lh`00ol0003oKI9]offBK@07offBK@03o`000?nEJYGoUFZE
00;oUFZE00?o0000ohMhQon7N8L02_n7N8L00ol0003oOH9mo`00000>ojIIYP03o`000?n<Lhco0000
00_oSW6>00?o0000of>LHomSW6<00_mSW6<01Ol0003oHYeRof:MH_mRWF;o000000coSG:=00?o0000
olHia_o6>LH03_o6>LH3o`0000WofbCK00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000ohacS?n<Lh`01_n<Lh`00ol0003oKI9]offBK@06offBK@03o`000?nEJYGoUFZE
00?oUFZE00?o0000ohMhQon7N8L02on7N8L00ol0003oYUVVojIIYP0>ojIIYP03o`000?n>LHkoSW6>
00_oSW6>0_l00003of>LH`04o`000?mRWF;oHYeRo`0000[oSG:=0ol0000>olHiaP;o00000ooj1OX2
o`0000OofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o?<<oocc3?00[occ3?00?o0000ohac
S?n<Lh`01?n<Lh`00ol0003oKI9]offBK@06offBK@03o`000?nEJYGoUFZE00GoUFZE00?o0000ohMh
Qon7N8L01on7N8L3o`00017oYUVV00?o0000ohiaS_n>LHh03On>LHh01Ol0003oHiaSof>LHol0003o
HYeR00Co00000on=LXd5o`0000;o_D:m00?o0000olHia_o6>LH02_o6>LH2o`0000OonPGj0_l00004
om/Tf`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003occ3?oll`c`0;oll`c`03o`000?n<LhcoS7><
00CoS7><00?o0000offBKOm]TVd01Om]TVd00ol0003oUFZEoiEZU@06oiEZU@03o`000?n7N8OoQgR7
00CoQgR70ol00002oi=/T`03o`000?nVFJKoYUVV00ooYUVV0_l0000?ohiaSP04o`000?mSW6?o0000
o`0000CoQ7^40ol00008oke2_@03o`000?o6>LKoaSW600OoaSW60_l0000;ooX5nP;o00000_oK9=/0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000oll`coo?<<l03?o?<<l6o`0000OoKI9]00?o0000oiEZ
UOnEJYD02?nEJYD00ol0003oQgR7ohMhQ`03o`0000KoTfbC00?o0000ojIIY_nVFJH03OnVFJH01?l0
003oWf2OoimPWol0000?ohiaSP03o`000?n4NhCoQ7^400GoQ7^400?o0000oke2_Onm@[d02?nm@[d0
0ol0003oaSW6olHiaP05olHiaP03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o?<<l00ol0003oSW6>ohiaSP04ohia
SP03o`000?m]TVgoKI9]00?oKI9]00?o0000oiEZUOnEJYD02_nEJYD2o`0000[oTfbC00?o0000ojII
Y_nVFJH02onVFJH00ol0003oWf2OoimPW`02oimPW`03o`000?n>LHkoSW6>00_oSW6>0_l00007ohAk
Q003o`000?nm@[go_D:m00Wo_D:m00?o0000olHia_o6>LH00_o6>LH2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000oll`coo?<<l02oo?<<l00ol0003oSW6>ohiaSP06ohiaSP05o`000?m]TVgoKI9]offB
KOl000003OnEJYD00ol0003oTfbCoi=/T`0:oi=/T`03o`000?nVFJKoYUVV00WoYUVV00?o0000oimP
WonOH9l01?nOH9l00ol0003oSW6>ohiaSP08ohiaSP;o000000?oIYUVo`000?n4Nh@01on4Nh@00ol0
003o_D:moke2_@09oke2_@04o`000?o6>LKo0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?o?<<oocc3?
00Wocc3?00?o0000ohiaS_n>LHh02?n>LHh00ol0003oKI9]o`00000=oiEZU@03o`000?nCK9?oTfbC
00_oTfbC00?o0000ojIIY_nVFJH02?nVFJH00ol0003oWf2OoimPW`06oimPW`03o`000?n>LHkoSW6>
00GoSW6>0_l00003ofJIIP03o`000?n4NhCoQ7^400KoQ7^400?o0000oke2_Onm@[d02_nm@[d00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003occ3?oll`c`07oll`c`03o`000?n>LHkoSW6>00[oSW6>00?o0000oiEZUOnE
JYD03?nEJYD00ol0003oTfbCoi=/T`0<oi=/T`03o`000?nVFJKoYUVV00KoYUVV00?o0000oimPWonO
H9l02?nOH9l00ol0003oSW6>ohiaSP02ohiaSP;o00001_mVVFH00ol0003oQ7^4ohAkQ005ohAkQ003
o`000?nm@[go_D:m00[o_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o?<<oocc3?00Gocc3?
00?o0000ohiaS_n>LHh03?n>LHh2o`0000coUFZE00?o0000oi=/TonCK9<03OnCK9<00ol0003oYUVV
ojIIYP04ojIIYP03o`000?nOH9ooWf2O00[oWf2O00Co0000ohiaS_l0003o00002?mVVFH00ol0003o
Q7^4ohAkQ006ohAkQ003o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_o?<<l00ol0003oSW6>ohiaSP0=ohiaSP03o`000?n:MH[o000000;o00002?nEJYD00ol0003oTfbC
oi=/T`0?oi=/T`Ko00003_nOH9l00ol0003oIYUVofJIIP08ofJIIP03o`000?n4NhCoQ7^400KoQ7^4
00?o0000oke2_Onm@[d02Onm@[d00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000ol`cc?o<<lcoc3?<
0_l0000?ohiaSP03o`000?n:MH[oRWF:00?oRWF:0ol00005oiEZU@;o00004?nCK9<01_l0003oPWf2
oh9mP_l0003oK9=/o`0000koWf2O00?o0000ofJII_mVVFH02OmVVFH00ol0003oQ7^4ohAkQ005ohAk
Q003o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000ol`cc?o<<l`00oo<<l`00ol0003o
SW6>ohiaSP0=ohiaSP03o`000?n:MH[oRWF:00KoRWF:0ol000001?nEJYGo0000ohUfROn9MXT3o`00
00coTfbC00Go0000oh9mP_n2OH;oPWf2o`000002ofbCK003o`000?nOH9ooWf2O00_oWf2O00?o0000
ofJII_mVVFH02OmVVFH00ol0003oQ7^4ohAkQ006ohAkQ003o`000?nm@[go_D:m00So_D:m0_l0000A
ooX5nP?o000000?onPGjo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003oc3?<ol`cc004ol`cc0oo00003?n:MHX00ol0003oRGJ9ohUfR@04ohUf
R@?o00002?nCK9<00ol0003oPWf2oh9mPP02oh9mPP05o`000?m/TfcoK9=/ofbCK?l000003?nOH9l0
0ol0003oIYUVofJIIP09ofJIIP03o`000?n4NhCoQ7^400GoQ7^43?l00002omhQgP;o00003Ooj1OX2
o`0000GonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003oc3?<ol`cc005ol`cc003o`000?mhQgSoN8Mh00_oN8Mh00?o0000ohYe
R_n:MHX02_n:MHX00ol0003oRGJ9ohUfR@07ohUfR@;o00001OnCK9<00ol0003oPWf2oh9mPP03oh9m
PP03o`000?m/TfcoK9=/00;oK9=/00?o0000oimPWonOH9l02OnOH9l00ol0003oIYUVofJIIP0:ofJI
IP03o`000?n4NhCoQ7^400?oQ7^400?o0000ohAkQ?n4Nh@02On4Nh@00ol0003ogR7NomhQgP02omhQ
gP;o00002Ooj1OX2o`0000OonPGj00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oc3?<ol`cc006ol`cc003o`000?mhQgSoN8Mh00[o
N8Mh00?o0000ohYeR_n:MHX02on:MHX00ol0003oRGJ9ohUfR@09ohUfR@?o000000?oTfbCo`000?n2
OH801On2OH800ol0003oK9=/ofbCK003ofbCK003o`000?nOH9ooWf2O00SoWf2O3_l00003ohAkQ0;o
00002on4Nh@00ol0003ogR7NomhQgP05omhQgP03o`000?oj1O[onPGj00?onPGj0ol00009ooX5nP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oRWF:o`00000;ogR7N003o`000?n:MH[oRWF:00[oRWF:
0_l0000>ohUfR@03o`000?n2OH;oPWf200GoPWf200?o0000ofbCK?m/Tf`00om/Tf`00ol0003oWf2O
oimPW`08oimPW`03o`000?n=LXgoSG:=00_oSG:=00?o0000ohAkQ?l000003On4Nh@00ol0003ogR7N
omhQgP06omhQgP;o000000?onPGjo`000?l000003Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o<<lcoc3?<00Koc3?<00Co
0000ohYeR_n:MH[o00002_mhQgP00ol0003oRWF:ohYeRP09ohYeRP03o`000?n5NXGo000000koRGJ9
00?o0000oh9mP_n2OH801On2OH800ol0003oK9=/ofbCK004ofbCK003o`000?nOH9ooWf2O00KoWf2O
00?o0000ohebSOn=LXd03On=LXd00ol0003oQ7^4ohAkQ00<ohAkQ003o`000?oN8MkogR7N00SogR7N
00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o<<lcoc3?<00Goc3?<00?o0000ohYeR_n:MHX00_n:
MHX00ol0003oN8MhogR7N006ogR7N003o`000?n:MH[oRWF:00SoRWF:0_l00003ohEjQ@03o`000?n9
MXWoRGJ900_oRGJ900?o0000oh9mP_n2OH801On2OH800ol0003oK9=/ofbCK005ofbCK003o`000?nO
H9ooWf2O00GoWf2O00?o0000ohebSOn=LXd03On=LXd00ol0003oQ7^4ohAkQ00;ohAkQ003o`000?oN
8MkogR7N00WogR7N00?o0000ooX5n_oj1OX03Ooj1OX00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o<<lcoc3?<00Koc3?<00?o0000
ohYeR_n:MHX00on:MHX00ol0003oN8MhogR7N005ogR7N003o`000?n:MH[oRWF:00OoRWF:00?o0000
ohEjQOn5NXD00on5NXD00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?n2OH;oPWf200KoPWf200?o0000
ofbCK?m/Tf`01_m/Tf`00ol0003oWf2OoimPW`04oimPW`03o`000?n=LXgoSG:=00goSG:=3ol0000;
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o<<lcoc3?<00Koc3?<00?o0000ohYeR_n:MHX01On:MHX00ol0
003oN8MhogR7N004ogR7N003o`000?n:MH[oRWF:00GoRWF:0_l00006ohEjQ@03o`000?n9MXWoRGJ9
00WoRGJ90_l00008oh9mPP03o`000?m/TfcoK9=/00KoK9=/1Ol000000onOH9oo0000ohebS@0?oheb
S@03o`000?mnPGkoOX5n00_oOX5n00?o0000omhQg_oN8Mh02OoN8Mh00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o<<lcoc3?<00Koc3?<00?o0000ohYeR_n:MHX01_n:MHX00ol0003o
N8MhogR7N004o`0000KoRWF:00?o0000ohEjQOn5NXD01on5NXD00ol0003oRGJ9ohUfR@05ohUfR@?o
000000?oMXUfo`000?n2OH801on2OH800ol0003oK9=/ofbCK005ofbCK003o`000?nPGj3oX5nP00?o
X5nP0_l0000?ohebS@;o00003OmnPGh00ol0003ogR7NomhQgP08omhQgP03o`000?oj1O[onPGj00go
nPGj00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000Woc3?<00?o0000ohYeR_n:MHX01on:MHX2o`0000CoZEJY00Co0000ohYeR_n:MH[o
RWF:0_l0000:ohEjQ@03o`000?n9MXWoRGJ900;oRGJ90ol00005ogJ9MP03o`000?n2OH;oPWf200Go
PWf200?o0000ofbCK?m/Tf`01?m/Tf`00ol0003oX5nPoj1OX006oj1OX003o`000?n=LXgoSG:=00[o
SG:=0_l00002ohiaSP03o`000?mnPGkoOX5n00[oOX5n00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000ol`cc?o<<l`01_o<<l`00ol0003oRWF:ohYeRP08ohYeRP03o`00
0?nYEZWoZEJY00CoZEJY00?o0000ohYeR_l000003?n5NXD00ol0003oRGJ9o`000002o`0000WoMXUf
00?o0000oh9mP_n2OH801?n2OH800ol0003oK9=/ofbCK003ofbCK003o`000?nPGj3oX5nP00SoX5nP
1_l00004ohebS@;o00001On>LHh00ol0003oOX5nogj1OP09ogj1OP03o`000?oN8MkogR7N00SogR7N
00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o<<lcoc3?<00Goc3?<00?o0000ohYeR_n:MHX01on:
MHX00ol0003oZEJYojUFZ@06ojUFZ@03o`000?n5NXGoQGZ500coQGZ500?o0000ogJ9M_mfRGH02_mf
RGH00ol0003oPWf2oh9mPP04oh9mPP04o`000?m/TfcoK9=/ofbCK0;o00002onPGj000ol0003oVFJI
oiUVV@03oiUVV@Co00002?n>LHh00ol0003oOX5nogj1OP08ogj1OP03o`000?oN8MkogR7N00OogR7N
0ol0000=ooX5nP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000ol`cc?o<<l`00oo<<l`00ol0003oRWF:ohYeRP07ohYeRP03o`000?nY
EZWoZEJY00OoZEJY00?o0000ohEjQOn5NXD03?n5NXD00ol0003oMXUfogJ9MP0;ogJ9MP03o`000?n2
OH;oPWf200?oPWf200Co0000ofbCK?m/Tfco00003OnPGj000ol0003oVFJIoiUVV@06oiUVV@03o`00
0?n>LHkoSW6>00OoSW6>00?o0000ogj1O_mnPGh01omnPGh00ol0003ogR7NomhQgP06omhQgP04o`00
0?ok1?_on`Ckoo/4n`;o00002ooj1OX00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o<<lcoc3?<00;oc3?<00?o0000ohYeR_n:MHX0
1_n:MHX00ol0003oZEJYojUFZ@09ojUFZ@03o`000?n5NXGoQGZ500WoQGZ50_l0000>ogJ9MP?o0000
0on2OH800ol0003oK9=/o`00000=oj1OX003o`000?nIIYWoVFJI00OoVFJI00?o0000ohiaS_n>LHh0
2?n>LHh:o`0000KogR7N0_l00006oo/4n`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoRWF:00?o
0000ojUFZOnYEZT02_nYEZT00ol0003oQGZ5ohEjQ@06ohEjQ@;o000000?oQGZ5o`000?mfRGH02omf
RGH2o`0000?oXEjQ1Ol0000>oj1OX003o`000?nIIYWoVFJI00OoVFJI00?o0000ohiaS_n>LHh02?n>
LHh00ol0003oWV6NoiiQWP06oiiQWP03o`000?oN8MkogR7N00?ogR7N00?o0000oo/4nook1?/01ook
1?/2o`0000SonPGj00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP03olHiaPCo00000_n:MHX00ol0003oZEJYojUFZ@0;
ojUFZ@03o`000?n5NXGoQGZ500?oQGZ50ol00004ohEjQ@03o`000?mfRGKoMXUf00OoMXUf0_l00008
oj5NX@03o`000?nPGj3oX5nP00goX5nP00?o0000oiUVVOnIIYT02?nIIYT00ol0003oSW6>ohiaSP07
ohiaSP03o`000?nNHIkoWV6N00OoWV6N0ol000000ooN8Mko0000oo/4n`0;oo/4n`;o00001Ooj1OX0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o6>LKoaSW600OoaSW60_l0000?ojUFZ@03o`000?n5NXGoQGZ500;o00002?n5NXD00ol0
003oMXUfogJ9MP05ogJ9MP03o`000?nQGZ7oXEjQ00SoXEjQ00?o0000oj1OX?nPGj003OnPGj000ol0
003oVFJIoiUVV@08oiUVV@03o`000?n>LHkoSW6>00KoSW6>00?o0000oiiQW_nNHIh02?nNHIh01?l0
003ogB;MomdRgOl0000?oo/4n`03o`000?oj1O[onPGj00;onPGj00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP09olHi
aP03o`000?nYEZWoZEJY00koZEJY0_l0000;ohEjQ@03o`000?mfRGKoMXUf00;oMXUf0_l0000;oj5N
X@03o`000?nPGj3oX5nP00goX5nP00?o0000oiUVVOnIIYT02?nIIYT00ol0003oSW6>ohiaSP06ohia
SP03o`000?nNHIkoWV6N00OoWV6N00Go0000omdRgOoM8]gogB;Mo`00000@oo/4n`;o000000?onPGj
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oaSW6olHiaP0:olHiaP03o`000?nYEZWoZEJY00goZEJY0_l0000<ohEjQ@04o`000?mfRGKo0000
o`0000goXEjQ00?o0000oj1OX?nPGj003?nPGj000ol0003oVFJIoiUVV@09oiUVV@03o`000?n>LHko
SW6>00KoSW6>00?o0000oiiQW_nNHIh01_nNHIh00ol0003ogB;MomdRg@03omdRg@03o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP0:olHiaP03o`000?nYEZWoZEJY00coZEJY00Co0000oeRW
F?mHYeSo00003?n5NXD00ol0003oXEjQoj5NX@0>oj5NX@03o`000?nPGj3oX5nP00SoX5nP1?l0000;
oiUVV@03o`000?n>LHkoSW6>00KoSW6>00?o0000oiiQW_nNHIh01OnNHIh00ol0003ogB;MomdRg@04
omdRg@03o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oaSW6olHiaP0;olHiaP03o`000?nYEZWoZEJY
00_oZEJY00?o0000oeRWF?mHYeP00_mHYeP00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?nQGZ7oXEjQ
00koXEjQ00Co0000oj1OX?nPGj3oX5nP1ol00003oj=LX`03o`000?nIIYWoVFJI00WoVFJI00?o0000
ohiaS_n>LHh01_n>LHh00ol0003oWV6NoiiQWP04oiiQWP03o`000?oM8]gogB;M00KogB;M00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o6>LKoaSW600coaSW600?o0000ojUFZOnYEZT02_nYEZT00ol0
003oF:MHoeRWF003oeRWF003o`000?n5NXGoQGZ500SoQGZ500?o0000oj5NXOnQGZ403_nQGZ44o`00
00_oXebS00?o0000oiUVVOnIIYT02?nIIYT00ol0003oSW6>ohiaSP05ohiaSP03o`000?nNHIkoWV6N
00GoWV6N00?o0000omdRgOoM8]d01_oM8]d00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olHia_o6
>LH03?o6>LH7o`0000GoZEJY00?o0000oeRWF?mHYeP01OmHYeP00ol0003oQGZ5ohEjQ@07ohEjQ@03
o`000?nQGZ7oXEjQ00koXEjQ00?o0000oj=LXonSG:<03OnSG:<00ol0003oVFJIoiUVV@08oiUVV@03
o`000?n>LHkoSW6>00CoSW6>00?o0000oiiQW_nNHIh01?nNHIh00ol0003ogB;MomdRg@07omdRg@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oaSW6olHiaP0=olHiaP03o`000?n[E:_oZeB[00CoZeB[
1Ol00009oeRWF003o`000?n5NXGoQGZ500KoQGZ500?o0000oj5NXOnQGZ403_nQGZ400ol0003oXebS
oj=LX`0=oj=LX`03o`000?nIIYWoVFJI00SoVFJI00Co0000ohiaS_n>LHkoSW6>1Ol00004oiiQWP03
o`000?oM8]gogB;M00WogB;M1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olHiaP03o`000?n[E:_oZeB[00WoZeB[
0_l00009oeRWF003o`000?n5NXGoQGZ500KoQGZ500?o0000oj5NXOnQGZ403?nQGZ400ol0003oXebS
oj=LX`0?oj=LX`Ko00001?nIIYT4o`0000Go^DJi0_l000000onNHIko0000omdRg@0;omdRg@04o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oG:=OoebSGomLXe`?o00002_o6>LH00ol0003o
ZeB[oj]DZ`09oj]DZ`03o`000?mYUVWo000000;o00001omHYeP00ol0003oQGZ5ohEjQ@05ohEjQ@03
o`000?nQGZ7oXEjQ00SoXEjQ1Ol0000Aoj=LX`03o`000?nMHYgoWF:M00?oWF:M1?l0000;okU6^@03
o`000?oM8]gogB;M00[ogB;M00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omLXeooG:=L01OoG:=L2o`0000OoaSW6
00?o0000oj]DZon[E:/02_n[E:/00ol0003oJIIYofVFJ@02ofVFJ@?o00001OmHYeP00ol0003oQGZ5
ohEjQ@04ohEjQ@04o`000?nQGZ7oXEjQoj5NX@Oo00001?n=LXd00ol0003oXebSoj=LX`0>oj=LX`03
o`000?nMHYgoWF:M00OoWF:M00?o0000okU6^OniA[T02OniA[T00ol0003ogB;MomdRg@09omdRg@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003oebSGomLXe`08omLXe`;o00001?o6>LH00ol0003oZeB[
oj]DZ`0;oj]DZ`03o`000?mYUVWoJIIY00GoJIIY0ol00003oeRWF004o`000?n5NXGoQGZ5ohEjQ@Ko
00003?n=LXd00ol0003oXebSoj=LX`0=oj=LX`03o`000?nMHYgoWF:M00OoWF:M00?o0000okU6^Oni
A[T02_niA[T00ol0003ogB;MomdRg@08omdRg@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omLXe`?o000000?oaSW6o`000?n[E:/0
3?n[E:/00ol0003oJIIYofVFJ@08ofVFJ@?o000000CoF:MHo`000?l0003o00000_nUFZD00ol0003o
SG:=ohebS@0=ohebS@03o`000?nSG:?oXebS00coXebS00?o0000oieRWOnMHYd02?nMHYd00ol0003o
^DJiokU6^@0;okU6^@03o`000?oM8]gogB;M00KogB;M00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003onPGjooX5n_oj1O[o000000oo
ebSG00?o0000oj]DZon[E:/03?n[E:/00ol0003oJIIYofVFJ@0;ofVFJ@03o`000?nUFZGoYEZU00?o
YEZU00?o0000ohebSOn=LXd03?n=LXd00ol0003oM8]do`00000=oj=LX`03o`000?nMHYgoWF:M00So
WF:M00?o0000okU6^OniA[T03?niA[T3o`0000GogB;M00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP03ooX5nP03o`00
0?oG:=OoebSG00coebSG00?o0000oj]DZon[E:/03?n[E:/00ol0003oJIIYofVFJ@0:ofVFJ@03o`00
0?nUFZGoYEZU00GoYEZU00?o0000ohebSOn=LXd02_n=LXd01?l0003oM8]dogB;M?mdRg@2o`0000[o
XebS00?o0000oieRWOnMHYd02OnMHYd00ol0003o^DJiokU6^@0<okU6^@03o`000?oS7>?ohacS00?o
000000?ogB;Mo`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003onPGjooX5nP04ooX5nP03o`000?oG:=OoebSG00_oebSG00?o0000oj]DZon[E:/0
3?n[E:/00ol0003oJIIYofVFJ@09ofVFJ@03o`000?nUFZGoYEZU00KoYEZU00?o0000ohebSOn=LXd0
2On=LXd00ol0003oM8]dogB;M002ogB;M003o`000?nRGJ;o000000;o00001onSG:<00ol0003oWF:M
oieRW@09oieRW@03o`000?niA[Wo^DJi00_o^DJi00?o0000on<LhooS7><01?oS7><00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oj
1O[onPGj00KonPGj00?o0000omLXeooG:=L02ooG:=L00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?mY
UVWoJIIY00SoJIIY00?o0000ojEJYOnUFZD01onUFZD00ol0003oSG:=ohebS@08ohebS@03o`000?md
RgCoM8]d00?oM8]d00?o0000oj9MX_nRGJ800_nRGJ82o`0000CoXebS00?o0000oieRWOnMHYd02_nM
HYd00ol0003o^DJiokU6^@0:okU6^@03o`000?oS7>?ohacS00GohacS00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003onPGjooX5nP07
ooX5nP03o`000?oG:=OoebSG00[oebSG0ol0000;oj]DZ`Ko00001?mYUVT00ol0003oYEZUojEJY@08
ojEJY@03o`000?n=LXgoSG:=00OoSG:=00?o0000ogB;M?mdRg@00omdRg@00ol0003oXUfRoj9MXP05
oj9MXP?o000000?oXebSo`000?nMHYd02onMHYd00ol0003o^DJiokU6^@09okU6^@03o`000?oS7>?o
hacS00OohacS00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003onPGjooX5nP08ooX5nP03o`000?oG:=OoebSG00WoebSG00?o0000oj5N
XOnQGZ401?l00006oj]DZ`03o`000?nRGJ;oXUfR00CoXUfR1?l0000<ojEJY@03o`000?n=LXgoSG:=
00GoSG:=00?o0000ogB;M?mdRg@01?mdRg@00ol0003oXUfRoj9MXP08oj9MXP03o`000?nMHYgoWF:M
00_oWF:M00?o0000okU6^OniA[T02?niA[T00ol0003ohacSon<Lh`08on<Lh`Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003onPGjooX5nP0:ooX5nP03
o`000?oG:=OoebSG00OoebSG00?o0000oj5NXOnQGZ401OnQGZ43o`0000;oZeB[00?o0000oj9MX_nR
GJ802?nRGJ800ol0003oYEZUojEJY@0:ojEJY@03o`000?n=LXgoSG:=00CoSG:=00?o0000ogB;M?md
Rg@01OmdRg@00ol0003oXUfRoj9MXP08oj9MXP03o`000?nMHYgoWF:M00WoWF:M1?l00008okU6^@03
o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oebSG
omLXe`05omLXe`03o`000?nQGZ7oXEjQ00WoXEjQ0_l0000<oj9MXP03o`000?nUFZGoYEZU00WoYEZU
00?o0000ohebSOn=LXd00on=LXd00ol0003oM8]dogB;M005ogB;M003o`000?nRGJ;oXUfR00[oXUfR
00?o0000oieRWOnMHYd01?nMHYd4o`0000Co[e2_00?o0000okU6^OniA[T01?niA[T00ol0003ohacS
on<Lh`0:on<Lh`03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oG:=OoebSG00?oebSG00?o0000oj5NXOnQGZ402onQ
GZ400ol0003oXUfRoj9MXP0:oj9MXP03o`000?nUFZGoYEZU00WoYEZU00?o0000ohebSOn=LXd00_n=
LXd00ol0003oM8]dogB;M006ogB;M003o`000?nRGJ;oXUfR00[oXUfR00?o0000oieRWOnMHYd01?l0
0009ojm@[`Ko00003?oS7><00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oj1O[onPGj00conPGj00Co0000omLXeooG:=OoebSG0_l0
000=oj5NX@03o`000?nRGJ;oXUfR00[oXUfR00?o0000ojEJYOnUFZD02OnUFZD01Ol0003oSG:=oheb
SOn=LXgo000000WoM8]d00?o0000oj9MX_nRGJ802onRGJ82o`0000go[e2_00?o0000om/TfooK9=/0
0_oK9=/00ol0003ohacSon<Lh`0:on<Lh`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oebSGo`00
0002omLXe`;o00002onQGZ400ol0003oXUfRoj9MXP0;oj9MXP03o`000?nUFZGoYEZU00WoYEZU00?o
0000ohebSOl000002OmdRg@00ol0003oXUfRoj9MXP0<oj9MXP03o`000?n_D:oo[e2_00co[e2_00?o
0000om/TfooK9=/00ooK9=/00ol0003ohacSon<Lh`09on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooX5n_oj1OX03Ooj1OX0
0ol0003oebSGomLXe`03omLXe`;o00002_nQGZ400ol0003oXUfRoj9MXP0:oj9MXP03o`000?nUFZGo
YEZU00SoYEZU1Ol00008ogB;M003o`000?nRGJ;oXUfR00coXUfR00?o0000ojm@[on_D:l02on_D:l0
0ol0003ofbCKom/Tf`05om/Tf`03o`000?oS7>?ohacS00SohacS00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003onPGjooX5nP0<ooX5
nP;o00001ooG:=L2o`0000SoXEjQ00?o0000oj9MX_nRGJ802_nRGJ800ol0003oYEZUojEJY@07ojEJ
Y@03o`000?nCK9?oTfbC00?oTfbC0ol00005ogB;M003o`000?nRGJ;oXUfR00_oXUfR00?o0000ojm@
[on_D:l03?n_D:l00ol0003ofbCKom/Tf`06om/Tf`03o`000?oS7>?ohacS00OohacS00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
nPGjooX5nP0;ooX5nP03o`000?ok1?_o000000WoebSG00?o0000oj5NXOnQGZ401OnQGZ42o`0000co
XUfR00?o0000ojEJYOnUFZD01OnUFZD00ol0003oTfbCoi=/T`07oi=/T`?o000000?oM8]do`000?nR
GJ803OnRGJ800ol0003o[e2_ojm@[`0<ojm@[`03o`000?oK9=_ofbCK00KofbCK00?o0000on<LhooS
7><01_oS7><00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oj1O[onPGj00SonPGj0_l00003oo/4n`03o`000?oG:=OoebSG00OoebSG
0_l00004oj5NX@03o`000?nYEZWoZEJY00;o00002_nRGJ800ol0003oYEZUojEJY@03ojEJY@;o0000
3OnCK9<2o`0000goXUfR0ol0000=ojm@[`03o`000?oK9=_ofbCK00OofbCK00?o0000on<LhooS7><0
1OoS7><00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oj1OX00ol0003on`Ckoo/4n`04oo/4n`03o`000?oG:=OoebSG00SoebSG0_l0
00000onQGZ7o0000ojUFZ@04ojUFZ@03o`000?nRGJ;oXUfR00OoXUfR00Co0000ojEJYOnUFZGoYEZU
0_l00002oiMXU`03o`000?nCK9?oTfbC00coTfbC3Ol00003ohacS003o`000?n_D:oo[e2_00[o[e2_
00?o0000om/TfooK9=/02?oK9=/01?l0003ohacSon<LhooS7><4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooX5nP;o00002?ok1?/00ol0003oebSG
omLXe`09omLXe`03o`000?nYEZWoZEJY00GoZEJY0_l00008oj9MXP03o`000?nUFZGo000000GoUfRG
00?o0000oi=/TonCK9<02onCK9<00ol0003oTVfBoi9]TP09oi9]TP03o`000?n<LhcoS7><00;oS7><
0_l00009ojm@[`03o`000?oK9=_ofbCK00[ofbCK0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooj1O[o0000oo/4
n`0:oo/4n`03o`000?oG:=OoebSG00SoebSG00?o0000ojUFZOnYEZT01onYEZT4o`0000?oXUfR0ol0
0007oiMXU`03o`000?nCK9?oTfbC00[oTfbC00?o0000oi9]T_nBKI802OnBKI800ol0003oS7><ohac
S004ohacS0;o00001on_D:l00ol0003ofbCKom/Tf`0:om/Tf`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oG:=OoebSG00OoebSG00?o0000ojUFZOnYEZT02?nYEZT0
1?l0003oZeB[oj]DZon[E:/3o`0000;oX5nP00?o0000oiMXUonGJ9L01_nGJ9L00ol0003oTfbCoi=/
T`08oi=/T`03o`000?nBKI;oTVfB00[oTVfB00?o0000ohacS?n<Lh`01_n<Lh`00ol0003o[e2_ojm@
[`04ojm@[`03o`000?oK9=_ofbCK00WofbCK00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000omLXeooG:=L01OoG:=L00ol0003oZEJYojUFZ@08ojUFZ@03o`000?n[E:_o
ZeB[00CoZeB[00Go0000oj1OX?nPGj3oX5nPo`000008oiMXU`03o`000?nCK9?oTfbC00OoTfbC00?o
0000oi9]T_nBKI802_nBKI800ol0003oS7><ohacS007ohacS0;o00001?n_D:l00ol0003ofbCKom/T
f`08om/Tf`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omLXeooG:=L00ooG:=L0
0ol0003oZEJYojUFZ@08ojUFZ@03o`000?n[E:_oZeB[00CoZeB[00?o0000oj1OX?nPGj000_nPGj00
0ol0003oUfRGoiMXU`07oiMXU`03o`000?nCK9?oTfbC00KoTfbC00?o0000oi9]T_nBKI802_nBKI80
0ol0003oS7><ohacS009ohacS005o`000?n_D:oo[e2_ojm@[ol000002OoK9=/00ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_oZEJY00?o0000oj]DZon[E:/01?n[E:/00ol0003oX5nPoj1OX003
oj1OX003o`000?nGJ9OoUfRG00OoUfRG00?o0000oi=/TonCK9<01OnCK9<00ol0003oTVfBoi9]TP0:
oi9]TP03o`000?n<LhcoS7><00WoS7><1?l00009om/Tf`03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oS7>?ohacS
on<Lhol000002_nYEZT00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?nPGj3oX5nP00?oX5nP00?o0000
oiMXUonGJ9L02?nGJ9L00ol0003oTfbCoi=/T`04oi=/T`03o`000?nBKI;oTVfB00WoTVfB00?o0000
ohacS?n<Lh`02?n<Lh`2o`0000?ofBKI00?o0000om/TfooK9=/01_oK9=/00ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000on<LhooS7><00ooS7><00ol0003oZEJYojUFZ@06ojUFZ@03o`000?n[E:_oZeB[
00GoZeB[00?o0000oj1OX?nPGj001?nPGj000ol0003oUfRGoiMXU`09oiMXU`03o`000?nCK9?oTfbC
00;oTfbC00?o0000oi9]T_nBKI802_nBKI800ol0003oS7><ohacS006ohacS0;o00001_oI9]T8o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003ohacSon<Lh`05on<Lh`03o`000?nYEZWoZEJY00GoZEJY00?o0000oj]DZon[
E:/01On[E:/00ol0003oX5nPoj1OX005oj1OX003o`000?nGJ9OoUfRG00WoUfRG00Go0000oi=/TonC
K9?oTfbCo`00000<oi9]TP03o`000?n<LhcoS7><00CoS7><0_l00008omTVf@03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oS7>?ohacS00OohacS00?o0000ojUFZOnY
EZT00onYEZT00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?nPGj3oX5nP00GoX5nP00?o0000oiMXUonG
J9L02_nGJ9L00ol0003oTfbCo`000004o`0000WoTVfB00?o0000ohacS?n<Lh`00_n<Lh`2o`0000[o
fBKI00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003ohacSon<Lh`07on<Lh`03o`00
0?nYEZWoZEJY00;oZEJY00?o0000oj]DZon[E:/01_n[E:/00ol0003oX5nPoj1OX007oj1OX0;o0000
2onGJ9L00ol0003o[5>/ojaC[003ojaC[0Oo00000_nBKI800ol0003oS7><ohacS002o`0000_ofBKI
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000on<LhooS7><02OoS
7><01Ol0003oZEJYojUFZOnYEZWo000000SoZeB[00?o0000oj1OX?nPGj001onPGj000ol0003obcC;
o`000002o`0000SoUfRG00?o0000ojaC[?n/Dj`02_n/Dj`5o`0000gofBKI00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<on<Lh`03o`000?nYEZWo000000WoZeB[00?o
0000oj1OX?nPGj001_nPGj000ol0003obcC;ol/db`03ol/db`?o00001?nGJ9L00ol0003o[5>/ojaC
[00=ojaC[003o`000?oI9]WofBKI00gofBKI00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ook1?/2o`0000_ohacS00?o0000oj]DZon[E:/01on[E:/00ol0003oX5nPoj1OX007
oj1OX003o`000?o;=<_obcC;00KobcC;0ol000000onGJ9Oo0000ojaC[00>ojaC[003o`000?oI9]Wo
fBKI00cofBKI00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009on<L
h`03o`000?n[E:_oZeB[00;oZeB[1_l00008oj1OX003o`000?o;=<_obcC;00[obcC;00?o0000ojaC
[?n/Dj`03on/Dj`00ol0003ofBKIomTVf@0:omTVf@;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007on<Lh`Go00001_oR7N800ol0003oX5nPoj1OX005oj1OX003o`000?o;=<_obcC;00[o
bcC;00?o0000ojaC[?n/Dj`03on/Dj`00ol0003ofBKIomTVf@07omTVf@?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005on<Lh`03o`000?oR7N;ohQgR00WohQgR00?o0000oj1OX?nP
Gj000onPGj000ol0003obcC;ol/db`0;ol/db`03o`000?n/Djco[5>/00oo[5>/00?o0000omTVfOoI
9]T01OoI9]T2o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?ohacSo`000?l00000
3OoR7N800ol0003oX5nPoj1OX002oj1OX003o`000?o;=<_obcC;00_obcC;5?l00004omTVf@;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003on`Cko`00000>on8MhP04o`000?nPGj3oX5nPo`0000kobcC;
00?o0000onHIi_oV6NH04?oV6NH00ol0003ofBKIo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000003_oR7N800ol0003oX5nPo`00000>ol/db`03o`00
0?oV6NKoiQWV017oiQWV00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00_ok1?/00ol0003ohQgRon8MhP0=on8MhP03o`000?o;=<_obcC;00WobcC;1Ol0
000BonHIiP;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/01?ok1?/0
0ol0003ohQgRon8MhP0<on8MhP03o`000?o;=<_obcC;00;obcC;1ol00004ooX5nP03o`000?oV6NKo
iQWV00ooiQWV00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oR7N;ohQgR00cohQgR1?l0000<ooX5nP03o`000?oV6NKoiQWV00coiQWV0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on8Mh_oR7N803?oR7N800ol0003onPGjooX5nP0=ooX5nP03o`000?oV6NKoiQWV00_o
iQWV00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/02Ook1?/00ol0003ohQgRon8MhP0:on8MhP03o`000?oj1O[onPGj00konPGj00?o0000onHIi_oV
6NH02OoV6NH2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000on8Mh_oR7N802_oR7N800ol0003onPGj
ooX5nP0?ooX5nP03o`000?oV6NKoiQWV00KoiQWV0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003on`Ck00gon`Ck3?l0
000AooX5nP?o00001_oV6NH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003onPGjooX5nP0>ooX5nP05o`000?ok1?_on`Ckoo/4nol000000ooV6NH2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003onPGjooX5nP0=ooX5nP03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onHIi_l000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5
n_oj1OX02ooj1OX00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003onPGjooX5nP0:ooX5nP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000ooX5n_oj1OX02Ooj1OX00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003onPGjooX5
nP07ooX5nP;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oj1O[o
nPGj00GonPGj00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000ooX5n_oj1OX01?oj1OX00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
nPGjooX5nP03ooX5nP03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oj1O[onPGj00;onPGj00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?oj1O[onPGjo`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00V?l00?l5oooo01co003o1Oooo`1]o`00o`7ooooo002H
o`00o`;oool000?o<S;<o`00ool00?l07_l00?l00olb</coool0oooo001]o`00o`7ooooo002Ho`00
o`;oool08_l00?l2oooo06go003o0Oooool009So003o0_ooo`0Ro`00o`;oool0KOl00?l1ooooo`00
L_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool03?l00?l4oooo00Wo003o0_ooo`1]o`00o`7ooooo
001bo`00o`;oool01_l00?l2oooo00Wo003o0_ooo`03o`00o`Coool00_l00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0008o`00o`?oool02Ol00?l2oooo00?o003o00?oool0o`00ool00?l01_l0
0?l2oooo06go003o0Oooool007;o003o0_ooo`06o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03
o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000:o`00o`?oool01_l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000_o003o0oooo`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0KOl00?l1ooooo`00LOl00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000<o`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1]o`00o`7ooooo001ao`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00go003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo
001`o`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`08o`00o`Goool0
00?o003ooooo0?ooo`000_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00L?l0
0?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool01ol00?l2oooo00Co003o
0oooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]o`00o`7ooooo001_o`00o`;oool01?l0
0?l00oooo`3o003ooooo0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000Ko003o0oooo`05o`00o`;oool00_l0
0?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1ooooo`00Kol00?l2oooo00Go003o0oooo`05
o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o
003o00;oool01_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1]
o`00o`7ooooo001_o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo
00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0KOl00?l1oooo
o`00K_l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00;o003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1]o`00o`7o
oooo001^o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01_l00?l2oooo00Ko003o
00?oool0o`00ool00?l00_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0KOl00?l1ooooo`00K_l0
0?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00
o`04o`00o`03oooo0?l00?oo003o00?o003o0_ooo`04o`00o`;oool01?l00?l2oooo00Ko003o00?o
<S;<oooo0?ooo`00KOl00?l1ooooo`00KOl00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo
003o01Ko003o1Oooo`04o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool01Ol00?l5
oooo06go003o0Oooool006co003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00
o`Coool02?l00?l4oooo07So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(100) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.982 .018 .982 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.982 .018 .982 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.982 .018 .982 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.981 .019 .981 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.866 .134 .866 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.98 .02 .98 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.859 .141 .859 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.895 .105 .895 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.846 .154 .846 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.979 .021 .979 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.779 .221 .779 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.982 .018 .982 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.726 .274 .726 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.692 .308 .692 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.983 .017 .983 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.67 .33 .67 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.74 .26 .74 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.978 .022 .978 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.979 .021 .979 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.981 .019 .981 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.845 .155 .845 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.577 .423 .577 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.517 .483 .517 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.504 .496 .504 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.498 .502 .498 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.554 .446 .554 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.818 .182 .818 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.844 .156 .844 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.982 .018 .982 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.533 .467 .533 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.729 .271 .729 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.472 .528 .472 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.805 .195 .805 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.776 .224 .776 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.982 .018 .982 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.704 .296 .704 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.694 .306 .694 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.711 .289 .711 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.813 .187 .813 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.528 .472 .528 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.983 .017 .983 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.874 .126 .874 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.6 .4 .6 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.583 .417 .583 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.545 .455 .545 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.853 .147 .853 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.894 .106 .894 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.629 .371 .629 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.982 .018 .982 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.541 .459 .541 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.452 .548 .452 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.672 .328 .672 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.696 .304 .696 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.473 .527 .473 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.531 .469 .531 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.654 .346 .654 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.982 .018 .982 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.689 .311 .689 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.637 .363 .637 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.86 .14 .86 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.184 .816 .184 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.669 .331 .669 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.698 .302 .698 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.673 .327 .673 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.397 .603 .397 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.353 .647 .353 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.299 .701 .299 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.36 .64 .36 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.626 .374 .626 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.391 .609 .391 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.507 .493 .507 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.676 .324 .676 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.583 .417 .583 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.609 .391 .609 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.614 .386 .614 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.89 .11 .89 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.981 .019 .981 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.395 .605 .395 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.483 .517 .483 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.375 .625 .375 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.981 .019 .981 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.691 .309 .691 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.55 .45 .55 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.309 .691 .309 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.39 .61 .39 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.618 .382 .618 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.484 .516 .484 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.856 .144 .856 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.577 .423 .577 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.311 .689 .311 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.622 .378 .622 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.506 .494 .506 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.45 .55 .45 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.617 .383 .617 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.823 .177 .823 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.624 .376 .624 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.326 .674 .326 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.447 .553 .447 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.623 .377 .623 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.491 .509 .491 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.496 .504 .496 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.8 .2 .8 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.475 .525 .475 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.419 .581 .419 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.373 .627 .373 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.98 .02 .98 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.384 .616 .384 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.539 .461 .539 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.42 .58 .42 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.573 .427 .573 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.596 .404 .596 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.98 .02 .98 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.628 .372 .628 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.555 .445 .555 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.577 .423 .577 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.618 .382 .618 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.496 .504 .496 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.45 .55 .45 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.515 .485 .515 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.547 .453 .547 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.981 .019 .981 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.741 .259 .741 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.585 .415 .585 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.683 .317 .683 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.414 .586 .414 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.844 .156 .844 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.284 .716 .284 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.469 .531 .469 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.465 .535 .465 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.619 .381 .619 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.718 .282 .718 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.381 .619 .381 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.981 .019 .981 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.531 .469 .531 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.671 .329 .671 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.903 .097 .903 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.604 .396 .604 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.542 .458 .542 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.572 .428 .572 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.829 .171 .829 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.392 .608 .392 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.517 .483 .517 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.595 .405 .595 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.78 .22 .78 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.385 .615 .385 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.509 .491 .509 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.588 .412 .588 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.605 .395 .605 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.981 .019 .981 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.443 .557 .443 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.981 .019 .981 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.866 .134 .866 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.655 .345 .655 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.606 .394 .606 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.487 .513 .487 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.538 .462 .538 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.519 .481 .519 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.854 .146 .854 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.641 .359 .641 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.666 .334 .666 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.667 .333 .667 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.587 .413 .587 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.803 .197 .803 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.571 .429 .571 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.488 .512 .488 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.344 .656 .344 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.359 .641 .359 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.521 .479 .521 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.677 .323 .677 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.981 .019 .981 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.861 .139 .861 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.535 .465 .535 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.345 .655 .345 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.623 .377 .623 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.75 .25 .75 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.533 .467 .533 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.981 .019 .981 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.489 .511 .489 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.722 .278 .722 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.863 .137 .863 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.981 .019 .981 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.5 .5 .5 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.549 .451 .549 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.861 .139 .861 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.584 .416 .584 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.529 .471 .529 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.81 .19 .81 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.504 .496 .504 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.699 .301 .699 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.741 .259 .741 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.517 .483 .517 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.494 .506 .494 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.623 .377 .623 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.564 .436 .564 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.894 .106 .894 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.7 .3 .7 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.671 .329 .671 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.632 .368 .632 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.981 .019 .981 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.787 .213 .787 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.535 .465 .535 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.981 .019 .981 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.87 .13 .87 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.772 .228 .772 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.874 .126 .874 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.573 .427 .573 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.862 .138 .862 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.705 .295 .705 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.624 .376 .624 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.982 .018 .982 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.637 .363 .637 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.619 .381 .619 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.982 .018 .982 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.804 .196 .804 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.978 .022 .978 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.982 .018 .982 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.747 .253 .747 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.98 .02 .98 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.604 .396 .604 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.981 .019 .981 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.481 .519 .481 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.706 .294 .706 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.557 .443 .557 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.858 .142 .858 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.862 .138 .862 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.698 .302 .698 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.732 .268 .732 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.701 .299 .701 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.797 .203 .797 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.848 .152 .848 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.759 .241 .759 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.765 .235 .765 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.979 .021 .979 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.646 .354 .646 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.849 .151 .849 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.98 .02 .98 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.889 .111 .889 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.888 .112 .888 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.642 .358 .642 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.874 .126 .874 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.87 .13 .87 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.598 .402 .598 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.98 .02 .98 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.978 .022 .978 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.983 .017 .983 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.856 .144 .856 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.981 .019 .981 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.981 .019 .981 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.98 .02 .98 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.981 .019 .981 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.98 .02 .98 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.981 .019 .981 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oj
1OX4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003onPGjooX5nP0=ooX5nP05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003og2?Lom`Sg?l0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?oj1OX03ooj1OX00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000om`Sg?oL8m`00_oL8m`00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?oj1O[onPGj00konPGj00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oL8mcog2?L00?og2?L00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000ooX5n_oj1OX03_oj1OX00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000om`Sg?oL8m`01OoL8m`00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003onPGjooX5nP0>ooX5nP03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003og2?Lom`Sg006om`Sg003
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?oj1OX00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000om`Sg?oL8m`02?oL8m`00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oK9=_o0000013onPGj00?o0000oo/4nook1?/02?ok
1?/9o`0000cog2?L00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?oj1O[onPGj00oonPGj
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003om/Tf`03o`000?oj
1O[onPGj00conPGj00?o0000oo/4nook1?/02Ook1?/00ol0003ogB;MomdRg@05omdRg@03o`000?oL
8mcog2?L00_og2?L0ol00003om`Sg003o`000?ok1?_on`Ck00con`Ck0ol0000>ooX5nP;o00003Ooj
1OX2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
om/TfooK9=/00ooK9=/00ol0003onPGjooX5nP0;ooX5nP;o00002ook1?/00ol0003ogB;MomdRg@06
omdRg@03o`000?oL8mcog2?L00[og2?L00?o0000om`Sg?oL8m`01?oL8m`00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oL8mcog2?Lom`Sg0;o00002_oj1OX2o`000003om`Sg?l0003onPGj00konPGj00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ofbCKom/Tf`05om/Tf`03o`000?oj1O[o
nPGj00WonPGj00?o0000omPWf?l000002ook1?/00ol0003ogB;MomdRg@06omdRg@03o`000?oL8mco
g2?L00Wog2?L00?o0000om`Sg?oL8m`01_oL8m`00ol0003on`Ckoo/4n`08oo/4n`03o`000?oL8mco
g2?L00Cog2?L0_l00005ooX5nP?o00001?oL8m`00ol0003onPGjooX5nP0=ooX5nP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008om/Tf`03o`000?oj1O[onPGj00OonPGj0_l00003omPW
f003o`000?ok1?_on`Ck00Oon`Ck00?o0000omdRgOoM8]d01ooM8]d00ol0003og2?Lom`Sg009om`S
g003o`000?oL8mcog2?L00Oog2?L00?o0000oo/4nook1?/01Ook1?/2o`0000Wog2?L0_l000000ooj
1O[o0000o`000007om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000om/TfooK
9=/02?oK9=/00ol0003onPGjooX5nP06ooX5nP03o`000?oH9mSof2OH00?of2OH00?o0000oo/4nook
1?/01ook1?/00ol0003ogB;MomdRg@08omdRg@03o`000?oL8mcog2?L00Oog2?L00?o0000om`Sg?oL
8m`02OoL8m`00ol0003on`Ckoo/4n`03oo/4n`03o`000?oL8mcog2?L00_og2?L00?o0000om`Sg?oL
8m`01ooL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lo`000005oo/4n`;o00002ooK9=/2o`0000KonPGj
00?o0000omPWf?oH9mP01OoH9mP00ol0003on`Ckoo/4n`06oo/4n`03o`000?oM8]gogB;M00SogB;M
00?o0000om`Sg?oL8m`01_oL8m`00ol0003og2?Lom`Sg00;om`Sg005o`000?ok1?_on`Ckoo/4nol0
00003_oL8m`00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00gonPGj00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oL8mcog2?Lom`Sg?l0
00000ook1?/00ol0003ofbCKom/Tf`0:om/Tf`04o`000?oB;M;odRgBo`0000?onPGj0_l00008omPW
f003o`000?ok1?_on`Ck00Kon`Ck00?o0000omdRgOoM8]d02OoM8]d00ol0003og2?Lom`Sg005om`S
g003o`000?oL8mcog2?L00cog2?L00?o0000oo/4nol000003ooL8m`00ol0003og2?Lom`Sg008om`S
g003o`000?oj1O[onPGj00konPGj00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lom`Sg003om`Sg003o`000?ok1?_o000000_o
fbCK0_l00004om8]dP03o`000?oj1O[o000000_of2OH00?o0000oo/4nook1?/01Ook1?/00ol0003o
gB;MomdRg@09omdRg@03o`000?oL8mcog2?L00Cog2?L00?o0000om`Sg?oL8m`03_oL8m`00ol0003o
g2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000om`Sg?oL8m`0
1?oL8m`00ol0003ofbCKom/Tf`09om/Tf`03o`000?oB;M;odRgB00GodRgB00?o0000omPWf?oH9mP0
2_oH9mP00ol0003on`Ckoo/4n`05oo/4n`03o`000?oM8]gogB;M00[ogB;M00?o0000om`Sg?oL8m`0
0ooL8m`00ol0003og2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00gog2?L00?o0000om`Sg?oL8m`0
2_oL8m`00ol0003onPGjooX5nP0>ooX5nP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lom`S
g005om`Sg003o`000?oK9=_ofbCK00OofbCK0_l00008om8]dP03o`000?oH9mSof2OH00_of2OH00?o
0000oo/4nook1?/01?ok1?/00ol0003ogB;MomdRg@0:omdRg@04o`000?oL8mcog2?Lom`Sg0?o0000
3ooL8m`00ol0003og2?Lom`Sg00>om`Sg003o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX0
3ooj1OX3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oL8mcog2?L00Oog2?L00?o0000om/TfooK9=/01?oK9=/2o`0000_odRgB1?l0
0009omPWf003o`000?ok1?_on`Ck00?on`Ck00?o0000omdRgOoM8]d02ooM8]d01?l0003og2?Lo`00
0?l00003oklo_`;o00003?oL8m`2o`00013og2?L00?o0000om`Sg?oL8m`02ooL8m`00ol0003onPGj
ooX5nP0=ooX5nP04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003og2?L
om`Sg007om`Sg003o`000?oK9=_ofbCK00?ofbCK00?o0000om8]d_oB;M802ooB;M801?l0003o_D:m
oke2_Onm@[d5o`0000Gof2OH00?o0000oo/4nook1?/00_ok1?/00ol0003ogB;MomdRg@0<omdRg@03
o`000?no?koo_cno00Go_cno0_l00008om`Sg0;o00000_ncC;<00ol0003og2?Lom`Sg00=om`Sg003
o`000?oL8mcog2?L00_og2?L00?o0000ooX5n_oj1OX03?oj1OX00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003og2?Lom`Sg009om`Sg003o`000?oK9=_ofbCK00;o0000
3OoB;M800ol0003o_D:moke2_@07oke2_@Ko00000_ok1?/4o`0000gogB;M00?o0000oklo_ono?kl0
1ono?kl2o`0000Gog2?L00?o0000ok=</oncC;<00oncC;<00ol0003og2?Lom`Sg00<om`Sg003o`00
0?oL8mcog2?L00cog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oL8mcog2?L00Wog2?L00?o
0000om/Tfol000003ooB;M800ol0003o_D:moke2_@0<oke2_@?o00001?oD:m@3o`0000WogB;M00?o
0000oklo_ono?kl02_no?kl2o`000003om`Sg?l0003o000000Oo/dbc00?o0000om`Sg?oL8m`02ooL
8m`00ol0003og2?Lom`Sg00<om`Sg003o`000?oj1O[onPGj00KonPGj1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oL8mcog2?L00_og2?L00?o0000
om8]d_oB;M803_oB;M800ol0003o_D:moke2_@0=oke2_@03o`000?oD:mCoe2_D00Koe2_D0ol00005
omdRg@03o`000?no?koo_cno00go_cno00?o0000ok=</oncC;<02?ncC;<00ol0003og2?Lom`Sg009
om`Sg003o`000?oL8mcog2?L00gog2?L00Co0000ooX5n_oj1O[onPGj1Ol00003on<Lh`03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
om`Sg?oL8m`02ooL8m`2o`0000oodRgB00?o0000oke2_Onm@[d03Onm@[d00ol0003oe2_Dom@[e00:
om@[e0?o000000?ogB;Mo`000?no?kl03ono?kl00ol0003o/dbcok=</`09ok=</`03o`000?oL8mco
g2?L00Sog2?L00?o0000om`Sg?oL8m`03_oL8m`3o`0000SohacS00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oL8mcog2?L00Sog2?L0ol000000onb
CK;o0000om8]dP0>om8]dP03o`000?nm@[go_D:m00go_D:m00?o0000om@[e?oD:m@03OoD:m@00ol0
003o_cnooklo_`0?oklo_`03o`000?ncC;?o/dbc00[o/dbc2ol0000;om`Sg0Go00003?oS7><00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02_ok1?/01Ol0003ogb3Oo`000?ok1?_o0000
00Sog2?L0ol00005ok9=/P03o`000?oB;M;odRgB00codRgB00?o0000oke2_Onm@[d03Onm@[d00ol0
003oe2_Dom@[e00=om@[e0;o00004?no?kl00ol0003o/dbcok=</`0:ok=</`03o`000?ndBkCo]4^d
00Oo]4^d00?o0000om`Sg?oL8m`00_oL8m`7o`0000Co/Tfb00?o0000on<LhooS7><02_oS7><00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02Ook1?/01?l0003ogb3OomlPgooO8=l2o`00
00Gog2?L0ol00009ok9=/P;o00002ooB;M800ol0003o_D:moke2_@0=oke2_@03o`000?oD:mCoe2_D
00goe2_D00Co0000oldbcOo=</go00003ono?kl00ol0003o/dbcok=</`09ok=</`03o`000?ndBkCo
]4^d00Wo]4^d1?l0000;ok9=/P03o`000?oS7>?ohacS00[ohacS00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?ok1?_on`Ck00Son`Ck00?o0000omlPgooO8=l01?oO8=l00ol0003og2?Lo`000002o`00
00co/Tfb00Co0000ok1?/?l0003o00002OoB;M800ol0003o_D:moke2_@0=oke2_@03o`000?oD:mCo
e2_D00goe2_D00Go0000oldbcOo=</gocC;=o`00000=oklo_`03o`000?ncC;?o/dbc00[o/dbc00?o
0000okA;]?ndBk@02OndBk@00ol0003o/Tfbok9=/P0<ok9=/P03o`000?oS7>?ohacS00[ohacS00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000omlPgooO8=l01_oO8=l0
0ol0003o/Tfbok9=/P0<ok9=/P03o`000?n`Ck3o/4n`00;o/4n`0_l00007om8]dP03o`000?nm@[go
_D:m00co_D:m00?o0000om@[e?oD:m@03OoD:m@00ol0003ocC;=oldbc@03oldbc@03o`000?no?koo
_cno00[o_cno00?o0000ok=</oncC;<02_ncC;<00ol0003o]4^dokA;]009okA;]003o`000?nbCK;o
/Tfb00co/Tfb00?o0000on<LhooS7><02ooS7><00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4
nook1?/01_ok1?/00ol0003ogb3OomlPg`06omlPg`03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ok1?
/?n`Ck001On`Ck000ol0003odRgBom8]dP03om8]dP03o`000?nm@[go_D:m00go_D:m00?o0000om@[
e?oD:m@03OoD:m@00ol0003ocC;=oldbc@04oldbc@03o`000?no?koo_cno00Wo_cno00?o0000ok=<
/oncC;<02OncC;<00ol0003o]4^dokA;]00:okA;]003o`000?nbCK;o/Tfb00co/Tfb00?o0000on<L
hooS7><02ooS7><00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook1?/01Ook1?/00ol0003o
gb3OomlPg`07omlPg`03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ok1?/?n`Ck001_n`Ck02o`0000?o
dRgB00?o0000oke2_Onm@[d03Onm@[d00ol0003oe2_Dom@[e00<om@[e003o`000?o=</gocC;=00Ko
cC;=00?o0000oklo_ono?kl02?no?kl00ol0003o/dbcok=</`09ok=</`03o`000?ndBkCo]4^d00[o
]4^d00?o0000ok9=/_nbCK803?nbCK800ol0003ohacSon<Lh`0;on<Lh`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?ok1?_on`Ck00Con`Ck00?o0000omlPgooO8=l02?oO8=l00ol0003o/Tfbok9=/P0:ok9=/P03o`00
0?n`Ck3o/4n`00Wo/4n`0_l000000ooB;M;o0000oke2_@0<oke2_@?o00003_oD:m@00ol0003ocC;=
oldbc@07oldbc@03o`000?no?koo_cno00Oo_cno00?o0000ok=</oncC;<02OncC;<00ol0003o]4^d
okA;]00;okA;]003o`000?nbCK;o/Tfb00co/Tfb00?o0000on<LhooS7><02_oS7><00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000omlPgooO8=l02_oO8=l00ol0003o/Tfbok9=
/P09ok9=/P03o`000?n`Ck3o/4n`00_o/4n`00?o0000oke2_Onm@[d02_nm@[d2o`0000?o]dRg00?o
0000om@[e?oD:m@02_oD:m@00ol0003ocC;=oldbc@09oldbc@03o`000?no?koo_cno00Ko_cno00?o
0000ok=</oncC;<02?ncC;<00ol0003o]4^dokA;]00<okA;]003o`000?nbCK;o/Tfb00co/Tfb00?o
0000on<LhooS7><02_oS7><00ol0003on`Ckoo/4n`04oo/4n`Co00000ooj1OX00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ook1?/0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oO8=oogb3O00_ogb3O00?o0000ok9=/_nbCK802?nbCK80
0ol0003o/4n`ok1?/00<ok1?/003o`000?nm@[go_D:m00So_D:m0_l00006okM8]`;o00002_oD:m@0
0ol0003ocC;=oldbc@0:oldbc@03o`000?no?koo_cno00Go_cno00?o0000ok=</oncC;<02?ncC;<0
0ol0003o]4^dokA;]00<okA;]003o`000?nbCK;o/Tfb00co/Tfb00?o0000on<LhooS7><02ooS7><0
0ol0003on`Cko`000003o`0000SonPGj00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?on`Ck00Go0000oo/4nook1?_on`Cko`00000=
omlPg`03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ok1?/?n`Ck003_n`Ck000ol0003o_D:moke2_@04
oke2_@?o00002_ngB;L00ol0003oe2_Dom@[e007om@[e003o`000?o=</gocC;=00_ocC;=00?o0000
oklo_ono?kl00ono?kl00ol0003o/dbcok=</`09ok=</`03o`000?ndBkCo]4^d00co]4^d00?o0000
ok9=/_nbCK803?nbCK800ol0003ohacSon<Lh`0;on<Lh`;o00003Ooj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003ogb3OomlPg`0<omlPg`03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ok1?/?n`Ck003on`Ck001?l0
003o_D:moke2_Onm@[d2o`0000ko]dRg0_l00006om@[e003o`000?o=</gocC;=00gocC;=00?o0000
oklo_ono?kl00_no?kl00ol0003o/dbcok=</`08ok=</`03o`000?ndBkCo]4^d00co]4^d0ol0000=
ok9=/P03o`000?oS7>?ohacS00_ohacS00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oogb3O00?o0000ok9=/_nbCK801_nbCK800ol0003o/4n`ok1?/00@ok1?/0Co00004_ngB;L00ol0
003oe2_Dom@[e003om@[e003o`000?o=</gocC;=00kocC;=00Go0000oklo_ono?koo_cnoo`000005
ok=</`Oo00003?ndBk@01Ol0003oVVFJoiYUV_nJII[o000000co/Tfb00?o0000on<LhooS7><02?oS
7><3o`0000oonPGj00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oogb3O00?o0000ok9=/_nbCK801_nbCK800ol0003o/4n`ok1?/00=
ok1?/0?o000000CoWV6No`000?l0003o00004ongB;L2o`0000;oe2_D00?o0000oldbcOo=</d04?o=
</d00ol0003o_cnoo`000006o`0000OobCK900?o0000okA;]?ndBk@02?ndBk@00ol0003oVVFJoiYU
VP03oiYUVP;o00002?nbCK83o`0000KohacS1?l00002omhQgP03o`000?oj1O[onPGj00konPGj00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003of2OHo`000?ndBk@3o`0000gogb3O00?o0000ok9=/_nbCK801?nbCK800ol0003o/4n`ok1?
/00;ok1?/0?o00000onNHIh01Ol0003oWf2Oo`000?nPGj3o000001Co]dRg00?o0000om@[e?l00000
4oo=</d00ol0003obCK9olTfb@0=olTfb@03o`000?ndBkCo]4^d00Go]4^d0_l00008oiYUVP03o`00
0?nbCK;o/Tfb00Go00000oncC;<00ol0003ohacSon<Lh`03o`0000OogR7N00?o0000ooX5n_oj1OX0
3Ooj1OX00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oH9mSof2OHo`0000Co]4^d0ol0000:omlPg`03o`000?nbCK;o/Tfb00?o/Tfb
00?o0000ok1?/?n`Ck002On`Ck03o`0000GoWV6N00Co0000oimPWonOH9oo00000_nPGj000ol0003o
]dRgokM8]`0BokM8]`03o`000?o=</gocC;=01;ocC;=00?o0000olTfbOo9=/T03_o9=/T00ol0003o
]4^dokA;]003okA;]003o`000?nJII[oVVFJ00WoVVFJ0_l00009ok=</`;o00002_oN8Mh00ol0003o
nPGjooX5nP0=ooX5nP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000omPWf?oH9mSof2OHo`000007okA;]0;o00001ooO8=l5o`0000;o
/Tfb00?o0000ok1?/?n`Ck001_n`Ck03o`0000SoWV6N00Co0000oimPWonOH9oo00000onPGj000ol0
003o]dRgokM8]`0AokM8]`03o`000?o=</gocC;=017ocC;=00?o0000olTfbOo9=/T04?o9=/T01Ol0
003o]4^dokA;]?ndBkCo000000coVVFJ00?o0000ok=</oncC;<02?ncC;<00ol0003ogR7NomhQgP0:
omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000Cof2OH00?o0000okA;]?ndBk@01ondBk@3o`00
0004omlPgol0003o0000o`0000Go/4n`0_l00006ok1?/0?o00002_nNHIh01Ol0003oWf2OoimPWonO
H9oo000000CoX5nP00?o0000okM8]ongB;L04?ngB;L00ol0003ocC;=oldbc@0Aoldbc@03o`000?o9
=/WobCK9017obCK900?o0000okA;]?l000003OnJIIX00ol0003o/dbcok=</`08ok=</`03o`000?oN
8MkogR7N00[ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oH9mSof2OH00Cof2OH00?o0000
okA;]?ndBk@02_ndBk@00ol0003o/4n`ok1?/008ok1?/003o`000?n`Ck3o/4n`00?o00003OnNHIh0
1Ol0003oWf2OoimPWonOH9oo000000GoX5nP00?o0000okM8]ongB;L03ongB;L00ol0003ocC;=oldb
c@0Aoldbc@03o`000?o9=/WobCK901;obCK900?o0000oiYUV_nJIIX03?nJIIX00ol0003o/dbcok=<
/`08ok=</`03o`000?oN8MkogR7N00_ogR7N00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000omPWf?oH9mP01OoH9mP0
0ol0003o]4^dokA;]00:okA;]003o`000?n`Ck3o/4n`00Wo/4n`0_l0000?oiiQWP03o`000?nOH9oo
Wf2O00;oWf2O00?o0000oj1OX?nPGj001?nPGj000ol0003o]dRgokM8]`0=okM8]`?o00004Oo=</d0
0ol0003obCK9olTfb@0ColTfb@03o`000?nJII[oVVFJ00_oVVFJ00?o0000ok=</oncC;<02OncC;<0
0ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooX5n_oj1O[onPGjo`000008oo/4n`;o00002?oH9mP0
0ol0003o]4^dokA;]00:okA;]003o`000?n`Ck3o/4n`00Wo/4n`00?o0000oiiQW_nNHIh03OnNHIh0
0ol0003oWf2OoimPW`03oimPW`03o`000?nPGj3oX5nP00GoX5nP00?o0000okM8]ongB;L02_ngB;L2
o`0000?oacS700?o0000oldbcOo=</d03_o=</d00ol0003obCK9olTfb@0ColTfb@03o`000?nJII[o
VVFJ00_oVVFJ00?o0000ok=</oncC;<02OncC;<00ol0003ogR7NomhQgP0;omhQgP03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooX5
n_oj1OX00ooj1OX2o`0000Gon`Ck00?o0000omPWf?oH9mP01ooH9mP2o`0000_o]4^d00?o0000ok1?
/?n`Ck002on`Ck000ol0003oWV6NoiiQWP0<oiiQWP03o`000?nOH9ooWf2O00?oWf2O00?o0000oj1O
X?nPGj001_nPGj000ol0003o]dRgokM8]`07okM8]`;o00001_o7><L2o`0000kocC;=00?o0000olTf
bOo9=/T04oo9=/T00ol0003oVVFJoiYUVP0;oiYUVP03o`000?ncC;?o/dbc00Wo/dbc00?o0000omhQ
g_oN8Mh03?oN8Mh00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oj1O[onPGj00KonPGj00Go0000oo/4nook1?_on`Cko`000009omPW
f003o`000?n4NhCo000000_o]4^d00?o0000ok1?/?n`Ck002on`Ck000ol0003oWV6NoiiQWP0;oiiQ
WP03o`000?nOH9ooWf2O00CoWf2O00?o0000oj1OX?nPGj001onPGj000ol0003o]dRgokM8]`05okM8
]`03o`000?o7><OoacS700SoacS700?o0000oldbcOo=</d02_o=</d00ol0003obCK9olTfb@0DolTf
b@03o`000?nJII[oVVFJ00_oVVFJ00?o0000ok=</oncC;<02OncC;<00ol0003ogR7NomhQgP0<omhQ
gP03o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003on`Cko`000009omPWf004o`000?n4NhCoQ7^4o`00
00_o]4^d00?o0000ok1?/?n`Ck002on`Ck000ol0003oWV6NoiiQWP0;oiiQWP03o`000?nOH9ooWf2O
00CoWf2O00?o0000oj1OX?nPGj002?nPGj000ol0003o]dRgokM8]`02okM8]`;o00003?o7><L2o`00
00[ocC;=00?o0000olTfbOo9=/T05?o9=/T00ol0003oVVFJoiYUVP0;oiYUVP03o`000?ncC;?o/dbc
00Wo/dbc00?o0000omhQg_oN8Mh03OoN8Mh00ol0003onPGjooX5nP06ooX5nP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003of2OHomPWf007omPWf003
o`000?n4NhCoQ7^400;oQ7^400?o0000okA;]?ndBk@02?ndBk@00ol0003o/4n`ok1?/00<ok1?/003
o`000?nNHIkoWV6N00WoWV6N00?o0000oimPWonOH9l01OnOH9l00ol0003oX5nPoj1OX009oj1OX004
o`000?ngB;Oo0000o`00013oacS70_l00008oldbc@03o`000?o9=/WobCK901CobCK90ol0000;oiYU
VP03o`000?ncC;?o/dbc00Wo/dbc00?o0000omhQg_oN8Mh03OoN8Mh01?l0003onPGjooX5n_oj1OX5
o`0000?onPGj00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003of2OHomPWf006omPWf003o`000?n4NhCoQ7^400?oQ7^400?o0000okA;
]?ndBk@02?ndBk@00ol0003o/4n`ok1?/00;ok1?/0;o00002_nNHIh00ol0003oWf2OoimPW`06oimP
W`03o`000?nPGj3oX5nP00[oX5nP00?o0000olLhaoo7><L04_o7><L00ol0003ocC;=oldbc@04oldb
c@03o`000?o9=/WobCK901GobCK900?o0000okm0_ono@;l01Ol00005oiYUVP03o`000?ncC;?o/dbc
00[o/dbc00?o0000omhQg_oN8Mh03_oN8Mh3o`0000WonPGj00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003of2OHomPWf004omPWf003
o`000?n4NhCoQ7^400CoQ7^400?o0000okA;]?ndBk@01ondBk@00ol0003o/4n`ok1?/00;ok1?/004
o`000?n/Djco[5>/o`0000WoWV6N00?o0000oimPWonOH9l01_nOH9l00ol0003oX5nPoj1OX00:oj1O
X003o`000?o7><OoacS701?oacS70_l00003oldbc@Co00005?o9=/T00ol0003o_d2ookm0_`06okm0
_`Co000000?oVVFJo`000?ncC;<02oncC;<00ol0003ogR7NomhQgP0>omhQgP03o`000?oj1O[onPGj
00[onPGj00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooX5n_oj
1OX02ooj1OX00ol0003of2OHomPWf003omPWf003o`000?n4NhCoQ7^400GoQ7^400?o0000okA;]?nd
Bk@01ondBk@00ol0003o/4n`ok1?/009ok1?/0;o00001?n/Dj`00ol0003oWV6NoiiQWP05oiiQWP03
o`000?nOH9ooWf2O00OoWf2O00?o0000oj1OX?nPGj002_nPGj000ol0003oacS7olLha`0EolLha`03
o`000?o=</go000000Cocc3?0ol0000@olTfb@03o`000?no@;oo_d2o00_o_d2o0_l0000<ok=</`03
o`000?oN8MkogR7N00cogR7N0_l0000>ooX5nP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oj1O[onPGj00conPGj00?o0000omPWf?oH9mP00_oH9mP00ol0003oQ7^4
ohAkQ006ohAkQ003o`000?ndBkCo]4^d00Oo]4^d00?o0000ok1?/?n`Ck002?n`Ck000ol0003o[5>/
ojaC[005ojaC[003o`000?nNHIkoWV6N00CoWV6N00?o0000oimPWonOH9l01onOH9l00ol0003oX5nP
oj1OX00:oj1OX003o`000?o7><OoacS701KoacS700?o0000oll`coo?<<l01_o?<<l3o`0000cobCK9
00?o0000okm0_ono@;l03Ono@;l00ol0003o/dbcok=</`09ok=</`Go00002OoN8Mh2o`000003om/T
fol0003onPGj00konPGj00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooX5n_oj1OX03?oj1OX3o`000003omPWf?l0003oQ7^400WoQ7^400?o0000okA;]?ndBk@01_nd
Bk@00ol0003o/4n`ok1?/007ok1?/003o`000?n/Djco[5>/00Oo[5>/00?o0000oiiQW_nNHIh00_nN
HIh00ol0003oWf2OoimPW`08oimPW`03o`000?nPGj3oX5nP00WoX5nP00?o0000olLhaoo7><L05oo7
><L00ol0003occ3?oll`c`09oll`c`?o00002Oo9=/T00ol0003o_d2ookm0_`0>okm0_`Ko00001?nc
C;<00ol0003oY5^TojAKY003ojAKY0Go00000_oN8Mh2o`0000CofbCK00?o0000ooX5n_oj1OX03?oj
1OX00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP0<
ooX5nP05o`000?o7><OoacS7olLhaol000002on4Nh@00ol0003o]4^dokA;]006okA;]003o`000?n`
Ck3o/4n`00Go/4n`0_l0000;ojaC[004o`000?nNHIkoWV6No`0000_oWf2O00?o0000oj1OX?nPGj00
2OnPGj000ol0003oacS7olLha`0FolLha`03o`000?o?<<oocc3?00gocc3?0ol00005olTfb@03o`00
0?no@;oo_d2o00oo_d2o00?o0000ok]4^onkA;/00onkA;/4o`0000_oY5^T0_l00006om/Tf`03o`00
0?oj1O[onPGj00conPGj00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooX5n_oj1OX02ooj1OX00ol0003oacS7olLha`02olLha`ko00001_ndBk@00ol0003o/4n`ok1?
/005ok1?/003o`000?n/Djco[5>/00co[5>/00?o0000oiiQW_l000002onOH9l00ol0003oX5nPoj1O
X007oj1OX0?o00006?o7><L00ol0003occ3?oll`c`0@oll`c`?o000000?obCK9o`000?no@;l04?no
@;l00ol0003o^dBkok]4^`07ok]4^`03o`000?nTFjCoY5^T00[oY5^T00?o0000om/TfooK9=/01OoK
9=/00ol0003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oj1O[onPGj00WonPGj0_l00005olLha`03o`000?n1OX7oPGj100_oPGj10_l00004
okA;]003o`000?n`Ck3o/4n`00?o/4n`0_l0000@ojaC[003o`000?nOH9ooWf2O00[oWf2O00?o0000
oj1OX?nPGj000onPGj04o`0000;oUFZE00?o0000olLhaoo7><L05Oo7><L00ol0003occ3?oll`c`0D
oll`c`03o`000?no@;oo_d2o013o_d2o00?o0000ok]4^onkA;/01onkA;/00ol0003oY5^TojAKY00:
ojAKY003o`000?oK9=_ofbCK00GofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003onPGjooX5nP08ooX5nP03o`000?o7><OoacS7
00GoacS700?o0000oh5nPOn1OX403On1OX46o`0000?o/4n`00?o0000ojaC[?n/Dj`04?n/Dj`00ol0
003oWf2OoimPW`0:oimPW`03o`000?nPGj3o000000?o00001onEJYD00ol0003oacS7olLha`0DolLh
a`03o`000?o?<<oocc3?01Cocc3?00?o0000okm0_ono@;l03ono@;l00ol0003o^dBkok]4^`08ok]4
^`03o`000?nTFjCoY5^T00[oY5^T00?o0000om/TfooK9=/01OoK9=/00ol0003onPGjooX5nP0<ooX5
nP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000olLhaoo7><L01_o7><L00ol0003oPGj1oh5nP@0=oh5nP@03o`000?nfBKKo]TVf00?o
]TVf00?o0000ok1?/?l000004on/Dj`4o`0000WoWf2O0_l0000<oiEZU@03o`000?o7><OoacS701?o
acS700?o0000oll`coo?<<l05Oo?<<l00ol0003o_d2ookm0_`0>okm0_`03o`000?nkA;_o^dBk00So
^dBk00?o0000ojAKY?nTFj@02OnTFj@00ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooX5nP03o`00
0?o7><OoacS700SoacS700?o0000oh5nPOn1OX402on1OX400ol0003o]TVfokI9]P05okI9]P03o`00
0?n/Djco[5>/01;o[5>/00Co0000oimPWonOH9ooWf2O1Ol00003oimPW`03o`000?nEJYGoUFZE00go
UFZE0ol0000@olLha`;o00006?o?<<l00ol0003o_d2ookm0_`0=okm0_`03o`000?nkA;_o^dBk00Wo
^dBk00?o0000ojAKY?nTFj@02OnTFj@00ol0003ofbCKom/Tf`07om/Tf`03o`000?oj1O[onPGj00_o
nPGj00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_oacS700?o0000oh5nPOn1OX402_n1OX400ol0003o]TVfokI9]P06okI9]P03o`00
0?n/Djco[5>/017o[5>/00?o0000oimPWonOH9l01onOH9l3o`00013oUFZE00?o0000oi9]T_nBKI80
1Ol00009olLha`;o000000?oY5^To`000?o?<<l05oo?<<l00ol0003o_d2ookm0_`0=okm0_`03o`00
0?nkA;_o^dBk00Wo^dBk00?o0000ojAKY?nTFj@02?nTFj@2o`0000[ofbCK00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oK9=_ofbCK00;ofbCK00?o0000olLhaoo7><L02Oo7><L00ol0003oPGj1oh5n
P@0:oh5nP@03o`000?nfBKKo]TVf00Oo]TVf00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oWf2OoimP
W`0:oimPW`03o`000?nEJYGoUFZE00goUFZE00?o0000oi9]T_nBKI801_nBKI84o`0000CoacS700?o
0000ojAKY?nTFj@00_nTFj@00ol0003occ3?oll`c`0Foll`c`03o`000?no@;oo_d2o00_o_d2o00?o
0000ok]4^onkA;/02onkA;/00ol0003oY5^TojAKY006ojAKY003o`000?nIIYWo000000[ofbCK00?o
0000ooX5n_oj1OX02_oj1OX00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oK9=_ofbCK00?ofbCK00?o0000olLhaoo7><L02?o7><L=
o`0000[o]TVf00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oWf2OoimPW`0;oimPW`03o`000?nEJYGo
UFZE00coUFZE00?o0000oi9]T_nBKI802_nBKI84o`0000GoY5^T00?o0000oll`coo?<<l05_o?<<l0
0ol0003o_d2ookm0_`0:okm0_`03o`000?nkA;_o^dBk00co^dBk00?o0000ojAKY?nTFj@01?nTFj@2
o`0000?oVFJI00?o0000om/TfooK9=/02?oK9=/00ol0003onPGjooX5nP08ooX5nP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000om/T
fooK9=/00ooK9=/00ol0003oacS7olLha`07olLha`03o`000?moP7ooOh1o00WoOh1o00?o0000okI9
]_nfBKH02OnfBKH00ol0003o[5>/ojaC[00=ojaC[003o`000?nOH9ooWf2O00coWf2O00?o0000oiEZ
UOnEJYD03?nEJYD00ol0003oTVfBoi9]TP0;oi9]TP03o`000?mlPgco000000KoY5^T00?o0000oll`
coo?<<l05_o?<<l00ol0003o_d2ookm0_`09okm0_`03o`000?nkA;_o^dBk00co^dBk00?o0000ojAK
Y?nTFj@00onTFj@00ol0003oVFJIoiUVV@03oiUVV@03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5
n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oK9=_ofbCK00CofbCK00?o0000olLhaoo7><L01_o7><L00ol0003o
Oh1oogn0O`08ogn0O`03o`000?nfBKKo]TVf00_o]TVf00?o0000ojaC[?n/Dj`02?n/Dj`4o`0000oo
Wf2O00?o0000oiEZUOnEJYD02onEJYD00ol0003oTVfBoi9]TP0;oi9]TP04o`000?mlPgcoO8=lo`00
00OoY5^T00?o0000oll`coo?<<l05Oo?<<l00ol0003o_d2ookm0_`08okm0_`03o`000?nkA;_o^dBk
00go^dBk00?o0000ojAKY?nTFj@00_nTFj@00ol0003oVFJIoiUVV@05oiUVV@03o`000?oK9=_ofbCK
00OofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oK9=_ofbCK00GofbCK00?o0000olLhaoo7
><L01Oo7><L00ol0003oOh1oogn0O`08ogn0O`03o`000?nfBKKo]TVf00_o]TVf00?o0000ojaC[?n/
Dj`00on/Dj`5o`0000?oX5nP00?o0000oimPWonOH9l03_nOH9l00ol0003oUFZEoiEZU@0:oiEZU@03
o`000?nBKI;oTVfB00[oTVfB00Go0000ogb3O?mlPgcoO8=lo`000007ojAKY003o`000?o?<<oocc3?
01Gocc3?00?o0000okm0_ono@;l02?no@;l00ol0003o^dBkok]4^`0=ok]4^`03o`000?nTFjCoY5^T
00;o00002?nIIYT00ol0003ofbCKom/Tf`08om/Tf`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003ofbCKom/Tf`05om/Tf`03o`000?o7><OoacS700Go
acS700?o0000ogn0OomoP7l02?moP7l00ol0003o]TVfokI9]P0<okI9]PGo00002OnPGj000ol0003o
Wf2OoimPW`0<oimPW`;o00003?nEJYD00ol0003oTVfBoi9]TP0:oi9]TP05o`000?mlPgcoO8=logb3
O?l000002?nTFj@00ol0003occ3?oll`c`0Doll`c`?o00001ono@;l00ol0003o^dBkok]4^`0>ok]4
^`03o`000?nTFjCo000000_oVFJI00?o0000om/TfooK9=/01_oK9=/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000om/TfooK9=/01OoK9=/00ol0003oacS7olLha`04olLha`03o`000?moP7ooOh1o00Oo
Oh1o00?o0000okI9]_nfBKH03?nfBKH01?l0003o[5>/ojaC[?l0000;oj1OX003o`000?nOH9ooWf2O
00_oWf2O00Co0000ogV6NOmiQWWo00002_nEJYD00ol0003oTVfBoi9]TP0:oi9]TP03o`000?mlPgco
O8=l00;oO8=l00?o0000ojAKY?nTFj@01_nTFj@00ol0003occ3?oll`c`0Aoll`c`?o00000on[E:/0
0ol0003o_d2ookm0_`04okm0_`03o`000?nkA;_o^dBk00go^dBk1?l0000;oiUVV@03o`000?oK9=_o
fbCK00GofbCK00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oK9=_ofbCK00KofbCK00Co0000olLh
aoo7><OoacS71?l00008ogn0O`03o`000?nfBKKo]TVf00_o]TVf00?o0000ojaC[?n/Dj`00_n/Dj`0
0ol0003oX5nPoj1OX008oj1OX003o`000?nOH9ooWf2O00[oWf2O00?o0000ogV6NOmiQWT00_miQWT0
0ol0003oUFZEoiEZU@03oiEZU@Go00002onBKI800ol0003oO8=logb3O003ogb3O003o`000?nTFjCo
Y5^T00OoY5^T00?o0000oll`coo?<<l03_o?<<l2o`0000OoZeB[00?o0000okm0_ono@;l00_no@;l0
0ol0003o^dBkok]4^`0=ok]4^`03o`000?nUFZGoYEZU00;oYEZU00?o0000oiUVVOnIIYT02OnIIYT0
0ol0003ofbCKom/Tf`03om/Tf`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003ofbCKom/Tf`07om/T
f`?o00001?niA[T00ol0003oOh1oogn0O`05ogn0O`03o`000?nfBKKo]TVf00[o]TVf00?o0000ojaC
[?n/Dj`00on/Dj`00ol0003oX5nPoj1OX009oj1OX003o`000?nOH9ooWf2O00SoWf2O00?o0000ogV6
NOmiQWT01?miQWT5o`0000CoB;M800?o0000oi9]T_nBKI802OnBKI800ol0003oO8=logb3O003ogb3
O003o`000?nTFjCoY5^T00SoY5^T00?o0000oll`coo?<<l02_o?<<l3o`0000[oZeB[00Go0000okm0
_ono@;oo_d2oo`00000>ok]4^`03o`000?nUFZGoYEZU00CoYEZU0_l00009oiUVV@03o`000?oK9=_o
fbCK00;ofbCK00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oK9=_ofbCK00OofbCK00?o0000okU6
^OniA[T01OniA[T00ol0003oOh1oogn0O`03ogn0O`03o`000?nfBKKo]TVf00[o]TVf00?o0000ojaC
[?n/Dj`01?n/Dj`00ol0003oX5nPoj1OX009oj1OX003o`000?nOH9ooWf2O00OoWf2O00?o0000ogV6
NOmiQWT01OmiQWT00ol0003oB;M8odRgB007odRgB003o`000?nBKI;oTVfB00OoTVfB00?o0000ogb3
O?mlPg`01?mlPg`00ol0003oY5^TojAKY008ojAKY003o`000?o?<<oocc3?00Socc3?0_l0000>oj]D
Z`Co00003?nkA;/2o`0000WoYEZU00?o0000oiUVVOnIIYT01onIIYT01?l0003ofbCKom/Tfol0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000om/TfooK9=/01OoK9=/00ol0003o^DJiokU6^@07okU6^@;o00000omoP7l00ol0
003o]TVfokI9]P09okI9]P03o`000?n/Djco[5>/00Ko[5>/00?o0000oj1OX?nPGj002OnPGj000ol0
003oWf2OoimPW`05oimPW`03o`000?miQWWoNHIi00KoNHIi00?o0000odRgB?m8]dP02?m8]dP00ol0
003oTVfBoi9]TP06oi9]TP03o`000?mlPgcoO8=l00CoO8=l00?o0000ojAKY?nTFj@02OnTFj@4o`00
00?occ3?0ol0000@oj]DZ`05o`000?o=</gocC;=oldbcOl000002_nkA;/00ol0003oYEZUojEJY@0:
ojEJY@Ko00000onIIYT00ol0003ofbCKo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000om/TfooK9=/01?oK9=/00ol0
003o^DJiokU6^@0:okU6^@04o`000?moP7ooOh1oo`0000[o]TVf00?o0000ojaC[?n/Dj`01on/Dj`0
0ol0003oX5nPoj1OX009oj1OX003o`000?nOH9ooWf2O00CoWf2O00?o0000ogV6NOmiQWT01omiQWT0
0ol0003oB;M8odRgB008odRgB0;o00001_nBKI800ol0003oO8=logb3O005ogb3O003o`000?nTFjCo
Y5^T00WoY5^T00Co0000oiEZUOnEJYGoUFZE0ol0000Boj]DZ`03o`000?o=</gocC;=00?ocC;=0_l0
0006ok]4^`;o00003OnUFZD00ol0003ogb3OomlPg`03omlPg`Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000om/TfooK9=/00ooK9=/0
0ol0003o^DJiokU6^@0<okU6^@;o00002_nfBKH00ol0003o[5>/ojaC[008ojaC[003o`000?nPGj3o
X5nP00[oX5nP00?o0000oimPWonOH9l00_nOH9l00ol0003oNHIiogV6N@08ogV6N@03o`000?m8]dSo
B;M800KoB;M80_l00002ogN8M`03o`000?nBKI;oTVfB00;oTVfB00?o0000ogb3O?mlPg`01_mlPg`0
0ol0003oY5^TojAKY008ojAKY003o`000?nEJYGoUFZE00CoUFZE00?o0000oj]DZon[E:/03on[E:/0
0ol0003ocC;=oldbc@06oldbc@;o00000onkA;/00ol0003oYEZUojEJY@0=ojEJY@03o`000?oO8=oo
gb3O00Oogb3O0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003ofbCKom/Tf`02om/Tf`03o`000?niA[Wo^DJi
00ko^DJi00?o0000okI9]_nfBKH01onfBKH00ol0003o[5>/ojaC[00:ojaC[003o`000?nPGj3oX5nP
00WoX5nP00Go0000oimPWonOH9ooWf2Oo`00000;ogV6N@03o`000?m8]dSoB;M800CoB;M80_l00005
ogN8M`05o`000?nBKI;oTVfBoi9]T_l000002?mlPg`00ol0003oY5^TojAKY008ojAKY003o`000?nE
JYGoUFZE00GoUFZE00?o0000oj]DZon[E:/03_n[E:/00ol0003ocC;=oldbc@08oldbc@03o`000?nk
A;_o000000ooYEZU00?o0000omlPgooO8=l02?oO8=l01?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oK9=_ofbCKo`00017o^DJi00?o0000okI9]_nfBKH01_nfBKH00ol0003o[5>/
ojaC[00;ojaC[003o`000?nPGj3oX5nP00WoX5nP00Co0000oimPWonOH9oo00003?miQWT00ol0003o
B;M8odRgB002odRgB0;o00002?mgR7L00ol0003oTVfBo`000009ogb3O003o`000?nTFjCoY5^T00So
Y5^T00?o0000oiEZUOnEJYD01OnEJYD00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?o=</gocC;=00[o
cC;=00?o0000ojEJYOnUFZD03_nUFZD00ol0003ogb3OomlPg`07omlPg`03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000BokU6^@03o`00
0?nfBKKo]TVf00Co]TVf00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oX5nPoj1OX00:oj1OX0?o0000
3?miQWT00ol0003oB;M8odRgB002o`0000_oMhQg00?o0000ogb3O?mlPg`02?mlPg`00ol0003oY5^T
ojAKY007ojAKY003o`000?nEJYGoUFZE00OoUFZE00?o0000oj]DZon[E:/03?n[E:/00ol0003ocC;=
oldbc@0;oldbc@;o00003_nUFZD00ol0003ogb3OomlPg`07omlPg`03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onDJiOoU6^D00ooU6^D00ol0003o^DJiokU6^@0?okU6^@?o00000onf
BKH00ol0003o[5>/ojaC[00>ojaC[003o`000?nPGj3oX5nP00SoX5nP00Co0000oh5nPOn1OX7oPGj1
0_l0000:ogV6N@?o00003OmgR7L00ol0003oO8=logb3O008ogb3O003o`000?nTFjCoY5^T00OoY5^T
00?o0000oiEZUOnEJYD01onEJYD00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?o=</gocC;=00cocC;=
00?o0000ol<l`ol000000_l0000:ojEJY@03o`000?oO8=oogb3O00Sogb3O00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oiA[UonDJi@04onDJi@03o`000?niA[Wo^DJi00co^DJi0_l0
0003oj]DZ`03o`000?nfBKKo0000017o[5>/00?o0000oj1OX?nPGj001onPGj000ol0003oPGj1oh5n
P@04oh5nP@;o00002?miQWT00ol0003oMhQgogN8M`0>ogN8M`;o00002?mlPg`00ol0003oY5^TojAK
Y006ojAKY003o`000?nEJYGoUFZE00WoUFZE00?o0000oj]DZon[E:/02On[E:/00ol0003ocC;=oldb
c@0=oldbc@03o`000?o3?<?o`cc300;o`cc30ol00007ojEJY@03o`000?oO8=oogb3O00Oogb3O00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oiA[UonDJi@05onDJi@03o`000?niA[Wo
^DJi00Wo^DJi0_l00006oj]DZ`03o`000?n/Djco[5>/013o[5>/00?o0000oj1OX?nPGj001_nPGj00
0ol0003oPGj1oh5nP@07oh5nP@03o`000?miQWWoNHIi00CoNHIi0ol0000>ogN8M`03o`000?mRWF;o
HYeR00?o00001OmlPg`00ol0003oY5^TojAKY006ojAKY003o`000?nEJYGoUFZE00[oUFZE00?o0000
oj]DZon[E:/02?n[E:/00ol0003ocC;=oldbc@0=oldbc@03o`000?o3?<?o`cc300Go`cc30ol00004
ojEJY@03o`000?oO8=oogb3O00Oogb3O00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oiA[UonDJi@06onDJi@03o`000?niA[Wo^DJi00Go^DJi0ol00008oj]DZ`03o`000?n/Djco[5>/
017o[5>/00Co0000oj1OX?nPGj3oX5nP1?l0000;oh5nP@;o000000CoNHIio`000?l0003o00000on>
LHh2o`0000_oMhQg00?o0000of:MH_mRWF801?mRWF82o`0000?oO8=l00?o0000ojAKY?nTFj@01_nT
Fj@00ol0003oUFZEoiEZU@0:oiEZU@03o`000?n[E:_oZeB[00OoZeB[00?o0000oldbcOo=</d03_o=
</d00ol0003o`cc3ol<l``08ol<l``Co00002_oO8=l00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiA[UonDJi@07onDJi@03o`000?niA[Wo^DJi00;o^DJi0_l0000<oj]DZ`03o`000?n/Djco
[5>/013o[5>/1?l00003oiEZU@03o`000?n1OX7oPGj100_oPGj100?o0000ohiaS_n>LHh01_n>LHh0
0ol0003oMhQgogN8M`07ogN8M`03o`000?mRWF;oHYeR00OoHYeR3?l0000>oiEZU@03o`000?n[E:_o
ZeB[00KoZeB[00?o0000oldbcOo=</d03_o=</d00ol0003o`cc3ol<l``0;ol<l``03o`000?oO8=oo
gb3O00Oogb3O00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oU6^GoiA[U00WoiA[U00Co0000okU6
^Ol0003o00003_n[E:/00ol0003o[5>/ojaC[00?ojaC[003o`000?nEJYGoUFZE00KoUFZE00?o0000
oh5nPOn1OX402_n1OX400ol0003oSW6>ohiaSP07ohiaSP;o00001_mgR7L00ol0003oHYeRof:MHP08
of:MHP03o`000?nZEJ[oZUFZ00SoZUFZ00?o0000oiEZUOnEJYD03?nEJYD00ol0003oZeB[oj]DZ`05
oj]DZ`03o`000?o=</gocC;=00oocC;=0_l0000=ol<l``03o`000?oO8=oogb3O00Kogb3O00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oU6^GoiA[U00[oiA[U00?o0000oj]DZon[E:/03_n[E:/00ol0
003o[5>/ojaC[00>ojaC[003o`000?nEJYGoUFZE00OoUFZE00?o0000oh5nPOn1OX402_n1OX400ol0
003oSW6>ohiaSP09ohiaSP;o00000omgR7L00ol0003oHYeRof:MHP09of:MHP03o`000?nZEJ[oZUFZ
00WoZUFZ00?o0000oiEZUOnEJYD02_nEJYD4o`0000CoZeB[00?o0000oldbcOo=</d04?o=</d01?l0
003o`Sg2o`000?l0000<ol<l``03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oU6^GoiA[U00[oiA[U00?o0000oj]DZon[E:/03on[E:/@o`0000[oUFZE00?o0000oh5n
POn1OX402On1OX400ol0003oJiA[o`00000<ohiaSP05o`000?mgR7Oo0000ofBKI?l000002_mRWF80
0ol0003oZUFZojYEZP09ojYEZP03o`000?nEJYGoUFZE00OoUFZE0ol00004ok9=/P?o000000?oZeB[
o`000?o=</d04Oo=</d01?l0003o`Sg2ol8m`_o2?L82o`0000_o`cc300?o0000omlPgooO8=l00ooO
8=l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onDJiOoU6^D02_oU6^D00ol0003oZeB[oj]DZ`0?
oj]DZ`03o`000?nbCK;o/Tfb00co/Tfb00?o0000oiEZUOnEJYD02OnEJYD00ol0003oPGj1oh5nP@07
oh5nP@04o`000?m[U6_oJiA[o`0000goSW6>00Go0000ofBKI?mTVfCoI9]To`000009of:MHP03o`00
0?nZEJ[oZUFZ00[oZUFZ00?o0000oiEZUOnEJYD00onEJYD3o`0000[o/Tfb00?o0000oldbcOo=</d0
4?o=</d00ol0003o`Sg2ol8m`P04ol8m`P;o00002_o3?<<00ol0003ogb3OomlPg`04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coiA[U00?o0000oj]DZon[E:/03on[E:/00ol0003o/Tfbok9=/P0<ok9=/P03o`000?nE
JYGoUFZE00WoUFZE00?o0000oh5nPOn1OX401_n1OX400ol0003oJiA[of^DJ`02of^DJ`03o`000?n>
LHkoSW6>00[oSW6>00?o0000ofBKI?mTVf@00_mTVf@00ol0003oHYeRof:MHP06of:MHP03o`000?nZ
EJ[oZUFZ00[oZUFZ00?o0000oiEZUOnEJYD00ol0000=ok9=/P03o`000?o=</gocC;=013ocC;=00?o
0000ol8m`_o2?L801_o2?L82o`0000Wo`cc30_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000onDJiOoU6^D02_oU6^D00ol0003oZeB[oj]DZ`0=oj]DZ`?o00003onbCK80
0ol0003oUFZEoiEZU@08oiEZU@03o`000?n1OX7oPGj100GoPGj100?o0000of^DJom[U6/00om[U6/0
0ol0003oSW6>ohiaSP0:ohiaSP03o`000?mTVfCoI9]T00?oI9]T00?o0000of:MH_mRWF801OmRWF80
0ol0003oZUFZojYEZP0;ojYEZP;o00004OnbCK800ol0003ocC;=oldbc@0?oldbc@03o`000?o2?L;o
`Sg200So`Sg20_l00007ol<l``03o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000onDJiOoU6^D02?oU6^D00ol0003oZeB[oj]DZ`09oj]DZ`Go00000_nCK9<00ol0
003o/Tfbok9=/P0=ok9=/P03o`000?nEJYGoUFZE00WoUFZE00?o0000oh5nPOn1OX401?n1OX400ol0
003oJiA[of^DJ`04of^DJ`03o`000?n>LHkoSW6>00SoSW6>00?o0000ofBKI?mTVf@01OmTVf@00ol0
003oHYeRof:MHP04of:MHP03o`000?nZEJ[oZUFZ00_oZUFZ00?o0000ok9=/_nbCK804?nbCK800ol0
003ocC;=oldbc@0?oldbc@03o`000?o2?L;o`Sg200[o`Sg20_l00004ol<l``03o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003oiA[UonDJi@07onDJi@03o`000?n[E:_oZeB[00CoZeB[1Ol00007oi=/T`03
o`000?nbCK;o/Tfb00go/Tfb00?o0000oiEZUOnEJYD02OnEJYD00ol0003oPGj1oh5nP@03oh5nP@03
o`000?m[U6_oJiA[00GoJiA[00?o0000ohiaS_n>LHh02?n>LHh00ol0003oI9]TofBKI006ofBKI003
o`000?mRWF;oHYeR00?oHYeR00?o0000ojYEZ_nZEJX02onZEJX00ol0003o/Tfbok9=/P0@ok9=/P03
o`000?o=</gocC;=00oocC;=00?o0000ol8m`_o2?L803?o2?L82o`000003ol<l`ol0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oU6^GoiA[U00OoiA[U00?o0000oj]DZol00000
1?l0000<oi=/T`03o`000?nbCK;o/Tfb00ko/Tfb00?o0000oiEZUOnEJYD02?nEJYD00ol0003oPGj1
oh5nP@02oh5nP@03o`000?m[U6_oJiA[00OoJiA[00?o0000ohiaS_n>LHh01on>LHh00ol0003oI9]T
ofBKI007ofBKI003o`000?mRWF;oHYeR00;oHYeR00?o0000ojYEZ_nZEJX02onZEJX00ol0003o/Tfb
ok9=/P0Aok9=/P03o`000?o=</gocC;=00gocC;=00?o0000ol8m`_o2?L803oo2?L800ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onDJiOoU6^D01OoU6^D3o`00017oTfbC00?o0000ok9=/_nbCK803_nb
CK800ol0003oUFZEoiEZU@09oiEZU@04o`000?n1OX7oPGj1o`0000[oJiA[00?o0000ohiaS_n>LHh0
1on>LHh00ol0003oI9]TofBKI008ofBKI005o`000?mRWF;oHYeRof:MH_l000003OnZEJX00ol0003o
/Tfbok9=/P0Aok9=/P?o00003Oo=</d00ol0003o`Sg2ol8m`P0?ol8m`P03o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oU6^D2o`0000;o/Dja00?o0000oi=/TonCK9<03onCK9<00ol0003o
/Tfbok9=/P0>ok9=/P03o`000?nEJYGoUFZE00SoUFZE1Ol0000;of^DJ`03o`000?n>LHkoSW6>00Ko
SW6>00?o0000ofBKI?mTVf@02OmTVf@01?l0003oHYeRof:MH_l0000=ojYEZP03o`000?nbCK;o/Tfb
017o/Tfb00?o0000oi9]T_nBKI800ol0000:oldbc@Co00003Oo2?L800ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000omdRgOoM8]gogB;M0_l00005ok5>/@03o`000?nCK9?oTfbC00koTfbC00?o0000ok9=
/_nbCK803_nbCK800ol0003oUFZEoiEZU@07oiEZU@03o`000?nCK9?oTfbC00?oTfbC00?o0000of^D
Jom[U6/02?m[U6/00ol0003oSW6>ohiaSP05ohiaSP03o`000?mTVfCoI9]T00[oI9]T1Ol0000<ojYE
ZP03o`000?nbCK;o/Tfb013o/Tfb00?o0000oi9]T_nBKI801?nBKI83o`0000KocC;=00?o0000ol`c
c?o<<l`00_o<<l`5o`0000So`Sg200?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oM8]gogB;M00?o
gB;M00?o0000ok5>/OnaC[401?naC[400ol0003oTfbCoi=/T`0=oi=/T`03o`000?nbCK;o/Tfb00oo
/Tfb00?o0000oiEZUOnEJYD01?nEJYD2o`0000OoTfbC00?o0000of^DJom[U6/01om[U6/Eo`0000Go
LHia00?o0000ojYEZ_nZEJX02?nZEJX3o`00013o/Tfb00?o0000oi9]T_nBKI802?nBKI83o`0000;o
cC;=00?o0000ol`cc?o<<l`02?o<<l`5o`0000?o`Sg200?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oM8]gogB;M00CogB;M00?o0000ok5>/OnaC[401OnaC[400ol0003oTfbCoi=/T`0;oi=/T`Co0000
3onbCK800ol0003oUFZEoiEZU@03oiEZU@03o`000?nCK9?oTfbC00SoTfbC00?o0000of^DJom[U6/0
1?m[U6/2o`0000SoTfbC00?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oLHiaog6>L@05og6>L@;o0000
1_nZEJX2o`0000?oWf2O00?o0000ok9=/_nbCK803?nbCK800ol0003oTVfBoi9]TP0<oi9]TP;o0000
4?o<<l`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003ogB;MomdRg@05omdRg@03o`000?naC[7o/Dja00Ko/Dja00?o
0000oi=/TonCK9<02OnCK9<00ol0003oN8Mho`000002oiEZU@?o00003?nbCK801?l0003oUFZEoiEZ
UOnEJYD2o`0000coTfbC00?o0000of^DJom[U6/00_m[U6/00ol0003oTfbCoi=/T`08oi=/T`03o`00
0?n4NhCoQ7^400SoQ7^400?o0000og6>LOmaSW401omaSW400ol0003oZUFZojYEZP02ojYEZP03o`00
0?nOH9ooWf2O00CoWf2O0_l0000;ok9=/P03o`000?nBKI;oTVfB00coTVfB00?o0000oj=LXol00000
4_o<<l`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003ogB;MomdRg@06omdRg@03o`000?naC[7o/Dja00Oo/Dja00?o
0000oi=/TonCK9<01_nCK9<2o`0000;oN8Mh00?o0000oiEZUOnEJYD00onEJYD3o`0000[o/Tfb00?o
0000oiEZUOl000003onCK9<01?l0003oJiA[o`000?l0000;oi=/T`03o`000?n4NhCoQ7^400SoQ7^4
00?o0000og6>LOmaSW402?maSW401?l0003oZUFZo`000?l00009oimPW`03o`000?nbCK;o/Tfb00Oo
/Tfb00?o0000oi9]T_nBKI803?nBKI801?l0003oXebSoj=LXol0000Col`cc003o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000omdRgOoM8]d01ooM8]d00ol0003o/Djaok5>/@08ok5>/@03o`000?nCK9?oTfbC00Co
TfbC00?o0000ogR7N?mhQgP00omhQgP00ol0003oUFZEoiEZU@05oiEZU@?o00001_nbCK84o`00013o
TfbC00?o0000oi=/TonCK9<03?nCK9<00ol0003oQ7^4ohAkQ007ohAkQ003o`000?maSW7oLHia00Wo
LHia00?o0000oimPWonOH9l02_nOH9l2o`0000Ko/Tfb00?o0000oi9]T_nBKI803?nBKI800ol0003o
XebSoj=LX`02oj=LX`03o`000?o<<lcoc3?<00ooc3?<00?o0000omTVfOl000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003ogB;MomdRg@08omdRg@03o`000?naC[7o/Dja00Wo/Dja00Co0000oi=/TonCK9?o
TfbC0_l00006ogR7N003o`000?nEJYGoUFZE00SoUFZE0ol000000onbCK;o0000o`000004oi]TV`03
o`000?nCK9?oTfbC00goTfbC00?o0000oi=/TonCK9<03?nCK9<00ol0003oQ7^4ohAkQ007ohAkQ003
o`000?maSW7oLHia00WoLHia00?o0000oimPWonOH9l03?nOH9l00ol0003o/Tfbok9=/P03o`0000ko
TVfB00?o0000oj=LXonSG:<00onSG:<00ol0003oc3?<ol`cc00>ol`cc005o`000?oI9]WofBKIomTV
fOl000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003ogB;MomdRg@09omdRg@03o`000?naC[7o/Dja00[o
/Dja00?o0000oi=/Tol000002?mhQgP00ol0003oUFZEoiEZU@0;oiEZU@03o`000?nKI9_oVfBK00Go
VfBK00?o0000oi=/TonCK9<03?nCK9<00ol0003oTfbCoi=/T`0<oi=/T`03o`000?n4NhCoQ7^400Oo
Q7^400?o0000og6>LOmaSW402?maSW42o`0000ooWf2O0_l00002oj5NX@03o`000?nBKI;oTVfB00_o
TVfB00?o0000oj=LXonSG:<01?nSG:<00ol0003oc3?<ol`cc00=ol`cc003o`000?oI9]WofBKI00?o
fBKI00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omdRg@03o`000?naC[7o/Dja00_o/Dja00?o0000ogR7N?mhQgP0
1omhQgP00ol0003oUFZEoiEZU@0;oiEZU@03o`000?nKI9_oVfBK00KoVfBK00?o0000oi=/TonCK9<0
2onCK9<2o`0000goTfbC00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oLHiaog6>L@07og6>L@04o`00
0?mlPgcoO8=lo`0000koWf2O00?o0000oj5NXOnQGZ400_nQGZ400ol0003oTVfBoi9]TP09oi9]TP03
o`000?nSG:?oXebS00KoXebS00?o0000ol`cc?o<<l`02oo<<l`00ol0003ofBKIomTVf@05omTVf@04
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000SogB;M00?o0000ok5>/OnaC[402_naC[42o`0000Wo
N8Mh00?o0000oiEZUOnEJYD02onEJYD00ol0003oVfBKoi]TV`07oi]TV`03o`000?nCK9?oTfbC00Wo
TfbC00Co0000of:MH_mRWF;o00003?nCK9<00ol0003oQ7^4ohAkQ007ohAkQ003o`000?maSW7oLHia
00KoLHia00Go0000ogb3O?mlPgcoO8=lo`00000>oimPW`03o`000?nQGZ7oXEjQ00?oXEjQ00?o0000
oi9]T_nBKI801onBKI800ol0003oXebSoj=LX`07oj=LX`03o`000?o<<lcoc3?<00[oc3?<00?o0000
omTVfOoI9]T01ooI9]T00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006omdRg@03o`000?naC[7o/Dja
00Wo/Dja00Co0000ohebSOn=LXgo00002OmhQgP00ol0003oUFZEoiEZU@09oiEZU@03o`000?nKI9_o
VfBK00WoVfBK00?o0000oi=/TonCK9<01onCK9<00ol0003oHYeRof:MHP02of:MHP03o`000?nCK9?o
TfbC00WoTfbC00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oLHiaog6>L@05og6>L@03o`000?mlPgco
O8=l00?oO8=l00?o0000oimPWonOH9l02_nOH9l00ol0003oXEjQoj5NX@05oj5NX@03o`000?nBKI;o
TVfB00GoTVfB00?o0000oj=LXonSG:<02?nSG:<00ol0003oc3?<ol`cc009ol`cc003o`000?oI9]Wo
fBKI00SofBKI00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oM8]d3o`0000Wo/Dja00?o0000oheb
SOn=LXd00_n=LXd00ol0003oN8MhogR7N006ogR7N003o`000?nEJYGoUFZE00WoUFZE00?o0000oi]T
VonKI9/02_nKI9/00ol0003oTfbCoi=/T`05oi=/T`03o`000?mRWF;oHYeR00CoHYeR00?o0000oi=/
TonCK9<02?nCK9<00ol0003oQ7^4ohAkQ007ohAkQ003o`000?maSW7oLHia00CoLHia00?o0000ogb3
O?mlPg`01?mlPg`00ol0003oWf2OoimPW`0:oimPW`03o`000?nQGZ7oXEjQ00KoXEjQ00?o0000oi9]
T_nBKI800onBKI800ol0003oXebSoj=LX`09oj=LX`03o`000?o<<lcoc3?<00Soc3?<00?o0000omTV
fOoI9]T02OoI9]T00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omPWf0?o00001OnaC[400ol0003o
SG:=ohebS@03ohebS@03o`000?mhQgSoN8Mh00KoN8Mh00?o0000oiEZUOnEJYD02OnEJYD00ol0003o
VfBKoi]TV`0;oi]TV`03o`000?nCK9?oTfbC00?oTfbC00?o0000of:MH_mRWF801_mRWF800ol0003o
TfbCoi=/T`08oi=/T`03o`000?n4NhCoQ7^400KoQ7^400?o0000og6>LOmaSW400_maSW42o`0000So
O8=l00?o0000oimPWonOH9l02OnOH9l00ol0003oXEjQoj5NX@07oj5NX@05o`000?nBKI;oTVfBoi9]
T_l000003OnSG:<00ol0003oc3?<ol`cc006ol`cc003o`000?oI9]WofBKI00[ofBKI00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oH9mSof2OH00Gof2OH0ol000000onaC[7o0000ohebS@06ohebS@03
o`000?mhQgSoN8Mh00GoN8Mh00?o0000oiEZUOnEJYD02OnEJYD00ol0003oVfBKoi]TV`0<oi]TV`05
o`000?nCK9?oTfbCoi=/Tol000002_mRWF800ol0003oTfbCoi=/T`07oi=/T`03o`000?n4NhCoQ7^4
00KoQ7^400?o0000og6>LOl000000_l000000onWF:Oo0000ogb3O007ogb3O003o`000?nOH9ooWf2O
00SoWf2O00?o0000oj5NXOnQGZ402OnQGZ400ol0003oTVfBo`00000=oj=LX`Co00001Oo<<l`00ol0
003ofBKIomTVf@0;omTVf@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003of2OHomPWf008omPWf003
o`000?n=LXgoSG:=00OoSG:=00?o0000ogR7N?mhQgP01?mhQgP00ol0003oUFZEoiEZU@09oiEZU@03
o`000?nKI9_oVfBK00goVfBK00?o0000oi=/Tol000003?mRWF8:o`0000OoQ7^40ol00005ojMHY`03
o`000?mlPgcoO8=l00KoO8=l00?o0000oimPWonOH9l01onOH9l00ol0003oXEjQoj5NX@0:oj5NX@03
o`000?nSG:?oXebS00_oXebS00?o0000okA;]?ndBk@00_ndBk@3o`000003ol`cc?l0003ofBKI00_o
fBKI0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omPWf?oH9mP02OoH9mP00ol0003oSG:=ohebS@07ohebS@03o`00
0?mhQgSoN8Mh00GoN8Mh00?o0000oiEZUOnEJYD01onEJYD00ol0003oVfBKoi]TV`0?oi]TV`;o0000
2omRWF800ol0003oWV6NoiiQWP07oiiQWP03o`000?n4NhCoQ7^400;oQ7^40ol00008ojMHY`03o`00
0?mlPgcoO8=l00KoO8=l00?o0000oimPWonOH9l01onOH9l00ol0003oXEjQoj5NX@0:oj5NX@03o`00
0?nSG:?oXebS00[oXebS00?o0000okA;]?ndBk@01_ndBk@00ol0003ofBKIomTVf@08omTVf@?o0000
0_oS7><00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omPWf?oH9mP02OoH9mP00ol0003oSG:=oheb
S@08ohebS@03o`000?mhQgSoN8Mh00CoN8Mh00?o0000oiEZUOnEJYD01onEJYD00ol0003oVfBKoi]T
V`0>oi]TV`04o`000?mcS7?oLhaco`0000WoHYeR00?o0000oiiQW_nNHIh02OnNHIh01?l0003oQ7^4
o`000?l0000<ojMHY`03o`000?mlPgcoO8=l00KoO8=l00?o0000oimPWonOH9l01_nOH9l00ol0003o
XEjQoj5NX@0;oj5NX@03o`000?nSG:?oXebS00OoXebS0_l00009okA;]003o`000?oI9]WofBKI00Co
fBKI1?l00006on<Lh`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003of2OHomPWf009omPWf003o`00
0?n=LXgoSG:=00SoSG:=00?o0000ogR7N?mhQgP00omhQgP>o`0000goVfBK00?o0000og><LomcS7<0
0_mcS7<00ol0003oHYeRof:MHP05of:MHP03o`000?nNHIkoWV6N00_oWV6N00?o0000ojMHYonWF:L0
3?nWF:L00ol0003oO8=logb3O006ogb3O003o`000?nOH9ooWf2O00GoWf2O00?o0000oj5NXOnQGZ40
3?nQGZ400ol0003oXebSoj=LX`06oj=LX`03o`000?ndBkCo]4^d00[o]4^d00?o0000omTVfOoI9]T0
0ol0000:on<Lh`?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oH9mSof2OH00_of2OH00?o0000ohebSOn=LXd02?n=
LXd01Ol0003oN8MhogR7N?mhQgSo000000_oRgB;00?o0000odbcC?m</d`00ol00009oi]TV`03o`00
0?mcS7?oLhac00CoLhac00?o0000of:MH_mRWF800omRWF800ol0003oWV6NoiiQWP0<oiiQWP03o`00
0?nWF:OoYeRW00goYeRW00?o0000ogb3O?mlPg`01_mlPg`00ol0003oWf2OoimPW`03oimPW`?o0000
3OnQGZ400ol0003oXebSoj=LX`05oj=LX`03o`000?ndBkCo]4^d00co]4^d0_l0000=on<Lh`03o`00
0?ok1?_on`Ck00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oH9mSof2OH00_of2OH00?o0000ohebSOn=LXd02?n=
LXd4o`0000coRgB;00?o0000odbcC?m</d`00om</d`3o`0000GoVfBK00?o0000og><LomcS7<01_mc
S7<01Ol0003oHYeRof:MH_mRWF;o000000ooWV6N00?o0000ojMHYonWF:L03OnWF:L00ol0003oO8=l
ogb3O006ogb3O003o`000?nOH9ooWf2O00?o00000omoOgl00ol0003oXEjQoj5NX@0;oj5NX@03o`00
0?nSG:?oXebS00?oXebS00?o0000okA;]?ndBk@03OndBk@00ol0003ohacSon<Lh`0;on<Lh`03o`00
0?ok1?_on`Ck00Con`Ck0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omPWf?oH9mP02_oH9mP3o`0000KoSG:=0ol0
0003ohQgR003o`000?n;M8_oRgB;00[oRgB;00?o0000odbcC?m</d`01_m</d`3o`000003oi]TVol0
003oLhac00WoLhac00?o0000of:MH_l000004?nNHIh00ol0003oYeRWojMHY`0=ojMHY`03o`000?ml
PgcoO8=l00OoO8=l0_l00007ogmoO`03o`000?nQGZ7oXEjQ00[oXEjQ00Co0000oj=LXonSG:?oXebS
0ol0000?okA;]003o`000?oS7>?ohacS00_ohacS00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omPWf?oH9mP02_oH
9mP01?l0003o_D:moke2_Onm@[d2o`000004ohebSOl0003o0000o`0000KoR7N800?o0000oh]dRon;
M8/02_n;M8/00ol0003oC;=<odbcC009odbcC003o`000?mcS7?oLhac00[oLhac00?o0000oiiQW_nN
HIh03onNHIh00ol0003oYeRWojMHY`0>ojMHY`03o`000?mlPgcoO8=l00KoO8=l00?o0000ogmoOomo
Ogl01omoOgl4o`0000SoXEjQ00Co0000oj=LXonSG:?o00000omkQ7/2o`0000go]4^d00?o0000on<L
hooS7><02_oS7><00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omPWf?oH9mP02OoH9mP00ol0003o
_D:moke2_@04oke2_@03o`000?n8MhSoR7N800OoR7N800?o0000oh]dRon;M8/02On;M8/00ol0003o
C;=<odbcC00:odbcC003o`000?mcS7?oLhac00[oLhac00?o0000oiiQW_nNHIh03onNHIh00ol0003o
YeRWojMHY`0>ojMHY`03o`000?mlPgcoO8=l00GoO8=l00?o0000ogmoOomoOgl02?moOgl01?l0003o
T6n@oi1_T?n@Ki07o`0000;oXEjQ0_l00006og^4N`;o00003?ndBk@00ol0003ohacSon<Lh`09on<L
h`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003of2OHomPWf008omPWf003o`000?nm@[go_D:m00Go
_D:m00?o0000ohQgR?n8MhP02?n8MhP00ol0003oRgB;oh]dR`08oh]dR`03o`000?m</dcoC;=<00[o
C;=<00?o0000og><LomcS7<02omcS7<00ol0003oWV6NoiiQWP0>oiiQWP03o`000?nWF:OoYeRW00ko
YeRW1Ol00002ogb3O003o`000?moOgooOgmo00WoOgmo00?o0000oi1_T?n@Ki002?n@Ki03o`0000Wo
NhAk0_l0000:okA;]003o`000?oS7>?ohacS00SohacS00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oH9mSof2OH00Sof2OH00?o0000oke2_Onm@[d01onm@[d00ol0003oR7N8ohQgR007ohQgR003o`00
0?n;M8_oRgB;00SoRgB;00?o0000odbcC?m</d`02_m</d`00ol0003oLhacog><L`0:og><L`;o0000
3_nNHIh3o`0000goYeRW0ol00005ojYEZP;o00002omoOgl00ol0003oT6n@oi1_T00;oi1_T0;o0000
2_mkQ7/2o`0000Oo]4^d0ol00009on<Lh`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:oke2_@03o`00
0?n8MhSoR7N800OoR7N800?o0000oh]dRon;M8/02?n;M8/>o`0000WoLhac0ol000000omC[5?o0000
oiiQWP0:oiiQWP?o00000_n^DJh00ol0003oYeRWojMHY`09ojMHY`;o00002OnZEJX00ol0003oOgmo
ogmoO`09ogmoO`03o`000?n@Ki3oT6n@00_oT6n@00?o0000oiiQW_l000002omkQ7/2o`0000Co]4^d
00Co0000omTVfOoI9]WofBKI0_l00007on<Lh`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003o_D:m
oke2_@09oke2_@03o`000?n8MhSoR7N800KoR7N800?o0000oh]dRon;M8/02?n;M8/00ol0003oG:=L
oebSG00:oebSG003o`000?mcS7?oLhac00CoLhac0ol00005oe>/D`03o`000?nNHIkoWV6N00CoWV6N
1?l00006ojiA[P03o`000?nWF:OoYeRW00KoYeRW0_l0000;ojYEZP03o`000?moOgooOgmo00WoOgmo
00?o0000oi1_T?n@Ki002_n@Ki001Ol0003oWV6NoiiQW_nNHIko000000coNhAk0_l000000ondBkCo
0000omTVf@05omTVf@03o`000?oS7>?ohacS00?ohacS00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?nm@[go_D:m00So_D:m00?o0000ohQgR?n8MhP01_n8MhP00ol0003oRgB;oh]dR`07oh]dR`03o`00
0?mLXecoG:=L00_oG:=L00?o0000og><LomcS7<00_mcS7<2o`0000WoDjaC00?o0000oiiQW_nNHIh0
0ol0000;ojiA[P03o`000?nWF:OoYeRW00;oYeRW0ol0000>ojYEZP03o`000?moOgooOgmo00OoOgmo
00?o0000oi1_T?n@Ki002on@Ki000ol0003oWV6NoiiQWP02oiiQWP03o`000?mkQ7_oNhAk00_oNhAk
00?o0000omTVfOoI9]T01_oI9]T2o`0000?ohacS00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?nm
@[go_D:m00Oo_D:m00?o0000ohQgR?n8MhP01on8MhP00ol0003oRgB;oh]dR`05oh]dR`?o00003OmL
Xe`4o`0000_oDjaC0ol0000?ojiA[P04o`000?nWF:Oo0000o`00017oZUFZ00?o0000ogmoOomoOgl0
1omoOgl00ol0003oT6n@oi1_T00:oi1_T003o`000?nNHIkoWV6N00CoWV6N00?o0000og^4NomkQ7/0
1omkQ7/3o`0000_ofBKI1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oke2_Onm@[d02?nm@[d00ol0003oR7N8ohQg
R006ohQgR003o`000?n;M8_oRgB;00;oRgB;0ol00003ogV6N@03o`000?mLXecoG:=L00[oG:=L00?o
0000oe>/DomC[5<02omC[5<00ol0003oGj1Oo`00000AojiA[P03o`000?nZEJ[oZUFZ017oZUFZ00?o
0000ogmoOomoOgl01omoOgl00ol0003oT6n@oi1_T00:oi1_T003o`000?nNHIkoWV6N00GoWV6N00Co
0000og^4NomkQ7_oNhAk1Ol00002ohiaSP03o`000?oI9]WofBKI00WofBKI00Co0000ooX5n_oj1O[o
nPGj0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oke2_Onm@[d01onm@[d00ol0003oR7N8ohQgR005ohQgR0?o0000
00?oRgB;o`000?l000001omiQWT00ol0003oG:=LoebSG008oebSG0?o00002_mC[5<2o`0000;oGj1O
00?o0000ojiA[_n^DJh03on^DJh00ol0003oZUFZojYEZP0AojYEZP03o`000?moOgooOgmo00OoOgmo
00?o0000oi1_T?n@Ki002On@Ki000ol0003oWV6NoiiQWP07oiiQWP?o00001on>LHh00ol0003ofBKI
omTVf@09omTVf@03o`000?oj1O[onPGj00ConPGj0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oke2_Onm@[d01onm
@[d4o`0000;oR7N80_l00003oiUVV@03o`000?miQWWoNHIi00SoNHIi0_l00006oebSG0;o00000omS
W6<00ol0003oDjaCoe>/D`06oe>/D`03o`000?mOX5ooGj1O00?oGj1O00?o0000ojiA[_n^DJh03_n^
DJh00ol0003oZUFZojYEZP0BojYEZP03o`000?moOgooOgmo00GoOgmo00?o0000oi1_T?n@Ki002On@
Ki000ol0003oWV6NoiiQWP08oiiQWP03o`000?n>LHkoSW6>00OoSW6>00?o0000omTVfOoI9]T02?oI
9]T00ol0003onPGjooX5nP07ooX5nP;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?nm@[go_D:m00Co_D:m0_l00004
om4^d@;o00001OnIIYT00ol0003oNHIiogV6N@0:ogV6N@03o`000?mLXecoG:=L00;oG:=L00?o0000
of>LHomSW6<01?mSW6<00ol0003oDjaCoe>/D`04oe>/D`03o`000?mOX5ooGj1O00CoGj1O00?o0000
ojiA[_n^DJh03_n^DJh00ol0003oZUFZojYEZP0BojYEZP[o00002_n@Ki000ol0003oWV6NoiiQWP08
oiiQWP03o`000?n>LHkoSW6>00OoSW6>00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP09
ooX5nP?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_D:moke2_Onm@[d2o`0000OodBkA00?o0000oiUVVOnIIYT01?nIIYT0
0ol0003oNHIiogV6N@0:ogV6N@04o`000?mLXeco0000o`0000SoHiaS00Co0000oe>/DomC[5?oDjaC
0_l00007oenPG`03o`000?n^DJko[U6^00ko[U6^00?o0000ojYEZ_nZEJX04_nZEJX00ol0003oS7><
ohacS007ohacS003o`000?n@Ki3oT6n@00KoT6n@00?o0000oiiQW_nNHIh02_nNHIh00ol0003oSW6>
ohiaSP06ohiaSP03o`000?oI9]WofBKI00SofBKI00?o0000ooX5n_oj1OX03?oj1OX00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?nm
@[go0000o`0000WodBkA00?o0000oiUVVOnIIYT01?nIIYT00ol0003oNHIiogV6N@0;ogV6N@03o`00
0?mSW6?oHiaS00WoHiaS00?o0000oe>/Dol000002OmOX5l00ol0003o[U6^ojiA[P0>ojiA[P;o0000
4_nZEJX00ol0003oS7><ohacS009ohacS0;o00001_n@Ki000ol0003oWV6NoiiQWP0:oiiQWP03o`00
0?n>LHkoSW6>00KoSW6>00?o0000omTVfOoI9]T02?oI9]T00ol0003onPGjooX5nP0<ooX5nP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om4^dOoA;]402OoA;]400ol0003oVFJIoiUVV@05oiUVV@03o`000?miQWWoNHIi00[oNHIi00?o
0000of>LHomSW6<02_mSW6<2o`0000WoGj1O00?o0000ojiA[_n^DJh03_n^DJh00ol0003oVfBKo`00
0002o`0000ooZUFZ00?o0000ohacS?n<Lh`02on<Lh`00ol0003oT6n@oi1_T003o`0000goWV6N00?o
0000ohiaS_n>LHh01_n>LHh00ol0003ofBKIomTVf@07omTVf@03o`000?oj1O[onPGj00conPGj00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odBkAom4^d@09om4^d@03o`000?nIIYWoVFJI00GoVFJI00?o0000ogV6NOmiQWT02OmiQWT2
o`0000_oHiaS0_l0000;oenPG`03o`000?n^DJko[U6^00co[U6^00?o0000oi]TVonKI9/00onKI9/3
o`0000coZUFZ00?o0000ohacS?n<Lh`03?n<Lh`2o`0000;oR7N800?o0000oiiQW_nNHIh03?nNHIh0
0ol0003oSW6>ohiaSP05ohiaSP03o`000?oI9]WofBKI00OofBKI00?o0000ooX5n_oj1OX03?oj1OX0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oA;]7odBkA00[odBkA00?o0000oiUVVOnIIYT01_nIIYT00ol0003oNHIiogV6N@07ogV6
N@03o`000?mUVVGo000000[oHiaS00Co0000odn`Com?/4oo00002_mOX5l00ol0003o[U6^ojiA[P0<
ojiA[P03o`000?nKI9_oVfBK00KoVfBK0_l00008ojYEZP;o00003on<Lh`00ol0003oR7N8ohQgR002
ohQgR003o`000?nNHIkoWV6N00_oWV6N00?o0000ohiaS_n>LHh01On>LHh00ol0003ofBKIomTVf@07
omTVf@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odBkAom4^d@0:om4^d@03o`000?nIIYWoVFJI
00KoVFJI00?o0000ogV6NOmiQWT01_miQWT01Ol0003oIIYUofFJIOmUVVGo000000SoHiaS00?o0000
odn`Com?/4l00_m?/4l00ol0003oGj1OoenPG`06oenPG`Co00003?n^DJh00ol0003oVfBKoi]TV`08
oi]TV`?o00000_nZEJX3o`000003ohQgR?l0003oS7><00goS7><00?o0000ohQgR?n8MhP01?n8MhP0
0ol0003oWV6NoiiQWP0:oiiQWP03o`000?n>LHkoSW6>00GoSW6>00?o0000omTVfOoI9]T01_oI9]T0
0ol0003onPGjooX5nP0<ooX5nP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]402ooA;]400ol0003oVFJIoiUVV@07oiUV
V@03o`000?miQWWoNHIi00?oNHIi0_l00005ofFJI@03o`000?mSW6?oHiaS00CoHiaS00?o0000odn`
Com?/4l00om?/4l00ol0003oGj1OoenPG`05oenPG`03o`000?mnPGkoOX5n00;oOX5n0ol00007ojiA
[P;o00003_nKI9/2o`0000GoR7N800?o0000ohacS?n<Lh`02_n<Lh`00ol0003oR7N8ohQgR005ohQg
R003o`000?nNHIkoWV6N00_oWV6N00?o0000ohiaS_n>LHh01?n>LHh00ol0003ofBKIomTVf@06omTV
f@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odBkAom4^d@0;om4^d@03o`000?nIIYWoVFJI00Oo
VFJI00?o0000ogV6NOmiQWT00_miQWT00ol0003oIIYUofFJI@06ofFJI@03o`000?mSW6?oHiaS00;o
HiaS00?o0000odn`Com?/4l01Om?/4l00ol0003oGj1OoenPG`02oenPG`;o00002?mnPGh3o`0000;o
[U6^0_l000000on7N8Oo0000oi]TV`0=oi]TV`03o`000?n8MhSoR7N800GoR7N800?o0000ohacS?n<
Lh`02?n<Lh`00ol0003oR7N8ohQgR007ohQgR003o`000?nNHIkoWV6N00[oWV6N00?o0000ohiaS_n>
LHh01?n>LHh00ol0003ofBKIomTVf@06omTVf@03o`000?oj1O[onPGj00conPGj00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkA
om4^d@0<om4^d@03o`000?nIIYWoVFJI00SoVFJI00Co0000ogV6NOmiQWWo00002OmUVVD01Ol0003o
HiaSof>LHomSW6?o000000SoCk1?00Go0000oenPGomOX5ooGj1Oo`00000=ogj1OP;o00001?n7N8L0
0ol0003oVfBKoi]TV`0;oi]TV`03o`000?n8MhSoR7N800KoR7N800?o0000ohacS?n<Lh`01on<Lh`0
0ol0003oR7N8ohQgR008ohQgR0Co00002?nNHIh00ol0003oSW6>ohiaSP04ohiaSP03o`000?oI9]Wo
fBKI00KofBKI00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00_odBkA0ol00009oiUV
V@03o`000?miQWWo000000_oIIYU00?o0000of>LHol000002_m?/4l00ol0003oGj1Oo`00000?ogj1
OP03o`000?n7N8OoQgR700;oQgR700?o0000oi]TVonKI9/02onKI9/00ol0003oR7N8ohQgR006ohQg
R003o`000?n<LhcoS7><00KoS7><00?o0000ohQgR?n8MhP02On8MhP01?l0003oWf2OoimPWonOH9l7
o`0000;oWV6N00?o0000ohiaS_n>LHh00on>LHh00ol0003ofBKIomTVf@05omTVf@03o`000?oj1O[o
nPGj00conPGj00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oA;]7odBkA00SodBkA0ol00003okY5^P03o`000?nIIYWoVFJI00OoVFJI00?o0000ofFJ
IOmUVVD02omUVVD00ol0003oCk1?odn`C`0:odn`C`03o`000?mnPGkoOX5n00goOX5n00?o0000ohMh
Qon7N8L01?n7N8L00ol0003oVfBKoi]TV`09oi]TV`03o`000?n8MhSoR7N800SoR7N800?o0000ohac
S?n<Lh`00on<Lh`2o`0000coR7N800?o0000oimPWonOH9l02?nOH9l<o`0000?ofBKI0ol0000=ooX5
nP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om4^dOoA;]401_oA;]43o`0000Oo^TFj00?o0000oiUVVOnIIYT01_nIIYT00ol0003o
IIYUofFJI@0;ofFJI@03o`000?m?/4ooCk1?00WoCk1?0_l0000>ogj1OP03o`000?n7N8OoQgR700Go
QgR700?o0000oi]TVonKI9/02OnKI9/00ol0003oR7N8ohQgR009ohQgR003o`000?n<Lhco000000;o
00000_n1OX400ol0003oR7N8ohQgR008ohQgR003o`000?nOH9ooWf2O00coWf2O00?o0000om/TfooK
9=/01_oK9=/3o`0000?onPGj0_l00009ooX5nP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odBkAom4^d@03om4^d@?o00002onjAKX00ol0003oVFJI
oiUVV@04oiUVV@03o`000?mUVVGoIIYU00_oIIYU0ol00007odn`C`?o000000?oLXebo`000?mnPGh0
3OmnPGh00ol0003oQgR7ohMhQ`06ohMhQ`03o`000?nKI9_oVfBK00SoVfBK00?o0000ohQgR?n8MhP0
2_n8MhP00ol0003oPGj1oh5nP@04oh5nP@03o`000?n8MhSoR7N800OoR7N800?o0000oimPWonOH9l0
2onOH9l00ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00ConPGj0ol00004ooX5nP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om4^dOl0
003o0000o`0000oo^TFj00?o0000oiUVVOnIIYT00onIIYT>o`0000?oIIYU0_l00002odn`C`?o0000
1OmbSG800ol0003oOX5nogj1OP0:ogj1OP03o`000?n7N8OoQgR700OoQgR700?o0000oi]TVonKI9/0
2?nKI9/00ol0003oR7N8ohQgR00:ohQgR003o`000?n1OX7oPGj100GoPGj100?o0000ohQgR?n8MhP0
1_n8MhP00ol0003oWf2OoimPW`0;oimPW`03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003ooX5n_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o^TFj00?o0000oiUVVOnIIYT00_nIIYT00ol0003oFZEJoeZU
FP0:oeZUFP03o`000?mUVVGoIIYU00?oIIYU0_l00009og:=LP03o`000?mnPGkoOX5n00WoOX5n00?o
0000ohMhQon7N8L02?n7N8L2o`0000SoVfBK00?o0000ohQgR?n8MhP02On8MhP00ol0003oPGj1oh5n
P@07oh5nP@03o`000?n8MhSoR7N800CoR7N800?o0000oimPWonOH9l02onOH9l00ol0003ofbCKom/T
f`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o^TFjokY5^P0?okY5^P?o000000?oVFJI
o`000?mJYEX02omJYEX00ol0003oIIYUofFJI@04ofFJI@03o`000?mbSG;oLXeb00WoLXeb00?o0000
ogj1O_mnPGh01omnPGh00ol0003oQgR7ohMhQ`09ohMhQ`04o`000?n2OH;o0000o`0000KoVfBK00?o
0000ohQgR?n8MhP02On8MhP00ol0003oPGj1oh5nP@08oh5nP@03o`000?n8MhSoR7N800?oR7N800?o
0000oimPWonOH9l02onOH9l00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o^TFjokY5^P0<okY5^P;o00000onaC[42o`0000coFZEJ00?o0000ofFJIOmUVVD01?mUVVD0
0ol0003oLXebog:=LP0:og:=LPWo00002on7N8L00ol0003oPWf2oh9mPP02oh9mPP?o00000_nKI9/0
0ol0003oR7N8ohQgR00:ohQgR003o`000?n1OX7oPGj100WoPGj100?o0000ohQgR?n8MhP00_n8MhP0
0ol0003oWf2OoimPW`0:oimPW`03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_njAKX2o`0000Go/Dja00?o0000ohMhQol000002_mJYEX00ol0003oIIYUofFJI@06ofFJ
I@03o`000?mbSG;oLXeb00WoLXeb00?o0000og><LomcS7<01OmcS7<00ol0003oQgR7ohMhQ`09ohMh
Q`03o`000?n2OH;oPWf200GoPWf20ol00009ohQgR0?o00003On1OX401Ol0003oR7N8ohQgR?n8MhSo
000000coWf2O00?o0000om/TfooK9=/02OoK9=/00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000okY5
^_njAKX01OnjAKX2o`0000Oo/Dja00Co0000ohMhQon7N8Oo00002OmJYEX00ol0003oIIYUofFJI@06
ofFJI@03o`000?mbSG;oLXeb00SoLXeb00?o0000og><LomcS7<01omcS7<00ol0003oQgR7ohMhQ`07
ohMhQ`03o`000?n2OH;oPWf200SoPWf20ol00002ohQgR0Go00000_mHYeP00ol0003oPGj1oh5nP@0<
oh5nP@03o`000?n8MhSo000000coWf2O00?o0000om/TfooK9=/02_oK9=/00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000okY5^_njAKX00_njAKX2o`0000So/Dja00?o0000ohMhQon7N8L00_n7N8L5o`00
00CoFZEJ00?o0000ofFJIOmUVVD01_mUVVD00ol0003oLXebog:=LP08og:=LP03o`000?mcS7?oLhac
00OoLhac00?o0000ohMhQon7N8L01on7N8L00ol0003oPWf2oh9mPP08oh9mPP03o`000?mHYeSoF:MH
00;o00002?mHYeP00ol0003oPGj1oh5nP@0<oh5nP@Co00002_nOH9l00ol0003ofbCKom/Tf`0:om/T
f`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o^TFjo`000?l0000:ok5>/@03o`000?n7N8OoQgR7
00;oQgR700?o0000obo@;ol_d2l00_l_d2l4o`0000WoIIYU00?o0000og:=L_mbSG802?mbSG800ol0
003oLhacog><L`08og><L`03o`000?n7N8OoQgR700GoQgR700?o0000oh9mP_n2OH802?n2OH801Ol0
003oF:MHoeRWF?mHYeSo000000[oF:MH0ol0000;oh5nP@04o`000?o5>/GoaC[5olDja@Co00001OnO
H9l00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o/Djaok5>/@0:
ok5>/@03o`000?n7N8OoQgR700?oQgR700?o0000obo@;ol_d2l01?l_d2l00ol0003oIIYUofFJI@07
ofFJI@03o`000?mbSG;oLXeb00KoLXeb0_l0000;og><L`03o`000?n7N8OoQgR700GoQgR700?o0000
oh9mP_n2OH802?n2OH800ol0003oF:MHoeRWF002oeRWF003o`000?mHYeSoF:MH00OoF:MH00?o0000
ohMhQon7N8L01?l00006oh5nP@03o`000?o5>/GoaC[500KoaC[50ol00002oimPW`03o`000?oK9=_o
fbCK00_ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?naC[7o/Dja00Wo/Dja00?o0000ohMh
Qon7N8L01?n7N8L00ol0003o;m0_obo@;`05obo@;`03o`000?mUVVGoIIYU00OoIIYU00?o0000og:=
L_mbSG800_mbSG83o`000003ogf2OOl0003oLhac00[oLhac00?o0000ohMhQon7N8L01On7N8L00ol0
003oPWf2oh9mPP07oh9mPP03o`000?mHYeSoF:MH00?oF:MH00?o0000oeRWF?mHYeP01omHYeP00ol0
003oQgR7ohMhQ`04ohMhQ`?o00000_n1OX400ol0003oaC[5olDja@0:olDja@;o00003_oK9=/00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok5>/OnaC[402OnaC[400ol0003oQgR7ohMhQ`04ohMhQ`03
o`000?l_d2oo;m0_00Ko;m0_0_l00007ofFJI@03o`000?mbSG;o000000;o00001OmmPWd00ol0003o
Lhacog><L`08og><L`?o00001?n7N8L00ol0003oPWf2oh9mPP08oh9mPP03o`000?mHYeSoF:MH00Co
F:MH00?o0000oeRWF?mHYeP01_mHYeP00ol0003oQgR7ohMhQ`07ohMhQ`;o00003_o5>/D00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djaok5>/@08ok5>/@03o`00
0?n7N8OoQgR700GoQgR700?o0000obo@;ol_d2l01?l_d2l00ol0003oI9]TofBKI003o`0000CoIIYU
0_l00008ogf2O@03o`000?mcS7?oLhac00OoLhac00Co0000oiiQW_nNHIkoWV6N0ol000000on7N8Oo
0000oh9mPP09oh9mPP03o`000?mHYeSoF:MH00CoF:MH00?o0000oeRWF?mHYeP01OmHYeP00ol0003o
QgR7ohMhQ`09ohMhQ`03o`000?o5>/GoaC[500goaC[500?o0000om/TfooK9=/02_oK9=/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok5>/OnaC[401onaC[400ol0003oQgR7ohMhQ`06ohMhQ`03o`00
0?l_d2oo;m0_00?o;m0_00?o0000ofBKI?mTVf@01?mTVf@2o`000003ofFJIOl0003oOH9m00[oOH9m
00?o0000og><LomcS7<01OmcS7<00ol0003oWV6NoiiQWP05oiiQWP03o`000?n2OH;oPWf200OoPWf2
0ol00007oeRWF003o`000?mHYeSoF:MH00CoF:MH00?o0000ohMhQon7N8L02On7N8L00ol0003oaC[5
olDja@0=olDja@03o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?na
C[7o/Dja00Go/Dja0ol00009ohMhQ`05o`000?l_d2oo;m0_obo@;ol000002OmTVf@00ol0003oOH9m
ogf2O@0;ogf2O@03o`000?mcS7?oLhac00?oLhac00?o0000oiiQW_nNHIh01_nNHIh00ol0003oPWf2
oh9mPP06oh9mPP05o`000?n4NhCoQ7^4ohAkQ?l000001omHYeP00ol0003oF:MHoeRWF003oeRWF003
o`000?n7N8OoQgR700WoQgR700?o0000olDjaOo5>/D03_o5>/D00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Djao`000004o`0000;od2o@00?o0000ohMhQon7N8L0
1on7N8L01?l0003o;m0_obo@;ol00009ofBKI0;o00003OmmPWd00ol0003oLhacog><L`02og><L`03
o`000?nNHIkoWV6N00SoWV6N00?o0000oh9mP_n2OH800on2OH82o`0000GoQ7^400?o0000oeRWF?mH
YeP01?mHYeP00ol0003oF:MHoeRWF003oeRWF003o`000?n7N8OoQgR700WoQgR700?o0000olDjaOo5
>/D03_o5>/D00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Sod2o@
00?o0000ohMhQon7N8L01_n7N8L00ol0003o;m0_o`000009ofBKI004o`000?n<LhcoS7><o`0000go
OH9m00Co0000og><LomcS7?o00003?nNHIh01Ol0003oPWf2oh9mP_n2OH;o000000SoQ7^40_l00005
oeRWF003o`000?mHYeSoF:MH00;oF:MH00?o0000ohMhQon7N8L02On7N8L00ol0003oaC[5olDja@0>
olDja@03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@;m3od2o@
00Ood2o@00?o0000ohMhQon7N8L01on7N8L00ol0003oI9]TofBKI007ofBKI003o`000?n<LhcoS7><
00;oS7><00?o0000ogf2OOmmPWd02_mmPWd00ol0003oLhaco`00000>oiiQWP03o`000?n2OH;o0000
00_oQ7^400?o0000oeRWF?mHYeP00_mHYeP01Ol0003oF:MHoeRWF?mHYeSo000000coQgR700?o0000
olDjaOo5>/D03_o5>/D3o`0000WofbCK00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o@;m3od2o@
00Wod2o@00?o0000ohMhQon7N8L01_n7N8L00ol0003oI9]TofBKI006ofBKI003o`000?n<LhcoS7><
00?oS7><00?o0000ogf2OOmmPWd02ommPWd00ol0003oWV6NoiiQWP0>oiiQWP03o`000?n4NhCoQ7^4
00_oQ7^40_l00003oeRWF004o`000?mHYeSoF:MHo`0000[oQgR70ol0000>olDja@;o00000ooj1OX2
o`0000OofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o@;m3od2o@00[od2o@00?o0000ohMh
Qon7N8L01?n7N8L00ol0003oI9]TofBKI006ofBKI003o`000?n<LhcoS7><00GoS7><00?o0000ogf2
OOmmPWd01ommPWd3o`00017oWV6N00?o0000ohAkQ?n4Nh@03On4Nh@01Ol0003oF:MHoeRWF?l0003o
F:MH00Co00000on7N8L5o`0000;o_D:m00?o0000olDjaOo5>/D02_o5>/D2o`0000OonPGj0_l00004
om/Tf`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003od2o@om0_d00;om0_d003o`000?n7N8OoQgR7
00CoQgR700?o0000ofBKI?mTVf@01OmTVf@00ol0003oS7><ohacS006ohacS003o`000?mmPWgoOH9m
00CoOH9m0ol00002ohUfR@03o`000?nNHIkoWV6N00ooWV6N0_l0000?ohAkQ004o`000?mHYeSo0000
o`0000CoOH9m0ol00008oke2_@03o`000?o5>/GoaC[500OoaC[50_l0000;ooX5nP;o00000_oK9=/0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om0_d?o@;m003?o@;m06o`0000OoI9]T00?o0000ohac
S?n<Lh`02?n<Lh`00ol0003oOH9mogf2O@03o`0000KoRGJ900?o0000oiiQW_nNHIh03OnNHIh01?l0
003oUVVFoiIYU_l0000?ohAkQ003o`000?mmPWgoOH9m00GoOH9m00?o0000oke2_Onm@[d02?nm@[d0
0ol0003oaC[5olDja@05olDja@03o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o@;m000ol0003oRWF:ohYeRP04ohYe
RP03o`000?mTVfCoI9]T00?oI9]T00?o0000ohacS?n<Lh`02_n<Lh`2o`0000[oRGJ900?o0000oiiQ
W_nNHIh02onNHIh00ol0003oUVVFoiIYUP02oiIYUP03o`000?n4NhCoQ7^400_oQ7^40_l00007ogf2
O@03o`000?nm@[go_D:m00Wo_D:m00?o0000olDjaOo5>/D00_o5>/D2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om0_d?o@;m002oo@;m000ol0003oRWF:ohYeRP06ohYeRP05o`000?mTVfCoI9]TofBK
I?l000003On<Lh`00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?nNHIkoWV6N00WoWV6N00?o0000oiIY
U_nFJIH01?nFJIH00ol0003oQ7^4ohAkQ008ohAkQ0;o000000?oFjAKo`000?mmPWd01ommPWd00ol0
003o_D:moke2_@09oke2_@04o`000?o5>/Go0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?o@;m3od2o@
00Wod2o@00?o0000ohYeR_n:MHX02?n:MHX00ol0003oI9]To`00000=ohacS003o`000?n9MXWoRGJ9
00_oRGJ900?o0000oiiQW_nNHIh02?nNHIh00ol0003oUVVFoiIYUP06oiIYUP03o`000?n4NhCoQ7^4
00GoQ7^40_l00003oe^TF`03o`000?mmPWgoOH9m00KoOH9m00?o0000oke2_Onm@[d02_nm@[d00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003od2o@om0_d007om0_d003o`000?n:MH[oRWF:00[oRWF:00?o0000ohacS?n<
Lh`03?n<Lh`00ol0003oRGJ9ohUfR@0<ohUfR@03o`000?nNHIkoWV6N00KoWV6N00?o0000oiIYU_nF
JIH02?nFJIH00ol0003oQ7^4ohAkQ002ohAkQ0;o00001_mKY5/00ol0003oOH9mogf2O@05ogf2O@03
o`000?nm@[go_D:m00[o_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o@;m3od2o@00God2o@
00?o0000ohYeR_n:MHX03?n:MHX2o`0000coS7><00?o0000ohUfROn9MXT03On9MXT00ol0003oWV6N
oiiQWP04oiiQWP03o`000?nFJIKoUVVF00[oUVVF00Co0000ohAkQ?l0003o00002?mKY5/00ol0003o
OH9mogf2O@06ogf2O@03o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_o@;m000ol0003oRWF:ohYeRP0=ohYeRP03o`000?n1OX7o000000;o00002?n<Lh`00ol0003oRGJ9
ohUfR@0?ohUfR@Ko00003_nFJIH00ol0003oFjAKoe^TF`08oe^TF`03o`000?mmPWgoOH9m00KoOH9m
00?o0000oke2_Onm@[d02Onm@[d00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000olhac_o><LkocS7>
0_l0000?ohYeRP03o`000?n1OX7oPGj100?oPGj10ol00005ohacS0;o00004?n9MXT01_l0003oN8Mh
ogR7N?l0003oHIiQo`0000koUVVF00?o0000oe^TFomKY5/02OmKY5/00ol0003oOH9mogf2O@05ogf2
O@03o`000?nm@[go_D:m00Wo_D:m00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000olhac_o><Lh00oo><Lh00ol0003o
RWF:ohYeRP0=ohYeRP03o`000?n1OX7oPGj100KoPGj10ol000001?n<Lhco0000ogj1O_mnPGh3o`00
00coRGJ900Go0000ogR7N?mhQgSoN8Mho`000002of6NH@03o`000?nFJIKoUVVF00_oUVVF00?o0000
oe^TFomKY5/02OmKY5/00ol0003oOH9mogf2O@06ogf2O@03o`000?nm@[go_D:m00So_D:m0_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003ocS7>olhacP04olhacPoo00003?n1OX400ol0003oOX5nogj1OP04ogj1
OP?o00002?n9MXT00ol0003oN8MhogR7N002ogR7N005o`000?mQWV7oHIiQof6NHOl000003?nFJIH0
0ol0003oFjAKoe^TF`09oe^TF`03o`000?mmPWgoOH9m00GoOH9m3?l00002omlPg`;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003ocS7>olhacP05olhacP03o`000?mcS7?oLhac00_oLhac00?o0000oh5n
POn1OX402_n1OX400ol0003oOX5nogj1OP07ogj1OP;o00001On9MXT00ol0003oN8MhogR7N003ogR7
N003o`000?mQWV7oHIiQ00;oHIiQ00?o0000oiIYU_nFJIH02OnFJIH00ol0003oFjAKoe^TF`0:oe^T
F`03o`000?mmPWgoOH9m00?oOH9m00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003ogb3OomlPg`02omlP
g`;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ocS7>olhacP06olhacP03o`000?mcS7?oLhac00[o
Lhac00?o0000oh5nPOn1OX402on1OX400ol0003oOX5nogj1OP09ogj1OP?o000000?oRGJ9o`000?mh
QgP01OmhQgP00ol0003oHIiQof6NH@03of6NH@03o`000?nFJIKoUVVF00SoUVVF3_l00003ogf2O@;o
00002on4Nh@00ol0003ogb3OomlPg`05omlPg`03o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000olhac_o><Lh01Oo><Lh00ol0003oQgR7o`00000;og><L`03o`000?n1OX7oPGj100[oPGj1
0_l0000>ogj1OP03o`000?mhQgSoN8Mh00GoN8Mh00?o0000of6NHOmQWV400omQWV400ol0003oUVVF
oiIYUP08oiIYUP03o`000?n5NXGoQGZ500_oQGZ500?o0000ogf2OOl000003On4Nh@00ol0003ogb3O
omlPg`06omlPg`;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o><LkocS7>00KocS7>00Co
0000ohMhQon7N8Oo00002_mcS7<00ol0003oPGj1oh5nP@09oh5nP@03o`000?mkQ7_o000000koOX5n
00?o0000ogR7N?mhQgP01OmhQgP00ol0003oHIiQof6NH@04of6NH@03o`000?nFJIKoUVVF00KoUVVF
00?o0000ohEjQOn5NXD03On5NXD00ol0003oQ7^4ohAkQ00<ohAkQ003o`000?oO8=oogb3O00Sogb3O
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o><LkocS7>00GocS7>00?o0000ohMhQon7N8L00_n7
N8L00ol0003oLhacog><L`06og><L`03o`000?n1OX7oPGj100SoPGj10_l00003og^4N`03o`000?mn
PGkoOX5n00_oOX5n00?o0000ogR7N?mhQgP01OmhQgP00ol0003oHIiQof6NH@05of6NH@03o`000?nF
JIKoUVVF00GoUVVF00?o0000ohEjQOn5NXD03On5NXD00ol0003oQ7^4ohAkQ00;ohAkQ003o`000?oO
8=oogb3O00Wogb3O00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o><LkocS7>00KocS7>00?o0000
ohMhQon7N8L00on7N8L00ol0003oLhacog><L`05og><L`03o`000?n1OX7oPGj100OoPGj100?o0000
og^4NomkQ7/00omkQ7/00ol0003oOX5nogj1OP0:ogj1OP03o`000?mhQgSoN8Mh00KoN8Mh00?o0000
of6NHOmQWV401_mQWV400ol0003oUVVFoiIYUP04oiIYUP03o`000?n5NXGoQGZ500goQGZ53ol0000;
omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o><LkocS7>00KocS7>00?o0000ohMhQon7N8L01On7N8L00ol0
003oLhacog><L`04og><L`03o`000?n1OX7oPGj100GoPGj10_l00006og^4N`03o`000?mnPGkoOX5n
00WoOX5n0_l00008ogR7N003o`000?mQWV7oHIiQ00KoHIiQ1Ol000000onFJIKo0000ohEjQ@0?ohEj
Q@03o`000?mnPGkoOX5n00_oOX5n00?o0000omlPgooO8=l02OoO8=l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o><LkocS7>00KocS7>00?o0000ohMhQon7N8L01_n7N8L00ol0003o
Lhacog><L`04o`0000KoPGj100?o0000og^4NomkQ7/01omkQ7/00ol0003oOX5nogj1OP05ogj1OP?o
000000?oJiA[o`000?mhQgP01omhQgP00ol0003oHIiQof6NH@05of6NH@03o`000?nHIiSoV6NH00?o
V6NH0_l0000?ohEjQ@;o00003OmnPGh00ol0003ogb3OomlPg`08omlPg`03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WocS7>00?o0000ohMhQon7N8L01on7N8L2o`0000CoXebS00Co0000oh5nPOn1OX7o
PGj10_l0000:og^4N`03o`000?mnPGkoOX5n00;oOX5n0ol00005of^DJ`03o`000?mhQgSoN8Mh00Go
N8Mh00?o0000of6NHOmQWV401?mQWV400ol0003oV6NHoiQWV006oiQWV003o`000?n5NXGoQGZ500[o
QGZ50_l00002ohQgR003o`000?mnPGkoOX5n00[oOX5n00?o0000omlPgooO8=l02?oO8=l00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000olhac_o><Lh01_o><Lh00ol0003oQgR7ohMhQ`08ohMhQ`03o`00
0?nSG:?oXebS00CoXebS00?o0000oh5nPOl000003?mkQ7/00ol0003oOX5no`000002o`0000WoJiA[
00?o0000ogR7N?mhQgP01?mhQgP00ol0003oHIiQof6NH@03of6NH@03o`000?nHIiSoV6NH00SoV6NH
1_l00004ohEjQ@;o00001On8MhP00ol0003oOX5nogj1OP09ogj1OP03o`000?oO8=oogb3O00Sogb3O
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o><LkocS7>00GocS7>00?o0000ohMhQon7N8L01on7
N8L00ol0003oXebSoj=LX`06oj=LX`03o`000?mkQ7_oNhAk00coNhAk00?o0000of^DJom[U6/02_m[
U6/00ol0003oN8MhogR7N004ogR7N004o`000?mQWV7oHIiQof6NH@;o00002onHIiP00ol0003oTVfB
oi9]TP03oi9]TPCo00002?n8MhP00ol0003oOX5nogj1OP08ogj1OP03o`000?oO8=oogb3O00Oogb3O
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000olhac_o><Lh00oo><Lh00ol0003oQgR7ohMhQ`07ohMhQ`03o`000?nS
G:?oXebS00OoXebS00?o0000og^4NomkQ7/03?mkQ7/00ol0003oJiA[of^DJ`0;of^DJ`03o`000?mh
QgSoN8Mh00?oN8Mh00Co0000of6NHOmQWV7o00003OnHIiP00ol0003oTVfBoi9]TP06oi9]TP03o`00
0?n8MhSoR7N800OoR7N800?o0000ogj1O_mnPGh01omnPGh00ol0003ogb3OomlPg`06omlPg`04o`00
0?ok1?_on`Ckoo/4n`;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o><LkocS7>00;ocS7>00?o0000ohMhQon7N8L0
1_n7N8L00ol0003oXebSoj=LX`09oj=LX`03o`000?mkQ7_oNhAk00WoNhAk0_l0000>of^DJ`?o0000
0omhQgP00ol0003oHIiQo`00000=oiQWV003o`000?nBKI;oTVfB00OoTVfB00?o0000ohQgR?n8MhP0
2?n8MhP:o`0000Kogb3O0_l00006oo/4n`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoQgR700?o
0000oj=LXonSG:<02_nSG:<00ol0003oNhAkog^4N`06og^4N`;o000000?oNhAko`000?m[U6/02om[
U6/2o`0000?oV6NH1Ol0000>oiQWV003o`000?nBKI;oTVfB00OoTVfB00?o0000ohQgR?n8MhP02?n8
MhP00ol0003oWf2OoimPW`06oimPW`03o`000?oO8=oogb3O00?ogb3O00?o0000oo/4nook1?/01ook
1?/2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP03olHiaPCo00000_n7N8L00ol0003oXebSoj=LX`0;
oj=LX`03o`000?mkQ7_oNhAk00?oNhAk0ol00004og^4N`03o`000?m[U6_oJiA[00OoJiA[0_l00008
oiQWV003o`000?nHIiSoV6NH00goV6NH00?o0000oi9]T_nBKI802?nBKI800ol0003oR7N8ohQgR007
ohQgR003o`000?nOH9ooWf2O00OoWf2O0ol000000ooO8=oo0000oo/4n`0;oo/4n`;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o6>LKoaSW600OoaSW60_l0000?oj=LX`03o`000?mkQ7_oNhAk00;o00002?mkQ7/00ol0
003oJiA[of^DJ`05of^DJ`03o`000?nHIiSoV6NH00SoV6NH00?o0000oiQWV?nHIiP03OnHIiP00ol0
003oTVfBoi9]TP08oi9]TP03o`000?n8MhSoR7N800KoR7N800?o0000oimPWonOH9l02?nOH9l01?l0
003ogR7NomhQg_l0000?oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP09olHi
aP03o`000?nSG:?oXebS00koXebS0_l0000;og^4N`03o`000?m[U6_oJiA[00;oJiA[0_l0000;oiQW
V003o`000?nHIiSoV6NH00goV6NH00?o0000oi9]T_nBKI802?nBKI800ol0003oR7N8ohQgR006ohQg
R003o`000?nOH9ooWf2O00OoWf2O00Go0000omhQg_oN8MkogR7No`00000@oo/4n`;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oaSW6olHiaP0:olHiaP03o`000?nSG:?oXebS00goXebS0_l0000<og^4N`04o`000?m[U6_o0000
o`0000goV6NH00?o0000oiQWV?nHIiP03?nHIiP00ol0003oTVfBoi9]TP09oi9]TP03o`000?n8MhSo
R7N800KoR7N800?o0000oimPWonOH9l01_nOH9l00ol0003ogR7NomhQgP03omhQgP03o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oaSW6olHiaP0:olHiaP03o`000?nSG:?oXebS00coXebS00Co0000odn`
Com?/4oo00003?mkQ7/00ol0003oV6NHoiQWV00>oiQWV003o`000?nHIiSoV6NH00SoV6NH1?l0000;
oi9]TP03o`000?n8MhSoR7N800KoR7N800?o0000oimPWonOH9l01OnOH9l00ol0003ogR7NomhQgP04
omhQgP03o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oaSW6olHiaP0;olHiaP03o`000?nSG:?oXebS
00_oXebS00?o0000odn`Com?/4l00_m?/4l00ol0003oNhAkog^4N`09og^4N`03o`000?nHIiSoV6NH
00koV6NH00Co0000oiQWV?nHIiSoV6NH1ol00003oiYUVP03o`000?nBKI;oTVfB00WoTVfB00?o0000
ohQgR?n8MhP01_n8MhP00ol0003oWf2OoimPW`04oimPW`03o`000?oN8MkogR7N00KogR7N00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o6>LKoaSW600coaSW600?o0000oj=LXonSG:<02_nSG:<00ol0
003oCk1?odn`C`03odn`C`03o`000?mkQ7_oNhAk00SoNhAk00?o0000oiQWV?nHIiP03_nHIiP4o`00
00_oVVFJ00?o0000oi9]T_nBKI802?nBKI800ol0003oR7N8ohQgR005ohQgR003o`000?nOH9ooWf2O
00GoWf2O00?o0000omhQg_oN8Mh01_oN8Mh00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olHia_o6
>LH03?o6>LH7o`0000GoXebS00?o0000odn`Com?/4l01Om?/4l00ol0003oNhAkog^4N`07og^4N`03
o`000?nHIiSoV6NH00koV6NH00?o0000oiYUV_nJIIX03OnJIIX00ol0003oTVfBoi9]TP08oi9]TP03
o`000?n8MhSoR7N800CoR7N800?o0000oimPWonOH9l01?nOH9l00ol0003ogR7NomhQgP07omhQgP03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oaSW6olHiaP0=olHiaP03o`000?nWF:OoYeRW00CoYeRW
1Ol00009odn`C`03o`000?mkQ7_oNhAk00KoNhAk00?o0000oiQWV?nHIiP03_nHIiP00ol0003oVVFJ
oiYUVP0=oiYUVP03o`000?nBKI;oTVfB00SoTVfB00Co0000ohQgR?n8MhSoR7N81Ol00004oimPW`03
o`000?oN8MkogR7N00WogR7N1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olHiaP03o`000?nWF:OoYeRW00WoYeRW
0_l00009odn`C`03o`000?mkQ7_oNhAk00KoNhAk00?o0000oiQWV?nHIiP03?nHIiP00ol0003oVVFJ
oiYUVP0?oiYUVPKo00001?nBKI84o`0000Go^4Nh0_l000000onOH9oo0000omhQgP0;omhQgP04o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oH9mSof2OHomPWf0?o00002_o6>LH00ol0003o
YeRWojMHY`09ojMHY`03o`000?mOWeoo000000;o00001om?/4l00ol0003oNhAkog^4N`05og^4N`03
o`000?nHIiSoV6NH00SoV6NH1Ol0000AoiYUVP03o`000?nFJIKoUVVF00?oUVVF1?l0000;okQ7^003
o`000?oN8MkogR7N00[ogR7N00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omPWf?oH9mP01OoH9mP2o`0000OoaSW6
00?o0000ojMHYonWF:L02_nWF:L00ol0003oGimOoenOG`02oenOG`?o00001Om?/4l00ol0003oNhAk
og^4N`04og^4N`04o`000?nHIiSoV6NHoiQWV0Oo00001?n3O8<00ol0003oVVFJoiYUVP0>oiYUVP03
o`000?nFJIKoUVVF00OoUVVF00?o0000okQ7^?nhAkP02OnhAkP00ol0003ogR7NomhQgP09omhQgP03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003of2OHomPWf008omPWf0;o00001?o6>LH00ol0003oYeRW
ojMHY`0;ojMHY`03o`000?mOWeooGimO00GoGimO0ol00003odn`C`04o`000?mkQ7_oNhAkog^4N`Ko
00003?n3O8<00ol0003oVVFJoiYUVP0=oiYUVP03o`000?nFJIKoUVVF00OoUVVF00?o0000okQ7^?nh
AkP02_nhAkP00ol0003ogR7NomhQgP08omhQgP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omPWf0?o000000?oaSW6o`000?nWF:L0
3?nWF:L00ol0003oGimOoenOG`08oenOG`?o000000CoCk1?o`000?l0003o00000_nMHYd00ol0003o
Pgb3oh=lP`0=oh=lP`03o`000?nJII[oVVFJ00coVVFJ00?o0000oiIYU_nFJIH02?nFJIH00ol0003o
^4NhokQ7^00;okQ7^003o`000?oN8MkogR7N00KogR7N00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
f2OH00?o0000ojMHYonWF:L03?nWF:L00ol0003oGimOoenOG`0;oenOG`03o`000?nMHYgoWF:M00?o
WF:M00?o0000oh=lPon3O8<03?n3O8<00ol0003oJIIYo`00000=oiYUVP03o`000?nFJIKoUVVF00So
UVVF00?o0000okQ7^?nhAkP03?nhAkP3o`0000GogR7N00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oH9mSof2OH00cof2OH00?o0000ojMHYonWF:L03?nWF:L00ol0003oGimOoenOG`0:oenOG`03o`00
0?nMHYgoWF:M00GoWF:M00?o0000oh=lPon3O8<02_n3O8<01?l0003oJIIYofVFJOmYUVT2o`0000[o
VVFJ00?o0000oiIYU_nFJIH02OnFJIH00ol0003o^4NhokQ7^00<okQ7^003o`000?oT6nCoi1_T00?o
000000?ogR7No`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oH9mSof2OH00_of2OH00?o0000ojMHYonWF:L0
3?nWF:L00ol0003oGimOoenOG`09oenOG`03o`000?nMHYgoWF:M00KoWF:M00?o0000oh=lPon3O8<0
2On3O8<00ol0003oJIIYofVFJ@02ofVFJ@03o`000?nJII[o000000;o00001onJIIX00ol0003oUVVF
oiIYUP09oiIYUP03o`000?nhAkSo^4Nh00_o^4Nh00?o0000on@Ki?oT6n@01?oT6n@00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omPWf?oH9mP02ooH9mP00ol0003oYeRWojMHY`0;ojMHY`03o`000?mO
WeooGimO00SoGimO00?o0000oieRWOnMHYd01onMHYd00ol0003oPgb3oh=lP`08oh=lP`03o`000?mY
UVWoJIIY00?oJIIY00?o0000oiYUV_nJIIX00_nJIIX2o`0000CoVVFJ00?o0000oiIYU_nFJIH02_nF
JIH00ol0003o^4NhokQ7^00:okQ7^003o`000?oT6nCoi1_T00Goi1_T00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oH9mSof2OH00[of2OH0ol0000;ojMHY`Ko00001?mOWel00ol0003oWF:MoieRW@08
oieRW@03o`000?n3O8?oPgb300OoPgb300?o0000ofVFJOmYUVT00omYUVT00ol0003oVVFJoiYUVP05
oiYUVP?o000000?oVVFJo`000?nFJIH02onFJIH00ol0003o^4NhokQ7^009okQ7^003o`000?oT6nCo
i1_T00Ooi1_T00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oH9mSof2OH00Wof2OH00?o0000oj5N
XOnQGZ401?l00006ojMHY`03o`000?nMHYgoWF:M00CoWF:M1?l0000<oieRW@03o`000?n3O8?oPgb3
00GoPgb300?o0000ofVFJOmYUVT01?mYUVT00ol0003oVVFJoiYUVP08oiYUVP03o`000?nFJIKoUVVF
00_oUVVF00?o0000okQ7^?nhAkP02?nhAkP00ol0003oi1_Ton@Ki008on@Ki0Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oH9mSof2OH00Oof2OH00?o0000oj5NXOnQGZ401OnQGZ43o`0000;oYeRW00?o0000oieRWOnM
HYd02?nMHYd00ol0003oWF:MoieRW@0:oieRW@03o`000?n3O8?oPgb300CoPgb300?o0000ofVFJOmY
UVT01OmYUVT00ol0003oVVFJoiYUVP08oiYUVP03o`000?nFJIKoUVVF00WoUVVF1?l00008okQ7^003
o`000?oT6nCoi1_T00Woi1_T00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003of2OH
omPWf005omPWf003o`000?nQGZ7oXEjQ00WoXEjQ0_l0000<oieRW@03o`000?nMHYgoWF:M00WoWF:M
00?o0000oh=lPon3O8<00on3O8<00ol0003oJIIYofVFJ@05ofVFJ@03o`000?nJII[oVVFJ00[oVVFJ
00?o0000oiIYU_nFJIH01?nFJIH4o`0000Co[E:]00?o0000okQ7^?nhAkP01?nhAkP00ol0003oi1_T
on@Ki00:on@Ki003o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oH9mSof2OH00?of2OH00?o0000oj5NXOnQGZ402onQ
GZ400ol0003oWF:MoieRW@0:oieRW@03o`000?nMHYgoWF:M00WoWF:M00?o0000oh=lPon3O8<00_n3
O8<00ol0003oJIIYofVFJ@06ofVFJ@03o`000?nJII[oVVFJ00[oVVFJ00?o0000oiIYU_nFJIH01?l0
0009ojeB[@Ko00003?oT6n@00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omPWf?oH9mSof2OH0_l0
000=oj5NX@03o`000?nMHYgoWF:M00[oWF:M00?o0000oieRWOnMHYd02OnMHYd01Ol0003oPgb3oh=l
Pon3O8?o000000WoJIIY00?o0000oiYUV_nJIIX02onJIIX2o`0000go[E:]00?o0000om`Sg?oL8m`0
0_oL8m`00ol0003oi1_Ton@Ki00:on@Ki003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003of2OHo`00
0002omXUfP;o00002onQGZ400ol0003oWF:MoieRW@0;oieRW@03o`000?nMHYgoWF:M00WoWF:M00?o
0000oh=lPol000002OmYUVT00ol0003oVVFJoiYUVP0<oiYUVP03o`000?n]DZgo[E:]00co[E:]00?o
0000om`Sg?oL8m`00ooL8m`00ol0003oi1_Ton@Ki009on@Ki003o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ofRGJomXUfP03omXUfP;o00002_nQGZ400ol0003oWF:MoieRW@0:oieRW@03o`000?nMHYgo
WF:M00SoWF:M1Ol00008ofVFJ@03o`000?nJII[oVVFJ00coVVFJ00?o0000ojeB[On]DZd02on]DZd0
0ol0003og2?Lom`Sg005om`Sg003o`000?oT6nCoi1_T00Soi1_T00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooJ9MX2o`0000SoXEjQ00?o0000oieRWOnMHYd02_nMHYd00ol0003oWF:MoieRW@07oieR
W@03o`000?n<LhcoS7><00?oS7><0ol00005ofVFJ@03o`000?nJII[oVVFJ00_oVVFJ00?o0000ojeB
[On]DZd03?n]DZd00ol0003og2?Lom`Sg006om`Sg003o`000?oT6nCoi1_T00Ooi1_T00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000WofRGJ00?o0000oj5NXOnQGZ401OnQGZ42o`0000co
WF:M00?o0000oieRWOnMHYd01OnMHYd00ol0003oS7><ohacS007ohacS0?o000000?oJIIYo`000?nJ
IIX03OnJIIX00ol0003o[E:]ojeB[@0<ojeB[@03o`000?oL8mcog2?L00Kog2?L00?o0000on@Ki?oT
6n@01_oT6n@00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?oJ9M[ofRGJ00OofRGJ
0_l00004oj5NX@03o`000?n[E:_oZeB[00;o00002_nMHYd00ol0003oWF:MoieRW@03oieRW@;o0000
3On<Lh`2o`0000goVVFJ0ol0000=ojeB[@03o`000?oL8mcog2?L00Oog2?L00?o0000on@Ki?oT6n@0
1OoT6n@00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?oJ9M[ofRGJ00SofRGJ0_l0
00000onQGZ7o0000oj]DZ`04oj]DZ`03o`000?nMHYgoWF:M00OoWF:M00Co0000oieRWOnMHYgoWF:M
0_l00002oi9]TP03o`000?n<LhcoS7><00coS7><3Ol00003ohUfR@03o`000?n]DZgo[E:]00[o[E:]
00?o0000om`Sg?oL8m`02?oL8m`01?l0003oi1_Ton@Ki?oT6n@4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003ofRGJ
omXUfP09omXUfP03o`000?n[E:_oZeB[00GoZeB[0_l00008oieRW@03o`000?nMHYgo000000GoTVfB
00?o0000ohacS?n<Lh`02on<Lh`00ol0003oRWF:ohYeRP09ohYeRP03o`000?n9MXWoRGJ900;oRGJ9
0_l00009ojeB[@03o`000?oL8mcog2?L00[og2?L0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?oJ9M[ofRGJ00SofRGJ00?o0000oj]DZon[E:/01on[E:/4o`0000?oWF:M0ol0
0007oi9]TP03o`000?n<LhcoS7><00[oS7><00?o0000ohYeR_n:MHX02On:MHX00ol0003oRGJ9ohUf
R@04ohUfR@;o00001on]DZd00ol0003og2?Lom`Sg00:om`Sg003o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oJ9M[ofRGJ00OofRGJ00?o0000oj]DZon[E:/02?n[E:/0
1?l0003o[E:]ojeB[On]DZd3o`0000;oWf2O00?o0000oi9]T_nBKI801_nBKI800ol0003oS7><ohac
S008ohacS003o`000?n:MH[oRWF:00[oRWF:00?o0000ohUfROn9MXT01_n9MXT00ol0003o[E:]ojeB
[@04ojeB[@03o`000?oL8mcog2?L00Wog2?L00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000omXUf_oJ9MX01OoJ9MX00ol0003oZeB[oj]DZ`08oj]DZ`03o`000?n]DZgo
[E:]00Co[E:]00Go0000oimPWonOH9ooWf2Oo`000008oi9]TP03o`000?n<LhcoS7><00OoS7><00?o
0000ohYeR_n:MHX02_n:MHX00ol0003oRGJ9ohUfR@07ohUfR@;o00001?n]DZd00ol0003og2?Lom`S
g008om`Sg003o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omXUf_oJ9MX00ooJ9MX0
0ol0003oZeB[oj]DZ`08oj]DZ`03o`000?n]DZgo[E:]00Co[E:]00?o0000oimPWonOH9l00_nOH9l0
0ol0003oTVfBoi9]TP07oi9]TP03o`000?n<LhcoS7><00KoS7><00?o0000ohYeR_n:MHX02_n:MHX0
0ol0003oRGJ9ohUfR@09ohUfR@05o`000?n]DZgo[E:]ojeB[Ol000002OoL8m`00ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_oZeB[00?o0000ojeB[On]DZd01?n]DZd00ol0003oWf2OoimPW`03
oimPW`03o`000?nBKI;oTVfB00OoTVfB00?o0000ohacS?n<Lh`01On<Lh`00ol0003oRWF:ohYeRP0:
ohYeRP03o`000?n9MXWoRGJ900WoRGJ91?l00009om`Sg003o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oT6nCoi1_T
on@Ki?l000002_n[E:/00ol0003o[E:]ojeB[@05ojeB[@03o`000?nOH9ooWf2O00?oWf2O00?o0000
oi9]T_nBKI802?nBKI800ol0003oS7><ohacS004ohacS003o`000?n:MH[oRWF:00WoRWF:00?o0000
ohUfROn9MXT02?n9MXT2o`0000?ofRGJ00?o0000om`Sg?oL8m`01_oL8m`00ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000on@Ki?oT6n@00ooT6n@00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?n]DZgo[E:]
00Go[E:]00?o0000oimPWonOH9l01?nOH9l00ol0003oTVfBoi9]TP09oi9]TP03o`000?n<LhcoS7><
00;oS7><00?o0000ohYeR_n:MHX02_n:MHX00ol0003oRGJ9ohUfR@06ohUfR@;o00001_oJ9MX8o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003oi1_Ton@Ki005on@Ki003o`000?n[E:_oZeB[00GoZeB[00?o0000ojeB[On]
DZd01On]DZd00ol0003oWf2OoimPW`05oimPW`03o`000?nBKI;oTVfB00WoTVfB00Go0000ohacS?n<
LhcoS7><o`00000<ohYeRP03o`000?n9MXWoRGJ900CoRGJ90_l00008omXUfP03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oT6nCoi1_T00Ooi1_T00?o0000oj]DZon[
E:/00on[E:/00ol0003o[E:]ojeB[@06ojeB[@03o`000?nOH9ooWf2O00GoWf2O00?o0000oi9]T_nB
KI802_nBKI800ol0003oS7><o`000004o`0000WoRWF:00?o0000ohUfROn9MXT00_n9MXT2o`0000[o
fRGJ00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003oi1_Ton@Ki007on@Ki003o`00
0?n[E:_oZeB[00;oZeB[00?o0000ojeB[On]DZd01_n]DZd00ol0003oWf2OoimPW`07oimPW`;o0000
2onBKI800ol0003oZeB[oj]DZ`03oj]DZ`Oo00000_n:MHX00ol0003oRGJ9ohUfR@02o`0000_ofRGJ
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000on@Ki?oT6n@02OoT
6n@01Ol0003oZeB[oj]DZon[E:_o000000So[E:]00?o0000oimPWonOH9l01onOH9l00ol0003oc3?<
o`000002o`0000SoTVfB00?o0000oj]DZon[E:/02_n[E:/5o`0000gofRGJ00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<on@Ki003o`000?n[E:_o000000Wo[E:]00?o
0000oimPWonOH9l01_nOH9l00ol0003oc3?<ol`cc003ol`cc0?o00001?nBKI800ol0003oZeB[oj]D
Z`0=oj]DZ`03o`000?oJ9M[ofRGJ00gofRGJ00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ook1?/2o`0000_oi1_T00?o0000ojeB[On]DZd01on]DZd00ol0003oWf2OoimPW`07
oimPW`03o`000?o<<lcoc3?<00Koc3?<0ol000000onBKI;o0000oj]DZ`0>oj]DZ`03o`000?oJ9M[o
fRGJ00cofRGJ00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009on@K
i003o`000?n]DZgo[E:]00;o[E:]1_l00008oimPW`03o`000?o<<lcoc3?<00[oc3?<00?o0000oj]D
Zon[E:/03on[E:/00ol0003ofRGJomXUfP0:omXUfP;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007on@Ki0Go00001_oS7><00ol0003oWf2OoimPW`05oimPW`03o`000?o<<lcoc3?<00[o
c3?<00?o0000oj]DZon[E:/03on[E:/00ol0003ofRGJomXUfP07omXUfP?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005on@Ki003o`000?oS7>?ohacS00WohacS00?o0000oimPWonO
H9l00onOH9l00ol0003oc3?<ol`cc00;ol`cc003o`000?n[E:_oZeB[00ooZeB[00?o0000omXUf_oJ
9MX01OoJ9MX2o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?oi1_To`000?l00000
3OoS7><00ol0003oWf2OoimPW`02oimPW`03o`000?o<<lcoc3?<00_oc3?<5?l00004omXUfP;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003on`Cko`00000>on<Lh`04o`000?nOH9ooWf2Oo`0000koc3?<
00?o0000onLHiooW6>L04?oW6>L00ol0003ofRGJo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000003_oS7><00ol0003oWf2Oo`00000>ol`cc003o`00
0?oW6>OoiaSW017oiaSW00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00_ok1?/00ol0003ohacSon<Lh`0=on<Lh`03o`000?o<<lcoc3?<00Woc3?<1Ol0
000BonLHi`;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/01?ok1?/0
0ol0003ohacSon<Lh`0<on<Lh`03o`000?o<<lcoc3?<00;oc3?<1ol00004ooX5nP03o`000?oW6>Oo
iaSW00ooiaSW00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oS7>?ohacS00cohacS1?l0000<ooX5nP03o`000?oW6>OoiaSW00coiaSW0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on<LhooS7><03?oS7><00ol0003onPGjooX5nP0=ooX5nP03o`000?oW6>OoiaSW00_o
iaSW00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/02Ook1?/00ol0003ohacSon<Lh`0:on<Lh`03o`000?oj1O[onPGj00konPGj00?o0000onLHiooW
6>L02OoW6>L2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000on<LhooS7><02_oS7><00ol0003onPGj
ooX5nP0?ooX5nP03o`000?oW6>OoiaSW00KoiaSW0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003on`Ck00gon`Ck3?l0
000AooX5nP?o00001_oW6>L00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003onPGjooX5nP0>ooX5nP05o`000?ok1?_on`Ckoo/4nol000000ooW6>L2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003onPGjooX5nP0=ooX5nP03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onLHiol000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5
n_oj1OX02ooj1OX00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003onPGjooX5nP0:ooX5nP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000ooX5n_oj1OX02Ooj1OX00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003onPGjooX5
nP07ooX5nP;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oj1O[o
nPGj00GonPGj00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000ooX5n_oj1OX01?oj1OX00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
nPGjooX5nP03ooX5nP03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oj1O[onPGj00;onPGj00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?oj1O[onPGjo`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01ol00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00So003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`07o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`02o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo000:o`00o`;oool01ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00;o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
2_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Coool0o`00ool00?oo003o0_ooo`02o`00o`;oool0
1ol00?l2oooo00Co003o0_ooo`04o`00o`?oool01?l00?l2oooo00[o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00[o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00[o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Ko003o0_oo
o`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`02o`00
o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go
003o00?oool0o`00ool00?l05ol00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l01?ooo`3o
003oo`00ool00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So
003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`0:o`00o`;oool01ol00?l2oooo00Co
003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool0
1_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o
0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00Go003o1?ooo`08o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0R
o`00o`;oool02Ol00?l4oooo00So003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(110) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.983 .017 .983 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.983 .017 .983 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.983 .017 .983 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.982 .018 .982 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.873 .127 .873 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.981 .019 .981 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.867 .133 .867 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.898 .102 .898 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.851 .149 .851 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.979 .021 .979 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.786 .214 .786 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.982 .018 .982 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.725 .275 .725 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.694 .306 .694 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.979 .021 .979 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.984 .016 .984 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.659 .341 .659 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.746 .254 .746 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.978 .022 .978 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.98 .02 .98 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.981 .019 .981 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.853 .147 .853 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.551 .449 .551 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.536 .464 .536 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.496 .504 .496 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.488 .512 .488 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.553 .447 .553 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.82 .18 .82 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.849 .151 .849 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.983 .017 .983 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.522 .478 .522 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.733 .267 .733 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.449 .551 .449 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.811 .189 .811 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.778 .222 .778 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.982 .018 .982 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.698 .302 .698 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.699 .301 .699 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.692 .308 .692 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.818 .182 .818 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.523 .477 .523 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.984 .016 .984 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.877 .123 .877 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.584 .416 .584 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.552 .448 .552 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.514 .486 .514 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.862 .138 .862 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.899 .101 .899 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.634 .366 .634 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.982 .018 .982 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.531 .469 .531 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.442 .558 .442 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.646 .354 .646 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.671 .329 .671 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.438 .562 .438 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.517 .483 .517 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.642 .358 .642 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.983 .017 .983 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.673 .327 .673 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.616 .384 .616 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.866 .134 .866 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.16 .84 .16 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.679 .321 .679 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.696 .304 .696 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.646 .354 .646 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.362 .638 .362 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.333 .667 .333 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.258 .742 .258 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.319 .681 .319 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.595 .405 .595 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.36 .64 .36 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.477 .523 .477 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.685 .315 .685 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.55 .45 .55 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.577 .423 .577 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.6 .4 .6 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.894 .106 .894 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.982 .018 .982 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.358 .642 .358 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.447 .553 .447 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.345 .655 .345 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.981 .019 .981 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.673 .327 .673 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.517 .483 .517 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.277 .723 .277 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.35 .65 .35 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.589 .411 .589 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.447 .553 .447 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.863 .137 .863 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.543 .457 .543 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.27 .73 .27 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.622 .378 .622 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.469 .531 .469 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.411 .589 .411 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.592 .408 .592 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.825 .175 .825 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.593 .407 .593 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.284 .716 .284 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.408 .592 .408 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.595 .405 .595 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.454 .546 .454 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.459 .541 .459 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.806 .194 .806 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.436 .564 .436 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.379 .621 .379 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.331 .669 .331 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.981 .019 .981 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.343 .657 .343 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.503 .497 .503 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.38 .62 .38 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.561 .439 .561 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.564 .436 .564 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.981 .019 .981 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.598 .402 .598 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.52 .48 .52 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.543 .457 .543 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.586 .414 .586 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.458 .542 .458 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.41 .59 .41 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.48 .52 .48 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.52 .48 .52 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.982 .018 .982 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.732 .268 .732 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.552 .448 .552 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.655 .345 .655 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.376 .624 .376 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.852 .148 .852 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.243 .757 .243 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.431 .569 .431 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.426 .574 .426 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.587 .413 .587 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.698 .302 .698 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.34 .66 .34 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.982 .018 .982 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.494 .506 .494 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.674 .326 .674 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.907 .093 .907 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.578 .422 .578 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.518 .482 .518 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.538 .462 .538 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.83 .17 .83 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.351 .649 .351 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.48 .52 .48 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.563 .437 .563 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.761 .239 .761 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.344 .656 .344 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.472 .528 .472 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.555 .445 .555 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.575 .425 .575 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.982 .018 .982 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.404 .596 .404 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.981 .019 .981 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.869 .131 .869 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.626 .374 .626 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.573 .427 .573 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.449 .551 .449 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.536 .464 .536 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.484 .516 .484 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.861 .139 .861 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.611 .389 .611 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.637 .363 .637 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.638 .362 .638 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.563 .437 .563 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.79 .21 .79 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.544 .456 .544 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.45 .55 .45 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.306 .694 .306 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.322 .678 .322 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.494 .506 .494 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.674 .326 .674 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.982 .018 .982 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.866 .134 .866 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.5 .5 .5 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.31 .69 .31 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.591 .409 .591 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.745 .255 .745 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.515 .485 .515 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.981 .019 .981 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.465 .535 .465 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.724 .276 .724 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.868 .132 .868 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.982 .018 .982 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.464 .536 .464 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.515 .485 .515 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.864 .136 .864 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.55 .45 .55 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.509 .491 .509 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.793 .207 .793 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.475 .525 .475 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.674 .326 .674 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.746 .254 .746 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.523 .477 .523 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.5 .5 .5 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.632 .368 .632 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.532 .468 .532 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.899 .101 .899 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.691 .309 .691 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.644 .356 .644 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.603 .397 .603 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.982 .018 .982 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.77 .23 .77 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.507 .493 .507 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.981 .019 .981 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.876 .124 .876 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.768 .232 .768 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.879 .121 .879 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.542 .458 .542 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.865 .135 .865 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.694 .306 .694 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.606 .394 .606 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.982 .018 .982 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.617 .383 .617 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.593 .407 .593 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.982 .018 .982 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.791 .209 .791 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.979 .021 .979 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.983 .017 .983 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.726 .274 .726 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.98 .02 .98 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.578 .422 .578 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.981 .019 .981 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.47 .53 .47 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.709 .291 .709 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.549 .451 .549 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.858 .142 .858 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.864 .136 .864 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.689 .311 .689 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.712 .288 .712 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.691 .309 .691 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.797 .203 .797 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.851 .149 .851 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.763 .237 .763 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.771 .229 .771 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.98 .02 .98 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.641 .359 .641 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.856 .144 .856 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.981 .019 .981 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.894 .106 .894 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.891 .109 .891 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.638 .362 .638 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.879 .121 .879 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.872 .128 .872 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.611 .389 .611 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.981 .019 .981 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.979 .021 .979 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.983 .017 .983 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.86 .14 .86 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.982 .018 .982 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.982 .018 .982 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.981 .019 .981 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.982 .018 .982 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.981 .019 .981 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.982 .018 .982 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooX5nP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_oj1OX2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003onPGjooX5nP0<ooX5nP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?oj1O[onPGj00gonPGj00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000ooX5n_oj1OX03_oj
1OX00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003ogB;MomdRgOl0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooX5n_oj1OX0
3_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000omdRgOoM8]d00_oM8]d00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000ooX5n_oj1OX03_oj1OX00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oM8]gogB;M00?ogB;M00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oj1O[onPGj00oonPGj00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omdRgOoM8]d01OoM8]d00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000ooX5n_oj1OX03ooj1OX00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ogB;MomdRg@06omdRg@03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003onPGjooX5nP0@ooX5nP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000omdRgOoM8]d02?oM8]d00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000ooX5n_oj1OX04?oj1OX<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oL8mco0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000cogB;M00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?oj1O[onPGj00oonPGj
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003om`Sg003o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ogR7NomhQgP05omhQgP03o`000?oM
8]gogB;M00_ogB;M0ol00003omdRg@03o`000?ok1?_on`Ck00con`Ck0ol0000>ooX5nP;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
om`Sg?oL8m`00ooL8m`00ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003ogR7NomhQgP06
omhQgP03o`000?oM8]gogB;M00[ogB;M00?o0000omdRgOoM8]d01?oM8]d00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oM8]gogB;MomdRg@;o00002_oj1OX2o`000003omdRgOl0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lom`Sg005om`Sg003o`000?ok1?_o
n`Ck00Won`Ck00?o0000omXUf_l000002ook1?/00ol0003ogR7NomhQgP06omhQgP03o`000?oM8]go
gB;M00WogB;M00?o0000omdRgOoM8]d01_oM8]d00ol0003on`Ckoo/4n`08oo/4n`03o`000?oM8]go
gB;M00CogB;M0_l00005ooX5nP?o00001?oM8]d00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008om`Sg003o`000?ok1?_on`Ck00Oon`Ck0_l00003omXU
fP03o`000?ok1?_on`Ck00Oon`Ck00?o0000omhQg_oN8Mh01ooN8Mh00ol0003ogB;MomdRg@09omdR
g@03o`000?oM8]gogB;M00OogB;M00?o0000oo/4nook1?/01Ook1?/2o`0000WogB;M0_l000000ooj
1O[o0000o`000007omdRg@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000om`Sg?oL
8m`02?oL8m`00ol0003on`Ckoo/4n`06oo/4n`03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000oo/4nook
1?/01ook1?/00ol0003ogR7NomhQgP08omhQgP03o`000?oM8]gogB;M00OogB;M00?o0000omdRgOoM
8]d02OoM8]d00ol0003on`Ckoo/4n`03oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000omdRgOoM
8]d01ooM8]d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003ogB;Mo`000005oo/4n`;o00002ooL8m`2o`0000Kon`Ck
00?o0000omXUf_oJ9MX01OoJ9MX00ol0003on`Ckoo/4n`06oo/4n`03o`000?oN8MkogR7N00SogR7N
00?o0000omdRgOoM8]d01_oM8]d00ol0003ogB;MomdRg@0;omdRg@05o`000?ok1?_on`Ckoo/4nol0
00003_oM8]d00ol0003ogB;MomdRg@08omdRg@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oM8]gogB;MomdRgOl0
00000ook1?/00ol0003og2?Lom`Sg00:om`Sg004o`000?oC;=?odbcCo`0000?on`Ck0_l00008omXU
fP03o`000?ok1?_on`Ck00Kon`Ck00?o0000omhQg_oN8Mh02OoN8Mh00ol0003ogB;MomdRg@05omdR
g@03o`000?oM8]gogB;M00cogB;M00?o0000oo/4nol000003ooM8]d00ol0003ogB;MomdRg@08omdR
g@03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003ogB;MomdRg@03omdRg@03o`000?ok1?_o000000_o
g2?L0_l00004om</d`03o`000?ok1?_o000000_ofRGJ00?o0000oo/4nook1?/01Ook1?/00ol0003o
gR7NomhQgP09omhQgP03o`000?oM8]gogB;M00CogB;M00?o0000omdRgOoM8]d03_oM8]d00ol0003o
gB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000omdRgOoM8]d0
1?oM8]d00ol0003og2?Lom`Sg009om`Sg003o`000?oC;=?odbcC00GodbcC00?o0000omXUf_oJ9MX0
2_oJ9MX00ol0003on`Ckoo/4n`05oo/4n`03o`000?oN8MkogR7N00[ogR7N00?o0000omdRgOoM8]d0
0ooM8]d00ol0003ogB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00gogB;M00?o0000omdRgOoM8]d0
2_oM8]d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ogB;MomdR
g@05omdRg@03o`000?oL8mcog2?L00Oog2?L0_l00008om</d`03o`000?oJ9M[ofRGJ00_ofRGJ00?o
0000oo/4nook1?/01?ok1?/00ol0003ogR7NomhQgP0:omhQgP04o`000?oM8]gogB;MomdRg@?o0000
3ooM8]d00ol0003ogB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00[ogB;M00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oM8]gogB;M00OogB;M00?o0000om`Sg?oL8m`01?oL8m`2o`0000_odbcC1?l0
0009omXUfP03o`000?ok1?_on`Ck00?on`Ck00?o0000omhQg_oN8Mh02ooN8Mh01?l0003ogB;Mo`00
0?l00003oki1_P;o00003?oM8]d2o`00013ogB;M00?o0000omdRgOoM8]d02ooM8]d00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003ogB;M
omdRg@07omdRg@03o`000?oL8mcog2?L00?og2?L00?o0000om</dooC;=<02ooC;=<01?l0003o^dBk
ok]4^onkA;/5o`0000GofRGJ00?o0000oo/4nook1?/00_ok1?/00ol0003ogR7NomhQgP0<omhQgP03
o`000?nn@Kko_T6n00Go_T6n0_l00008omdRg@;o00000_n`Ck000ol0003ogB;MomdRg@0=omdRg@03
o`000?oM8]gogB;M00_ogB;M00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo/4nook1?/00_ok1?/3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003ogB;MomdRg@09omdRg@03o`000?oL8mcog2?L00;o0000
3OoC;=<00ol0003o^dBkok]4^`07ok]4^`Ko00000_ok1?/4o`0000gogR7N00?o0000oki1__nn@Kh0
1onn@Kh2o`0000GogB;M00?o0000ok1?/?n`Ck000on`Ck000ol0003ogB;MomdRg@0<omdRg@03o`00
0?oM8]gogB;M00cogB;M00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oM8]gogB;M00WogB;M00?o
0000om`Sg?l000003ooC;=<00ol0003o^dBkok]4^`0<ok]4^`?o00001?oD:m@3o`0000WogR7N00?o
0000oki1__nn@Kh02_nn@Kh2o`000003omdRgOl0003o000000Oo/4n`00?o0000omdRgOoM8]d02ooM
8]d00ol0003ogB;MomdRg@0<omdRg@03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000
om</dooC;=<03_oC;=<00ol0003o^dBkok]4^`0=ok]4^`03o`000?oD:mCoe2_D00Koe2_D0ol00005
omhQgP03o`000?nn@Kko_T6n00go_T6n00?o0000ok1?/?n`Ck002?n`Ck000ol0003ogB;MomdRg@09
omdRg@03o`000?oM8]gogB;M00gogB;M00Co0000oo/4nook1?_on`Ck1Ol00003on@Ki003o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
omdRgOoM8]d02ooM8]d2o`0000oodbcC00?o0000ok]4^onkA;/03OnkA;/00ol0003oe2_Dom@[e00:
om@[e0?o000000?ogR7No`000?nn@Kh03onn@Kh00ol0003o/4n`ok1?/009ok1?/003o`000?oM8]go
gB;M00SogB;M00?o0000omdRgOoM8]d03_oM8]d3o`0000Soi1_T00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oM8]gogB;M00SogB;M0ol000000onb
CK;o0000om</d`0>om</d`03o`000?nkA;_o^dBk00go^dBk00?o0000om@[e?oD:m@03OoD:m@00ol0
003o_T6noki1_P0?oki1_P03o`000?n`Ck3o/4n`00[o/4n`2ol0000;omdRg@Go00003?oT6n@00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02_ok1?/01Ol0003oh1oPo`000?ok1?_o0000
00SogB;M0ol00005ok9=/P03o`000?oC;=?odbcC00codbcC00?o0000ok]4^onkA;/03OnkA;/00ol0
003oe2_Dom@[e00=om@[e0;o00004?nn@Kh00ol0003o/4n`ok1?/00:ok1?/003o`000?naC[7o/Dja
00Oo/Dja00?o0000omdRgOoM8]d00_oM8]d7o`0000Co/4n`00?o0000on@Ki?oT6n@02_oT6n@00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/02Ook1?/01?l0003oh1oPon0Oh?oP7n02o`00
00GogB;M0ol00009ok9=/P;o00002ooC;=<00ol0003o^dBkok]4^`0=ok]4^`03o`000?oD:mCoe2_D
00goe2_D00Co0000olXeb_o:=L[o00003onn@Kh00ol0003o/4n`ok1?/009ok1?/003o`000?naC[7o
/Dja00Wo/Dja1?l0000;ok1?/003o`000?oT6nCoi1_T00[oi1_T00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?ok1?_on`Ck00Son`Ck00?o0000on0Oh?oP7n001?oP7n000ol0003ogB;Mo`000002o`00
00co/Tfb00Co0000ojaC[?l0003o00002OoC;=<00ol0003o^dBkok]4^`0=ok]4^`03o`000?oD:mCo
e2_D00goe2_D00Go0000olXeb_o:=L[obSG:o`00000=oki1_P03o`000?n`Ck3o/4n`00[o/4n`00?o
0000ok5>/OnaC[402OnaC[400ol0003o/4n`ok1?/00<ok1?/003o`000?oT6nCoi1_T00[oi1_T00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000on0Oh?oP7n001_oP7n00
0ol0003o/Tfbok9=/P0<ok9=/P03o`000?n/Djco[5>/00;o[5>/0_l00007om</d`03o`000?nkA;_o
^dBk00co^dBk00?o0000om@[e?oD:m@03OoD:m@00ol0003obSG:olXebP03olXebP03o`000?nn@Kko
_T6n00[o_T6n00?o0000ok1?/?n`Ck002_n`Ck000ol0003o/Djaok5>/@09ok5>/@03o`000?n`Ck3o
/4n`00co/4n`00?o0000on@Ki?oT6n@02ooT6n@00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4
nook1?/01_ok1?/00ol0003oh1oPon0Oh006on0Oh003o`000?nbCK;o/Tfb00_o/Tfb00?o0000ojaC
[?n/Dj`01On/Dj`00ol0003odbcCom</d`03om</d`03o`000?nkA;_o^dBk00go^dBk00?o0000om@[
e?oD:m@03OoD:m@00ol0003obSG:olXebP04olXebP03o`000?nn@Kko_T6n00Wo_T6n00?o0000ok1?
/?n`Ck002On`Ck000ol0003o/Djaok5>/@0:ok5>/@03o`000?n`Ck3o/4n`00co/4n`00?o0000on@K
i?oT6n@02ooT6n@00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook1?/01Ook1?/00ol0003o
h1oPon0Oh007on0Oh003o`000?nbCK;o/Tfb00_o/Tfb00?o0000ojaC[?n/Dj`01_n/Dj`2o`0000?o
dbcC00?o0000ok]4^onkA;/03OnkA;/00ol0003oe2_Dom@[e00<om@[e003o`000?o:=L[obSG:00Ko
bSG:00?o0000oki1__nn@Kh02?nn@Kh00ol0003o/4n`ok1?/009ok1?/003o`000?naC[7o/Dja00[o
/Dja00?o0000ok1?/?n`Ck003?n`Ck000ol0003oi1_Ton@Ki00;on@Ki003o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo/4n`03o`00
0?ok1?_on`Ck00Con`Ck00?o0000on0Oh?oP7n002?oP7n000ol0003o/Tfbok9=/P0:ok9=/P03o`00
0?n/Djco[5>/00Wo[5>/0_l000000ooC;=?o0000ok]4^`0<ok]4^`?o00003_oD:m@00ol0003obSG:
olXebP07olXebP03o`000?nn@Kko_T6n00Oo_T6n00?o0000ok1?/?n`Ck002On`Ck000ol0003o/Dja
ok5>/@0;ok5>/@03o`000?n`Ck3o/4n`00co/4n`00?o0000on@Ki?oT6n@02_oT6n@00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000on0Oh?oP7n002_oP7n000ol0003o/Tfbok9=
/P09ok9=/P03o`000?n/Djco[5>/00_o[5>/00?o0000ok]4^onkA;/02_nkA;/2o`0000?o/Tfb00?o
0000om@[e?oD:m@02_oD:m@00ol0003obSG:olXebP09olXebP03o`000?nn@Kko_T6n00Ko_T6n00?o
0000ok1?/?n`Ck002?n`Ck000ol0003o/Djaok5>/@0<ok5>/@03o`000?n`Ck3o/4n`00co/4n`00?o
0000on@Ki?oT6n@02_oT6n@00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ook1?/0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oP7n3oh1oP00_oh1oP00?o0000ok9=/_nbCK802?nbCK80
0ol0003o[5>/ojaC[00<ojaC[003o`000?nkA;_o^dBk00So^dBk0_l00006ok9=/P;o00002_oD:m@0
0ol0003obSG:olXebP0:olXebP03o`000?nn@Kko_T6n00Go_T6n00?o0000ok1?/?n`Ck002?n`Ck00
0ol0003o/Djaok5>/@0<ok5>/@03o`000?n`Ck3o/4n`00co/4n`00?o0000on@Ki?oT6n@02ooT6n@0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?on`Ck00Go0000oo/4nook1?_on`Cko`00000=
on0Oh003o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003o^dBkok]4^`04
ok]4^`?o00002_nbCK800ol0003oe2_Dom@[e007om@[e003o`000?o:=L[obSG:00_obSG:00?o0000
oki1__nn@Kh00onn@Kh00ol0003o/4n`ok1?/009ok1?/003o`000?naC[7o/Dja00co/Dja00?o0000
ok1?/?n`Ck003?n`Ck000ol0003oi1_Ton@Ki00;on@Ki0;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003oh1oPon0Oh00<on0Oh003o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojaC[?n/Dj`03on/Dj`01?l0
003o^dBkok]4^onkA;/2o`0000ko/Tfb0_l00006om@[e003o`000?o:=L[obSG:00gobSG:00?o0000
oki1__nn@Kh00_nn@Kh00ol0003o/4n`ok1?/008ok1?/003o`000?naC[7o/Dja00co/Dja0ol0000=
ok1?/003o`000?oT6nCoi1_T00_oi1_T00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00ooh1oP00?o0000ok9=/_nbCK801_nbCK800ol0003o[5>/ojaC[00@ojaC[0Co00004_nbCK800ol0
003oe2_Dom@[e003om@[e003o`000?o:=L[obSG:00kobSG:00Go0000oki1__nn@Kko_T6no`000005
ok1?/0Oo00003?naC[401Ol0003oTfbCoi=/TonCK9?o000000co/4n`00?o0000on@Ki?oT6n@02?oT
6n@3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000ooh1oP00?o0000ok9=/_nbCK801_nbCK800ol0003o[5>/ojaC[00=
ojaC[0?o000000CoUVVFo`000?l0003o00004onbCK82o`0000;oe2_D00?o0000olXeb_o:=LX04?o:
=LX00ol0003o_T6no`000006o`0000OoaC[500?o0000ok5>/OnaC[402?naC[400ol0003oTfbCoi=/
T`03oi=/T`;o00002?n`Ck03o`0000Koi1_T1?l00002omlPg`03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003ofRGJo`000?nbCK83o`0000goh1oP00?o0000ok9=/_nbCK801?nbCK800ol0003o[5>/ojaC
[00;ojaC[0?o00000onFJIH01Ol0003oV6NHo`000?nIIYWo000001Co/Tfb00?o0000om@[e?l00000
4oo:=LX00ol0003oaC[5olDja@0=olDja@03o`000?naC[7o/Dja00Go/Dja0_l00008oi=/T`03o`00
0?n`Ck3o/4n`00Go00000on`Ck000ol0003oi1_Ton@Ki003o`0000Oogb3O00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oJ9M[ofRGJo`0000Co/Tfb0ol0000:on0Oh003o`000?nbCK;o/Tfb00?o/Tfb
00?o0000ojaC[?n/Dj`02On/Dj`3o`0000GoUVVF00Co0000oiQWV?nHIiSo00000_nIIYT00ol0003o
/Tfbok9=/P0Bok9=/P03o`000?o:=L[obSG:01;obSG:00?o0000olDjaOo5>/D03_o5>/D00ol0003o
/Djaok5>/@03ok5>/@03o`000?nCK9?oTfbC00WoTfbC0_l00009ok1?/0;o00002_oO8=l00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000omXUf_oJ9M[ofRGJo`000007ok9=/P;o00001ooP7n05o`0000;o
/Tfb00?o0000ojaC[?n/Dj`01_n/Dj`3o`0000SoUVVF00Co0000oiQWV?nHIiSo00000onIIYT00ol0
003o/Tfbok9=/P0Aok9=/P03o`000?o:=L[obSG:017obSG:00?o0000olDjaOo5>/D04?o5>/D01Ol0
003o/Djaok5>/OnaC[7o000000coTfbC00?o0000ok1?/?n`Ck002?n`Ck000ol0003ogb3OomlPg`0:
omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000CofRGJ00?o0000ok9=/_nbCK801onbCK83o`00
0004on0Oh?l0003o0000o`0000Go[5>/0_l00006ojaC[0?o00002_nFJIH01Ol0003oV6NHoiQWV?nH
IiSo000000CoVFJI00?o0000ok9=/_nbCK804?nbCK800ol0003obSG:olXebP0AolXebP03o`000?o5
>/GoaC[5017oaC[500?o0000ok5>/Ol000003OnCK9<00ol0003o/4n`ok1?/008ok1?/003o`000?oO
8=oogb3O00[ogb3O00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oJ9M[ofRGJ00CofRGJ00?o0000
ok9=/_nbCK802_nbCK800ol0003o[5>/ojaC[008ojaC[003o`000?n/Djco[5>/00?o00003OnFJIH0
1Ol0003oV6NHoiQWV?nHIiSo000000GoVFJI00?o0000ok9=/_nbCK803onbCK800ol0003obSG:olXe
bP0AolXebP03o`000?o5>/GoaC[501;oaC[500?o0000oi=/TonCK9<03?nCK9<00ol0003o/4n`ok1?
/008ok1?/003o`000?oO8=oogb3O00_ogb3O00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000omXUf_oJ9MX01OoJ9MX0
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?n/Djco[5>/00Wo[5>/0_l0000?oiIYUP03o`000?nHIiSo
V6NH00;oV6NH00?o0000oiUVVOnIIYT01?nIIYT00ol0003o/Tfbok9=/P0=ok9=/P?o00004Oo:=LX0
0ol0003oaC[5olDja@0ColDja@03o`000?nCK9?oTfbC00_oTfbC00?o0000ok1?/?n`Ck002On`Ck00
0ol0003ogb3OomlPg`0;omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo/4n`;o00002?oJ9MX0
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?n/Djco[5>/00Wo[5>/00?o0000oiIYU_nFJIH03OnFJIH0
0ol0003oV6NHoiQWV003oiQWV003o`000?nIIYWoVFJI00GoVFJI00?o0000ok9=/_nbCK802_nbCK82
o`0000?o`Sg200?o0000olXeb_o:=LX03_o:=LX00ol0003oaC[5olDja@0ColDja@03o`000?nCK9?o
TfbC00_oTfbC00?o0000ok1?/?n`Ck002On`Ck000ol0003ogb3OomlPg`0;omlPg`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Gon`Ck00?o0000omXUf_oJ9MX01ooJ9MX2o`0000_o/Tfb00?o0000ojaC
[?n/Dj`02on/Dj`00ol0003oUVVFoiIYUP0<oiIYUP03o`000?nHIiSoV6NH00?oV6NH00?o0000oiUV
VOnIIYT01_nIIYT00ol0003o/Tfbok9=/P07ok9=/P;o00001_o2?L82o`0000kobSG:00?o0000olDj
aOo5>/D04oo5>/D00ol0003oTfbCoi=/T`0;oi=/T`03o`000?n`Ck3o/4n`00Wo/4n`00?o0000omlP
gooO8=l03?oO8=l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo/4nook1?_on`Cko`000009omXU
fP03o`000?n9MXWo000000_o/Tfb00?o0000ojaC[?n/Dj`02on/Dj`00ol0003oUVVFoiIYUP0;oiIY
UP03o`000?nHIiSoV6NH00CoV6NH00?o0000oiUVVOnIIYT01onIIYT00ol0003o/Tfbok9=/P05ok9=
/P03o`000?o2?L;o`Sg200So`Sg200?o0000olXeb_o:=LX02_o:=LX00ol0003oaC[5olDja@0DolDj
a@03o`000?nCK9?oTfbC00_oTfbC00?o0000ok1?/?n`Ck002On`Ck000ol0003ogb3OomlPg`0<omlP
g`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003on`Cko`000009omXUfP04o`000?n9MXWoRGJ9o`00
00_o/Tfb00?o0000ojaC[?n/Dj`02on/Dj`00ol0003oUVVFoiIYUP0;oiIYUP03o`000?nHIiSoV6NH
00CoV6NH00?o0000oiUVVOnIIYT02?nIIYT00ol0003o/Tfbok9=/P02ok9=/P;o00003?o2?L82o`00
00[obSG:00?o0000olDjaOo5>/D05?o5>/D00ol0003oTfbCoi=/T`0;oi=/T`03o`000?n`Ck3o/4n`
00Wo/4n`00?o0000omlPgooO8=l03OoO8=l00ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003ofRGJomXUfP07omXUfP03
o`000?n9MXWoRGJ900;oRGJ900?o0000ok9=/_nbCK802?nbCK800ol0003o[5>/ojaC[00<ojaC[003
o`000?nFJIKoUVVF00WoUVVF00?o0000oiQWV?nHIiP01OnHIiP00ol0003oVFJIoiUVV@09oiUVV@04
o`000?nbCK;o0000o`00013o`Sg20_l00008olXebP03o`000?o5>/GoaC[501CoaC[50ol0000;oi=/
T`03o`000?n`Ck3o/4n`00Wo/4n`00?o0000omlPgooO8=l03OoO8=l01?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003ofRGJomXUfP06omXUfP03o`000?n9MXWoRGJ900?oRGJ900?o0000ok9=
/_nbCK802?nbCK800ol0003o[5>/ojaC[00;ojaC[0;o00002_nFJIH00ol0003oV6NHoiQWV006oiQW
V003o`000?nIIYWoVFJI00[oVFJI00?o0000ol8m`_o2?L804_o2?L800ol0003obSG:olXebP04olXe
bP03o`000?o5>/GoaC[501GoaC[500?o0000okU6^OniA[T01Ol00005oi=/T`03o`000?n`Ck3o/4n`
00[o/4n`00?o0000omlPgooO8=l03_oO8=l3o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJomXUfP04omXUfP03
o`000?n9MXWoRGJ900CoRGJ900?o0000ok9=/_nbCK801onbCK800ol0003o[5>/ojaC[00;ojaC[004
o`000?nUFZGoYEZUo`0000WoUVVF00?o0000oiQWV?nHIiP01_nHIiP00ol0003oVFJIoiUVV@0:oiUV
V@03o`000?o2?L;o`Sg201?o`Sg20_l00003olXebPCo00005?o5>/D00ol0003o^DJiokU6^@06okU6
^@Co000000?oTfbCo`000?n`Ck002on`Ck000ol0003ogb3OomlPg`0>omlPg`03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003ofRGJomXUfP03omXUfP03o`000?n9MXWoRGJ900GoRGJ900?o0000ok9=/_nb
CK801onbCK800ol0003o[5>/ojaC[009ojaC[0;o00001?nUFZD00ol0003oUVVFoiIYUP05oiIYUP03
o`000?nHIiSoV6NH00OoV6NH00?o0000oiUVVOnIIYT02_nIIYT00ol0003o`Sg2ol8m`P0Eol8m`P03
o`000?o:=L[o000000CobcC;0ol0000@olDja@03o`000?niA[Wo^DJi00_o^DJi0_l0000<ok1?/003
o`000?oO8=oogb3O00cogb3O0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omXUf_oJ9MX00_oJ9MX00ol0003oRGJ9
ohUfR@06ohUfR@03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003oYEZU
ojEJY@05ojEJY@03o`000?nFJIKoUVVF00CoUVVF00?o0000oiQWV?nHIiP01onHIiP00ol0003oVFJI
oiUVV@0:oiUVV@03o`000?o2?L;o`Sg201Ko`Sg200?o0000ol/dboo;=</01_o;=</3o`0000coaC[5
00?o0000okU6^OniA[T03OniA[T00ol0003o/4n`ok1?/009ok1?/0Go00002OoO8=l2o`000003om`S
g?l0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003omXUf_l0003oRGJ900WoRGJ900?o0000ok9=/_nbCK801_nb
CK800ol0003o[5>/ojaC[007ojaC[003o`000?nUFZGoYEZU00OoYEZU00?o0000oiIYU_nFJIH00_nF
JIH00ol0003oV6NHoiQWV008oiQWV003o`000?nIIYWoVFJI00WoVFJI00?o0000ol8m`_o2?L805oo2
?L800ol0003obcC;ol/db`09ol/db`?o00002Oo5>/D00ol0003o^DJiokU6^@0>okU6^@Ko00001?n`
Ck000ol0003oXebSoj=LX`03oj=LX`Go00000_oO8=l2o`0000Cog2?L00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?o9=/WobCK9olTfbOl000002on9MXT00ol0003o/Tfbok9=/P06ok9=/P03o`000?n/
Djco[5>/00Go[5>/0_l0000;ojEJY@04o`000?nFJIKoUVVFo`0000_oV6NH00?o0000oiUVVOnIIYT0
2OnIIYT00ol0003o`Sg2ol8m`P0Fol8m`P03o`000?o;=<_obcC;00gobcC;0ol00005olDja@03o`00
0?niA[Wo^DJi00oo^DJi00?o0000okI9]_nfBKH00onfBKH4o`0000_oXebS0_l00006om`Sg003o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003obCK9olTfb@02olTfb@ko00001_nbCK800ol0003o[5>/ojaC
[005ojaC[003o`000?nUFZGoYEZU00coYEZU00?o0000oiIYU_l000002onHIiP00ol0003oVFJIoiUV
V@07oiUVV@?o00006?o2?L800ol0003obcC;ol/db`0@ol/db`?o000000?oaC[5o`000?niA[T04?ni
A[T00ol0003o]TVfokI9]P07okI9]P03o`000?nSG:?oXebS00[oXebS00?o0000om`Sg?oL8m`01OoL
8m`00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005olTfb@03o`000?mnPGkoOX5n00_oOX5n0_l00004
ok9=/P03o`000?n/Djco[5>/00?o[5>/0_l0000@ojEJY@03o`000?nHIiSoV6NH00[oV6NH00?o0000
oiUVVOnIIYT00onIIYT4o`0000;oSG:=00?o0000ol8m`_o2?L805Oo2?L800ol0003obcC;ol/db`0D
ol/db`03o`000?niA[Wo^DJi013o^DJi00?o0000okI9]_nfBKH01onfBKH00ol0003oXebSoj=LX`0:
oj=LX`03o`000?oL8mcog2?L00Gog2?L00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o9=/WobCK9
00GobCK900?o0000ogj1O_mnPGh03OmnPGh6o`0000?o[5>/00?o0000ojEJYOnUFZD04?nUFZD00ol0
003oV6NHoiQWV00:oiQWV003o`000?nIIYWo000000?o00001on=LXd00ol0003o`Sg2ol8m`P0Dol8m
`P03o`000?o;=<_obcC;01CobcC;00?o0000okU6^OniA[T03oniA[T00ol0003o]TVfokI9]P08okI9
]P03o`000?nSG:?oXebS00[oXebS00?o0000om`Sg?oL8m`01OoL8m`00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000olTfbOo9=/T01_o9=/T00ol0003oOX5nogj1OP0=ogj1OP03o`000?naC[7o/Dja00?o
/Dja00?o0000ojaC[?l000004onUFZD4o`0000WoV6NH0_l0000<ohebS@03o`000?o2?L;o`Sg201?o
`Sg200?o0000ol/dboo;=</05Oo;=</00ol0003o^DJiokU6^@0>okU6^@03o`000?nfBKKo]TVf00So
]TVf00?o0000oj=LXonSG:<02OnSG:<00ol0003og2?Lom`Sg007om`Sg003o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?o9=/WobCK900SobCK900?o0000ogj1O_mnPGh02omnPGh00ol0003o/Djaok5>/@05ok5>/@03o`00
0?nUFZGoYEZU01;oYEZU00Co0000oiMXUonGJ9OoUfRG1Ol00003oiQWV003o`000?n=LXgoSG:=00go
SG:=0ol0000@ol8m`P;o00006?o;=</00ol0003o^DJiokU6^@0=okU6^@03o`000?nfBKKo]TVf00Wo
]TVf00?o0000oj=LXonSG:<02OnSG:<00ol0003og2?Lom`Sg007om`Sg003o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_obCK900?o0000ogj1O_mnPGh02_mnPGh00ol0003o/Djaok5>/@06ok5>/@03o`00
0?nUFZGoYEZU017oYEZU00?o0000oiMXUonGJ9L01onGJ9L3o`00013oSG:=00?o0000ohUfROn9MXT0
1Ol00009ol8m`P;o000000?oW6>Lo`000?o;=</05oo;=</00ol0003o^DJiokU6^@0=okU6^@03o`00
0?nfBKKo]TVf00Wo]TVf00?o0000oj=LXonSG:<02?nSG:<2o`0000[og2?L00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oM8]gogB;M00;ogB;M00?o0000olTfbOo9=/T02Oo9=/T00ol0003oOX5nogj1
OP0:ogj1OP03o`000?naC[7o/Dja00Oo/Dja00?o0000ojEJYOnUFZD03onUFZD00ol0003oUfRGoiMX
U`0:oiMXU`03o`000?n=LXgoSG:=00goSG:=00?o0000ohUfROn9MXT01_n9MXT4o`0000Co`Sg200?o
0000oiaSW?nLHi`00_nLHi`00ol0003obcC;ol/db`0Fol/db`03o`000?niA[Wo^DJi00_o^DJi00?o
0000okI9]_nfBKH02onfBKH00ol0003oXebSoj=LX`06oj=LX`03o`000?nLHico000000[og2?L00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oM8]gogB;M00?ogB;M00?o0000olTfbOo9=/T02?o9=/T=
o`0000[o/Dja00?o0000ojEJYOnUFZD03onUFZD00ol0003oUfRGoiMXU`0;oiMXU`03o`000?n=LXgo
SG:=00coSG:=00?o0000ohUfROn9MXT02_n9MXT4o`0000GoW6>L00?o0000ol/dboo;=</05_o;=</0
0ol0003o^DJiokU6^@0:okU6^@03o`000?nfBKKo]TVf00co]TVf00?o0000oj=LXonSG:<01?nSG:<2
o`0000?oW6>L00?o0000om`Sg?oL8m`02?oL8m`00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omdR
gOoM8]d00ooM8]d00ol0003obCK9olTfb@07olTfb@03o`000?mlPgcoO8=l00WoO8=l00?o0000ok5>
/OnaC[402OnaC[400ol0003oYEZUojEJY@0=ojEJY@03o`000?nGJ9OoUfRG00coUfRG00?o0000oheb
SOn=LXd03?n=LXd00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?mbSG;o000000KoW6>L00?o0000ol/d
boo;=</05_o;=</00ol0003o^DJiokU6^@09okU6^@03o`000?nfBKKo]TVf00co]TVf00?o0000oj=L
XonSG:<00onSG:<00ol0003oW6>LoiaSW003oiaSW003o`000?oL8mcog2?L00Sog2?L00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oM8]gogB;M00CogB;M00?o0000olTfbOo9=/T01_o9=/T00ol0003o
O8=logb3O008ogb3O003o`000?naC[7o/Dja00_o/Dja00?o0000ojEJYOnUFZD02?nUFZD4o`0000oo
UfRG00?o0000ohebSOn=LXd02on=LXd00ol0003oRGJ9ohUfR@0;ohUfR@04o`000?mbSG;oLXebo`00
00OoW6>L00?o0000ol/dboo;=</05Oo;=</00ol0003o^DJiokU6^@08okU6^@03o`000?nfBKKo]TVf
00go]TVf00?o0000oj=LXonSG:<00_nSG:<00ol0003oW6>LoiaSW005oiaSW003o`000?oL8mcog2?L
00Oog2?L00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oM8]gogB;M00GogB;M00?o0000olTfbOo9
=/T01Oo9=/T00ol0003oO8=logb3O008ogb3O003o`000?naC[7o/Dja00_o/Dja00?o0000ojEJYOnU
FZD00onUFZD5o`0000?oV6NH00?o0000oiMXUonGJ9L03_nGJ9L00ol0003oSG:=ohebS@0:ohebS@03
o`000?n9MXWoRGJ900[oRGJ900Go0000og:=L_mbSG;oLXebo`000007oiaSW003o`000?o;=<_obcC;
01GobcC;00?o0000okU6^OniA[T02?niA[T00ol0003o]TVfokI9]P0=okI9]P03o`000?nSG:?oXebS
00;o00002?nLHi`00ol0003og2?Lom`Sg008om`Sg0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003ogB;MomdRg@05omdRg@03o`000?o9=/WobCK900Go
bCK900?o0000ogb3O?mlPg`02?mlPg`00ol0003o/Djaok5>/@0<ok5>/@Go00002OnHIiP00ol0003o
UfRGoiMXU`0<oiMXU`;o00003?n=LXd00ol0003oRGJ9ohUfR@0:ohUfR@05o`000?mbSG;oLXebog:=
L_l000002?nLHi`00ol0003obcC;ol/db`0Dol/db`?o00001oniA[T00ol0003o]TVfokI9]P0>okI9
]P03o`000?nSG:?o000000_oW6>L00?o0000om`Sg?oL8m`01_oL8m`00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000omdRgOoM8]d01OoM8]d00ol0003obCK9olTfb@04olTfb@03o`000?mlPgcoO8=l00Oo
O8=l00?o0000ok5>/OnaC[403?naC[401?l0003oYEZUojEJYOl0000;oiQWV003o`000?nGJ9OoUfRG
00_oUfRG00Co0000ofn@Kom_T6oo00002_n=LXd00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?mbSG;o
LXeb00;oLXeb00?o0000oiaSW?nLHi`01_nLHi`00ol0003obcC;ol/db`0Aol/db`?o00000onTFj@0
0ol0003o^DJiokU6^@04okU6^@03o`000?nfBKKo]TVf00go]TVf1?l0000;oiaSW003o`000?oL8mco
g2?L00Gog2?L00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oM8]gogB;M00KogB;M00Co0000olTf
bOo9=/WobCK91?l00008ogb3O003o`000?naC[7o/Dja00_o/Dja00?o0000ojEJYOnUFZD00_nUFZD0
0ol0003oV6NHoiQWV008oiQWV003o`000?nGJ9OoUfRG00[oUfRG00?o0000ofn@Kom_T6l00_m_T6l0
0ol0003oSG:=ohebS@03ohebS@Go00002on9MXT00ol0003oLXebog:=LP03og:=LP03o`000?nLHico
W6>L00OoW6>L00?o0000ol/dboo;=</03_o;=</2o`0000OoY5^T00?o0000okU6^OniA[T00_niA[T0
0ol0003o]TVfokI9]P0=okI9]P03o`000?nTFjCoY5^T00;oY5^T00?o0000oiaSW?nLHi`02OnLHi`0
0ol0003og2?Lom`Sg003om`Sg003o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003ogB;MomdRg@07omdR
g@?o00001?niA[T00ol0003oO8=logb3O005ogb3O003o`000?naC[7o/Dja00[o/Dja00?o0000ojEJ
YOnUFZD00onUFZD00ol0003oV6NHoiQWV009oiQWV003o`000?nGJ9OoUfRG00SoUfRG00?o0000ofn@
Kom_T6l01?m_T6l5o`0000Co?/4n00?o0000ohUfROn9MXT02On9MXT00ol0003oLXebog:=LP03og:=
LP03o`000?nLHicoW6>L00SoW6>L00?o0000ol/dboo;=</02_o;=</3o`0000[oY5^T00Go0000okU6
^OniA[Wo^DJio`00000>okI9]P03o`000?nTFjCoY5^T00CoY5^T0_l00009oiaSW003o`000?oL8mco
g2?L00;og2?L00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oM8]gogB;M00OogB;M00?o0000okU6
^OniA[T01OniA[T00ol0003oO8=logb3O003ogb3O003o`000?naC[7o/Dja00[o/Dja00?o0000ojEJ
YOnUFZD01?nUFZD00ol0003oV6NHoiQWV009oiQWV003o`000?nGJ9OoUfRG00OoUfRG00?o0000ofn@
Kom_T6l01Om_T6l00ol0003o?/4nock1?P07ock1?P03o`000?n9MXWoRGJ900OoRGJ900?o0000og:=
L_mbSG801?mbSG800ol0003oW6>LoiaSW008oiaSW003o`000?o;=<_obcC;00SobcC;0_l0000>ojAK
Y0Co00003?nfBKH2o`0000WoY5^T00?o0000oiaSW?nLHi`01onLHi`01?l0003og2?Lom`Sg?l0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omdRgOoM8]d01OoM8]d00ol0003o^DJiokU6^@07okU6^@;o00000omlPg`00ol0
003o/Djaok5>/@09ok5>/@03o`000?nUFZGoYEZU00KoYEZU00?o0000oiQWV?nHIiP02OnHIiP00ol0
003oUfRGoiMXU`05oiMXU`03o`000?m_T6ooKi1_00KoKi1_00?o0000ock1?_ln`Ch02?ln`Ch00ol0
003oRGJ9ohUfR@06ohUfR@03o`000?mbSG;oLXeb00CoLXeb00?o0000oiaSW?nLHi`02OnLHi`4o`00
00?obcC;0ol0000@ojAKY005o`000?o:=L[obSG:olXeb_l000002_nfBKH00ol0003oY5^TojAKY00:
ojAKY0Ko00000onLHi`00ol0003og2?Lo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000omdRgOoM8]d01?oM8]d00ol0
003o^DJiokU6^@0:okU6^@04o`000?mlPgcoO8=lo`0000[o/Dja00?o0000ojEJYOnUFZD01onUFZD0
0ol0003oV6NHoiQWV009oiQWV003o`000?nGJ9OoUfRG00CoUfRG00?o0000ofn@Kom_T6l01om_T6l0
0ol0003o?/4nock1?P08ock1?P;o00001_n9MXT00ol0003oLXebog:=LP05og:=LP03o`000?nLHico
W6>L00WoW6>L00Co0000ohacS?n<LhcoS7><0ol0000BojAKY003o`000?o:=L[obSG:00?obSG:0_l0
0006okI9]P;o00003OnTFj@00ol0003ohAkQon4Nh@03on4Nh@Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000omdRgOoM8]d00ooM8]d0
0ol0003o^DJiokU6^@0<okU6^@;o00002_naC[400ol0003oYEZUojEJY@08ojEJY@03o`000?nHIiSo
V6NH00[oV6NH00?o0000oiMXUonGJ9L00_nGJ9L00ol0003oKi1_ofn@K`08ofn@K`03o`000?ln`Cko
?/4n00Ko?/4n0_l00002offBK@03o`000?n9MXWoRGJ900;oRGJ900?o0000og:=L_mbSG801_mbSG80
0ol0003oW6>LoiaSW008oiaSW003o`000?n<LhcoS7><00CoS7><00?o0000ojAKY?nTFj@03onTFj@0
0ol0003obSG:olXebP06olXebP;o00000onfBKH00ol0003oY5^TojAKY00=ojAKY003o`000?oQ7^7o
hAkQ00OohAkQ0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003ogB;MomdRg@02omdRg@03o`000?niA[Wo^DJi
00ko^DJi00?o0000ok5>/OnaC[401onaC[400ol0003oYEZUojEJY@0:ojEJY@03o`000?nHIiSoV6NH
00WoV6NH00Go0000oiMXUonGJ9OoUfRGo`00000;ofn@K`03o`000?ln`Cko?/4n00Co?/4n0_l00005
offBK@05o`000?n9MXWoRGJ9ohUfROl000002?mbSG800ol0003oW6>LoiaSW008oiaSW003o`000?n<
LhcoS7><00GoS7><00?o0000ojAKY?nTFj@03_nTFj@00ol0003obSG:olXebP08olXebP03o`000?nf
BKKo000000ooY5^T00?o0000on4NhOoQ7^402?oQ7^401?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oM8]gogB;Mo`00017o^DJi00?o0000ok5>/OnaC[401_naC[400ol0003oYEZU
ojEJY@0;ojEJY@03o`000?nHIiSoV6NH00WoV6NH00Co0000oiMXUonGJ9Oo00003?m_T6l00ol0003o
?/4nock1?P02ock1?P;o00002?m]TVd00ol0003oRGJ9o`000009og:=LP03o`000?nLHicoW6>L00So
W6>L00?o0000ohacS?n<Lh`01On<Lh`00ol0003oY5^TojAKY00=ojAKY003o`000?o:=L[obSG:00[o
bSG:00?o0000ojAKY?nTFj@03_nTFj@00ol0003ohAkQon4Nh@07on4Nh@03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000BokU6^@03o`00
0?naC[7o/Dja00Co/Dja00?o0000ojEJYOnUFZD03?nUFZD00ol0003oV6NHoiQWV00:oiQWV0?o0000
3?m_T6l00ol0003o?/4nock1?P02o`0000_oKI9]00?o0000og:=L_mbSG802?mbSG800ol0003oW6>L
oiaSW007oiaSW003o`000?n<LhcoS7><00OoS7><00?o0000ojAKY?nTFj@03?nTFj@00ol0003obSG:
olXebP0;olXebP;o00003_nTFj@00ol0003ohAkQon4Nh@07on4Nh@03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onDJiOoU6^D00ooU6^D00ol0003o^DJiokU6^@0?okU6^@?o00000ona
C[400ol0003oYEZUojEJY@0>ojEJY@03o`000?nHIiSoV6NH00SoV6NH00Co0000ogR7N?mhQgSoN8Mh
0_l0000:ofn@K`?o00003Om]TVd00ol0003oLXebog:=LP08og:=LP03o`000?nLHicoW6>L00OoW6>L
00?o0000ohacS?n<Lh`01on<Lh`00ol0003oY5^TojAKY00;ojAKY003o`000?o:=L[obSG:00cobSG:
00?o0000olDjaOl000000_l0000:ojAKY003o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oiA[UonDJi@04onDJi@03o`000?niA[Wo^DJi00co^DJi0_l0
0003ojQGZ003o`000?naC[7o0000017oYEZU00?o0000oiQWV?nHIiP01onHIiP00ol0003oN8MhogR7
N004ogR7N0;o00002?m_T6l00ol0003oKI9]offBK@0>offBK@;o00002?mbSG800ol0003oW6>LoiaS
W006oiaSW003o`000?n<LhcoS7><00WoS7><00?o0000ojAKY?nTFj@02OnTFj@00ol0003obSG:olXe
bP0=olXebP03o`000?o5>/GoaC[500;oaC[50ol00007ojAKY003o`000?oQ7^7ohAkQ00OohAkQ00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oiA[UonDJi@05onDJi@03o`000?niA[Wo
^DJi00Wo^DJi0_l00006ojQGZ003o`000?nUFZGoYEZU013oYEZU00?o0000oiQWV?nHIiP01_nHIiP0
0ol0003oN8MhogR7N007ogR7N003o`000?m_T6ooKi1_00CoKi1_0ol0000>offBK@03o`000?mHYeSo
F:MH00?o00001OmbSG800ol0003oW6>LoiaSW006oiaSW003o`000?n<LhcoS7><00[oS7><00?o0000
ojAKY?nTFj@02?nTFj@00ol0003obSG:olXebP0=olXebP03o`000?o5>/GoaC[500GoaC[50ol00004
ojAKY003o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oiA[UonDJi@06onDJi@03o`000?niA[Wo^DJi00Go^DJi0ol00008ojQGZ003o`000?nUFZGoYEZU
017oYEZU00Co0000oiQWV?nHIiSoV6NH1?l0000;ogR7N0;o000000CoKi1_o`000?l0003o00000on5
NXD2o`0000_oKI9]00?o0000oeRWF?mHYeP01?mHYeP2o`0000?oLXeb00?o0000oiaSW?nLHi`01_nL
Hi`00ol0003oS7><ohacS00:ohacS003o`000?nTFjCoY5^T00OoY5^T00?o0000olXeb_o:=LX03_o:
=LX00ol0003oaC[5olDja@08olDja@Co00002_oQ7^400ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiA[UonDJi@07onDJi@03o`000?niA[Wo^DJi00;o^DJi0_l0000<ojQGZ003o`000?nUFZGo
YEZU013oYEZU1?l00003ohacS003o`000?mhQgSoN8Mh00_oN8Mh00?o0000ohEjQOn5NXD01_n5NXD0
0ol0003oKI9]offBK@07offBK@03o`000?mHYeSoF:MH00OoF:MH3?l0000>ohacS003o`000?nTFjCo
Y5^T00KoY5^T00?o0000olXeb_o:=LX03_o:=LX00ol0003oaC[5olDja@0;olDja@03o`000?oQ7^7o
hAkQ00OohAkQ00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oU6^GoiA[U00WoiA[U00Co0000okU6
^Ol0003o00003_nXEjP00ol0003oYEZUojEJY@0?ojEJY@03o`000?n<LhcoS7><00KoS7><00?o0000
ogR7N?mhQgP02_mhQgP00ol0003oQGZ5ohEjQ@07ohEjQ@;o00001_m]TVd00ol0003oF:MHoeRWF008
oeRWF003o`000?nSG:?oXebS00SoXebS00?o0000ohacS?n<Lh`03?n<Lh`00ol0003oY5^TojAKY005
ojAKY003o`000?o:=L[obSG:00oobSG:0_l0000=olDja@03o`000?oQ7^7ohAkQ00KohAkQ00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oU6^GoiA[U00[oiA[U00?o0000ojQGZ?nXEjP03_nXEjP00ol0
003oYEZUojEJY@0>ojEJY@03o`000?n<LhcoS7><00OoS7><00?o0000ogR7N?mhQgP02_mhQgP00ol0
003oQGZ5ohEjQ@09ohEjQ@;o00000om]TVd00ol0003oF:MHoeRWF009oeRWF003o`000?nSG:?oXebS
00WoXebS00?o0000ohacS?n<Lh`02_n<Lh`4o`0000CoY5^T00?o0000olXeb_o:=LX04?o:=LX01?l0
003o`cc3o`000?l0000<olDja@03o`000?oQ7^7ohAkQ00GohAkQ00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oU6^GoiA[U00[oiA[U00?o0000ojQGZ?nXEjP03onXEjP@o`0000[oS7><00?o0000ogR7
N?mhQgP02OmhQgP00ol0003oHIiQo`00000<ohEjQ@05o`000?m]TVgo0000oeVVFOl000002_mHYeP0
0ol0003oXebSoj=LX`09oj=LX`03o`000?n<LhcoS7><00OoS7><0ol00004ojaC[0?o000000?oY5^T
o`000?o:=LX04Oo:=LX01?l0003o`cc3ol<l`oo3?<<2o`0000_oaC[500?o0000on4NhOoQ7^400ooQ
7^400ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onDJiOoU6^D02_oU6^D00ol0003oZ5NXojQGZ00?
ojQGZ003o`000?n[E:_oZeB[00coZeB[00?o0000ohacS?n<Lh`02On<Lh`00ol0003oN8MhogR7N007
ogR7N004o`000?mQWV7oHIiQo`0000goQGZ500Go0000oeVVFOmIYUWoFJIIo`000009oeRWF003o`00
0?nSG:?oXebS00[oXebS00?o0000ohacS?n<Lh`00on<Lh`3o`0000[o[5>/00?o0000olXeb_o:=LX0
4?o:=LX00ol0003o`cc3ol<l``04ol<l``;o00002_o5>/D00ol0003ohAkQon4Nh@04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coiA[U00?o0000ojQGZ?nXEjP03onXEjP00ol0003oZeB[oj]DZ`0<oj]DZ`03o`000?n<
LhcoS7><00WoS7><00?o0000ogR7N?mhQgP01_mhQgP00ol0003oHIiQof6NH@02of6NH@03o`000?n5
NXGoQGZ500[oQGZ500?o0000oeVVFOmIYUT00_mIYUT00ol0003oF:MHoeRWF006oeRWF003o`000?nS
G:?oXebS00[oXebS00?o0000ohacS?n<Lh`00ol0000=ojaC[003o`000?o:=L[obSG:013obSG:00?o
0000ol<l`oo3?<<01_o3?<<2o`0000WoaC[50_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000onDJiOoU6^D02_oU6^D00ol0003oZ5NXojQGZ00=ojQGZ0?o00003on[E:/0
0ol0003oS7><ohacS008ohacS003o`000?mhQgSoN8Mh00GoN8Mh00?o0000of6NHOmQWV400omQWV40
0ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?mIYUWoFJII00?oFJII00?o0000oeRWF?mHYeP01OmHYeP0
0ol0003oXebSoj=LX`0;oj=LX`;o00004On/Dj`00ol0003obSG:olXebP0?olXebP03o`000?o3?<?o
`cc300So`cc30_l00007olDja@03o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000onDJiOoU6^D02?oU6^D00ol0003oZ5NXojQGZ009ojQGZ0Go00000_n=LXd00ol0
003oZeB[oj]DZ`0=oj]DZ`03o`000?n<LhcoS7><00WoS7><00?o0000ogR7N?mhQgP01?mhQgP00ol0
003oHIiQof6NH@04of6NH@03o`000?n5NXGoQGZ500SoQGZ500?o0000oeVVFOmIYUT01OmIYUT00ol0
003oF:MHoeRWF004oeRWF003o`000?nSG:?oXebS00_oXebS00?o0000ojaC[?n/Dj`04?n/Dj`00ol0
003obSG:olXebP0?olXebP03o`000?o3?<?o`cc300[o`cc30_l00004olDja@03o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003oiA[UonDJi@07onDJi@03o`000?nXEjSoZ5NX00CoZ5NX1Ol00007ohebS@03
o`000?n[E:_oZeB[00goZeB[00?o0000ohacS?n<Lh`02On<Lh`00ol0003oN8MhogR7N003ogR7N003
o`000?mQWV7oHIiQ00GoHIiQ00?o0000ohEjQOn5NXD02?n5NXD00ol0003oFJIIoeVVF@06oeVVF@03
o`000?mHYeSoF:MH00?oF:MH00?o0000oj=LXonSG:<02onSG:<00ol0003o[5>/ojaC[00@ojaC[003
o`000?o:=L[obSG:00oobSG:00?o0000ol<l`oo3?<<03?o3?<<2o`000003olDjaOl0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oU6^GoiA[U00OoiA[U00?o0000ojQGZ?l00000
1?l0000<ohebS@03o`000?n[E:_oZeB[00koZeB[00?o0000ohacS?n<Lh`02?n<Lh`00ol0003oN8Mh
ogR7N002ogR7N003o`000?mQWV7oHIiQ00OoHIiQ00?o0000ohEjQOn5NXD01on5NXD00ol0003oFJII
oeVVF@07oeVVF@03o`000?mHYeSoF:MH00;oF:MH00?o0000oj=LXonSG:<02onSG:<00ol0003o[5>/
ojaC[00AojaC[003o`000?o:=L[obSG:00gobSG:00?o0000ol<l`oo3?<<03oo3?<<00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onDJiOoU6^D01OoU6^D3o`00017oSG:=00?o0000oj]DZon[E:/03_n[
E:/00ol0003oS7><ohacS009ohacS004o`000?mhQgSoN8Mho`0000[oHIiQ00?o0000ohEjQOn5NXD0
1on5NXD00ol0003oFJIIoeVVF@08oeVVF@05o`000?mHYeSoF:MHoeRWF?l000003OnSG:<00ol0003o
[5>/ojaC[00AojaC[0?o00003Oo:=LX00ol0003o`cc3ol<l``0?ol<l``03o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oU6^D2o`0000;o/Dja00?o0000ohebSOn=LXd03on=LXd00ol0003o
ZeB[oj]DZ`0>oj]DZ`03o`000?n<LhcoS7><00SoS7><1Ol0000;of6NH@03o`000?n5NXGoQGZ500Ko
QGZ500?o0000oeVVFOmIYUT02OmIYUT01?l0003oF:MHoeRWF?l0000=oj=LX`03o`000?n/Djco[5>/
017o[5>/00?o0000ohYeR_n:MHX00ol0000:olXebPCo00003Oo3?<<00ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000omlPgooO8=oogb3O0_l00005ok5>/@03o`000?n=LXgoSG:=00koSG:=00?o0000oj]D
Zon[E:/03_n[E:/00ol0003oS7><ohacS007ohacS003o`000?n;M8_oRgB;00?oRgB;00?o0000of6N
HOmQWV402?mQWV400ol0003oQGZ5ohEjQ@05ohEjQ@03o`000?mIYUWoFJII00[oFJII1Ol0000<oj=L
X`03o`000?n/Djco[5>/013o[5>/00?o0000ohYeR_n:MHX01?n:MHX3o`0000KobSG:00?o0000ol`c
c?o<<l`00_o<<l`5o`0000So`cc300?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oO8=oogb3O00?o
gb3O00?o0000ok5>/OnaC[401?naC[400ol0003oSG:=ohebS@0=ohebS@03o`000?n[E:_oZeB[00oo
ZeB[00?o0000ohacS?n<Lh`01?n<Lh`2o`0000OoRgB;00?o0000of6NHOmQWV401omQWV4Eo`0000Go
IiQW00?o0000oj=LXonSG:<02?nSG:<3o`00013o[5>/00?o0000ohYeR_n:MHX02?n:MHX3o`0000;o
bSG:00?o0000ol`cc?o<<l`02?o<<l`5o`0000?o`cc300?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oO8=oogb3O00Cogb3O00?o0000ok5>/OnaC[401OnaC[400ol0003oSG:=ohebS@0;ohebS@Co0000
3on[E:/00ol0003oS7><ohacS003ohacS003o`000?n;M8_oRgB;00SoRgB;00?o0000of6NHOmQWV40
1?mQWV42o`0000SoRgB;00?o0000ogZ5N_mjQGX02?mjQGX00ol0003oIiQWofNHI`05ofNHI`;o0000
1_nSG:<2o`0000?oUfRG00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oRWF:ohYeRP0<ohYeRP;o0000
4?o<<l`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003ogb3OomlPg`05omlPg`03o`000?naC[7o/Dja00Ko/Dja00?o
0000ohebSOn=LXd02On=LXd00ol0003oLXebo`000002ohebS@?o00003?n[E:/01?l0003oS7><ohac
S?n<Lh`2o`0000coRgB;00?o0000of6NHOmQWV400_mQWV400ol0003oRgB;oh]dR`08oh]dR`03o`00
0?mjQG[oNXEj00SoNXEj00?o0000ofNHIomWV6L01omWV6L00ol0003oXebSoj=LX`02oj=LX`03o`00
0?nGJ9OoUfRG00CoUfRG0_l0000;ojaC[003o`000?n:MH[oRWF:00coRWF:00?o0000oieRWOl00000
4_o<<l`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003ogb3OomlPg`06omlPg`03o`000?naC[7o/Dja00Oo/Dja00?o
0000ohebSOn=LXd01_n=LXd2o`0000;oLXeb00?o0000ohebSOn=LXd00on=LXd3o`0000[oZeB[00?o
0000ohacS?l000003on;M8/01?l0003oHIiQo`000?l0000;oh]dR`03o`000?mjQG[oNXEj00SoNXEj
00?o0000ofNHIomWV6L02?mWV6L01?l0003oXebSo`000?l00009oiMXU`03o`000?n/Djco[5>/00Oo
[5>/00?o0000ohYeR_n:MHX03?n:MHX01?l0003oWF:MoieRWOl0000Col`cc003o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000omlPgooO8=l01ooO8=l00ol0003o/Djaok5>/@08ok5>/@03o`000?n=LXgoSG:=00Co
SG:=00?o0000og:=L_mbSG800ombSG800ol0003oSG:=ohebS@05ohebS@?o00001_n[E:/4o`00013o
RgB;00?o0000oh]dRon;M8/03?n;M8/00ol0003oNXEjogZ5NP07ogZ5NP03o`000?mWV6OoIiQW00Wo
IiQW00?o0000oiMXUonGJ9L02_nGJ9L2o`0000Ko[5>/00?o0000ohYeR_n:MHX03?n:MHX00ol0003o
WF:MoieRW@02oieRW@03o`000?o<<lcoc3?<00ooc3?<00?o0000om/Tfol000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003ogb3OomlPg`08omlPg`03o`000?naC[7o/Dja00Wo/Dja00Co0000ohebSOn=LXgo
SG:=0_l00006og:=LP03o`000?n=LXgoSG:=00SoSG:=0ol000000on[E:_o0000o`000004oi=/T`03
o`000?n;M8_oRgB;00goRgB;00?o0000oh]dRon;M8/03?n;M8/00ol0003oNXEjogZ5NP07ogZ5NP03
o`000?mWV6OoIiQW00WoIiQW00?o0000oiMXUonGJ9L03?nGJ9L00ol0003o[5>/ojaC[003o`0000ko
RWF:00?o0000oieRWOnMHYd00onMHYd00ol0003oc3?<ol`cc00>ol`cc005o`000?oK9=_ofbCKom/T
fol000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003ogb3OomlPg`09omlPg`03o`000?naC[7o/Dja00[o
/Dja00?o0000ohebSOl000002?mbSG800ol0003oSG:=ohebS@0;ohebS@03o`000?nCK9?oTfbC00Go
TfbC00?o0000oh]dRon;M8/03?n;M8/00ol0003oRgB;oh]dR`0<oh]dR`03o`000?mjQG[oNXEj00Oo
NXEj00?o0000ofNHIomWV6L02?mWV6L2o`0000ooUfRG0_l00002oiYUVP03o`000?n:MH[oRWF:00_o
RWF:00?o0000oieRWOnMHYd01?nMHYd00ol0003oc3?<ol`cc00=ol`cc003o`000?oK9=_ofbCK00?o
fbCK00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;omlPg`03o`000?naC[7o/Dja00_o/Dja00?o0000og:=L_mbSG80
1ombSG800ol0003oSG:=ohebS@0;ohebS@03o`000?nCK9?oTfbC00KoTfbC00?o0000oh]dRon;M8/0
2on;M8/2o`0000goRgB;00?o0000ogZ5N_mjQGX01omjQGX00ol0003oIiQWofNHI`07ofNHI`04o`00
0?mcS7?oLhaco`0000koUfRG00?o0000oiYUV_nJIIX00_nJIIX00ol0003oRWF:ohYeRP09ohYeRP03
o`000?nMHYgoWF:M00KoWF:M00?o0000ol`cc?o<<l`02oo<<l`00ol0003ofbCKom/Tf`05om/Tf`04
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000Sogb3O00?o0000ok5>/OnaC[402_naC[42o`0000Wo
LXeb00?o0000ohebSOn=LXd02on=LXd00ol0003oTfbCoi=/T`07oi=/T`03o`000?n;M8_oRgB;00Wo
RgB;00Co0000oeNXEomGZ5Oo00003?n;M8/00ol0003oNXEjogZ5NP07ogZ5NP03o`000?mWV6OoIiQW
00KoIiQW00Go0000og><LomcS7?oLhaco`00000>oiMXU`03o`000?nJII[oVVFJ00?oVVFJ00?o0000
ohYeR_n:MHX01on:MHX00ol0003oWF:MoieRW@07oieRW@03o`000?o<<lcoc3?<00[oc3?<00?o0000
om/TfooK9=/01ooK9=/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006omlPg`03o`000?naC[7o/Dja
00Wo/Dja00Co0000ohebSOn=LXgo00002OmbSG800ol0003oSG:=ohebS@09ohebS@03o`000?nCK9?o
TfbC00WoTfbC00?o0000oh]dRon;M8/01on;M8/00ol0003oEjQGoeNXE`02oeNXE`03o`000?n;M8_o
RgB;00WoRgB;00?o0000ogZ5N_mjQGX01omjQGX00ol0003oIiQWofNHI`05ofNHI`03o`000?mcS7?o
Lhac00?oLhac00?o0000oiMXUonGJ9L02_nGJ9L00ol0003oVVFJoiYUVP05oiYUVP03o`000?n:MH[o
RWF:00GoRWF:00?o0000oieRWOnMHYd02?nMHYd00ol0003oc3?<ol`cc009ol`cc003o`000?oK9=_o
fbCK00SofbCK00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oO8=l3o`0000Wo/Dja00?o0000oheb
SOn=LXd00_n=LXd00ol0003oLXebog:=LP06og:=LP03o`000?n=LXgoSG:=00WoSG:=00?o0000oi=/
TonCK9<02_nCK9<00ol0003oRgB;oh]dR`05oh]dR`03o`000?mGZ5OoEjQG00CoEjQG00?o0000oh]d
Ron;M8/02?n;M8/00ol0003oNXEjogZ5NP07ogZ5NP03o`000?mWV6OoIiQW00CoIiQW00?o0000og><
LomcS7<01?mcS7<00ol0003oUfRGoiMXU`0:oiMXU`03o`000?nJII[oVVFJ00KoVVFJ00?o0000ohYe
R_n:MHX00on:MHX00ol0003oWF:MoieRW@09oieRW@03o`000?o<<lcoc3?<00Soc3?<00?o0000om/T
fooK9=/02OoK9=/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omTVf@?o00001OnaC[400ol0003o
SG:=ohebS@03ohebS@03o`000?mbSG;oLXeb00KoLXeb00?o0000ohebSOn=LXd02On=LXd00ol0003o
TfbCoi=/T`0;oi=/T`03o`000?n;M8_oRgB;00?oRgB;00?o0000oeNXEomGZ5L01_mGZ5L00ol0003o
RgB;oh]dR`08oh]dR`03o`000?mjQG[oNXEj00KoNXEj00?o0000ofNHIomWV6L00_mWV6L2o`0000So
Lhac00?o0000oiMXUonGJ9L02OnGJ9L00ol0003oVVFJoiYUVP07oiYUVP05o`000?n:MH[oRWF:ohYe
R_l000003OnMHYd00ol0003oc3?<ol`cc006ol`cc003o`000?oK9=_ofbCK00[ofbCK00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oI9]WofBKI00GofBKI0ol000000onaC[7o0000ohebS@06ohebS@03
o`000?mbSG;oLXeb00GoLXeb00?o0000ohebSOn=LXd02On=LXd00ol0003oTfbCoi=/T`0<oi=/T`05
o`000?n;M8_oRgB;oh]dRol000002_mGZ5L00ol0003oRgB;oh]dR`07oh]dR`03o`000?mjQG[oNXEj
00KoNXEj00?o0000ofNHIol000000_l000000onPGj3o0000og><L`07og><L`03o`000?nGJ9OoUfRG
00SoUfRG00?o0000oiYUV_nJIIX02OnJIIX00ol0003oRWF:o`00000=oieRW@Co00001Oo<<l`00ol0
003ofbCKom/Tf`0;om/Tf`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003ofBKIomTVf@08omTVf@03
o`000?n=LXgoSG:=00OoSG:=00?o0000og:=L_mbSG801?mbSG800ol0003oSG:=ohebS@09ohebS@03
o`000?nCK9?oTfbC00goTfbC00?o0000oh]dRol000003?mGZ5L:o`0000OoNXEj0ol00005oj1OX003
o`000?mcS7?oLhac00KoLhac00?o0000oiMXUonGJ9L01onGJ9L00ol0003oVVFJoiYUVP0:oiYUVP03
o`000?nMHYgoWF:M00_oWF:M00?o0000okE:]OneB[D00_neB[D3o`000003ol`cc?l0003ofbCK00_o
fbCK0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omTVfOoI9]T02OoI9]T00ol0003oSG:=ohebS@07ohebS@03o`00
0?mbSG;oLXeb00GoLXeb00?o0000ohebSOn=LXd01on=LXd00ol0003oTfbCoi=/T`0?oi=/T`;o0000
2omGZ5L00ol0003oUVVFoiIYUP07oiIYUP03o`000?mjQG[oNXEj00;oNXEj0ol00008oj1OX003o`00
0?mcS7?oLhac00KoLhac00?o0000oiMXUonGJ9L01onGJ9L00ol0003oVVFJoiYUVP0:oiYUVP03o`00
0?nMHYgoWF:M00[oWF:M00?o0000okE:]OneB[D01_neB[D00ol0003ofbCKom/Tf`08om/Tf`?o0000
0_oT6n@00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omTVfOoI9]T02OoI9]T00ol0003oSG:=oheb
S@08ohebS@03o`000?mbSG;oLXeb00CoLXeb00?o0000ohebSOn=LXd01on=LXd00ol0003oTfbCoi=/
T`0>oi=/T`04o`000?mYUVWoJIIYo`0000WoEjQG00?o0000oiIYU_nFJIH02OnFJIH01?l0003oNXEj
o`000?l0000<oj1OX003o`000?mcS7?oLhac00KoLhac00?o0000oiMXUonGJ9L01_nGJ9L00ol0003o
VVFJoiYUVP0;oiYUVP03o`000?nMHYgoWF:M00OoWF:M0_l00009okE:]@03o`000?oK9=_ofbCK00Co
fbCK1?l00006on@Ki003o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003ofBKIomTVf@09omTVf@03o`00
0?n=LXgoSG:=00SoSG:=00?o0000og:=L_mbSG800ombSG8>o`0000goTfbC00?o0000ofVFJOmYUVT0
0_mYUVT00ol0003oEjQGoeNXE`05oeNXE`03o`000?nFJIKoUVVF00_oUVVF00?o0000oj1OX?nPGj00
3?nPGj000ol0003oLhacog><L`06og><L`03o`000?nGJ9OoUfRG00GoUfRG00?o0000oiYUV_nJIIX0
3?nJIIX00ol0003oWF:MoieRW@06oieRW@03o`000?neB[Go]DZe00[o]DZe00?o0000om/TfooK9=/0
0ol0000:on@Ki0?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oI9]WofBKI00_ofBKI00?o0000ohebSOn=LXd02?n=
LXd01Ol0003oLXebog:=L_mbSG;o000000_oPgb300?o0000od:m@_m2_D800ol00009oi=/T`03o`00
0?mYUVWoJIIY00CoJIIY00?o0000oeNXEomGZ5L00omGZ5L00ol0003oUVVFoiIYUP0<oiIYUP03o`00
0?nPGj3oX5nP00goX5nP00?o0000og><LomcS7<01_mcS7<00ol0003oUfRGoiMXU`03oiMXU`?o0000
3OnJIIX00ol0003oWF:MoieRW@05oieRW@03o`000?neB[Go]DZe00co]DZe0_l0000=on@Ki003o`00
0?ok1?_on`Ck00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oI9]WofBKI00_ofBKI00?o0000ohebSOn=LXd02?n=
LXd4o`0000coPgb300?o0000od:m@_m2_D800om2_D83o`0000GoTfbC00?o0000ofVFJOmYUVT01_mY
UVT01Ol0003oEjQGoeNXEomGZ5Oo000000ooUVVF00?o0000oj1OX?nPGj003OnPGj000ol0003oLhac
og><L`06og><L`03o`000?nGJ9OoUfRG00?o00000omfRGH00ol0003oVVFJoiYUVP0;oiYUVP03o`00
0?nMHYgoWF:M00?oWF:M00?o0000okE:]OneB[D03OneB[D00ol0003oi1_Ton@Ki00;on@Ki003o`00
0?ok1?_on`Ck00Con`Ck0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omTVfOoI9]T02_oI9]T3o`0000KoSG:=0ol0
0003ohEjQ@03o`000?n3O8?oPgb300[oPgb300?o0000od:m@_m2_D801_m2_D83o`000003oi=/Tol0
003oJIIY00WoJIIY00?o0000oeNXEol000004?nFJIH00ol0003oX5nPoj1OX00=oj1OX003o`000?mc
S7?oLhac00OoLhac0_l00007ogJ9MP03o`000?nJII[oVVFJ00[oVVFJ00Co0000oieRWOnMHYgoWF:M
0ol0000?okE:]@03o`000?oT6nCoi1_T00_oi1_T00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omTVfOoI9]T02_oI
9]T01?l0003o_T6noki1__nn@Kh2o`000004ohebSOl0003o0000o`0000KoQGZ500?o0000oh=lPon3
O8<02_n3O8<00ol0003o@[e2od:m@P09od:m@P03o`000?mYUVWoJIIY00[oJIIY00?o0000oiIYU_nF
JIH03onFJIH00ol0003oX5nPoj1OX00>oj1OX003o`000?mcS7?oLhac00KoLhac00?o0000ogJ9M_mf
RGH01omfRGH4o`0000SoVVFJ00Co0000oieRWOnMHYgo00000omhQgP2o`0000go]DZe00?o0000on@K
i?oT6n@02_oT6n@00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omTVfOoI9]T02OoI9]T00ol0003o
_T6noki1_P04oki1_P03o`000?n5NXGoQGZ500OoQGZ500?o0000oh=lPon3O8<02On3O8<00ol0003o
@[e2od:m@P0:od:m@P03o`000?mYUVWoJIIY00[oJIIY00?o0000oiIYU_nFJIH03onFJIH00ol0003o
X5nPoj1OX00>oj1OX003o`000?mcS7?oLhac00GoLhac00?o0000ogJ9M_mfRGH02?mfRGH01?l0003o
R7N8ohQgR?n8MhP7o`0000;oVVFJ0_l00006ogR7N0;o00003?neB[D00ol0003oi1_Ton@Ki009on@K
i003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003ofBKIomTVf@08omTVf@03o`000?nn@Kko_T6n00Go
_T6n00?o0000ohEjQOn5NXD02?n5NXD00ol0003oPgb3oh=lP`08oh=lP`03o`000?m2_D;o@[e200[o
@[e200?o0000ofVFJOmYUVT02omYUVT00ol0003oUVVFoiIYUP0>oiIYUP03o`000?nPGj3oX5nP00ko
X5nP1Ol00002og><L`03o`000?mfRGKoMXUf00WoMXUf00?o0000ohQgR?n8MhP02?n8MhP3o`0000Wo
N8Mh0_l0000:okE:]@03o`000?oT6nCoi1_T00Soi1_T00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oI9]WofBKI00SofBKI00?o0000oki1__nn@Kh01onn@Kh00ol0003oQGZ5ohEjQ@07ohEjQ@03o`00
0?n3O8?oPgb300SoPgb300?o0000od:m@_m2_D802_m2_D800ol0003oJIIYofVFJ@0:ofVFJ@;o0000
3_nFJIH3o`0000goX5nP0ol00005oj=LX`;o00002omfRGH00ol0003oR7N8ohQgR00;ohQgR0;o0000
2_mhQgP2o`0000Oo]DZe0ol00009on@Ki003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:oki1_P03o`00
0?n5NXGoQGZ500OoQGZ500?o0000oh=lPon3O8<02?n3O8<>o`0000WoJIIY0ol000000om8]dSo0000
oiIYUP0:oiIYUP?o00000_nWF:L00ol0003oX5nPoj1OX009oj1OX0;o00002OnSG:<00ol0003oMXUf
ogJ9MP09ogJ9MP03o`000?n8MhSoR7N800_oR7N800?o0000oiMXUol000002omhQgP2o`0000Co]DZe
00Co0000omTVfOoI9]WofBKI0_l00007on@Ki003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003o_T6n
oki1_P09oki1_P03o`000?n5NXGoQGZ500KoQGZ500?o0000oh=lPon3O8<02?n3O8<00ol0003oDJiA
oe6^D@0:oe6^D@03o`000?mYUVWoJIIY00CoJIIY0ol00005odRgB003o`000?nFJIKoUVVF00CoUVVF
1?l00006ojMHY`03o`000?nPGj3oX5nP00KoX5nP0_l0000;oj=LX`03o`000?mfRGKoMXUf00WoMXUf
00?o0000ohQgR?n8MhP02_n8MhP01Ol0003oUfRGoiMXUonGJ9Oo000000coN8Mh0_l000000oneB[Go
0000omTVf@05omTVf@03o`000?oT6nCoi1_T00?oi1_T00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?nn@Kko_T6n00So_T6n00?o0000ohEjQOn5NXD01_n5NXD00ol0003oPgb3oh=lP`07oh=lP`03o`00
0?mA[U7oDJiA00_oDJiA00?o0000ofVFJOmYUVT00_mYUVT2o`0000WoB;M800?o0000oiIYU_nFJIH0
0ol0000;ojMHY`03o`000?nPGj3oX5nP00;oX5nP0ol0000>oj=LX`03o`000?mfRGKoMXUf00OoMXUf
00?o0000ohQgR?n8MhP02on8MhP00ol0003oUfRGoiMXU`02oiMXU`03o`000?mhQgSoN8Mh00_oN8Mh
00?o0000omTVfOoI9]T01_oI9]T2o`0000?oi1_T00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?nn
@Kko_T6n00Oo_T6n00?o0000ohEjQOn5NXD01on5NXD00ol0003oPgb3oh=lP`05oh=lP`?o00003OmA
[U44o`0000_oB;M80ol0000?ojMHY`04o`000?nPGj3o0000o`00017oXebS00?o0000ogJ9M_mfRGH0
1omfRGH00ol0003oR7N8ohQgR00:ohQgR003o`000?nGJ9OoUfRG00CoUfRG00?o0000ogR7N?mhQgP0
1omhQgP3o`0000_ofBKI1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000oki1__nn@Kh02?nn@Kh00ol0003oQGZ5ohEj
Q@06ohEjQ@03o`000?n3O8?oPgb300;oPgb30ol00003og2?L003o`000?mA[U7oDJiA00[oDJiA00?o
0000odRgB?m8]dP02om8]dP00ol0003oE:]Do`00000AojMHY`03o`000?nSG:?oXebS017oXebS00?o
0000ogJ9M_mfRGH01omfRGH00ol0003oR7N8ohQgR00:ohQgR003o`000?nGJ9OoUfRG00GoUfRG00Co
0000ogR7N?mhQgSoN8Mh1Ol00002ohacS003o`000?oI9]WofBKI00WofBKI00Co0000oo/4nook1?_o
n`Ck0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000oki1__nn@Kh01onn@Kh00ol0003oQGZ5ohEjQ@05ohEjQ@?o0000
00?oPgb3o`000?l000001om`Sg000ol0003oDJiAoe6^D@08oe6^D@?o00002_m8]dP2o`0000;oE:]D
00?o0000ojMHYonWF:L03onWF:L00ol0003oXebSoj=LX`0Aoj=LX`03o`000?mfRGKoMXUf00OoMXUf
00?o0000ohQgR?n8MhP02On8MhP00ol0003oUfRGoiMXU`07oiMXU`?o00001on<Lh`00ol0003ofBKI
omTVf@09omTVf@03o`000?ok1?_on`Ck00Con`Ck0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000oki1__nn@Kh01onn
@Kh4o`0000;oQGZ50_l00003oiEZU@03o`000?m`Sg3oL8m`00SoL8m`0_l00006oe6^D@;o00000omI
YUT00ol0003oB;M8odRgB006odRgB003o`000?mDZeCoE:]D00?oE:]D00?o0000ojMHYonWF:L03_nW
F:L00ol0003oXebSoj=LX`0Boj=LX`03o`000?mfRGKoMXUf00GoMXUf00?o0000ohQgR?n8MhP02On8
MhP00ol0003oUfRGoiMXU`08oiMXU`03o`000?n<LhcoS7><00OoS7><00?o0000omTVfOoI9]T02?oI
9]T00ol0003on`Ckoo/4n`07oo/4n`;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?nn@Kko_T6n00Co_T6n0_l00004
om4^d@;o00001OnEJYD00ol0003oL8m`og2?L00:og2?L003o`000?mA[U7oDJiA00;oDJiA00?o0000
oeVVFOmIYUT01?mIYUT00ol0003oB;M8odRgB004odRgB003o`000?mDZeCoE:]D00CoE:]D00?o0000
ojMHYonWF:L03_nWF:L00ol0003oXebSoj=LX`0Boj=LX`[o00002_n8MhP00ol0003oUfRGoiMXU`08
oiMXU`03o`000?n<LhcoS7><00OoS7><00?o0000omTVfOoI9]T02?oI9]T00ol0003on`Ckoo/4n`09
oo/4n`?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o_T6noki1__nn@Kh2o`0000OodBkA00?o0000oiEZUOnEJYD01?nEJYD0
0ol0003oL8m`og2?L00:og2?L004o`000?mA[U7o0000o`0000SoFJII00Co0000odRgB?m8]dSoB;M8
0_l00007oeB[E003o`000?nWF:OoYeRW00koYeRW00?o0000oj=LXonSG:<04_nSG:<00ol0003oPgb3
oh=lP`07oh=lP`03o`000?n8MhSoR7N800KoR7N800?o0000oiMXUonGJ9L02_nGJ9L00ol0003oS7><
ohacS006ohacS003o`000?oI9]WofBKI00SofBKI00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?nn
@Kko0000o`0000WodBkA00?o0000oiEZUOnEJYD01?nEJYD00ol0003oL8m`og2?L00;og2?L003o`00
0?mIYUWoFJII00WoFJII00?o0000odRgB?l000002OmDZe@00ol0003oYeRWojMHY`0>ojMHY`;o0000
4_nSG:<00ol0003oPgb3oh=lP`09oh=lP`;o00001_n8MhP00ol0003oUfRGoiMXU`0:oiMXU`03o`00
0?n<LhcoS7><00KoS7><00?o0000omTVfOoI9]T02?oI9]T00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om4^dOoA;]402OoA;]400ol0003oUFZEoiEZU@05oiEZU@03o`000?m`Sg3oL8m`00[oL8m`00?o
0000oeVVFOmIYUT02_mIYUT2o`0000WoE:]D00?o0000ojMHYonWF:L03_nWF:L00ol0003oTVfBo`00
0002o`0000ooXebS00?o0000oh=lPon3O8<02on3O8<00ol0003oR7N8ohQgR003o`0000goUfRG00?o
0000ohacS?n<Lh`01_n<Lh`00ol0003ofBKIomTVf@07omTVf@03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odBkAom4^d@09om4^d@03o`000?nEJYGoUFZE00GoUFZE00?o0000og2?L?m`Sg002Om`Sg02
o`0000_oFJII0_l0000;oeB[E003o`000?nWF:OoYeRW00coYeRW00?o0000oi9]T_nBKI800onBKI83
o`0000coXebS00?o0000oh=lPon3O8<03?n3O8<2o`0000;oPGj100?o0000oiMXUonGJ9L03?nGJ9L0
0ol0003oS7><ohacS005ohacS003o`000?oI9]WofBKI00OofBKI00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oA;]7odBkA00[odBkA00?o0000oiEZUOnEJYD01_nEJYD00ol0003oL8m`og2?L007og2?
L003o`000?mLXeco000000[oFJII00Co0000odFjAOm5^TGo00002_mDZe@00ol0003oYeRWojMHY`0<
ojMHY`03o`000?nBKI;oTVfB00KoTVfB0_l00008oj=LX`;o00003on3O8<00ol0003oPGj1oh5nP@02
oh5nP@03o`000?nGJ9OoUfRG00_oUfRG00?o0000ohacS?n<Lh`01On<Lh`00ol0003ofBKIomTVf@07
omTVf@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odBkAom4^d@0:om4^d@03o`000?nEJYGoUFZE
00KoUFZE00?o0000og2?L?m`Sg001_m`Sg001Ol0003oG:=LoebSG?mLXeco000000SoFJII00?o0000
odFjAOm5^TD00_m5^TD00ol0003oE:]DoeB[E006oeB[E0Co00003?nWF:L00ol0003oTVfBoi9]TP08
oi9]TP?o00000_nSG:<3o`000003ogmoOol0003oPgb300goPgb300?o0000oh5nPOn1OX401?n1OX40
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?n<LhcoS7><00GoS7><00?o0000omTVfOoI9]T01_oI9]T0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om4^dOoA;]402ooA;]400ol0003oUFZEoiEZU@07oiEZ
U@03o`000?m`Sg3oL8m`00?oL8m`0_l00005oebSG003o`000?mIYUWoFJII00CoFJII00?o0000odFj
AOm5^TD00om5^TD00ol0003oE:]DoeB[E005oeB[E003o`000?meRWGoMHYe00;oMHYe0ol00007ojMH
Y`;o00003_nBKI82o`0000GoOgmo00?o0000oh=lPon3O8<02_n3O8<00ol0003oPGj1oh5nP@05oh5n
P@03o`000?nGJ9OoUfRG00_oUfRG00?o0000ohacS?n<Lh`01?n<Lh`00ol0003ofBKIomTVf@06omTV
f@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odBkAom4^d@0;om4^d@03o`000?nEJYGoUFZE00Oo
UFZE00?o0000og2?L?m`Sg000_m`Sg000ol0003oG:=LoebSG006oebSG003o`000?mIYUWoFJII00;o
FJII00?o0000odFjAOm5^TD01Om5^TD00ol0003oE:]DoeB[E002oeB[E0;o00002?meRWD3o`0000;o
YeRW0_l000000omnPGko0000oi9]TP0=oi9]TP03o`000?moOgooOgmo00GoOgmo00?o0000oh=lPon3
O8<02?n3O8<00ol0003oPGj1oh5nP@07oh5nP@03o`000?nGJ9OoUfRG00[oUfRG00?o0000ohacS?n<
Lh`01?n<Lh`00ol0003ofBKIomTVf@06omTVf@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odBkA
om4^d@0<om4^d@03o`000?nEJYGoUFZE00SoUFZE00Co0000og2?L?m`Sg3o00002OmLXe`01Ol0003o
FJIIoeVVFOmIYUWo000000SoAKY500Go0000oeB[E?mDZeCoE:]Do`00000=ogF:M@;o00001?mnPGh0
0ol0003oTVfBoi9]TP0;oi9]TP03o`000?moOgooOgmo00KoOgmo00?o0000oh=lPon3O8<01on3O8<0
0ol0003oPGj1oh5nP@08oh5nP@Co00002?nGJ9L00ol0003oS7><ohacS004ohacS003o`000?oI9]Wo
fBKI00KofBKI00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00_odBkA0ol00009oiEZ
U@03o`000?m`Sg3o000000_oG:=L00?o0000oeVVFOl000002_m5^TD00ol0003oE:]Do`00000?ogF:
M@03o`000?mnPGkoOX5n00;oOX5n00?o0000oi9]T_nBKI802onBKI800ol0003oOgmoogmoO`06ogmo
O`03o`000?n3O8?oPgb300KoPgb300?o0000oh5nPOn1OX402On1OX401?l0003oVfBKoi]TVonKI9/7
o`0000;oUfRG00?o0000ohacS?n<Lh`00on<Lh`00ol0003ofBKIomTVf@05omTVf@03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oA;]7odBkA00SodBkA0ol00003ok]4^`03o`000?nEJYGoUFZE00OoUFZE00?o0000oebS
G?mLXe`02omLXe`00ol0003oAKY5odFjA@0:odFjA@03o`000?meRWGoMHYe00goMHYe00?o0000ogj1
O_mnPGh01?mnPGh00ol0003oTVfBoi9]TP09oi9]TP03o`000?moOgooOgmo00SoOgmo00?o0000oh=l
Pon3O8<00on3O8<2o`0000coPGj100?o0000oi]TVonKI9/02?nKI9/<o`0000?ofBKI0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om4^dOoA;]401_oA;]43o`0000Oo^dBk00?o0000oiEZUOnEJYD01_nEJYD00ol0003o
G:=LoebSG00;oebSG003o`000?m5^TGoAKY500WoAKY50_l0000>ogF:M@03o`000?mnPGkoOX5n00Go
OX5n00?o0000oi9]T_nBKI802OnBKI800ol0003oOgmoogmoO`09ogmoO`03o`000?n3O8?o000000;o
00000_miQWT00ol0003oPGj1oh5nP@08oh5nP@03o`000?nKI9_oVfBK00coVfBK00?o0000om/TfooK
9=/01_oK9=/3o`0000?onPGj0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odBkAom4^d@03om4^d@?o00002onkA;/00ol0003oUFZE
oiEZU@04oiEZU@03o`000?mLXecoG:=L00_oG:=L0ol00007odFjA@?o000000?oJ9MXo`000?meRWD0
3OmeRWD00ol0003oOX5nogj1OP06ogj1OP03o`000?nBKI;oTVfB00SoTVfB00?o0000ogmoOomoOgl0
2_moOgl00ol0003oNHIiogV6N@04ogV6N@03o`000?n1OX7oPGj100OoPGj100?o0000oi]TVonKI9/0
2onKI9/00ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00ConPGj0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om4^dOl0
003o0000o`0000oo^dBk00?o0000oiEZUOnEJYD00onEJYD>o`0000?oFjAK0_l00002odFjA@?o0000
1OmXUfP00ol0003oMHYeogF:M@0:ogF:M@03o`000?mnPGkoOX5n00OoOX5n00?o0000oi9]T_nBKI80
2?nBKI800ol0003oOgmoogmoO`0:ogmoO`03o`000?miQWWoNHIi00GoNHIi00?o0000oh5nPOn1OX40
1_n1OX400ol0003oVfBKoi]TV`0;oi]TV`03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o^dBk00?o0000oiEZUOnEJYD00_nEJYD00ol0003oEJYEoeFZ
E@0:oeFZE@03o`000?mKY5_oFjAK00?oFjAK0_l00009ofRGJ003o`000?meRWGoMHYe00WoMHYe00?o
0000ogj1O_mnPGh02?mnPGh2o`0000SoTVfB00?o0000ogmoOomoOgl02OmoOgl00ol0003oNHIiogV6
N@07ogV6N@03o`000?n1OX7oPGj100CoPGj100?o0000oi]TVonKI9/02onKI9/00ol0003ofbCKom/T
f`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o^dBkok]4^`0?ok]4^`?o000000?oUFZE
o`000?mEZUD02omEZUD00ol0003oFjAKoe^TF`04oe^TF`03o`000?mXUfSoJ9MX00WoJ9MX00?o0000
ogF:MOmeRWD01omeRWD00ol0003oOX5nogj1OP09ogj1OP04o`000?mhQgSo0000o`0000KoTVfB00?o
0000ogmoOomoOgl02OmoOgl00ol0003oNHIiogV6N@08ogV6N@03o`000?n1OX7oPGj100?oPGj100?o
0000oi]TVonKI9/02onKI9/00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o^dBkok]4^`0<ok]4^`;o00000onbCK82o`0000coEJYE00?o0000oe^TFomKY5/01?mKY5/0
0ol0003oJ9MXofRGJ00:ofRGJ0Wo00002omnPGh00ol0003oN8MhogR7N002ogR7N0?o00000_nBKI80
0ol0003oOgmoogmoO`0:ogmoO`03o`000?miQWWoNHIi00WoNHIi00?o0000oh5nPOn1OX400_n1OX40
0ol0003oVfBKoi]TV`0:oi]TV`03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_nkA;/2o`0000Go/Tfb00?o0000ohAkQ?l000002_mEZUD00ol0003oFjAKoe^TF`06oe^T
F`03o`000?mXUfSoJ9MX00WoJ9MX00?o0000ofRGJ?mXUfP01OmXUfP00ol0003oOX5nogj1OP09ogj1
OP03o`000?mhQgSoN8Mh00GoN8Mh0ol00009ogmoO`?o00003OmiQWT01Ol0003oPGj1oh5nPOn1OX7o
000000coVfBK00?o0000om/TfooK9=/02OoK9=/00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000ok]4
^onkA;/01OnkA;/2o`0000Oo/Tfb00Co0000ohAkQ?n4NhCo00002OmEZUD00ol0003oFjAKoe^TF`06
oe^TF`03o`000?mXUfSoJ9MX00SoJ9MX00?o0000ofRGJ?mXUfP01omXUfP00ol0003oOX5nogj1OP07
ogj1OP03o`000?mhQgSoN8Mh00SoN8Mh0ol00002ogmoO`Go00000_m?/4l00ol0003oNHIiogV6N@0<
ogV6N@03o`000?n1OX7o000000coVfBK00?o0000om/TfooK9=/02_oK9=/00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000ok]4^onkA;/00_nkA;/2o`0000So/Tfb00?o0000ohAkQ?n4Nh@00_n4Nh@5o`00
00CoEJYE00?o0000oe^TFomKY5/01_mKY5/00ol0003oJ9MXofRGJ008ofRGJ003o`000?mXUfSoJ9MX
00OoJ9MX00?o0000ogj1O_mnPGh01omnPGh00ol0003oN8MhogR7N008ogR7N003o`000?m>/DkoC[5>
00;o00002?m?/4l00ol0003oNHIiogV6N@0<ogV6N@Co00002_nKI9/00ol0003ofbCKom/Tf`0:om/T
f`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o^dBko`000?l0000:ok9=/P03o`000?n4NhCoQ7^4
00;oQ7^400?o0000obSG:?lXebP00_lXebP4o`0000WoFjAK00?o0000ofRGJ?mXUfP02?mXUfP00ol0
003oJ9MXofRGJ008ofRGJ003o`000?mnPGkoOX5n00GoOX5n00?o0000ogR7N?mhQgP02?mhQgP01Ol0
003oC[5>odjaC_m>/Dko000000[oCk1?0ol0000;ogV6N@04o`000?o4>lCoa3_4ol@ka0Co00001OnK
I9/00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o/Tfbok9=/P0:
ok9=/P03o`000?n4NhCoQ7^400?oQ7^400?o0000obSG:?lXebP01?lXebP00ol0003oFjAKoe^TF`07
oe^TF`03o`000?mXUfSoJ9MX00KoJ9MX0_l0000;ofRGJ003o`000?mnPGkoOX5n00GoOX5n00?o0000
ogR7N?mhQgP02?mhQgP00ol0003oC[5>odjaCP02odjaCP03o`000?m?/4ooCk1?00OoCk1?00?o0000
oh9mP_n2OH801?l00006ogV6N@03o`000?o4>lCoa3_400Koa3_40ol00002oi]TV`03o`000?oK9=_o
fbCK00_ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nbCK;o/Tfb00Wo/Tfb00?o0000ohAk
Q?n4Nh@01?n4Nh@00ol0003o:=LXobSG:005obSG:003o`000?mKY5_oFjAK00OoFjAK00?o0000ofRG
J?mXUfP00_mXUfP3o`000003ogB;M?l0003oJ9MX00[oJ9MX00?o0000ogj1O_mnPGh01OmnPGh00ol0
003oN8MhogR7N007ogR7N003o`000?m>/DkoC[5>00?oC[5>00?o0000odn`Com?/4l01om?/4l00ol0
003oPWf2oh9mPP04oh9mPP?o00000_miQWT00ol0003oa3_4ol@ka00:ol@ka0;o00003_oK9=/00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok9=/_nbCK802OnbCK800ol0003oQ7^4ohAkQ004ohAkQ003
o`000?lXebSo:=LX00Ko:=LX0_l00007oe^TF`03o`000?mXUfSo000000;o00001OmdRg@00ol0003o
J9MXofRGJ008ofRGJ0?o00001?mnPGh00ol0003oN8MhogR7N008ogR7N003o`000?m>/DkoC[5>00Co
C[5>00?o0000odn`Com?/4l01_m?/4l00ol0003oPWf2oh9mPP07oh9mPP;o00003_o4>l@00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Tfbok9=/P08ok9=/P03o`00
0?n4NhCoQ7^400GoQ7^400?o0000obSG:?lXebP01?lXebP00ol0003oG:=LoebSG003o`0000CoFjAK
0_l00008ogB;M003o`000?mXUfSoJ9MX00OoJ9MX00Co0000oiIYU_nFJIKoUVVF0ol000000omnPGko
0000ogR7N009ogR7N003o`000?m>/DkoC[5>00CoC[5>00?o0000odn`Com?/4l01Om?/4l00ol0003o
PWf2oh9mPP09oh9mPP03o`000?o4>lCoa3_400goa3_400?o0000om/TfooK9=/02_oK9=/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok9=/_nbCK801onbCK800ol0003oQ7^4ohAkQ006ohAkQ003o`00
0?lXebSo:=LX00?o:=LX00?o0000oebSG?mLXe`01?mLXe`2o`000003oe^TFol0003oM8]d00[oM8]d
00?o0000ofRGJ?mXUfP01OmXUfP00ol0003oUVVFoiIYUP05oiIYUP03o`000?mhQgSoN8Mh00OoN8Mh
0ol00007odjaCP03o`000?m?/4ooCk1?00CoCk1?00?o0000oh9mP_n2OH802On2OH800ol0003oa3_4
ol@ka00=ol@ka003o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nb
CK;o/Tfb00Go/Tfb0ol00009ohAkQ005o`000?lXebSo:=LXobSG:?l000002OmLXe`00ol0003oM8]d
ogB;M00;ogB;M003o`000?mXUfSoJ9MX00?oJ9MX00?o0000oiIYU_nFJIH01_nFJIH00ol0003oN8Mh
ogR7N006ogR7N005o`000?mkQ7_oNhAkog^4Nol000001om>/Dh00ol0003oCk1?odn`C`03odn`C`03
o`000?n2OH;oPWf200WoPWf200?o0000ol@ka?o4>l@03_o4>l@00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o/Tfbo`000004o`0000;odBkA00?o0000ohAkQ?n4Nh@0
1on4Nh@01?l0003o:=LXobSG:?l00009oebSG0;o00003OmdRg@00ol0003oJ9MXofRGJ002ofRGJ003
o`000?nFJIKoUVVF00SoUVVF00?o0000ogR7N?mhQgP00omhQgP2o`0000GoNhAk00?o0000odjaC_m>
/Dh01?m>/Dh00ol0003oCk1?odn`C`03odn`C`03o`000?n2OH;oPWf200WoPWf200?o0000ol@ka?o4
>l@03_o4>l@00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SodBkA
00?o0000ohAkQ?n4Nh@01_n4Nh@00ol0003o:=LXo`000009oebSG004o`000?n4NhCoQ7^4o`0000go
M8]d00Co0000ofRGJ?mXUfSo00003?nFJIH01Ol0003oN8MhogR7N?mhQgSo000000SoNhAk0_l00005
odjaCP03o`000?m?/4ooCk1?00;oCk1?00?o0000oh9mP_n2OH802On2OH800ol0003oa3_4ol@ka00>
ol@ka003o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oA;]7odBkA
00OodBkA00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oG:=LoebSG007oebSG003o`000?n4NhCoQ7^4
00;oQ7^400?o0000ogB;M?mdRg@02_mdRg@00ol0003oJ9MXo`00000>oiIYUP03o`000?mhQgSo0000
00_oNhAk00?o0000odjaC_m>/Dh00_m>/Dh01Ol0003oCk1?odn`Com?/4oo000000coPWf200?o0000
ol@ka?o4>l@03_o4>l@3o`0000WofbCK00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oA;]7odBkA
00WodBkA00?o0000ohAkQ?n4Nh@01_n4Nh@00ol0003oG:=LoebSG006oebSG003o`000?n4NhCoQ7^4
00?oQ7^400?o0000ogB;M?mdRg@02omdRg@00ol0003oUVVFoiIYUP0>oiIYUP03o`000?mkQ7_oNhAk
00_oNhAk0_l00003odjaCP04o`000?m?/4ooCk1?o`0000[oPWf20ol0000>ol@ka0;o00000ooj1OX2
o`0000OofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oA;]7odBkA00[odBkA00?o0000ohAk
Q?n4Nh@01?n4Nh@00ol0003oG:=LoebSG006oebSG003o`000?n4NhCoQ7^400GoQ7^400?o0000ogB;
M?mdRg@01omdRg@3o`00017oUVVF00?o0000og^4NomkQ7/03OmkQ7/01Ol0003oC[5>odjaC_l0003o
Ck1?00Co00000on2OH85o`0000;o_T6n00?o0000ol@ka?o4>l@02_o4>l@2o`0000OonPGj0_l00004
om/Tf`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odBkAom4^d@0;om4^d@03o`000?n4NhCoQ7^4
00CoQ7^400?o0000oebSG?mLXe`01OmLXe`00ol0003oQ7^4ohAkQ006ohAkQ003o`000?mdRgCoM8]d
00CoM8]d0ol00002oh1oP003o`000?nFJIKoUVVF00ooUVVF0_l0000?og^4N`04o`000?m>/Dko0000
o`0000CoMhQg0ol00008oki1_P03o`000?o4>lCoa3_400Ooa3_40_l0000;ooX5nP;o00000_oK9=/0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om4^dOoA;]403?oA;]46o`0000OoG:=L00?o0000ohAk
Q?n4Nh@02?n4Nh@00ol0003oM8]dogB;M003o`0000KoP7n000?o0000oiIYU_nFJIH03OnFJIH01?l0
003oSW6>ohiaS_l0000?og^4N`03o`000?mgR7OoMhQg00GoMhQg00?o0000oki1__nn@Kh02?nn@Kh0
0ol0003oa3_4ol@ka005ol@ka003o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oA;]400ol0003oQgR7ohMhQ`04ohMh
Q`03o`000?mLXecoG:=L00?oG:=L00?o0000ohAkQ?n4Nh@02_n4Nh@2o`0000[oP7n000?o0000oiIY
U_nFJIH02onFJIH00ol0003oSW6>ohiaSP02ohiaSP03o`000?mkQ7_oNhAk00_oNhAk0_l00007ogN8
M`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ol@ka?o4>l@00_o4>l@2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om4^dOoA;]402ooA;]400ol0003oQgR7ohMhQ`06ohMhQ`05o`000?mLXecoG:=LoebS
G?l000003On4Nh@00ol0003oP7n0oh1oP00:oh1oP003o`000?nFJIKoUVVF00WoUVVF00?o0000ohia
S_n>LHh01?n>LHh00ol0003oNhAkog^4N`08og^4N`;o000000?oDZeBo`000?mgR7L01omgR7L00ol0
003o_T6noki1_P09oki1_P04o`000?o4>lCo0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oA;]7odBkA
00WodBkA00?o0000ohMhQon7N8L02?n7N8L00ol0003oG:=Lo`00000=ohAkQ003o`000?n0Oh3oP7n0
00_oP7n000?o0000oiIYU_nFJIH02?nFJIH00ol0003oSW6>ohiaSP06ohiaSP03o`000?mkQ7_oNhAk
00GoNhAk0_l00003oe:]DP03o`000?mgR7OoMhQg00KoMhQg00?o0000oki1__nn@Kh02_nn@Kh00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003odBkAom4^d@07om4^d@03o`000?n7N8OoQgR700[oQgR700?o0000ohAkQ?n4
Nh@03?n4Nh@00ol0003oP7n0oh1oP00<oh1oP003o`000?nFJIKoUVVF00KoUVVF00?o0000ohiaS_n>
LHh02?n>LHh00ol0003oNhAkog^4N`02og^4N`;o00001_mB[E800ol0003oMhQgogN8M`05ogN8M`03
o`000?nn@Kko_T6n00[o_T6n00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oA;]7odBkA00GodBkA
00?o0000ohMhQon7N8L03?n7N8L2o`0000coQ7^400?o0000oh1oP?n0Oh003On0Oh000ol0003oUVVF
oiIYUP04oiIYUP03o`000?n>LHkoSW6>00[oSW6>00Co0000og^4Nol0003o00002?mB[E800ol0003o
MhQgogN8M`06ogN8M`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oA;]400ol0003oQgR7ohMhQ`0=ohMhQ`03o`000?mjQG[o000000;o00002?n4Nh@00ol0003oP7n0
oh1oP00?oh1oP0Ko00003_n>LHh00ol0003oDZeBoe:]DP08oe:]DP03o`000?mgR7OoMhQg00KoMhQg
00?o0000oki1__nn@Kh02Onn@Kh00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000oll`coo?<<oocc3?
0_l0000?ohMhQ`03o`000?mjQG[oNXEj00?oNXEj0ol00005ohAkQ0;o00004?n0Oh001_l0003oKY5^
ofjAK_l0003oEjQGo`0000koSW6>00?o0000oe:]D_mB[E802OmB[E800ol0003oMhQgogN8M`05ogN8
M`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000oll`coo?<<l00oo?<<l00ol0003o
QgR7ohMhQ`0=ohMhQ`03o`000?mjQG[oNXEj00KoNXEj0ol000001?n4NhCo0000ogF:MOmeRWD3o`00
00coP7n000Go0000ofjAK_m^TFkoKY5^o`000002oeNXE`03o`000?n>LHkoSW6>00_oSW6>00?o0000
oe:]D_mB[E802OmB[E800ol0003oMhQgogN8M`06ogN8M`03o`000?nn@Kko_T6n00So_T6n0_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003occ3?oll`c`04oll`c`oo00003?mjQGX00ol0003oMHYeogF:M@04ogF:
M@?o00002?n0Oh000ol0003oKY5^ofjAKP02ofjAKP05o`000?mGZ5OoEjQGoeNXEol000003?n>LHh0
0ol0003oDZeBoe:]DP09oe:]DP03o`000?mgR7OoMhQg00GoMhQg3?l00002on4Nh@;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003occ3?oll`c`05oll`c`03o`000?maSW7oLHia00_oLHia00?o0000ogZ5
N_mjQGX02_mjQGX00ol0003oMHYeogF:M@07ogF:M@;o00001On0Oh000ol0003oKY5^ofjAKP03ofjA
KP03o`000?mGZ5OoEjQG00;oEjQG00?o0000ohiaS_n>LHh02On>LHh00ol0003oDZeBoe:]DP0:oe:]
DP03o`000?mgR7OoMhQg00?oMhQg00?o0000ohEjQOn5NXD02On5NXD00ol0003ohAkQon4Nh@02on4N
h@;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003occ3?oll`c`06oll`c`03o`000?maSW7oLHia00[o
LHia00?o0000ogZ5N_mjQGX02omjQGX00ol0003oMHYeogF:M@09ogF:M@?o000000?oP7n0o`000?m^
TFh01Om^TFh00ol0003oEjQGoeNXE`03oeNXE`03o`000?n>LHkoSW6>00SoSW6>3_l00003ogN8M`;o
00002on5NXD00ol0003ohAkQon4Nh@05on4Nh@03o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000oll`coo?<<l01Oo?<<l00ol0003oQGZ5o`00000;og6>L@03o`000?mjQG[oNXEj00[oNXEj
0_l0000>ogF:M@03o`000?m^TFkoKY5^00GoKY5^00?o0000oeNXEomGZ5L00omGZ5L00ol0003oSW6>
ohiaSP08ohiaSP03o`000?mnPGkoOX5n00_oOX5n00?o0000ogN8Mol000003On5NXD00ol0003ohAkQ
on4Nh@06on4Nh@;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o?<<oocc3?00Kocc3?00Co
0000ohEjQOn5NXGo00002_maSW400ol0003oNXEjogZ5NP09ogZ5NP03o`000?mbSG;o000000koMHYe
00?o0000ofjAK_m^TFh01Om^TFh00ol0003oEjQGoeNXE`04oeNXE`03o`000?n>LHkoSW6>00KoSW6>
00?o0000ogj1O_mnPGh03OmnPGh00ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?o?<<oocc3?00Gocc3?00?o0000ohEjQOn5NXD00_n5
NXD00ol0003oLHiaog6>L@06og6>L@03o`000?mjQG[oNXEj00SoNXEj0_l00003og:=LP03o`000?me
RWGoMHYe00_oMHYe00?o0000ofjAK_m^TFh01Om^TFh00ol0003oEjQGoeNXE`05oeNXE`03o`000?n>
LHkoSW6>00GoSW6>00?o0000ogj1O_mnPGh03OmnPGh00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?oQ
7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o?<<oocc3?00Kocc3?00?o0000
ohEjQOn5NXD00on5NXD00ol0003oLHiaog6>L@05og6>L@03o`000?mjQG[oNXEj00OoNXEj00?o0000
og:=L_mbSG800ombSG800ol0003oMHYeogF:M@0:ogF:M@03o`000?m^TFkoKY5^00KoKY5^00?o0000
oeNXEomGZ5L01_mGZ5L00ol0003oSW6>ohiaSP04ohiaSP03o`000?mnPGkoOX5n00goOX5n3ol0000;
on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?o?<<oocc3?00Kocc3?00?o0000ohEjQOn5NXD01On5NXD00ol0
003oLHiaog6>L@04og6>L@03o`000?mjQG[oNXEj00GoNXEj0_l00006og:=LP03o`000?meRWGoMHYe
00WoMHYe0_l00008ofjAKP03o`000?mGZ5OoEjQG00KoEjQG1Ol000000on>LHko0000ogj1OP0?ogj1
OP03o`000?moOgooOgmo00_oOgmo00?o0000on4NhOoQ7^402OoQ7^400ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?o?<<oocc3?00Kocc3?00?o0000ohEjQOn5NXD01_n5NXD00ol0003o
LHiaog6>L@04o`0000KoNXEj00?o0000og:=L_mbSG801ombSG800ol0003oMHYeogF:M@05ogF:M@?o
000000?oHIiQo`000?m^TFh01om^TFh00ol0003oEjQGoeNXE`05oeNXE`03o`000?n@Ki3oT6n@00?o
T6n@0_l0000?ogj1OP;o00003OmoOgl00ol0003ohAkQon4Nh@08on4Nh@03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000Wocc3?00?o0000ohEjQOn5NXD01on5NXD2o`0000CoWF:M00Co0000ogZ5N_mjQG[o
NXEj0_l0000:og:=LP03o`000?meRWGoMHYe00;oMHYe0ol00005of6NH@03o`000?m^TFkoKY5^00Go
KY5^00?o0000oeNXEomGZ5L01?mGZ5L00ol0003oT6n@oi1_T006oi1_T003o`000?mnPGkoOX5n00[o
OX5n0_l00002oh=lP`03o`000?moOgooOgmo00[oOgmo00?o0000on4NhOoQ7^402?oQ7^400ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000oll`coo?<<l01_o?<<l00ol0003oQGZ5ohEjQ@08ohEjQ@03o`00
0?nMHYgoWF:M00CoWF:M00?o0000ogZ5N_l000003?mbSG800ol0003oMHYeo`000002o`0000WoHIiQ
00?o0000ofjAK_m^TFh01?m^TFh00ol0003oEjQGoeNXE`03oeNXE`03o`000?n@Ki3oT6n@00SoT6n@
1_l00004ogj1OP;o00001On3O8<00ol0003oOgmoogmoO`09ogmoO`03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?o?<<oocc3?00Gocc3?00?o0000ohEjQOn5NXD01on5
NXD00ol0003oWF:MoieRW@06oieRW@03o`000?mbSG;oLXeb00coLXeb00?o0000of6NHOmQWV402_mQ
WV400ol0003oKY5^ofjAKP04ofjAKP04o`000?mGZ5OoEjQGoeNXE`;o00002on@Ki000ol0003oRgB;
oh]dR`03oh]dR`Co00002?n3O8<00ol0003oOgmoogmoO`08ogmoO`03o`000?oQ7^7ohAkQ00OohAkQ
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000oll`coo?<<l00oo?<<l00ol0003oQGZ5ohEjQ@07ohEjQ@03o`000?nM
HYgoWF:M00OoWF:M00?o0000og:=L_mbSG803?mbSG800ol0003oHIiQof6NH@0;of6NH@03o`000?m^
TFkoKY5^00?oKY5^00Co0000oeNXEomGZ5Oo00003On@Ki000ol0003oRgB;oh]dR`06oh]dR`03o`00
0?n3O8?oPgb300OoPgb300?o0000ogmoOomoOgl01omoOgl00ol0003ohAkQon4Nh@06on4Nh@04o`00
0?ok1?_on`Ckoo/4n`;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o?<<oocc3?00;occ3?00?o0000ohEjQOn5NXD0
1_n5NXD00ol0003oWF:MoieRW@09oieRW@03o`000?mbSG;oLXeb00WoLXeb0_l0000>of6NH@?o0000
0om^TFh00ol0003oEjQGo`00000=oi1_T003o`000?n;M8_oRgB;00OoRgB;00?o0000oh=lPon3O8<0
2?n3O8<:o`0000KohAkQ0_l00006oo/4n`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoQGZ500?o
0000oieRWOnMHYd02_nMHYd00ol0003oLXebog:=LP06og:=LP;o000000?oLXebo`000?mQWV402omQ
WV42o`0000?oT6n@1Ol0000>oi1_T003o`000?n;M8_oRgB;00OoRgB;00?o0000oh=lPon3O8<02?n3
O8<00ol0003oXEjQoj5NX@06oj5NX@03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000oo/4nook1?/01ook
1?/2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003oacS7olLha`03olLha`Co00000_n5NXD00ol0003oWF:MoieRW@0;
oieRW@03o`000?mbSG;oLXeb00?oLXeb0ol00004og:=LP03o`000?mQWV7oHIiQ00OoHIiQ0_l00008
oi1_T003o`000?n@Ki3oT6n@00goT6n@00?o0000oh]dRon;M8/02?n;M8/00ol0003oPgb3oh=lP`07
oh=lP`03o`000?nQGZ7oXEjQ00OoXEjQ0ol000000ooQ7^7o0000oo/4n`0;oo/4n`;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o7><OoacS700OoacS70_l0000?oieRW@03o`000?mbSG;oLXeb00;o00002?mbSG800ol0
003oHIiQof6NH@05of6NH@03o`000?n@Ki3oT6n@00SoT6n@00?o0000oi1_T?n@Ki003On@Ki000ol0
003oRgB;oh]dR`08oh]dR`03o`000?n3O8?oPgb300KoPgb300?o0000oj5NXOnQGZ402?nQGZ401?l0
003oh1oPon0Oh?l0000?oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oacS7olLha`09olLh
a`03o`000?nMHYgoWF:M00koWF:M0_l0000;og:=LP03o`000?mQWV7oHIiQ00;oHIiQ0_l0000;oi1_
T003o`000?n@Ki3oT6n@00goT6n@00?o0000oh]dRon;M8/02?n;M8/00ol0003oPgb3oh=lP`06oh=l
P`03o`000?nQGZ7oXEjQ00OoXEjQ00Go0000on0Oh?oP7n3oh1oPo`00000@oo/4n`;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003oacS7olLha`0:olLha`03o`000?nMHYgoWF:M00goWF:M0_l0000<og:=LP04o`000?mQWV7o0000
o`0000goT6n@00?o0000oi1_T?n@Ki003?n@Ki000ol0003oRgB;oh]dR`09oh]dR`03o`000?n3O8?o
Pgb300KoPgb300?o0000oj5NXOnQGZ401_nQGZ400ol0003oh1oPon0Oh003on0Oh003o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oacS7olLha`0:olLha`03o`000?nMHYgoWF:M00coWF:M00Co0000odJi
A_m6^DKo00003?mbSG800ol0003oT6n@oi1_T00>oi1_T003o`000?n@Ki3oT6n@00SoT6n@1?l0000;
oh]dR`03o`000?n3O8?oPgb300KoPgb300?o0000oj5NXOnQGZ401OnQGZ400ol0003oh1oPon0Oh004
on0Oh003o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oacS7olLha`0;olLha`03o`000?nMHYgoWF:M
00_oWF:M00?o0000odJiA_m6^DH00_m6^DH00ol0003oLXebog:=LP09og:=LP03o`000?n@Ki3oT6n@
00koT6n@00Co0000oi1_T?n@Ki3oT6n@1ol00003oi=/T`03o`000?n;M8_oRgB;00WoRgB;00?o0000
oh=lPon3O8<01_n3O8<00ol0003oXEjQoj5NX@04oj5NX@03o`000?oP7n3oh1oP00Koh1oP00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o7><OoacS700coacS700?o0000oieRWOnMHYd02_nMHYd00ol0
003oA[U6odJiAP03odJiAP03o`000?mbSG;oLXeb00SoLXeb00?o0000oi1_T?n@Ki003_n@Ki04o`00
00_oTfbC00?o0000oh]dRon;M8/02?n;M8/00ol0003oPgb3oh=lP`05oh=lP`03o`000?nQGZ7oXEjQ
00GoXEjQ00?o0000on0Oh?oP7n001_oP7n000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olLhaoo7
><L03?o7><L7o`0000GoWF:M00?o0000odJiA_m6^DH01Om6^DH00ol0003oLXebog:=LP07og:=LP03
o`000?n@Ki3oT6n@00koT6n@00?o0000oi=/TonCK9<03OnCK9<00ol0003oRgB;oh]dR`08oh]dR`03
o`000?n3O8?oPgb300CoPgb300?o0000oj5NXOnQGZ401?nQGZ400ol0003oh1oPon0Oh007on0Oh003
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003oacS7olLha`0=olLha`03o`000?nTFjCoY5^T00CoY5^T
1Ol00009odJiAP03o`000?mbSG;oLXeb00KoLXeb00?o0000oi1_T?n@Ki003_n@Ki000ol0003oTfbC
oi=/T`0=oi=/T`03o`000?n;M8_oRgB;00SoRgB;00Co0000oh=lPon3O8?oPgb31Ol00004oj5NX@03
o`000?oP7n3oh1oP00Woh1oP1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olLha`03o`000?nTFjCoY5^T00WoY5^T
0_l00009odJiAP03o`000?mbSG;oLXeb00KoLXeb00?o0000oi1_T?n@Ki003?n@Ki000ol0003oTfbC
oi=/T`0?oi=/T`Ko00001?n;M8/4o`0000Go^DJi0_l000000onQGZ7o0000on0Oh00;on0Oh004o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oI9]WofBKIomTVf@?o00002_o7><L00ol0003o
Y5^TojAKY009ojAKY003o`000?mHYeSo000000;o00001om6^DH00ol0003oLXebog:=LP05og:=LP03
o`000?n@Ki3oT6n@00SoT6n@1Ol0000Aoi=/T`03o`000?n@Ki3oT6n@00?oT6n@1?l0000;okU6^@03
o`000?oP7n3oh1oP00[oh1oP00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omTVfOoI9]T01OoI9]T2o`0000OoacS7
00?o0000ojAKY?nTFj@02_nTFj@00ol0003oF:MHoeRWF002oeRWF0?o00001Om6^DH00ol0003oLXeb
og:=LP04og:=LP04o`000?n@Ki3oT6n@oi1_T0Oo00001?mjQGX00ol0003oTfbCoi=/T`0>oi=/T`03
o`000?n@Ki3oT6n@00OoT6n@00?o0000okU6^OniA[T02OniA[T00ol0003oh1oPon0Oh009on0Oh003
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003ofBKIomTVf@08omTVf@;o00001?o7><L00ol0003oY5^T
ojAKY00;ojAKY003o`000?mHYeSoF:MH00GoF:MH0ol00003odJiAP04o`000?mbSG;oLXebog:=LPKo
00003?mjQGX00ol0003oTfbCoi=/T`0=oi=/T`03o`000?n@Ki3oT6n@00OoT6n@00?o0000okU6^Oni
A[T02_niA[T00ol0003oh1oPon0Oh008on0Oh003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omTVf@?o000000?oacS7o`000?nTFj@0
3?nTFj@00ol0003oF:MHoeRWF008oeRWF0?o000000CoA[U6o`000?l0003o00000_nGJ9L00ol0003o
NXEjogZ5NP0=ogZ5NP03o`000?nCK9?oTfbC00coTfbC00?o0000oi1_T?n@Ki002?n@Ki000ol0003o
^DJiokU6^@0;okU6^@03o`000?oP7n3oh1oP00Koh1oP00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
fBKI00?o0000ojAKY?nTFj@03?nTFj@00ol0003oF:MHoeRWF00;oeRWF003o`000?nGJ9OoUfRG00?o
UfRG00?o0000ogZ5N_mjQGX03?mjQGX00ol0003oH9mPo`00000=oi=/T`03o`000?n@Ki3oT6n@00So
T6n@00?o0000okU6^OniA[T03?niA[T3o`0000Goh1oP00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oI9]WofBKI00cofBKI00?o0000ojAKY?nTFj@03?nTFj@00ol0003oF:MHoeRWF00:oeRWF003o`00
0?nGJ9OoUfRG00GoUfRG00?o0000ogZ5N_mjQGX02_mjQGX01?l0003oH9mPof2OH?mPWf02o`0000[o
TfbC00?o0000oi1_T?n@Ki002On@Ki000ol0003o^DJiokU6^@0<okU6^@03o`000?oV6NKoiQWV00?o
000000?oh1oPo`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oI9]WofBKI00_ofBKI00?o0000ojAKY?nTFj@0
3?nTFj@00ol0003oF:MHoeRWF009oeRWF003o`000?nGJ9OoUfRG00KoUfRG00?o0000ogZ5N_mjQGX0
2OmjQGX00ol0003oH9mPof2OH002of2OH003o`000?nCK9?o000000;o00001onCK9<00ol0003oT6n@
oi1_T009oi1_T003o`000?niA[Wo^DJi00_o^DJi00?o0000onHIi_oV6NH01?oV6NH00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omTVfOoI9]T02ooI9]T00ol0003oY5^TojAKY00;ojAKY003o`000?mH
YeSoF:MH00SoF:MH00?o0000oiMXUonGJ9L01onGJ9L00ol0003oNXEjogZ5NP08ogZ5NP03o`000?mP
Wf3oH9mP00?oH9mP00?o0000oi=/TonCK9<00_nCK9<2o`0000CoTfbC00?o0000oi1_T?n@Ki002_n@
Ki000ol0003o^DJiokU6^@0:okU6^@03o`000?oV6NKoiQWV00GoiQWV00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oI9]WofBKI00[ofBKI0ol0000;ojAKY0Ko00001?mHYeP00ol0003oUfRGoiMXU`08
oiMXU`03o`000?mjQG[oNXEj00OoNXEj00?o0000of2OH?mPWf000omPWf000ol0003oTfbCoi=/T`05
oi=/T`?o000000?oTfbCo`000?n@Ki002on@Ki000ol0003o^DJiokU6^@09okU6^@03o`000?oV6NKo
iQWV00OoiQWV00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oI9]WofBKI00WofBKI00?o0000oj9M
X_nRGJ801?l00006ojAKY003o`000?nIIYWoVFJI00CoVFJI1?l0000<oiMXU`03o`000?mjQG[oNXEj
00GoNXEj00?o0000of2OH?mPWf001?mPWf000ol0003oTfbCoi=/T`08oi=/T`03o`000?n@Ki3oT6n@
00_oT6n@00?o0000okU6^OniA[T02?niA[T00ol0003oiQWVonHIiP08onHIiPGo00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oI9]WofBKI00OofBKI00?o0000oj9MX_nRGJ801OnRGJ83o`0000;oY5^T00?o0000oiUVVOnI
IYT02?nIIYT00ol0003oUfRGoiMXU`0:oiMXU`03o`000?mjQG[oNXEj00CoNXEj00?o0000of2OH?mP
Wf001OmPWf000ol0003oTfbCoi=/T`08oi=/T`03o`000?n@Ki3oT6n@00WoT6n@1?l00008okU6^@03
o`000?oV6NKoiQWV00WoiQWV00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ofBKI
omTVf@05omTVf@03o`000?nRGJ;oXUfR00WoXUfR0_l0000<oiUVV@03o`000?nGJ9OoUfRG00WoUfRG
00?o0000ogZ5N_mjQGX00omjQGX00ol0003oH9mPof2OH005of2OH003o`000?nCK9?oTfbC00[oTfbC
00?o0000oi1_T?n@Ki001?n@Ki04o`0000Co[5>/00?o0000okU6^OniA[T01?niA[T00ol0003oiQWV
onHIiP0:onHIiP03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oI9]WofBKI00?ofBKI00?o0000oj9MX_nRGJ802onR
GJ800ol0003oVFJIoiUVV@0:oiUVV@03o`000?nGJ9OoUfRG00WoUfRG00?o0000ogZ5N_mjQGX00_mj
QGX00ol0003oH9mPof2OH006of2OH003o`000?nCK9?oTfbC00[oTfbC00?o0000oi1_T?n@Ki001?l0
0009ojaC[0Ko00003?oV6NH00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omTVfOoI9]WofBKI0_l0
000=oj9MXP03o`000?nIIYWoVFJI00[oVFJI00?o0000oiMXUonGJ9L02OnGJ9L01Ol0003oNXEjogZ5
N_mjQG[o000000WoH9mP00?o0000oi=/TonCK9<02onCK9<2o`0000go[5>/00?o0000omhQg_oN8Mh0
0_oN8Mh00ol0003oiQWVonHIiP0:onHIiP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ofBKIo`00
0002om`Sg0;o00002onRGJ800ol0003oVFJIoiUVV@0;oiUVV@03o`000?nGJ9OoUfRG00WoUfRG00?o
0000ogZ5N_l000002OmPWf000ol0003oTfbCoi=/T`0<oi=/T`03o`000?n/Djco[5>/00co[5>/00?o
0000omhQg_oN8Mh00ooN8Mh00ol0003oiQWVonHIiP09onHIiP03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003og2?Lom`Sg003om`Sg0;o00002_nRGJ800ol0003oVFJIoiUVV@0:oiUVV@03o`000?nGJ9Oo
UfRG00SoUfRG1Ol00008of2OH003o`000?nCK9?oTfbC00coTfbC00?o0000ojaC[?n/Dj`02on/Dj`0
0ol0003ogR7NomhQgP05omhQgP03o`000?oV6NKoiQWV00SoiQWV00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooL8m`2o`0000SoXUfR00?o0000oiUVVOnIIYT02_nIIYT00ol0003oUfRGoiMXU`07oiMX
U`03o`000?n5NXGoQGZ500?oQGZ50ol00005of2OH003o`000?nCK9?oTfbC00_oTfbC00?o0000ojaC
[?n/Dj`03?n/Dj`00ol0003ogR7NomhQgP06omhQgP03o`000?oV6NKoiQWV00OoiQWV00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000Wog2?L00?o0000oj9MX_nRGJ801OnRGJ82o`0000co
VFJI00?o0000oiMXUonGJ9L01OnGJ9L00ol0003oQGZ5ohEjQ@07ohEjQ@?o000000?oH9mPo`000?nC
K9<03OnCK9<00ol0003o[5>/ojaC[00<ojaC[003o`000?oN8MkogR7N00KogR7N00?o0000onHIi_oV
6NH01_oV6NH00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?oL8mcog2?L00Oog2?L
0_l00004oj9MXP03o`000?n]DZgo[E:]00;o00002_nIIYT00ol0003oUfRGoiMXU`03oiMXU`;o0000
3On5NXD2o`0000goTfbC0ol0000=ojaC[003o`000?oN8MkogR7N00OogR7N00?o0000onHIi_oV6NH0
1OoV6NH00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?oL8mcog2?L00Sog2?L0_l0
00000onRGJ;o0000ojeB[@04ojeB[@03o`000?nIIYWoVFJI00OoVFJI00Co0000oiMXUonGJ9OoUfRG
0_l00002ohm`S`03o`000?n5NXGoQGZ500coQGZ53Ol00003ohUfR@03o`000?n/Djco[5>/00[o[5>/
00?o0000omhQg_oN8Mh02?oN8Mh01?l0003oiQWVonHIi_oV6NH4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003og2?L
om`Sg009om`Sg003o`000?n]DZgo[E:]00Go[E:]0_l00008oiUVV@03o`000?nGJ9Oo000000GoSg2?
00?o0000ohEjQOn5NXD02on5NXD00ol0003oQ7^4ohAkQ009ohAkQ003o`000?n9MXWoRGJ900;oRGJ9
0_l00009ojaC[003o`000?oN8MkogR7N00[ogR7N0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?oL8mcog2?L00Sog2?L00?o0000ojeB[On]DZd01on]DZd4o`0000?oVFJI0ol0
0007ohm`S`03o`000?n5NXGoQGZ500[oQGZ500?o0000ohAkQ?n4Nh@02On4Nh@00ol0003oRGJ9ohUf
R@04ohUfR@;o00001on/Dj`00ol0003ogR7NomhQgP0:omhQgP03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oL8mcog2?L00Oog2?L00?o0000ojeB[On]DZd02?n]DZd0
1?l0003o[e2_ojm@[on_D:l3o`0000;oWf2O00?o0000ohm`Son?L8l01_n?L8l00ol0003oQGZ5ohEj
Q@08ohEjQ@03o`000?n4NhCoQ7^400[oQ7^400?o0000ohUfROn9MXT01_n9MXT00ol0003o[5>/ojaC
[004ojaC[003o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000om`Sg?oL8m`01OoL8m`00ol0003o[E:]ojeB[@08ojeB[@03o`000?n_D:oo
[e2_00Co[e2_00Go0000oimPWonOH9ooWf2Oo`000008ohm`S`03o`000?n5NXGoQGZ500OoQGZ500?o
0000ohAkQ?n4Nh@02_n4Nh@00ol0003oRGJ9ohUfR@07ohUfR@;o00001?n/Dj`00ol0003ogR7NomhQ
gP08omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om`Sg?oL8m`00ooL8m`0
0ol0003o[E:]ojeB[@08ojeB[@03o`000?n_D:oo[e2_00Co[e2_00?o0000oimPWonOH9l00_nOH9l0
0ol0003oSg2?ohm`S`07ohm`S`03o`000?n5NXGoQGZ500KoQGZ500?o0000ohAkQ?n4Nh@02_n4Nh@0
0ol0003oRGJ9ohUfR@09ohUfR@05o`000?n/Djco[5>/ojaC[?l000002OoN8Mh00ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_o[E:]00?o0000ojm@[on_D:l01?n_D:l00ol0003oWf2OoimPW`03
oimPW`03o`000?n?L8ooSg2?00OoSg2?00?o0000ohEjQOn5NXD01On5NXD00ol0003oQ7^4ohAkQ00:
ohAkQ003o`000?n9MXWoRGJ900WoRGJ91?l00009omhQgP03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oV6NKoiQWV
onHIi_l000002_n]DZd00ol0003o[e2_ojm@[`05ojm@[`03o`000?nOH9ooWf2O00?oWf2O00?o0000
ohm`Son?L8l02?n?L8l00ol0003oQGZ5ohEjQ@04ohEjQ@03o`000?n4NhCoQ7^400WoQ7^400?o0000
ohUfROn9MXT02?n9MXT2o`0000?og2?L00?o0000omhQg_oN8Mh01_oN8Mh00ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000onHIi_oV6NH00ooV6NH00ol0003o[E:]ojeB[@06ojeB[@03o`000?n_D:oo[e2_
00Go[e2_00?o0000oimPWonOH9l01?nOH9l00ol0003oSg2?ohm`S`09ohm`S`03o`000?n5NXGoQGZ5
00;oQGZ500?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003oRGJ9ohUfR@06ohUfR@;o00001_oL8m`8o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003oiQWVonHIiP05onHIiP03o`000?n]DZgo[E:]00Go[E:]00?o0000ojm@[on_
D:l01On_D:l00ol0003oWf2OoimPW`05oimPW`03o`000?n?L8ooSg2?00WoSg2?00Go0000ohEjQOn5
NXGoQGZ5o`00000<ohAkQ003o`000?n9MXWoRGJ900CoRGJ90_l00008om`Sg003o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV6NKoiQWV00OoiQWV00?o0000ojeB[On]
DZd00on]DZd00ol0003o[e2_ojm@[`06ojm@[`03o`000?nOH9ooWf2O00GoWf2O00?o0000ohm`Son?
L8l02_n?L8l00ol0003oQGZ5o`000004o`0000WoQ7^400?o0000ohUfROn9MXT00_n9MXT2o`0000[o
g2?L00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003oiQWVonHIiP07onHIiP03o`00
0?n]DZgo[E:]00;o[E:]00?o0000ojm@[on_D:l01_n_D:l00ol0003oWf2OoimPW`07oimPW`;o0000
2on?L8l00ol0003o[5>/ojaC[003ojaC[0Oo00000_n4Nh@00ol0003oRGJ9ohUfR@02o`0000_og2?L
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000onHIi_oV6NH02OoV
6NH01Ol0003o[E:]ojeB[On]DZgo000000So[e2_00?o0000oimPWonOH9l01onOH9l00ol0003ocS7>
o`000002o`0000SoSg2?00?o0000ojaC[?n/Dj`02_n/Dj`5o`0000gog2?L00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<onHIiP03o`000?n]DZgo000000Wo[e2_00?o
0000oimPWonOH9l01_nOH9l00ol0003ocS7>olhacP03olhacP?o00001?n?L8l00ol0003o[5>/ojaC
[00=ojaC[003o`000?oL8mcog2?L00gog2?L00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ook1?/2o`0000_oiQWV00?o0000ojm@[on_D:l01on_D:l00ol0003oWf2OoimPW`07
oimPW`03o`000?o><LkocS7>00KocS7>0ol000000on?L8oo0000ojaC[00>ojaC[003o`000?oL8mco
g2?L00cog2?L00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00Kon`Ck0_l00009onHI
iP03o`000?n_D:oo[e2_00;o[e2_1_l00008oimPW`03o`000?o><LkocS7>00[ocS7>00?o0000ojaC
[?n/Dj`03on/Dj`00ol0003og2?Lom`Sg00:om`Sg0;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00So
n`Ck0_l00007onHIiPGo00001_oT6n@00ol0003oWf2OoimPW`05oimPW`03o`000?o><LkocS7>00[o
cS7>00?o0000ojaC[?n/Dj`03on/Dj`00ol0003og2?Lom`Sg007om`Sg0?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ok1?_on`Ck00[on`Ck0_l00005onHIiP03o`000?oT6nCoi1_T00Woi1_T00?o0000oimPWonO
H9l00onOH9l00ol0003ocS7>olhacP0;olhacP03o`000?n/Djco[5>/00oo[5>/00?o0000om`Sg?oL
8m`01OoL8m`2o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`;o000000?oiQWVo`000?l00000
3OoT6n@00ol0003oWf2OoimPW`02oimPW`03o`000?o><LkocS7>00_ocS7>5?l00004om`Sg0;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo/4nook1?/03_ok1?/00ol0003on`Cko`00000>on@Ki004o`000?nOH9ooWf2Oo`0000kocS7>
00?o0000onPGj?oX5nP04?oX5nP00ol0003og2?Lo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003on`Ckoo/4
n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000003_oT6n@00ol0003oWf2Oo`00000>olhacP03o`00
0?oX5nSoj1OX017oj1OX00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00_ok1?/00ol0003oi1_Ton@Ki00=on@Ki003o`000?o><LkocS7>00WocS7>1Ol0
000BonPGj0;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4nook1?/01?ok1?/0
0ol0003oi1_Ton@Ki00<on@Ki003o`000?o><LkocS7>00;ocS7>1ol00004oo/4n`03o`000?oX5nSo
j1OX00ooj1OX00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo/4nook1?/02?ok1?/00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oT6nCoi1_T00coi1_T1?l0000<oo/4n`03o`000?oX5nSoj1OX00coj1OX0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on@Ki?oT6n@03?oT6n@00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oX5nSoj1OX00_o
j1OX00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/02Ook1?/00ol0003oi1_Ton@Ki00:on@Ki003o`000?ok1?_on`Ck00kon`Ck00?o0000onPGj?oX
5nP02OoX5nP2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000on@Ki?oT6n@02_oT6n@00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?oX5nSoj1OX00Koj1OX0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo/4nol0003on`Ck00gon`Ck3?l0
000Aoo/4n`?o00001_oX5nP00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000ooX5nP2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onPGj?l000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01_l00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00[o003o0_ooo`08o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0_ooo`0:o`00o`;oool01ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00[o003o0_ooo`0:o`00o`;oool01ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`002_l00?l2oooo00[o
003o0_ooo`07o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00[o003o0_ooo`0:o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2_l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool0
2_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00[o003o0_oo
o`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003o
oooo0?l00?l00_ooo`0:o`00o`;oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2
oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00
o`;oool02_l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o
003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006So003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`0:o`00o`;oool0
2_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_oo
o`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l01ol0
0?l2oooo00[o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol0
0?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05
o`00o`Coool02?l00?l4oooo00So003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool0
06Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Ro`00o`;oool02_l00?l2oooo
00Wo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(120) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.983 .017 .983 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.983 .017 .983 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.983 .017 .983 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.982 .018 .982 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.88 .12 .88 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.981 .019 .981 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.874 .126 .874 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.902 .098 .902 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.855 .145 .855 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.979 .021 .979 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.794 .206 .794 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.983 .017 .983 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.726 .274 .726 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.7 .3 .7 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.98 .02 .98 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.985 .015 .985 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.652 .348 .652 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.753 .247 .753 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.978 .022 .978 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.98 .02 .98 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.861 .139 .861 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.53 .47 .53 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.56 .44 .56 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.494 .506 .494 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.486 .514 .486 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.558 .442 .558 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.823 .177 .823 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.854 .146 .854 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.984 .016 .984 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.517 .483 .517 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.739 .261 .739 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.433 .567 .433 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.818 .182 .818 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.782 .218 .782 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.983 .017 .983 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.695 .305 .695 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.706 .294 .706 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.675 .325 .675 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.823 .177 .823 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.522 .478 .522 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.985 .015 .985 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.88 .12 .88 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.574 .426 .574 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.522 .478 .522 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.487 .513 .487 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.871 .129 .871 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.905 .095 .905 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.643 .357 .643 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.983 .017 .983 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.526 .474 .526 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.438 .562 .438 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.621 .379 .621 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.647 .353 .647 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.406 .594 .406 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.509 .491 .509 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.633 .367 .633 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.983 .017 .983 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.661 .339 .661 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.597 .403 .597 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.872 .128 .872 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.144 .856 .144 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.691 .309 .691 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.697 .303 .697 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.621 .379 .621 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.331 .669 .331 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.32 .68 .32 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.222 .778 .222 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.283 .717 .283 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.565 .435 .565 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.334 .666 .334 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.449 .551 .449 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.696 .304 .696 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.518 .482 .518 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.546 .454 .546 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.59 .41 .59 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.897 .103 .897 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.982 .018 .982 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.325 .675 .325 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.414 .586 .414 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.322 .678 .322 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.982 .018 .982 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.658 .342 .658 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.487 .513 .487 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.252 .748 .252 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.313 .687 .313 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.562 .438 .562 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.413 .587 .413 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.87 .13 .87 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.51 .49 .51 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.233 .767 .233 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.627 .373 .627 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.433 .567 .433 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.374 .626 .374 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.569 .431 .569 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.828 .172 .828 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.563 .437 .563 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.246 .754 .246 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.371 .629 .371 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.569 .431 .569 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.419 .581 .419 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.425 .575 .425 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.813 .187 .813 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.4 .6 .4 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.341 .659 .341 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.293 .707 .293 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.981 .019 .981 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.304 .696 .304 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.469 .531 .469 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.343 .657 .343 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.553 .447 .553 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.532 .468 .532 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.981 .019 .981 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.569 .431 .569 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.486 .514 .486 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.51 .49 .51 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.555 .445 .555 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.422 .578 .422 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.373 .627 .373 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.447 .553 .447 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.497 .503 .497 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.982 .018 .982 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.725 .275 .725 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.52 .48 .52 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.628 .372 .628 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.343 .657 .343 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.861 .139 .861 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.205 .795 .205 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.395 .605 .395 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.389 .611 .389 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.557 .443 .557 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.68 .32 .68 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.302 .698 .302 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.982 .018 .982 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.46 .54 .46 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.68 .32 .68 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.91 .09 .91 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.556 .444 .556 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.498 .502 .498 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.505 .495 .505 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.831 .169 .831 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.313 .687 .313 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.444 .556 .444 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.533 .467 .533 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.741 .259 .741 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.305 .695 .305 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.437 .563 .437 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.524 .476 .524 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.546 .454 .546 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.982 .018 .982 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.367 .633 .367 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.982 .018 .982 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.872 .128 .872 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.597 .403 .597 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.542 .458 .542 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.413 .587 .413 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.54 .46 .54 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.451 .549 .451 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.867 .133 .867 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.582 .418 .582 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.609 .391 .609 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.611 .389 .611 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.543 .457 .543 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.779 .221 .779 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.521 .479 .521 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.414 .586 .414 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.271 .729 .271 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.29 .71 .29 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.471 .529 .471 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.674 .326 .674 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.982 .018 .982 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.871 .129 .871 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.468 .532 .468 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.281 .719 .281 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.561 .439 .561 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.742 .258 .742 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.504 .496 .504 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.982 .018 .982 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.446 .554 .446 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.727 .273 .727 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.874 .126 .874 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.982 .018 .982 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.429 .571 .429 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.484 .516 .484 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.868 .132 .868 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.519 .481 .519 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.494 .506 .494 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.776 .224 .776 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.449 .551 .449 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.649 .351 .649 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.752 .248 .752 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.533 .467 .533 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.513 .487 .513 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.644 .356 .644 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.503 .497 .503 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.903 .097 .903 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.686 .314 .686 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.618 .382 .618 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.577 .423 .577 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.982 .018 .982 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.754 .246 .754 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.482 .518 .482 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.982 .018 .982 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.881 .119 .881 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.767 .233 .767 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.883 .117 .883 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.513 .487 .513 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.867 .133 .867 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.686 .314 .686 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.592 .408 .592 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.983 .017 .983 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.6 .4 .6 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.569 .431 .569 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.983 .017 .983 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.779 .221 .779 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.979 .021 .979 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.984 .016 .984 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.706 .294 .706 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.981 .019 .981 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.556 .444 .556 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.982 .018 .982 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.465 .535 .465 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.715 .285 .715 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.547 .453 .547 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.859 .141 .859 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.867 .133 .867 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.685 .315 .685 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.694 .306 .694 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.685 .315 .685 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.799 .201 .799 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.855 .145 .855 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.769 .231 .769 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.777 .223 .777 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.98 .02 .98 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.641 .359 .641 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.862 .138 .862 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.981 .019 .981 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.899 .101 .899 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.894 .106 .894 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.639 .361 .639 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.884 .116 .884 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.874 .126 .874 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.626 .374 .626 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.981 .019 .981 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.979 .021 .979 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.984 .016 .984 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.865 .135 .865 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.982 .018 .982 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.982 .018 .982 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.981 .019 .981 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.982 .018 .982 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.981 .019 .981 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.982 .018 .982 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003ogR7NomhQg_l0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000omhQg_oN8Mh00_oN8Mh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oN8MkogR7N00?ogR7N00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omhQg_oN8Mh01OoN8Mh00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ogR7NomhQgP06omhQgP03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000omhQg_oN8Mh02?oN8Mh00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oN8Mko0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000cogR7N00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003omhQgP03o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ogb3OomlPg`05omlPg`03o`000?oN
8MkogR7N00_ogR7N0ol00003omhQgP03o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
omhQg_oN8Mh00ooN8Mh00ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003ogb3OomlPg`06
omlPg`03o`000?oN8MkogR7N00[ogR7N00?o0000omhQg_oN8Mh01?oN8Mh00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oM8]gogB;MomdRg@;o00002_ok1?/2o`000003omdRgOl0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ogR7NomhQgP05omhQgP03o`000?ok1?_o
n`Ck00Won`Ck00?o0000om`Sg?l000002ook1?/00ol0003ogb3OomlPg`06omlPg`03o`000?oN8Mko
gR7N00WogR7N00?o0000omhQg_oN8Mh01_oN8Mh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oM8]go
gB;M00CogB;M0_l00005oo/4n`?o00001?oM8]d00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008omhQgP03o`000?ok1?_on`Ck00Oon`Ck0_l00003om`S
g003o`000?ok1?_on`Ck00Oon`Ck00?o0000omlPgooO8=l01ooO8=l00ol0003ogR7NomhQgP09omhQ
gP03o`000?oN8MkogR7N00OogR7N00?o0000oo/4nook1?/01Ook1?/2o`0000WogB;M0_l000000ook
1?_o0000o`000007omdRg@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000omhQg_oN
8Mh02?oN8Mh00ol0003on`Ckoo/4n`06oo/4n`03o`000?oL8mcog2?L00?og2?L00?o0000oo/4nook
1?/01ook1?/00ol0003ogb3OomlPg`08omlPg`03o`000?oN8MkogR7N00OogR7N00?o0000omhQg_oN
8Mh02OoN8Mh00ol0003on`Ckoo/4n`03oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000omdRgOoM
8]d01ooM8]d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003ogb3Oo`000005oo/4n`;o00002ooN8Mh2o`0000Kon`Ck
00?o0000om`Sg?oL8m`01OoL8m`00ol0003on`Ckoo/4n`06oo/4n`03o`000?oO8=oogb3O00Sogb3O
00?o0000omhQg_oN8Mh01_oN8Mh00ol0003ogR7NomhQgP0;omhQgP05o`000?ok1?_on`Ckoo/4nol0
00003_oM8]d00ol0003ogB;MomdRg@08omdRg@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oO8=oogb3OomlPgol0
00000ook1?/00ol0003ogR7NomhQgP0:omhQgP04o`000?oC;=?odbcCo`0000?on`Ck0_l00008om`S
g003o`000?ok1?_on`Ck00Kon`Ck00?o0000omlPgooO8=l02OoO8=l00ol0003ogR7NomhQgP05omhQ
gP03o`000?oN8MkogR7N00cogR7N00?o0000oo/4nol000003ooM8]d00ol0003ogB;MomdRg@08omdR
g@03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003ogb3OomlPg`03omlPg`03o`000?ok1?_o000000_o
gR7N0_l00004om</d`03o`000?ok1?_o000000_og2?L00?o0000oo/4nook1?/01Ook1?/00ol0003o
gb3OomlPg`09omlPg`03o`000?oN8MkogR7N00CogR7N00?o0000omhQg_oN8Mh03_oN8Mh00ol0003o
gB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000omlPgooO8=l0
1?oO8=l00ol0003ogR7NomhQgP09omhQgP03o`000?oC;=?odbcC00GodbcC00?o0000om`Sg?oL8m`0
2_oL8m`00ol0003on`Ckoo/4n`05oo/4n`03o`000?oO8=oogb3O00[ogb3O00?o0000omhQg_oN8Mh0
0ooN8Mh00ol0003ogR7NomhQgP0>omhQgP03o`000?oM8]gogB;M00gogB;M00?o0000omdRgOoM8]d0
2_oM8]d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ogb3OomlP
g`05omlPg`03o`000?oN8MkogR7N00OogR7N0_l00008om</d`03o`000?oL8mcog2?L00_og2?L00?o
0000oo/4nook1?/01?ok1?/00ol0003ogb3OomlPg`0:omlPg`04o`000?oN8MkogR7NomhQgP?o0000
3ooN8Mh00ol0003ogB;MomdRg@0>omdRg@03o`000?oM8]gogB;M00[ogB;M00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oO8=oogb3O00Oogb3O00?o0000omhQg_oN8Mh01?oN8Mh2o`0000_odbcC1?l0
0009om`Sg003o`000?ok1?_on`Ck00?on`Ck00?o0000omlPgooO8=l02ooO8=l01?l0003ogR7No`00
0?l00003oke2_@;o00003?oN8Mh2o`00013ogB;M00?o0000omdRgOoM8]d02ooM8]d00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003ogb3O
omlPg`07omlPg`03o`000?oN8MkogR7N00?ogR7N00?o0000om</dooC;=<02ooC;=<01?l0003o^DJi
okU6^OniA[T5o`0000Gog2?L00?o0000oo/4nook1?/00_ok1?/00ol0003ogb3OomlPg`0<omlPg`03
o`000?nm@[go_D:m00Go_D:m0_l00008omhQgP;o00000_n_D:l00ol0003ogB;MomdRg@0=omdRg@03
o`000?oM8]gogB;M00_ogB;M00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003ogb3OomlPg`09omlPg`03o`000?oN8MkogR7N00;o0000
3OoC;=<00ol0003o^DJiokU6^@07okU6^@Ko00000_ok1?/4o`0000gogb3O00?o0000oke2_Onm@[d0
1onm@[d2o`0000GogR7N00?o0000ojm@[on_D:l00on_D:l00ol0003ogB;MomdRg@0<omdRg@03o`00
0?oM8]gogB;M00cogB;M00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oO8=oogb3O00Wogb3O00?o
0000omhQg_l000003ooC;=<00ol0003o^DJiokU6^@0<okU6^@?o00001?oD:m@3o`0000Wogb3O00?o
0000oke2_Onm@[d02_nm@[d2o`000003omhQg_l0003o000000Oo[e2_00?o0000omdRgOoM8]d02ooM
8]d00ol0003ogB;MomdRg@0<omdRg@03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oO8=oogb3O00_ogb3O00?o0000
om</dooC;=<03_oC;=<00ol0003o^DJiokU6^@0=okU6^@03o`000?oD:mCoe2_D00Koe2_D0ol00005
omlPg`03o`000?nm@[go_D:m00go_D:m00?o0000ojm@[on_D:l02?n_D:l00ol0003ogB;MomdRg@09
omdRg@03o`000?oM8]gogB;M00gogB;M00Co0000oo/4nook1?_on`Ck1Ol00003on@Ki003o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
omlPgooO8=l02ooO8=l2o`0000oodbcC00?o0000okU6^OniA[T03OniA[T00ol0003oe2_Dom@[e00:
om@[e0?o000000?ogb3Oo`000?nm@[d03onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?oM8]go
gB;M00SogB;M00?o0000omdRgOoM8]d03_oM8]d3o`0000Soi1_T00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oO8=oogb3O00Sogb3O0ol000000onb
CK;o0000om</d`0>om</d`03o`000?niA[Wo^DJi00go^DJi00?o0000om@[e?oD:m@03OoD:m@00ol0
003o_D:moke2_@0?oke2_@03o`000?n_D:oo[e2_00[o[e2_2ol0000;omdRg@Go00003?oT6n@00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/02_ok1?/01Ol0003ohAkQo`000?ok1?_o0000
00Sogb3O0ol00005ok9=/P03o`000?oC;=?odbcC00codbcC00?o0000okU6^OniA[T03OniA[T00ol0
003oe2_Dom@[e00=om@[e0;o00004?nm@[d00ol0003o[e2_ojm@[`0:ojm@[`03o`000?n_D:oo[e2_
00Oo[e2_00?o0000omdRgOoM8]d00_oM8]d7o`0000Co[e2_00?o0000on@Ki?oT6n@02_oT6n@00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/02Ook1?/01?l0003ohAkQon4NhOoQ7^42o`00
00Gogb3O0ol00009ok9=/P;o00002ooC;=<00ol0003o^DJiokU6^@0=okU6^@03o`000?oD:mCoe2_D
00goe2_D00Co0000olLhaoo7><Oo00003onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n_D:oo
[e2_00Wo[e2_1?l0000;ojm@[`03o`000?oT6nCoi1_T00[oi1_T00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ok1?_on`Ck00Son`Ck00?o0000on4NhOoQ7^401?oQ7^400ol0003ogb3Oo`000002o`00
00co/Tfb00Co0000ojQGZ?l0003o00002OoC;=<00ol0003o^DJiokU6^@0=okU6^@03o`000?oD:mCo
e2_D00goe2_D00Go0000olLhaoo7><OoacS7o`00000=oke2_@03o`000?n_D:oo[e2_00[o[e2_00?o
0000ojm@[on_D:l02On_D:l00ol0003o[e2_ojm@[`0<ojm@[`03o`000?oT6nCoi1_T00[oi1_T00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ok1?_on`Ck00Oon`Ck00?o0000on4NhOoQ7^401_oQ7^40
0ol0003o/Tfbok9=/P0<ok9=/P03o`000?nXEjSoZ5NX00;oZ5NX0_l00007om</d`03o`000?niA[Wo
^DJi00co^DJi00?o0000om@[e?oD:m@03OoD:m@00ol0003oacS7olLha`03olLha`03o`000?nm@[go
_D:m00[o_D:m00?o0000ojm@[on_D:l02_n_D:l00ol0003o[e2_ojm@[`09ojm@[`03o`000?n_D:oo
[e2_00co[e2_00?o0000on@Ki?oT6n@02ooT6n@00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo/4
nook1?/01_ok1?/00ol0003ohAkQon4Nh@06on4Nh@03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ojQG
Z?nXEjP01OnXEjP00ol0003odbcCom</d`03om</d`03o`000?niA[Wo^DJi00go^DJi00?o0000om@[
e?oD:m@03OoD:m@00ol0003oacS7olLha`04olLha`03o`000?nm@[go_D:m00Wo_D:m00?o0000ojm@
[on_D:l02On_D:l00ol0003o[e2_ojm@[`0:ojm@[`03o`000?n_D:oo[e2_00co[e2_00?o0000on@K
i?oT6n@02ooT6n@00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo/4nook1?/01Ook1?/00ol0003o
hAkQon4Nh@07on4Nh@03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ojQGZ?nXEjP01_nXEjP2o`0000?o
dbcC00?o0000okU6^OniA[T03OniA[T00ol0003oe2_Dom@[e00<om@[e003o`000?o7><OoacS700Ko
acS700?o0000oke2_Onm@[d02?nm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n_D:oo[e2_00[o
[e2_00?o0000ojm@[on_D:l03?n_D:l00ol0003oi1_Ton@Ki00;on@Ki003o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ok1?_on`Ck00Con`Ck00?o0000on4NhOoQ7^402?oQ7^400ol0003o/Tfbok9=/P0:ok9=/P03o`00
0?nXEjSoZ5NX00WoZ5NX0_l000000ooC;=?o0000okU6^@0<okU6^@?o00003_oD:m@00ol0003oacS7
olLha`07olLha`03o`000?nm@[go_D:m00Oo_D:m00?o0000ojm@[on_D:l02On_D:l00ol0003o[e2_
ojm@[`0;ojm@[`03o`000?n_D:oo[e2_00co[e2_00?o0000on@Ki?oT6n@02_oT6n@00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo`3o003o`000?ok1?_on`Ck00?on`Ck00?o0000on4NhOoQ7^402_oQ7^400ol0003o/Tfbok9=
/P09ok9=/P03o`000?nXEjSoZ5NX00_oZ5NX00?o0000okU6^OniA[T02_niA[T2o`0000?o[U6^00?o
0000om@[e?oD:m@02_oD:m@00ol0003oacS7olLha`09olLha`03o`000?nm@[go_D:m00Ko_D:m00?o
0000ojm@[on_D:l02?n_D:l00ol0003o[e2_ojm@[`0<ojm@[`03o`000?n_D:oo[e2_00co[e2_00?o
0000on@Ki?oT6n@02_oT6n@00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ool0o`0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ok9=/_nbCK802?nbCK80
0ol0003oZ5NXojQGZ00<ojQGZ003o`000?niA[Wo^DJi00So^DJi0_l00006ojiA[P;o00002_oD:m@0
0ol0003oacS7olLha`0:olLha`03o`000?nm@[go_D:m00Go_D:m00?o0000ojm@[on_D:l02?n_D:l0
0ol0003o[e2_ojm@[`0<ojm@[`03o`000?n_D:oo[e2_00co[e2_00?o0000on@Ki?oT6n@02ooT6n@0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?oo0?l00Go0000oo/4nook1?_on`Cko`00000=
on4Nh@03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojQGZ?nXEjP03_nXEjP00ol0003o^DJiokU6^@04
okU6^@?o00002_n^DJh00ol0003oe2_Dom@[e007om@[e003o`000?o7><OoacS700_oacS700?o0000
oke2_Onm@[d00onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n_D:oo[e2_00co[e2_00?o0000
ojm@[on_D:l03?n_D:l00ol0003oi1_Ton@Ki00;on@Ki0;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003ohAkQon4Nh@0<on4Nh@03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojQGZ?nXEjP03onXEjP01?l0
003o^DJiokU6^OniA[T2o`0000ko[U6^0_l00006om@[e003o`000?o7><OoacS700goacS700?o0000
oke2_Onm@[d00_nm@[d00ol0003o[e2_ojm@[`08ojm@[`03o`000?n_D:oo[e2_00co[e2_0ol0000=
ojm@[`03o`000?oT6nCoi1_T00_oi1_T00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oohAkQ00?o0000ok9=/_nbCK801_nbCK800ol0003oZ5NXojQGZ00@ojQGZ0Co00004_n^DJh00ol0
003oe2_Dom@[e003om@[e003o`000?o7><OoacS700koacS700Go0000oke2_Onm@[go_D:mo`000005
ojm@[`Oo00003?n_D:l01Ol0003oSW6>ohiaS_n>LHko000000co[e2_00?o0000on@Ki?oT6n@02?oT
6n@3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oohAkQ00?o0000ok9=/_nbCK801_nbCK800ol0003oZ5NXojQGZ00=
ojQGZ0?o000000CoSg2?o`000?l0003o00004on^DJh2o`0000;oe2_D00?o0000olLhaoo7><L04?o7
><L00ol0003o_D:mo`000006o`0000Oo`Ck100?o0000ojm@[on_D:l02?n_D:l00ol0003oSW6>ohia
SP03ohiaSP;o00002?n_D:l3o`0000Koi1_T1?l00002omlPg`03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003og2?Lo`000?naC[43o`0000gohAkQ00?o0000ok9=/_nbCK801?nbCK800ol0003oZ5NXojQG
Z00;ojQGZ0?o00000on?L8l01Ol0003oTFjAo`000?nAKY7o000001Co[U6^00?o0000om@[e?l00000
4oo7><L00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?n_D:oo[e2_00Go[e2_0_l00008ohiaSP03o`00
0?n_D:oo[e2_00Go00000on_D:l00ol0003oi1_Ton@Ki003o`0000Oogb3O00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oL8mcog2?Lo`0000Co/Dja0ol0000:on4Nh@03o`000?nbCK;o/Tfb00?o/Tfb
00?o0000ojQGZ?nXEjP02OnXEjP3o`0000GoSg2?00Co0000oi5^TOnAKY7o00000_nAKY400ol0003o
[U6^ojiA[P0BojiA[P03o`000?o7><OoacS701;oacS700?o0000ol4n`Oo1?/403_o1?/400ol0003o
[e2_ojm@[`03ojm@[`03o`000?n>LHkoSW6>00WoSW6>0_l00009ojm@[`;o00002_oO8=l00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000om`Sg?oL8mcog2?Lo`000007ok5>/@;o00001ooQ7^45o`0000;o
/Tfb00?o0000ojQGZ?nXEjP01_nXEjP3o`0000SoSg2?00Co0000oi5^TOnAKY7o00000onAKY400ol0
003o[U6^ojiA[P0AojiA[P03o`000?o7><OoacS7017oacS700?o0000ol4n`Oo1?/404?o1?/401Ol0
003o[e2_ojm@[on_D:oo000000coSW6>00?o0000ojm@[on_D:l02?n_D:l00ol0003ogb3OomlPg`0:
omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000Cog2?L00?o0000ok5>/OnaC[401onaC[43o`00
0004on4NhOl0003o0000o`0000GoZEJY0_l00006ojQGZ0?o00002_n?L8l01Ol0003oTFjAoi5^TOnA
KY7o000000CoTFjA00?o0000ojiA[_n^DJh04?n^DJh00ol0003oacS7olLha`0AolLha`03o`000?o1
?/7o`Ck1017o`Ck100?o0000ojm@[ol000003On>LHh00ol0003o[e2_ojm@[`08ojm@[`03o`000?oO
8=oogb3O00[ogb3O00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oL8mcog2?L00Cog2?L00?o0000
ok5>/OnaC[402_naC[400ol0003oZEJYojUFZ@08ojUFZ@03o`000?nXEjSoZ5NX00?o00003On?L8l0
1Ol0003oTFjAoi5^TOnAKY7o000000GoTFjA00?o0000ojiA[_n^DJh03on^DJh00ol0003oacS7olLh
a`0AolLha`03o`000?o1?/7o`Ck101;o`Ck100?o0000ohiaS_n>LHh03?n>LHh00ol0003o[e2_ojm@
[`08ojm@[`03o`000?oO8=oogb3O00_ogb3O00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000om`Sg?oL8m`01OoL8m`0
0ol0003o/Djaok5>/@0:ok5>/@03o`000?nYEZWoZEJY00WoZEJY0_l0000?ohm`S`03o`000?nAKY7o
TFjA00;oTFjA00?o0000oi5^TOnAKY401?nAKY400ol0003o[U6^ojiA[P0=ojiA[P?o00004Oo7><L0
0ol0003o`Ck1ol4n`@0Col4n`@03o`000?n>LHkoSW6>00_oSW6>00?o0000ojm@[on_D:l02On_D:l0
0ol0003ogb3OomlPg`0;omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo/4n`;o00002?oL8m`0
0ol0003o/Djaok5>/@0:ok5>/@03o`000?nYEZWoZEJY00WoZEJY00?o0000ohm`Son?L8l03On?L8l0
0ol0003oTFjAoi5^T@03oi5^T@03o`000?nAKY7oTFjA00GoTFjA00?o0000ojiA[_n^DJh02_n^DJh2
o`0000?o_D:m00?o0000olLhaoo7><L03_o7><L00ol0003o`Ck1ol4n`@0Col4n`@03o`000?n>LHko
SW6>00_oSW6>00?o0000ojm@[on_D:l02On_D:l00ol0003ogb3OomlPg`0;omlPg`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Gon`Ck00?o0000om`Sg?oL8m`01ooL8m`2o`0000_o/Dja00?o0000ojUF
ZOnYEZT02onYEZT00ol0003oSg2?ohm`S`0<ohm`S`03o`000?nAKY7oTFjA00?oTFjA00?o0000oi5^
TOnAKY401_nAKY400ol0003o[U6^ojiA[P07ojiA[P;o00001_nm@[d2o`0000koacS700?o0000ol4n
`Oo1?/404oo1?/400ol0003oSW6>ohiaSP0;ohiaSP03o`000?n_D:oo[e2_00Wo[e2_00?o0000omlP
gooO8=l03?oO8=l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo/4nook1?_on`Cko`000009om`S
g003o`000?n?L8oo000000_o/Dja00?o0000ojUFZOnYEZT02onYEZT00ol0003oSg2?ohm`S`0;ohm`
S`03o`000?nAKY7oTFjA00CoTFjA00?o0000oi5^TOnAKY401onAKY400ol0003o[U6^ojiA[P05ojiA
[P03o`000?nm@[go_D:m00So_D:m00?o0000olLhaoo7><L02_o7><L00ol0003o`Ck1ol4n`@0Dol4n
`@03o`000?n>LHkoSW6>00_oSW6>00?o0000ojm@[on_D:l02On_D:l00ol0003ogb3OomlPg`0<omlP
g`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003on`Cko`000009om`Sg004o`000?n?L8ooSg2?o`00
00_o/Dja00?o0000ojUFZOnYEZT02onYEZT00ol0003oSg2?ohm`S`0;ohm`S`03o`000?nAKY7oTFjA
00CoTFjA00?o0000oi5^TOnAKY402?nAKY400ol0003o[U6^ojiA[P02ojiA[P;o00003?nm@[d2o`00
00[oacS700?o0000ol4n`Oo1?/405?o1?/400ol0003oSW6>ohiaSP0;ohiaSP03o`000?n_D:oo[e2_
00Wo[e2_00?o0000omlPgooO8=l03OoO8=l00ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003og2?Lom`Sg007om`Sg003
o`000?n?L8ooSg2?00;oSg2?00?o0000ok5>/OnaC[402?naC[400ol0003oZEJYojUFZ@0<ojUFZ@03
o`000?n?L8ooSg2?00WoSg2?00?o0000oi5^TOnAKY401OnAKY400ol0003oTFjAoi5^T@09oi5^T@04
o`000?n^DJko0000o`00013o_D:m0_l00008olLha`03o`000?o1?/7o`Ck101Co`Ck10ol0000;ohia
SP03o`000?n_D:oo[e2_00Wo[e2_00?o0000omlPgooO8=l03OoO8=l01?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003og2?Lom`Sg006om`Sg003o`000?n?L8ooSg2?00?oSg2?00?o0000ok5>
/OnaC[402?naC[400ol0003oZEJYojUFZ@0;ojUFZ@;o00002_n?L8l00ol0003oTFjAoi5^T@06oi5^
T@03o`000?nAKY7oTFjA00[oTFjA00?o0000oke2_Onm@[d04_nm@[d00ol0003oacS7olLha`04olLh
a`03o`000?o1?/7o`Ck101Go`Ck100?o0000okA;]?ndBk@01Ol00005ohiaSP03o`000?n_D:oo[e2_
00[o[e2_00?o0000omlPgooO8=l03_oO8=l3o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lom`Sg004om`Sg003
o`000?n?L8ooSg2?00CoSg2?00?o0000ok5>/OnaC[401onaC[400ol0003oZEJYojUFZ@0;ojUFZ@04
o`000?nNHIkoWV6No`0000WoSg2?00?o0000oi5^TOnAKY401_nAKY400ol0003oTFjAoi5^T@0:oi5^
T@03o`000?nm@[go_D:m01?o_D:m0_l00003olLha`Co00005?o1?/400ol0003o]4^dokA;]006okA;
]0Co000000?oSW6>o`000?n_D:l02on_D:l00ol0003ogb3OomlPg`0>omlPg`03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003og2?Lom`Sg003om`Sg003o`000?n?L8ooSg2?00GoSg2?00?o0000ok5>/Ona
C[401onaC[400ol0003oZEJYojUFZ@09ojUFZ@;o00001?nNHIh00ol0003oSg2?ohm`S`05ohm`S`03
o`000?nAKY7oTFjA00OoTFjA00?o0000oi5^TOnAKY402_nAKY400ol0003o_D:moke2_@0Eoke2_@03
o`000?o7><Oo000000CoaSW60ol0000@ol4n`@03o`000?ndBkCo]4^d00_o]4^d0_l0000<ojm@[`03
o`000?oO8=oogb3O00cogb3O0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om`Sg?oL8m`00_oL8m`00ol0003oSg2?
ohm`S`06ohm`S`03o`000?naC[7o/Dja00Oo/Dja00?o0000ojUFZOnYEZT02?nYEZT00ol0003oWV6N
oiiQWP05oiiQWP03o`000?n?L8ooSg2?00CoSg2?00?o0000oi5^TOnAKY401onAKY400ol0003oTFjA
oi5^T@0:oi5^T@03o`000?nm@[go_D:m01Ko_D:m00?o0000olHia_o6>LH01_o6>LH3o`0000co`Ck1
00?o0000okA;]?ndBk@03OndBk@00ol0003o[e2_ojm@[`09ojm@[`Go00002OoO8=l2o`000003omdR
gOl0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003om`Sg?l0003oSg2?00WoSg2?00?o0000ok5>/OnaC[401_na
C[400ol0003oZEJYojUFZ@07ojUFZ@03o`000?nNHIkoWV6N00OoWV6N00?o0000ohm`Son?L8l00_n?
L8l00ol0003oTFjAoi5^T@08oi5^T@03o`000?nAKY7oTFjA00WoTFjA00?o0000oke2_Onm@[d05onm
@[d00ol0003oaSW6olHiaP09olHiaP?o00002Oo1?/400ol0003o]4^dokA;]00>okA;]0Ko00001?n_
D:l00ol0003oXebSoj=LX`03oj=LX`Go00000_oO8=l2o`0000CogB;M00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?o;=<_obcC;ol/dbol000002on?L8l00ol0003o/Djaok5>/@06ok5>/@03o`000?nY
EZWoZEJY00GoZEJY0_l0000;oiiQWP04o`000?n?L8ooSg2?o`0000_oTFjA00?o0000oi5^TOnAKY40
2OnAKY400ol0003o_D:moke2_@0Foke2_@03o`000?o6>LKoaSW600goaSW60ol00005ol4n`@03o`00
0?ndBkCo]4^d00oo]4^d00?o0000ok5>/OnaC[400onaC[44o`0000_oXebS0_l00006omdRg@03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003obcC;ol/db`02ol/db`ko00001_naC[400ol0003oZEJYojUF
Z@05ojUFZ@03o`000?nNHIkoWV6N00coWV6N00?o0000ohm`Sol000002onAKY400ol0003oTFjAoi5^
T@07oi5^T@?o00006?nm@[d00ol0003oaSW6olHiaP0@olHiaP?o000000?o`Ck1o`000?ndBk@04?nd
Bk@00ol0003o/Djaok5>/@07ok5>/@03o`000?nSG:?oXebS00[oXebS00?o0000omdRgOoM8]d01OoM
8]d00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005ol/db`03o`000?mnPGkoOX5n00_oOX5n0_l00004
ok5>/@03o`000?nYEZWoZEJY00?oZEJY0_l0000@oiiQWP03o`000?nAKY7oTFjA00[oTFjA00?o0000
oi5^TOnAKY400onAKY44o`0000;oQGZ500?o0000oke2_Onm@[d05Onm@[d00ol0003oaSW6olHiaP0D
olHiaP03o`000?ndBkCo]4^d013o]4^d00?o0000ok5>/OnaC[401onaC[400ol0003oXebSoj=LX`0:
oj=LX`03o`000?oM8]gogB;M00GogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o;=<_obcC;
00GobcC;00?o0000ogj1O_mnPGh03OmnPGh6o`0000?oZEJY00?o0000oiiQW_nNHIh04?nNHIh00ol0
003oTFjAoi5^T@0:oi5^T@03o`000?nAKY7o000000?o00001on5NXD00ol0003o_D:moke2_@0Doke2
_@03o`000?o6>LKoaSW601CoaSW600?o0000okA;]?ndBk@03ondBk@00ol0003o/Djaok5>/@08ok5>
/@03o`000?nSG:?oXebS00[oXebS00?o0000omdRgOoM8]d01OoM8]d00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000ol/dboo;=</01_o;=</00ol0003oOX5nogj1OP0=ogj1OP03o`000?n/Djco[5>/00?o
[5>/00?o0000ojUFZOl000004onNHIh4o`0000WoTFjA0_l0000<ohEjQ@03o`000?nm@[go_D:m01?o
_D:m00?o0000olHia_o6>LH05Oo6>LH00ol0003o]4^dokA;]00>okA;]003o`000?naC[7o/Dja00So
/Dja00?o0000oj=LXonSG:<02OnSG:<00ol0003ogB;MomdRg@07omdRg@03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?o;=<_obcC;00SobcC;00?o0000ogj1O_mnPGh02omnPGh00ol0003o[5>/ojaC[005ojaC[003o`00
0?nNHIkoWV6N01;oWV6N00Co0000oi1_T?n@Ki3oT6n@1Ol00003oi5^T@03o`000?n5NXGoQGZ500go
QGZ50ol0000@oke2_@;o00006?o6>LH00ol0003o]4^dokA;]00=okA;]003o`000?naC[7o/Dja00Wo
/Dja00?o0000oj=LXonSG:<02OnSG:<00ol0003ogB;MomdRg@07omdRg@03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_obcC;00?o0000ogj1O_mnPGh02_mnPGh00ol0003o[5>/ojaC[006ojaC[003o`00
0?nNHIkoWV6N017oWV6N00?o0000oi1_T?n@Ki001on@Ki03o`00013oQGZ500?o0000oh5nPOn1OX40
1Ol00009oke2_@;o000000?oU6^Do`000?o6>LH05oo6>LH00ol0003o]4^dokA;]00=okA;]003o`00
0?naC[7o/Dja00Wo/Dja00?o0000oj=LXonSG:<02?nSG:<2o`0000[ogB;M00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oO8=oogb3O00;ogb3O00?o0000ol/dboo;=</02Oo;=</00ol0003oOX5nogj1
OP0:ogj1OP03o`000?n/Djco[5>/00Oo[5>/00?o0000oiiQW_nNHIh03onNHIh00ol0003oT6n@oi1_
T00:oi1_T003o`000?n5NXGoQGZ500goQGZ500?o0000oh5nPOn1OX401_n1OX44o`0000Co_D:m00?o
0000oiA[U?nDJi@00_nDJi@00ol0003oaSW6olHiaP0FolHiaP03o`000?ndBkCo]4^d00_o]4^d00?o
0000ok5>/OnaC[402onaC[400ol0003oXebSoj=LX`06oj=LX`03o`000?nPGj3o000000[ogB;M00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oO8=oogb3O00?ogb3O00?o0000ol/dboo;=</02?o;=</=
o`0000[o[5>/00?o0000oiiQW_nNHIh03onNHIh00ol0003oT6n@oi1_T00;oi1_T003o`000?n5NXGo
QGZ500coQGZ500?o0000oh5nPOn1OX402_n1OX44o`0000GoU6^D00?o0000olHia_o6>LH05_o6>LH0
0ol0003o]4^dokA;]00:okA;]003o`000?naC[7o/Dja00co/Dja00?o0000oj=LXonSG:<01?nSG:<2
o`0000?oX5nP00?o0000omdRgOoM8]d02?oM8]d00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omlP
gooO8=l00ooO8=l00ol0003obcC;ol/db`07ol/db`03o`000?mlPgcoO8=l00WoO8=l00?o0000ojaC
[?n/Dj`02On/Dj`00ol0003oWV6NoiiQWP0=oiiQWP03o`000?n@Ki3oT6n@00coT6n@00?o0000ohEj
QOn5NXD03?n5NXD00ol0003oPGj1oh5nP@0;oh5nP@03o`000?mYUVWo000000KoU6^D00?o0000olHi
a_o6>LH05_o6>LH00ol0003o]4^dokA;]009okA;]003o`000?naC[7o/Dja00co/Dja00?o0000oj=L
XonSG:<00onSG:<00ol0003oX5nPoj1OX003oj1OX003o`000?oM8]gogB;M00SogB;M00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oO8=oogb3O00Cogb3O00?o0000ol/dboo;=</01_o;=</00ol0003o
O8=logb3O008ogb3O003o`000?n/Djco[5>/00_o[5>/00?o0000oiiQW_nNHIh02?nNHIh4o`0000oo
T6n@00?o0000ohEjQOn5NXD02on5NXD00ol0003oPGj1oh5nP@0;oh5nP@04o`000?mYUVWoJIIYo`00
00OoU6^D00?o0000olHia_o6>LH05Oo6>LH00ol0003o]4^dokA;]008okA;]003o`000?naC[7o/Dja
00go/Dja00?o0000oj=LXonSG:<00_nSG:<00ol0003oX5nPoj1OX005oj1OX003o`000?oM8]gogB;M
00OogB;M00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oO8=oogb3O00Gogb3O00?o0000ol/dboo;
=</01Oo;=</00ol0003oO8=logb3O008ogb3O003o`000?n/Djco[5>/00_o[5>/00?o0000oiiQW_nN
HIh00onNHIh5o`0000?oT6n@00?o0000oi1_T?n@Ki003_n@Ki000ol0003oQGZ5ohEjQ@0:ohEjQ@03
o`000?n1OX7oPGj100[oPGj100Go0000ofVFJOmYUVWoJIIYo`000007oiA[U003o`000?o6>LKoaSW6
01GoaSW600?o0000okA;]?ndBk@02?ndBk@00ol0003o/Djaok5>/@0=ok5>/@03o`000?nSG:?oXebS
00;o00002?nPGj000ol0003ogB;MomdRg@08omdRg@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003ogb3OomlPg`05omlPg`03o`000?o;=<_obcC;00Go
bcC;00?o0000ogb3O?mlPg`02?mlPg`00ol0003o[5>/ojaC[00<ojaC[0Go00002On@Ki000ol0003o
T6n@oi1_T00<oi1_T0;o00003?n5NXD00ol0003oPGj1oh5nP@0:oh5nP@05o`000?mYUVWoJIIYofVF
JOl000002?nDJi@00ol0003oaSW6olHiaP0DolHiaP?o00001ondBk@00ol0003o/Djaok5>/@0>ok5>
/@03o`000?nSG:?o000000_oX5nP00?o0000omdRgOoM8]d01_oM8]d00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000omlPgooO8=l01OoO8=l00ol0003obcC;ol/db`04ol/db`03o`000?mlPgcoO8=l00Oo
O8=l00?o0000ojaC[?n/Dj`03?n/Dj`01?l0003oWV6NoiiQW_l0000;oi1_T003o`000?n@Ki3oT6n@
00_oT6n@00Co0000ofJII_mVVFKo00002_n5NXD00ol0003oPGj1oh5nP@0:oh5nP@03o`000?mYUVWo
JIIY00;oJIIY00?o0000oiA[U?nDJi@01_nDJi@00ol0003oaSW6olHiaP0AolHiaP?o00000onNHIh0
0ol0003o]4^dokA;]004okA;]003o`000?naC[7o/Dja00go/Dja1?l0000;oj1OX003o`000?oM8]go
gB;M00GogB;M00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oO8=oogb3O00Kogb3O00Co0000ol/d
boo;=<_obcC;1?l00008ogb3O003o`000?n/Djco[5>/00_o[5>/00?o0000oiiQW_nNHIh00_nNHIh0
0ol0003oT6n@oi1_T008oi1_T003o`000?n@Ki3oT6n@00[oT6n@00?o0000ofJII_mVVFH00_mVVFH0
0ol0003oQGZ5ohEjQ@03ohEjQ@Go00002on1OX400ol0003oJIIYofVFJ@03ofVFJ@03o`000?nDJiCo
U6^D00OoU6^D00?o0000olHia_o6>LH03_o6>LH2o`0000OoWV6N00?o0000okA;]?ndBk@00_ndBk@0
0ol0003o/Djaok5>/@0=ok5>/@03o`000?nTFjCoY5^T00;oY5^T00?o0000oj1OX?nPGj002OnPGj00
0ol0003ogB;MomdRg@03omdRg@03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003ogb3OomlPg`07omlP
g`?o00001?niA[T00ol0003oO8=logb3O005ogb3O003o`000?n/Djco[5>/00[o[5>/00?o0000oiiQ
W_nNHIh00onNHIh00ol0003oT6n@oi1_T009oi1_T003o`000?n@Ki3oT6n@00SoT6n@00?o0000ofJI
I_mVVFH01?mVVFH5o`0000Co=</d00?o0000oh5nPOn1OX402On1OX400ol0003oJIIYofVFJ@03ofVF
J@03o`000?nDJiCoU6^D00SoU6^D00?o0000olHia_o6>LH02_o6>LH3o`0000[oWV6N00Go0000okA;
]?ndBkCo]4^do`00000>ok5>/@03o`000?nTFjCoY5^T00CoY5^T0_l00009oj1OX003o`000?oM8]go
gB;M00;ogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oO8=oogb3O00Oogb3O00?o0000okU6
^OniA[T01OniA[T00ol0003oO8=logb3O003ogb3O003o`000?n/Djco[5>/00[o[5>/00?o0000oiiQ
W_nNHIh01?nNHIh00ol0003oT6n@oi1_T009oi1_T003o`000?n@Ki3oT6n@00OoT6n@00?o0000ofJI
I_mVVFH01OmVVFH00ol0003o=</docC;=007ocC;=003o`000?n1OX7oPGj100OoPGj100?o0000ofVF
JOmYUVT01?mYUVT00ol0003oU6^DoiA[U008oiA[U003o`000?o6>LKoaSW600SoaSW60_l0000>oiiQ
WPCo00003?naC[42o`0000WoY5^T00?o0000oj1OX?nPGj001onPGj001?l0003ogB;MomdRgOl0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000omlPgooO8=l01OoO8=l00ol0003o^DJiokU6^@07okU6^@;o00000omlPg`00ol0
003o[5>/ojaC[009ojaC[003o`000?nNHIkoWV6N00KoWV6N00?o0000oi1_T?n@Ki002On@Ki000ol0
003oT6n@oi1_T005oi1_T003o`000?mVVFKoIYUV00KoIYUV00?o0000ocC;=?ldbc@02?ldbc@00ol0
003oPGj1oh5nP@06oh5nP@03o`000?mYUVWoJIIY00CoJIIY00?o0000oiA[U?nDJi@02OnDJi@4o`00
00?oaSW60ol0000@oiiQWP05o`000?o7><OoacS7olLhaol000002_naC[400ol0003oY5^TojAKY00:
ojAKY0Ko00000onPGj000ol0003ogB;Mo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000omlPgooO8=l01?oO8=l00ol0
003o^DJiokU6^@0:okU6^@04o`000?mlPgcoO8=lo`0000[o[5>/00?o0000oiiQW_nNHIh01onNHIh0
0ol0003oT6n@oi1_T009oi1_T003o`000?n@Ki3oT6n@00CoT6n@00?o0000ofJII_mVVFH01omVVFH0
0ol0003o=</docC;=008ocC;=0;o00001_n1OX400ol0003oJIIYofVFJ@05ofVFJ@03o`000?nDJiCo
U6^D00WoU6^D00Co0000ohAkQ?n4NhCoQ7^40ol0000BoiiQWP03o`000?o7><OoacS700?oacS70_l0
0006ok5>/@;o00003OnTFj@00ol0003ohQgRon8MhP03on8MhPGo00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000omlPgooO8=l00ooO8=l0
0ol0003o^DJiokU6^@0<okU6^@;o00002_n/Dj`00ol0003oWV6NoiiQWP08oiiQWP03o`000?n@Ki3o
T6n@00[oT6n@00?o0000oi1_T?n@Ki000_n@Ki000ol0003oIYUVofJIIP08ofJIIP03o`000?ldbcCo
=</d00Ko=</d0_l00002of>LH`03o`000?n1OX7oPGj100;oPGj100?o0000ofVFJOmYUVT01_mYUVT0
0ol0003oU6^DoiA[U008oiA[U003o`000?n4NhCoQ7^400CoQ7^400?o0000oiiQW_nNHIh03onNHIh0
0ol0003oacS7olLha`06olLha`;o00000onaC[400ol0003oY5^TojAKY00=ojAKY003o`000?oR7N;o
hQgR00OohQgR0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003ogb3OomlPg`02omlPg`03o`000?niA[Wo^DJi
00ko^DJi00?o0000ojaC[?n/Dj`01on/Dj`00ol0003oWV6NoiiQWP0:oiiQWP03o`000?n@Ki3oT6n@
00WoT6n@00Go0000oi1_T?n@Ki3oT6n@o`00000;ofJIIP03o`000?ldbcCo=</d00Co=</d0_l00005
of>LH`05o`000?n1OX7oPGj1oh5nPOl000002?mYUVT00ol0003oU6^DoiA[U008oiA[U003o`000?n4
NhCoQ7^400GoQ7^400?o0000oiiQW_nNHIh03_nNHIh00ol0003oacS7olLha`08olLha`03o`000?na
C[7o000000ooY5^T00?o0000on8Mh_oR7N802?oR7N801?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oO8=oogb3Oo`00017o^DJi00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003oWV6N
oiiQWP0;oiiQWP03o`000?n@Ki3oT6n@00WoT6n@00Co0000oi1_T?n@Ki3o00003?mVVFH00ol0003o
=</docC;=002ocC;=0;o00002?mSW6<00ol0003oPGj1o`000009ofVFJ@03o`000?nDJiCoU6^D00So
U6^D00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003oWV6NoiiQWP0=oiiQWP03o`000?o7><OoacS700[o
acS700?o0000ojAKY?nTFj@03_nTFj@00ol0003ohQgRon8MhP07on8MhP03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000BokU6^@03o`00
0?n/Djco[5>/00Co[5>/00?o0000oiiQW_nNHIh03?nNHIh00ol0003oT6n@oi1_T00:oi1_T0?o0000
3?mVVFH00ol0003o=</docC;=002o`0000_oHiaS00?o0000ofVFJOmYUVT02?mYUVT00ol0003oU6^D
oiA[U007oiA[U003o`000?n4NhCoQ7^400OoQ7^400?o0000oiiQW_nNHIh03?nNHIh00ol0003oacS7
olLha`0;olLha`;o00003_nTFj@00ol0003ohQgRon8MhP07on8MhP03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onHIi_oV6NH00ooV6NH00ol0003o^DJiokU6^@0?okU6^@?o00000on/
Dj`00ol0003oWV6NoiiQWP0>oiiQWP03o`000?n@Ki3oT6n@00SoT6n@00Co0000ofjAK_m^TFkoKY5^
0_l0000:ofJIIP?o00003OmSW6<00ol0003oJIIYofVFJ@08ofVFJ@03o`000?nDJiCoU6^D00OoU6^D
00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oWV6NoiiQWP0;oiiQWP03o`000?o7><OoacS700coacS7
00?o0000olHia_l000000_l0000:ojAKY003o`000?oR7N;ohQgR00SohQgR00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oiQWVonHIiP04onHIiP03o`000?niA[Wo^DJi00co^DJi0_l0
0003ojIIYP03o`000?n/Djco0000017oWV6N00?o0000oi1_T?n@Ki001on@Ki000ol0003oKY5^ofjA
KP04ofjAKP;o00002?mVVFH00ol0003oHiaSof>LH`0>of>LH`;o00002?mYUVT00ol0003oU6^DoiA[
U006oiA[U003o`000?n4NhCoQ7^400WoQ7^400?o0000oiiQW_nNHIh02OnNHIh00ol0003oacS7olLh
a`0=olLha`03o`000?o6>LKoaSW600;oaSW60ol00007ojAKY003o`000?oR7N;ohQgR00OohQgR00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oiQWVonHIiP05onHIiP03o`000?niA[Wo
^DJi00Wo^DJi0_l00006ojIIYP03o`000?nNHIkoWV6N013oWV6N00?o0000oi1_T?n@Ki001_n@Ki00
0ol0003oKY5^ofjAKP07ofjAKP03o`000?mVVFKoIYUV00CoIYUV0ol0000>of>LH`03o`000?m>/Dko
C[5>00?o00001OmYUVT00ol0003oU6^DoiA[U006oiA[U003o`000?n4NhCoQ7^400[oQ7^400?o0000
oiiQW_nNHIh02?nNHIh00ol0003oacS7olLha`0=olLha`03o`000?o6>LKoaSW600GoaSW60ol00004
ojAKY003o`000?oR7N;ohQgR00OohQgR00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oiQWVonHIiP06onHIiP03o`000?niA[Wo^DJi00Go^DJi0ol00008ojIIYP03o`000?nNHIkoWV6N
017oWV6N00Co0000oi1_T?n@Ki3oT6n@1?l0000;ofjAKP;o000000CoIYUVo`000?l0003o00000oml
Pg`2o`0000_oHiaS00?o0000odjaC_m>/Dh01?m>/Dh2o`0000?oJIIY00?o0000oiA[U?nDJi@01_nD
Ji@00ol0003oQ7^4ohAkQ00:ohAkQ003o`000?nNHIkoWV6N00OoWV6N00?o0000olLhaoo7><L03_o7
><L00ol0003oaSW6olHiaP08olHiaPCo00002_oR7N800ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiQWVonHIiP07onHIiP03o`000?niA[Wo^DJi00;o^DJi0_l0000<ojIIYP03o`000?nNHIko
WV6N013oWV6N1?l00003ohAkQ003o`000?m^TFkoKY5^00_oKY5^00?o0000ogb3O?mlPg`01_mlPg`0
0ol0003oHiaSof>LH`07of>LH`03o`000?m>/DkoC[5>00OoC[5>3?l0000>ohAkQ003o`000?nNHIko
WV6N00KoWV6N00?o0000olLhaoo7><L03_o7><L00ol0003oaSW6olHiaP0;olHiaP03o`000?oR7N;o
hQgR00OohQgR00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oV6NKoiQWV00WoiQWV00Co0000okU6
^Ol0003o00003_nVFJH00ol0003oWV6NoiiQWP0?oiiQWP03o`000?n4NhCoQ7^400KoQ7^400?o0000
ofjAK_m^TFh02_m^TFh00ol0003oO8=logb3O007ogb3O0;o00001_mSW6<00ol0003oC[5>odjaCP08
odjaCP03o`000?nKI9_oVfBK00SoVfBK00?o0000ohAkQ?n4Nh@03?n4Nh@00ol0003oWV6NoiiQWP05
oiiQWP03o`000?o7><OoacS700ooacS70_l0000=olHiaP03o`000?oR7N;ohQgR00KohQgR00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oV6NKoiQWV00[oiQWV00?o0000ojIIY_nVFJH03_nVFJH00ol0
003oWV6NoiiQWP0>oiiQWP03o`000?n4NhCoQ7^400OoQ7^400?o0000ofjAK_m^TFh02_m^TFh00ol0
003oO8=logb3O009ogb3O0;o00000omSW6<00ol0003oC[5>odjaCP09odjaCP03o`000?nKI9_oVfBK
00WoVfBK00?o0000ohAkQ?n4Nh@02_n4Nh@4o`0000CoWV6N00?o0000olLhaoo7><L04?o7><L01?l0
003oa3_4o`000?l0000<olHiaP03o`000?oR7N;ohQgR00GohQgR00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oV6NKoiQWV00[oiQWV00?o0000ojIIY_nVFJH03onVFJH@o`0000[oQ7^400?o0000ofjA
K_m^TFh02Om^TFh00ol0003oEjQGo`00000<ogb3O005o`000?mSW6?o0000oe2_D?l000002_m>/Dh0
0ol0003oVfBKoi]TV`09oi]TV`03o`000?n4NhCoQ7^400OoQ7^40ol00004ojIIYP?o000000?oWV6N
o`000?o7><L04Oo7><L01?l0003oa3_4ol@ka?o4>l@2o`0000_oaSW600?o0000on8Mh_oR7N800ooR
7N800ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onHIi_oV6NH02_oV6NH00ol0003oYUVVojIIYP0?
ojIIYP03o`000?nUFZGoYEZU00coYEZU00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003oKY5^ofjAKP07
ofjAKP04o`000?mGZ5OoEjQGo`0000goO8=l00Go0000oe2_D?m@[e3oD:m@o`000009odjaCP03o`00
0?nKI9_oVfBK00[oVfBK00?o0000ohAkQ?n4Nh@00on4Nh@3o`0000[oYUVV00?o0000olLhaoo7><L0
4?o7><L00ol0003oa3_4ol@ka004ol@ka0;o00002_o6>LH00ol0003ohQgRon8MhP04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coiQWV00?o0000ojIIY_nVFJH03onVFJH00ol0003oYEZUojEJY@0<ojEJY@03o`000?n4
NhCoQ7^400WoQ7^400?o0000ofjAK_m^TFh01_m^TFh00ol0003oEjQGoeNXE`02oeNXE`03o`000?ml
PgcoO8=l00[oO8=l00?o0000oe2_D?m@[e000_m@[e000ol0003oC[5>odjaCP06odjaCP03o`000?nK
I9_oVfBK00[oVfBK00?o0000ohAkQ?n4Nh@00ol0000=ojIIYP03o`000?o7><OoacS7013oacS700?o
0000ol@ka?o4>l@01_o4>l@2o`0000WoaSW60_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000onHIi_oV6NH02_oV6NH00ol0003oYUVVojIIYP0=ojIIYP?o00003onUFZD0
0ol0003oQ7^4ohAkQ008ohAkQ003o`000?m^TFkoKY5^00GoKY5^00?o0000oeNXEomGZ5L00omGZ5L0
0ol0003oO8=logb3O00:ogb3O003o`000?m@[e3oD:m@00?oD:m@00?o0000odjaC_m>/Dh01Om>/Dh0
0ol0003oVfBKoi]TV`0;oi]TV`;o00004OnVFJH00ol0003oacS7olLha`0?olLha`03o`000?o4>lCo
a3_400Soa3_40_l00007olHiaP03o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000onHIi_oV6NH02?oV6NH00ol0003oYUVVojIIYP09ojIIYPGo00000_n7N8L00ol0
003oYEZUojEJY@0=ojEJY@03o`000?n4NhCoQ7^400WoQ7^400?o0000ofjAK_m^TFh01?m^TFh00ol0
003oEjQGoeNXE`04oeNXE`03o`000?mlPgcoO8=l00SoO8=l00?o0000oe2_D?m@[e001Om@[e000ol0
003oC[5>odjaCP04odjaCP03o`000?nKI9_oVfBK00_oVfBK00?o0000ojIIY_nVFJH04?nVFJH00ol0
003oacS7olLha`0?olLha`03o`000?o4>lCoa3_400[oa3_40_l00004olHiaP03o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003oiQWVonHIiP07onHIiP03o`000?nVFJKoYUVV00CoYUVV1Ol00007ohMhQ`03
o`000?nUFZGoYEZU00goYEZU00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003oKY5^ofjAKP03ofjAKP03
o`000?mGZ5OoEjQG00GoEjQG00?o0000ogb3O?mlPg`02?mlPg`00ol0003oD:m@oe2_D006oe2_D003
o`000?m>/DkoC[5>00?oC[5>00?o0000oi]TVonKI9/02onKI9/00ol0003oYUVVojIIYP0@ojIIYP03
o`000?o7><OoacS700ooacS700?o0000ol@ka?o4>l@03?o4>l@2o`000003olHia_l0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oV6NKoiQWV00OoiQWV00?o0000ojIIY_l00000
1?l0000<ohMhQ`03o`000?nUFZGoYEZU00koYEZU00?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oKY5^
ofjAKP02ofjAKP03o`000?mGZ5OoEjQG00OoEjQG00?o0000ogb3O?mlPg`01omlPg`00ol0003oD:m@
oe2_D007oe2_D003o`000?m>/DkoC[5>00;oC[5>00?o0000oi]TVonKI9/02onKI9/00ol0003oYUVV
ojIIYP0AojIIYP03o`000?o7><OoacS700goacS700?o0000ol@ka?o4>l@03oo4>l@00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onHIi_oV6NH01OoV6NH3o`00017oQgR700?o0000ojEJYOnUFZD03_nU
FZD00ol0003oQ7^4ohAkQ009ohAkQ004o`000?m^TFkoKY5^o`0000[oEjQG00?o0000ogb3O?mlPg`0
1omlPg`00ol0003oD:m@oe2_D008oe2_D005o`000?m>/DkoC[5>odjaC_l000003OnKI9/00ol0003o
YUVVojIIYP0AojIIYP?o00003Oo7><L00ol0003oa3_4ol@ka00?ol@ka003o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oV6NH2o`0000;o/dbc00?o0000ohMhQon7N8L03on7N8L00ol0003o
YEZUojEJY@0>ojEJY@03o`000?n4NhCoQ7^400SoQ7^41Ol0000;oeNXE`03o`000?mlPgcoO8=l00Ko
O8=l00?o0000oe2_D?m@[e002Om@[e001?l0003oC[5>odjaC_l0000=oi]TV`03o`000?nVFJKoYUVV
017oYUVV00?o0000oh=lPon3O8<00ol0000:olLha`Co00003Oo4>l@00ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000on4NhOoQ7^7ohAkQ0_l00005ok=</`03o`000?n7N8OoQgR700koQgR700?o0000ojEJ
YOnUFZD03_nUFZD00ol0003oQ7^4ohAkQ007ohAkQ003o`000?n2OH;oPWf200?oPWf200?o0000oeNX
EomGZ5L02?mGZ5L00ol0003oO8=logb3O005ogb3O003o`000?m@[e3oD:m@00[oD:m@1Ol0000<oi]T
V`03o`000?nVFJKoYUVV013oYUVV00?o0000oh=lPon3O8<01?n3O8<3o`0000KoacS700?o0000ol`c
c?o<<l`00_o<<l`5o`0000Soa3_400?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oQ7^7ohAkQ00?o
hAkQ00?o0000ok=</oncC;<01?ncC;<00ol0003oQgR7ohMhQ`0=ohMhQ`03o`000?nUFZGoYEZU00oo
YEZU00?o0000ohAkQ?n4Nh@01?n4Nh@2o`0000OoPWf200?o0000oeNXEomGZ5L01omGZ5LEo`0000Go
GJ9M00?o0000oi]TVonKI9/02?nKI9/3o`00013oYUVV00?o0000oh=lPon3O8<02?n3O8<3o`0000;o
acS700?o0000ol`cc?o<<l`02?o<<l`5o`0000?oa3_400?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oQ7^7ohAkQ00CohAkQ00?o0000ok=</oncC;<01OncC;<00ol0003oQgR7ohMhQ`0;ohMhQ`Co0000
3onUFZD00ol0003oQ7^4ohAkQ003ohAkQ003o`000?n2OH;oPWf200SoPWf200?o0000oeNXEomGZ5L0
1?mGZ5L2o`0000SoPWf200?o0000og6>LOmaSW402?maSW400ol0003oGJ9MoefRG@05oefRG@;o0000
1_nKI9/2o`0000?oSg2?00?o0000ojIIY_nVFJH03?nVFJH00ol0003oPgb3oh=lP`0<oh=lP`;o0000
4?o<<l`3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003ohAkQon4Nh@05on4Nh@03o`000?ncC;?o/dbc00Ko/dbc00?o
0000ohMhQon7N8L02On7N8L00ol0003oKY5^o`000002ohEjQ@?o00003?nUFZD01?l0003oQ7^4ohAk
Q?n4Nh@2o`0000coPWf200?o0000oeNXEomGZ5L00_mGZ5L00ol0003oPWf2oh9mPP08oh9mPP03o`00
0?maSW7oLHia00SoLHia00?o0000oefRGOmMXUd01omMXUd00ol0003oVfBKoi]TV`02oi]TV`03o`00
0?n?L8ooSg2?00CoSg2?0_l0000;ojIIYP03o`000?n3O8?oPgb300coPgb300?o0000oiUVVOl00000
4_o<<l`00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003ohAkQon4Nh@06on4Nh@03o`000?ncC;?o/dbc00Oo/dbc00?o
0000ohMhQon7N8L01_n7N8L2o`0000;oKY5^00?o0000ohEjQOn5NXD00on5NXD3o`0000[oYEZU00?o
0000ohAkQ?l000003on2OH801?l0003oEjQGo`000?l0000;oh9mPP03o`000?maSW7oLHia00SoLHia
00?o0000oefRGOmMXUd02?mMXUd01?l0003oVfBKo`000?l00009ohm`S`03o`000?nVFJKoYUVV00Oo
YUVV00?o0000oh=lPon3O8<03?n3O8<01?l0003oVFJIoiUVVOl0000Col`cc003o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000on4NhOoQ7^401ooQ7^400ol0003o/dbcok=</`08ok=</`03o`000?n7N8OoQgR700Co
QgR700?o0000ofjAK_m^TFh00om^TFh00ol0003oQGZ5ohEjQ@05ohEjQ@?o00001_nUFZD4o`00013o
PWf200?o0000oh9mP_n2OH803?n2OH800ol0003oLHiaog6>L@07og6>L@03o`000?mMXUgoGJ9M00Wo
GJ9M00?o0000ohm`Son?L8l02_n?L8l2o`0000KoYUVV00?o0000oh=lPon3O8<03?n3O8<00ol0003o
VFJIoiUVV@02oiUVV@03o`000?o<<lcoc3?<00ooc3?<00?o0000om`Sg?l000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003ohAkQon4Nh@08on4Nh@03o`000?ncC;?o/dbc00Wo/dbc00Co0000ohMhQon7N8Oo
QgR70_l00006ofjAKP03o`000?n5NXGoQGZ500SoQGZ50ol000000onUFZGo0000o`000004oh]dR`03
o`000?n2OH;oPWf200goPWf200?o0000oh9mP_n2OH803?n2OH800ol0003oLHiaog6>L@07og6>L@03
o`000?mMXUgoGJ9M00WoGJ9M00?o0000ohm`Son?L8l03?n?L8l00ol0003oYUVVojIIYP03o`0000ko
Pgb300?o0000oiUVVOnIIYT00onIIYT00ol0003oc3?<ol`cc00>ol`cc005o`000?oL8mcog2?Lom`S
g?l000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003ohAkQon4Nh@09on4Nh@03o`000?ncC;?o/dbc00[o
/dbc00?o0000ohMhQol000002?m^TFh00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n;M8_oRgB;00Go
RgB;00?o0000oh9mP_n2OH803?n2OH800ol0003oPWf2oh9mPP0<oh9mPP03o`000?maSW7oLHia00Oo
LHia00?o0000oefRGOmMXUd02?mMXUd2o`0000ooSg2?0_l00002oi=/T`03o`000?n3O8?oPgb300_o
Pgb300?o0000oiUVVOnIIYT01?nIIYT00ol0003oc3?<ol`cc00=ol`cc003o`000?oL8mcog2?L00?o
g2?L00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on4Nh@03o`000?ncC;?o/dbc00_o/dbc00?o0000ofjAK_m^TFh0
1om^TFh00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n;M8_oRgB;00KoRgB;00?o0000oh9mP_n2OH80
2on2OH82o`0000goPWf200?o0000og6>LOmaSW401omaSW400ol0003oGJ9MoefRG@07oefRG@04o`00
0?mYUVWoJIIYo`0000koSg2?00?o0000oi=/TonCK9<00_nCK9<00ol0003oPgb3oh=lP`09oh=lP`03
o`000?nIIYWoVFJI00KoVFJI00?o0000ol`cc?o<<l`02oo<<l`00ol0003og2?Lom`Sg005om`Sg004
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000SohAkQ00?o0000ok=</oncC;<02_ncC;<2o`0000Wo
KY5^00?o0000ohEjQOn5NXD02on5NXD00ol0003oRgB;oh]dR`07oh]dR`03o`000?n2OH;oPWf200Wo
PWf200Co0000odfbCOm=/Tgo00003?n2OH800ol0003oLHiaog6>L@07og6>L@03o`000?mMXUgoGJ9M
00KoGJ9M00Go0000ofVFJOmYUVWoJIIYo`00000>ohm`S`03o`000?nCK9?oTfbC00?oTfbC00?o0000
oh=lPon3O8<01on3O8<00ol0003oVFJIoiUVV@07oiUVV@03o`000?o<<lcoc3?<00[oc3?<00?o0000
om`Sg?oL8m`01ooL8m`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006on4Nh@03o`000?ncC;?o/dbc
00Wo/dbc00Co0000ohiaS_n>LHko00002Om^TFh00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?n;M8_o
RgB;00WoRgB;00?o0000oh9mP_n2OH801on2OH800ol0003oCK9=odfbC@02odfbC@03o`000?n2OH;o
PWf200WoPWf200?o0000og6>LOmaSW401omaSW400ol0003oGJ9MoefRG@05oefRG@03o`000?mYUVWo
JIIY00?oJIIY00?o0000ohm`Son?L8l02_n?L8l00ol0003oTfbCoi=/T`05oi=/T`03o`000?n3O8?o
Pgb300GoPgb300?o0000oiUVVOnIIYT02?nIIYT00ol0003oc3?<ol`cc009ol`cc003o`000?oL8mco
g2?L00Sog2?L00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oQ7^43o`0000Wo/dbc00?o0000ohia
S_n>LHh00_n>LHh00ol0003oKY5^ofjAKP06ofjAKP03o`000?n5NXGoQGZ500WoQGZ500?o0000oh]d
Ron;M8/02_n;M8/00ol0003oPWf2oh9mPP05oh9mPP03o`000?m=/TgoCK9=00CoCK9=00?o0000oh9m
P_n2OH802?n2OH800ol0003oLHiaog6>L@07og6>L@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000ofVF
JOmYUVT01?mYUVT00ol0003oSg2?ohm`S`0:ohm`S`03o`000?nCK9?oTfbC00KoTfbC00?o0000oh=l
Pon3O8<00on3O8<00ol0003oVFJIoiUVV@09oiUVV@03o`000?o<<lcoc3?<00Soc3?<00?o0000om`S
g?oL8m`02OoL8m`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omXUfP?o00001OncC;<00ol0003o
SW6>ohiaSP03ohiaSP03o`000?m^TFkoKY5^00KoKY5^00?o0000ohEjQOn5NXD02On5NXD00ol0003o
RgB;oh]dR`0;oh]dR`03o`000?n2OH;oPWf200?oPWf200?o0000odfbCOm=/Td01_m=/Td00ol0003o
PWf2oh9mPP08oh9mPP03o`000?maSW7oLHia00KoLHia00?o0000oefRGOmMXUd00_mMXUd2o`0000So
JIIY00?o0000ohm`Son?L8l02On?L8l00ol0003oTfbCoi=/T`07oi=/T`05o`000?n3O8?oPgb3oh=l
Pol000003OnIIYT00ol0003oc3?<ol`cc006ol`cc003o`000?oL8mcog2?L00[og2?L00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oJ9M[ofRGJ00GofRGJ0ol000000oncC;?o0000ohiaSP06ohiaSP03
o`000?m^TFkoKY5^00GoKY5^00?o0000ohEjQOn5NXD02On5NXD00ol0003oRgB;oh]dR`0<oh]dR`05
o`000?n2OH;oPWf2oh9mP_l000002_m=/Td00ol0003oPWf2oh9mPP07oh9mPP03o`000?maSW7oLHia
00KoLHia00?o0000oefRGOl000000_l000000onHIiSo0000ofVFJ@07ofVFJ@03o`000?n?L8ooSg2?
00SoSg2?00?o0000oi=/TonCK9<02OnCK9<00ol0003oPgb3o`00000=oiUVV@Co00001Oo<<l`00ol0
003og2?Lom`Sg00;om`Sg003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJomXUfP08omXUfP03
o`000?n>LHkoSW6>00OoSW6>00?o0000ofjAK_m^TFh01?m^TFh00ol0003oQGZ5ohEjQ@09ohEjQ@03
o`000?n;M8_oRgB;00goRgB;00?o0000oh9mP_l000003?m=/Td:o`0000OoLHia0ol00005oiQWV003
o`000?mYUVWoJIIY00KoJIIY00?o0000ohm`Son?L8l01on?L8l00ol0003oTfbCoi=/T`0:oi=/T`03
o`000?nIIYWoVFJI00_oVFJI00?o0000okM8]ongB;L00_ngB;L3o`000003ol`cc?l0003og2?L00_o
g2?L0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omXUf_oJ9MX02OoJ9MX00ol0003oSW6>ohiaSP07ohiaSP03o`00
0?m^TFkoKY5^00GoKY5^00?o0000ohEjQOn5NXD01on5NXD00ol0003oRgB;oh]dR`0?oh]dR`;o0000
2om=/Td00ol0003oSW6>ohiaSP07ohiaSP03o`000?maSW7oLHia00;oLHia0ol00008oiQWV003o`00
0?mYUVWoJIIY00KoJIIY00?o0000ohm`Son?L8l01on?L8l00ol0003oTfbCoi=/T`0:oi=/T`03o`00
0?nIIYWoVFJI00[oVFJI00?o0000okM8]ongB;L01_ngB;L00ol0003og2?Lom`Sg008om`Sg0?o0000
0_oV6NH00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omXUf_oJ9MX02OoJ9MX00ol0003oSW6>ohia
SP08ohiaSP03o`000?m^TFkoKY5^00CoKY5^00?o0000ohEjQOn5NXD01on5NXD00ol0003oRgB;oh]d
R`0>oh]dR`04o`000?mOX5ooGj1Oo`0000WoCK9=00?o0000ohiaS_n>LHh02On>LHh01?l0003oLHia
o`000?l0000<oiQWV003o`000?mYUVWoJIIY00KoJIIY00?o0000ohm`Son?L8l01_n?L8l00ol0003o
TfbCoi=/T`0;oi=/T`03o`000?nIIYWoVFJI00OoVFJI0_l00009okM8]`03o`000?oL8mcog2?L00Co
g2?L1?l00006onHIiP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003ofRGJomXUfP09omXUfP03o`00
0?n>LHkoSW6>00SoSW6>00?o0000ofjAK_m^TFh00om^TFh>o`0000goRgB;00?o0000oenPGomOX5l0
0_mOX5l00ol0003oCK9=odfbC@05odfbC@03o`000?n>LHkoSW6>00_oSW6>00?o0000oiQWV?nHIiP0
3?nHIiP00ol0003oJIIYofVFJ@06ofVFJ@03o`000?n?L8ooSg2?00GoSg2?00?o0000oi=/TonCK9<0
3?nCK9<00ol0003oVFJIoiUVV@06oiUVV@03o`000?ngB;Oo]dRg00[o]dRg00?o0000om`Sg?oL8m`0
0ol0000:onHIiP?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000ohiaS_n>LHh02?n>
LHh01Ol0003oKY5^ofjAK_m^TFko000000_oO8=l00?o0000ocS7>?lhacP00ol00009oh]dR`03o`00
0?mOX5ooGj1O00CoGj1O00?o0000odfbCOm=/Td00om=/Td00ol0003oSW6>ohiaSP0<ohiaSP03o`00
0?nHIiSoV6NH00goV6NH00?o0000ofVFJOmYUVT01_mYUVT00ol0003oSg2?ohm`S`03ohm`S`?o0000
3OnCK9<00ol0003oVFJIoiUVV@05oiUVV@03o`000?ngB;Oo]dRg00co]dRg0_l0000=onHIiP03o`00
0?ok1?_on`Ck00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000ohiaS_n>LHh02?n>
LHh4o`0000coO8=l00?o0000ocS7>?lhacP00olhacP3o`0000GoRgB;00?o0000oenPGomOX5l01_mO
X5l01Ol0003oCK9=odfbCOm=/Tgo000000ooSW6>00?o0000oiQWV?nHIiP03OnHIiP00ol0003oJIIY
ofVFJ@06ofVFJ@03o`000?n?L8ooSg2?00?o00000om]TVd00ol0003oTfbCoi=/T`0;oi=/T`03o`00
0?nIIYWoVFJI00?oVFJI00?o0000okM8]ongB;L03OngB;L00ol0003oiQWVonHIiP0;onHIiP03o`00
0?ok1?_on`Ck00Con`Ck0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omXUf_oJ9MX02_oJ9MX3o`0000KoSW6>0ol0
0003ohAkQ003o`000?mlPgcoO8=l00[oO8=l00?o0000ocS7>?lhacP01_lhacP3o`000003oh]dRol0
003oGj1O00WoGj1O00?o0000odfbCOl000004?n>LHh00ol0003oV6NHoiQWV00=oiQWV003o`000?mY
UVWoJIIY00OoJIIY0_l00007offBK@03o`000?nCK9?oTfbC00[oTfbC00Co0000oiUVVOnIIYWoVFJI
0ol0000?okM8]`03o`000?oV6NKoiQWV00_oiQWV00?o0000oo/4nook1?/01ook1?/4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omXUf_oJ9MX02_oJ
9MX01?l0003o`3o0ol0o`?o0?l02o`000004ohiaS_l0003o0000o`0000KoQ7^400?o0000ogb3O?ml
Pg`02_mlPg`00ol0003o><LhocS7>009ocS7>003o`000?mOX5ooGj1O00[oGj1O00?o0000ohiaS_n>
LHh03on>LHh00ol0003oV6NHoiQWV00>oiQWV003o`000?mYUVWoJIIY00KoJIIY00?o0000offBKOm]
TVd01om]TVd4o`0000SoTfbC00Co0000oiUVVOnIIYWo00000omgR7L2o`0000go]dRg00?o0000onHI
i_oV6NH02_oV6NH00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omXUf_oJ9MX02OoJ9MX00ol0003o
`3o0ol0o`004ol0o`003o`000?n4NhCoQ7^400OoQ7^400?o0000ogb3O?mlPg`02OmlPg`00ol0003o
><LhocS7>00:ocS7>003o`000?mOX5ooGj1O00[oGj1O00?o0000ohiaS_n>LHh03on>LHh00ol0003o
V6NHoiQWV00>oiQWV003o`000?mYUVWoJIIY00GoJIIY00?o0000offBKOm]TVd02?m]TVd01?l0003o
P7n0oh1oP?n0Oh07o`0000;oTfbC0_l00006ogN8M`;o00003?ngB;L00ol0003oiQWVonHIiP09onHI
iP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003ofRGJomXUfP08omXUfP03o`000?o0?l3o`3o000Go
`3o000?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oO8=logb3O008ogb3O003o`000?lhacSo><Lh00[o
><Lh00?o0000oenPGomOX5l02omOX5l00ol0003oSW6>ohiaSP0>ohiaSP03o`000?nHIiSoV6NH00ko
V6NH1Ol00002ofVFJ@03o`000?m]TVgoKI9]00WoKI9]00?o0000oh1oP?n0Oh002?n0Oh03o`0000Wo
MhQg0_l0000:okM8]`03o`000?oV6NKoiQWV00SoiQWV00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oJ9M[ofRGJ00SofRGJ00?o0000ol0o`?o0?l001oo0?l000ol0003oQ7^4ohAkQ007ohAkQ003o`00
0?mlPgcoO8=l00SoO8=l00?o0000ocS7>?lhacP02_lhacP00ol0003oGj1OoenPG`0:oenPG`;o0000
3_n>LHh3o`0000goV6NH0ol00005oiaSW0;o00002om]TVd00ol0003oP7n0oh1oP00;oh1oP0;o0000
2_mgR7L2o`0000Oo]dRg0ol00009onHIiP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:ol0o`003o`00
0?n4NhCoQ7^400OoQ7^400?o0000ogb3O?mlPg`02?mlPg`>o`0000WoGj1O0ol000000oln`Cko0000
ohiaSP0:ohiaSP?o00000_nPGj000ol0003oV6NHoiQWV009oiQWV0;o00002OnLHi`00ol0003oKI9]
offBK@09offBK@03o`000?n0Oh3oP7n000_oP7n000?o0000oi5^TOl000002omgR7L2o`0000Co]dRg
00Co0000omXUf_oJ9M[ofRGJ0_l00007onHIiP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003o`3o0
ol0o`009ol0o`003o`000?n4NhCoQ7^400KoQ7^400?o0000ogb3O?mlPg`02?mlPg`00ol0003oB;M8
odRgB00:odRgB003o`000?mOX5ooGj1O00CoGj1O0ol00005ock1?P03o`000?n>LHkoSW6>00CoSW6>
1?l00006oj1OX003o`000?nHIiSoV6NH00KoV6NH0_l0000;oiaSW003o`000?m]TVgoKI9]00WoKI9]
00?o0000oh1oP?n0Oh002_n0Oh001Ol0003oTFjAoi5^TOnAKY7o000000coMhQg0_l000000ongB;Oo
0000omXUfP05omXUfP03o`000?oV6NKoiQWV00?oiQWV00?o0000oo/4nook1?/02ook1?/00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o0?l3o`3o000So`3o000?o0000ohAkQ?n4Nh@01_n4Nh@00ol0003oO8=logb3O007ogb3O003o`00
0?m8]dSoB;M800_oB;M800?o0000oenPGomOX5l00_mOX5l2o`0000Wo?/4n00?o0000ohiaS_n>LHh0
0ol0000;oj1OX003o`000?nHIiSoV6NH00;oV6NH0ol0000>oiaSW003o`000?m]TVgoKI9]00OoKI9]
00?o0000oh1oP?n0Oh002on0Oh000ol0003oTFjAoi5^T@02oi5^T@03o`000?mgR7OoMhQg00_oMhQg
00?o0000omXUf_oJ9MX01_oJ9MX2o`0000?oiQWV00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o0
?l3o`3o000Oo`3o000?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oO8=logb3O005ogb3O0?o00003Om8
]dP4o`0000_o?/4n0ol0000?oj1OX004o`000?nHIiSo0000o`00017oW6>L00?o0000offBKOm]TVd0
1om]TVd00ol0003oP7n0oh1oP00:oh1oP003o`000?nAKY7oTFjA00CoTFjA00?o0000ogN8MomgR7L0
1omgR7L3o`0000_ofRGJ1?l0000=oo/4n`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol0o`?o0?l002?o0?l000ol0003oQ7^4ohAk
Q006ohAkQ003o`000?mlPgcoO8=l00;oO8=l0ol00003ofNHI`03o`000?m8]dSoB;M800[oB;M800?o
0000ock1?_ln`Ch02oln`Ch00ol0003oBkA;o`00000Aoj1OX003o`000?nLHicoW6>L017oW6>L00?o
0000offBKOm]TVd01om]TVd00ol0003oP7n0oh1oP00:oh1oP003o`000?nAKY7oTFjA00GoTFjA00Co
0000ogN8MomgR7OoMhQg1Ol00002ohacS003o`000?oJ9M[ofRGJ00WofRGJ00Co0000oo/4nook1?_o
n`Ck0ol00009oo/4n`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000ol0o`?o0?l001oo0?l000ol0003oQ7^4ohAkQ005ohAkQ0?o0000
00?oO8=lo`000?l000001omWV6L00ol0003oB;M8odRgB008odRgB0?o00002_ln`Ch2o`0000;oBkA;
00?o0000oj1OX?nPGj003onPGj000ol0003oW6>LoiaSW00AoiaSW003o`000?m]TVgoKI9]00OoKI9]
00?o0000oh1oP?n0Oh002On0Oh000ol0003oTFjAoi5^T@07oi5^T@?o00001on<Lh`00ol0003ofRGJ
omXUfP09omXUfP03o`000?ok1?_on`Ck00Con`Ck0_l00007oo/4n`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000ol0o`?o0?l001oo0
?l04o`0000;oQ7^40_l00003oi9]TP03o`000?mWV6OoIiQW00SoIiQW0_l00006odRgB0;o00000om@
[e000ol0003o?/4nock1?P06ock1?P03o`000?m;]4_oBkA;00?oBkA;00?o0000oj1OX?nPGj003_nP
Gj000ol0003oW6>LoiaSW00BoiaSW003o`000?m]TVgoKI9]00GoKI9]00?o0000oh1oP?n0Oh002On0
Oh000ol0003oTFjAoi5^T@08oi5^T@03o`000?n<LhcoS7><00OoS7><00?o0000omXUf_oJ9MX02?oJ
9MX00ol0003on`Ckoo/4n`07oo/4n`;o00001Ook1?/00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o0?l3o`3o000Co`3o00_l00004
om8]dP;o00001OnBKI800ol0003oIiQWofNHI`0:ofNHI`03o`000?m8]dSoB;M800;oB;M800?o0000
oe2_D?m@[e001?m@[e000ol0003o?/4nock1?P04ock1?P03o`000?m;]4_oBkA;00CoBkA;00?o0000
oj1OX?nPGj003_nPGj000ol0003oW6>LoiaSW00BoiaSW0[o00002_n0Oh000ol0003oTFjAoi5^T@08
oi5^T@03o`000?n<LhcoS7><00OoS7><00?o0000omXUf_oJ9MX02?oJ9MX00ol0003on`Ckoo/4n`09
oo/4n`?o000000?on`Cko`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o`3o0ol0o`?o0?l02o`0000OodRgB00?o0000oi9]T_nBKI801?nBKI80
0ol0003oIiQWofNHI`0:ofNHI`04o`000?m8]dSo0000o`0000SoD:m@00Co0000ock1?_ln`Cko?/4n
0_l00007od^dB`03o`000?nPGj3oX5nP00koX5nP00?o0000oiaSW?nLHi`04_nLHi`00ol0003oNhAk
og^4N`07og^4N`03o`000?n0Oh3oP7n000KoP7n000?o0000oi5^TOnAKY402_nAKY400ol0003oS7><
ohacS006ohacS003o`000?oJ9M[ofRGJ00SofRGJ00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o0
?l3o0000o`0000WodRgB00?o0000oi9]T_nBKI801?nBKI800ol0003oIiQWofNHI`0;ofNHI`03o`00
0?m@[e3oD:m@00WoD:m@00?o0000ock1?_l000002Om;]4/00ol0003oX5nPoj1OX00>oj1OX0;o0000
4_nLHi`00ol0003oNhAkog^4N`09og^4N`;o00001_n0Oh000ol0003oTFjAoi5^T@0:oi5^T@03o`00
0?n<LhcoS7><00KoS7><00?o0000omXUf_oJ9MX02?oJ9MX00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om8]d_oB;M802OoB;M800ol0003oTVfBoi9]TP05oi9]TP03o`000?mWV6OoIiQW00[oIiQW00?o
0000oe2_D?m@[e002_m@[e02o`0000WoBkA;00?o0000oj1OX?nPGj003_nPGj000ol0003oRWF:o`00
0002o`0000ooW6>L00?o0000og^4NomkQ7/02omkQ7/00ol0003oP7n0oh1oP003o`0000goTFjA00?o
0000ohacS?n<Lh`01_n<Lh`00ol0003ofRGJomXUfP07omXUfP03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odRgBom8]dP09om8]dP03o`000?nBKI;oTVfB00GoTVfB00?o0000ofNHIomWV6L02OmWV6L2
o`0000_oD:m@0_l0000;od^dB`03o`000?nPGj3oX5nP00coX5nP00?o0000ohYeR_n:MHX00on:MHX3
o`0000coW6>L00?o0000og^4NomkQ7/03?mkQ7/2o`0000;oNhAk00?o0000oi5^TOnAKY403?nAKY40
0ol0003oS7><ohacS005ohacS003o`000?oJ9M[ofRGJ00OofRGJ00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oB;M;odRgB00[odRgB00?o0000oi9]T_nBKI801_nBKI800ol0003oIiQWofNHI`07ofNH
I`03o`000?mDZeCo000000[oD:m@00Co0000oc_4>olka3_o00002_m;]4/00ol0003oX5nPoj1OX00<
oj1OX003o`000?n:MH[oRWF:00KoRWF:0_l00008oiaSW0;o00003omkQ7/00ol0003oNhAkog^4N`02
og^4N`03o`000?nAKY7oTFjA00_oTFjA00?o0000ohacS?n<Lh`01On<Lh`00ol0003ofRGJomXUfP07
omXUfP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odRgBom8]dP0:om8]dP03o`000?nBKI;oTVfB
00KoTVfB00?o0000ofNHIomWV6L01_mWV6L01Ol0003oE:]DoeB[E?mDZeCo000000SoD:m@00?o0000
oc_4>olka3/00_lka3/00ol0003oBkA;od^dB`06od^dB`Co00003?nPGj000ol0003oRWF:ohYeRP08
ohYeRP?o00000_nLHi`3o`000003ogN8Mol0003oNhAk00goNhAk00?o0000og^4NomkQ7/01?mkQ7/0
0ol0003oTFjAoi5^T@0:oi5^T@03o`000?n<LhcoS7><00GoS7><00?o0000omXUf_oJ9MX01_oJ9MX0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om8]d_oB;M802ooB;M800ol0003oTVfBoi9]TP07oi9]
TP03o`000?mWV6OoIiQW00?oIiQW0_l00005oeB[E003o`000?m@[e3oD:m@00CoD:m@00?o0000oc_4
>olka3/00olka3/00ol0003oBkA;od^dB`05od^dB`03o`000?m/TfcoK9=/00;oK9=/0ol00007oj1O
X0;o00003_n:MHX2o`0000GoMhQg00?o0000og^4NomkQ7/02_mkQ7/00ol0003oNhAkog^4N`05og^4
N`03o`000?nAKY7oTFjA00_oTFjA00?o0000ohacS?n<Lh`01?n<Lh`00ol0003ofRGJomXUfP06omXU
fP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odRgBom8]dP0;om8]dP03o`000?nBKI;oTVfB00Oo
TVfB00?o0000ofNHIomWV6L00_mWV6L00ol0003oE:]DoeB[E006oeB[E003o`000?m@[e3oD:m@00;o
D:m@00?o0000oc_4>olka3/01Olka3/00ol0003oBkA;od^dB`02od^dB`;o00002?m/Tf`3o`0000;o
X5nP0_l000000omeRWGo0000ohYeRP0=ohYeRP03o`000?mgR7OoMhQg00GoMhQg00?o0000og^4Nomk
Q7/02?mkQ7/00ol0003oNhAkog^4N`07og^4N`03o`000?nAKY7oTFjA00[oTFjA00?o0000ohacS?n<
Lh`01?n<Lh`00ol0003ofRGJomXUfP06omXUfP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odRgB
om8]dP0<om8]dP03o`000?nBKI;oTVfB00SoTVfB00Co0000ofNHIomWV6Oo00002OmDZe@01Ol0003o
D:m@oe2_D?m@[e3o000000So>l@k00Go0000od^dBom;]4_oBkA;o`00000=ofbCK0;o00001?meRWD0
0ol0003oRWF:ohYeRP0;ohYeRP03o`000?mgR7OoMhQg00KoMhQg00?o0000og^4NomkQ7/01omkQ7/0
0ol0003oNhAkog^4N`08og^4N`Co00002?nAKY400ol0003oS7><ohacS004ohacS003o`000?oJ9M[o
fRGJ00KofRGJ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oB;M;odRgB00_odRgB0ol00009oi9]
TP03o`000?mWV6Oo000000_oE:]D00?o0000oe2_D?l000002_lka3/00ol0003oBkA;o`00000?ofbC
K003o`000?meRWGoMHYe00;oMHYe00?o0000ohYeR_n:MHX02on:MHX00ol0003oMhQgogN8M`06ogN8
M`03o`000?mkQ7_oNhAk00KoNhAk00?o0000og^4NomkQ7/02OmkQ7/01?l0003oUfRGoiMXUonGJ9L7
o`0000;oTFjA00?o0000ohacS?n<Lh`00on<Lh`00ol0003ofRGJomXUfP05omXUfP03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oB;M;odRgB00SodRgB0ol00003oke2_@03o`000?nBKI;oTVfB00OoTVfB00?o0000oeB[
E?mDZe@02omDZe@00ol0003o>l@koc_4>`0:oc_4>`03o`000?m/TfcoK9=/00goK9=/00?o0000ogF:
MOmeRWD01?meRWD00ol0003oRWF:ohYeRP09ohYeRP03o`000?mgR7OoMhQg00SoMhQg00?o0000og^4
NomkQ7/00omkQ7/2o`0000coNhAk00?o0000oiMXUonGJ9L02?nGJ9L<o`0000?ofRGJ0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om8]d_oB;M801_oB;M83o`0000Oo_D:m00?o0000oi9]T_nBKI801_nBKI800ol0003o
E:]DoeB[E00;oeB[E003o`000?lka3_o>l@k00Wo>l@k0_l0000>ofbCK003o`000?meRWGoMHYe00Go
MHYe00?o0000ohYeR_n:MHX02On:MHX00ol0003oMhQgogN8M`09ogN8M`03o`000?mkQ7_o000000;o
00000_mbSG800ol0003oNhAkog^4N`08og^4N`03o`000?nGJ9OoUfRG00coUfRG00?o0000om/TfooK
9=/01_oK9=/3o`0000?onPGj0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odRgBom8]dP03om8]dP?o00002onm@[d00ol0003oTVfB
oi9]TP04oi9]TP03o`000?mDZeCoE:]D00_oE:]D0ol00007oc_4>`?o000000?oGZ5No`000?m/Tf`0
3Om/Tf`00ol0003oMHYeogF:M@06ogF:M@03o`000?n:MH[oRWF:00SoRWF:00?o0000ogN8MomgR7L0
2_mgR7L00ol0003oLXebog:=LP04og:=LP03o`000?mkQ7_oNhAk00OoNhAk00?o0000oiMXUonGJ9L0
2onGJ9L00ol0003ofbCKom/Tf`08om/Tf`03o`000?oj1O[onPGj00ConPGj0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om8]d_l0
003o0000o`0000oo_D:m00?o0000oi9]T_nBKI800onBKI8>o`0000?oDjaC0_l00002oc_4>`?o0000
1OmNXEh00ol0003oK9=/ofbCK00:ofbCK003o`000?meRWGoMHYe00OoMHYe00?o0000ohYeR_n:MHX0
2?n:MHX00ol0003oMhQgogN8M`0:ogN8M`03o`000?mbSG;oLXeb00GoLXeb00?o0000og^4NomkQ7/0
1_mkQ7/00ol0003oUfRGoiMXU`0;oiMXU`03o`000?oK9=_ofbCK00SofbCK00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o_D:m00?o0000oi9]T_nBKI800_nBKI800ol0003oDJiAoe6^
D@0:oe6^D@03o`000?mC[5?oDjaC00?oDjaC0_l00009oejQGP03o`000?m/TfcoK9=/00WoK9=/00?o
0000ogF:MOmeRWD02?meRWD2o`0000SoRWF:00?o0000ogN8MomgR7L02OmgR7L00ol0003oLXebog:=
LP07og:=LP03o`000?mkQ7_oNhAk00CoNhAk00?o0000oiMXUonGJ9L02onGJ9L00ol0003ofbCKom/T
f`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o_D:moke2_@0?oke2_@?o000000?oTVfB
o`000?mA[U402omA[U400ol0003oDjaCoe>/D`04oe>/D`03o`000?mNXEkoGZ5N00WoGZ5N00?o0000
ofbCK?m/Tf`01om/Tf`00ol0003oMHYeogF:M@09ogF:M@04o`000?m_T6oo0000o`0000KoRWF:00?o
0000ogN8MomgR7L02OmgR7L00ol0003oLXebog:=LP08og:=LP03o`000?mkQ7_oNhAk00?oNhAk00?o
0000oiMXUonGJ9L02onGJ9L00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o_D:moke2_@0<oke2_@;o00000ondBk@2o`0000coDJiA00?o0000oe>/DomC[5<01?mC[5<0
0ol0003oGZ5NoejQGP0:oejQGPWo00002omeRWD00ol0003oKi1_ofn@K`02ofn@K`?o00000_n:MHX0
0ol0003oMhQgogN8M`0:ogN8M`03o`000?mbSG;oLXeb00WoLXeb00?o0000og^4NomkQ7/00_mkQ7/0
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_nm@[d2o`0000Go]4^d00?o0000oh9mP_l000002_mA[U400ol0003oDjaCoe>/D`06oe>/
D`03o`000?mNXEkoGZ5N00WoGZ5N00?o0000oenPGomOX5l01OmOX5l00ol0003oMHYeogF:M@09ogF:
M@03o`000?m_T6ooKi1_00GoKi1_0ol00009ogN8M`?o00003OmbSG801Ol0003oNhAkog^4NomkQ7_o
000000coUfRG00?o0000om/TfooK9=/02OoK9=/00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000oke2
_Onm@[d01Onm@[d2o`0000Oo]4^d00Co0000oh9mP_n2OH;o00002OmA[U400ol0003oDjaCoe>/D`06
oe>/D`03o`000?mNXEkoGZ5N00SoGZ5N00?o0000oenPGomOX5l01omOX5l00ol0003oMHYeogF:M@07
ogF:M@03o`000?m_T6ooKi1_00SoKi1_0ol00002ogN8M`Go00000_m7^4L00ol0003oLXebog:=LP0<
og:=LP03o`000?mkQ7_o000000coUfRG00?o0000om/TfooK9=/02_oK9=/00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000oke2_Onm@[d00_nm@[d2o`0000So]4^d00?o0000oh9mP_n2OH800_n2OH85o`00
00CoDJiA00?o0000oe>/DomC[5<01_mC[5<00ol0003oGZ5NoejQGP08oejQGP03o`000?mOX5ooGj1O
00OoGj1O00?o0000ogF:MOmeRWD01omeRWD00ol0003oKi1_ofn@K`08ofn@K`03o`000?m5^TGoAKY5
00;o00002?m7^4L00ol0003oLXebog:=LP0<og:=LPCo00002_nGJ9L00ol0003ofbCKom/Tf`0:om/T
f`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o_D:mo`000?l0000:okA;]003o`000?n2OH;oPWf2
00;oPWf200?o0000obCK9?lTfb@00_lTfb@4o`0000WoDjaC00?o0000oejQG_mNXEh02?mNXEh00ol0
003oGj1OoenPG`08oenPG`03o`000?meRWGoMHYe00GoMHYe00?o0000ofn@Kom_T6l02?m_T6l01Ol0
003oAKY5odFjAOm5^TGo000000[oAkQ70ol0000;og:=LP04o`000?o4>lCoa3_4ol@ka0Co00001OnG
J9L00ol0003ofbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o]4^dokA;]00:
okA;]003o`000?n2OH;oPWf200?oPWf200?o0000obCK9?lTfb@01?lTfb@00ol0003oDjaCoe>/D`07
oe>/D`03o`000?mNXEkoGZ5N00KoGZ5N0_l0000;oenPG`03o`000?meRWGoMHYe00GoMHYe00?o0000
ofn@Kom_T6l02?m_T6l00ol0003oAKY5odFjA@02odFjA@03o`000?m7^4OoAkQ700OoAkQ700?o0000
ogj1O_mnPGh01?l00006og:=LP03o`000?o4>lCoa3_400Koa3_40ol00002oiMXU`03o`000?oK9=_o
fbCK00_ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?ndBkCo]4^d00Wo]4^d00?o0000oh9m
P_n2OH801?n2OH800ol0003o9=/TobCK9005obCK9003o`000?mC[5?oDjaC00OoDjaC00?o0000oejQ
G_mNXEh00_mNXEh3o`000003of^DJol0003oGj1O00[oGj1O00?o0000ogF:MOmeRWD01OmeRWD00ol0
003oKi1_ofn@K`07ofn@K`03o`000?m5^TGoAKY500?oAKY500?o0000odNhAom7^4L01om7^4L00ol0
003oOX5nogj1OP04ogj1OP?o00000_mbSG800ol0003oa3_4ol@ka00:ol@ka0;o00003_oK9=/00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000okA;]?ndBk@02OndBk@00ol0003oPWf2oh9mPP04oh9mPP03
o`000?lTfbCo9=/T00Ko9=/T0_l00007oe>/D`03o`000?mNXEko000000;o00001Om[U6/00ol0003o
Gj1OoenPG`08oenPG`?o00001?meRWD00ol0003oKi1_ofn@K`08ofn@K`03o`000?m5^TGoAKY500Co
AKY500?o0000odNhAom7^4L01_m7^4L00ol0003oOX5nogj1OP07ogj1OP;o00003_o4>l@00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]4^dokA;]008okA;]003o`00
0?n2OH;oPWf200GoPWf200?o0000obCK9?lTfb@01?lTfb@00ol0003oEJYEoeFZE@03o`0000CoDjaC
0_l00008of^DJ`03o`000?mOX5ooGj1O00OoGj1O00Co0000ohiaS_n>LHkoSW6>0ol000000omeRWGo
0000ofn@K`09ofn@K`03o`000?m5^TGoAKY500CoAKY500?o0000odNhAom7^4L01Om7^4L00ol0003o
OX5nogj1OP09ogj1OP03o`000?o4>lCoa3_400goa3_400?o0000om/TfooK9=/02_oK9=/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000okA;]?ndBk@01ondBk@00ol0003oPWf2oh9mPP06oh9mPP03o`00
0?lTfbCo9=/T00?o9=/T00?o0000oeFZEOmEZUD01?mEZUD2o`000003oe>/Dol0003oJiA[00[oJiA[
00?o0000oenPGomOX5l01OmOX5l00ol0003oSW6>ohiaSP05ohiaSP03o`000?m_T6ooKi1_00OoKi1_
0ol00007odFjA@03o`000?m7^4OoAkQ700CoAkQ700?o0000ogj1O_mnPGh02OmnPGh00ol0003oa3_4
ol@ka00=ol@ka003o`000?oK9=_ofbCK00[ofbCK00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nd
BkCo]4^d00Go]4^d0ol00009oh9mPP05o`000?lTfbCo9=/TobCK9?l000002OmEZUD00ol0003oJiA[
of^DJ`0;of^DJ`03o`000?mOX5ooGj1O00?oGj1O00?o0000ohiaS_n>LHh01_n>LHh00ol0003oKi1_
ofn@K`06ofn@K`05o`000?mcS7?oLhacog><Lol000001om5^TD00ol0003oAkQ7odNhA`03odNhA`03
o`000?mnPGkoOX5n00WoOX5n00?o0000ol@ka?o4>l@03_o4>l@00ol0003ofbCKom/Tf`09om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]4^do`000004o`0000;odRgB00?o0000oh9mP_n2OH80
1on2OH801?l0003o9=/TobCK9?l00009oeFZE@;o00003Om[U6/00ol0003oGj1OoenPG`02oenPG`03
o`000?n>LHkoSW6>00SoSW6>00?o0000ofn@Kom_T6l00om_T6l2o`0000GoLhac00?o0000odFjAOm5
^TD01?m5^TD00ol0003oAkQ7odNhA`03odNhA`03o`000?mnPGkoOX5n00WoOX5n00?o0000ol@ka?o4
>l@03_o4>l@00ol0003ofbCKom/Tf`09om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SodRgB
00?o0000oh9mP_n2OH801_n2OH800ol0003o9=/To`000009oeFZE@04o`000?mlPgcoO8=lo`0000go
JiA[00Co0000oenPGomOX5oo00003?n>LHh01Ol0003oKi1_ofn@Kom_T6oo000000SoLhac0_l00005
odFjA@03o`000?m7^4OoAkQ700;oAkQ700?o0000ogj1O_mnPGh02OmnPGh00ol0003oa3_4ol@ka00>
ol@ka003o`000?oK9=_ofbCK00WofbCK00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oB;M;odRgB
00OodRgB00?o0000oh9mP_n2OH801on2OH800ol0003oEJYEoeFZE@07oeFZE@03o`000?mlPgcoO8=l
00;oO8=l00?o0000of^DJom[U6/02_m[U6/00ol0003oGj1Oo`00000>ohiaSP03o`000?m_T6oo0000
00_oLhac00?o0000odFjAOm5^TD00_m5^TD01Ol0003oAkQ7odNhAom7^4Oo000000coOX5n00?o0000
ol@ka?o4>l@03_o4>l@3o`0000WofbCK00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oB;M;odRgB
00WodRgB00?o0000oh9mP_n2OH801_n2OH800ol0003oEJYEoeFZE@06oeFZE@03o`000?mlPgcoO8=l
00?oO8=l00?o0000of^DJom[U6/02om[U6/00ol0003oSW6>ohiaSP0>ohiaSP03o`000?mcS7?oLhac
00_oLhac0_l00003odFjA@04o`000?m7^4OoAkQ7o`0000[oOX5n0ol0000>ol@ka0;o00000ooj1OX2
o`0000OofbCK00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oB;M;odRgB00[odRgB00?o0000oh9m
P_n2OH801?n2OH800ol0003oEJYEoeFZE@06oeFZE@03o`000?mlPgcoO8=l00GoO8=l00?o0000of^D
Jom[U6/01om[U6/3o`00017oSW6>00?o0000og><LomcS7<03OmcS7<01Ol0003oAKY5odFjAOl0003o
AkQ700Co00000omnPGh5o`0000;o`3o000?o0000ol@ka?o4>l@02_o4>l@2o`0000OonPGj0_l00004
om/Tf`03o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odRgBom8]dP0;om8]dP03o`000?n2OH;oPWf2
00CoPWf200?o0000oeFZEOmEZUD01OmEZUD00ol0003oO8=logb3O006ogb3O003o`000?m[U6_oJiA[
00CoJiA[0ol00002ogR7N003o`000?n>LHkoSW6>00ooSW6>0_l0000?og><L`04o`000?m5^TGo0000
o`0000CoLXeb0ol00008ol0o`003o`000?o4>lCoa3_400Ooa3_40_l0000;ooX5nP;o00000_oK9=/0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om8]d_oB;M803?oB;M86o`0000OoEJYE00?o0000ogb3
O?mlPg`02?mlPg`00ol0003oJiA[of^DJ`03o`0000KoN8Mh00?o0000ohiaS_n>LHh03On>LHh01?l0
003oQWV6ohIiQ_l0000?og><L`03o`000?mbSG;oLXeb00GoLXeb00?o0000ol0o`?o0?l002?o0?l00
0ol0003oa3_4ol@ka005ol@ka003o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oB;M800ol0003oQWV6ohIiQP04ohIi
QP03o`000?mEZUGoEJYE00?oEJYE00?o0000ogb3O?mlPg`02_mlPg`2o`0000[oN8Mh00?o0000ohia
S_n>LHh02on>LHh00ol0003oQWV6ohIiQP02ohIiQP03o`000?mcS7?oLhac00_oLhac0_l00007og:=
LP03o`000?o0?l3o`3o000Wo`3o000?o0000ol@ka?o4>l@00_o4>l@2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om8]d_oB;M802ooB;M800ol0003oQWV6ohIiQP06ohIiQP05o`000?mEZUGoEJYEoeFZ
EOl000003OmlPg`00ol0003oN8MhogR7N00:ogR7N003o`000?n>LHkoSW6>00WoSW6>00?o0000ohIi
Q_n6NHH01?n6NHH00ol0003oLhacog><L`08og><L`;o000000?oB[E:o`000?mbSG801ombSG800ol0
003o`3o0ol0o`009ol0o`004o`000?o4>lCo0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oB;M;odRgB
00WodRgB00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oEJYEo`00000=ogb3O003o`000?mhQgSoN8Mh
00_oN8Mh00?o0000ohiaS_n>LHh02?n>LHh00ol0003oQWV6ohIiQP06ohIiQP03o`000?mcS7?oLhac
00GoLhac0_l00003odZeBP03o`000?mbSG;oLXeb00KoLXeb00?o0000ol0o`?o0?l002_o0?l000ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003odRgBom8]dP07om8]dP03o`000?n6NHKoQWV600[oQWV600?o0000ogb3O?ml
Pg`03?mlPg`00ol0003oN8MhogR7N00<ogR7N003o`000?n>LHkoSW6>00KoSW6>00?o0000ohIiQ_n6
NHH02?n6NHH00ol0003oLhacog><L`02og><L`;o00001_m:]DX00ol0003oLXebog:=LP05og:=LP03
o`000?o0?l3o`3o000[o`3o000?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oB;M;odRgB00GodRgB
00?o0000ohIiQ_n6NHH03?n6NHH2o`0000coO8=l00?o0000ogR7N?mhQgP03OmhQgP00ol0003oSW6>
ohiaSP04ohiaSP03o`000?n6NHKoQWV600[oQWV600Co0000og><Lol0003o00002?m:]DX00ol0003o
LXebog:=LP06og:=LP03o`000?o0?l3o`3o000Wo`3o000?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oB;M800ol0003oQWV6ohIiQP0=ohIiQP03o`000?mbSG;o000000;o00002?mlPg`00ol0003oN8Mh
ogR7N00?ogR7N0Ko00003_n6NHH00ol0003oB[E:odZeBP08odZeBP03o`000?mbSG;oLXeb00KoLXeb
00?o0000ol0o`?o0?l002Oo0?l000ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000om4^dOoA;]7odBkA
0_l0000?ohIiQP03o`000?mbSG;oLXeb00?oLXeb0ol00005ogb3O0;o00004?mhQgP01_l0003oIIYU
ofFJIOl0003oCK9=o`0000koQWV600?o0000odZeB_m:]DX02Om:]DX00ol0003oLXebog:=LP05og:=
LP03o`000?o0?l3o`3o000Wo`3o000?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000om4^dOoA;]400ooA;]400ol0003o
QWV6ohIiQP0=ohIiQP03o`000?mbSG;oLXeb00KoLXeb0ol000001?mlPgco0000ofbCK?m/Tf`3o`00
00coN8Mh00Go0000ofFJIOmUVVGoIIYUo`000002odfbC@03o`000?n6NHKoQWV600_oQWV600?o0000
odZeB_m:]DX02Om:]DX00ol0003oLXebog:=LP06og:=LP03o`000?o0?l3o`3o000So`3o00_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003odBkAom4^d@04om4^d@oo00003?mbSG800ol0003oK9=/ofbCK004ofbC
K0?o00002?mhQgP00ol0003oIIYUofFJI@02ofFJI@05o`000?m=/TgoCK9=odfbCOl000003?n6NHH0
0ol0003oB[E:odZeBP09odZeBP03o`000?mbSG;oLXeb00GoLXeb3?l00002on8MhP;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003odBkAom4^d@05om4^d@03o`000?m`Sg3oL8m`00_oL8m`00?o0000og:=
L_mbSG802_mbSG800ol0003oK9=/ofbCK007ofbCK0;o00001OmhQgP00ol0003oIIYUofFJI@03ofFJ
I@03o`000?m=/TgoCK9=00;oCK9=00?o0000ohIiQ_n6NHH02On6NHH00ol0003oB[E:odZeBP0:odZe
BP03o`000?mbSG;oLXeb00?oLXeb00?o0000ohQgR?n8MhP02On8MhP00ol0003ohQgRon8MhP02on8M
hP;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003odBkAom4^d@06om4^d@03o`000?m`Sg3oL8m`00[o
L8m`00?o0000og:=L_mbSG802ombSG800ol0003oK9=/ofbCK009ofbCK0?o000000?oN8Mho`000?mU
VVD01OmUVVD00ol0003oCK9=odfbC@03odfbC@03o`000?n6NHKoQWV600SoQWV63_l00003og:=LP;o
00002on8MhP00ol0003ohQgRon8MhP05on8MhP03o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000om4^dOoA;]401OoA;]400ol0003oQGZ5o`00000;og2?L003o`000?mbSG;oLXeb00[oLXeb
0_l0000>ofbCK003o`000?mUVVGoIIYU00GoIIYU00?o0000odfbCOm=/Td00om=/Td00ol0003oQWV6
ohIiQP08ohIiQP03o`000?mhQgSoN8Mh00_oN8Mh00?o0000og:=L_l000003On8MhP00ol0003ohQgR
on8MhP06on8MhP;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oA;]7odBkA00KodBkA00Co
0000ohEjQOn5NXGo00002_m`Sg000ol0003oLXebog:=LP09og:=LP03o`000?mYUVWo000000koK9=/
00?o0000ofFJIOmUVVD01OmUVVD00ol0003oCK9=odfbC@04odfbC@03o`000?n6NHKoQWV600KoQWV6
00?o0000ogR7N?mhQgP03OmhQgP00ol0003oR7N8ohQgR00<ohQgR003o`000?oR7N;ohQgR00SohQgR
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oA;]7odBkA00GodBkA00?o0000ohEjQOn5NXD00_n5
NXD00ol0003oL8m`og2?L006og2?L003o`000?mbSG;oLXeb00SoLXeb0_l00003ofVFJ@03o`000?m/
TfcoK9=/00_oK9=/00?o0000ofFJIOmUVVD01OmUVVD00ol0003oCK9=odfbC@05odfbC@03o`000?n6
NHKoQWV600GoQWV600?o0000ogR7N?mhQgP03OmhQgP00ol0003oR7N8ohQgR00;ohQgR003o`000?oR
7N;ohQgR00WohQgR00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000
ohEjQOn5NXD00on5NXD00ol0003oL8m`og2?L005og2?L003o`000?mbSG;oLXeb00OoLXeb00?o0000
ofVFJOmYUVT00omYUVT00ol0003oK9=/ofbCK00:ofbCK003o`000?mUVVGoIIYU00KoIIYU00?o0000
odfbCOm=/Td01_m=/Td00ol0003oQWV6ohIiQP04ohIiQP03o`000?mhQgSoN8Mh00goN8Mh3ol0000;
on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000ohEjQOn5NXD01On5NXD00ol0
003oL8m`og2?L004og2?L003o`000?mbSG;oLXeb00GoLXeb0_l00006ofVFJ@03o`000?m/TfcoK9=/
00WoK9=/0_l00008ofFJI@03o`000?m=/TgoCK9=00KoCK9=1Ol000000on6NHKo0000ogR7N00?ogR7
N003o`000?n3O8?oPgb300_oPgb300?o0000on8Mh_oR7N802OoR7N800ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?oA;]7odBkA00KodBkA00?o0000ohEjQOn5NXD01_n5NXD00ol0003o
L8m`og2?L004o`0000KoLXeb00?o0000ofVFJOmYUVT01omYUVT00ol0003oK9=/ofbCK005ofbCK0?o
000000?oEjQGo`000?mUVVD01omUVVD00ol0003oCK9=odfbC@05odfbC@03o`000?n8MhSoR7N800?o
R7N80_l0000?ogR7N0;o00003On3O8<00ol0003ohQgRon8MhP08on8MhP03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WodBkA00?o0000ohEjQOn5NXD01on5NXD2o`0000CoV6NH00Co0000og:=L_mbSG;o
LXeb0_l0000:ofVFJ@03o`000?m/TfcoK9=/00;oK9=/0ol00005oeNXE`03o`000?mUVVGoIIYU00Go
IIYU00?o0000odfbCOm=/Td01?m=/Td00ol0003oR7N8ohQgR006ohQgR003o`000?mhQgSoN8Mh00[o
N8Mh0_l00002oh5nP@03o`000?n3O8?oPgb300[oPgb300?o0000on8Mh_oR7N802?oR7N800ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000om4^dOoA;]401_oA;]400ol0003oQGZ5ohEjQ@08ohEjQ@03o`00
0?nHIiSoV6NH00CoV6NH00?o0000og:=L_l000003?mYUVT00ol0003oK9=/o`000002o`0000WoEjQG
00?o0000ofFJIOmUVVD01?mUVVD00ol0003oCK9=odfbC@03odfbC@03o`000?n8MhSoR7N800SoR7N8
1_l00004ogR7N0;o00001On1OX400ol0003oPgb3oh=lP`09oh=lP`03o`000?oR7N;ohQgR00SohQgR
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oA;]7odBkA00GodBkA00?o0000ohEjQOn5NXD01on5
NXD00ol0003oV6NHoiQWV006oiQWV003o`000?mYUVWoJIIY00coJIIY00?o0000oeNXEomGZ5L02_mG
Z5L00ol0003oIIYUofFJI@04ofFJI@04o`000?m=/TgoCK9=odfbC@;o00002on8MhP00ol0003oQGZ5
ohEjQ@03ohEjQ@Co00002?n1OX400ol0003oPgb3oh=lP`08oh=lP`03o`000?oR7N;ohQgR00OohQgR
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000om4^dOoA;]400ooA;]400ol0003oQGZ5ohEjQ@07ohEjQ@03o`000?nH
IiSoV6NH00OoV6NH00?o0000ofVFJOmYUVT03?mYUVT00ol0003oEjQGoeNXE`0;oeNXE`03o`000?mU
VVGoIIYU00?oIIYU00Co0000odfbCOm=/Tgo00003On8MhP00ol0003oQGZ5ohEjQ@06ohEjQ@03o`00
0?n1OX7oPGj100OoPGj100?o0000oh=lPon3O8<01on3O8<00ol0003ohQgRon8MhP06on8MhP04o`00
0?ok1?_on`Ckoo/4n`;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oA;]7odBkA00;odBkA00?o0000ohEjQOn5NXD0
1_n5NXD00ol0003oV6NHoiQWV009oiQWV003o`000?mYUVWoJIIY00WoJIIY0_l0000>oeNXE`?o0000
0omUVVD00ol0003oCK9=o`00000=ohQgR003o`000?n5NXGoQGZ500OoQGZ500?o0000oh5nPOn1OX40
2?n1OX4:o`0000KohQgR0_l00006oo/4n`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoQGZ500?o
0000oiQWV?nHIiP02_nHIiP00ol0003oJIIYofVFJ@06ofVFJ@;o000000?oJIIYo`000?mGZ5L02omG
Z5L2o`0000?oR7N81Ol0000>ohQgR003o`000?n5NXGoQGZ500OoQGZ500?o0000oh5nPOn1OX402?n1
OX400ol0003oY5^TojAKY006ojAKY003o`000?oR7N;ohQgR00?ohQgR00?o0000oo/4nook1?/01ook
1?/2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003ob3O8olPgb003olPgb0Co00000_n5NXD00ol0003oV6NHoiQWV00;
oiQWV003o`000?mYUVWoJIIY00?oJIIY0ol00004ofVFJ@03o`000?mGZ5OoEjQG00OoEjQG0_l00008
ohQgR003o`000?n8MhSoR7N800goR7N800?o0000ohEjQOn5NXD02?n5NXD00ol0003oPGj1oh5nP@07
oh5nP@03o`000?nTFjCoY5^T00OoY5^T0ol000000ooR7N;o0000oo/4n`0;oo/4n`;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o8=lSob3O800Oob3O80_l0000?oiQWV003o`000?mYUVWoJIIY00;o00002?mYUVT00ol0
003oEjQGoeNXE`05oeNXE`03o`000?n8MhSoR7N800SoR7N800?o0000ohQgR?n8MhP03On8MhP00ol0
003oQGZ5ohEjQ@08ohEjQ@03o`000?n1OX7oPGj100KoPGj100?o0000ojAKY?nTFj@02?nTFj@01?l0
003ohAkQon4NhOl0000?oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ob3O8olPgb009olPg
b003o`000?nHIiSoV6NH00koV6NH0_l0000;ofVFJ@03o`000?mGZ5OoEjQG00;oEjQG0_l0000;ohQg
R003o`000?n8MhSoR7N800goR7N800?o0000ohEjQOn5NXD02?n5NXD00ol0003oPGj1oh5nP@06oh5n
P@03o`000?nTFjCoY5^T00OoY5^T00Go0000on4NhOoQ7^7ohAkQo`00000@oo/4n`;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003ob3O8olPgb00:olPgb003o`000?nHIiSoV6NH00goV6NH0_l0000<ofVFJ@04o`000?mGZ5Oo0000
o`0000goR7N800?o0000ohQgR?n8MhP03?n8MhP00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?n1OX7o
PGj100KoPGj100?o0000ojAKY?nTFj@01_nTFj@00ol0003ohAkQon4Nh@03on4Nh@03o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ob3O8olPgb00:olPgb003o`000?nHIiSoV6NH00coV6NH00Co0000od2o
@?m0_d3o00003?mYUVT00ol0003oR7N8ohQgR00>ohQgR003o`000?n8MhSoR7N800SoR7N81?l0000;
ohEjQ@03o`000?n1OX7oPGj100KoPGj100?o0000ojAKY?nTFj@01OnTFj@00ol0003ohAkQon4Nh@04
on4Nh@03o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003ob3O8olPgb00;olPgb003o`000?nHIiSoV6NH
00_oV6NH00?o0000od2o@?m0_d000_m0_d000ol0003oJIIYofVFJ@09ofVFJ@03o`000?n8MhSoR7N8
00koR7N800Co0000ohQgR?n8MhSoR7N81ol00003oh]dR`03o`000?n5NXGoQGZ500WoQGZ500?o0000
oh5nPOn1OX401_n1OX400ol0003oY5^TojAKY004ojAKY003o`000?oQ7^7ohAkQ00KohAkQ00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o8=lSob3O800cob3O800?o0000oiQWV?nHIiP02_nHIiP00ol0
003o@;m0od2o@003od2o@003o`000?mYUVWoJIIY00SoJIIY00?o0000ohQgR?n8MhP03_n8MhP4o`00
00_oRgB;00?o0000ohEjQOn5NXD02?n5NXD00ol0003oPGj1oh5nP@05oh5nP@03o`000?nTFjCoY5^T
00GoY5^T00?o0000on4NhOoQ7^401_oQ7^400ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olPgb?o8
=lP03?o8=lP7o`0000GoV6NH00?o0000od2o@?m0_d001Om0_d000ol0003oJIIYofVFJ@07ofVFJ@03
o`000?n8MhSoR7N800koR7N800?o0000oh]dRon;M8/03On;M8/00ol0003oQGZ5ohEjQ@08ohEjQ@03
o`000?n1OX7oPGj100CoPGj100?o0000ojAKY?nTFj@01?nTFj@00ol0003ohAkQon4Nh@07on4Nh@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003ob3O8olPgb00=olPgb003o`000?nRGJ;oXUfR00CoXUfR
1Ol00009od2o@003o`000?mYUVWoJIIY00KoJIIY00?o0000ohQgR?n8MhP03_n8MhP00ol0003oRgB;
oh]dR`0=oh]dR`03o`000?n5NXGoQGZ500SoQGZ500Co0000oh5nPOn1OX7oPGj11Ol00004ojAKY003
o`000?oQ7^7ohAkQ00WohAkQ1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olPgb003o`000?nRGJ;oXUfR00WoXUfR
0_l00009od2o@003o`000?mYUVWoJIIY00KoJIIY00?o0000ohQgR?n8MhP03?n8MhP00ol0003oRgB;
oh]dR`0?oh]dR`Ko00001?n5NXD4o`0000Go^TFj0_l000000onTFjCo0000on4Nh@0;on4Nh@04o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oJ9M[ofRGJomXUfP?o00002_o8=lP00ol0003o
XUfRoj9MXP09oj9MXP03o`000?mB[E;o000000;o00001om0_d000ol0003oJIIYofVFJ@05ofVFJ@03
o`000?n8MhSoR7N800SoR7N81Ol0000Aoh]dR`03o`000?n;M8_oRgB;00?oRgB;1?l0000;okY5^P03
o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000omXUf_oJ9MX01OoJ9MX2o`0000Oob3O8
00?o0000oj9MX_nRGJ802_nRGJ800ol0003oDZeBoe:]DP02oe:]DP?o00001Om0_d000ol0003oJIIY
ofVFJ@04ofVFJ@04o`000?n8MhSoR7N8ohQgR0Oo00001?mbSG800ol0003oRgB;oh]dR`0>oh]dR`03
o`000?n;M8_oRgB;00OoRgB;00?o0000okY5^_njAKX02OnjAKX00ol0003ohAkQon4Nh@09on4Nh@03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003ofRGJomXUfP08omXUfP;o00001?o8=lP00ol0003oXUfR
oj9MXP0;oj9MXP03o`000?mB[E;oDZeB00GoDZeB0ol00003od2o@004o`000?mYUVWoJIIYofVFJ@Ko
00003?mbSG800ol0003oRgB;oh]dR`0=oh]dR`03o`000?n;M8_oRgB;00OoRgB;00?o0000okY5^_nj
AKX02_njAKX00ol0003ohAkQon4Nh@08on4Nh@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omXUfP?o000000?ob3O8o`000?nRGJ80
3?nRGJ800ol0003oDZeBoe:]DP08oe:]DP?o000000Co@;m0o`000?l0003o00000_nAKY400ol0003o
LXebog:=LP0=og:=LP03o`000?n;M8_oRgB;00coRgB;00?o0000oh]dRon;M8/02?n;M8/00ol0003o
^TFjokY5^P0;okY5^P03o`000?oQ7^7ohAkQ00KohAkQ00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
fRGJ00?o0000oj9MX_nRGJ803?nRGJ800ol0003oDZeBoe:]DP0;oe:]DP03o`000?nAKY7oTFjA00?o
TFjA00?o0000og:=L_mbSG803?mbSG800ol0003oEjQGo`00000=oh]dR`03o`000?n;M8_oRgB;00So
RgB;00?o0000okY5^_njAKX03?njAKX3o`0000GohAkQ00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oJ9M[ofRGJ00cofRGJ00?o0000oj9MX_nRGJ803?nRGJ800ol0003oDZeBoe:]DP0:oe:]DP03o`00
0?nAKY7oTFjA00GoTFjA00?o0000og:=L_mbSG802_mbSG801?l0003oEjQGoeNXEomGZ5L2o`0000[o
RgB;00?o0000oh]dRon;M8/02On;M8/00ol0003o^TFjokY5^P0<okY5^P03o`000?oW6>OoiaSW00?o
000000?ohAkQo`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000oj9MX_nRGJ80
3?nRGJ800ol0003oDZeBoe:]DP09oe:]DP03o`000?nAKY7oTFjA00KoTFjA00?o0000og:=L_mbSG80
2OmbSG800ol0003oEjQGoeNXE`02oeNXE`03o`000?n>LHko000000;o00001on;M8/00ol0003oRgB;
oh]dR`09oh]dR`03o`000?njAK[o^TFj00_o^TFj00?o0000onLHiooW6>L01?oW6>L00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omXUf_oJ9MX02ooJ9MX00ol0003oXUfRoj9MXP0;oj9MXP03o`000?mB
[E;oDZeB00SoDZeB00?o0000oi5^TOnAKY401onAKY400ol0003oLXebog:=LP08og:=LP03o`000?mG
Z5OoEjQG00?oEjQG00?o0000ohiaS_n>LHh00_n>LHh2o`0000CoRgB;00?o0000oh]dRon;M8/02_n;
M8/00ol0003o^TFjokY5^P0:okY5^P03o`000?oW6>OoiaSW00GoiaSW00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oJ9M[ofRGJ00[ofRGJ0ol0000;oj9MXPKo00001?mB[E800ol0003oTFjAoi5^T@08
oi5^T@03o`000?mbSG;oLXeb00OoLXeb00?o0000oeNXEomGZ5L00omGZ5L00ol0003oSW6>ohiaSP05
ohiaSP?o000000?oRgB;o`000?n;M8/02on;M8/00ol0003o^TFjokY5^P09okY5^P03o`000?oW6>Oo
iaSW00OoiaSW00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000ojAK
Y?nTFj@01?l00006oj9MXP03o`000?nGJ9OoUfRG00CoUfRG1?l0000<oi5^T@03o`000?mbSG;oLXeb
00GoLXeb00?o0000oeNXEomGZ5L01?mGZ5L00ol0003oSW6>ohiaSP08ohiaSP03o`000?n;M8_oRgB;
00_oRgB;00?o0000okY5^_njAKX02?njAKX00ol0003oiaSWonLHi`08onLHi`Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oJ9M[ofRGJ00OofRGJ00?o0000ojAKY?nTFj@01OnTFj@3o`0000;oXUfR00?o0000oiMXUonG
J9L02?nGJ9L00ol0003oTFjAoi5^T@0:oi5^T@03o`000?mbSG;oLXeb00CoLXeb00?o0000oeNXEomG
Z5L01OmGZ5L00ol0003oSW6>ohiaSP08ohiaSP03o`000?n;M8_oRgB;00WoRgB;1?l00008okY5^P03
o`000?oW6>OoiaSW00WoiaSW00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJ
omXUfP05omXUfP03o`000?nTFjCoY5^T00WoY5^T0_l0000<oiMXU`03o`000?nAKY7oTFjA00WoTFjA
00?o0000og:=L_mbSG800ombSG800ol0003oEjQGoeNXE`05oeNXE`03o`000?n>LHkoSW6>00[oSW6>
00?o0000oh]dRon;M8/01?n;M8/4o`0000Co[5>/00?o0000okY5^_njAKX01?njAKX00ol0003oiaSW
onLHi`0:onLHi`03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oJ9M[ofRGJ00?ofRGJ00?o0000ojAKY?nTFj@02onT
Fj@00ol0003oUfRGoiMXU`0:oiMXU`03o`000?nAKY7oTFjA00WoTFjA00?o0000og:=L_mbSG800_mb
SG800ol0003oEjQGoeNXE`06oeNXE`03o`000?n>LHkoSW6>00[oSW6>00?o0000oh]dRon;M8/01?l0
0009ojaC[0Ko00003?oW6>L00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omXUf_oJ9M[ofRGJ0_l0
000=ojAKY003o`000?nGJ9OoUfRG00[oUfRG00?o0000oi5^TOnAKY402OnAKY401Ol0003oLXebog:=
L_mbSG;o000000WoEjQG00?o0000ohiaS_n>LHh02on>LHh2o`0000go[5>/00?o0000omlPgooO8=l0
0_oO8=l00ol0003oiaSWonLHi`0:onLHi`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ofRGJo`00
0002omhQgP;o00002onTFj@00ol0003oUfRGoiMXU`0;oiMXU`03o`000?nAKY7oTFjA00WoTFjA00?o
0000og:=L_l000002OmGZ5L00ol0003oSW6>ohiaSP0<ohiaSP03o`000?n/Djco[5>/00co[5>/00?o
0000omlPgooO8=l00ooO8=l00ol0003oiaSWonLHi`09onLHi`03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ogR7NomhQgP03omhQgP;o00002_nTFj@00ol0003oUfRGoiMXU`0:oiMXU`03o`000?nAKY7o
TFjA00SoTFjA1Ol00008oeNXE`03o`000?n>LHkoSW6>00coSW6>00?o0000ojaC[?n/Dj`02on/Dj`0
0ol0003ogb3OomlPg`05omlPg`03o`000?oW6>OoiaSW00SoiaSW00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooN8Mh2o`0000SoY5^T00?o0000oiMXUonGJ9L02_nGJ9L00ol0003oTFjAoi5^T@07oi5^
T@03o`000?moP7ooOh1o00?oOh1o0ol00005oeNXE`03o`000?n>LHkoSW6>00_oSW6>00?o0000ojaC
[?n/Dj`03?n/Dj`00ol0003ogb3OomlPg`06omlPg`03o`000?oW6>OoiaSW00OoiaSW00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000WogR7N00?o0000ojAKY?nTFj@01OnTFj@2o`0000co
UfRG00?o0000oi5^TOnAKY401OnAKY400ol0003oOh1oogn0O`07ogn0O`?o000000?oEjQGo`000?n>
LHh03On>LHh00ol0003o[5>/ojaC[00<ojaC[003o`000?oO8=oogb3O00Kogb3O00?o0000onLHiooW
6>L01_oW6>L00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?oN8MkogR7N00OogR7N
0_l00004ojAKY003o`000?n`Ck3o/4n`00;o00002_nGJ9L00ol0003oTFjAoi5^T@03oi5^T@;o0000
3OmoP7l2o`0000goSW6>0ol0000=ojaC[003o`000?oO8=oogb3O00Oogb3O00?o0000onLHiooW6>L0
1OoW6>L00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?oN8MkogR7N00SogR7N0_l0
00000onTFjCo0000ok1?/004ok1?/003o`000?nGJ9OoUfRG00OoUfRG00Co0000oi5^TOnAKY7oTFjA
0_l00002ohebS@03o`000?moP7ooOh1o00coOh1o3Ol00003ohYeRP03o`000?n/Djco[5>/00[o[5>/
00?o0000omlPgooO8=l02?oO8=l01?l0003oiaSWonLHiooW6>L4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003ogR7N
omhQgP09omhQgP03o`000?n`Ck3o/4n`00Go/4n`0_l00008oiMXU`03o`000?nAKY7o000000GoSG:=
00?o0000ogn0OomoP7l02omoP7l00ol0003oOh1oogn0O`09ogn0O`03o`000?n:MH[oRWF:00;oRWF:
0_l00009ojaC[003o`000?oO8=oogb3O00[ogb3O0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?oN8MkogR7N00SogR7N00?o0000ok1?/?n`Ck001on`Ck04o`0000?oUfRG0ol0
0007ohebS@03o`000?moP7ooOh1o00[oOh1o00?o0000ogn0OomoP7l02OmoP7l00ol0003oRWF:ohYe
RP04ohYeRP;o00001on/Dj`00ol0003ogb3OomlPg`0:omlPg`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oN8MkogR7N00OogR7N00?o0000ok1?/?n`Ck002?n`Ck00
1?l0003o/Tfbok9=/_nbCK83o`0000;oX5nP00?o0000ohebSOn=LXd01_n=LXd00ol0003oOh1oogn0
O`08ogn0O`03o`000?moP7ooOh1o00[oOh1o00?o0000ohYeR_n:MHX01_n:MHX00ol0003o[5>/ojaC
[004ojaC[003o`000?oO8=oogb3O00Wogb3O00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000omhQg_oN8Mh01OoN8Mh00ol0003o/4n`ok1?/008ok1?/003o`000?nbCK;o
/Tfb00Co/Tfb00Go0000oj1OX?nPGj3oX5nPo`000008ohebS@03o`000?moP7ooOh1o00OoOh1o00?o
0000ogn0OomoP7l02_moP7l00ol0003oRWF:ohYeRP07ohYeRP;o00001?n/Dj`00ol0003ogb3OomlP
g`08omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omhQg_oN8Mh00ooN8Mh0
0ol0003o/4n`ok1?/008ok1?/003o`000?nbCK;o/Tfb00Co/Tfb00?o0000oj1OX?nPGj000_nPGj00
0ol0003oSG:=ohebS@07ohebS@03o`000?moP7ooOh1o00KoOh1o00?o0000ogn0OomoP7l02_moP7l0
0ol0003oRWF:ohYeRP09ohYeRP05o`000?n/Djco[5>/ojaC[?l000002OoO8=l00ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_o/4n`00?o0000ok9=/_nbCK801?nbCK800ol0003oX5nPoj1OX003
oj1OX003o`000?n=LXgoSG:=00OoSG:=00?o0000ogn0OomoP7l01OmoP7l00ol0003oOh1oogn0O`0:
ogn0O`03o`000?n:MH[oRWF:00WoRWF:1?l00009omlPg`03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oW6>OoiaSW
onLHiol000002_n`Ck000ol0003o/Tfbok9=/P05ok9=/P03o`000?nPGj3oX5nP00?oX5nP00?o0000
ohebSOn=LXd02?n=LXd00ol0003oOh1oogn0O`04ogn0O`03o`000?moP7ooOh1o00WoOh1o00?o0000
ohYeR_n:MHX02?n:MHX2o`0000?ogB;M00?o0000omlPgooO8=l01_oO8=l00ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000onLHiooW6>L00ooW6>L00ol0003o/4n`ok1?/006ok1?/003o`000?nbCK;o/Tfb
00Go/Tfb00?o0000oj1OX?nPGj001?nPGj000ol0003oSG:=ohebS@09ohebS@03o`000?moP7ooOh1o
00;oOh1o00?o0000ogn0OomoP7l02_moP7l00ol0003oRWF:ohYeRP06ohYeRP;o00001_oM8]d8o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003oiaSWonLHi`05onLHi`03o`000?n`Ck3o/4n`00Go/4n`00?o0000ok9=/_nb
CK801OnbCK800ol0003oX5nPoj1OX005oj1OX003o`000?n=LXgoSG:=00WoSG:=00Go0000ogn0Oomo
P7ooOh1oo`00000<ogn0O`03o`000?n:MH[oRWF:00CoRWF:0_l00008omdRg@03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW6>OoiaSW00OoiaSW00?o0000ok1?/?n`
Ck000on`Ck000ol0003o/Tfbok9=/P06ok9=/P03o`000?nPGj3oX5nP00GoX5nP00?o0000ohebSOn=
LXd02_n=LXd00ol0003oOh1oo`000004o`0000WoOh1o00?o0000ohYeR_n:MHX00_n:MHX2o`0000[o
gB;M00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003oiaSWonLHi`07onLHi`03o`00
0?n`Ck3o/4n`00;o/4n`00?o0000ok9=/_nbCK801_nbCK800ol0003oX5nPoj1OX007oj1OX0;o0000
2on=LXd00ol0003o[U6^ojiA[P03ojiA[POo00000_moP7l00ol0003oRWF:ohYeRP02o`0000_ogB;M
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000onLHiooW6>L02OoW
6>L01Ol0003o/4n`ok1?/?n`Ck3o000000So/Tfb00?o0000oj1OX?nPGj001onPGj000ol0003od2o@
o`000002o`0000SoSG:=00?o0000ojiA[_n^DJh02_n^DJh5o`0000gogB;M00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<onLHi`03o`000?n`Ck3o000000Wo/Tfb00?o
0000oj1OX?nPGj001_nPGj000ol0003od2o@om0_d003om0_d0?o00001?n=LXd00ol0003o[U6^ojiA
[P0=ojiA[P03o`000?oM8]gogB;M00gogB;M00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ool0o`2o`0000_oiaSW00?o0000ok9=/_nbCK801onbCK800ol0003oX5nPoj1OX007
oj1OX003o`000?o@;m3od2o@00Kod2o@0ol000000on=LXgo0000ojiA[P0>ojiA[P03o`000?oM8]go
gB;M00cogB;M00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009onLH
i`03o`000?nbCK;o/Tfb00;o/Tfb1_l00008oj1OX003o`000?o@;m3od2o@00[od2o@00?o0000ojiA
[_n^DJh03on^DJh00ol0003ogB;MomdRg@0:omdRg@;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007onLHi`Go00001_oU6^D00ol0003oX5nPoj1OX005oj1OX003o`000?o@;m3od2o@00[o
d2o@00?o0000ojiA[_n^DJh03on^DJh00ol0003ogB;MomdRg@07omdRg@?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005onLHi`03o`000?oU6^GoiA[U00WoiA[U00?o0000oj1OX?nP
Gj000onPGj000ol0003od2o@om0_d00;om0_d003o`000?n^DJko[U6^00oo[U6^00?o0000omdRgOoM
8]d01OoM8]d2o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?oiaSWo`000?l00000
3OoU6^D00ol0003oX5nPoj1OX002oj1OX003o`000?o@;m3od2o@00_od2o@5?l00004omdRg@;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on`Cko`00000>onDJi@04o`000?nPGj3oX5nPo`0000kod2o@
00?o0000onPGj?oX5nP04?oX5nP00ol0003ogB;Mo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ok1?_on`Ckoo/4nol000003_oU6^D00ol0003oX5nPo`00000>om0_d003o`00
0?oX5nSoj1OX017oj1OX00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00_ok1?/00ol0003oiA[UonDJi@0=onDJi@03o`000?o@;m3od2o@00Wod2o@1Ol0
000BonPGj0;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/0
0ol0003oiA[UonDJi@0<onDJi@03o`000?o@;m3od2o@00;od2o@1ol00004oo/4n`03o`000?oX5nSo
j1OX00ooj1OX00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oU6^GoiA[U00coiA[U1?l0000<oo/4n`03o`000?oX5nSoj1OX00coj1OX0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ok1?_on`Ck00Oo
n`Ck00?o0000onDJiOoU6^D03?oU6^D00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oX5nSoj1OX00_o
j1OX00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003oiA[UonDJi@0:onDJi@03o`000?ok1?_on`Ck00kon`Ck00?o0000onPGj?oX
5nP02OoX5nP2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ok1?_on`Ck00[on`Ck00?o0000onDJiOoU6^D02_oU6^D00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?oX5nSoj1OX00Koj1OX0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003on`Ck00gon`Ck3?l0
000Aoo/4n`?o00001_oX5nP00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000ooX5nP2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onPGj?l000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01?l00?l9oooo00Ko003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Oo003o2?ooo`05o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0_ooo`08o`00o`03oooo0?l00?oo003o00?o003o0_ooo`03o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Wo003o00?oool0o`00ool00?l00ol00?l01?oo
o`3o003oo`00ool00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool0
06_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo
00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`002_l00?l2oooo00Wo003o0_ooo`08o`00
o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o
003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co
003o0_ooo`05o`00o`Coool00_l00?l2oooo00[o003o0_ooo`0:o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo
0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co
003o0_ooo`0:o`00o`;oool02ol00?l00oooo`3o003oo`00o`04o`00o`;oool01_l00?l2oooo00Ko
003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o
00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003o
oooo0?ooo`0:o`00o`;oool03?l00?l00oooo`3o003oo`00o`03o`00o`;oool01_l00?l2oooo00Ko
003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o
00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003o
oooo0?ooo`0:o`00o`;oool03?l00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo
003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003o
o`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`00
2_l00?l2oooo00go003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0ooo
o`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02_l00?l2oooo00go003o0_oo
o`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o003o0_ooo`0=o`00o`;oool00ol00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`;oool01_l00?l00oooo`3o003oo`00o`04o`00
o`;oool00ol00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So
003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Go
003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool0
1_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o
0_ooo`07o`00o`;oool00ol00?l3oooo00Co003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00Go003o1?ooo`08o`00o`Koool01_l00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol0
0?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo02;o003o0_ooo`09
o`00o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(130) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.984 .016 .984 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.984 .016 .984 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.984 .016 .984 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.983 .017 .983 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.887 .113 .887 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.982 .018 .982 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.882 .118 .882 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.906 .094 .906 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.86 .14 .86 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.98 .02 .98 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.802 .198 .802 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.984 .016 .984 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.729 .271 .729 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.707 .293 .707 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.98 .02 .98 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.985 .015 .985 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.649 .351 .649 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.761 .239 .761 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.979 .021 .979 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.98 .02 .98 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.869 .131 .869 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.512 .488 .512 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.585 .415 .585 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.498 .502 .498 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.489 .511 .489 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.567 .433 .567 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.826 .174 .826 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.859 .141 .859 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.984 .016 .984 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.517 .483 .517 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.746 .254 .746 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.421 .579 .421 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.825 .175 .825 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.786 .214 .786 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.983 .017 .983 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.695 .305 .695 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.714 .286 .714 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.661 .339 .661 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.828 .172 .828 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.527 .473 .527 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.986 .014 .986 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.884 .116 .884 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.567 .433 .567 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.495 .505 .495 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.462 .538 .462 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.88 .12 .88 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.91 .09 .91 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.654 .346 .654 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.983 .017 .983 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.525 .475 .525 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.44 .56 .44 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.597 .403 .597 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.624 .376 .624 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.378 .622 .378 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.505 .495 .505 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.628 .372 .628 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.984 .016 .984 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.653 .347 .653 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.582 .418 .582 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.877 .123 .877 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.134 .866 .134 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.705 .295 .705 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.7 .3 .7 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.598 .402 .598 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.305 .695 .305 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.313 .687 .313 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.189 .811 .189 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.25 .75 .25 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.537 .463 .537 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.314 .686 .314 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.426 .574 .426 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.708 .292 .708 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.488 .512 .488 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.517 .483 .517 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.586 .414 .586 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.901 .099 .901 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.983 .017 .983 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.296 .704 .296 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.385 .615 .385 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.304 .696 .304 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.982 .018 .982 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.646 .354 .646 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.46 .54 .46 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.233 .767 .233 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.28 .72 .28 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.537 .463 .537 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.382 .618 .382 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.876 .124 .876 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.479 .521 .479 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.2 .8 .2 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.635 .365 .635 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.4 .6 .4 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.339 .661 .339 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.549 .451 .549 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.832 .168 .832 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.534 .466 .534 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.211 .789 .211 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.337 .663 .337 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.545 .455 .545 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.386 .614 .386 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.393 .607 .393 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.82 .18 .82 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.366 .634 .366 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.306 .694 .306 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.258 .742 .258 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.982 .018 .982 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.269 .731 .269 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.437 .563 .437 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.309 .691 .309 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.551 .449 .551 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.503 .497 .503 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.982 .018 .982 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.542 .458 .542 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.454 .546 .454 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.479 .521 .479 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.526 .474 .526 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.388 .612 .388 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.338 .662 .338 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.417 .583 .417 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.478 .522 .478 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.983 .017 .983 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.72 .28 .72 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.49 .51 .49 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.602 .398 .602 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.313 .687 .313 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.869 .131 .869 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.17 .83 .17 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.361 .639 .361 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.355 .645 .355 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.528 .472 .528 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.664 .336 .664 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.268 .732 .268 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.983 .017 .983 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.427 .573 .427 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.689 .311 .689 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.914 .086 .914 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.536 .464 .536 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.483 .517 .483 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.474 .526 .474 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.833 .167 .833 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.278 .722 .278 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.411 .589 .411 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.504 .496 .504 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.723 .277 .723 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.27 .73 .27 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.404 .596 .404 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.495 .505 .495 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.519 .481 .519 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.983 .017 .983 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.332 .668 .332 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.983 .017 .983 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.876 .124 .876 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.57 .43 .57 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.512 .488 .512 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.38 .62 .38 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.548 .452 .548 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.42 .58 .42 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.873 .127 .873 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.554 .446 .554 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.582 .418 .582 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.584 .416 .584 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.527 .473 .527 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.769 .231 .769 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.501 .499 .501 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.38 .62 .38 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.241 .759 .241 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.262 .738 .262 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.452 .548 .452 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.678 .322 .678 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.983 .017 .983 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.876 .124 .876 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.437 .563 .437 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.257 .743 .257 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.533 .467 .533 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.741 .259 .741 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.497 .503 .497 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.982 .018 .982 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.431 .569 .431 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.733 .267 .733 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.879 .121 .879 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.983 .017 .983 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.397 .603 .397 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.454 .546 .454 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.872 .128 .872 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.488 .512 .488 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.484 .516 .484 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.759 .241 .759 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.428 .572 .428 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.625 .375 .625 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.759 .241 .759 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.547 .453 .547 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.529 .471 .529 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.659 .341 .659 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.477 .523 .477 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.907 .093 .907 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.684 .316 .684 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.593 .407 .593 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.552 .448 .552 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.983 .017 .983 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.739 .261 .739 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.461 .539 .461 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.982 .018 .982 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.887 .113 .887 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.767 .233 .767 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.888 .112 .888 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.487 .513 .487 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.871 .129 .871 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.681 .319 .681 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.581 .419 .581 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.984 .016 .984 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.587 .413 .587 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.548 .452 .548 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.769 .231 .769 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.979 .021 .979 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.984 .016 .984 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.687 .313 .687 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.981 .019 .981 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.538 .462 .538 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.982 .018 .982 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.466 .534 .466 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.722 .278 .722 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.549 .451 .549 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.86 .14 .86 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.87 .13 .87 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.683 .317 .683 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.679 .321 .679 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.681 .319 .681 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.801 .199 .801 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.859 .141 .859 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.775 .225 .775 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.785 .215 .785 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.98 .02 .98 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.644 .356 .644 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.869 .131 .869 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.982 .018 .982 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.904 .096 .904 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.896 .104 .896 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.643 .357 .643 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.889 .111 .889 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.877 .123 .877 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.644 .356 .644 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.982 .018 .982 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.98 .02 .98 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.985 .015 .985 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.87 .13 .87 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.983 .017 .983 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.983 .017 .983 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.982 .018 .982 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.983 .017 .983 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.982 .018 .982 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.983 .017 .983 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003oh1oPon0Oh?l0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000on0Oh?oP7n000_oP7n000ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oP7n3oh1oP00?oh1oP00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000on0Oh?oP7n001OoP7n000ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003oh1oPon0Oh006on0Oh003
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000on0Oh?oP7n002?oP7n000ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oP7n3o0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000coh1oP00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003on0Oh003o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003oh1oPon0Oh005on0Oh003o`000?oP
7n3oh1oP00_oh1oP0ol00003omlPg`03o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
on0Oh?oP7n000ooP7n000ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003oh1oPon0Oh006
on0Oh003o`000?oP7n3oh1oP00[oh1oP00?o0000omlPgooO8=l01?oO8=l00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oN8MkogR7NomhQgP;o00002_ok1?/2o`000003omhQg_l0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003oh1oPon0Oh005on0Oh003o`000?ok1?_o
n`Ck00Won`Ck00?o0000omhQg_l000002ook1?/00ol0003oh1oPon0Oh006on0Oh003o`000?oP7n3o
h1oP00Woh1oP00?o0000omlPgooO8=l01_oO8=l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oN8Mko
gR7N00CogR7N0_l00005oo/4n`?o00001?oN8Mh00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008on0Oh003o`000?ok1?_on`Ck00Oon`Ck0_l00003omhQ
gP03o`000?ok1?_on`Ck00Oon`Ck00?o0000on0Oh?oP7n001ooP7n000ol0003oh1oPon0Oh009on0O
h003o`000?oO8=oogb3O00Oogb3O00?o0000oo/4nook1?/01Ook1?/2o`0000WogR7N0_l000000ook
1?_o0000o`000007omhQgP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000on0Oh?oP
7n002?oP7n000ol0003on`Ckoo/4n`06oo/4n`03o`000?oN8MkogR7N00?ogR7N00?o0000oo/4nook
1?/01ook1?/00ol0003oh1oPon0Oh008on0Oh003o`000?oP7n3oh1oP00Ooh1oP00?o0000omlPgooO
8=l02OoO8=l00ol0003on`Ckoo/4n`03oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000omhQg_oN
8Mh01ooN8Mh00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003oh1oPo`000005oo/4n`;o00002ooP7n02o`0000Kon`Ck
00?o0000omhQg_oN8Mh01OoN8Mh00ol0003on`Ckoo/4n`06oo/4n`03o`000?oP7n3oh1oP00Soh1oP
00?o0000on0Oh?oP7n001_oP7n000ol0003ogb3OomlPg`0;omlPg`05o`000?ok1?_on`Ckoo/4nol0
00003_oN8Mh00ol0003ogR7NomhQgP08omhQgP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oP7n3oh1oPon0Oh?l0
00000ook1?/00ol0003oh1oPon0Oh00:on0Oh004o`000?oD:mCoe2_Do`0000?on`Ck0_l00008omhQ
gP03o`000?ok1?_on`Ck00Kon`Ck00?o0000on0Oh?oP7n002OoP7n000ol0003oh1oPon0Oh005on0O
h003o`000?oO8=oogb3O00cogb3O00?o0000oo/4nol000003ooN8Mh00ol0003ogR7NomhQgP08omhQ
gP03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003oh1oPon0Oh003on0Oh003o`000?ok1?_o000000_o
h1oP0_l00004om@[e003o`000?ok1?_o000000_ogR7N00?o0000oo/4nook1?/01Ook1?/00ol0003o
h1oPon0Oh009on0Oh003o`000?oP7n3oh1oP00Coh1oP00?o0000omlPgooO8=l03_oO8=l00ol0003o
gR7NomhQgP0>omhQgP03o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000on0Oh?oP7n00
1?oP7n000ol0003oh1oPon0Oh009on0Oh003o`000?oD:mCoe2_D00Goe2_D00?o0000omhQg_oN8Mh0
2_oN8Mh00ol0003on`Ckoo/4n`05oo/4n`03o`000?oP7n3oh1oP00[oh1oP00?o0000on0Oh?oP7n00
0ooP7n000ol0003ogb3OomlPg`0>omlPg`03o`000?oN8MkogR7N00gogR7N00?o0000omhQg_oN8Mh0
2_oN8Mh00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003oh1oPon0O
h005on0Oh003o`000?oP7n3oh1oP00Ooh1oP0_l00008om@[e003o`000?oN8MkogR7N00_ogR7N00?o
0000oo/4nook1?/01?ok1?/00ol0003oh1oPon0Oh00:on0Oh004o`000?oP7n3oh1oPon0Oh0?o0000
3ooO8=l00ol0003ogR7NomhQgP0>omhQgP03o`000?oN8MkogR7N00[ogR7N00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ok1?/00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oP7n3oh1oP00Ooh1oP00?o0000on0Oh?oP7n001?oP7n02o`0000_oe2_D1?l0
0009omhQgP03o`000?ok1?_on`Ck00?on`Ck00?o0000on0Oh?oP7n002ooP7n001?l0003oh1oPo`00
0?l00003oke2_@;o00003?oO8=l2o`00013ogR7N00?o0000omhQg_oN8Mh02ooN8Mh00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/02?ok1?/00ol0003oh1oP
on0Oh007on0Oh003o`000?oP7n3oh1oP00?oh1oP00?o0000om@[e?oD:m@02ooD:m@01?l0003o^4Nh
okQ7^?nhAkP5o`0000GogR7N00?o0000oo/4nook1?/00_ok1?/00ol0003oh1oPon0Oh00<on0Oh003
o`000?nm@[go_D:m00Go_D:m0_l00008omlPg`;o00000_n_D:l00ol0003ogR7NomhQgP0=omhQgP03
o`000?oN8MkogR7N00_ogR7N00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[on`Ck
00?o0000oo/4nook1?/01ook1?/00ol0003oh1oPon0Oh009on0Oh003o`000?oP7n3oh1oP00;o0000
3OoD:m@00ol0003o^4NhokQ7^007okQ7^0Ko00000_ok1?/4o`0000goh1oP00?o0000oke2_Onm@[d0
1onm@[d2o`0000Gogb3O00?o0000ojm@[on_D:l00on_D:l00ol0003ogR7NomhQgP0<omhQgP03o`00
0?oN8MkogR7N00cogR7N00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oP7n3oh1oP00Woh1oP00?o
0000on0Oh?l000003ooD:m@00ol0003o^4NhokQ7^00<okQ7^0?o00001?oE:]D3o`0000Woh1oP00?o
0000oke2_Onm@[d02_nm@[d2o`000003omlPgol0003o000000Oo[e2_00?o0000omhQg_oN8Mh02ooN
8Mh00ol0003ogR7NomhQgP0<omhQgP03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oP7n3oh1oP00_oh1oP00?o0000
om@[e?oD:m@03_oD:m@00ol0003o^4NhokQ7^00=okQ7^003o`000?oE:]GoeB[E00KoeB[E0ol00005
on0Oh003o`000?nm@[go_D:m00go_D:m00?o0000ojm@[on_D:l02?n_D:l00ol0003ogR7NomhQgP09
omhQgP03o`000?oN8MkogR7N00gogR7N00Co0000oo/4nook1?_on`Ck1Ol00003onDJi@03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00?on`Ck00?o0000
on0Oh?oP7n002ooP7n02o`0000ooe2_D00?o0000okQ7^?nhAkP03OnhAkP00ol0003oeB[EomDZe@0:
omDZe@?o000000?oh1oPo`000?nm@[d03onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?oN8Mko
gR7N00SogR7N00?o0000omhQg_oN8Mh03_oN8Mh3o`0000SoiA[U00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00[on`Ck0_l00003oo/4n`03o`000?oP7n3oh1oP00Soh1oP0ol000000onc
C;?o0000om@[e00>om@[e003o`000?nhAkSo^4Nh00go^4Nh00?o0000omDZeOoE:]D03OoE:]D00ol0
003o_D:moke2_@0?oke2_@03o`000?n_D:oo[e2_00[o[e2_2ol0000;omhQgPGo00003?oU6^D00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/02_ok1?/01Ol0003ohQgRo`000?ok1?_o0000
00Soh1oP0ol00005ok=</`03o`000?oD:mCoe2_D00coe2_D00?o0000okQ7^?nhAkP03OnhAkP00ol0
003oeB[EomDZe@0=omDZe@;o00004?nm@[d00ol0003o[e2_ojm@[`0:ojm@[`03o`000?n^DJko[U6^
00Oo[U6^00?o0000omhQg_oN8Mh00_oN8Mh7o`0000Co[U6^00?o0000onDJiOoU6^D02_oU6^D00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/02Ook1?/01?l0003ohQgRon8Mh_oR7N82o`00
00Goh1oP0ol00009ok=</`;o00002ooD:m@00ol0003o^4NhokQ7^00=okQ7^003o`000?oE:]GoeB[E
00goeB[E00Co0000ol@ka?o4>lCo00003onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n^DJko
[U6^00Wo[U6^1?l0000;ojiA[P03o`000?oU6^GoiA[U00[oiA[U00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ok1?_on`Ck00Son`Ck00?o0000on8Mh_oR7N801?oR7N800ol0003oh1oPo`000002o`00
00co/dbc00Co0000ojEJYOl0003o00002OoD:m@00ol0003o^4NhokQ7^00=okQ7^003o`000?oE:]Go
eB[E00goeB[E00Go0000ol@ka?o4>lCoa3_4o`00000=oke2_@03o`000?n_D:oo[e2_00[o[e2_00?o
0000ojiA[_n^DJh02On^DJh00ol0003o[U6^ojiA[P0<ojiA[P03o`000?oU6^GoiA[U00[oiA[U00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ok1?_on`Ck00Oon`Ck00?o0000on8Mh_oR7N801_oR7N80
0ol0003o/dbcok=</`0<ok=</`03o`000?nUFZGoYEZU00;oYEZU0_l00007om@[e003o`000?nhAkSo
^4Nh00co^4Nh00?o0000omDZeOoE:]D03OoE:]D00ol0003oa3_4ol@ka003ol@ka003o`000?nm@[go
_D:m00[o_D:m00?o0000ojm@[on_D:l02_n_D:l00ol0003o[U6^ojiA[P09ojiA[P03o`000?n^DJko
[U6^00co[U6^00?o0000onDJiOoU6^D02ooU6^D00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo/4
nook1?/01_ok1?/00ol0003ohQgRon8MhP06on8MhP03o`000?ncC;?o/dbc00_o/dbc00?o0000ojEJ
YOnUFZD01OnUFZD00ol0003oe2_Dom@[e003om@[e003o`000?nhAkSo^4Nh00go^4Nh00?o0000omDZ
eOoE:]D03OoE:]D00ol0003oa3_4ol@ka004ol@ka003o`000?nm@[go_D:m00Wo_D:m00?o0000ojm@
[on_D:l02On_D:l00ol0003o[U6^ojiA[P0:ojiA[P03o`000?n^DJko[U6^00co[U6^00?o0000onDJ
iOoU6^D02ooU6^D00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo/4nook1?/01Ook1?/00ol0003o
hQgRon8MhP07on8MhP03o`000?ncC;?o/dbc00_o/dbc00?o0000ojEJYOnUFZD01_nUFZD2o`0000?o
e2_D00?o0000okQ7^?nhAkP03OnhAkP00ol0003oeB[EomDZe@0<omDZe@03o`000?o4>lCoa3_400Ko
a3_400?o0000oke2_Onm@[d02?nm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n^DJko[U6^00[o
[U6^00?o0000ojiA[_n^DJh03?n^DJh00ol0003oiA[UonDJi@0;onDJi@03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ok1?_on`Ck00Con`Ck00?o0000on8Mh_oR7N802?oR7N800ol0003o/dbcok=</`0:ok=</`03o`00
0?nUFZGoYEZU00WoYEZU0_l000000ooD:mCo0000okQ7^00<okQ7^0?o00003_oE:]D00ol0003oa3_4
ol@ka007ol@ka003o`000?nm@[go_D:m00Oo_D:m00?o0000ojm@[on_D:l02On_D:l00ol0003o[U6^
ojiA[P0;ojiA[P03o`000?n^DJko[U6^00co[U6^00?o0000onDJiOoU6^D02_oU6^D00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo`3o003o`000?ok1?_on`Ck00?on`Ck00?o0000on8Mh_oR7N802_oR7N800ol0003o/dbcok=<
/`09ok=</`03o`000?nUFZGoYEZU00_oYEZU00?o0000okQ7^?nhAkP02_nhAkP2o`0000?oZEJY00?o
0000omDZeOoE:]D02_oE:]D00ol0003oa3_4ol@ka009ol@ka003o`000?nm@[go_D:m00Ko_D:m00?o
0000ojm@[on_D:l02?n_D:l00ol0003o[U6^ojiA[P0<ojiA[P03o`000?n^DJko[U6^00co[U6^00?o
0000onDJiOoU6^D02_oU6^D00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ool0o`0
0ol0003on`Ckoo/4n`02oo/4n`03o`000?oR7N;ohQgR00_ohQgR00?o0000ok=</oncC;<02?ncC;<0
0ol0003oYEZUojEJY@0<ojEJY@03o`000?nhAkSo^4Nh00So^4Nh0_l00006ojUFZ@;o00002_oE:]D0
0ol0003oa3_4ol@ka00:ol@ka003o`000?nm@[go_D:m00Go_D:m00?o0000ojm@[on_D:l02?n_D:l0
0ol0003o[U6^ojiA[P0<ojiA[P03o`000?n^DJko[U6^00co[U6^00?o0000onDJiOoU6^D02ooU6^D0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?oo0?l00Go0000oo/4nook1?_on`Cko`00000=
on8MhP03o`000?ncC;?o/dbc00Oo/dbc00?o0000ojEJYOnUFZD03_nUFZD00ol0003o^4NhokQ7^004
okQ7^0?o00002_nYEZT00ol0003oeB[EomDZe@07omDZe@03o`000?o4>lCoa3_400_oa3_400?o0000
oke2_Onm@[d00onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n^DJko[U6^00co[U6^00?o0000
ojiA[_n^DJh03?n^DJh00ol0003oiA[UonDJi@0;onDJi@;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ok1?/00ol0
003ohQgRon8MhP0<on8MhP03o`000?ncC;?o/dbc00Oo/dbc00?o0000ojEJYOnUFZD03onUFZD01?l0
003o^4NhokQ7^?nhAkP2o`0000koZEJY0_l00006omDZe@03o`000?o4>lCoa3_400goa3_400?o0000
oke2_Onm@[d00_nm@[d00ol0003o[e2_ojm@[`08ojm@[`03o`000?n^DJko[U6^00co[U6^0ol0000=
ojiA[P03o`000?oU6^GoiA[U00_oiA[U00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ok1?_o0000
00oohQgR00?o0000ok=</oncC;<01_ncC;<00ol0003oYEZUojEJY@0@ojEJY@Co00004_nYEZT00ol0
003oeB[EomDZe@03omDZe@03o`000?o4>lCoa3_400koa3_400Go0000oke2_Onm@[go_D:mo`000005
ojm@[`Oo00003?n^DJh01Ol0003oRGJ9ohUfROn9MXWo000000co[U6^00?o0000onDJiOoU6^D02?oU
6^D3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oohQgR00?o0000ok=</oncC;<01_ncC;<00ol0003oYEZUojEJY@0=
ojEJY@?o000000CoRGJ9o`000?l0003o00004onYEZT2o`0000;oeB[E00?o0000ol@ka?o4>l@04?o4
>l@00ol0003o_D:mo`000006o`0000Oo_D:m00?o0000ojiA[_n^DJh02?n^DJh00ol0003oRGJ9ohUf
R@03ohUfR@;o00002?n^DJh3o`0000KoiA[U1?l00002on0Oh003o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003ogR7No`000?naC[43o`0000gohQgR00?o0000ok=</oncC;<01?ncC;<00ol0003oYEZUojEJ
Y@0;ojEJY@?o00000on9MXT01Ol0003oRgB;o`000?n:MH[o000001CoZEJY00?o0000omDZeOl00000
4oo4>l@00ol0003o_D:moke2_@0=oke2_@03o`000?n^DJko[U6^00Go[U6^0_l00008ohUfR@03o`00
0?n^DJko[U6^00Go00000on^DJh00ol0003oiA[UonDJi@03o`0000Ooh1oP00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oN8MkogR7No`0000Co/Dja0ol0000:on8MhP03o`000?ncC;?o/dbc00?o/dbc
00?o0000ojEJYOnUFZD02OnUFZD3o`0000GoRGJ900Co0000oh]dRon;M8_o00000_n:MHX00ol0003o
ZEJYojUFZ@0BojUFZ@03o`000?o4>lCoa3_401;oa3_400?o0000oke2_Onm@[d03_nm@[d00ol0003o
[U6^ojiA[P03ojiA[P03o`000?n9MXWoRGJ900WoRGJ90_l00009ojiA[P;o00002_oP7n000ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000omhQg_oN8MkogR7No`000007ok5>/@;o00001ooR7N85o`0000;o
/dbc00?o0000ojEJYOnUFZD01_nUFZD3o`0000SoRGJ900Co0000oh]dRon;M8_o00000on:MHX00ol0
003oZEJYojUFZ@0AojUFZ@03o`000?o4>lCoa3_4017oa3_400?o0000oke2_Onm@[d04?nm@[d01Ol0
003o[U6^ojiA[_n^DJko000000coRGJ900?o0000ojiA[_n^DJh02?n^DJh00ol0003oh1oPon0Oh00:
on0Oh003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000CogR7N00?o0000ok5>/OnaC[401onaC[43o`00
0004on8Mh_l0003o0000o`0000GoYeRW0_l00006ojEJY@?o00002_n9MXT01Ol0003oRgB;oh]dRon;
M8_o000000CoRWF:00?o0000ojUFZOnYEZT04?nYEZT00ol0003oa3_4ol@ka00Aol@ka003o`000?nm
@[go_D:m017o_D:m00?o0000ojiA[_l000003On9MXT00ol0003o[U6^ojiA[P08ojiA[P03o`000?oP
7n3oh1oP00[oh1oP00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oN8MkogR7N00CogR7N00?o0000
ok5>/OnaC[402_naC[400ol0003oYeRWojMHY`08ojMHY`03o`000?nUFZGoYEZU00?o00003On9MXT0
1Ol0003oRgB;oh]dRon;M8_o000000GoRWF:00?o0000ojUFZOnYEZT03onYEZT00ol0003oa3_4ol@k
a00Aol@ka003o`000?nm@[go_D:m01;o_D:m00?o0000ohUfROn9MXT03?n9MXT00ol0003o[U6^ojiA
[P08ojiA[P03o`000?oP7n3oh1oP00_oh1oP00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000omhQg_oN8Mh01OoN8Mh0
0ol0003o/Djaok5>/@0:ok5>/@03o`000?nWF:OoYeRW00WoYeRW0_l0000?ohUfR@03o`000?n;M8_o
RgB;00;oRgB;00?o0000ohYeR_n:MHX01?n:MHX00ol0003oZEJYojUFZ@0=ojUFZ@?o00004Oo4>l@0
0ol0003o_D:moke2_@0Coke2_@03o`000?n9MXWoRGJ900_oRGJ900?o0000ojiA[_n^DJh02On^DJh0
0ol0003oh1oPon0Oh00;on0Oh003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo/4n`;o00002?oN8Mh0
0ol0003o/Djaok5>/@0:ok5>/@03o`000?nWF:OoYeRW00WoYeRW00?o0000ohUfROn9MXT03On9MXT0
0ol0003oRgB;oh]dR`03oh]dR`03o`000?n:MH[oRWF:00GoRWF:00?o0000ojUFZOnYEZT02_nYEZT2
o`0000?o^DJi00?o0000ol@ka?o4>l@03_o4>l@00ol0003o_D:moke2_@0Coke2_@03o`000?n9MXWo
RGJ900_oRGJ900?o0000ojiA[_n^DJh02On^DJh00ol0003oh1oPon0Oh00;on0Oh003o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Gon`Ck00?o0000omhQg_oN8Mh01ooN8Mh2o`0000_o/Dja00?o0000ojMH
YonWF:L02onWF:L00ol0003oRGJ9ohUfR@0<ohUfR@03o`000?n;M8_oRgB;00?oRgB;00?o0000ohYe
R_n:MHX01_n:MHX00ol0003oZEJYojUFZ@07ojUFZ@;o00001_niA[T2o`0000koa3_400?o0000oke2
_Onm@[d04onm@[d00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?n^DJko[U6^00Wo[U6^00?o0000on0O
h?oP7n003?oP7n000ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo/4nook1?_on`Cko`000009omhQ
gP03o`000?nEJYGo000000_o/Dja00?o0000ojMHYonWF:L02onWF:L00ol0003oRGJ9ohUfR@0;ohUf
R@03o`000?n;M8_oRgB;00CoRgB;00?o0000ohYeR_n:MHX01on:MHX00ol0003oZEJYojUFZ@05ojUF
Z@03o`000?niA[Wo^DJi00So^DJi00?o0000ol@ka?o4>l@02_o4>l@00ol0003o_D:moke2_@0Doke2
_@03o`000?n9MXWoRGJ900_oRGJ900?o0000ojiA[_n^DJh02On^DJh00ol0003oh1oPon0Oh00<on0O
h003o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003on`Cko`000009omhQgP04o`000?nEJYGoUFZEo`00
00_o/Dja00?o0000ojMHYonWF:L02onWF:L00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?n;M8_oRgB;
00CoRgB;00?o0000ohYeR_n:MHX02?n:MHX00ol0003oZEJYojUFZ@02ojUFZ@;o00003?niA[T2o`00
00[oa3_400?o0000oke2_Onm@[d05?nm@[d00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?n^DJko[U6^
00Wo[U6^00?o0000on0Oh?oP7n003OoP7n000ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003ogR7NomhQgP07omhQgP03
o`000?nEJYGoUFZE00;oUFZE00?o0000ok5>/OnaC[402?naC[400ol0003oYeRWojMHY`0<ojMHY`03
o`000?n9MXWoRGJ900WoRGJ900?o0000oh]dRon;M8/01On;M8/00ol0003oRWF:ohYeRP09ohYeRP04
o`000?nYEZWo0000o`00013o^DJi0_l00008ol@ka003o`000?nm@[go_D:m01Co_D:m0ol0000;ohUf
R@03o`000?n^DJko[U6^00Wo[U6^00?o0000on0Oh?oP7n003OoP7n001?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003ogR7NomhQgP06omhQgP03o`000?nEJYGoUFZE00?oUFZE00?o0000ok5>
/OnaC[402?naC[400ol0003oYeRWojMHY`0;ojMHY`;o00002_n9MXT00ol0003oRgB;oh]dR`06oh]d
R`03o`000?n:MH[oRWF:00[oRWF:00?o0000okU6^OniA[T04_niA[T00ol0003oa3_4ol@ka004ol@k
a003o`000?nm@[go_D:m01Go_D:m00?o0000ojm@[on_D:l01Ol00005ohUfR@03o`000?n^DJko[U6^
00[o[U6^00?o0000on0Oh?oP7n003_oP7n03o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003ogR7NomhQgP04omhQgP03
o`000?nEJYGoUFZE00CoUFZE00?o0000ok5>/OnaC[401onaC[400ol0003oYeRWojMHY`0;ojMHY`04
o`000?nIIYWoVFJIo`0000WoRGJ900?o0000oh]dRon;M8/01_n;M8/00ol0003oRWF:ohYeRP0:ohYe
RP03o`000?niA[Wo^DJi01?o^DJi0_l00003ol@ka0Co00005?nm@[d00ol0003o[e2_ojm@[`06ojm@
[`Co000000?oRGJ9o`000?n^DJh02on^DJh00ol0003oh1oPon0Oh00>on0Oh003o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003ogR7NomhQgP03omhQgP03o`000?nEJYGoUFZE00GoUFZE00?o0000ok5>/Ona
C[401onaC[400ol0003oYeRWojMHY`09ojMHY`;o00001?nIIYT00ol0003oRGJ9ohUfR@05ohUfR@03
o`000?n;M8_oRgB;00OoRgB;00?o0000ohYeR_n:MHX02_n:MHX00ol0003o^DJiokU6^@0EokU6^@03
o`000?o4>lCo000000Co`Sg20ol0000@oke2_@03o`000?n_D:oo[e2_00_o[e2_0_l0000<ojiA[P03
o`000?oP7n3oh1oP00coh1oP0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omhQg_oN8Mh00_oN8Mh00ol0003oUFZE
oiEZU@06oiEZU@03o`000?naC[7o/Dja00Oo/Dja00?o0000ojMHYonWF:L02?nWF:L00ol0003oVFJI
oiUVV@05oiUVV@03o`000?n9MXWoRGJ900CoRGJ900?o0000oh]dRon;M8/01on;M8/00ol0003oRWF:
ohYeRP0:ohYeRP03o`000?niA[Wo^DJi01Ko^DJi00?o0000ol8m`_o2?L801_o2?L83o`0000co_D:m
00?o0000ojm@[on_D:l03On_D:l00ol0003o[U6^ojiA[P09ojiA[PGo00002OoP7n02o`000003omhQ
g_l0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003omhQg_l0003oUFZE00WoUFZE00?o0000ok5>/OnaC[401_na
C[400ol0003oYeRWojMHY`07ojMHY`03o`000?nIIYWoVFJI00OoVFJI00?o0000ohUfROn9MXT00_n9
MXT00ol0003oRgB;oh]dR`08oh]dR`03o`000?n:MH[oRWF:00WoRWF:00?o0000okU6^OniA[T05oni
A[T00ol0003o`Sg2ol8m`P09ol8m`P?o00002Onm@[d00ol0003o[e2_ojm@[`0>ojm@[`Ko00001?n^
DJh00ol0003oY5^TojAKY003ojAKY0Go00000_oP7n02o`0000CogR7N00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?o=</gocC;=oldbcOl000002onEJYD00ol0003o/Djaok5>/@06ok5>/@03o`000?nW
F:OoYeRW00GoYeRW0_l0000;oiUVV@04o`000?n9MXWoRGJ9o`0000_oRgB;00?o0000ohYeR_n:MHX0
2On:MHX00ol0003o^DJiokU6^@0FokU6^@03o`000?o2?L;o`Sg200go`Sg20ol00005oke2_@03o`00
0?n_D:oo[e2_00oo[e2_00?o0000ojeB[On]DZd00on]DZd4o`0000_oY5^T0_l00006omhQgP03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003ocC;=oldbc@02oldbc@ko00001_naC[400ol0003oYeRWojMH
Y`05ojMHY`03o`000?nIIYWoVFJI00coVFJI00?o0000ohUfROl000002on;M8/00ol0003oRWF:ohYe
RP07ohYeRP?o00006?niA[T00ol0003o`Sg2ol8m`P0@ol8m`P?o000000?o_D:mo`000?n_D:l04?n_
D:l00ol0003o[E:]ojeB[@07ojeB[@03o`000?nTFjCoY5^T00[oY5^T00?o0000omhQg_oN8Mh01OoN
8Mh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005oldbc@03o`000?moP7ooOh1o00_oOh1o0_l00004
ok5>/@03o`000?nWF:OoYeRW00?oYeRW0_l0000@oiUVV@03o`000?n;M8_oRgB;00[oRgB;00?o0000
ohYeR_n:MHX00on:MHX4o`0000;oOH9m00?o0000okU6^OniA[T05OniA[T00ol0003o`Sg2ol8m`P0D
ol8m`P03o`000?n_D:oo[e2_013o[e2_00?o0000ojeB[On]DZd01on]DZd00ol0003oY5^TojAKY00:
ojAKY003o`000?oN8MkogR7N00GogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o=</gocC;=
00GocC;=00?o0000ogn0OomoP7l03OmoP7l6o`0000?oYeRW00?o0000oiUVVOnIIYT04?nIIYT00ol0
003oRgB;oh]dR`0:oh]dR`03o`000?n:MH[o000000?o00001ommPWd00ol0003o^DJiokU6^@0DokU6
^@03o`000?o2?L;o`Sg201Co`Sg200?o0000ojm@[on_D:l03on_D:l00ol0003o[E:]ojeB[@08ojeB
[@03o`000?nTFjCoY5^T00[oY5^T00?o0000omhQg_oN8Mh01OoN8Mh00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000oldbcOo=</d01_o=</d00ol0003oOh1oogn0O`0=ogn0O`03o`000?nYEZWoZEJY00?o
ZEJY00?o0000ojMHYol000004onIIYT4o`0000WoRgB;0_l0000<ogf2O@03o`000?niA[Wo^DJi01?o
^DJi00?o0000ol8m`_o2?L805Oo2?L800ol0003o[e2_ojm@[`0>ojm@[`03o`000?n]DZgo[E:]00So
[E:]00?o0000ojAKY?nTFj@02OnTFj@00ol0003ogR7NomhQgP07omhQgP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?o=</gocC;=00SocC;=00?o0000ogn0OomoP7l02omoP7l00ol0003oZEJYojUFZ@05ojUFZ@03o`00
0?nIIYWoVFJI01;oVFJI00Co0000ohQgR?n8MhSoR7N81Ol00003oh]dR`03o`000?mmPWgoOH9m00go
OH9m0ol0000@okU6^@;o00006?o2?L800ol0003o[e2_ojm@[`0=ojm@[`03o`000?n]DZgo[E:]00Wo
[E:]00?o0000ojAKY?nTFj@02OnTFj@00ol0003ogR7NomhQgP07omhQgP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo/4nook1?/0
0_ok1?/6o`0000_ocC;=00?o0000ogn0OomoP7l02_moP7l00ol0003oZEJYojUFZ@06ojUFZ@03o`00
0?nIIYWoVFJI017oVFJI00?o0000ohQgR?n8MhP01on8MhP3o`00013oOH9m00?o0000ogV6NOmiQWT0
1Ol00009okU6^@;o000000?oSG:=o`000?o2?L805oo2?L800ol0003o[e2_ojm@[`0=ojm@[`03o`00
0?n]DZgo[E:]00Wo[E:]00?o0000ojAKY?nTFj@02?nTFj@2o`0000[ogR7N00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003on`Ckoo/4
n`03oo/4n`03o`000?oQ7^7ohAkQ00;ohAkQ00?o0000oldbcOo=</d02Oo=</d00ol0003oOh1oogn0
O`0:ogn0O`03o`000?nYEZWoZEJY00OoZEJY00?o0000oiUVVOnIIYT03onIIYT00ol0003oR7N8ohQg
R00:ohQgR003o`000?mmPWgoOH9m00goOH9m00?o0000ogV6NOmiQWT01_miQWT4o`0000Co^DJi00?o
0000ohebSOn=LXd00_n=LXd00ol0003o`Sg2ol8m`P0Fol8m`P03o`000?n_D:oo[e2_00_o[e2_00?o
0000ojeB[On]DZd02on]DZd00ol0003oY5^TojAKY006ojAKY003o`000?nTFjCo000000[ogR7N00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003on`Ckoo/4n`04oo/4n`03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000oldbcOo=</d02?o=</d=
o`0000[oZEJY00?o0000oiUVVOnIIYT03onIIYT00ol0003oR7N8ohQgR00;ohQgR003o`000?mmPWgo
OH9m00coOH9m00?o0000ogV6NOmiQWT02_miQWT4o`0000GoSG:=00?o0000ol8m`_o2?L805_o2?L80
0ol0003o[e2_ojm@[`0:ojm@[`03o`000?n]DZgo[E:]00co[E:]00?o0000ojAKY?nTFj@01?nTFj@2
o`0000?oY5^T00?o0000omhQg_oN8Mh02?oN8Mh00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000on4N
hOoQ7^400ooQ7^400ol0003ocC;=oldbc@07oldbc@03o`000?mmPWgoOH9m00WoOH9m00?o0000ojUF
ZOnYEZT02OnYEZT00ol0003oVFJIoiUVV@0=oiUVV@03o`000?n8MhSoR7N800coR7N800?o0000ogf2
OOmmPWd03?mmPWd00ol0003oNHIiogV6N@0;ogV6N@03o`000?mQWV7o000000KoSG:=00?o0000ol8m
`_o2?L805_o2?L800ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo[E:]00co[E:]00?o0000ojAK
Y?nTFj@00onTFj@00ol0003oY5^TojAKY003ojAKY003o`000?oN8MkogR7N00SogR7N00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
n`Ckoo/4n`06oo/4n`03o`000?oQ7^7ohAkQ00CohAkQ00?o0000oldbcOo=</d01_o=</d00ol0003o
OH9mogf2O@08ogf2O@03o`000?nYEZWoZEJY00_oZEJY00?o0000oiUVVOnIIYT02?nIIYT4o`0000oo
R7N800?o0000ogf2OOmmPWd02ommPWd00ol0003oNHIiogV6N@0;ogV6N@04o`000?mQWV7oHIiQo`00
00OoSG:=00?o0000ol8m`_o2?L805Oo2?L800ol0003o[e2_ojm@[`08ojm@[`03o`000?n]DZgo[E:]
00go[E:]00?o0000ojAKY?nTFj@00_nTFj@00ol0003oY5^TojAKY005ojAKY003o`000?oN8MkogR7N
00OogR7N00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?oQ7^7ohAkQ00GohAkQ00?o0000oldbcOo=
</d01Oo=</d00ol0003oOH9mogf2O@08ogf2O@03o`000?nYEZWoZEJY00_oZEJY00?o0000oiUVVOnI
IYT00onIIYT5o`0000?oRGJ900?o0000ohQgR?n8MhP03_n8MhP00ol0003oOH9mogf2O@0:ogf2O@03
o`000?miQWWoNHIi00[oNHIi00Go0000of6NHOmQWV7oHIiQo`000007ohebS@03o`000?o2?L;o`Sg2
01Go`Sg200?o0000ojm@[on_D:l02?n_D:l00ol0003o[E:]ojeB[@0=ojeB[@03o`000?nTFjCoY5^T
00;o00002?nTFj@00ol0003ogR7NomhQgP08omhQgPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo/4nook1?/01ook1?/00ol0003ohAkQon4Nh@05on4Nh@03o`000?o=</gocC;=00Go
cC;=00?o0000ogf2OOmmPWd02?mmPWd00ol0003oZEJYojUFZ@0<ojUFZ@Go00002On9MXT00ol0003o
R7N8ohQgR00<ohQgR0;o00003?mmPWd00ol0003oNHIiogV6N@0:ogV6N@05o`000?mQWV7oHIiQof6N
HOl000002?n=LXd00ol0003o`Sg2ol8m`P0Dol8m`P?o00001on_D:l00ol0003o[E:]ojeB[@0>ojeB
[@03o`000?nTFjCo000000_oY5^T00?o0000omhQg_oN8Mh01_oN8Mh00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00So
n`Ck00?o0000on4NhOoQ7^401OoQ7^400ol0003ocC;=oldbc@04oldbc@03o`000?mmPWgoOH9m00Oo
OH9m00?o0000ojUFZOnYEZT03?nYEZT01?l0003oV6NHoiQWV?l0000;ohUfR@03o`000?n8MhSoR7N8
00_oR7N800Co0000oefRGOmMXUgo00002_mmPWd00ol0003oNHIiogV6N@0:ogV6N@03o`000?mQWV7o
HIiQ00;oHIiQ00?o0000ohebSOn=LXd01_n=LXd00ol0003o`Sg2ol8m`P0Aol8m`P?o00000onGJ9L0
0ol0003o[e2_ojm@[`04ojm@[`03o`000?n]DZgo[E:]00go[E:]1?l0000;ojAKY003o`000?oN8Mko
gR7N00GogR7N00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oQ7^7ohAkQ00KohAkQ00Co0000oldb
cOo=</gocC;=1?l00008ogf2O@03o`000?nYEZWoZEJY00_oZEJY00?o0000oiQWV?nHIiP00_nHIiP0
0ol0003oRGJ9ohUfR@08ohUfR@03o`000?n8MhSoR7N800[oR7N800?o0000oefRGOmMXUd00_mMXUd0
0ol0003oOH9mogf2O@03ogf2O@Go00002omiQWT00ol0003oHIiQof6NH@03of6NH@03o`000?n=LXgo
SG:=00OoSG:=00?o0000ol8m`_o2?L803_o2?L82o`0000OoUfRG00?o0000ojm@[on_D:l00_n_D:l0
0ol0003o[E:]ojeB[@0=ojeB[@03o`000?nTFjCoY5^T00;oY5^T00?o0000ojAKY?nTFj@02OnTFj@0
0ol0003ogR7NomhQgP03omhQgP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo/4nook1?/02Ook1?/00ol0003ohAkQon4Nh@07on4N
h@?o00001?njAKX00ol0003oOH9mogf2O@05ogf2O@03o`000?nYEZWoZEJY00[oZEJY00?o0000oiQW
V?nHIiP00onHIiP00ol0003oRGJ9ohUfR@09ohUfR@03o`000?n8MhSoR7N800SoR7N800?o0000oefR
GOmMXUd01?mMXUd5o`0000Co:m@[00?o0000ogV6NOmiQWT02OmiQWT00ol0003oHIiQof6NH@03of6N
H@03o`000?n=LXgoSG:=00SoSG:=00?o0000ol8m`_o2?L802_o2?L83o`0000[oUfRG00Go0000ojm@
[on_D:oo[e2_o`00000>ojeB[@03o`000?nTFjCoY5^T00CoY5^T0_l00009ojAKY003o`000?oN8Mko
gR7N00;ogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000okY5
^_njAKX01OnjAKX00ol0003oOH9mogf2O@03ogf2O@03o`000?nYEZWoZEJY00[oZEJY00?o0000oiQW
V?nHIiP01?nHIiP00ol0003oRGJ9ohUfR@09ohUfR@03o`000?n8MhSoR7N800OoR7N800?o0000oefR
GOmMXUd01OmMXUd00ol0003o:m@[ob_D:`07ob_D:`03o`000?miQWWoNHIi00OoNHIi00?o0000of6N
HOmQWV401?mQWV400ol0003oSG:=ohebS@08ohebS@03o`000?o2?L;o`Sg200So`Sg20_l0000>oiMX
U`Co00003?n]DZd2o`0000WoY5^T00?o0000ojAKY?nTFj@01onTFj@01?l0003ogR7NomhQg_l0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ok1?_on`Ck
00[on`Ck00?o0000on4NhOoQ7^401OoQ7^400ol0003o^TFjokY5^P07okY5^P;o00000ommPWd00ol0
003oZEJYojUFZ@09ojUFZ@03o`000?nHIiSoV6NH00KoV6NH00?o0000ohUfROn9MXT02On9MXT00ol0
003oR7N8ohQgR005ohQgR003o`000?mMXUgoGJ9M00KoGJ9M00?o0000ob_D:ol[e2/02?l[e2/00ol0
003oNHIiogV6N@06ogV6N@03o`000?mQWV7oHIiQ00CoHIiQ00?o0000ohebSOn=LXd02On=LXd4o`00
00?o`Sg20ol0000@oiMXU`05o`000?o4>lCoa3_4ol@ka?l000002_n]DZd00ol0003oY5^TojAKY00:
ojAKY0Ko00000onTFj@00ol0003ogR7No`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ok1?_on`Ck00Won`Ck00?o0000on4NhOoQ7^401?oQ7^400ol0
003o^TFjokY5^P0:okY5^P04o`000?mmPWgoOH9mo`0000[oZEJY00?o0000oiQWV?nHIiP01onHIiP0
0ol0003oRGJ9ohUfR@09ohUfR@03o`000?n8MhSoR7N800CoR7N800?o0000oefRGOmMXUd01omMXUd0
0ol0003o:m@[ob_D:`08ob_D:`;o00001_miQWT00ol0003oHIiQof6NH@05of6NH@03o`000?n=LXgo
SG:=00WoSG:=00Co0000ogb3O?mlPgcoO8=l0ol0000BoiMXU`03o`000?o4>lCoa3_400?oa3_40_l0
0006ojeB[@;o00003OnTFj@00ol0003ohacSon<Lh`03on<Lh`Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[on`Ck00?o0000on4NhOoQ7^400ooQ7^40
0ol0003o^TFjokY5^P0<okY5^P;o00002_nYEZT00ol0003oV6NHoiQWV008oiQWV003o`000?n9MXWo
RGJ900[oRGJ900?o0000ohQgR?n8MhP00_n8MhP00ol0003oGJ9MoefRG@08oefRG@03o`000?l[e2_o
:m@[00Ko:m@[0_l00002oeZUFP03o`000?miQWWoNHIi00;oNHIi00?o0000of6NHOmQWV401_mQWV40
0ol0003oSG:=ohebS@08ohebS@03o`000?mlPgcoO8=l00CoO8=l00?o0000oiMXUonGJ9L03onGJ9L0
0ol0003oa3_4ol@ka006ol@ka0;o00000on]DZd00ol0003oY5^TojAKY00=ojAKY003o`000?oS7>?o
hacS00OohacS0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ook1?/00ol0003ohAkQon4Nh@02on4Nh@03o`000?njAK[o^TFj
00ko^TFj00?o0000ojUFZOnYEZT01onYEZT00ol0003oV6NHoiQWV00:oiQWV003o`000?n9MXWoRGJ9
00WoRGJ900Go0000ohQgR?n8MhSoR7N8o`00000;oefRG@03o`000?l[e2_o:m@[00Co:m@[0_l00005
oeZUFP05o`000?miQWWoNHIiogV6NOl000002?mQWV400ol0003oSG:=ohebS@08ohebS@03o`000?ml
PgcoO8=l00GoO8=l00?o0000oiMXUonGJ9L03_nGJ9L00ol0003oa3_4ol@ka008ol@ka003o`000?n]
DZgo000000ooY5^T00?o0000on<LhooS7><02?oS7><01?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo/4n`04o`000?oQ7^7ohAkQo`00017o^TFj00?o0000ojUFZOnYEZT01_nYEZT00ol0003oV6NH
oiQWV00;oiQWV003o`000?n9MXWoRGJ900WoRGJ900Co0000ohQgR?n8MhSo00003?mMXUd00ol0003o
:m@[ob_D:`02ob_D:`;o00002?mJYEX00ol0003oNHIio`000009of6NH@03o`000?n=LXgoSG:=00So
SG:=00?o0000ogb3O?mlPg`01OmlPg`00ol0003oUfRGoiMXU`0=oiMXU`03o`000?o4>lCoa3_400[o
a3_400?o0000ojAKY?nTFj@03_nTFj@00ol0003ohacSon<Lh`07on<Lh`03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?on`Cko`000?l000000ol0000BokY5^P03o`00
0?nYEZWoZEJY00CoZEJY00?o0000oiQWV?nHIiP03?nHIiP00ol0003oRGJ9ohUfR@0:ohUfR@?o0000
3?mMXUd00ol0003o:m@[ob_D:`02o`0000_oFZEJ00?o0000of6NHOmQWV402?mQWV400ol0003oSG:=
ohebS@07ohebS@03o`000?mlPgcoO8=l00OoO8=l00?o0000oiMXUonGJ9L03?nGJ9L00ol0003oa3_4
ol@ka00;ol@ka0;o00003_nTFj@00ol0003ohacSon<Lh`07on<Lh`03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onLHiooW6>L00ooW6>L00ol0003o^TFjokY5^P0?okY5^P?o00000onY
EZT00ol0003oV6NHoiQWV00>oiQWV003o`000?n9MXWoRGJ900SoRGJ900Co0000ofJII_mVVFKoIYUV
0_l0000:oefRG@?o00003OmJYEX00ol0003oHIiQof6NH@08of6NH@03o`000?n=LXgoSG:=00OoSG:=
00?o0000ogb3O?mlPg`01omlPg`00ol0003oUfRGoiMXU`0;oiMXU`03o`000?o4>lCoa3_400coa3_4
00?o0000olPgb?l000000_l0000:ojAKY003o`000?oS7>?ohacS00SohacS00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oiaSWonLHi`04onLHi`03o`000?njAK[o^TFj00co^TFj0_l0
0003ojIIYP03o`000?nYEZWo0000017oV6NH00?o0000ohUfROn9MXT01on9MXT00ol0003oIYUVofJI
IP04ofJIIP;o00002?mMXUd00ol0003oFZEJoeZUFP0>oeZUFP;o00002?mQWV400ol0003oSG:=oheb
S@06ohebS@03o`000?mlPgcoO8=l00WoO8=l00?o0000oiMXUonGJ9L02OnGJ9L00ol0003oa3_4ol@k
a00=ol@ka003o`000?o8=lSob3O800;ob3O80ol00007ojAKY003o`000?oS7>?ohacS00OohacS00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oiaSWonLHi`05onLHi`03o`000?njAK[o
^TFj00Wo^TFj0_l00006ojIIYP03o`000?nHIiSoV6NH013oV6NH00?o0000ohUfROn9MXT01_n9MXT0
0ol0003oIYUVofJIIP07ofJIIP03o`000?mMXUgoGJ9M00CoGJ9M0ol0000>oeZUFP03o`000?m5^TGo
AKY500?o00001OmQWV400ol0003oSG:=ohebS@06ohebS@03o`000?mlPgcoO8=l00[oO8=l00?o0000
oiMXUonGJ9L02?nGJ9L00ol0003oa3_4ol@ka00=ol@ka003o`000?o8=lSob3O800Gob3O80ol00004
ojAKY003o`000?oS7>?ohacS00OohacS00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oiaSWonLHi`06onLHi`03o`000?njAK[o^TFj00Go^TFj0ol00008ojIIYP03o`000?nHIiSoV6NH
017oV6NH00Co0000ohUfROn9MXWoRGJ91?l0000;ofJIIP;o000000CoGJ9Mo`000?l0003o00000omd
Rg@2o`0000_oFZEJ00?o0000odFjAOm5^TD01?m5^TD2o`0000?oHIiQ00?o0000ohebSOn=LXd01_n=
LXd00ol0003oO8=logb3O00:ogb3O003o`000?nGJ9OoUfRG00OoUfRG00?o0000ol@ka?o4>l@03_o4
>l@00ol0003ob3O8olPgb008olPgb0Co00002_oS7><00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiaSWonLHi`07onLHi`03o`000?njAK[o^TFj00;o^TFj0_l0000<ojIIYP03o`000?nHIiSo
V6NH013oV6NH1?l00003ogb3O003o`000?mVVFKoIYUV00_oIYUV00?o0000ogB;M?mdRg@01_mdRg@0
0ol0003oFZEJoeZUFP07oeZUFP03o`000?m5^TGoAKY500OoAKY53?l0000>ogb3O003o`000?nGJ9Oo
UfRG00KoUfRG00?o0000ol@ka?o4>l@03_o4>l@00ol0003ob3O8olPgb00;olPgb003o`000?oS7>?o
hacS00OohacS00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oW6>OoiaSW00WoiaSW00Co0000okY5
^_l0003o00003_nVFJH00ol0003oV6NHoiQWV00?oiQWV003o`000?mlPgcoO8=l00KoO8=l00?o0000
ofJII_mVVFH02_mVVFH00ol0003oM8]dogB;M007ogB;M0;o00001_mJYEX00ol0003oAKY5odFjA@08
odFjA@03o`000?nDJiCoU6^D00SoU6^D00?o0000ogb3O?mlPg`03?mlPg`00ol0003oUfRGoiMXU`05
oiMXU`03o`000?o4>lCoa3_400ooa3_40_l0000=olPgb003o`000?oS7>?ohacS00KohacS00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oW6>OoiaSW00[oiaSW00?o0000ojIIY_nVFJH03_nVFJH00ol0
003oV6NHoiQWV00>oiQWV003o`000?mlPgcoO8=l00OoO8=l00?o0000ofJII_mVVFH02_mVVFH00ol0
003oM8]dogB;M009ogB;M0;o00000omJYEX00ol0003oAKY5odFjA@09odFjA@03o`000?nDJiCoU6^D
00WoU6^D00?o0000ogb3O?mlPg`02_mlPg`4o`0000CoUfRG00?o0000ol@ka?o4>l@04?o4>l@01?l0
003oaSW6o`000?l0000<olPgb003o`000?oS7>?ohacS00GohacS00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oW6>OoiaSW00[oiaSW00?o0000ojIIY_nVFJH03onVFJH@o`0000[oO8=l00?o0000ofJI
I_mVVFH02OmVVFH00ol0003oC[5>o`00000<ogB;M005o`000?mJYE[o0000odNhAol000002_m5^TD0
0ol0003oU6^DoiA[U009oiA[U003o`000?mlPgcoO8=l00OoO8=l0ol00004oimOW`?o000000?oUfRG
o`000?o4>l@04Oo4>l@01?l0003oaSW6olHia_o6>LH2o`0000_ob3O800?o0000on<LhooS7><00ooS
7><00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onLHiooW6>L02_oW6>L00ol0003oYUVVojIIYP0?
ojIIYP03o`000?nOH9ooWf2O00coWf2O00?o0000ogb3O?mlPg`02OmlPg`00ol0003oIYUVofJIIP07
ofJIIP04o`000?m>/DkoC[5>o`0000goM8]d00Go0000odNhAom7^4OoAkQ7o`000009odFjA@03o`00
0?nDJiCoU6^D00[oU6^D00?o0000ogb3O?mlPg`00omlPg`3o`0000[oWenO00?o0000ol@ka?o4>l@0
4?o4>l@00ol0003oaSW6olHiaP04olHiaP;o00002_o8=lP00ol0003ohacSon<Lh`04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coiaSW00?o0000ojIIY_nVFJH03onVFJH00ol0003oWf2OoimPW`0<oimPW`03o`000?ml
PgcoO8=l00WoO8=l00?o0000ofJII_mVVFH01_mVVFH00ol0003oC[5>odjaCP02odjaCP03o`000?md
RgCoM8]d00[oM8]d00?o0000odNhAom7^4L00_m7^4L00ol0003oAKY5odFjA@06odFjA@03o`000?nD
JiCoU6^D00[oU6^D00?o0000ogb3O?mlPg`00ol0000=oimOW`03o`000?o4>lCoa3_4013oa3_400?o
0000olHia_o6>LH01_o6>LH2o`0000Wob3O80_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;on`Ck00?o0000onLHiooW6>L02_oW6>L00ol0003oYUVVojIIYP0=ojIIYP?o00003onOH9l0
0ol0003oO8=logb3O008ogb3O003o`000?mVVFKoIYUV00GoIYUV00?o0000odjaC_m>/Dh00om>/Dh0
0ol0003oM8]dogB;M00:ogB;M003o`000?m7^4OoAkQ700?oAkQ700?o0000odFjAOm5^TD01Om5^TD0
0ol0003oU6^DoiA[U00;oiA[U0;o00004OnOGil00ol0003oa3_4ol@ka00?ol@ka003o`000?o6>LKo
aSW600SoaSW60_l00007olPgb003o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Oon`Ck00?o0000onLHiooW6>L02?oW6>L00ol0003oYUVVojIIYP09ojIIYPGo00000_n3O8<00ol0
003oWf2OoimPW`0=oimPW`03o`000?mlPgcoO8=l00WoO8=l00?o0000ofJII_mVVFH01?mVVFH00ol0
003oC[5>odjaCP04odjaCP03o`000?mdRgCoM8]d00SoM8]d00?o0000odNhAom7^4L01Om7^4L00ol0
003oAKY5odFjA@04odFjA@03o`000?nDJiCoU6^D00_oU6^D00?o0000oimOWonOGil04?nOGil00ol0
003oa3_4ol@ka00?ol@ka003o`000?o6>LKoaSW600[oaSW60_l00004olPgb003o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ok1?/00ol0003oiaSWonLHi`07onLHi`03o`000?nVFJKoYUVV00CoYUVV1Ol00007oh=lP`03
o`000?nOH9ooWf2O00goWf2O00?o0000ogb3O?mlPg`02OmlPg`00ol0003oIYUVofJIIP03ofJIIP03
o`000?m>/DkoC[5>00GoC[5>00?o0000ogB;M?mdRg@02?mdRg@00ol0003oAkQ7odNhA`06odNhA`03
o`000?m5^TGoAKY500?oAKY500?o0000oiA[U?nDJi@02onDJi@00ol0003oWenOoimOW`0@oimOW`03
o`000?o4>lCoa3_400ooa3_400?o0000olHia_o6>LH03?o6>LH2o`000003olPgb?l0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oW6>OoiaSW00OoiaSW00?o0000ojIIY_l00000
1?l0000<oh=lP`03o`000?nOH9ooWf2O00koWf2O00?o0000ogb3O?mlPg`02?mlPg`00ol0003oIYUV
ofJIIP02ofJIIP03o`000?m>/DkoC[5>00OoC[5>00?o0000ogB;M?mdRg@01omdRg@00ol0003oAkQ7
odNhA`07odNhA`03o`000?m5^TGoAKY500;oAKY500?o0000oiA[U?nDJi@02onDJi@00ol0003oWenO
oimOW`0AoimOW`03o`000?o4>lCoa3_400goa3_400?o0000olHia_o6>LH03oo6>LH00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onLHiooW6>L01OoW6>L3o`00017oPgb300?o0000oimPWonOH9l03_nO
H9l00ol0003oO8=logb3O009ogb3O004o`000?mVVFKoIYUVo`0000[oC[5>00?o0000ogB;M?mdRg@0
1omdRg@00ol0003oAkQ7odNhA`08odNhA`05o`000?m5^TGoAKY5odFjAOl000003OnDJi@00ol0003o
WenOoimOW`0AoimOW`?o00003Oo4>l@00ol0003oaSW6olHiaP0?olHiaP03o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
n`Ckoo/4n`0=oo/4n`?o00000_oW6>L2o`0000;o]4^d00?o0000oh=lPon3O8<03on3O8<00ol0003o
Wf2OoimPW`0>oimPW`03o`000?mlPgcoO8=l00SoO8=l1Ol0000;odjaCP03o`000?mdRgCoM8]d00Ko
M8]d00?o0000odNhAom7^4L02Om7^4L01?l0003oAKY5odFjAOl0000=oiA[U003o`000?nOGiooWenO
017oWenO00?o0000ogb3O?mlPg`00ol0000:ol@ka0Co00003Oo6>LH00ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00co
n`Ck00Co0000on<LhooS7>?ohacS0_l00005okA;]003o`000?n3O8?oPgb300koPgb300?o0000oimP
WonOH9l03_nOH9l00ol0003oO8=logb3O007ogb3O003o`000?mjQG[oNXEj00?oNXEj00?o0000odja
C_m>/Dh02?m>/Dh00ol0003oM8]dogB;M005ogB;M003o`000?m7^4OoAkQ700[oAkQ71Ol0000<oiA[
U003o`000?nOGiooWenO013oWenO00?o0000ogb3O?mlPg`01?mlPg`3o`0000Koa3_400?o0000oldb
cOo=</d00_o=</d5o`0000SoaSW600?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oS7>?ohacS00?o
hacS00?o0000okA;]?ndBk@01?ndBk@00ol0003oPgb3oh=lP`0=oh=lP`03o`000?nOH9ooWf2O00oo
Wf2O00?o0000ogb3O?mlPg`01?mlPg`2o`0000OoNXEj00?o0000odjaC_m>/Dh01om>/DhEo`0000Go
E:]D00?o0000oiA[U?nDJi@02?nDJi@3o`00013oWenO00?o0000ogb3O?mlPg`02?mlPg`3o`0000;o
a3_400?o0000oldbcOo=</d02?o=</d5o`0000?oaSW600?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?oS7>?ohacS00CohacS00?o0000okA;]?ndBk@01OndBk@00ol0003oPgb3oh=lP`0;oh=lP`Co0000
3onOH9l00ol0003oO8=logb3O003ogb3O003o`000?mjQG[oNXEj00SoNXEj00?o0000odjaC_m>/Dh0
1?m>/Dh2o`0000SoNXEj00?o0000ofVFJOmYUVT02?mYUVT00ol0003oE:]DoeB[E005oeB[E0;o0000
1_nDJi@2o`0000?oR7N800?o0000oimOWonOGil03?nOGil00ol0003oO8=logb3O00<ogb3O0;o0000
4?o=</d3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02Ook1?/00ol0003ohacSon<Lh`05on<Lh`03o`000?ndBkCo]4^d00Ko]4^d00?o
0000oh=lPon3O8<02On3O8<00ol0003oJiA[o`000002ogj1OP?o00003?nOH9l01?l0003oO8=logb3
O?mlPg`2o`0000coNXEj00?o0000odjaC_m>/Dh00_m>/Dh00ol0003oNXEjogZ5NP08ogZ5NP03o`00
0?mYUVWoJIIY00SoJIIY00?o0000oeB[E?mDZe@01omDZe@00ol0003oU6^DoiA[U002oiA[U003o`00
0?n8MhSoR7N800CoR7N80_l0000;oimOW`03o`000?mlPgcoO8=l00coO8=l00?o0000oiIYU_l00000
4_o=</d00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo/4nook1?/02?ok1?/00ol0003ohacSon<Lh`06on<Lh`03o`000?ndBkCo]4^d00Oo]4^d00?o
0000oh=lPon3O8<01_n3O8<2o`0000;oJiA[00?o0000ogj1O_mnPGh00omnPGh3o`0000[oWf2O00?o
0000ogb3O?l000003omjQGX01?l0003oC[5>o`000?l0000;ogZ5NP03o`000?mYUVWoJIIY00SoJIIY
00?o0000oeB[E?mDZe@02?mDZe@01?l0003oU6^Do`000?l00009ohQgR003o`000?nOGiooWenO00Oo
WenO00?o0000ogb3O?mlPg`03?mlPg`01?l0003oUVVFoiIYU_l0000Coldbc@03o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
n`Ck00?o0000on<LhooS7><01ooS7><00ol0003o]4^dokA;]008okA;]003o`000?n3O8?oPgb300Co
Pgb300?o0000of^DJom[U6/00om[U6/00ol0003oOX5nogj1OP05ogj1OP?o00001_nOH9l4o`00013o
NXEj00?o0000ogZ5N_mjQGX03?mjQGX00ol0003oJIIYofVFJ@07ofVFJ@03o`000?mDZeCoE:]D00Wo
E:]D00?o0000ohQgR?n8MhP02_n8MhP2o`0000KoWenO00?o0000ogb3O?mlPg`03?mlPg`00ol0003o
UVVFoiIYUP02oiIYUP03o`000?o=</gocC;=00oocC;=00?o0000omhQg_l000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo/4nook1?/0
1?ok1?/00ol0003ohacSon<Lh`08on<Lh`03o`000?ndBkCo]4^d00Wo]4^d00Co0000oh=lPon3O8?o
Pgb30_l00006of^DJ`03o`000?mnPGkoOX5n00SoOX5n0ol000000onOH9oo0000o`000004ohAkQ003
o`000?mjQG[oNXEj00goNXEj00?o0000ogZ5N_mjQGX03?mjQGX00ol0003oJIIYofVFJ@07ofVFJ@03
o`000?mDZeCoE:]D00WoE:]D00?o0000ohQgR?n8MhP03?n8MhP00ol0003oWenOoimOW`03o`0000ko
O8=l00?o0000oiIYU_nFJIH00onFJIH00ol0003ocC;=oldbc@0>oldbc@05o`000?oN8MkogR7NomhQ
g_l000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo/4nook1?/00_ok1?/00ol0003ohacSon<Lh`09on<Lh`03o`000?ndBkCo]4^d00[o
]4^d00?o0000oh=lPol000002?m[U6/00ol0003oOX5nogj1OP0;ogj1OP03o`000?n4NhCoQ7^400Go
Q7^400?o0000ogZ5N_mjQGX03?mjQGX00ol0003oNXEjogZ5NP0<ogZ5NP03o`000?mYUVWoJIIY00Oo
JIIY00?o0000oeB[E?mDZe@02?mDZe@2o`0000ooR7N80_l00002ohebS@03o`000?mlPgcoO8=l00_o
O8=l00?o0000oiIYU_nFJIH01?nFJIH00ol0003ocC;=oldbc@0=oldbc@03o`000?oN8MkogR7N00?o
gR7N00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on<Lh`03o`000?ndBkCo]4^d00_o]4^d00?o0000of^DJom[U6/0
1om[U6/00ol0003oOX5nogj1OP0;ogj1OP03o`000?n4NhCoQ7^400KoQ7^400?o0000ogZ5N_mjQGX0
2omjQGX2o`0000goNXEj00?o0000ofVFJOmYUVT01omYUVT00ol0003oE:]DoeB[E007oeB[E004o`00
0?mQWV7oHIiQo`0000koR7N800?o0000ohebSOn=LXd00_n=LXd00ol0003oO8=logb3O009ogb3O003
o`000?nFJIKoUVVF00KoUVVF00?o0000oldbcOo=</d02oo=</d00ol0003ogR7NomhQgP05omhQgP04
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000SohacS00?o0000okA;]?ndBk@02_ndBk@2o`0000Wo
JiA[00?o0000ogj1O_mnPGh02omnPGh00ol0003oQ7^4ohAkQ007ohAkQ003o`000?mjQG[oNXEj00Wo
NXEj00Co0000odBkA?m4^dCo00003?mjQGX00ol0003oJIIYofVFJ@07ofVFJ@03o`000?mDZeCoE:]D
00KoE:]D00Go0000of6NHOmQWV7oHIiQo`00000>ohQgR003o`000?n=LXgoSG:=00?oSG:=00?o0000
ogb3O?mlPg`01omlPg`00ol0003oUVVFoiIYUP07oiIYUP03o`000?o=</gocC;=00[ocC;=00?o0000
omhQg_oN8Mh01ooN8Mh00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006on<Lh`03o`000?ndBkCo]4^d
00Wo]4^d00Co0000oi5^TOnAKY7o00002Om[U6/00ol0003oOX5nogj1OP09ogj1OP03o`000?n4NhCo
Q7^400WoQ7^400?o0000ogZ5N_mjQGX01omjQGX00ol0003oA;]4odBkA002odBkA003o`000?mjQG[o
NXEj00WoNXEj00?o0000ofVFJOmYUVT01omYUVT00ol0003oE:]DoeB[E005oeB[E003o`000?mQWV7o
HIiQ00?oHIiQ00?o0000ohQgR?n8MhP02_n8MhP00ol0003oSG:=ohebS@05ohebS@03o`000?mlPgco
O8=l00GoO8=l00?o0000oiIYU_nFJIH02?nFJIH00ol0003ocC;=oldbc@09oldbc@03o`000?oN8Mko
gR7N00SogR7N00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oS7><3o`0000Wo]4^d00?o0000oi5^
TOnAKY400_nAKY400ol0003oJiA[of^DJ`06of^DJ`03o`000?mnPGkoOX5n00WoOX5n00?o0000ohAk
Q?n4Nh@02_n4Nh@00ol0003oNXEjogZ5NP05ogZ5NP03o`000?m4^dCoA;]400CoA;]400?o0000ogZ5
N_mjQGX02?mjQGX00ol0003oJIIYofVFJ@07ofVFJ@03o`000?mDZeCoE:]D00CoE:]D00?o0000of6N
HOmQWV401?mQWV400ol0003oR7N8ohQgR00:ohQgR003o`000?n=LXgoSG:=00KoSG:=00?o0000ogb3
O?mlPg`00omlPg`00ol0003oUVVFoiIYUP09oiIYUP03o`000?o=</gocC;=00SocC;=00?o0000omhQ
g_oN8Mh02OoN8Mh00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003om`Sg0?o00001OndBk@00ol0003o
TFjAoi5^T@03oi5^T@03o`000?m[U6_oJiA[00KoJiA[00?o0000ogj1O_mnPGh02OmnPGh00ol0003o
Q7^4ohAkQ00;ohAkQ003o`000?mjQG[oNXEj00?oNXEj00?o0000odBkA?m4^d@01_m4^d@00ol0003o
NXEjogZ5NP08ogZ5NP03o`000?mYUVWoJIIY00KoJIIY00?o0000oeB[E?mDZe@00_mDZe@2o`0000So
HIiQ00?o0000ohQgR?n8MhP02On8MhP00ol0003oSG:=ohebS@07ohebS@05o`000?mlPgcoO8=logb3
O?l000003OnFJIH00ol0003ocC;=oldbc@06oldbc@03o`000?oN8MkogR7N00[ogR7N00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oL8mcog2?L00Gog2?L0ol000000ondBkCo0000oi5^T@06oi5^T@03
o`000?m[U6_oJiA[00GoJiA[00?o0000ogj1O_mnPGh02OmnPGh00ol0003oQ7^4ohAkQ00<ohAkQ005
o`000?mjQG[oNXEjogZ5N_l000002_m4^d@00ol0003oNXEjogZ5NP07ogZ5NP03o`000?mYUVWoJIIY
00KoJIIY00?o0000oeB[E?l000000_l000000onAKY7o0000of6NH@07of6NH@03o`000?n8MhSoR7N8
00SoR7N800?o0000ohebSOn=LXd02On=LXd00ol0003oO8=lo`00000=oiIYUPCo00001Oo=</d00ol0
003ogR7NomhQgP0;omhQgP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003og2?Lom`Sg008om`Sg003
o`000?nAKY7oTFjA00OoTFjA00?o0000of^DJom[U6/01?m[U6/00ol0003oOX5nogj1OP09ogj1OP03
o`000?n4NhCoQ7^400goQ7^400?o0000ogZ5N_l000003?m4^d@:o`0000OoJIIY0ol00005oi5^T@03
o`000?mQWV7oHIiQ00KoHIiQ00?o0000ohQgR?n8MhP01on8MhP00ol0003oSG:=ohebS@0:ohebS@03
o`000?nFJIKoUVVF00_oUVVF00?o0000okQ7^?nhAkP00_nhAkP3o`000003oldbcOl0003ogR7N00_o
gR7N0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000om`Sg?oL8m`02OoL8m`00ol0003oTFjAoi5^T@07oi5^T@03o`00
0?m[U6_oJiA[00GoJiA[00?o0000ogj1O_mnPGh01omnPGh00ol0003oQ7^4ohAkQ00?ohAkQ0;o0000
2om4^d@00ol0003oQWV6ohIiQP07ohIiQP03o`000?mYUVWoJIIY00;oJIIY0ol00008oi5^T@03o`00
0?mQWV7oHIiQ00KoHIiQ00?o0000ohQgR?n8MhP01on8MhP00ol0003oSG:=ohebS@0:ohebS@03o`00
0?nFJIKoUVVF00[oUVVF00?o0000okQ7^?nhAkP01_nhAkP00ol0003ogR7NomhQgP08omhQgP?o0000
0_oW6>L00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000om`Sg?oL8m`02OoL8m`00ol0003oTFjAoi5^
T@08oi5^T@03o`000?m[U6_oJiA[00CoJiA[00?o0000ogj1O_mnPGh01omnPGh00ol0003oQ7^4ohAk
Q00>ohAkQ004o`000?mFZEKoEZUFo`0000WoA;]400?o0000ohIiQ_n6NHH02On6NHH01?l0003oJIIY
o`000?l0000<oi5^T@03o`000?mQWV7oHIiQ00KoHIiQ00?o0000ohQgR?n8MhP01_n8MhP00ol0003o
SG:=ohebS@0;ohebS@03o`000?nFJIKoUVVF00OoUVVF0_l00009okQ7^003o`000?oN8MkogR7N00Co
gR7N1?l00006onLHi`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003og2?Lom`Sg009om`Sg003o`00
0?nAKY7oTFjA00SoTFjA00?o0000of^DJom[U6/00om[U6/>o`0000goQ7^400?o0000oeJYE_mFZEH0
0_mFZEH00ol0003oA;]4odBkA005odBkA003o`000?n6NHKoQWV600_oQWV600?o0000oi5^TOnAKY40
3?nAKY400ol0003oHIiQof6NH@06of6NH@03o`000?n8MhSoR7N800GoR7N800?o0000ohebSOn=LXd0
3?n=LXd00ol0003oUVVFoiIYUP06oiIYUP03o`000?nhAkSo^4Nh00[o^4Nh00?o0000omhQg_oN8Mh0
0ol0000:onLHi`?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oL8mcog2?L00_og2?L00?o0000oi5^TOnAKY402?nA
KY401Ol0003oJiA[of^DJom[U6_o000000_oMXUf00?o0000oc3?<?l`cc000ol00009ohAkQ003o`00
0?mFZEKoEZUF00CoEZUF00?o0000odBkA?m4^d@00om4^d@00ol0003oQWV6ohIiQP0<ohIiQP03o`00
0?nAKY7oTFjA00goTFjA00?o0000of6NHOmQWV401_mQWV400ol0003oR7N8ohQgR003ohQgR0?o0000
3On=LXd00ol0003oUVVFoiIYUP05oiIYUP03o`000?nhAkSo^4Nh00co^4Nh0_l0000=onLHi`03o`00
0?ol0ocoo0?l00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oL8mcog2?L00_og2?L00?o0000oi5^TOnAKY402?nA
KY44o`0000coMXUf00?o0000oc3?<?l`cc000ol`cc03o`0000GoQ7^400?o0000oeJYE_mFZEH01_mF
ZEH01Ol0003oA;]4odBkA?m4^dCo000000ooQWV600?o0000oi5^TOnAKY403OnAKY400ol0003oHIiQ
of6NH@06of6NH@03o`000?n8MhSoR7N800?o00000omUVVD00ol0003oSG:=ohebS@0;ohebS@03o`00
0?nFJIKoUVVF00?oUVVF00?o0000okQ7^?nhAkP03OnhAkP00ol0003oiaSWonLHi`0;onLHi`03o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000om`Sg?oL8m`02_oL8m`3o`0000KoTFjA0ol0
0003ohAkQ003o`000?mfRGKoMXUf00[oMXUf00?o0000oc3?<?l`cc001_l`cc03o`000003ohAkQ?l0
003oEZUF00WoEZUF00?o0000odBkA?l000004?n6NHH00ol0003oTFjAoi5^T@0=oi5^T@03o`000?mQ
WV7oHIiQ00OoHIiQ0_l00007ofFJI@03o`000?n=LXgoSG:=00[oSG:=00Co0000oiIYU_nFJIKoUVVF
0ol0000?okQ7^003o`000?oW6>OoiaSW00_oiaSW00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000om`Sg?oL8m`02_oL
8m`01?l0003o`Sg2ol8m`_o2?L82o`000004oi5^TOl0003o0000o`0000KoQ7^400?o0000ogJ9M_mf
RGH02_mfRGH00ol0003o<<l`oc3?<009oc3?<003o`000?mFZEKoEZUF00[oEZUF00?o0000ohIiQ_n6
NHH03on6NHH00ol0003oTFjAoi5^T@0>oi5^T@03o`000?mQWV7oHIiQ00KoHIiQ00?o0000ofFJIOmU
VVD01omUVVD4o`0000SoSG:=00Co0000oiIYU_nFJIKo00000omgR7L2o`0000go^4Nh00?o0000onLH
iooW6>L02_oW6>L00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000om`Sg?oL8m`02OoL8m`00ol0003o
`Sg2ol8m`P04ol8m`P03o`000?n4NhCoQ7^400OoQ7^400?o0000ogJ9M_mfRGH02OmfRGH00ol0003o
<<l`oc3?<00:oc3?<003o`000?mFZEKoEZUF00[oEZUF00?o0000ohIiQ_n6NHH03on6NHH00ol0003o
TFjAoi5^T@0>oi5^T@03o`000?mQWV7oHIiQ00GoHIiQ00?o0000ofFJIOmUVVD02?mUVVD01?l0003o
NXEjogZ5N_mjQGX7o`0000;oSG:=0_l00006ogN8M`;o00003?nhAkP00ol0003oiaSWonLHi`09onLH
i`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003og2?Lom`Sg008om`Sg003o`000?o2?L;o`Sg200Go
`Sg200?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oMXUfogJ9MP08ogJ9MP03o`000?l`cc3o<<l`00[o
<<l`00?o0000oeJYE_mFZEH02omFZEH00ol0003oQWV6ohIiQP0>ohIiQP03o`000?nAKY7oTFjA00ko
TFjA1Ol00002of6NH@03o`000?mUVVGoIIYU00WoIIYU00?o0000ogZ5N_mjQGX02?mjQGX3o`0000Wo
MhQg0_l0000:okQ7^003o`000?oW6>OoiaSW00SoiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oL8mcog2?L00Sog2?L00?o0000ol8m`_o2?L801oo2?L800ol0003oQ7^4ohAkQ007ohAkQ003o`00
0?mfRGKoMXUf00SoMXUf00?o0000oc3?<?l`cc002_l`cc000ol0003oEZUFoeJYEP0:oeJYEP;o0000
3_n6NHH3o`0000goTFjA0ol00005oiEZU@;o00002omUVVD00ol0003oNXEjogZ5NP0;ogZ5NP;o0000
2_mgR7L2o`0000Oo^4Nh0ol00009onLHi`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:ol8m`P03o`00
0?n4NhCoQ7^400OoQ7^400?o0000ogJ9M_mfRGH02?mfRGH>o`0000WoEZUF0ol000000olfbCKo0000
ohIiQP0:ohIiQP?o00000_nJIIX00ol0003oTFjAoi5^T@09oi5^T@;o00002OnEJYD00ol0003oIIYU
ofFJI@09ofFJI@03o`000?mjQG[oNXEj00_oNXEj00?o0000ohacS?l000002omgR7L2o`0000Co^4Nh
00Co0000om/TfooK9=_ofbCK0_l00007onLHi`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003o`Sg2
ol8m`P09ol8m`P03o`000?n4NhCoQ7^400KoQ7^400?o0000ogJ9M_mfRGH02?mfRGH00ol0003o?klo
ocno?`0:ocno?`03o`000?mFZEKoEZUF00CoEZUF0ol00005ocK9=P03o`000?n6NHKoQWV600CoQWV6
1?l00006oiYUVP03o`000?nAKY7oTFjA00KoTFjA0_l0000;oiEZU@03o`000?mUVVGoIIYU00WoIIYU
00?o0000ogZ5N_mjQGX02_mjQGX01Ol0003oS7><ohacS?n<Lhco000000coMhQg0_l000000onhAkSo
0000om/Tf`05om/Tf`03o`000?oW6>OoiaSW00?oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o2?L;o`Sg200So`Sg200?o0000ohAkQ?n4Nh@01_n4Nh@00ol0003oMXUfogJ9MP07ogJ9MP03o`00
0?lo_coo?klo00_o?klo00?o0000oeJYE_mFZEH00_mFZEH2o`0000Wo=/Tf00?o0000ohIiQ_n6NHH0
0ol0000;oiYUVP03o`000?nAKY7oTFjA00;oTFjA0ol0000>oiEZU@03o`000?mUVVGoIIYU00OoIIYU
00?o0000ogZ5N_mjQGX02omjQGX00ol0003oS7><ohacS002ohacS003o`000?mgR7OoMhQg00_oMhQg
00?o0000om/TfooK9=/01_oK9=/2o`0000?oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o2
?L;o`Sg200Oo`Sg200?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oMXUfogJ9MP05ogJ9MP?o00003Olo
_cl4o`0000_o=/Tf0ol0000?oiYUVP04o`000?nAKY7o0000o`00017oUFZE00?o0000ofFJIOmUVVD0
1omUVVD00ol0003oNXEjogZ5NP0:ogZ5NP03o`000?n<LhcoS7><00CoS7><00?o0000ogN8MomgR7L0
1omgR7L3o`0000_ofbCK1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol8m`_o2?L802?o2?L800ol0003oQ7^4ohAk
Q006ohAkQ003o`000?mfRGKoMXUf00;oMXUf0ol00003of2OH003o`000?lo_coo?klo00[o?klo00?o
0000ocK9=_lfbCH02olfbCH00ol0003o@[e2o`00000AoiYUVP03o`000?nEJYGoUFZE017oUFZE00?o
0000ofFJIOmUVVD01omUVVD00ol0003oNXEjogZ5NP0:ogZ5NP03o`000?n<LhcoS7><00GoS7><00Co
0000ogN8MomgR7OoMhQg1Ol00002ohacS003o`000?oK9=_ofbCK00WofbCK00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000ol8m`_o2?L801oo2?L800ol0003oQ7^4ohAkQ005ohAkQ0?o0000
00?oMXUfo`000?l000001omPWf000ol0003o?kloocno?`08ocno?`?o00002_lfbCH2o`0000;o@[e2
00?o0000oiYUV_nJIIX03onJIIX00ol0003oUFZEoiEZU@0AoiEZU@03o`000?mUVVGoIIYU00OoIIYU
00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oS7><ohacS007ohacS0?o00001on<Lh`00ol0003ofbCK
om/Tf`09om/Tf`03o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000ol8m`_o2?L801oo2
?L84o`0000;oQ7^40_l00003oi5^T@03o`000?mPWf3oH9mP00SoH9mP0_l00006ocno?`;o00000om7
^4L00ol0003o=/TfocK9=P06ocK9=P03o`000?m2_D;o@[e200?o@[e200?o0000oiYUV_nJIIX03_nJ
IIX00ol0003oUFZEoiEZU@0BoiEZU@03o`000?mUVVGoIIYU00GoIIYU00?o0000ogZ5N_mjQGX02Omj
QGX00ol0003oS7><ohacS008ohacS003o`000?n<LhcoS7><00OoS7><00?o0000om/TfooK9=/02?oK
9=/00ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o2?L;o`Sg200Co`Sg20_l00004
om</d`;o00001OnAKY400ol0003oH9mPof2OH00:of2OH003o`000?lo_coo?klo00;o?klo00?o0000
odNhAom7^4L01?m7^4L00ol0003o=/TfocK9=P04ocK9=P03o`000?m2_D;o@[e200Co@[e200?o0000
oiYUV_nJIIX03_nJIIX00ol0003oUFZEoiEZU@0BoiEZU@[o00002_mjQGX00ol0003oS7><ohacS008
ohacS003o`000?n<LhcoS7><00OoS7><00?o0000om/TfooK9=/02?oK9=/00ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003o`Sg2ol8m`_o2?L82o`0000OodbcC00?o0000oi5^TOnAKY401?nAKY40
0ol0003oH9mPof2OH00:of2OH004o`000?lo_coo0000o`0000SoAkQ700Co0000ocK9=_lfbCKo=/Tf
0_l00007od:m@P03o`000?nJII[oVVFJ00koVVFJ00?o0000oiEZUOnEJYD04_nEJYD00ol0003oM8]d
ogB;M007ogB;M003o`000?mjQG[oNXEj00KoNXEj00?o0000ohacS?n<Lh`02_n<Lh`00ol0003oS7><
ohacS006ohacS003o`000?oK9=_ofbCK00SofbCK00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o2
?L;o0000o`0000WodbcC00?o0000oi5^TOnAKY401?nAKY400ol0003oH9mPof2OH00;of2OH003o`00
0?m7^4OoAkQ700WoAkQ700?o0000ocK9=_l000002Om2_D800ol0003oVVFJoiYUVP0>oiYUVP;o0000
4_nEJYD00ol0003oM8]dogB;M009ogB;M0;o00001_mjQGX00ol0003oS7><ohacS00:ohacS003o`00
0?n<LhcoS7><00KoS7><00?o0000om/TfooK9=/02?oK9=/00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om</dooC;=<02OoC;=<00ol0003oTFjAoi5^T@05oi5^T@03o`000?mPWf3oH9mP00[oH9mP00?o
0000odNhAom7^4L02_m7^4L2o`0000Wo@[e200?o0000oiYUV_nJIIX03_nJIIX00ol0003oPgb3o`00
0002o`0000ooUFZE00?o0000ogB;M?mdRg@02omdRg@00ol0003oNXEjogZ5NP03o`0000goS7><00?o
0000ohacS?n<Lh`01_n<Lh`00ol0003ofbCKom/Tf`07om/Tf`03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003odbcCom</d`09om</d`03o`000?nAKY7oTFjA00GoTFjA00?o0000of2OH?mPWf002OmPWf02
o`0000_oAkQ70_l0000;od:m@P03o`000?nJII[oVVFJ00coVVFJ00?o0000oh=lPon3O8<00on3O8<3
o`0000coUFZE00?o0000ogB;M?mdRg@03?mdRg@2o`0000;oMXUf00?o0000ohacS?n<Lh`03?n<Lh`0
0ol0003oS7><ohacS005ohacS003o`000?oK9=_ofbCK00OofbCK00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oC;=?odbcC00[odbcC00?o0000oi5^TOnAKY401_nAKY400ol0003oH9mPof2OH007of2O
H003o`000?m>/Dko000000[oAkQ700Co0000oc?<<olcc3?o00002_m2_D800ol0003oVVFJoiYUVP0<
oiYUVP03o`000?n3O8?oPgb300KoPgb30_l00008oiEZU@;o00003omdRg@00ol0003oMXUfogJ9MP02
ogJ9MP03o`000?n<LhcoS7><00_oS7><00?o0000ohacS?n<Lh`01On<Lh`00ol0003ofbCKom/Tf`07
om/Tf`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odbcCom</d`0:om</d`03o`000?nAKY7oTFjA
00KoTFjA00?o0000of2OH?mPWf001_mPWf001Ol0003oC[5>odjaC_m>/Dko000000SoAkQ700?o0000
oc?<<olcc3<00_lcc3<00ol0003o@[e2od:m@P06od:m@PCo00003?nJIIX00ol0003oPgb3oh=lP`08
oh=lP`?o00000_nEJYD3o`000003ofn@Kol0003oM8]d00goM8]d00?o0000ogJ9M_mfRGH01?mfRGH0
0ol0003oS7><ohacS00:ohacS003o`000?n<LhcoS7><00GoS7><00?o0000om/TfooK9=/01_oK9=/0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om</dooC;=<02ooC;=<00ol0003oTFjAoi5^T@07oi5^
T@03o`000?mPWf3oH9mP00?oH9mP0_l00005odjaCP03o`000?m7^4OoAkQ700CoAkQ700?o0000oc?<
<olcc3<00olcc3<00ol0003o@[e2od:m@P05od:m@P03o`000?mSW6?oHiaS00;oHiaS0ol00007oiYU
VP;o00003_n3O8<2o`0000GoKi1_00?o0000ogB;M?mdRg@02_mdRg@00ol0003oMXUfogJ9MP05ogJ9
MP03o`000?n<LhcoS7><00_oS7><00?o0000ohacS?n<Lh`01?n<Lh`00ol0003ofbCKom/Tf`06om/T
f`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003odbcCom</d`0;om</d`03o`000?nAKY7oTFjA00Oo
TFjA00?o0000of2OH?mPWf000_mPWf000ol0003oC[5>odjaCP06odjaCP03o`000?m7^4OoAkQ700;o
AkQ700?o0000oc?<<olcc3<01Olcc3<00ol0003o@[e2od:m@P02od:m@P;o00002?mSW6<3o`0000;o
VVFJ0_l000000om]TVgo0000oh=lP`0=oh=lP`03o`000?m_T6ooKi1_00GoKi1_00?o0000ogB;M?md
Rg@02?mdRg@00ol0003oMXUfogJ9MP07ogJ9MP03o`000?n<LhcoS7><00[oS7><00?o0000ohacS?n<
Lh`01?n<Lh`00ol0003ofbCKom/Tf`06om/Tf`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003odbcC
om</d`0<om</d`03o`000?nAKY7oTFjA00SoTFjA00Co0000of2OH?mPWf3o00002Om>/Dh01Ol0003o
AkQ7odNhAom7^4Oo000000So<l`c00Go0000od:m@_m2_D;o@[e2o`00000=of>LH`;o00001?m]TVd0
0ol0003oPgb3oh=lP`0;oh=lP`03o`000?m_T6ooKi1_00KoKi1_00?o0000ogB;M?mdRg@01omdRg@0
0ol0003oMXUfogJ9MP08ogJ9MPCo00002?n<Lh`00ol0003oS7><ohacS004ohacS003o`000?oK9=_o
fbCK00KofbCK00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oC;=?odbcC00_odbcC0ol00009oi5^
T@03o`000?mPWf3o000000_oC[5>00?o0000odNhAol000002_lcc3<00ol0003o@[e2o`00000?of>L
H`03o`000?m]TVgoKI9]00;oKI9]00?o0000oh=lPon3O8<02on3O8<00ol0003oKi1_ofn@K`06ofn@
K`03o`000?mdRgCoM8]d00KoM8]d00?o0000ogJ9M_mfRGH02OmfRGH01?l0003oU6^DoiA[U?nDJi@7
o`0000;oS7><00?o0000ohacS?n<Lh`00on<Lh`00ol0003ofbCKom/Tf`05om/Tf`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oC;=?odbcC00SodbcC0ol00003oki1_P03o`000?nAKY7oTFjA00OoTFjA00?o0000odja
C_m>/Dh02om>/Dh00ol0003o<l`coc?<<`0:oc?<<`03o`000?mSW6?oHiaS00goHiaS00?o0000offB
KOm]TVd01?m]TVd00ol0003oPgb3oh=lP`09oh=lP`03o`000?m_T6ooKi1_00SoKi1_00?o0000ogB;
M?mdRg@00omdRg@2o`0000coMXUf00?o0000oiA[U?nDJi@02?nDJi@<o`0000?ofbCK0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om</dooC;=<01_oC;=<3o`0000Oo_T6n00?o0000oi5^TOnAKY401_nAKY400ol0003o
C[5>odjaCP0;odjaCP03o`000?lcc3?o<l`c00Wo<l`c0_l0000>of>LH`03o`000?m]TVgoKI9]00Go
KI9]00?o0000oh=lPon3O8<02On3O8<00ol0003oKi1_ofn@K`09ofn@K`03o`000?mdRgCo000000;o
00000_m]TVd00ol0003oMXUfogJ9MP08ogJ9MP03o`000?nDJiCoU6^D00coU6^D00?o0000om`Sg?oL
8m`01_oL8m`3o`0000?onPGj0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003odbcCom</d`03om</d`?o00002onn@Kh00ol0003oTFjA
oi5^T@04oi5^T@03o`000?m>/DkoC[5>00_oC[5>0ol00007oc?<<`?o000000?oEZUFo`000?mSW6<0
3OmSW6<00ol0003oKI9]offBK@06offBK@03o`000?n3O8?oPgb300SoPgb300?o0000ofn@Kom_T6l0
2_m_T6l00ol0003oKI9]offBK@04offBK@03o`000?mfRGKoMXUf00OoMXUf00?o0000oiA[U?nDJi@0
2onDJi@00ol0003og2?Lom`Sg008om`Sg003o`000?oj1O[onPGj00ConPGj0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om</dol0
003o0000o`0000oo_T6n00?o0000oi5^TOnAKY400onAKY4>o`0000?oBkA;0_l00002oc?<<`?o0000
1OmFZEH00ol0003oHiaSof>LH`0:of>LH`03o`000?m]TVgoKI9]00OoKI9]00?o0000oh=lPon3O8<0
2?n3O8<00ol0003oKi1_ofn@K`0:ofn@K`03o`000?m]TVgoKI9]00GoKI9]00?o0000ogJ9M_mfRGH0
1_mfRGH00ol0003oU6^DoiA[U00;oiA[U003o`000?oL8mcog2?L00Sog2?L00?o0000ooX5n_oj1OX0
1ooj1OX2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o_T6n00?o0000oi5^TOnAKY400_nAKY400ol0003oD:m@oe2_
D00:oe2_D003o`000?m;]4_oBkA;00?oBkA;0_l00009oeJYEP03o`000?mSW6?oHiaS00WoHiaS00?o
0000offBKOm]TVd02?m]TVd2o`0000SoPgb300?o0000ofn@Kom_T6l02Om_T6l00ol0003oKI9]offB
K@07offBK@03o`000?mfRGKoMXUf00CoMXUf00?o0000oiA[U?nDJi@02onDJi@00ol0003og2?Lom`S
g009om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o_T6noki1_P0?oki1_P?o000000?oTFjA
o`000?m@[e002om@[e000ol0003oBkA;od^dB`04od^dB`03o`000?mFZEKoEZUF00WoEZUF00?o0000
of>LHomSW6<01omSW6<00ol0003oKI9]offBK@09offBK@04o`000?mWV6Oo0000o`0000KoPgb300?o
0000ofn@Kom_T6l02Om_T6l00ol0003oKI9]offBK@08offBK@03o`000?mfRGKoMXUf00?oMXUf00?o
0000oiA[U?nDJi@02onDJi@00ol0003og2?Lom`Sg009om`Sg003o`000?oj1O[onPGj00WonPGj00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o_T6noki1_P0<oki1_P;o00000onfBKH2o`0000coD:m@00?o0000od^dBom;]4/01?m;]4/0
0ol0003oEZUFoeJYEP0:oeJYEPWo00002om]TVd00ol0003oIiQWofNHI`02ofNHI`?o00000_n3O8<0
0ol0003oKi1_ofn@K`0:ofn@K`03o`000?m]TVgoKI9]00WoKI9]00?o0000ogJ9M_mfRGH00_mfRGH0
0ol0003oU6^DoiA[U00:oiA[U003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX02_oj1OX0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_nn@Kh2o`0000Go]TVf00?o0000oh5nPOl000002_m@[e000ol0003oBkA;od^dB`06od^d
B`03o`000?mFZEKoEZUF00WoEZUF00?o0000oeJYE_mFZEH01OmFZEH00ol0003oKI9]offBK@09offB
K@03o`000?mWV6OoIiQW00GoIiQW0ol00009ofn@K`?o00003Om]TVd01Ol0003oMXUfogJ9M_mfRGKo
000000coU6^D00?o0000om`Sg?oL8m`02OoL8m`00ol0003onPGjooX5nP0:ooX5nP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000oki1
__nn@Kh01Onn@Kh2o`0000Oo]TVf00Co0000oh5nPOn1OX7o00002Om@[e000ol0003oBkA;od^dB`06
od^dB`03o`000?mFZEKoEZUF00SoEZUF00?o0000oeJYE_mFZEH01omFZEH00ol0003oKI9]offBK@07
offBK@03o`000?mWV6OoIiQW00SoIiQW0ol00002ofn@K`Go00000_m1_T400ol0003oKI9]offBK@0<
offBK@03o`000?mfRGKo000000coU6^D00?o0000om`Sg?oL8m`02_oL8m`00ol0003onPGjooX5nP0:
ooX5nP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000oki1__nn@Kh00_nn@Kh2o`0000So]TVf00?o0000oh5nPOn1OX400_n1OX45o`00
00CoD:m@00?o0000od^dBom;]4/01_m;]4/00ol0003oEZUFoeJYEP08oeJYEP03o`000?mFZEKoEZUF
00OoEZUF00?o0000offBKOm]TVd01om]TVd00ol0003oIiQWofNHI`08ofNHI`03o`000?lm`Sgo?L8m
00;o00002?m1_T400ol0003oKI9]offBK@0<offBK@Co00002_nDJi@00ol0003og2?Lom`Sg00:om`S
g003o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o_T6no`000?l0000:okI9]P03o`000?n1OX7oPGj1
00;oPGj100?o0000ob;M8_lRgB800_lRgB84o`0000WoBkA;00?o0000oeJYE_mFZEH02?mFZEH00ol0
003oEZUFoeJYEP08oeJYEP03o`000?m]TVgoKI9]00GoKI9]00?o0000ofNHIomWV6L02?mWV6L01Ol0
003o?L8mocg2?Olm`Sgo000000[o@Ki10ol0000;offBK@04o`000?o4>lCoa3_4ol@ka0Co00001OnD
Ji@00ol0003og2?Lom`Sg00;om`Sg003o`000?oj1O[onPGj00_onPGj00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o]TVfokI9]P0:
okI9]P03o`000?n1OX7oPGj100?oPGj100?o0000ob;M8_lRgB801?lRgB800ol0003oBkA;od^dB`07
od^dB`03o`000?mFZEKoEZUF00KoEZUF0_l0000;oeJYEP03o`000?m]TVgoKI9]00GoKI9]00?o0000
ofNHIomWV6L02?mWV6L00ol0003o?L8mocg2?@02ocg2?@03o`000?m1_T7o@Ki100Oo@Ki100?o0000
og^4NomkQ7/01?l00006offBK@03o`000?o4>lCoa3_400Koa3_40ol00002oiA[U003o`000?oL8mco
g2?L00_og2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nfBKKo]TVf00Wo]TVf00?o0000oh5n
POn1OX401?n1OX400ol0003o8]dRob;M8P05ob;M8P03o`000?m;]4_oBkA;00OoBkA;00?o0000oeJY
E_mFZEH00_mFZEH3o`000003of:MH_l0003oEZUF00[oEZUF00?o0000offBKOm]TVd01Om]TVd00ol0
003oIiQWofNHI`07ofNHI`03o`000?lm`Sgo?L8m00?o?L8m00?o0000od6n@Om1_T401om1_T400ol0
003oNhAkog^4N`04og^4N`?o00000_m]TVd00ol0003oa3_4ol@ka00:ol@ka0;o00003_oL8m`00ol0
003onPGjooX5nP0;ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000okI9]_nfBKH02OnfBKH00ol0003oPGj1oh5nP@04oh5nP@03
o`000?lRgB;o8]dR00Ko8]dR0_l00007od^dB`03o`000?mFZEKo000000;o00001OmRWF800ol0003o
EZUFoeJYEP08oeJYEP?o00001?m]TVd00ol0003oIiQWofNHI`08ofNHI`03o`000?lm`Sgo?L8m00Co
?L8m00?o0000od6n@Om1_T401_m1_T400ol0003oNhAkog^4N`07og^4N`;o00003_o4>l@00ol0003o
g2?Lom`Sg00;om`Sg003o`000?oj1O[onPGj00conPGj00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]TVfokI9]P08okI9]P03o`00
0?n1OX7oPGj100GoPGj100?o0000ob;M8_lRgB801?lRgB800ol0003oD:m@oe2_D003o`0000CoBkA;
0_l00008of:MHP03o`000?mFZEKoEZUF00OoEZUF00Co0000ohMhQon7N8OoQgR70ol000000om]TVgo
0000ofNHI`09ofNHI`03o`000?lm`Sgo?L8m00Co?L8m00?o0000od6n@Om1_T401Om1_T400ol0003o
NhAkog^4N`09og^4N`03o`000?o4>lCoa3_400goa3_400?o0000om`Sg?oL8m`02_oL8m`00ol0003o
nPGjooX5nP0<ooX5nP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000okI9]_nfBKH01onfBKH00ol0003oPGj1oh5nP@06oh5nP@03o`00
0?lRgB;o8]dR00?o8]dR00?o0000oe2_D?m@[e001?m@[e02o`000003od^dBol0003oHYeR00[oHYeR
00?o0000oeJYE_mFZEH01OmFZEH00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?mWV6OoIiQW00OoIiQW
0ol00007ocg2?@03o`000?m1_T7o@Ki100Co@Ki100?o0000og^4NomkQ7/02OmkQ7/00ol0003oa3_4
ol@ka00=ol@ka003o`000?oL8mcog2?L00[og2?L00?o0000ooX5n_oj1OX02ooj1OX00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nf
BKKo]TVf00Go]TVf0ol00009oh5nP@05o`000?lRgB;o8]dRob;M8_l000002Om@[e000ol0003oHYeR
of:MHP0;of:MHP03o`000?mFZEKoEZUF00?oEZUF00?o0000ohMhQon7N8L01_n7N8L00ol0003oIiQW
ofNHI`06ofNHI`05o`000?m[U6_oJiA[of^DJol000001olm`Sd00ol0003o@Ki1od6n@@03od6n@@03
o`000?mkQ7_oNhAk00WoNhAk00?o0000ol@ka?o4>l@03_o4>l@00ol0003og2?Lom`Sg009om`Sg003
o`000?oj1O[onPGj00[onPGj00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o]TVfo`000004o`0000;odbcC00?o0000oh5nPOn1OX40
1on1OX401?l0003o8]dRob;M8_l00009oe2_D0;o00003OmRWF800ol0003oEZUFoeJYEP02oeJYEP03
o`000?n7N8OoQgR700SoQgR700?o0000ofNHIomWV6L00omWV6L2o`0000GoJiA[00?o0000ocg2?Olm
`Sd01?lm`Sd00ol0003o@Ki1od6n@@03od6n@@03o`000?mkQ7_oNhAk00WoNhAk00?o0000ol@ka?o4
>l@03_o4>l@00ol0003og2?Lom`Sg009om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SodbcC
00?o0000oh5nPOn1OX401_n1OX400ol0003o8]dRo`000009oe2_D004o`000?meRWGoMHYeo`0000go
HYeR00Co0000oeJYE_mFZEKo00003?n7N8L01Ol0003oIiQWofNHIomWV6Oo000000SoJiA[0_l00005
ocg2?@03o`000?m1_T7o@Ki100;o@Ki100?o0000og^4NomkQ7/02OmkQ7/00ol0003oa3_4ol@ka00>
ol@ka003o`000?oL8mcog2?L00Wog2?L00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oC;=?odbcC
00OodbcC00?o0000oh5nPOn1OX401on1OX400ol0003oD:m@oe2_D007oe2_D003o`000?meRWGoMHYe
00;oMHYe00?o0000of:MH_mRWF802_mRWF800ol0003oEZUFo`00000>ohMhQ`03o`000?mWV6Oo0000
00_oJiA[00?o0000ocg2?Olm`Sd00_lm`Sd01Ol0003o@Ki1od6n@Om1_T7o000000coNhAk00?o0000
ol@ka?o4>l@03_o4>l@3o`0000Wog2?L00?o0000ooX5n_oj1OX02?oj1OX00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oC;=?odbcC
00WodbcC00?o0000oh5nPOn1OX401_n1OX400ol0003oD:m@oe2_D006oe2_D003o`000?meRWGoMHYe
00?oMHYe00?o0000of:MH_mRWF802omRWF800ol0003oQgR7ohMhQ`0>ohMhQ`03o`000?m[U6_oJiA[
00_oJiA[0_l00003ocg2?@04o`000?m1_T7o@Ki1o`0000[oNhAk0ol0000>ol@ka0;o00000ooj1OX2
o`0000Oog2?L00?o0000ooX5n_oj1OX01ooj1OX00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oC;=?odbcC00[odbcC00?o0000oh5n
POn1OX401?n1OX400ol0003oD:m@oe2_D006oe2_D003o`000?meRWGoMHYe00GoMHYe00?o0000of:M
H_mRWF801omRWF83o`00017oQgR700?o0000of^DJom[U6/03Om[U6/01Ol0003o?L8mocg2?Ol0003o
@Ki100Co00000omkQ7/5o`0000;o`Sg200?o0000ol@ka?o4>l@02_o4>l@2o`0000OonPGj0_l00004
om`Sg003o`000?oj1O[onPGj00SonPGj00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003odbcCom</d`0;om</d`03o`000?n1OX7oPGj1
00CoPGj100?o0000oe2_D?m@[e001Om@[e000ol0003oMHYeogF:M@06ogF:M@03o`000?mRWF;oHYeR
00CoHYeR0ol00002ofn@K`03o`000?n7N8OoQgR700ooQgR70_l0000?of^DJ`04o`000?lm`Sgo0000
o`0000CoKY5^0ol00008ol8m`P03o`000?o4>lCoa3_400Ooa3_40_l0000;ooX5nP;o00000_oL8m`0
0ol0003onPGjooX5nP07ooX5nP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om</dooC;=<03?oC;=<6o`0000OoD:m@00?o0000ogF:
MOmeRWD02?meRWD00ol0003oHYeRof:MHP03o`0000KoKi1_00?o0000ohMhQon7N8L03On7N8L01?l0
003oOX5nogj1O_l0000?of^DJ`03o`000?m^TFkoKY5^00GoKY5^00?o0000ol8m`_o2?L802?o2?L80
0ol0003oa3_4ol@ka005ol@ka003o`000?oj1O[onPGj00gonPGj0ol00008ooX5nP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oC;=<00ol0003oQWV6ohIiQP04ohIi
QP03o`000?m@[e3oD:m@00?oD:m@00?o0000ogF:MOmeRWD02_meRWD2o`0000[oKi1_00?o0000ohMh
Qon7N8L02on7N8L00ol0003oOX5nogj1OP02ogj1OP03o`000?m[U6_oJiA[00_oJiA[0_l00007ofjA
KP03o`000?o2?L;o`Sg200Wo`Sg200?o0000ol@ka?o4>l@00_o4>l@2o`0001;onPGj00?o0000ooX5
n_oj1OX00ooj1OX3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00co
nPGj00?o0000om</dooC;=<02ooC;=<00ol0003oQWV6ohIiQP06ohIiQP05o`000?m@[e3oD:m@oe2_
D?l000003OmeRWD00ol0003oKi1_ofn@K`0:ofn@K`03o`000?n7N8OoQgR700WoQgR700?o0000ogj1
O_mnPGh01?mnPGh00ol0003oJiA[of^DJ`08of^DJ`;o000000?o@ka3o`000?m^TFh01om^TFh00ol0
003o`Sg2ol8m`P09ol8m`P04o`000?o4>lCo0000o`0001ConPGj00?o0000ooX5n_oj1OX00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5nP03o`000?oC;=?odbcC
00WodbcC00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oD:m@o`00000=ogF:M@03o`000?m_T6ooKi1_
00_oKi1_00?o0000ohMhQon7N8L02?n7N8L00ol0003oOX5nogj1OP06ogj1OP03o`000?m[U6_oJiA[
00GoJiA[0_l00003od>l@`03o`000?m^TFkoKY5^00KoKY5^00?o0000ol8m`_o2?L802_o2?L800ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooX5n_oj
1OX03ooj1OX00ol0003odbcCom</d`07om</d`03o`000?n6NHKoQWV600[oQWV600?o0000ogF:MOme
RWD03?meRWD00ol0003oKi1_ofn@K`0<ofn@K`03o`000?n7N8OoQgR700KoQgR700?o0000ogj1O_mn
PGh02?mnPGh00ol0003oJiA[of^DJ`02of^DJ`;o00001_m3_4<00ol0003oKY5^ofjAKP05ofjAKP03
o`000?o2?L;o`Sg200[o`Sg200?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oC;=?odbcC00GodbcC
00?o0000ohIiQ_n6NHH03?n6NHH2o`0000coMHYe00?o0000ofn@Kom_T6l03Om_T6l00ol0003oQgR7
ohMhQ`04ohMhQ`03o`000?mnPGkoOX5n00[oOX5n00Co0000of^DJol0003o00002?m3_4<00ol0003o
KY5^ofjAKP06ofjAKP03o`000?o2?L;o`Sg200Wo`Sg200?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0AooX5nPCo0000
0_oC;=<00ol0003oQWV6ohIiQP0=ohIiQP03o`000?m]TVgo000000;o00002?meRWD00ol0003oKi1_
ofn@K`0?ofn@K`Ko00003_mnPGh00ol0003o@ka3od>l@`08od>l@`03o`000?m^TFkoKY5^00KoKY5^
00?o0000ol8m`_o2?L802Oo2?L800ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj017onPGj00Co0000om</dooC;=?odbcC
0_l0000?ohIiQP03o`000?m]TVgoKI9]00?oKI9]0ol00005ogF:M@;o00004?m_T6l01_l0003oG:=L
oebSG?l0003oA;]4o`0000koOX5n00?o0000od>l@om3_4<02Om3_4<00ol0003oKY5^ofjAKP05ofjA
KP03o`000?o2?L;o`Sg200Wo`Sg200?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oj1O[onPGj00oonPGj00?o0000om</dooC;=<00ooC;=<00ol0003o
QWV6ohIiQP0=ohIiQP03o`000?m]TVgoKI9]00KoKI9]0ol000001?meRWGo0000ofBKI?mTVf@3o`00
00coKi1_00Go0000oebSG?mLXecoG:=Lo`000002odBkA003o`000?mnPGkoOX5n00_oOX5n00?o0000
od>l@om3_4<02Om3_4<00ol0003oKY5^ofjAKP06ofjAKP03o`000?o2?L;o`Sg200So`Sg20_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03ooj1OX00ol0003odbcCom</d`04om</d`oo00003?m]TVd00ol0003oI9]TofBKI004ofBK
I0?o00002?m_T6l00ol0003oG:=LoebSG002oebSG005o`000?m4^dCoA;]4odBkA?l000003?mnPGh0
0ol0003o@ka3od>l@`09od>l@`03o`000?m^TFkoKY5^00GoKY5^3?l00002on<Lh`;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooX5
n_oj1OX03_oj1OX00ol0003odbcCom</d`05om</d`03o`000?m`Sg3oL8m`00_oL8m`00?o0000offB
KOm]TVd02_m]TVd00ol0003oI9]TofBKI007ofBKI0;o00001Om_T6l00ol0003oG:=LoebSG003oebS
G003o`000?m4^dCoA;]400;oA;]400?o0000ogj1O_mnPGh02OmnPGh00ol0003o@ka3od>l@`0:od>l
@`03o`000?m^TFkoKY5^00?oKY5^00?o0000ohacS?n<Lh`02On<Lh`00ol0003ohacSon<Lh`02on<L
h`;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003odbcCom</d`06om</d`03o`000?m`Sg3oL8m`00[o
L8m`00?o0000offBKOm]TVd02om]TVd00ol0003oI9]TofBKI009ofBKI0?o000000?oKi1_o`000?mL
Xe`01OmLXe`00ol0003oA;]4odBkA003odBkA003o`000?mnPGkoOX5n00SoOX5n3_l00003ofjAKP;o
00002on<Lh`00ol0003ohacSon<Lh`05on<Lh`03o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00gonPGj
00?o0000om</dooC;=<01OoC;=<00ol0003oQWV6o`00000;og2?L003o`000?m]TVgoKI9]00[oKI9]
0_l0000>ofBKI003o`000?mLXecoG:=L00GoG:=L00?o0000odBkA?m4^d@00om4^d@00ol0003oOX5n
ogj1OP08ogj1OP03o`000?mcS7?oLhac00_oLhac00?o0000ofjAK_l000003On<Lh`00ol0003ohacS
on<Lh`06on<Lh`;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oC;=?odbcC00KodbcC00Co
0000ohIiQ_n6NHKo00002_m`Sg000ol0003oKI9]offBK@09offBK@03o`000?mRWF;o000000koI9]T
00?o0000oebSG?mLXe`01OmLXe`00ol0003oA;]4odBkA004odBkA003o`000?mnPGkoOX5n00KoOX5n
00?o0000og><LomcS7<03OmcS7<00ol0003oS7><ohacS00<ohacS003o`000?oS7>?ohacS00SohacS
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003onPGjooX5nP0;ooX5nP03o`000?oC;=?odbcC00GodbcC00?o0000ohIiQ_n6NHH00_n6
NHH00ol0003oL8m`og2?L006og2?L003o`000?m]TVgoKI9]00SoKI9]0_l00003of:MHP03o`000?mT
VfCoI9]T00_oI9]T00?o0000oebSG?mLXe`01OmLXe`00ol0003oA;]4odBkA005odBkA003o`000?mn
PGkoOX5n00GoOX5n00?o0000og><LomcS7<03OmcS7<00ol0003oS7><ohacS00;ohacS003o`000?oS
7>?ohacS00WohacS00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oC;=?odbcC00KodbcC00?o0000
ohIiQ_n6NHH00on6NHH00ol0003oL8m`og2?L005og2?L003o`000?m]TVgoKI9]00OoKI9]00?o0000
of:MH_mRWF800omRWF800ol0003oI9]TofBKI00:ofBKI003o`000?mLXecoG:=L00KoG:=L00?o0000
odBkA?m4^d@01_m4^d@00ol0003oOX5nogj1OP04ogj1OP03o`000?mcS7?oLhac00goLhac3ol0000;
on<Lh`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooX5nP03o`000?oC;=?odbcC00KodbcC00?o0000ohIiQ_n6NHH01On6NHH00ol0
003oL8m`og2?L004og2?L003o`000?m]TVgoKI9]00GoKI9]0_l00006of:MHP03o`000?mTVfCoI9]T
00WoI9]T0_l00008oebSG003o`000?m4^dCoA;]400KoA;]41Ol000000omnPGko0000og><L`0?og><
L`03o`000?n7N8OoQgR700_oQgR700?o0000on<LhooS7><02OoS7><00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oj1O[onPGj00;o
nPGj1Ol00003ooX5nP03o`000?oC;=?odbcC00KodbcC00?o0000ohIiQ_n6NHH01_n6NHH00ol0003o
L8m`og2?L004o`0000KoKI9]00?o0000of:MH_mRWF801omRWF800ol0003oI9]TofBKI005ofBKI0?o
000000?oCk1?o`000?mLXe`01omLXe`00ol0003oA;]4odBkA005odBkA003o`000?n1OX7oPGj100?o
PGj10_l0000?og><L`;o00003On7N8L00ol0003ohacSon<Lh`08on<Lh`03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooX5n_oj1OX0
1ooj1OX3o`0000WodbcC00?o0000ohIiQ_n6NHH01on6NHH2o`0000CoU6^D00Co0000offBKOm]TVgo
KI9]0_l0000:of:MHP03o`000?mTVfCoI9]T00;oI9]T0ol00005odn`C`03o`000?mLXecoG:=L00Go
G:=L00?o0000odBkA?m4^d@01?m4^d@00ol0003oPGj1oh5nP@06oh5nP@03o`000?mcS7?oLhac00[o
Lhac0_l00002ogn0O`03o`000?n7N8OoQgR700[oQgR700?o0000on<LhooS7><02?oS7><00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oj1O[onPGj00WonPGj00?o0000om</dooC;=<01_oC;=<00ol0003oQWV6ohIiQP08ohIiQP03o`00
0?nDJiCoU6^D00CoU6^D00?o0000offBKOl000003?mRWF800ol0003oI9]To`000002o`0000WoCk1?
00?o0000oebSG?mLXe`01?mLXe`00ol0003oA;]4odBkA003odBkA003o`000?n1OX7oPGj100SoPGj1
1_l00004og><L`;o00001OmoP7l00ol0003oQgR7ohMhQ`09ohMhQ`03o`000?oS7>?ohacS00SohacS
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oC;=?odbcC00GodbcC00?o0000ohIiQ_n6NHH01on6
NHH00ol0003oU6^DoiA[U006oiA[U003o`000?mRWF;oHYeR00coHYeR00?o0000odn`Com?/4l02_m?
/4l00ol0003oG:=LoebSG004oebSG004o`000?m4^dCoA;]4odBkA0;o00002on1OX400ol0003oP7n0
oh1oP003oh1oP0Co00002?moP7l00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?oS7>?ohacS00OohacS
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oj
1O[onPGj00_onPGj00?o0000om</dooC;=<00ooC;=<00ol0003oQWV6ohIiQP07ohIiQP03o`000?nD
JiCoU6^D00OoU6^D00?o0000of:MH_mRWF803?mRWF800ol0003oCk1?odn`C`0;odn`C`03o`000?mL
XecoG:=L00?oG:=L00Co0000odBkA?m4^dCo00003On1OX400ol0003oP7n0oh1oP006oh1oP003o`00
0?moP7ooOh1o00OoOh1o00?o0000ohMhQon7N8L01on7N8L00ol0003ohacSon<Lh`06on<Lh`04o`00
0?ok1?_on`Ckoo/4n`;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?oC;=?odbcC00;odbcC00?o0000ohIiQ_n6NHH0
1_n6NHH00ol0003oU6^DoiA[U009oiA[U003o`000?mRWF;oHYeR00WoHYeR0_l0000>odn`C`?o0000
0omLXe`00ol0003oA;]4o`00000=oh5nP@03o`000?n0Oh3oP7n000OoP7n000?o0000ogn0OomoP7l0
2?moP7l:o`0000KohacS0_l00006oo/4n`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooX5n_oj1OX03Ooj1OX6o`0000OoQWV600?o
0000oiA[U?nDJi@02_nDJi@00ol0003oHYeRof:MHP06of:MHP;o000000?oHIiQo`000?m?/4l02om?
/4l2o`0000?oP7n01Ol0000>oh5nP@03o`000?n0Oh3oP7n000OoP7n000?o0000ogn0OomoP7l02?mo
P7l00ol0003oZ5NXojQGZ006ojQGZ003o`000?oS7>?ohacS00?ohacS00?o0000oo/4nook1?/01ook
1?/2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooX5n_oj1OX03Ooj1OX00ol0003obCK9olTfb@03olTfb@Co00000_n6NHH00ol0003oU6^DoiA[U00;
oiA[U003o`000?mRWF;oHYeR00?oHYeR0ol00004of6NH@03o`000?m?/4ooCk1?00OoCk1?0_l00008
oh1oP003o`000?n1OX7oPGj100goPGj100?o0000oh1oP?n0Oh002?n0Oh000ol0003oOh1oogn0O`07
ogn0O`03o`000?nXEjSoZ5NX00OoZ5NX0ol000000ooS7>?o0000oo/4n`0;oo/4n`;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?o9=/WobCK900OobCK90_l0000?oiA[U003o`000?mRWF;oHYeR00;o00002?mQWV400ol0
003oCk1?odn`C`05odn`C`03o`000?n0Oh3oP7n000SoP7n000?o0000oh5nPOn1OX403On1OX400ol0
003oP7n0oh1oP008oh1oP003o`000?moP7ooOh1o00KoOh1o00?o0000ojQGZ?nXEjP02?nXEjP01?l0
003ohacSon<Lhol0000?oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003obCK9olTfb@09olTf
b@03o`000?nDJiCoU6^D00koU6^D0_l0000;of6NH@03o`000?m?/4ooCk1?00;oCk1?0_l0000;oh1o
P003o`000?n1OX7oPGj100goPGj100?o0000oh1oP?n0Oh002?n0Oh000ol0003oOh1oogn0O`06ogn0
O`03o`000?nXEjSoZ5NX00OoZ5NX00Go0000on<LhooS7>?ohacSo`00000@oo/4n`;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003obCK9olTfb@0:olTfb@03o`000?nDJiCoU6^D00goU6^D0_l0000<of6NH@04o`000?m?/4oo0000
o`0000goP7n000?o0000oh5nPOn1OX403?n1OX400ol0003oP7n0oh1oP009oh1oP003o`000?moP7oo
Oh1o00KoOh1o00?o0000ojQGZ?nXEjP01_nXEjP00ol0003ohacSon<Lh`03on<Lh`03o`000?ok1?_o
n`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003obCK9olTfb@0:olTfb@03o`000?nDJiCoU6^D00coU6^D00Co0000oc_4
>olka3_o00003?mQWV400ol0003oP7n0oh1oP00>oh1oP003o`000?n1OX7oPGj100SoPGj11?l0000;
oh1oP003o`000?moP7ooOh1o00KoOh1o00?o0000ojQGZ?nXEjP01OnXEjP00ol0003ohacSon<Lh`04
on<Lh`03o`000?ok1?_on`Ck00oon`Ck00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003obCK9olTfb@0;olTfb@03o`000?nDJiCoU6^D
00_oU6^D00?o0000oc_4>olka3/00_lka3/00ol0003oHIiQof6NH@09of6NH@03o`000?n0Oh3oP7n0
00koP7n000Co0000oh5nPOn1OX7oPGj11ol00003ohAkQ003o`000?n0Oh3oP7n000WoP7n000?o0000
ogn0OomoP7l01_moP7l00ol0003oZ5NXojQGZ004ojQGZ003o`000?oS7>?ohacS00KohacS00?o0000
oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?o9=/WobCK900cobCK900?o0000oiA[U?nDJi@02_nDJi@00ol0
003o>l@koc_4>`03oc_4>`03o`000?mQWV7oHIiQ00SoHIiQ00?o0000oh1oP?n0Oh003_n0Oh04o`00
00_oQ7^400?o0000oh1oP?n0Oh002?n0Oh000ol0003oOh1oogn0O`05ogn0O`03o`000?nXEjSoZ5NX
00GoZ5NX00?o0000on<LhooS7><01_oS7><00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oj1O[onPGj00conPGj00?o0000olTfbOo9
=/T03?o9=/T7o`0000GoU6^D00?o0000oc_4>olka3/01Olka3/00ol0003oHIiQof6NH@07of6NH@03
o`000?n0Oh3oP7n000koP7n000?o0000ohAkQ?n4Nh@03On4Nh@00ol0003oP7n0oh1oP008oh1oP003
o`000?moP7ooOh1o00CoOh1o00?o0000ojQGZ?nXEjP01?nXEjP00ol0003ohacSon<Lh`07on<Lh`03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooX5n_oj1OX02_oj1OX00ol0003obCK9olTfb@0=olTfb@03o`000?nPGj3oX5nP00CoX5nP
1Ol00009oc_4>`03o`000?mQWV7oHIiQ00KoHIiQ00?o0000oh1oP?n0Oh003_n0Oh000ol0003oQ7^4
ohAkQ00=ohAkQ003o`000?n0Oh3oP7n000SoP7n000Co0000ogn0OomoP7ooOh1o1Ol00004ojQGZ003
o`000?oS7>?ohacS00WohacS1?l0000:oo/4n`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oj1O[onPGj00SonPGj0ol0000=olTfb@03o`000?nPGj3oX5nP00WoX5nP
0_l00009oc_4>`03o`000?mQWV7oHIiQ00KoHIiQ00?o0000oh1oP?n0Oh003?n0Oh000ol0003oQ7^4
ohAkQ00?ohAkQ0Ko00001?n0Oh04o`0000Go^dBk0_l000000onXEjSo0000on<Lh`0;on<Lh`04o`00
0?ok1?_on`Ckoo/4n`Oo00000ook1?/00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003onPGjooX5nP06ooX5nP04o`000?oK9=_ofbCKom/Tf`?o00002_o9=/T00ol0003o
X5nPoj1OX009oj1OX003o`000?m=/Tgo000000;o00001olka3/00ol0003oHIiQof6NH@05of6NH@03
o`000?n0Oh3oP7n000SoP7n01Ol0000AohAkQ003o`000?n6NHKoQWV600?oQWV61?l0000;ok]4^`03
o`000?oS7>?ohacS00[ohacS00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oj1O[onPGj00ConPGj00?o0000om/TfooK9=/01OoK9=/2o`0000OobCK9
00?o0000oj1OX?nPGj002_nPGj000ol0003oCK9=odfbC@02odfbC@?o00001Olka3/00ol0003oHIiQ
of6NH@04of6NH@04o`000?n0Oh3oP7n0oh1oP0Oo00001?mZUFX00ol0003oQ7^4ohAkQ00>ohAkQ003
o`000?n6NHKoQWV600OoQWV600?o0000ok]4^onkA;/02OnkA;/00ol0003ohacSon<Lh`09on<Lh`03
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooX5n_oj1OX00_oj1OX00ol0003ofbCKom/Tf`08om/Tf`;o00001?o9=/T00ol0003oX5nP
oj1OX00;oj1OX003o`000?m=/TgoCK9=00GoCK9=0ol00003oc_4>`04o`000?mQWV7oHIiQof6NH@Ko
00003?mZUFX00ol0003oQ7^4ohAkQ00=ohAkQ003o`000?n6NHKoQWV600OoQWV600?o0000ok]4^onk
A;/02_nkA;/00ol0003ohacSon<Lh`08on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=om/Tf`?o000000?obCK9o`000?nPGj00
3?nPGj000ol0003oCK9=odfbC@08odfbC@?o000000Co>l@ko`000?l0003o00000_n<Lh`00ol0003o
JYEZofZEJP0=ofZEJP03o`000?n4NhCoQ7^400coQ7^400?o0000ohIiQ_n6NHH02?n6NHH00ol0003o
^dBkok]4^`0;ok]4^`03o`000?oS7>?ohacS00KohacS00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
fbCK00?o0000oj1OX?nPGj003?nPGj000ol0003oCK9=odfbC@0;odfbC@03o`000?n<LhcoS7><00?o
S7><00?o0000ofZEJ_mZUFX03?mZUFX00ol0003oD:m@o`00000=ohAkQ003o`000?n6NHKoQWV600So
QWV600?o0000ok]4^onkA;/03?nkA;/3o`0000GohacS00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oK9=_ofbCK00cofbCK00?o0000oj1OX?nPGj003?nPGj000ol0003oCK9=odfbC@0:odfbC@03o`00
0?n<LhcoS7><00GoS7><00?o0000ofZEJ_mZUFX02_mZUFX01?l0003oD:m@oe2_D?m@[e02o`0000[o
Q7^400?o0000ohIiQ_n6NHH02On6NHH00ol0003o^dBkok]4^`0<ok]4^`03o`000?oX5nSoj1OX00?o
000000?ohacSo`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oK9=_ofbCK00_ofbCK00?o0000oj1OX?nPGj00
3?nPGj000ol0003oCK9=odfbC@09odfbC@03o`000?n<LhcoS7><00KoS7><00?o0000ofZEJ_mZUFX0
2OmZUFX00ol0003oD:m@oe2_D002oe2_D003o`000?n9MXWo000000;o00001on4Nh@00ol0003oQWV6
ohIiQP09ohIiQP03o`000?nkA;_o^dBk00_o^dBk00?o0000onPGj?oX5nP01?oX5nP00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000om/TfooK9=/02ooK9=/00ol0003oX5nPoj1OX00;oj1OX003o`000?m=
/TgoCK9=00SoCK9=00?o0000ohacS?n<Lh`01on<Lh`00ol0003oJYEZofZEJP08ofZEJP03o`000?m@
[e3oD:m@00?oD:m@00?o0000ohUfROn9MXT00_n9MXT2o`0000CoQ7^400?o0000ohIiQ_n6NHH02_n6
NHH00ol0003o^dBkok]4^`0:ok]4^`03o`000?oX5nSoj1OX00Goj1OX00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oK9=_ofbCK00[ofbCK0ol0000;oj1OX0Ko00001?m=/Td00ol0003oS7><ohacS008
ohacS003o`000?mZUF[oJYEZ00OoJYEZ00?o0000oe2_D?m@[e000om@[e000ol0003oRGJ9ohUfR@05
ohUfR@?o000000?oQ7^4o`000?n6NHH02on6NHH00ol0003o^dBkok]4^`09ok]4^`03o`000?oX5nSo
j1OX00Ooj1OX00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oK9=_ofbCK00WofbCK00?o0000ojMH
YonWF:L01?l00006oj1OX003o`000?nFJIKoUVVF00CoUVVF1?l0000<ohacS003o`000?mZUF[oJYEZ
00GoJYEZ00?o0000oe2_D?m@[e001?m@[e000ol0003oRGJ9ohUfR@08ohUfR@03o`000?n6NHKoQWV6
00_oQWV600?o0000ok]4^onkA;/02?nkA;/00ol0003oj1OXonPGj008onPGj0Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oK9=_ofbCK00OofbCK00?o0000ojMHYonWF:L01OnWF:L3o`0000;oX5nP00?o0000oiIYU_nF
JIH02?nFJIH00ol0003oS7><ohacS00:ohacS003o`000?mZUF[oJYEZ00CoJYEZ00?o0000oe2_D?m@
[e001Om@[e000ol0003oRGJ9ohUfR@08ohUfR@03o`000?n6NHKoQWV600WoQWV61?l00008ok]4^`03
o`000?oX5nSoj1OX00Woj1OX00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ofbCK
om/Tf`05om/Tf`03o`000?nWF:OoYeRW00WoYeRW0_l0000<oiIYUP03o`000?n<LhcoS7><00WoS7><
00?o0000ofZEJ_mZUFX00omZUFX00ol0003oD:m@oe2_D005oe2_D003o`000?n9MXWoRGJ900[oRGJ9
00?o0000ohIiQ_n6NHH01?n6NHH4o`0000Co[E:]00?o0000ok]4^onkA;/01?nkA;/00ol0003oj1OX
onPGj00:onPGj003o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oK9=_ofbCK00?ofbCK00?o0000ojMHYonWF:L02onW
F:L00ol0003oUVVFoiIYUP0:oiIYUP03o`000?n<LhcoS7><00WoS7><00?o0000ofZEJ_mZUFX00_mZ
UFX00ol0003oD:m@oe2_D006oe2_D003o`000?n9MXWoRGJ900[oRGJ900?o0000ohIiQ_n6NHH01?l0
0009ojeB[@Ko00003?oX5nP00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000om/TfooK9=_ofbCK0_l0
000=ojMHY`03o`000?nFJIKoUVVF00[oUVVF00?o0000ohacS?n<Lh`02On<Lh`01Ol0003oJYEZofZE
J_mZUF[o000000WoD:m@00?o0000ohUfROn9MXT02on9MXT2o`0000go[E:]00?o0000on4NhOoQ7^40
0_oQ7^400ol0003oj1OXonPGj00:onPGj003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ofbCKo`00
0002on4Nh@;o00002onWF:L00ol0003oUVVFoiIYUP0;oiIYUP03o`000?n<LhcoS7><00WoS7><00?o
0000ofZEJ_l000002Om@[e000ol0003oRGJ9ohUfR@0<ohUfR@03o`000?n]DZgo[E:]00co[E:]00?o
0000on4NhOoQ7^400ooQ7^400ol0003oj1OXonPGj009onPGj003o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ohAkQon4Nh@03on4Nh@;o00002_nWF:L00ol0003oUVVFoiIYUP0:oiIYUP03o`000?n<Lhco
S7><00SoS7><1Ol00008oe2_D003o`000?n9MXWoRGJ900coRGJ900?o0000ojeB[On]DZd02on]DZd0
0ol0003ohAkQon4Nh@05on4Nh@03o`000?oX5nSoj1OX00Soj1OX00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooQ7^42o`0000SoYeRW00?o0000oiIYU_nFJIH02_nFJIH00ol0003oS7><ohacS007ohac
S003o`000?mjQG[oNXEj00?oNXEj0ol00005oe2_D003o`000?n9MXWoRGJ900_oRGJ900?o0000ojeB
[On]DZd03?n]DZd00ol0003ohAkQon4Nh@06on4Nh@03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000WohAkQ00?o0000ojMHYonWF:L01OnWF:L2o`0000co
UVVF00?o0000ohacS?n<Lh`01On<Lh`00ol0003oNXEjogZ5NP07ogZ5NP?o000000?oD:m@o`000?n9
MXT03On9MXT00ol0003o[E:]ojeB[@0<ojeB[@03o`000?oQ7^7ohAkQ00KohAkQ00?o0000onPGj?oX
5nP01_oX5nP00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?oQ7^7ohAkQ00OohAkQ
0_l00004ojMHY`03o`000?ndBkCo]4^d00;o00002_nFJIH00ol0003oS7><ohacS003ohacS0;o0000
3OmjQGX2o`0000goRGJ90ol0000=ojeB[@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000onPGj?oX5nP0
1OoX5nP00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?oQ7^7ohAkQ00SohAkQ0_l0
00000onWF:Oo0000okA;]004okA;]003o`000?nFJIKoUVVF00OoUVVF00Co0000ohacS?n<LhcoS7><
0_l00002ohebS@03o`000?mjQG[oNXEj00coNXEj3Ol00003ohacS003o`000?n]DZgo[E:]00[o[E:]
00?o0000on4NhOoQ7^402?oQ7^401?l0003oj1OXonPGj?oX5nP4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003ohAkQ
on4Nh@09on4Nh@03o`000?ndBkCo]4^d00Go]4^d0_l00008oiIYUP03o`000?n<Lhco000000GoSG:=
00?o0000ogZ5N_mjQGX02omjQGX00ol0003oNhAkog^4N`09og^4N`03o`000?n<LhcoS7><00;oS7><
0_l00009ojeB[@03o`000?oQ7^7ohAkQ00[ohAkQ0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?oQ7^7ohAkQ00SohAkQ00?o0000okA;]?ndBk@01ondBk@4o`0000?oUVVF0ol0
0007ohebS@03o`000?mjQG[oNXEj00[oNXEj00?o0000og^4NomkQ7/02OmkQ7/00ol0003oS7><ohac
S004ohacS0;o00001on]DZd00ol0003ohAkQon4Nh@0:on4Nh@03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000okA;]?ndBk@02?ndBk@0
1?l0003o]DZeokE:]OneB[D3o`0000;oXUfR00?o0000ohebSOn=LXd01_n=LXd00ol0003oNXEjogZ5
NP08ogZ5NP03o`000?mkQ7_oNhAk00[oNhAk00?o0000ohacS?n<Lh`01_n<Lh`00ol0003o[E:]ojeB
[@04ojeB[@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000on4NhOoQ7^401OoQ7^400ol0003o]4^dokA;]008okA;]003o`000?neB[Go
]DZe00Co]DZe00Go0000oj9MX_nRGJ;oXUfRo`000008ohebS@03o`000?mjQG[oNXEj00OoNXEj00?o
0000og^4NomkQ7/02_mkQ7/00ol0003oS7><ohacS007ohacS0;o00001?n]DZd00ol0003ohAkQon4N
h@08on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on4NhOoQ7^400ooQ7^40
0ol0003o]4^dokA;]008okA;]003o`000?neB[Go]DZe00Co]DZe00?o0000oj9MX_nRGJ800_nRGJ80
0ol0003oSG:=ohebS@07ohebS@03o`000?mjQG[oNXEj00KoNXEj00?o0000og^4NomkQ7/02_mkQ7/0
0ol0003oS7><ohacS009ohacS005o`000?n]DZgo[E:]ojeB[Ol000002OoQ7^400ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_o]4^d00?o0000okE:]OneB[D01?neB[D00ol0003oXUfRoj9MXP03
oj9MXP03o`000?n=LXgoSG:=00OoSG:=00?o0000ogZ5N_mjQGX01OmjQGX00ol0003oNhAkog^4N`0:
og^4N`03o`000?n<LhcoS7><00WoS7><1?l00009on4Nh@03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oX5nSoj1OX
onPGj?l000002_ndBk@00ol0003o]DZeokE:]@05okE:]@03o`000?nRGJ;oXUfR00?oXUfR00?o0000
ohebSOn=LXd02?n=LXd00ol0003oNXEjogZ5NP04ogZ5NP03o`000?mkQ7_oNhAk00WoNhAk00?o0000
ohacS?n<Lh`02?n<Lh`2o`0000?ogb3O00?o0000on4NhOoQ7^401_oQ7^400ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000onPGj?oX5nP00ooX5nP00ol0003o]4^dokA;]006okA;]003o`000?neB[Go]DZe
00Go]DZe00?o0000oj9MX_nRGJ801?nRGJ800ol0003oSG:=ohebS@09ohebS@03o`000?mjQG[oNXEj
00;oNXEj00?o0000og^4NomkQ7/02_mkQ7/00ol0003oS7><ohacS006ohacS0;o00001_oO8=l8o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003oj1OXonPGj005onPGj003o`000?ndBkCo]4^d00Go]4^d00?o0000okE:]One
B[D01OneB[D00ol0003oXUfRoj9MXP05oj9MXP03o`000?n=LXgoSG:=00WoSG:=00Go0000ogZ5N_mj
QG[oNXEjo`00000<og^4N`03o`000?n<LhcoS7><00CoS7><0_l00008omlPg`03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oX5nSoj1OX00Ooj1OX00?o0000okA;]?nd
Bk@00ondBk@00ol0003o]DZeokE:]@06okE:]@03o`000?nRGJ;oXUfR00GoXUfR00?o0000ohebSOn=
LXd02_n=LXd00ol0003oNXEjo`000004o`0000WoNhAk00?o0000ohacS?n<Lh`00_n<Lh`2o`0000[o
gb3O00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003oj1OXonPGj007onPGj003o`00
0?ndBkCo]4^d00;o]4^d00?o0000okE:]OneB[D01_neB[D00ol0003oXUfRoj9MXP07oj9MXP;o0000
2on=LXd00ol0003o/4n`ok1?/003ok1?/0Oo00000_mkQ7/00ol0003oS7><ohacS002o`0000_ogb3O
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000onPGj?oX5nP02OoX
5nP01Ol0003o]4^dokA;]?ndBkCo000000So]DZe00?o0000oj9MX_nRGJ801onRGJ800ol0003odBkA
o`000002o`0000SoSG:=00?o0000ok1?/?n`Ck002_n`Ck05o`0000gogb3O00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<onPGj003o`000?ndBkCo000000Wo]DZe00?o
0000oj9MX_nRGJ801_nRGJ800ol0003odBkAom4^d@03om4^d@?o00001?n=LXd00ol0003o/4n`ok1?
/00=ok1?/003o`000?oO8=oogb3O00gogb3O00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ool0o`2o`0000_oj1OX00?o0000okE:]OneB[D01oneB[D00ol0003oXUfRoj9MXP07
oj9MXP03o`000?oA;]7odBkA00KodBkA0ol000000on=LXgo0000ok1?/00>ok1?/003o`000?oO8=oo
gb3O00cogb3O00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009onPG
j003o`000?neB[Go]DZe00;o]DZe1_l00008oj9MXP03o`000?oA;]7odBkA00[odBkA00?o0000ok1?
/?n`Ck003on`Ck000ol0003ogb3OomlPg`0:omlPg`;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007onPGj0Go00001_oV6NH00ol0003oXUfRoj9MXP05oj9MXP03o`000?oA;]7odBkA00[o
dBkA00?o0000ok1?/?n`Ck003on`Ck000ol0003ogb3OomlPg`07omlPg`?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005onPGj003o`000?oV6NKoiQWV00WoiQWV00?o0000oj9MX_nR
GJ800onRGJ800ol0003odBkAom4^d@0;om4^d@03o`000?n`Ck3o/4n`00oo/4n`00?o0000omlPgooO
8=l01OoO8=l2o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?oj1OXo`000?l00000
3OoV6NH00ol0003oXUfRoj9MXP02oj9MXP03o`000?oA;]7odBkA00_odBkA5?l00004omlPg`;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on`Cko`00000>onHIiP04o`000?nRGJ;oXUfRo`0000kodBkA
00?o0000onTFjOoY5^T04?oY5^T00ol0003ogb3Oo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ok1?_on`Ckoo/4nol000003_oV6NH00ol0003oXUfRo`00000>om4^d@03o`00
0?oY5^WojAKY017ojAKY00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00_ok1?/00ol0003oiQWVonHIiP0=onHIiP03o`000?oA;]7odBkA00WodBkA1Ol0
000BonTFj@;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/0
0ol0003oiQWVonHIiP0<onHIiP03o`000?oA;]7odBkA00;odBkA1ol00004oo/4n`03o`000?oY5^Wo
jAKY00oojAKY00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oV6NKoiQWV00coiQWV1?l0000<oo/4n`03o`000?oY5^WojAKY00cojAKY0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ok1?_on`Ck00Oo
n`Ck00?o0000onHIi_oV6NH03?oV6NH00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oY5^WojAKY00_o
jAKY00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003oiQWVonHIiP0:onHIiP03o`000?ok1?_on`Ck00kon`Ck00?o0000onTFjOoY
5^T02OoY5^T2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ok1?_on`Ck00[on`Ck00?o0000onHIi_oV6NH02_oV6NH00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?oY5^WojAKY00KojAKY0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003on`Ck00gon`Ck3?l0
000Aoo/4n`?o00001_oY5^T00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000ooY5^T2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onTFjOl000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool00ol00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Go003o0oooo`03o`00o`;oool01ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`;oool03?l00?l2oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000:o`00o`;oool03Ol00?l00oooo`3o003oo`00o`03o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000:o`00o`;oool03Ol00?l2oooo00Co003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
2_l00?l2oooo00go003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool02_l00?l2oooo00go003o0_ooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool03?l00?l3oooo00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`0;o`00o`?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
000:o`00o`;oool02?l00?l5oooo00Go003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3
oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`0:o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`;oool02ol00?l2oooo00Go003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool02_l00?l2oooo00co003o0_ooo`04o`00o`;oool01_l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
6?l00?l2oooo00[o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o0_ooo`05o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`05o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol0
0?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05
o`00o`Coool01_l00?l2oooo00?o003o0_ooo`07o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1W
o`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08_l00?l2oooo
00So003o1?ooo`09o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(140) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.984 .016 .984 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.985 .015 .985 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.985 .015 .985 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.984 .016 .984 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.893 .107 .893 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.983 .017 .983 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.888 .112 .888 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.909 .091 .909 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.865 .135 .865 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.98 .02 .98 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.81 .19 .81 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.984 .016 .984 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.734 .266 .734 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.715 .285 .715 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.981 .019 .981 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.986 .014 .986 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.647 .353 .647 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.77 .23 .77 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.979 .021 .979 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.981 .019 .981 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.983 .017 .983 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.876 .124 .876 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.497 .503 .497 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.612 .388 .612 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.507 .493 .507 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.496 .504 .496 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.578 .422 .578 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.83 .17 .83 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.865 .135 .865 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.985 .015 .985 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.521 .479 .521 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.754 .246 .754 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.415 .585 .415 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.832 .168 .832 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.791 .209 .791 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.984 .016 .984 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.697 .303 .697 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.723 .277 .723 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.65 .35 .65 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.833 .167 .833 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.535 .465 .535 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.986 .014 .986 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.887 .113 .887 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.563 .437 .563 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.47 .53 .47 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.441 .559 .441 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.888 .112 .888 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.915 .085 .915 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.667 .333 .667 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.984 .016 .984 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.528 .472 .528 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.446 .554 .446 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.576 .424 .576 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.603 .397 .603 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.353 .647 .353 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.506 .494 .506 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.627 .373 .627 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.984 .016 .984 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.647 .353 .647 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.57 .43 .57 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.883 .117 .883 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.13 .87 .13 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.719 .281 .719 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.705 .295 .705 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.576 .424 .576 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.282 .718 .282 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.311 .689 .311 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.16 .84 .16 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.22 .78 .22 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.51 .49 .51 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.297 .703 .297 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.406 .594 .406 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.721 .279 .721 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.459 .541 .459 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.489 .511 .489 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.585 .415 .585 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.905 .095 .905 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.984 .016 .984 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.271 .729 .271 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.358 .642 .358 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.293 .707 .293 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.983 .017 .983 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.637 .363 .637 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.435 .565 .435 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.22 .78 .22 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.249 .751 .249 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.515 .485 .515 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.354 .646 .354 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.883 .117 .883 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.449 .551 .449 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.171 .829 .171 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.646 .354 .646 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.368 .632 .368 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.307 .693 .307 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.533 .467 .533 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.836 .164 .836 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.507 .493 .507 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.179 .821 .179 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.306 .694 .306 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.523 .477 .523 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.355 .645 .355 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.364 .636 .364 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.827 .173 .827 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.334 .666 .334 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.273 .727 .273 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.226 .774 .226 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.982 .018 .982 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.236 .764 .236 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.407 .593 .407 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.278 .722 .278 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.553 .447 .553 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.474 .526 .474 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.982 .018 .982 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.516 .484 .516 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.423 .577 .423 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.449 .551 .449 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.497 .503 .497 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.356 .644 .356 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.306 .694 .306 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.39 .61 .39 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.463 .537 .463 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.983 .017 .983 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.717 .283 .717 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.461 .539 .461 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.577 .423 .577 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.287 .713 .287 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.877 .123 .877 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.139 .861 .139 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.329 .671 .329 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.322 .678 .322 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.5 .5 .5 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.65 .35 .65 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.236 .764 .236 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.983 .017 .983 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.396 .604 .396 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.698 .302 .698 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.917 .083 .917 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.521 .479 .521 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.473 .527 .473 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.444 .556 .444 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.836 .164 .836 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.245 .755 .245 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.379 .621 .379 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.478 .522 .478 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.705 .295 .705 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.237 .763 .237 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.373 .627 .373 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.468 .532 .468 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.494 .506 .494 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.983 .017 .983 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.299 .701 .299 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.983 .017 .983 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.879 .121 .879 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.543 .457 .543 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.484 .516 .484 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.348 .652 .348 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.559 .441 .559 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.392 .608 .392 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.879 .121 .879 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.527 .473 .527 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.556 .444 .556 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.558 .442 .558 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.515 .485 .515 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.761 .239 .761 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.486 .514 .486 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.348 .652 .348 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.214 .786 .214 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.238 .762 .238 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.438 .562 .438 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.683 .317 .683 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.984 .016 .984 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.881 .119 .881 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.409 .591 .409 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.237 .763 .237 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.505 .495 .505 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.742 .258 .742 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.495 .505 .495 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.983 .017 .983 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.42 .58 .42 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.739 .261 .739 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.885 .115 .885 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.984 .016 .984 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.367 .633 .367 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.427 .573 .427 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.876 .124 .876 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.46 .54 .46 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.477 .523 .477 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.743 .257 .743 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.41 .59 .41 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.602 .398 .602 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.766 .234 .766 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.564 .436 .564 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.548 .452 .548 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.674 .326 .674 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.453 .547 .453 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.911 .089 .911 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.684 .316 .684 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.57 .43 .57 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.529 .471 .529 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.984 .016 .984 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.726 .274 .726 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.444 .556 .444 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.983 .017 .983 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.892 .108 .892 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.768 .232 .768 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.893 .107 .893 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.463 .537 .463 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.874 .126 .874 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.679 .321 .679 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.574 .426 .574 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.984 .016 .984 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.578 .422 .578 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.53 .47 .53 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.76 .24 .76 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.98 .02 .98 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.985 .015 .985 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.669 .331 .669 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.982 .018 .982 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.523 .477 .523 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.983 .017 .983 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.471 .529 .471 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.73 .27 .73 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.555 .445 .555 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.862 .138 .862 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.873 .127 .873 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.684 .316 .684 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.665 .335 .665 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.681 .319 .681 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.804 .196 .804 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.863 .137 .863 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.782 .218 .782 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.793 .207 .793 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.981 .019 .981 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.649 .351 .649 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.876 .124 .876 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.982 .018 .982 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.908 .092 .908 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.899 .101 .899 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.65 .35 .65 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.894 .106 .894 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.88 .12 .88 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.662 .338 .662 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.982 .018 .982 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.98 .02 .98 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.985 .015 .985 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.875 .125 .875 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.983 .017 .983 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.984 .016 .984 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.982 .018 .982 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.983 .017 .983 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.982 .018 .982 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.983 .017 .983 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003ohAkQon4NhOl0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000on4NhOoQ7^400_oQ7^400ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000on4NhOoQ7^401OoQ7^400ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ohAkQon4Nh@06on4Nh@03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000on4NhOoQ7^402?oQ7^400ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oR7N;o0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000cohAkQ00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003on8MhP03o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ohAkQon4Nh@05on4Nh@03o`000?oQ
7^7ohAkQ00_ohAkQ0ol00003on0Oh003o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
on8Mh_oR7N800ooR7N800ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003ohAkQon4Nh@06
on4Nh@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000on0Oh?oP7n001?oP7n000ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oO8=oogb3OomlPg`;o00002_ok1?/2o`000003omlPgol0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ok1?_o
n`Ck00Oon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ohQgRon8MhP05on8MhP03o`000?ok1?_o
n`Ck00Won`Ck00?o0000on0Oh?l000002ook1?/00ol0003ohAkQon4Nh@06on4Nh@03o`000?oQ7^7o
hAkQ00WohAkQ00?o0000on0Oh?oP7n001_oP7n000ol0003on`Ckoo/4n`08oo/4n`03o`000?oO8=oo
gb3O00Cogb3O0_l00005oo/4n`?o00001?oO8=l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?ok1?_on`Ck00Son`Ck0_l00008on8MhP03o`000?ok1?_on`Ck00Oon`Ck0_l00003on0O
h003o`000?ok1?_on`Ck00Oon`Ck00?o0000on4NhOoQ7^401ooQ7^400ol0003ohAkQon4Nh@09on4N
h@03o`000?oP7n3oh1oP00Ooh1oP00?o0000oo/4nook1?/01Ook1?/2o`0000Wogb3O0_l000000ook
1?_o0000o`000007omlPg`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo/4nook1?/02_ok1?/2o`0000Son`Ck00?o0000on8Mh_oR
7N802?oR7N800ol0003on`Ckoo/4n`06oo/4n`03o`000?oP7n3oh1oP00?oh1oP00?o0000oo/4nook
1?/01ook1?/00ol0003ohAkQon4Nh@08on4Nh@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000on0Oh?oP
7n002OoP7n000ol0003on`Ckoo/4n`03oo/4n`03o`000?oO8=oogb3O00_ogb3O00?o0000omlPgooO
8=l01ooO8=l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo/4nook1?/02ook1?/00ol0003ohQgRo`000005oo/4n`;o00002ooR7N82o`0000Kon`Ck
00?o0000on0Oh?oP7n001OoP7n000ol0003on`Ckoo/4n`06oo/4n`03o`000?oQ7^7ohAkQ00SohAkQ
00?o0000on4NhOoQ7^401_oQ7^400ol0003oh1oPon0Oh00;on0Oh005o`000?ok1?_on`Ckoo/4nol0
00003_oO8=l00ol0003ogb3OomlPg`08omlPg`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003on`Ckoo/4n`0;oo/4n`05o`000?oR7N;ohQgRon8Mh_l0
00000ook1?/00ol0003ohQgRon8MhP0:on8MhP04o`000?oF:MKoeRWFo`0000?on`Ck0_l00008on0O
h003o`000?ok1?_on`Ck00Kon`Ck00?o0000on4NhOoQ7^402OoQ7^400ol0003ohAkQon4Nh@05on4N
h@03o`000?oP7n3oh1oP00coh1oP00?o0000oo/4nol000003ooO8=l00ol0003ogb3OomlPg`08omlP
g`03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo/4nook1?/02ook1?/00ol0003ohQgRon8MhP03on8MhP03o`000?ok1?_o000000_o
hQgR0_l00004omHYeP03o`000?ok1?_o000000_oh1oP00?o0000oo/4nook1?/01Ook1?/00ol0003o
hAkQon4Nh@09on4Nh@03o`000?oQ7^7ohAkQ00CohAkQ00?o0000on0Oh?oP7n003_oP7n000ol0003o
gb3OomlPg`0>omlPg`03o`000?oO8=oogb3O00Wogb3O00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kon`Ck00?o0000on8Mh_oR7N80
1?oR7N800ol0003ohQgRon8MhP09on8MhP03o`000?oF:MKoeRWF00GoeRWF00?o0000on0Oh?oP7n00
2_oP7n000ol0003on`Ckoo/4n`05oo/4n`03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000on4NhOoQ7^40
0ooQ7^400ol0003oh1oPon0Oh00>on0Oh003o`000?oO8=oogb3O00gogb3O00?o0000omlPgooO8=l0
2_oO8=l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo/4nook1?/02ook1?/00ol0003ohQgRon8M
hP05on8MhP03o`000?oR7N;ohQgR00OohQgR0_l00008omHYeP03o`000?oP7n3oh1oP00_oh1oP00?o
0000oo/4nook1?/01?ok1?/00ol0003ohAkQon4Nh@0:on4Nh@04o`000?oQ7^7ohAkQon4Nh@?o0000
3ooP7n000ol0003ogb3OomlPg`0>omlPg`03o`000?oO8=oogb3O00[ogb3O00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003on`Ckoo/4
n`09oo/4n`03o`000?oR7N;ohQgR00OohQgR00?o0000on8Mh_oR7N801?oR7N82o`0000_oeRWF1?l0
0009on0Oh003o`000?ok1?_on`Ck00?on`Ck00?o0000on4NhOoQ7^402ooQ7^401?l0003ohAkQo`00
0?l00003oke2_@;o00003?oP7n02o`00013ogb3O00?o0000omlPgooO8=l02ooO8=l00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook1?/02?ok1?/00ol0003ohQgR
on8MhP07on8MhP03o`000?oR7N;ohQgR00?ohQgR00?o0000omHYe_oF:MH02ooF:MH01?l0003o]dRg
okM8]ongB;L5o`0000Goh1oP00?o0000oo/4nook1?/00_ok1?/00ol0003ohAkQon4Nh@0<on4Nh@03
o`000?nm@[go_D:m00Go_D:m0_l00008on0Oh0;o00000_n_D:l00ol0003ogb3OomlPg`0=omlPg`03
o`000?oO8=oogb3O00_ogb3O00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo/4nook1?/01ook1?/00ol0003ohQgRon8MhP09on8MhP03o`000?oR7N;ohQgR00;o0000
3OoF:MH00ol0003o]dRgokM8]`07okM8]`Ko00000_ok1?/4o`0000gohAkQ00?o0000oke2_Onm@[d0
1onm@[d2o`0000Goh1oP00?o0000ojm@[on_D:l00on_D:l00ol0003ogb3OomlPg`0<omlPg`03o`00
0?oO8=oogb3O00cogb3O00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`06oo/4n`03o`000?oR7N;ohQgR00WohQgR00?o
0000on8Mh_l000003ooF:MH00ol0003o]dRgokM8]`0<okM8]`?o00001?oF:MH3o`0000WohAkQ00?o
0000oke2_Onm@[d02_nm@[d2o`000003on0Oh?l0003o000000Oo[e2_00?o0000omlPgooO8=l02ooO
8=l00ol0003ogb3OomlPg`0<omlPg`03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`05oo/4n`03o`000?oR7N;ohQgR00_ohQgR00?o0000
omHYe_oF:MH03_oF:MH00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKoeRWF00KoeRWF0ol00005
on4Nh@03o`000?nm@[go_D:m00go_D:m00?o0000ojm@[on_D:l02?n_D:l00ol0003ogb3OomlPg`09
omlPg`03o`000?oO8=oogb3O00gogb3O00Co0000oo/4nook1?_on`Ck1Ol00003onHIiP03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ok1?_on`Ck00?on`Ck00?o0000
on8Mh_oR7N802ooR7N82o`0000ooeRWF00?o0000okM8]ongB;L03OngB;L00ol0003oeRWFomHYeP0:
omHYeP?o000000?ohAkQo`000?nm@[d03onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?oO8=oo
gb3O00Sogb3O00?o0000omlPgooO8=l03_oO8=l3o`0000SoiQWV00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo/4n`03o`000?oR7N;ohQgR00SohQgR0ol000000ond
BkCo0000omHYeP0>omHYeP03o`000?ngB;Oo]dRg00go]dRg00?o0000omHYe_oF:MH03OoF:MH00ol0
003o_D:moke2_@0?oke2_@03o`000?n_D:oo[e2_00[o[e2_2ol0000;omlPg`Go00003?oV6NH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003ohacSo`000?ok1?_o0000
00SohQgR0ol00005okA;]003o`000?oF:MKoeRWF00coeRWF00?o0000okM8]ongB;L03OngB;L00ol0
003oeRWFomHYeP0=omHYeP;o00004?nm@[d00ol0003o[e2_ojm@[`0:ojm@[`03o`000?n]DZgo[E:]
00Oo[E:]00?o0000omlPgooO8=l00_oO8=l7o`0000Co[e2_00?o0000onHIi_oV6NH02_oV6NH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003ohacSon<LhooS7><2o`00
00GohQgR0ol00009okA;]0;o00002ooF:MH00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKoeRWF
00goeRWF00Co0000ol8m`_o2?L;o00003onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo
[E:]00Wo[E:]1?l0000;ojm@[`03o`000?oV6NKoiQWV00[oiQWV00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000on<LhooS7><01?oS7><00ol0003ohQgRo`000002o`00
00co]4^d00Co0000oj=LXol0003o00002OoF:MH00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKo
eRWF00goeRWF00Go0000ol8m`_o2?L;o`Sg2o`00000=oke2_@03o`000?n_D:oo[e2_00[o[e2_00?o
0000ojeB[On]DZd02On]DZd00ol0003o[e2_ojm@[`0<ojm@[`03o`000?oV6NKoiQWV00[oiQWV00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000on<LhooS7><01_oS7><0
0ol0003o]4^dokA;]00<okA;]003o`000?nSG:?oXebS00;oXebS0_l00007omHYeP03o`000?ngB;Oo
]dRg00co]dRg00?o0000omHYe_oF:MH03OoF:MH00ol0003o`Sg2ol8m`P03ol8m`P03o`000?nm@[go
_D:m00[o_D:m00?o0000ojm@[on_D:l02_n_D:l00ol0003o[E:]ojeB[@09ojeB[@03o`000?n_D:oo
[e2_00co[e2_00?o0000onHIi_oV6NH02ooV6NH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003ohacSon<Lh`06on<Lh`03o`000?ndBkCo]4^d00_o]4^d00?o0000oj=L
XonSG:<01OnSG:<00ol0003oeRWFomHYeP03omHYeP03o`000?ngB;Oo]dRg00go]dRg00?o0000omHY
e_oF:MH03OoF:MH00ol0003o`Sg2ol8m`P04ol8m`P03o`000?nm@[go_D:m00Wo_D:m00?o0000ojm@
[on_D:l02On_D:l00ol0003o[E:]ojeB[@0:ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHI
i_oV6NH02ooV6NH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
hacSon<Lh`07on<Lh`03o`000?ndBkCo]4^d00_o]4^d00?o0000oj=LXonSG:<01_nSG:<2o`0000?o
eRWF00?o0000okM8]ongB;L03OngB;L00ol0003oeRWFomHYeP0<omHYeP03o`000?o2?L;o`Sg200Ko
`Sg200?o0000oke2_Onm@[d02?nm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo[E:]00[o
[E:]00?o0000ojm@[on_D:l03?n_D:l00ol0003oiQWVonHIiP0;onHIiP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000on<LhooS7><02?oS7><00ol0003o]4^dokA;]00:okA;]003o`00
0?nSG:?oXebS00WoXebS0_l000000ooF:MKo0000okM8]`0<okM8]`?o00003_oF:MH00ol0003o`Sg2
ol8m`P07ol8m`P03o`000?nm@[go_D:m00Oo_D:m00?o0000ojm@[on_D:l02On_D:l00ol0003o[E:]
ojeB[@0;ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHIi_oV6NH02_oV6NH00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo/4nook1?/00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000on<LhooS7><02_oS7><00ol0003o]4^dokA;
]009okA;]003o`000?nSG:?oXebS00_oXebS00?o0000okM8]ongB;L02_ngB;L2o`0000?oYUVV00?o
0000omHYe_oF:MH02_oF:MH00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nm@[go_D:m00Ko_D:m00?o
0000ojm@[on_D:l02?n_D:l00ol0003o[E:]ojeB[@0<ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o
0000onHIi_oV6NH02_oV6NH00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`04oo/4n`?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000okA;]?ndBk@02?ndBk@0
0ol0003oXebSoj=LX`0<oj=LX`03o`000?ngB;Oo]dRg00So]dRg0_l00006ojIIYP;o00002_oF:MH0
0ol0003o`Sg2ol8m`P0:ol8m`P03o`000?nm@[go_D:m00Go_D:m00?o0000ojm@[on_D:l02?n_D:l0
0ol0003o[E:]ojeB[@0<ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHIi_oV6NH02ooV6NH0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/02?ok1?/3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
on<Lh`03o`000?ndBkCo]4^d00Oo]4^d00?o0000oj=LXonSG:<03_nSG:<00ol0003o]dRgokM8]`04
okM8]`?o00002_nVFJH00ol0003oeRWFomHYeP07omHYeP03o`000?o2?L;o`Sg200_o`Sg200?o0000
oke2_Onm@[d00onm@[d00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo[E:]00co[E:]00?o0000
ojm@[on_D:l03?n_D:l00ol0003oiQWVonHIiP0;onHIiP;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0<oo/4n`Co00000_ol0o`00ol0
003ohacSon<Lh`0<on<Lh`03o`000?ndBkCo]4^d00Oo]4^d00?o0000oj=LXonSG:<03onSG:<01?l0
003o]dRgokM8]ongB;L2o`0000koYUVV0_l00006omHYeP03o`000?o2?L;o`Sg200go`Sg200?o0000
oke2_Onm@[d00_nm@[d00ol0003o[e2_ojm@[`08ojm@[`03o`000?n]DZgo[E:]00co[E:]0ol0000=
ojm@[`03o`000?oV6NKoiQWV00_oiQWV00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ol0oco0000
00oohacS00?o0000okA;]?ndBk@01_ndBk@00ol0003oXebSoj=LX`0@oj=LX`Co00004_nVFJH00ol0
003oeRWFomHYeP03omHYeP03o`000?o2?L;o`Sg200ko`Sg200Go0000oke2_Onm@[go_D:mo`000005
ojm@[`Oo00003?n]DZd01Ol0003oQGZ5ohEjQOn5NXGo000000co[e2_00?o0000onHIi_oV6NH02?oV
6NH3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo/4nook1?/04?ok1?/3o`0000oohacS00?o0000okA;]?ndBk@01_ndBk@00ol0003oXebSoj=LX`0=
oj=LX`?o000000CoPgb3o`000?l0003o00004onVFJH2o`0000;oeRWF00?o0000ol8m`_o2?L804?o2
?L800ol0003o_D:mo`000006o`0000Oo^DJi00?o0000ojeB[On]DZd02?n]DZd00ol0003oQGZ5ohEj
Q@03ohEjQ@;o00002?n_D:l3o`0000KoiQWV1?l00002on4Nh@03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo/4nook1?/03ook1?/0
1?l0003oh1oPo`000?nbCK83o`0000gohacS00?o0000okA;]?ndBk@01?ndBk@00ol0003oXebSoj=L
X`0;oj=LX`?o00000on3O8<01Ol0003oQGZ5o`000?n4NhCo000001CoYUVV00?o0000omHYe_l00000
4oo2?L800ol0003o^DJiokU6^@0=okU6^@03o`000?n]DZgo[E:]00Go[E:]0_l00008ohEjQ@03o`00
0?n_D:oo[e2_00Go00000on^DJh00ol0003oiQWVonHIiP03o`0000OohAkQ00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003on`Ckoo/4
n`0>oo/4n`04o`000?oP7n3oh1oPo`0000Co/Tfb0ol0000:on<Lh`03o`000?ndBkCo]4^d00?o]4^d
00?o0000oj=LXonSG:<02OnSG:<3o`0000GoPgb300Co0000ohEjQOn5NXGo00000_n4Nh@00ol0003o
YUVVojIIYP0BojIIYP03o`000?o2?L;o`Sg201;o`Sg200?o0000okU6^OniA[T03_niA[T00ol0003o
[E:]ojeB[@03ojeB[@03o`000?n5NXGoQGZ500WoQGZ50_l00009ojiA[P;o00002_oQ7^400ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00Go0000on0Oh?oP7n3oh1oPo`000007ok9=/P;o00001ooS7><5o`0000;o
]4^d00?o0000oj=LXonSG:<01_nSG:<3o`0000SoPgb300Co0000ohEjQOn5NXGo00000on4Nh@00ol0
003oYUVVojIIYP0AojIIYP03o`000?o2?L;o`Sg2017o`Sg200?o0000okU6^OniA[T04?niA[T01Ol0
003o[E:]ojeB[On]DZgo000000coQGZ500?o0000ojiA[_n^DJh02?n^DJh00ol0003ohAkQon4Nh@0:
on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo/4nook1?/03?ok1?/2o`0000Coh1oP00?o0000ok9=/_nbCK801onbCK83o`00
0004on<Lhol0003o0000o`0000GoYEZU0_l00006oj=LX`?o00002_n3O8<01Ol0003oQGZ5ohEjQOn5
NXGo000000CoQ7^400?o0000ojIIY_nVFJH04?nVFJH00ol0003o`Sg2ol8m`P0Aol8m`P03o`000?ni
A[Wo^DJi017o^DJi00?o0000ojeB[Ol000003On5NXD00ol0003o[U6^ojiA[P08ojiA[P03o`000?oQ
7^7ohAkQ00[ohAkQ00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oP7n3oh1oP00Coh1oP00?o0000
ok9=/_nbCK802_nbCK800ol0003oYEZUojEJY@08ojEJY@03o`000?nSG:?oXebS00?o00003On3O8<0
1Ol0003oQGZ5ohEjQOn5NXGo000000GoQ7^400?o0000ojIIY_nVFJH03onVFJH00ol0003o`Sg2ol8m
`P0Aol8m`P03o`000?niA[Wo^DJi01;o^DJi00?o0000ohEjQOn5NXD03?n5NXD00ol0003o[U6^ojiA
[P08ojiA[P03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_on`Ck00?o0000on0Oh?oP7n001OoP7n00
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?nUFZGoYEZU00WoYEZU0_l0000?oh=lP`03o`000?n5NXGo
QGZ500;oQGZ500?o0000ohAkQ?n4Nh@01?n4Nh@00ol0003oYUVVojIIYP0=ojIIYP?o00004Oo2?L80
0ol0003o^DJiokU6^@0CokU6^@03o`000?n5NXGoQGZ500_oQGZ500?o0000ojiA[_n^DJh02On^DJh0
0ol0003ohAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo/4n`;o00002?oP7n00
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?nUFZGoYEZU00WoYEZU00?o0000oh=lPon3O8<03On3O8<0
0ol0003oQGZ5ohEjQ@03ohEjQ@03o`000?n4NhCoQ7^400GoQ7^400?o0000ojIIY_nVFJH02_nVFJH2
o`0000?o]4^d00?o0000ol8m`_o2?L803_o2?L800ol0003o^DJiokU6^@0CokU6^@03o`000?n5NXGo
QGZ500_oQGZ500?o0000ojiA[_n^DJh02On^DJh00ol0003ohAkQon4Nh@0;on4Nh@03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Gon`Ck00?o0000on0Oh?oP7n001ooP7n02o`0000_o/Tfb00?o0000ojEJ
YOnUFZD02onUFZD00ol0003oPgb3oh=lP`0<oh=lP`03o`000?n5NXGoQGZ500?oQGZ500?o0000ohAk
Q?n4Nh@01_n4Nh@00ol0003oYUVVojIIYP07ojIIYP;o00001_ndBk@2o`0000ko`Sg200?o0000okU6
^OniA[T04oniA[T00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n^DJko[U6^00Wo[U6^00?o0000on4N
hOoQ7^403?oQ7^400ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo/4nook1?_on`Cko`000009on0O
h003o`000?nLHico000000_o/Tfb00?o0000ojEJYOnUFZD02onUFZD00ol0003oPgb3oh=lP`0;oh=l
P`03o`000?n5NXGoQGZ500CoQGZ500?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oYUVVojIIYP05ojII
YP03o`000?ndBkCo]4^d00So]4^d00?o0000ol8m`_o2?L802_o2?L800ol0003o^DJiokU6^@0DokU6
^@03o`000?n5NXGoQGZ500_oQGZ500?o0000ojiA[_n^DJh02On^DJh00ol0003ohAkQon4Nh@0<on4N
h@03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003on`Cko`000009on0Oh004o`000?nLHicoW6>Lo`00
00_o/Tfb00?o0000ojEJYOnUFZD02onUFZD00ol0003oPgb3oh=lP`0;oh=lP`03o`000?n5NXGoQGZ5
00CoQGZ500?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oYUVVojIIYP02ojIIYP;o00003?ndBk@2o`00
00[o`Sg200?o0000okU6^OniA[T05?niA[T00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n^DJko[U6^
00Wo[U6^00?o0000on4NhOoQ7^403OoQ7^400ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003oh1oPon0Oh007on0Oh003
o`000?nLHicoW6>L00;oW6>L00?o0000ok9=/_nbCK802?nbCK800ol0003oYEZUojEJY@0<ojEJY@03
o`000?n3O8?oPgb300WoPgb300?o0000ohEjQOn5NXD01On5NXD00ol0003oQ7^4ohAkQ009ohAkQ004
o`000?nVFJKo0000o`00013o]4^d0_l00008ol8m`P03o`000?niA[Wo^DJi01Co^DJi0ol0000;ohEj
Q@03o`000?n^DJko[U6^00Wo[U6^00?o0000on4NhOoQ7^403OoQ7^401?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003oh1oPon0Oh006on0Oh003o`000?nLHicoW6>L00?oW6>L00?o0000ok9=
/_nbCK802?nbCK800ol0003oYEZUojEJY@0;ojEJY@;o00002_n3O8<00ol0003oQGZ5ohEjQ@06ohEj
Q@03o`000?n4NhCoQ7^400[oQ7^400?o0000okA;]?ndBk@04_ndBk@00ol0003o`Sg2ol8m`P04ol8m
`P03o`000?niA[Wo^DJi01Go^DJi00?o0000oj]DZon[E:/01Ol00005ohEjQ@03o`000?n^DJko[U6^
00[o[U6^00?o0000on4NhOoQ7^403_oQ7^43o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003oh1oPon0Oh004on0Oh003
o`000?nLHicoW6>L00CoW6>L00?o0000ok9=/_nbCK801onbCK800ol0003oYEZUojEJY@0;ojEJY@04
o`000?nCK9?oTfbCo`0000WoPgb300?o0000ohEjQOn5NXD01_n5NXD00ol0003oQ7^4ohAkQ00:ohAk
Q003o`000?ndBkCo]4^d01?o]4^d0_l00003ol8m`PCo00005?niA[T00ol0003oZeB[oj]DZ`06oj]D
Z`Co000000?oQGZ5o`000?n^DJh02on^DJh00ol0003ohAkQon4Nh@0>on4Nh@03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003oh1oPon0Oh003on0Oh003o`000?nLHicoW6>L00GoW6>L00?o0000ok9=/_nb
CK801onbCK800ol0003oYEZUojEJY@09ojEJY@;o00001?nCK9<00ol0003oPgb3oh=lP`05oh=lP`03
o`000?n5NXGoQGZ500OoQGZ500?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003o]4^dokA;]00EokA;]003
o`000?o2?L;o000000Co_T6n0ol0000@okU6^@03o`000?n[E:_oZeB[00_oZeB[0_l0000<ojiA[P03
o`000?oQ7^7ohAkQ00cohAkQ0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on0Oh?oP7n000_oP7n000ol0003oW6>L
oiaSW006oiaSW003o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ojEJYOnUFZD02?nUFZD00ol0003oTfbC
oi=/T`05oi=/T`03o`000?n3O8?oPgb300CoPgb300?o0000ohEjQOn5NXD01on5NXD00ol0003oQ7^4
ohAkQ00:ohAkQ003o`000?ndBkCo]4^d01Ko]4^d00?o0000oki1__nn@Kh01_nn@Kh3o`0000co^DJi
00?o0000oj]DZon[E:/03On[E:/00ol0003o[U6^ojiA[P09ojiA[PGo00002OoQ7^42o`000003omlO
gol0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003on0Oh?l0003oW6>L00WoW6>L00?o0000ok9=/_nbCK801_nb
CK800ol0003oYEZUojEJY@07ojEJY@03o`000?nCK9?oTfbC00OoTfbC00?o0000oh=lPon3O8<00_n3
O8<00ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?n4NhCoQ7^400WoQ7^400?o0000okA;]?ndBk@05ond
Bk@00ol0003o_T6noki1_P09oki1_P?o00002OniA[T00ol0003oZeB[oj]DZ`0>oj]DZ`Ko00001?n^
DJh00ol0003oYUVVojIIYP03ojIIYPGo00000_oQ7^42o`0000CogaoO00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?o?<<oocc3?oll`col000002onLHi`00ol0003o/Tfbok9=/P06ok9=/P03o`000?nU
FZGoYEZU00GoYEZU0_l0000;oi=/T`04o`000?n3O8?oPgb3o`0000_oQGZ500?o0000ohAkQ?n4Nh@0
2On4Nh@00ol0003o]4^dokA;]00FokA;]003o`000?nn@Kko_T6n00go_T6n0ol00005okU6^@03o`00
0?n[E:_oZeB[00ooZeB[00?o0000ojYEZ_nZEJX00onZEJX4o`0000_oYUVV0_l00006omlOg`03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003occ3?oll`c`02oll`c`ko00001_nbCK800ol0003oYEZUojEJ
Y@05ojEJY@03o`000?nCK9?oTfbC00coTfbC00?o0000oh=lPol000002on5NXD00ol0003oQ7^4ohAk
Q007ohAkQ0?o00006?ndBk@00ol0003o_T6noki1_P0@oki1_P?o000000?o^DJio`000?n[E:/04?n[
E:/00ol0003oZUFZojYEZP07ojYEZP03o`000?nVFJKoYUVV00[oYUVV00?o0000omlOgooO7ml01OoO
7ml00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005oll`c`03o`000?n1OX7oPGj100_oPGj10_l00004
ok9=/P03o`000?nUFZGoYEZU00?oYEZU0_l0000@oi=/T`03o`000?n5NXGoQGZ500[oQGZ500?o0000
ohAkQ?n4Nh@00on4Nh@4o`0000;oMXUf00?o0000okA;]?ndBk@05OndBk@00ol0003o_T6noki1_P0D
oki1_P03o`000?n[E:_oZeB[013oZeB[00?o0000ojYEZ_nZEJX01onZEJX00ol0003oYUVVojIIYP0:
ojIIYP03o`000?oO7moogaoO00GogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?o?<<oocc3?
00Gocc3?00?o0000oh5nPOn1OX403On1OX46o`0000?oYEZU00?o0000oi=/TonCK9<04?nCK9<00ol0
003oQGZ5ohEjQ@0:ohEjQ@03o`000?n4NhCo000000?o00001omfRGH00ol0003o]4^dokA;]00DokA;
]003o`000?nn@Kko_T6n01Co_T6n00?o0000oj]DZon[E:/03on[E:/00ol0003oZUFZojYEZP08ojYE
ZP03o`000?nVFJKoYUVV00[oYUVV00?o0000omlOgooO7ml01OoO7ml00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000oll`coo?<<l01_o?<<l00ol0003oPGj1oh5nP@0=oh5nP@03o`000?nVFJKoYUVV00?o
YUVV00?o0000ojEJYOl000004onCK9<4o`0000WoQGZ50_l0000<ogJ9MP03o`000?ndBkCo]4^d01?o
]4^d00?o0000oki1__nn@Kh05Onn@Kh00ol0003oZeB[oj]DZ`0>oj]DZ`03o`000?nZEJ[oZUFZ00So
ZUFZ00?o0000ojIIY_nVFJH02OnVFJH00ol0003ogaoOomlOg`07omlOg`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?o?<<oocc3?00Socc3?00?o0000oh5nPOn1OX402on1OX400ol0003oYUVVojIIYP05ojIIYP03o`00
0?nCK9?oTfbC01;oTfbC00Co0000oh5nPOn1OX7oPGj11Ol00003ohEjQ@03o`000?mfRGKoMXUf00go
MXUf0ol0000@okA;]0;o00006?nn@Kh00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?nZEJ[oZUFZ00Wo
ZUFZ00?o0000ojIIY_nVFJH02OnVFJH00ol0003ogaoOomlOg`07omlOg`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_occ3?00?o0000oh5nPOn1OX402_n1OX400ol0003oYUVVojIIYP06ojIIYP03o`00
0?nCK9?oTfbC017oTfbC00?o0000oh5nPOn1OX401on1OX43o`00013oMXUf00?o0000og6>LOmaSW40
1Ol00009okA;]0;o000000?oQWV6o`000?nn@Kh05onn@Kh00ol0003oZeB[oj]DZ`0=oj]DZ`03o`00
0?nZEJ[oZUFZ00WoZUFZ00?o0000ojIIY_nVFJH02?nVFJH2o`0000[ogaoO00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?oS7>?ohacS00;ohacS00?o0000oll`coo?<<l02Oo?<<l00ol0003oPGj1oh5n
P@0:oh5nP@03o`000?nVFJKoYUVV00OoYUVV00?o0000oi=/TonCK9<03onCK9<00ol0003oPGj1oh5n
P@0:oh5nP@03o`000?mfRGKoMXUf00goMXUf00?o0000og6>LOmaSW401_maSW44o`0000Co]4^d00?o
0000ohIiQ_n6NHH00_n6NHH00ol0003o_T6noki1_P0Foki1_P03o`000?n[E:_oZeB[00_oZeB[00?o
0000ojYEZ_nZEJX02onZEJX00ol0003oYUVVojIIYP06ojIIYP03o`000?nYEZWo000000[ogaoO00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?oS7>?ohacS00?ohacS00?o0000oll`coo?<<l02?o?<<l=
o`0000[oYUVV00?o0000oi=/TonCK9<03onCK9<00ol0003oPGj1oh5nP@0;oh5nP@03o`000?mfRGKo
MXUf00coMXUf00?o0000og6>LOmaSW402_maSW44o`0000GoQWV600?o0000oki1__nn@Kh05_nn@Kh0
0ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?nZEJ[oZUFZ00coZUFZ00?o0000ojIIY_nVFJH01?nVFJH2
o`0000?oZEJY00?o0000omlOgooO7ml02?oO7ml00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on<L
hooS7><00ooS7><00ol0003occ3?oll`c`07oll`c`03o`000?mnPGkoOX5n00WoOX5n00?o0000ojII
Y_nVFJH02OnVFJH00ol0003oTfbCoi=/T`0=oi=/T`03o`000?n1OX7oPGj100coPGj100?o0000ogJ9
M_mfRGH03?mfRGH00ol0003oLHiaog6>L@0;og6>L@03o`000?mIYUWo000000KoQWV600?o0000oki1
__nn@Kh05_nn@Kh00ol0003oZeB[oj]DZ`09oj]DZ`03o`000?nZEJ[oZUFZ00coZUFZ00?o0000ojII
Y_nVFJH00onVFJH00ol0003oZEJYojUFZ@03ojUFZ@03o`000?oO7moogaoO00SogaoO00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?oS7>?ohacS00CohacS00?o0000oll`coo?<<l01_o?<<l00ol0003o
OX5nogj1OP08ogj1OP03o`000?nVFJKoYUVV00_oYUVV00?o0000oi=/TonCK9<02?nCK9<4o`0000oo
PGj100?o0000ogJ9M_mfRGH02omfRGH00ol0003oLHiaog6>L@0;og6>L@04o`000?mIYUWoFJIIo`00
00OoQWV600?o0000oki1__nn@Kh05Onn@Kh00ol0003oZeB[oj]DZ`08oj]DZ`03o`000?nZEJ[oZUFZ
00goZUFZ00?o0000ojIIY_nVFJH00_nVFJH00ol0003oZEJYojUFZ@05ojUFZ@03o`000?oO7moogaoO
00OogaoO00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?oS7>?ohacS00GohacS00?o0000oll`coo?
<<l01Oo?<<l00ol0003oOX5nogj1OP08ogj1OP03o`000?nVFJKoYUVV00_oYUVV00?o0000oi=/TonC
K9<00onCK9<5o`0000?oPWf200?o0000oh5nPOn1OX403_n1OX400ol0003oMXUfogJ9MP0:ogJ9MP03
o`000?maSW7oLHia00[oLHia00Go0000oeVVFOmIYUWoFJIIo`000007ohIiQP03o`000?nn@Kko_T6n
01Go_T6n00?o0000oj]DZon[E:/02?n[E:/00ol0003oZUFZojYEZP0=ojYEZP03o`000?nVFJKoYUVV
00;o00002?nYEZT00ol0003ogaoOomlOg`08omlOg`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ohacSon<Lh`05on<Lh`03o`000?o?<<oocc3?00Go
cc3?00?o0000ogj1O_mnPGh02?mnPGh00ol0003oYUVVojIIYP0<ojIIYPGo00002On2OH800ol0003o
PGj1oh5nP@0<oh5nP@;o00003?mfRGH00ol0003oLHiaog6>L@0:og6>L@05o`000?mIYUWoFJIIoeVV
FOl000002?n6NHH00ol0003o_T6noki1_P0Doki1_P?o00001on[E:/00ol0003oZUFZojYEZP0>ojYE
ZP03o`000?nVFJKo000000_oZEJY00?o0000omlOgooO7ml01_oO7ml00ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000on<LhooS7><01OoS7><00ol0003occ3?oll`c`04oll`c`03o`000?mnPGkoOX5n00Oo
OX5n00?o0000ojIIY_nVFJH03?nVFJH01?l0003oTfbCoi=/Tol0000;oh9mPP03o`000?n1OX7oPGj1
00_oPGj100Co0000oeFZEOmEZUGo00002_mfRGH00ol0003oLHiaog6>L@0:og6>L@03o`000?mIYUWo
FJII00;oFJII00?o0000ohIiQ_n6NHH01_n6NHH00ol0003o_T6noki1_P0Aoki1_P?o00000onAKY40
0ol0003oZeB[oj]DZ`04oj]DZ`03o`000?nZEJ[oZUFZ00goZUFZ1?l0000;ojUFZ@03o`000?oO7moo
gaoO00GogaoO00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oS7>?ohacS00KohacS00Co0000oll`
coo?<<oocc3?1?l00008ogj1OP03o`000?nVFJKoYUVV00_oYUVV00?o0000oi=/TonCK9<00_nCK9<0
0ol0003oPWf2oh9mPP08oh9mPP03o`000?n1OX7oPGj100[oPGj100?o0000oeFZEOmEZUD00_mEZUD0
0ol0003oMXUfogJ9MP03ogJ9MPGo00002omaSW400ol0003oFJIIoeVVF@03oeVVF@03o`000?n6NHKo
QWV600OoQWV600?o0000oki1__nn@Kh03_nn@Kh2o`0000OoTFjA00?o0000oj]DZon[E:/00_n[E:/0
0ol0003oZUFZojYEZP0=ojYEZP03o`000?nVFJKoYUVV00;oYUVV00?o0000ojUFZOnYEZT02OnYEZT0
0ol0003ogaoOomlOg`03omlOg`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ohacSon<Lh`07on<L
h`?o00001?nkA;/00ol0003oOX5nogj1OP05ogj1OP03o`000?nVFJKoYUVV00[oYUVV00?o0000oi=/
TonCK9<00onCK9<00ol0003oPWf2oh9mPP09oh9mPP03o`000?n1OX7oPGj100SoPGj100?o0000oeFZ
EOmEZUD01?mEZUD5o`0000Co8m`S00?o0000og6>LOmaSW402OmaSW400ol0003oFJIIoeVVF@03oeVV
F@03o`000?n6NHKoQWV600SoQWV600?o0000oki1__nn@Kh02_nn@Kh3o`0000[oTFjA00Go0000oj]D
Zon[E:_oZeB[o`00000>ojYEZP03o`000?nVFJKoYUVV00CoYUVV0_l00009ojUFZ@03o`000?oO7moo
gaoO00;ogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?oS7>?ohacS00OohacS00?o0000ok]4
^onkA;/01OnkA;/00ol0003oOX5nogj1OP03ogj1OP03o`000?nVFJKoYUVV00[oYUVV00?o0000oi=/
TonCK9<01?nCK9<00ol0003oPWf2oh9mPP09oh9mPP03o`000?n1OX7oPGj100OoPGj100?o0000oeFZ
EOmEZUD01OmEZUD00ol0003o8m`Sob?L8`07ob?L8`03o`000?maSW7oLHia00OoLHia00?o0000oeVV
FOmIYUT01?mIYUT00ol0003oQWV6ohIiQP08ohIiQP03o`000?nn@Kko_T6n00So_T6n0_l0000>oi5^
T@Co00003?nZEJX2o`0000WoYUVV00?o0000ojUFZOnYEZT01onYEZT01?l0003ogaoOomlOgol0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000on<LhooS7><01OoS7><00ol0003o^dBkok]4^`07ok]4^`;o00000omnPGh00ol0
003oYUVVojIIYP09ojIIYP03o`000?nCK9?oTfbC00KoTfbC00?o0000oh9mP_n2OH802On2OH800ol0
003oPGj1oh5nP@05oh5nP@03o`000?mEZUGoEJYE00KoEJYE00?o0000ob?L8olSg2<02?lSg2<00ol0
003oLHiaog6>L@06og6>L@03o`000?mIYUWoFJII00CoFJII00?o0000ohIiQ_n6NHH02On6NHH4o`00
00?o_T6n0ol0000@oi5^T@05o`000?o2?L;o`Sg2ol8m`_l000002_nZEJX00ol0003oYUVVojIIYP0:
ojIIYPKo00000onYEZT00ol0003ogaoOo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000on<LhooS7><01?oS7><00ol0
003o^dBkok]4^`0:ok]4^`04o`000?mnPGkoOX5no`0000[oYUVV00?o0000oi=/TonCK9<01onCK9<0
0ol0003oPWf2oh9mPP09oh9mPP03o`000?n1OX7oPGj100CoPGj100?o0000oeFZEOmEZUD01omEZUD0
0ol0003o8m`Sob?L8`08ob?L8`;o00001_maSW400ol0003oFJIIoeVVF@05oeVVF@03o`000?n6NHKo
QWV600WoQWV600Co0000ogF:MOmeRWGoMHYe0ol0000Boi5^T@03o`000?o2?L;o`Sg200?o`Sg20_l0
0006ojYEZP;o00003OnVFJH00ol0003oi1_Ton@Ki003on@Ki0Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000on<LhooS7><00ooS7><0
0ol0003o^dBkok]4^`0<ok]4^`;o00002_nVFJH00ol0003oTfbCoi=/T`08oi=/T`03o`000?n2OH;o
PWf200[oPWf200?o0000oh5nPOn1OX400_n1OX400ol0003oEJYEoeFZE@08oeFZE@03o`000?lSg2?o
8m`S00Ko8m`S0_l00002oe:]DP03o`000?maSW7oLHia00;oLHia00?o0000oeVVFOmIYUT01_mIYUT0
0ol0003oQWV6ohIiQP08ohIiQP03o`000?meRWGoMHYe00CoMHYe00?o0000oi5^TOnAKY403onAKY40
0ol0003o`Sg2ol8m`P06ol8m`P;o00000onZEJX00ol0003oYUVVojIIYP0=ojIIYP03o`000?oT6nCo
i1_T00Ooi1_T0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ok1?_on`Ck00?o00001ool0o`00ol0003ohacSon<Lh`02on<Lh`03o`000?nkA;_o^dBk
00ko^dBk00?o0000ojIIY_nVFJH01onVFJH00ol0003oTfbCoi=/T`0:oi=/T`03o`000?n2OH;oPWf2
00WoPWf200Go0000oh5nPOn1OX7oPGj1o`00000;oeFZE@03o`000?lSg2?o8m`S00Co8m`S0_l00005
oe:]DP05o`000?maSW7oLHiaog6>LOl000002?mIYUT00ol0003oQWV6ohIiQP08ohIiQP03o`000?me
RWGoMHYe00GoMHYe00?o0000oi5^TOnAKY403_nAKY400ol0003o`Sg2ol8m`P08ol8m`P03o`000?nZ
EJ[o000000ooYUVV00?o0000on@Ki?oT6n@02?oT6n@01?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ok1?_on`Ck00Con`Ck0ol0
0005oo`3o004o`000?oS7>?ohacSo`00017o^dBk00?o0000ojIIY_nVFJH01_nVFJH00ol0003oTfbC
oi=/T`0;oi=/T`03o`000?n2OH;oPWf200WoPWf200Co0000oh5nPOn1OX7o00003?mEZUD00ol0003o
8m`Sob?L8`02ob?L8`;o00002?mB[E800ol0003oLHiao`000009oeVVF@03o`000?n6NHKoQWV600So
QWV600?o0000ogF:MOmeRWD01OmeRWD00ol0003oTFjAoi5^T@0=oi5^T@03o`000?o2?L;o`Sg200[o
`Sg200?o0000ojIIY_nVFJH03_nVFJH00ol0003oi1_Ton@Ki007on@Ki003o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003on`Ckoo/4n`08oo/4n`?o000000?oo0?lo`000?l000000ol0000Bok]4^`03o`00
0?nVFJKoYUVV00CoYUVV00?o0000oi=/TonCK9<03?nCK9<00ol0003oPWf2oh9mPP0:oh9mPP?o0000
3?mEZUD00ol0003o8m`Sob?L8`02o`0000_oDZeB00?o0000oeVVFOmIYUT02?mIYUT00ol0003oQWV6
ohIiQP07ohIiQP03o`000?meRWGoMHYe00OoMHYe00?o0000oi5^TOnAKY403?nAKY400ol0003o`Sg2
ol8m`P0;ol8m`P;o00003_nVFJH00ol0003oi1_Ton@Ki007on@Ki003o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ok
1?_on`Ck00con`Ck00?o0000onPGj?oX5nP00ooX5nP00ol0003o^dBkok]4^`0?ok]4^`?o00000onV
FJH00ol0003oTfbCoi=/T`0>oi=/T`03o`000?n2OH;oPWf200SoPWf200Co0000oejQG_mNXEkoGZ5N
0_l0000:oeFZE@?o00003OmB[E800ol0003oFJIIoeVVF@08oeVVF@03o`000?n6NHKoQWV600OoQWV6
00?o0000ogF:MOmeRWD01omeRWD00ol0003oTFjAoi5^T@0;oi5^T@03o`000?o2?L;o`Sg200co`Sg2
00?o0000ol/dbol000000_l0000:ojIIYP03o`000?oT6nCoi1_T00Soi1_T00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo/4nook1?/03Ook1?/00ol0003oj1OXonPGj004onPGj003o`000?nkA;_o^dBk00co^dBk0_l0
0003ojEJY@03o`000?nVFJKo0000017oTfbC00?o0000oh9mP_n2OH801on2OH800ol0003oGZ5NoejQ
GP04oejQGP;o00002?mEZUD00ol0003oDZeBoe:]DP0>oe:]DP;o00002?mIYUT00ol0003oQWV6ohIi
QP06ohIiQP03o`000?meRWGoMHYe00WoMHYe00?o0000oi5^TOnAKY402OnAKY400ol0003o`Sg2ol8m
`P0=ol8m`P03o`000?o;=<_obcC;00;obcC;0ol00007ojIIYP03o`000?oT6nCoi1_T00Ooi1_T00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0003oj1OXonPGj005onPGj003o`000?nkA;_o
^dBk00Wo^dBk0_l00006ojEJY@03o`000?nCK9?oTfbC013oTfbC00?o0000oh9mP_n2OH801_n2OH80
0ol0003oGZ5NoejQGP07oejQGP03o`000?mEZUGoEJYE00CoEJYE0ol0000>oe:]DP03o`000?ll`cco
?<<l00?o00001OmIYUT00ol0003oQWV6ohIiQP06ohIiQP03o`000?meRWGoMHYe00[oMHYe00?o0000
oi5^TOnAKY402?nAKY400ol0003o`Sg2ol8m`P0=ol8m`P03o`000?o;=<_obcC;00GobcC;0ol00004
ojIIYP03o`000?oT6nCoi1_T00Ooi1_T00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oj1OXonPGj006onPGj003o`000?nkA;_o^dBk00Go^dBk0ol00008ojEJY@03o`000?nCK9?oTfbC
017oTfbC00Co0000oh9mP_n2OH;oPWf21?l0000;oejQGP;o000000CoEJYEo`000?l0003o00000om/
Tf`2o`0000_oDZeB00?o0000occ3??ll`c`01?ll`c`2o`0000?oFJII00?o0000ohIiQ_n6NHH01_n6
NHH00ol0003oMHYeogF:M@0:ogF:M@03o`000?nAKY7oTFjA00OoTFjA00?o0000ol8m`_o2?L803_o2
?L800ol0003obcC;ol/db`08ol/db`Co00002_oT6n@00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oj1OXonPGj007onPGj003o`000?nkA;_o^dBk00;o^dBk0_l0000<ojEJY@03o`000?nCK9?o
TfbC013oTfbC1?l00003ogF:M@03o`000?mNXEkoGZ5N00_oGZ5N00?o0000ofbCK?m/Tf`01_m/Tf`0
0ol0003oDZeBoe:]DP07oe:]DP03o`000?ll`cco?<<l00Oo?<<l3?l0000>ogF:M@03o`000?nAKY7o
TFjA00KoTFjA00?o0000ol8m`_o2?L803_o2?L800ol0003obcC;ol/db`0;ol/db`03o`000?oT6nCo
i1_T00Ooi1_T00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oX5nSoj1OX00Woj1OX00Co0000ok]4
^ol0003o00003_nUFZD00ol0003oTfbCoi=/T`0?oi=/T`03o`000?meRWGoMHYe00KoMHYe00?o0000
oejQG_mNXEh02_mNXEh00ol0003oK9=/ofbCK007ofbCK0;o00001_mB[E800ol0003o?<<locc3?008
occ3?003o`000?n>LHkoSW6>00SoSW6>00?o0000ogF:MOmeRWD03?meRWD00ol0003oTFjAoi5^T@05
oi5^T@03o`000?o2?L;o`Sg200oo`Sg20_l0000=ol/db`03o`000?oT6nCoi1_T00Koi1_T00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oX5nSoj1OX00[oj1OX00?o0000ojEJYOnUFZD03_nUFZD00ol0
003oTfbCoi=/T`0>oi=/T`03o`000?meRWGoMHYe00OoMHYe00?o0000oejQG_mNXEh02_mNXEh00ol0
003oK9=/ofbCK009ofbCK0;o00000omB[E800ol0003o?<<locc3?009occ3?003o`000?n>LHkoSW6>
00WoSW6>00?o0000ogF:MOmeRWD02_meRWD4o`0000CoTFjA00?o0000ol8m`_o2?L804?o2?L801?l0
003ob3O8o`000?l0000<ol/db`03o`000?oT6nCoi1_T00Goi1_T00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oX5nSoj1OX00[oj1OX00?o0000ojEJYOnUFZD03onUFZD@o`0000[oMHYe00?o0000oejQ
G_mNXEh02OmNXEh00ol0003oAKY5o`00000<ofbCK005o`000?mB[E;o0000ock1?_l000002_ll`c`0
0ol0003oSW6>ohiaSP09ohiaSP03o`000?meRWGoMHYe00OoMHYe0ol00004oiYUVP?o000000?oTFjA
o`000?o2?L804Oo2?L801?l0003ob3O8olPgb?o8=lP2o`0000_obcC;00?o0000on@Ki?oT6n@00ooT
6n@00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onPGj?oX5nP02_oX5nP00ol0003oYEZUojEJY@0?
ojEJY@03o`000?nJII[oVVFJ00coVVFJ00?o0000ogF:MOmeRWD02OmeRWD00ol0003oGZ5NoejQGP07
oejQGP04o`000?m5^TGoAKY5o`0000goK9=/00Go0000ock1?_ln`Cko?/4no`000009occ3?003o`00
0?n>LHkoSW6>00[oSW6>00?o0000ogF:MOmeRWD00omeRWD3o`0000[oVVFJ00?o0000ol8m`_o2?L80
4?o2?L800ol0003ob3O8olPgb004olPgb0;o00002_o;=</00ol0003oi1_Ton@Ki004o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo/4nook1?/02_ok
1?/3o`0000coj1OX00?o0000ojEJYOnUFZD03onUFZD00ol0003oVVFJoiYUVP0<oiYUVP03o`000?me
RWGoMHYe00WoMHYe00?o0000oejQG_mNXEh01_mNXEh00ol0003oAKY5odFjA@02odFjA@03o`000?m/
TfcoK9=/00[oK9=/00?o0000ock1?_ln`Ch00_ln`Ch00ol0003o?<<locc3?006occ3?003o`000?n>
LHkoSW6>00[oSW6>00?o0000ogF:MOmeRWD00ol0000=oiYUVP03o`000?o2?L;o`Sg2013o`Sg200?o
0000olPgb?o8=lP01_o8=lP2o`0000WobcC;0_l00004ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo/4nook1?/01Ook1?/4
o`0000;oo0?l00?o0000onPGj?oX5nP02_oX5nP00ol0003oYEZUojEJY@0=ojEJY@?o00003onJIIX0
0ol0003oMHYeogF:M@08ogF:M@03o`000?mNXEkoGZ5N00GoGZ5N00?o0000odFjAOm5^TD00om5^TD0
0ol0003oK9=/ofbCK00:ofbCK003o`000?ln`Cko?/4n00?o?/4n00?o0000occ3??ll`c`01Oll`c`0
0ol0003oSW6>ohiaSP0;ohiaSP;o00004OnJIIX00ol0003o`Sg2ol8m`P0?ol8m`P03o`000?o8=lSo
b3O800Sob3O80_l00007ol/db`03o`000?oj1O[onPGj00ConPGj00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003on`Ckoo/4n`04o`00
00Ooo0?l00?o0000onPGj?oX5nP02?oX5nP00ol0003oYEZUojEJY@09ojEJY@Go00000_moP7l00ol0
003oVVFJoiYUVP0=oiYUVP03o`000?meRWGoMHYe00WoMHYe00?o0000oejQG_mNXEh01?mNXEh00ol0
003oAKY5odFjA@04odFjA@03o`000?m/TfcoK9=/00SoK9=/00?o0000ock1?_ln`Ch01Oln`Ch00ol0
003o?<<locc3?004occ3?003o`000?n>LHkoSW6>00_oSW6>00?o0000oiYUV_nJIIX04?nJIIX00ol0
003o`Sg2ol8m`P0?ol8m`P03o`000?o8=lSob3O800[ob3O80_l00004ol/db`03o`000?oj1O[onPGj
00KonPGj0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003oj1OXonPGj007onPGj003o`000?nUFZGoYEZU00CoYEZU1Ol00007ogn0O`03
o`000?nJII[oVVFJ00goVVFJ00?o0000ogF:MOmeRWD02OmeRWD00ol0003oGZ5NoejQGP03oejQGP03
o`000?m5^TGoAKY500GoAKY500?o0000ofbCK?m/Tf`02?m/Tf`00ol0003o?/4nock1?P06ock1?P03
o`000?ll`cco?<<l00?o?<<l00?o0000ohiaS_n>LHh02on>LHh00ol0003oVVFJoiYUVP0@oiYUVP03
o`000?o2?L;o`Sg200oo`Sg200?o0000olPgb?o8=lP03?o8=lP2o`000003ol/dbol0003onPGj00[o
nPGj00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oX5nSoj1OX00Ooj1OX00?o0000ojEJYOl00000
1?l0000<ogn0O`03o`000?nJII[oVVFJ00koVVFJ00?o0000ogF:MOmeRWD02?meRWD00ol0003oGZ5N
oejQGP02oejQGP03o`000?m5^TGoAKY500OoAKY500?o0000ofbCK?m/Tf`01om/Tf`00ol0003o?/4n
ock1?P07ock1?P03o`000?ll`cco?<<l00;o?<<l00?o0000ohiaS_n>LHh02on>LHh00ol0003oVVFJ
oiYUVP0AoiYUVP03o`000?o2?L;o`Sg200go`Sg200?o0000olPgb?o8=lP03oo8=lP00ol0003onPGj
ooX5nP0;ooX5nP;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onPGj?oX5nP01OoX5nP3o`00017oOh1o00?o0000oiYUV_nJIIX03_nJ
IIX00ol0003oMHYeogF:M@09ogF:M@04o`000?mNXEkoGZ5No`0000[oAKY500?o0000ofbCK?m/Tf`0
1om/Tf`00ol0003o?/4nock1?P08ock1?P05o`000?ll`cco?<<locc3??l000003On>LHh00ol0003o
VVFJoiYUVP0AoiYUVP?o00003Oo2?L800ol0003ob3O8olPgb00?olPgb003o`000?oj1O[onPGj00go
nPGj00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_oX5nP2o`0000;o]dRg00?o0000ogn0OomoP7l03omoP7l00ol0003o
VVFJoiYUVP0>oiYUVP03o`000?meRWGoMHYe00SoMHYe1Ol0000;odFjA@03o`000?m/TfcoK9=/00Ko
K9=/00?o0000ock1?_ln`Ch02Oln`Ch01?l0003o?<<locc3??l0000=ohiaSP03o`000?nJII[oVVFJ
017oVVFJ00?o0000ogJ9M_mfRGH00ol0000:ol8m`PCo00003Oo8=lP00ol0003onPGjooX5nP0?ooX5
nP03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000on@Ki?oT6nCoi1_T0_l00005okM8]`03o`000?moP7ooOh1o00koOh1o00?o0000oiYU
V_nJIIX03_nJIIX00ol0003oMHYeogF:M@07ogF:M@03o`000?mbSG;oLXeb00?oLXeb00?o0000odFj
AOm5^TD02?m5^TD00ol0003oK9=/ofbCK005ofbCK003o`000?ln`Cko?/4n00[o?/4n1Ol0000<ohia
SP03o`000?nJII[oVVFJ013oVVFJ00?o0000ogJ9M_mfRGH01?mfRGH3o`0000Ko`Sg200?o0000oldb
cOo=</d00_o=</d5o`0000Sob3O800?o0000ooX5n_oj1OX04?oj1OX00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oT6nCoi1_T00?o
i1_T00?o0000okM8]ongB;L01?ngB;L00ol0003oOh1oogn0O`0=ogn0O`03o`000?nJII[oVVFJ00oo
VVFJ00?o0000ogF:MOmeRWD01?meRWD2o`0000OoLXeb00?o0000odFjAOm5^TD01om5^TDEo`0000Go
C;=<00?o0000ohiaS_n>LHh02?n>LHh3o`00013oVVFJ00?o0000ogJ9M_mfRGH02?mfRGH3o`0000;o
`Sg200?o0000oldbcOo=</d02?o=</d5o`0000?ob3O800?o0000ooX5n_oj1OX04?oj1OX00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?oT6nCoi1_T00Coi1_T00?o0000okM8]ongB;L01OngB;L00ol0003oOh1oogn0O`0;ogn0O`Co0000
3onJIIX00ol0003oMHYeogF:M@03ogF:M@03o`000?mbSG;oLXeb00SoLXeb00?o0000odFjAOm5^TD0
1?m5^TD2o`0000SoLXeb00?o0000of6NHOmQWV402?mQWV400ol0003oC;=<odbcC005odbcC0;o0000
1_n>LHh2o`0000?oPGj100?o0000oiYUV_nJIIX03?nJIIX00ol0003oMXUfogJ9MP0<ogJ9MP;o0000
4?o=</d3o`0001?onPGj00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oi1_Ton@Ki005on@Ki003o`000?ngB;Oo]dRg00Ko]dRg00?o
0000ogn0OomoP7l02OmoP7l00ol0003oJYEZo`000002ogR7N0?o00003?nJIIX01?l0003oMHYeogF:
MOmeRWD2o`0000coLXeb00?o0000odFjAOm5^TD00_m5^TD00ol0003oLXebog:=LP08og:=LP03o`00
0?mQWV7oHIiQ00SoHIiQ00?o0000odbcC?m</d`01om</d`00ol0003oSW6>ohiaSP02ohiaSP03o`00
0?n1OX7oPGj100CoPGj10_l0000;oiYUVP03o`000?mfRGKoMXUf00coMXUf00?o0000oi=/Tol00000
4_o=</d00ol0003onPGjooX5nP0@ooX5nP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003oi1_Ton@Ki006on@Ki003o`000?ngB;Oo]dRg00Oo]dRg00?o
0000ogn0OomoP7l01_moP7l2o`0000;oJYEZ00?o0000ogR7N?mhQgP00omhQgP3o`0000[oVVFJ00?o
0000ogF:MOl000003ombSG801?l0003oAKY5o`000?l0000;og:=LP03o`000?mQWV7oHIiQ00SoHIiQ
00?o0000odbcC?m</d`02?m</d`01?l0003oSW6>o`000?l00009oh5nP@03o`000?nJII[oVVFJ00Oo
VVFJ00?o0000ogJ9M_mfRGH03?mfRGH01?l0003oTfbCoi=/Tol0000Coldbc@03o`000?oj1O[onPGj
00conPGj0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000on@Ki?oT6n@01ooT6n@00ol0003o]dRgokM8]`08okM8]`03o`000?moP7ooOh1o00Co
Oh1o00?o0000ofZEJ_mZUFX00omZUFX00ol0003oN8MhogR7N005ogR7N0?o00001_nJIIX4o`00013o
LXeb00?o0000og:=L_mbSG803?mbSG800ol0003oHIiQof6NH@07of6NH@03o`000?m</dcoC;=<00Wo
C;=<00?o0000oh5nPOn1OX402_n1OX42o`0000KoVVFJ00?o0000ogJ9M_mfRGH03?mfRGH00ol0003o
TfbCoi=/T`02oi=/T`03o`000?o=</gocC;=00oocC;=00?o0000on0Oh?l000002ooj1OX2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oi1_Ton@Ki008on@Ki003o`000?ngB;Oo]dRg00Wo]dRg00Co0000ogn0OomoP7oo
Oh1o0_l00006ofZEJP03o`000?mhQgSoN8Mh00SoN8Mh0ol000000onJII[o0000o`000004ogf2O@03
o`000?mbSG;oLXeb00goLXeb00?o0000og:=L_mbSG803?mbSG800ol0003oHIiQof6NH@07of6NH@03
o`000?m</dcoC;=<00WoC;=<00?o0000oh5nPOn1OX403?n1OX400ol0003oVVFJoiYUVP03o`0000ko
MXUf00?o0000oi=/TonCK9<00onCK9<00ol0003ocC;=oldbc@0>oldbc@05o`000?oP7n3oh1oPon0O
h?l000002?oj1OX2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003oi1_Ton@Ki009on@Ki003o`000?ngB;Oo]dRg00[o
]dRg00?o0000ogn0Ool000002?mZUFX00ol0003oN8MhogR7N00;ogR7N003o`000?mmPWgoOH9m00Go
OH9m00?o0000og:=L_mbSG803?mbSG800ol0003oLXebog:=LP0<og:=LP03o`000?mQWV7oHIiQ00Oo
HIiQ00?o0000odbcC?m</d`02?m</d`2o`0000ooPGj10_l00002ohMhQ`03o`000?mfRGKoMXUf00_o
MXUf00?o0000oi=/TonCK9<01?nCK9<00ol0003ocC;=oldbc@0=oldbc@03o`000?oP7n3oh1oP00?o
h1oP00?o0000ooX5n_oj1OX00_oj1OX3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on@Ki003o`000?ngB;Oo]dRg00_o]dRg00?o0000ofZEJ_mZUFX0
1omZUFX00ol0003oN8MhogR7N00;ogR7N003o`000?mmPWgoOH9m00KoOH9m00?o0000og:=L_mbSG80
2ombSG82o`0000goLXeb00?o0000of6NHOmQWV401omQWV400ol0003oC;=<odbcC007odbcC004o`00
0?mIYUWoFJIIo`0000koPGj100?o0000ohMhQon7N8L00_n7N8L00ol0003oMXUfogJ9MP09ogJ9MP03
o`000?nCK9?oTfbC00KoTfbC00?o0000oldbcOo=</d02oo=</d00ol0003oh1oPon0Oh005on0Oh004
o`000?oj1O[o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000Soi1_T00?o0000okM8]ongB;L02_ngB;L2o`0000Wo
JYEZ00?o0000ogR7N?mhQgP02omhQgP00ol0003oOH9mogf2O@07ogf2O@03o`000?mbSG;oLXeb00Wo
LXeb00Co0000occ3??ll`cco00003?mbSG800ol0003oHIiQof6NH@07of6NH@03o`000?m</dcoC;=<
00KoC;=<00Go0000oeVVFOmIYUWoFJIIo`00000>oh5nP@03o`000?n7N8OoQgR700?oQgR700?o0000
ogJ9M_mfRGH01omfRGH00ol0003oTfbCoi=/T`07oi=/T`03o`000?o=</gocC;=00[ocC;=00?o0000
on0Oh?oP7n001ooP7n000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006on@Ki003o`000?ngB;Oo]dRg
00Wo]dRg00Co0000oi=/TonCK9?o00002OmZUFX00ol0003oN8MhogR7N009ogR7N003o`000?mmPWgo
OH9m00WoOH9m00?o0000og:=L_mbSG801ombSG800ol0003o?<<locc3?002occ3?003o`000?mbSG;o
LXeb00WoLXeb00?o0000of6NHOmQWV401omQWV400ol0003oC;=<odbcC005odbcC003o`000?mIYUWo
FJII00?oFJII00?o0000oh5nPOn1OX402_n1OX400ol0003oQgR7ohMhQ`05ohMhQ`03o`000?mfRGKo
MXUf00GoMXUf00?o0000oi=/TonCK9<02?nCK9<00ol0003ocC;=oldbc@09oldbc@03o`000?oP7n3o
h1oP00Soh1oP00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oT6n@3o`0000Wo]dRg00?o0000oi=/
TonCK9<00_nCK9<00ol0003oJYEZofZEJP06ofZEJP03o`000?mhQgSoN8Mh00WoN8Mh00?o0000ogf2
OOmmPWd02_mmPWd00ol0003oLXebog:=LP05og:=LP03o`000?ll`cco?<<l00Co?<<l00?o0000og:=
L_mbSG802?mbSG800ol0003oHIiQof6NH@07of6NH@03o`000?m</dcoC;=<00CoC;=<00?o0000oeVV
FOmIYUT01?mIYUT00ol0003oPGj1oh5nP@0:oh5nP@03o`000?n7N8OoQgR700KoQgR700?o0000ogJ9
M_mfRGH00omfRGH00ol0003oTfbCoi=/T`09oi=/T`03o`000?o=</gocC;=00SocC;=00?o0000on0O
h?oP7n002OoP7n000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omdRg@?o00001OngB;L00ol0003o
TfbCoi=/T`03oi=/T`03o`000?mZUF[oJYEZ00KoJYEZ00?o0000ogR7N?mhQgP02OmhQgP00ol0003o
OH9mogf2O@0;ogf2O@03o`000?mbSG;oLXeb00?oLXeb00?o0000occ3??ll`c`01_ll`c`00ol0003o
LXebog:=LP08og:=LP03o`000?mQWV7oHIiQ00KoHIiQ00?o0000odbcC?m</d`00_m</d`2o`0000So
FJII00?o0000oh5nPOn1OX402On1OX400ol0003oQgR7ohMhQ`07ohMhQ`05o`000?mfRGKoMXUfogJ9
M_l000003OnCK9<00ol0003ocC;=oldbc@06oldbc@03o`000?oP7n3oh1oP00[oh1oP00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oM8]gogB;M00GogB;M0ol000000ongB;Oo0000oi=/T`06oi=/T`03
o`000?mZUF[oJYEZ00GoJYEZ00?o0000ogR7N?mhQgP02OmhQgP00ol0003oOH9mogf2O@0<ogf2O@05
o`000?mbSG;oLXebog:=L_l000002_ll`c`00ol0003oLXebog:=LP07og:=LP03o`000?mQWV7oHIiQ
00KoHIiQ00?o0000odbcC?l000000_l000000on;M8_o0000oeVVF@07oeVVF@03o`000?n1OX7oPGj1
00SoPGj100?o0000ohMhQon7N8L02On7N8L00ol0003oMXUfo`00000=oi=/T`Co00001Oo=</d00ol0
003oh1oPon0Oh00;on0Oh003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003ogB;MomdRg@08omdRg@03
o`000?nCK9?oTfbC00OoTfbC00?o0000ofZEJ_mZUFX01?mZUFX00ol0003oN8MhogR7N009ogR7N003
o`000?mmPWgoOH9m00goOH9m00?o0000og:=L_l000003?ll`c`:o`0000OoHIiQ0ol00005oh]dR`03
o`000?mIYUWoFJII00KoFJII00?o0000oh5nPOn1OX401on1OX400ol0003oQgR7ohMhQ`0:ohMhQ`03
o`000?nCK9?oTfbC00_oTfbC00?o0000okY5^_njAKX00_njAKX3o`000003oldbcOl0003oh1oP00_o
h1oP0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omdRgOoM8]d02OoM8]d00ol0003oTfbCoi=/T`07oi=/T`03o`00
0?mZUF[oJYEZ00GoJYEZ00?o0000ogR7N?mhQgP01omhQgP00ol0003oOH9mogf2O@0?ogf2O@;o0000
2oll`c`00ol0003oOh1oogn0O`07ogn0O`03o`000?mQWV7oHIiQ00;oHIiQ0ol00008oh]dR`03o`00
0?mIYUWoFJII00KoFJII00?o0000oh5nPOn1OX401on1OX400ol0003oQgR7ohMhQ`0:ohMhQ`03o`00
0?nCK9?oTfbC00[oTfbC00?o0000okY5^_njAKX01_njAKX00ol0003oh1oPon0Oh008on0Oh0?o0000
0_oX5nP00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omdRgOoM8]d02OoM8]d00ol0003oTfbCoi=/
T`08oi=/T`03o`000?mZUF[oJYEZ00CoJYEZ00?o0000ogR7N?mhQgP01omhQgP00ol0003oOH9mogf2
O@0>ogf2O@04o`000?m>/DkoC[5>o`0000Wo?<<l00?o0000ogn0OomoP7l02OmoP7l01?l0003oHIiQ
o`000?l0000<oh]dR`03o`000?mIYUWoFJII00KoFJII00?o0000oh5nPOn1OX401_n1OX400ol0003o
QgR7ohMhQ`0;ohMhQ`03o`000?nCK9?oTfbC00OoTfbC0_l00009okY5^P03o`000?oP7n3oh1oP00Co
h1oP1?l00006onPGj003o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003ogB;MomdRg@09omdRg@03o`00
0?nCK9?oTfbC00SoTfbC00?o0000ofZEJ_mZUFX00omZUFX>o`0000goOH9m00?o0000odjaC_m>/Dh0
0_m>/Dh00ol0003o?<<locc3?005occ3?003o`000?moP7ooOh1o00_oOh1o00?o0000oh]dRon;M8/0
3?n;M8/00ol0003oFJIIoeVVF@06oeVVF@03o`000?n1OX7oPGj100GoPGj100?o0000ohMhQon7N8L0
3?n7N8L00ol0003oTfbCoi=/T`06oi=/T`03o`000?njAK[o^TFj00[o^TFj00?o0000on0Oh?oP7n00
0ol0000:onPGj0?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000oi=/TonCK9<02?nC
K9<01Ol0003oJYEZofZEJ_mZUF[o000000_oL8m`00?o0000obSG:?lXebP00ol00009ogf2O@03o`00
0?m>/DkoC[5>00CoC[5>00?o0000occ3??ll`c`00oll`c`00ol0003oOh1oogn0O`0<ogn0O`03o`00
0?n;M8_oRgB;00goRgB;00?o0000oeVVFOmIYUT01_mIYUT00ol0003oPGj1oh5nP@03oh5nP@?o0000
3On7N8L00ol0003oTfbCoi=/T`05oi=/T`03o`000?njAK[o^TFj00co^TFj0_l0000=onPGj003o`00
0?ol0ocoo0?l00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000oi=/TonCK9<02?nC
K9<4o`0000coL8m`00?o0000obSG:?lXebP00olXebP3o`0000GoOH9m00?o0000odjaC_m>/Dh01_m>
/Dh01Ol0003o?<<locc3??ll`cco000000ooOh1o00?o0000oh]dRon;M8/03On;M8/00ol0003oFJII
oeVVF@06oeVVF@03o`000?n1OX7oPGj100?o00000omMXUd00ol0003oQgR7ohMhQ`0;ohMhQ`03o`00
0?nCK9?oTfbC00?oTfbC00?o0000okY5^_njAKX03OnjAKX00ol0003oj1OXonPGj00;onPGj003o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omdRgOoM8]d02_oM8]d3o`0000KoTfbC0ol0
0003ohEjQ@03o`000?m`Sg3oL8m`00[oL8m`00?o0000obSG:?lXebP01_lXebP3o`000003ogf2OOl0
003oC[5>00WoC[5>00?o0000occ3??l000004?moP7l00ol0003oRgB;oh]dR`0=oh]dR`03o`000?mI
YUWoFJII00OoFJII0_l00007oefRG@03o`000?n7N8OoQgR700[oQgR700Co0000oi=/TonCK9?oTfbC
0ol0000?okY5^P03o`000?oX5nSoj1OX00_oj1OX00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omdRgOoM8]d02_oM
8]d01?l0003oaC[5olDjaOo5>/D2o`000004oi=/Tol0003o0000o`0000KoQGZ500?o0000og2?L?m`
Sg002_m`Sg000ol0003o:=LXobSG:009obSG:003o`000?m>/DkoC[5>00[oC[5>00?o0000ogn0Oomo
P7l03omoP7l00ol0003oRgB;oh]dR`0>oh]dR`03o`000?mIYUWoFJII00KoFJII00?o0000oefRGOmM
XUd01omMXUd4o`0000SoQgR700Co0000oi=/TonCK9?o00000omhQgP2o`0000go^TFj00?o0000onPG
j?oX5nP02_oX5nP00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omdRgOoM8]d02OoM8]d00ol0003o
aC[5olDja@04olDja@03o`000?n5NXGoQGZ500OoQGZ500?o0000og2?L?m`Sg002Om`Sg000ol0003o
:=LXobSG:00:obSG:003o`000?m>/DkoC[5>00[oC[5>00?o0000ogn0OomoP7l03omoP7l00ol0003o
RgB;oh]dR`0>oh]dR`03o`000?mIYUWoFJII00GoFJII00?o0000oefRGOmMXUd02?mMXUd01?l0003o
Lhacog><LomcS7<7o`0000;oQgR70_l00006ogR7N0;o00003?njAKX00ol0003oj1OXonPGj009onPG
j003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003ogB;MomdRg@08omdRg@03o`000?o5>/GoaC[500Go
aC[500?o0000ohEjQOn5NXD02?n5NXD00ol0003oL8m`og2?L008og2?L003o`000?lXebSo:=LX00[o
:=LX00?o0000odjaC_m>/Dh02om>/Dh00ol0003oOh1oogn0O`0>ogn0O`03o`000?n;M8_oRgB;00ko
RgB;1Ol00002oeVVF@03o`000?mMXUgoGJ9M00WoGJ9M00?o0000og><LomcS7<02?mcS7<3o`0000Wo
N8Mh0_l0000:okY5^P03o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oM8]gogB;M00SogB;M00?o0000olDjaOo5>/D01oo5>/D00ol0003oQGZ5ohEjQ@07ohEjQ@03o`00
0?m`Sg3oL8m`00SoL8m`00?o0000obSG:?lXebP02_lXebP00ol0003oC[5>odjaCP0:odjaCP;o0000
3_moP7l3o`0000goRgB;0ol00005ohiaSP;o00002omMXUd00ol0003oLhacog><L`0;og><L`;o0000
2_mhQgP2o`0000Oo^TFj0ol00009onPGj003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:olDja@03o`00
0?n5NXGoQGZ500OoQGZ500?o0000og2?L?m`Sg002?m`Sg0>o`0000WoC[5>0ol000000ol]dRgo0000
ogn0O`0:ogn0O`?o00000_nCK9<00ol0003oRgB;oh]dR`09oh]dR`;o00002On>LHh00ol0003oGJ9M
oefRG@09oefRG@03o`000?mcS7?oLhac00_oLhac00?o0000ohMhQol000002omhQgP2o`0000Co^TFj
00Co0000om`Sg?oL8mcog2?L0_l00007onPGj003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003oaC[5
olDja@09olDja@03o`000?n5NXGoQGZ500KoQGZ500?o0000og2?L?m`Sg002?m`Sg000ol0003o><Lh
ocS7>00:ocS7>003o`000?m>/DkoC[5>00CoC[5>0ol00005obgB;@03o`000?moP7ooOh1o00CoOh1o
1?l00006oi=/T`03o`000?n;M8_oRgB;00KoRgB;0_l0000;ohiaSP03o`000?mMXUgoGJ9M00WoGJ9M
00?o0000og><LomcS7<02_mcS7<01Ol0003oQgR7ohMhQon7N8Oo000000coN8Mh0_l000000onjAK[o
0000om`Sg005om`Sg003o`000?oX5nSoj1OX00?oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o5>/GoaC[500SoaC[500?o0000ohEjQOn5NXD01_n5NXD00ol0003oL8m`og2?L007og2?L003o`00
0?lhacSo><Lh00_o><Lh00?o0000odjaC_m>/Dh00_m>/Dh2o`0000Wo;M8]00?o0000ogn0OomoP7l0
0ol0000;oi=/T`03o`000?n;M8_oRgB;00;oRgB;0ol0000>ohiaSP03o`000?mMXUgoGJ9M00OoGJ9M
00?o0000og><LomcS7<02omcS7<00ol0003oQgR7ohMhQ`02ohMhQ`03o`000?mhQgSoN8Mh00_oN8Mh
00?o0000om`Sg?oL8m`01_oL8m`2o`0000?oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o5
>/GoaC[500OoaC[500?o0000ohEjQOn5NXD01on5NXD00ol0003oL8m`og2?L005og2?L0?o00003Olh
acP4o`0000_o;M8]0ol0000?oi=/T`04o`000?n;M8_o0000o`00017oSW6>00?o0000oefRGOmMXUd0
1omMXUd00ol0003oLhacog><L`0:og><L`03o`000?n7N8OoQgR700CoQgR700?o0000ogR7N?mhQgP0
1omhQgP3o`0000_og2?L1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000olDjaOo5>/D02?o5>/D00ol0003oQGZ5ohEj
Q@06ohEjQ@03o`000?m`Sg3oL8m`00;oL8m`0ol00003oeZUFP03o`000?lhacSo><Lh00[o><Lh00?o
0000obgB;Ol]dRd02ol]dRd00ol0003o>LHio`00000Aoi=/T`03o`000?n>LHkoSW6>017oSW6>00?o
0000oefRGOmMXUd01omMXUd00ol0003oLhacog><L`0:og><L`03o`000?n7N8OoQgR700GoQgR700Co
0000ogR7N?mhQgSoN8Mh1Ol00002ohiaSP03o`000?oL8mcog2?L00Wog2?L00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000olDjaOo5>/D01oo5>/D00ol0003oQGZ5ohEjQ@05ohEjQ@?o0000
00?oL8m`o`000?l000001omJYEX00ol0003o><LhocS7>008ocS7>0?o00002_l]dRd2o`0000;o>LHi
00?o0000oi=/TonCK9<03onCK9<00ol0003oSW6>ohiaSP0AohiaSP03o`000?mMXUgoGJ9M00OoGJ9M
00?o0000og><LomcS7<02OmcS7<00ol0003oQgR7ohMhQ`07ohMhQ`?o00001on>LHh00ol0003og2?L
om`Sg009om`Sg003o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000olDjaOo5>/D01oo5
>/D4o`0000;oQGZ50_l00003oi1_T003o`000?mJYE[oFZEJ00SoFZEJ0_l00006ocS7>0;o00000olo
`3l00ol0003o;M8]obgB;@06obgB;@03o`000?liaSWo>LHi00?o>LHi00?o0000oi=/TonCK9<03_nC
K9<00ol0003oSW6>ohiaSP0BohiaSP03o`000?mMXUgoGJ9M00GoGJ9M00?o0000og><LomcS7<02Omc
S7<00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?n>LHkoSW6>00OoSW6>00?o0000om`Sg?oL8m`02?oL
8m`00ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o5>/GoaC[500CoaC[50_l00004
om@[e0;o00001On@Ki000ol0003oFZEJoeZUFP0:oeZUFP03o`000?lhacSo><Lh00;o><Lh00?o0000
oco0?olo`3l01?lo`3l00ol0003o;M8]obgB;@04obgB;@03o`000?liaSWo>LHi00Co>LHi00?o0000
oi=/TonCK9<03_nCK9<00ol0003oSW6>ohiaSP0BohiaSP[o00002_mcS7<00ol0003oQgR7ohMhQ`08
ohMhQ`03o`000?n>LHkoSW6>00OoSW6>00?o0000om`Sg?oL8m`02?oL8m`00ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003oaC[5olDjaOo5>/D2o`0000Ooe2_D00?o0000oi1_T?n@Ki001?n@Ki00
0ol0003oFZEJoeZUFP0:oeZUFP04o`000?lhacSo0000o`0000So?l0o00Co0000obgB;Ol]dRgo;M8]
0_l00007ocW6>@03o`000?nCK9?oTfbC00koTfbC00?o0000ohiaS_n>LHh04_n>LHh00ol0003oKI9]
offBK@07offBK@03o`000?mcS7?oLhac00KoLhac00?o0000ohMhQon7N8L02_n7N8L00ol0003oSW6>
ohiaSP06ohiaSP03o`000?oL8mcog2?L00Sog2?L00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o5
>/Go0000o`0000Woe2_D00?o0000oi1_T?n@Ki001?n@Ki000ol0003oFZEJoeZUFP0;oeZUFP03o`00
0?lo`3oo?l0o00Wo?l0o00?o0000obgB;Ol000002OliaST00ol0003oTfbCoi=/T`0>oi=/T`;o0000
4_n>LHh00ol0003oKI9]offBK@09offBK@;o00001_mcS7<00ol0003oQgR7ohMhQ`0:ohMhQ`03o`00
0?n>LHkoSW6>00KoSW6>00?o0000om`Sg?oL8m`02?oL8m`00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000om@[e?oD:m@02OoD:m@00ol0003oT6n@oi1_T005oi1_T003o`000?mJYE[oFZEJ00[oFZEJ00?o
0000oco0?olo`3l02_lo`3l2o`0000Wo>LHi00?o0000oi=/TonCK9<03_nCK9<00ol0003oNhAko`00
0002o`0000ooSW6>00?o0000offBKOm]TVd02om]TVd00ol0003oLhacog><L`03o`0000goQgR700?o
0000ohiaS_n>LHh01_n>LHh00ol0003og2?Lom`Sg007om`Sg003o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003oe2_Dom@[e009om@[e003o`000?n@Ki3oT6n@00GoT6n@00?o0000oeZUF_mJYEX02OmJYEX2
o`0000_o?l0o0_l0000;ocW6>@03o`000?nCK9?oTfbC00coTfbC00?o0000og^4NomkQ7/00omkQ7/3
o`0000coSW6>00?o0000offBKOm]TVd03?m]TVd2o`0000;oLHia00?o0000ohMhQon7N8L03?n7N8L0
0ol0003oSW6>ohiaSP05ohiaSP03o`000?oL8mcog2?L00Oog2?L00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oD:mCoe2_D00[oe2_D00?o0000oi1_T?n@Ki001_n@Ki000ol0003oFZEJoeZUFP07oeZU
FP03o`000?m8]dSo000000[o?l0o00Co0000ob_D:ol[e2_o00002_liaST00ol0003oTfbCoi=/T`0<
oi=/T`03o`000?mkQ7_oNhAk00KoNhAk0_l00008ohiaSP;o00003om]TVd00ol0003oLHiaog6>L@02
og6>L@03o`000?n7N8OoQgR700_oQgR700?o0000ohiaS_n>LHh01On>LHh00ol0003og2?Lom`Sg007
om`Sg003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oe2_Dom@[e00:om@[e003o`000?n@Ki3oT6n@
00KoT6n@00?o0000oeZUF_mJYEX01_mJYEX01Ol0003oB;M8odRgB?m8]dSo000000So?l0o00?o0000
ob_D:ol[e2/00_l[e2/00ol0003o>LHiocW6>@06ocW6>@Co00003?nCK9<00ol0003oNhAkog^4N`08
og^4N`?o00000_n>LHh3o`000003ofRGJ?l0003oKI9]00goKI9]00?o0000og6>LOmaSW401?maSW40
0ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?n>LHkoSW6>00GoSW6>00?o0000om`Sg?oL8m`01_oL8m`0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000om@[e?oD:m@02ooD:m@00ol0003oT6n@oi1_T007oi1_
T003o`000?mJYE[oFZEJ00?oFZEJ0_l00005odRgB003o`000?lo`3oo?l0o00Co?l0o00?o0000ob_D
:ol[e2/00ol[e2/00ol0003o>LHiocW6>@05ocW6>@03o`000?mKY5_oFjAK00;oFjAK0ol00007oi=/
T`;o00003_mkQ7/2o`0000GoJ9MX00?o0000offBKOm]TVd02_m]TVd00ol0003oLHiaog6>L@05og6>
L@03o`000?n7N8OoQgR700_oQgR700?o0000ohiaS_n>LHh01?n>LHh00ol0003og2?Lom`Sg006om`S
g003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oe2_Dom@[e00;om@[e003o`000?n@Ki3oT6n@00Oo
T6n@00?o0000oeZUF_mJYEX00_mJYEX00ol0003oB;M8odRgB006odRgB003o`000?lo`3oo?l0o00;o
?l0o00?o0000ob_D:ol[e2/01Ol[e2/00ol0003o>LHiocW6>@02ocW6>@;o00002?mKY5/3o`0000;o
TfbC0_l000000omUVVGo0000og^4N`0=og^4N`03o`000?mXUfSoJ9MX00GoJ9MX00?o0000offBKOm]
TVd02?m]TVd00ol0003oLHiaog6>L@07og6>L@03o`000?n7N8OoQgR700[oQgR700?o0000ohiaS_n>
LHh01?n>LHh00ol0003og2?Lom`Sg006om`Sg003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oe2_D
om@[e00<om@[e003o`000?n@Ki3oT6n@00SoT6n@00Co0000oeZUF_mJYE[o00002Om8]dP01Ol0003o
?l0ooco0?olo`3oo000000So:m@[00Go0000ocW6>OliaSWo>LHio`00000=oe^TF`;o00001?mUVVD0
0ol0003oNhAkog^4N`0;og^4N`03o`000?mXUfSoJ9MX00KoJ9MX00?o0000offBKOm]TVd01om]TVd0
0ol0003oLHiaog6>L@08og6>L@Co00002?n7N8L00ol0003oSW6>ohiaSP04ohiaSP03o`000?oL8mco
g2?L00Kog2?L00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oD:mCoe2_D00_oe2_D0ol00009oi1_
T003o`000?mJYE[o000000_oB;M800?o0000oco0?ol000002_l[e2/00ol0003o>LHio`00000?oe^T
F`03o`000?mUVVGoIIYU00;oIIYU00?o0000og^4NomkQ7/02omkQ7/00ol0003oJ9MXofRGJ006ofRG
J003o`000?m]TVgoKI9]00KoKI9]00?o0000og6>LOmaSW402OmaSW401?l0003oTVfBoi9]T_nBKI87
o`0000;oQgR700?o0000ohiaS_n>LHh00on>LHh00ol0003og2?Lom`Sg005om`Sg003o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oD:mCoe2_D00Soe2_D0ol00003ol4n`@03o`000?n@Ki3oT6n@00OoT6n@00?o0000odRg
B?m8]dP02om8]dP00ol0003o:m@[ob_D:`0:ob_D:`03o`000?mKY5_oFjAK00goFjAK00?o0000ofFJ
IOmUVVD01?mUVVD00ol0003oNhAkog^4N`09og^4N`03o`000?mXUfSoJ9MX00SoJ9MX00?o0000offB
KOm]TVd00om]TVd2o`0000coLHia00?o0000oi9]T_nBKI802?nBKI8<o`0000?og2?L0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000om@[e?oD:m@01_oD:m@3o`0000Oo`Ck100?o0000oi1_T?n@Ki001_n@Ki000ol0003o
B;M8odRgB00;odRgB003o`000?l[e2_o:m@[00Wo:m@[0_l0000>oe^TF`03o`000?mUVVGoIIYU00Go
IIYU00?o0000og^4NomkQ7/02OmkQ7/00ol0003oJ9MXofRGJ009ofRGJ003o`000?m]TVgo000000;o
00000_mXUfP00ol0003oLHiaog6>L@08og6>L@03o`000?nBKI;oTVfB00coTVfB00?o0000om`Sg?oL
8m`01_oL8m`3o`0000?on`Ck0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003oe2_Dom@[e003om@[e0?o00002oo1?/400ol0003oT6n@
oi1_T004oi1_T003o`000?m8]dSoB;M800_oB;M80ol00007ob_D:`?o000000?oC[5>o`000?mKY5/0
3OmKY5/00ol0003oIIYUofFJI@06ofFJI@03o`000?mkQ7_oNhAk00SoNhAk00?o0000ofRGJ?mXUfP0
2_mXUfP00ol0003oJ9MXofRGJ004ofRGJ003o`000?maSW7oLHia00OoLHia00?o0000oi9]T_nBKI80
2onBKI800ol0003og2?Lom`Sg008om`Sg003o`000?ok1?_on`Ck00Con`Ck0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004om@[e?l0
003o0000o`0000oo`Ck100?o0000oi1_T?n@Ki000on@Ki0>o`0000?oAKY50_l00002ob_D:`?o0000
1Om>/Dh00ol0003oFjAKoe^TF`0:oe^TF`03o`000?mUVVGoIIYU00OoIIYU00?o0000og^4NomkQ7/0
2?mkQ7/00ol0003oJ9MXofRGJ00:ofRGJ003o`000?mXUfSoJ9MX00GoJ9MX00?o0000og6>LOmaSW40
1_maSW400ol0003oTVfBoi9]TP0;oi9]TP03o`000?oL8mcog2?L00Sog2?L00?o0000oo/4nook1?/0
1ook1?/2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o`Ck100?o0000oi1_T?n@Ki000_n@Ki000ol0003oCk1?odn`
C`0:odn`C`03o`000?m5^TGoAKY500?oAKY50_l00009odjaCP03o`000?mKY5_oFjAK00WoFjAK00?o
0000ofFJIOmUVVD02?mUVVD2o`0000SoNhAk00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oJ9MXofRG
J007ofRGJ003o`000?maSW7oLHia00CoLHia00?o0000oi9]T_nBKI802onBKI800ol0003og2?Lom`S
g009om`Sg003o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o`Ck1ol4n`@0?ol4n`@?o000000?oT6n@
o`000?m?/4l02om?/4l00ol0003oAKY5odFjA@04odFjA@03o`000?m>/DkoC[5>00WoC[5>00?o0000
oe^TFomKY5/01omKY5/00ol0003oIIYUofFJI@09ofFJI@04o`000?mOX5oo0000o`0000KoNhAk00?o
0000ofRGJ?mXUfP02OmXUfP00ol0003oJ9MXofRGJ008ofRGJ003o`000?maSW7oLHia00?oLHia00?o
0000oi9]T_nBKI802onBKI800ol0003og2?Lom`Sg009om`Sg003o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o`Ck1ol4n`@0<ol4n`@;o00000oniA[T2o`0000coCk1?00?o0000odFjAOm5^TD01?m5^TD0
0ol0003oC[5>odjaCP0:odjaCPWo00002omUVVD00ol0003oGj1OoenPG`02oenPG`?o00000_mkQ7/0
0ol0003oJ9MXofRGJ00:ofRGJ003o`000?mXUfSoJ9MX00WoJ9MX00?o0000og6>LOmaSW400_maSW40
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?oL8mcog2?L00Wog2?L00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o1?/42o`0000Go^DJi00?o0000oh5nPOl000002_m?/4l00ol0003oAKY5odFjA@06odFj
A@03o`000?m>/DkoC[5>00WoC[5>00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oIIYUofFJI@09ofFJ
I@03o`000?mOX5ooGj1O00GoGj1O0ol00009ofRGJ0?o00003OmXUfP01Ol0003oLHiaog6>LOmaSW7o
000000coTVfB00?o0000om`Sg?oL8m`02OoL8m`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol4n
`Oo1?/401Oo1?/42o`0000Oo^DJi00Co0000oh5nPOn1OX7o00002Om?/4l00ol0003oAKY5odFjA@06
odFjA@03o`000?m>/DkoC[5>00SoC[5>00?o0000odjaC_m>/Dh01om>/Dh00ol0003oIIYUofFJI@07
ofFJI@03o`000?mOX5ooGj1O00SoGj1O0ol00002ofRGJ0Go00000_ll`c`00ol0003oJ9MXofRGJ00<
ofRGJ003o`000?maSW7o000000coTVfB00?o0000om`Sg?oL8m`02_oL8m`00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000ol4n`Oo1?/400_o1?/42o`0000So^DJi00?o0000oh5nPOn1OX400_n1OX45o`00
00CoCk1?00?o0000odFjAOm5^TD01_m5^TD00ol0003oC[5>odjaCP08odjaCP03o`000?m>/DkoC[5>
00OoC[5>00?o0000ofFJIOmUVVD01omUVVD00ol0003oGj1OoenPG`08oenPG`03o`000?lfbCKo=/Tf
00;o00002?ll`c`00ol0003oJ9MXofRGJ00<ofRGJ0Co00002_nBKI800ol0003og2?Lom`Sg00:om`S
g003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o`Ck1o`000?l0000:okU6^@03o`000?n1OX7oPGj1
00;oPGj100?o0000ob7N8OlQgR400_lQgR44o`0000WoAKY500?o0000odjaC_m>/Dh02?m>/Dh00ol0
003oC[5>odjaCP08odjaCP03o`000?mUVVGoIIYU00GoIIYU00?o0000oenPGomOX5l02?mOX5l01Ol0
003o=/TfocK9=_lfbCKo000000[o?<<l0ol0000;ofRGJ004o`000?o4>lCoa3_4ol@ka0Co00001OnB
KI800ol0003og2?Lom`Sg00;om`Sg003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o^DJiokU6^@0:
okU6^@03o`000?n1OX7oPGj100?oPGj100?o0000ob7N8OlQgR401?lQgR400ol0003oAKY5odFjA@07
odFjA@03o`000?m>/DkoC[5>00KoC[5>0_l0000;odjaCP03o`000?mUVVGoIIYU00GoIIYU00?o0000
oenPGomOX5l02?mOX5l00ol0003o=/TfocK9=P02ocK9=P03o`000?ll`cco?<<l00Oo?<<l00?o0000
ogZ5N_mjQGX01?l00006ofRGJ003o`000?o4>lCoa3_400Koa3_40ol00002oi9]TP03o`000?oL8mco
g2?L00_og2?L00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?niA[Wo^DJi00Wo^DJi00?o0000oh5n
POn1OX401?n1OX400ol0003o8MhQob7N8@05ob7N8@03o`000?m5^TGoAKY500OoAKY500?o0000odja
C_m>/Dh00_m>/Dh3o`000003oeZUF_l0003oC[5>00[oC[5>00?o0000ofFJIOmUVVD01OmUVVD00ol0
003oGj1OoenPG`07oenPG`03o`000?lfbCKo=/Tf00?o=/Tf00?o0000occ3??ll`c`01oll`c`00ol0
003oNXEjogZ5NP04ogZ5NP?o00000_mXUfP00ol0003oa3_4ol@ka00:ol@ka0;o00003_oL8m`00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000okU6^OniA[T02OniA[T00ol0003oPGj1oh5nP@04oh5nP@03
o`000?lQgR7o8MhQ00Ko8MhQ0_l00007odFjA@03o`000?m>/Dko000000;o00001OmJYEX00ol0003o
C[5>odjaCP08odjaCP?o00001?mUVVD00ol0003oGj1OoenPG`08oenPG`03o`000?lfbCKo=/Tf00Co
=/Tf00?o0000occ3??ll`c`01_ll`c`00ol0003oNXEjogZ5NP07ogZ5NP;o00003_o4>l@00ol0003o
g2?Lom`Sg00;om`Sg003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o^DJiokU6^@08okU6^@03o`00
0?n1OX7oPGj100GoPGj100?o0000ob7N8OlQgR401?lQgR400ol0003oC;=<odbcC003o`0000CoAKY5
0_l00008oeZUFP03o`000?m>/DkoC[5>00OoC[5>00Co0000ogmoOomoOgooOgmo0ol000000omUVVGo
0000oenPG`09oenPG`03o`000?lfbCKo=/Tf00Co=/Tf00?o0000occ3??ll`c`01Oll`c`00ol0003o
NXEjogZ5NP09ogZ5NP03o`000?o4>lCoa3_400goa3_400?o0000om`Sg?oL8m`02_oL8m`00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000okU6^OniA[T01oniA[T00ol0003oPGj1oh5nP@06oh5nP@03o`00
0?lQgR7o8MhQ00?o8MhQ00?o0000odbcC?m</d`01?m</d`2o`000003odFjAOl0003oFZEJ00[oFZEJ
00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oOgmoogmoO`05ogmoO`03o`000?mOX5ooGj1O00OoGj1O
0ol00007ocK9=P03o`000?ll`cco?<<l00Co?<<l00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oa3_4
ol@ka00=ol@ka003o`000?oL8mcog2?L00[og2?L00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?ni
A[Wo^DJi00Go^DJi0ol00009oh5nP@05o`000?lQgR7o8MhQob7N8Ol000002Om</d`00ol0003oFZEJ
oeZUFP0;oeZUFP03o`000?m>/DkoC[5>00?oC[5>00?o0000ogmoOomoOgl01_moOgl00ol0003oGj1O
oenPG`06oenPG`05o`000?mTVfCoI9]TofBKI?l000001olfbCH00ol0003o?<<locc3?003occ3?003
o`000?mjQG[oNXEj00WoNXEj00?o0000ol@ka?o4>l@03_o4>l@00ol0003og2?Lom`Sg009om`Sg003
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o^DJio`000004o`0000;oeB[E00?o0000oh5nPOn1OX40
1on1OX401?l0003o8MhQob7N8Ol00009odbcC0;o00003OmJYEX00ol0003oC[5>odjaCP02odjaCP03
o`000?moOgooOgmo00SoOgmo00?o0000oenPGomOX5l00omOX5l2o`0000GoI9]T00?o0000ocK9=_lf
bCH01?lfbCH00ol0003o?<<locc3?003occ3?003o`000?mjQG[oNXEj00WoNXEj00?o0000ol@ka?o4
>l@03_o4>l@00ol0003og2?Lom`Sg009om`Sg003o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SoeB[E
00?o0000oh5nPOn1OX401_n1OX400ol0003o8MhQo`000009odbcC004o`000?m_T6ooKi1_o`0000go
FZEJ00Co0000odjaC_m>/Dko00003?moOgl01Ol0003oGj1OoenPGomOX5oo000000SoI9]T0_l00005
ocK9=P03o`000?ll`cco?<<l00;o?<<l00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oa3_4ol@ka00>
ol@ka003o`000?oL8mcog2?L00Wog2?L00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oE:]GoeB[E
00OoeB[E00?o0000oh5nPOn1OX401on1OX400ol0003oC;=<odbcC007odbcC003o`000?m_T6ooKi1_
00;oKi1_00?o0000oeZUF_mJYEX02_mJYEX00ol0003oC[5>o`00000>ogmoO`03o`000?mOX5oo0000
00_oI9]T00?o0000ocK9=_lfbCH00_lfbCH01Ol0003o?<<locc3??ll`cco000000coNXEj00?o0000
ol@ka?o4>l@03_o4>l@3o`0000Wog2?L00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oE:]GoeB[E
00WoeB[E00?o0000oh5nPOn1OX401_n1OX400ol0003oC;=<odbcC006odbcC003o`000?m_T6ooKi1_
00?oKi1_00?o0000oeZUF_mJYEX02omJYEX00ol0003oOgmoogmoO`0>ogmoO`03o`000?mTVfCoI9]T
00_oI9]T0_l00003ocK9=P04o`000?ll`cco?<<lo`0000[oNXEj0ol0000>ol@ka0;o00000ooj1OX2
o`0000Oog2?L00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oE:]GoeB[E00[oeB[E00?o0000oh5n
POn1OX401?n1OX400ol0003oC;=<odbcC006odbcC003o`000?m_T6ooKi1_00GoKi1_00?o0000oeZU
F_mJYEX01omJYEX3o`00017oOgmo00?o0000ofBKI?mTVf@03OmTVf@01Ol0003o=/TfocK9=_l0003o
?<<l00Co00000omjQGX5o`0000;oa3_400?o0000ol@ka?o4>l@02_o4>l@2o`0000OonPGj0_l00004
om`Sg003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oeB[EomDZe@0;omDZe@03o`000?n1OX7oPGj1
00CoPGj100?o0000odbcC?m</d`01Om</d`00ol0003oKi1_ofn@K`06ofn@K`03o`000?mJYE[oFZEJ
00CoFZEJ0ol00002ofRGJ003o`000?moOgooOgmo00ooOgmo0_l0000?ofBKI004o`000?lfbCKo0000
o`0000CoJiA[0ol00008ol@ka003o`000?o4>lCoa3_400Ooa3_40_l0000;ooX5nP;o00000_oL8m`0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omDZeOoE:]D03?oE:]D6o`0000OoC;=<00?o0000ofn@
Kom_T6l02?m_T6l00ol0003oFZEJoeZUFP03o`0000KoJ9MX00?o0000ogmoOomoOgl03OmoOgl01?l0
003oMhQgogN8Mol0000?ofBKI003o`000?m[U6_oJiA[00GoJiA[00?o0000ol@ka?o4>l@02?o4>l@0
0ol0003oa3_4ol@ka005ol@ka003o`000?oj1O[onPGj00gonPGj0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oE:]D00ol0003oQgR7ohMhQ`04ohMh
Q`03o`000?m</dcoC;=<00?oC;=<00?o0000ofn@Kom_T6l02_m_T6l2o`0000[oJ9MX00?o0000ogmo
OomoOgl02omoOgl00ol0003oMhQgogN8M`02ogN8M`03o`000?mTVfCoI9]T00_oI9]T0_l00007of^D
J`03o`000?o4>lCoa3_400Woa3_400?o0000ol@ka?o4>l@00_o4>l@2o`0001;onPGj00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omDZeOoE:]D02ooE:]D00ol0003oQgR7ohMhQ`06ohMhQ`05o`000?m</dcoC;=<odbc
C?l000003Om_T6l00ol0003oJ9MXofRGJ00:ofRGJ003o`000?moOgooOgmo00WoOgmo00?o0000ogN8
MomgR7L01?mgR7L00ol0003oI9]TofBKI008ofBKI0;o000000?o?<<lo`000?m[U6/01om[U6/00ol0
003oa3_4ol@ka009ol@ka004o`000?o4>lCo0000o`0001ConPGj00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oE:]GoeB[E
00WoeB[E00?o0000ohMhQon7N8L02?n7N8L00ol0003oC;=<o`00000=ofn@K`03o`000?mXUfSoJ9MX
00_oJ9MX00?o0000ogmoOomoOgl02?moOgl00ol0003oMhQgogN8M`06ogN8M`03o`000?mTVfCoI9]T
00GoI9]T0_l00003occ3?003o`000?m[U6_oJiA[00KoJiA[00?o0000ol@ka?o4>l@02_o4>l@00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003oeB[EomDZe@07omDZe@03o`000?n7N8OoQgR700[oQgR700?o0000ofn@Kom_
T6l03?m_T6l00ol0003oJ9MXofRGJ00<ofRGJ003o`000?moOgooOgmo00KoOgmo00?o0000ogN8Momg
R7L02?mgR7L00ol0003oI9]TofBKI002ofBKI0;o00001_ll`c`00ol0003oJiA[of^DJ`05of^DJ`03
o`000?o4>lCoa3_400[oa3_400?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oE:]GoeB[E00GoeB[E
00?o0000ohMhQon7N8L03?n7N8L2o`0000coKi1_00?o0000ofRGJ?mXUfP03OmXUfP00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mgR7OoMhQg00[oMhQg00Co0000ofBKI?l0003o00002?ll`c`00ol0003o
JiA[of^DJ`06of^DJ`03o`000?o4>lCoa3_400Woa3_400?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oE:]D00ol0003oQgR7ohMhQ`0=ohMhQ`03o`000?mWV6Oo000000;o00002?m_T6l00ol0003oJ9MX
ofRGJ00?ofRGJ0Ko00003_mgR7L00ol0003o?<<locc3?008occ3?003o`000?m[U6_oJiA[00KoJiA[
00?o0000ol@ka?o4>l@02Oo4>l@00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000om@[e?oD:mCoe2_D
0_l0000?ohMhQ`03o`000?mWV6OoIiQW00?oIiQW0ol00005ofn@K`;o00004?mXUfP01_l0003oE:]D
oeB[E?l0003o?<<lo`0000koMhQg00?o0000occ3??ll`c`02Oll`c`00ol0003oJiA[of^DJ`05of^D
J`03o`000?o4>lCoa3_400Woa3_400?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000om@[e?oD:m@00ooD:m@00ol0003o
QgR7ohMhQ`0=ohMhQ`03o`000?mWV6OoIiQW00KoIiQW0ol000001?m_T6oo0000oefRGOmMXUd3o`00
00coJ9MX00Go0000oeB[E?mDZeCoE:]Do`000002occ3?003o`000?mgR7OoMhQg00_oMhQg00?o0000
occ3??ll`c`02Oll`c`00ol0003oJiA[of^DJ`06of^DJ`03o`000?o4>lCoa3_400Soa3_40_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003oe2_Dom@[e004om@[e0oo00003?mWV6L00ol0003oGJ9MoefRG@04oefR
G@?o00002?mXUfP00ol0003oE:]DoeB[E002oeB[E005o`000?ll`cco?<<locc3??l000003?mgR7L0
0ol0003o?<<locc3?009occ3?003o`000?m[U6_oJiA[00GoJiA[3?l00002on@Ki0;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003oe2_Dom@[e005om@[e003o`000?mbSG;oLXeb00_oLXeb00?o0000ofNH
IomWV6L02_mWV6L00ol0003oGJ9MoefRG@07oefRG@;o00001OmXUfP00ol0003oE:]DoeB[E003oeB[
E003o`000?ll`cco?<<l00;o?<<l00?o0000ogN8MomgR7L02OmgR7L00ol0003o?<<locc3?00:occ3
?003o`000?m[U6_oJiA[00?oJiA[00?o0000oi1_T?n@Ki002On@Ki000ol0003oi1_Ton@Ki002on@K
i0;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003oe2_Dom@[e006om@[e003o`000?mbSG;oLXeb00[o
LXeb00?o0000ofNHIomWV6L02omWV6L00ol0003oGJ9MoefRG@09oefRG@?o000000?oJ9MXo`000?mD
Ze@01OmDZe@00ol0003o?<<locc3?003occ3?003o`000?mgR7OoMhQg00SoMhQg3_l00003of^DJ`;o
00002on@Ki000ol0003oi1_Ton@Ki005on@Ki003o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000om@[e?oD:m@01OoD:m@00ol0003oR7N8o`00000;og:=LP03o`000?mWV6OoIiQW00[oIiQW
0_l0000>oefRG@03o`000?mDZeCoE:]D00GoE:]D00?o0000occ3??ll`c`00oll`c`00ol0003oMhQg
ogN8M`08ogN8M`03o`000?m`Sg3oL8m`00_oL8m`00?o0000of^DJol000003On@Ki000ol0003oi1_T
on@Ki006on@Ki0;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oD:mCoe2_D00Koe2_D00Co
0000ohQgR?n8MhSo00002_mbSG800ol0003oIiQWofNHI`09ofNHI`03o`000?mKY5_o000000koGJ9M
00?o0000oeB[E?mDZe@01OmDZe@00ol0003o?<<locc3?004occ3?003o`000?mgR7OoMhQg00KoMhQg
00?o0000og2?L?m`Sg003Om`Sg000ol0003oT6n@oi1_T00<oi1_T003o`000?oT6nCoi1_T00Soi1_T
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oD:mCoe2_D00Goe2_D00?o0000ohQgR?n8MhP00_n8
MhP00ol0003oLXebog:=LP06og:=LP03o`000?mWV6OoIiQW00SoIiQW0_l00003oe^TF`03o`000?mM
XUgoGJ9M00_oGJ9M00?o0000oeB[E?mDZe@01OmDZe@00ol0003o?<<locc3?005occ3?003o`000?mg
R7OoMhQg00GoMhQg00?o0000og2?L?m`Sg003Om`Sg000ol0003oT6n@oi1_T00;oi1_T003o`000?oT
6nCoi1_T00Woi1_T00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oD:mCoe2_D00Koe2_D00?o0000
ohQgR?n8MhP00on8MhP00ol0003oLXebog:=LP05og:=LP03o`000?mWV6OoIiQW00OoIiQW00?o0000
oe^TFomKY5/00omKY5/00ol0003oGJ9MoefRG@0:oefRG@03o`000?mDZeCoE:]D00KoE:]D00?o0000
occ3??ll`c`01_ll`c`00ol0003oMhQgogN8M`04ogN8M`03o`000?m`Sg3oL8m`00goL8m`3ol0000;
on@Ki003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oD:mCoe2_D00Koe2_D00?o0000ohQgR?n8MhP01On8MhP00ol0
003oLXebog:=LP04og:=LP03o`000?mWV6OoIiQW00GoIiQW0_l00006oe^TF`03o`000?mMXUgoGJ9M
00WoGJ9M0_l00008oeB[E003o`000?ll`cco?<<l00Ko?<<l1Ol000000omgR7Oo0000og2?L00?og2?
L003o`000?n<LhcoS7><00_oS7><00?o0000on@Ki?oT6n@02OoT6n@00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oD:mCoe2_D00Koe2_D00?o0000ohQgR?n8MhP01_n8MhP00ol0003o
LXebog:=LP04o`0000KoIiQW00?o0000oe^TFomKY5/01omKY5/00ol0003oGJ9MoefRG@05oefRG@?o
000000?oAkQ7o`000?mDZe@01omDZe@00ol0003o?<<locc3?005occ3?003o`000?mjQG[oNXEj00?o
NXEj0_l0000?og2?L0;o00003On<Lh`00ol0003oi1_Ton@Ki008on@Ki003o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000Woe2_D00?o0000ohQgR?n8MhP01on8MhP2o`0000CoTFjA00Co0000ofNHIomWV6Oo
IiQW0_l0000:oe^TF`03o`000?mMXUgoGJ9M00;oGJ9M0ol00005odNhA`03o`000?mDZeCoE:]D00Go
E:]D00?o0000occ3??ll`c`01?ll`c`00ol0003oNXEjogZ5NP06ogZ5NP03o`000?m`Sg3oL8m`00[o
L8m`0_l00002ogj1OP03o`000?n<LhcoS7><00[oS7><00?o0000on@Ki?oT6n@02?oT6n@00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000om@[e?oD:m@01_oD:m@00ol0003oR7N8ohQgR008ohQgR003o`00
0?nAKY7oTFjA00CoTFjA00?o0000ofNHIol000003?mKY5/00ol0003oGJ9Mo`000002o`0000WoAkQ7
00?o0000oeB[E?mDZe@01?mDZe@00ol0003o?<<locc3?003occ3?003o`000?mjQG[oNXEj00SoNXEj
1_l00004og2?L0;o00001OmnPGh00ol0003oS7><ohacS009ohacS003o`000?oT6nCoi1_T00Soi1_T
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oD:mCoe2_D00Goe2_D00?o0000ohQgR?n8MhP01on8
MhP00ol0003oTFjAoi5^T@06oi5^T@03o`000?mKY5_oFjAK00coFjAK00?o0000odNhAom7^4L02_m7
^4L00ol0003oE:]DoeB[E004oeB[E004o`000?ll`cco?<<locc3?0;o00002omjQGX00ol0003oO8=l
ogb3O003ogb3O0Co00002?mnPGh00ol0003oS7><ohacS008ohacS003o`000?oT6nCoi1_T00Ooi1_T
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000om@[e?oD:m@00ooD:m@00ol0003oR7N8ohQgR007ohQgR003o`000?nA
KY7oTFjA00OoTFjA00?o0000oe^TFomKY5/03?mKY5/00ol0003oAkQ7odNhA`0;odNhA`03o`000?mD
ZeCoE:]D00?oE:]D00Co0000occ3??ll`cco00003OmjQGX00ol0003oO8=logb3O006ogb3O003o`00
0?mnPGkoOX5n00OoOX5n00?o0000ohacS?n<Lh`01on<Lh`00ol0003oi1_Ton@Ki006on@Ki004o`00
0?ol0ocoo0?loo`3o0;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oD:mCoe2_D00;oe2_D00?o0000ohQgR?n8MhP0
1_n8MhP00ol0003oTFjAoi5^T@09oi5^T@03o`000?mKY5_oFjAK00WoFjAK0_l0000>odNhA`?o0000
0omDZe@00ol0003o?<<lo`00000=ogZ5NP03o`000?mlPgcoO8=l00OoO8=l00?o0000ogj1O_mnPGh0
2?mnPGh:o`0000Koi1_T0_l00006oo`3o003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoR7N800?o
0000oi5^TOnAKY402_nAKY400ol0003oFjAKoe^TF`06oe^TF`;o000000?oFZEJo`000?m7^4L02om7
^4L2o`0000?oNHIi1Ol0000>ogZ5NP03o`000?mlPgcoO8=l00OoO8=l00?o0000ogj1O_mnPGh02?mn
PGh00ol0003o[5>/ojaC[006ojaC[003o`000?oT6nCoi1_T00?oi1_T00?o0000oo`3o?ol0o`01ool
0o`2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003obSG:olXebP03olXebPCo00000_n8MhP00ol0003oTFjAoi5^T@0;
oi5^T@03o`000?mKY5_oFjAK00?oFjAK0ol00004oeZUFP03o`000?m7^4OoAkQ700OoAkQ70_l00008
ogV6N@03o`000?mjQG[oNXEj00goNXEj00?o0000ogb3O?mlPg`02?mlPg`00ol0003oOX5nogj1OP07
ogj1OP03o`000?n/Djco[5>/00Oo[5>/0ol000000ooT6nCo0000oo`3o00;oo`3o0;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o:=L[obSG:00OobSG:0_l0000?oi5^T@03o`000?mKY5_oFjAK00;o00002?mJYEX00ol0
003oAkQ7odNhA`05odNhA`03o`000?miQWWoNHIi00SoNHIi00?o0000ogZ5N_mjQGX03OmjQGX00ol0
003oO8=logb3O008ogb3O003o`000?mnPGkoOX5n00KoOX5n00?o0000ojaC[?n/Dj`02?n/Dj`01?l0
003oi1_Ton@Ki?l0000?oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003obSG:olXebP09olXe
bP03o`000?nAKY7oTFjA00koTFjA0_l0000;oeZUFP03o`000?m7^4OoAkQ700;oAkQ70_l0000;ogV6
N@03o`000?mjQG[oNXEj00goNXEj00?o0000ogb3O?mlPg`02?mlPg`00ol0003oOX5nogj1OP06ogj1
OP03o`000?n/Djco[5>/00Oo[5>/00Go0000on@Ki?oT6nCoi1_To`00000@oo`3o0;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003obSG:olXebP0:olXebP03o`000?nAKY7oTFjA00goTFjA0_l0000<oeZUFP04o`000?m7^4Oo0000
o`0000goNHIi00?o0000ogZ5N_mjQGX03?mjQGX00ol0003oO8=logb3O009ogb3O003o`000?mnPGko
OX5n00KoOX5n00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003oi1_Ton@Ki003on@Ki003o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003obSG:olXebP0:olXebP03o`000?nAKY7oTFjA00coTFjA00Co0000ocS7
>?lhacSo00003?mJYEX00ol0003oNHIiogV6N@0>ogV6N@03o`000?mjQG[oNXEj00SoNXEj1?l0000;
ogb3O003o`000?mnPGkoOX5n00KoOX5n00?o0000ojaC[?n/Dj`01On/Dj`00ol0003oi1_Ton@Ki004
on@Ki003o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003obSG:olXebP0;olXebP03o`000?nAKY7oTFjA
00_oTFjA00?o0000ocS7>?lhacP00_lhacP00ol0003oFZEJoeZUFP09oeZUFP03o`000?miQWWoNHIi
00koNHIi00Co0000ogZ5N_mjQG[oNXEj1ol00003ogj1OP03o`000?mlPgcoO8=l00WoO8=l00?o0000
ogj1O_mnPGh01_mnPGh00ol0003o[5>/ojaC[004ojaC[003o`000?oT6nCoi1_T00Koi1_T00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?o:=L[obSG:00cobSG:00?o0000oi5^TOnAKY402_nAKY400ol0
003o><LhocS7>003ocS7>003o`000?mJYE[oFZEJ00SoFZEJ00?o0000ogV6NOmiQWT03_miQWT4o`00
00_oOX5n00?o0000ogb3O?mlPg`02?mlPg`00ol0003oOX5nogj1OP05ogj1OP03o`000?n/Djco[5>/
00Go[5>/00?o0000on@Ki?oT6n@01_oT6n@00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000olXeb_o:
=LX03?o:=LX7o`0000GoTFjA00?o0000ocS7>?lhacP01OlhacP00ol0003oFZEJoeZUFP07oeZUFP03
o`000?miQWWoNHIi00koNHIi00?o0000ogj1O_mnPGh03OmnPGh00ol0003oO8=logb3O008ogb3O003
o`000?mnPGkoOX5n00CoOX5n00?o0000ojaC[?n/Dj`01?n/Dj`00ol0003oi1_Ton@Ki007on@Ki003
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003obSG:olXebP0=olXebP03o`000?nPGj3oX5nP00CoX5nP
1Ol00009ocS7>003o`000?mJYE[oFZEJ00KoFZEJ00?o0000ogV6NOmiQWT03_miQWT00ol0003oOX5n
ogj1OP0=ogj1OP03o`000?mlPgcoO8=l00SoO8=l00Co0000ogj1O_mnPGkoOX5n1Ol00004ojaC[003
o`000?oT6nCoi1_T00Woi1_T1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=olXebP03o`000?nPGj3oX5nP00WoX5nP
0_l00009ocS7>003o`000?mJYE[oFZEJ00KoFZEJ00?o0000ogV6NOmiQWT03?miQWT00ol0003oOX5n
ogj1OP0?ogj1OPKo00001?mlPg`4o`0000Go_D:m0_l000000on/Djco0000on@Ki00;on@Ki004o`00
0?ok1?_on`Ckoo/4n`Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oM8]gogB;MomdRg@?o00002_o:=LX00ol0003o
X5nPoj1OX009oj1OX003o`000?m;]4_o000000;o00001olhacP00ol0003oFZEJoeZUFP05oeZUFP03
o`000?miQWWoNHIi00SoNHIi1Ol0000Aogj1OP03o`000?n3O8?oPgb300?oPgb31?l0000;oke2_@03
o`000?oT6nCoi1_T00[oi1_T00?o0000oo/4nook1?/02Ook1?/3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000omdRgOoM8]d01OoM8]d2o`0000OobSG:
00?o0000oj1OX?nPGj002_nPGj000ol0003oBkA;od^dB`02od^dB`?o00001OlhacP00ol0003oFZEJ
oeZUFP04oeZUFP04o`000?miQWWoNHIiogV6N@Oo00001?mSW6<00ol0003oOX5nogj1OP0>ogj1OP03
o`000?n3O8?oPgb300OoPgb300?o0000oke2_Onm@[d02Onm@[d00ol0003oi1_Ton@Ki009on@Ki003
o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ogB;MomdRg@08omdRg@;o00001?o:=LX00ol0003oX5nP
oj1OX00;oj1OX003o`000?m;]4_oBkA;00GoBkA;0ol00003ocS7>004o`000?mJYE[oFZEJoeZUFPKo
00003?mSW6<00ol0003oOX5nogj1OP0=ogj1OP03o`000?n3O8?oPgb300OoPgb300?o0000oke2_Onm
@[d02_nm@[d00ol0003oi1_Ton@Ki008on@Ki003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omdRg@?o000000?obSG:o`000?nPGj00
3?nPGj000ol0003oBkA;od^dB`08od^dB`?o000000Co><Lho`000?l0003o00000_n8MhP00ol0003o
HiaSof>LH`0=of>LH`03o`000?mnPGkoOX5n00coOX5n00?o0000oh=lPon3O8<02?n3O8<00ol0003o
_D:moke2_@0;oke2_@03o`000?oT6nCoi1_T00Koi1_T00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
gB;M00?o0000oj1OX?nPGj003?nPGj000ol0003oBkA;od^dB`0;od^dB`03o`000?n8MhSoR7N800?o
R7N800?o0000of>LHomSW6<03?mSW6<00ol0003oBKI9o`00000=ogj1OP03o`000?n3O8?oPgb300So
Pgb300?o0000oke2_Onm@[d03?nm@[d3o`0000Goi1_T00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oM8]gogB;M00cogB;M00?o0000oj1OX?nPGj003?nPGj000ol0003oBkA;od^dB`0:od^dB`03o`00
0?n8MhSoR7N800GoR7N800?o0000of>LHomSW6<02_mSW6<01?l0003oBKI9odVfBOm9]TT2o`0000[o
OX5n00?o0000oh=lPon3O8<02On3O8<00ol0003o_D:moke2_@0<oke2_@03o`000?oY5^WojAKY00?o
000000?oi1_To`000?ok1?/03ook1?/00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oM8]gogB;M00_ogB;M00?o0000oj1OX?nPGj00
3?nPGj000ol0003oBkA;od^dB`09od^dB`03o`000?n8MhSoR7N800KoR7N800?o0000of>LHomSW6<0
2OmSW6<00ol0003oBKI9odVfB@02odVfB@03o`000?n5NXGo000000;o00001omnPGh00ol0003oPgb3
oh=lP`09oh=lP`03o`000?nm@[go_D:m00_o_D:m00?o0000onTFjOoY5^T01?oY5^T00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omdRgOoM8]d02ooM8]d00ol0003oX5nPoj1OX00;oj1OX003o`000?m;
]4_oBkA;00SoBkA;00?o0000ohQgR?n8MhP01on8MhP00ol0003oHiaSof>LH`08of>LH`03o`000?m9
]TWoBKI900?oBKI900?o0000ohEjQOn5NXD00_n5NXD2o`0000CoOX5n00?o0000oh=lPon3O8<02_n3
O8<00ol0003o_D:moke2_@0:oke2_@03o`000?oY5^WojAKY00GojAKY00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oM8]gogB;M00[ogB;M0ol0000;oj1OX0Ko00001?m;]4/00ol0003oR7N8ohQgR008
ohQgR003o`000?mSW6?oHiaS00OoHiaS00?o0000odVfBOm9]TT00om9]TT00ol0003oQGZ5ohEjQ@05
ohEjQ@?o000000?oOX5no`000?n3O8<02on3O8<00ol0003o_D:moke2_@09oke2_@03o`000?oY5^Wo
jAKY00OojAKY00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oM8]gogB;M00WogB;M00?o0000ojYE
Z_nZEJX01?l00006oj1OX003o`000?nEJYGoUFZE00CoUFZE1?l0000<ohQgR003o`000?mSW6?oHiaS
00GoHiaS00?o0000odVfBOm9]TT01?m9]TT00ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?n3O8?oPgb3
00_oPgb300?o0000oke2_Onm@[d02?nm@[d00ol0003ojAKYonTFj@08onTFj@Go00002_ok1?/00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oM8]gogB;M00OogB;M00?o0000ojYEZ_nZEJX01OnZEJX3o`0000;oX5nP00?o0000oiEZUOnE
JYD02?nEJYD00ol0003oR7N8ohQgR00:ohQgR003o`000?mSW6?oHiaS00CoHiaS00?o0000odVfBOm9
]TT01Om9]TT00ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?n3O8?oPgb300WoPgb31?l00008oke2_@03
o`000?oY5^WojAKY00WojAKY00?o0000oo/4nook1?/00_ok1?/7o`0000?on`Ck00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ogB;M
omdRg@05omdRg@03o`000?nZEJ[oZUFZ00WoZUFZ0_l0000<oiEZU@03o`000?n8MhSoR7N800WoR7N8
00?o0000of>LHomSW6<00omSW6<00ol0003oBKI9odVfB@05odVfB@03o`000?n5NXGoQGZ500[oQGZ5
00?o0000oh=lPon3O8<01?n3O8<4o`0000Co[U6^00?o0000oke2_Onm@[d01?nm@[d00ol0003ojAKY
onTFj@0:onTFj@03o`000?ok1?_on`Ck00Won`Ck0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oM8]gogB;M00?ogB;M00?o0000ojYEZ_nZEJX02onZ
EJX00ol0003oUFZEoiEZU@0:oiEZU@03o`000?n8MhSoR7N800WoR7N800?o0000of>LHomSW6<00_mS
W6<00ol0003oBKI9odVfB@06odVfB@03o`000?n5NXGoQGZ500[oQGZ500?o0000oh=lPon3O8<01?l0
0009ojiA[PKo00003?oY5^T00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omdRgOoM8]gogB;M0_l0
000=ojYEZP03o`000?nEJYGoUFZE00[oUFZE00?o0000ohQgR?n8MhP02On8MhP01Ol0003oHiaSof>L
HomSW6?o000000WoBKI900?o0000ohEjQOn5NXD02on5NXD2o`0000go[U6^00?o0000on8Mh_oR7N80
0_oR7N800ol0003ojAKYonTFj@0:onTFj@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ogB;Mo`00
0002on<Lh`;o00002onZEJX00ol0003oUFZEoiEZU@0;oiEZU@03o`000?n8MhSoR7N800WoR7N800?o
0000of>LHol000002Om9]TT00ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?n^DJko[U6^00co[U6^00?o
0000on8Mh_oR7N800ooR7N800ol0003ojAKYonTFj@09onTFj@03o`000?ok1?_on`Ck00gon`Ck00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003ohacSon<Lh`03on<Lh`;o00002_nZEJX00ol0003oUFZEoiEZU@0:oiEZU@03o`000?n8MhSo
R7N800SoR7N81Ol00008odVfB@03o`000?n5NXGoQGZ500coQGZ500?o0000ojiA[_n^DJh02on^DJh0
0ol0003ohQgRon8MhP05on8MhP03o`000?oY5^WojAKY00SojAKY00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooS7><2o`0000SoZUFZ00?o0000oiEZUOnEJYD02_nEJYD00ol0003oR7N8ohQgR007ohQg
R003o`000?mfRGKoMXUf00?oMXUf0ol00005odVfB@03o`000?n5NXGoQGZ500_oQGZ500?o0000ojiA
[_n^DJh03?n^DJh00ol0003ohQgRon8MhP06on8MhP03o`000?oY5^WojAKY00OojAKY00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ok1?_o000000WohacS00?o0000ojYEZ_nZEJX01OnZEJX2o`0000co
UFZE00?o0000ohQgR?n8MhP01On8MhP00ol0003oMXUfogJ9MP07ogJ9MP?o000000?oBKI9o`000?n5
NXD03On5NXD00ol0003o[U6^ojiA[P0<ojiA[P03o`000?oR7N;ohQgR00KohQgR00?o0000onTFjOoY
5^T01_oY5^T00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo/4n`03o`000?oS7>?ohacS00OohacS
0_l00004ojYEZP03o`000?nhAkSo^4Nh00;o00002_nEJYD00ol0003oR7N8ohQgR003ohQgR0;o0000
3OmfRGH2o`0000goQGZ50ol0000=ojiA[P03o`000?oR7N;ohQgR00OohQgR00?o0000onTFjOoY5^T0
1OoY5^T00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003on`Ckoo/4n`04oo/4n`03o`000?oS7>?ohacS00SohacS0_l0
00000onZEJ[o0000okQ7^004okQ7^003o`000?nEJYGoUFZE00OoUFZE00Co0000ohQgR?n8MhSoR7N8
0_l00002ohebS@03o`000?mfRGKoMXUf00coMXUf3Ol00003ohm`S`03o`000?n^DJko[U6^00[o[U6^
00?o0000on8Mh_oR7N802?oR7N801?l0003ojAKYonTFjOoY5^T4o`0000kon`Ck00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ok1?/00ol0003ohacS
on<Lh`09on<Lh`03o`000?nhAkSo^4Nh00Go^4Nh0_l00008oiEZU@03o`000?n8MhSo000000GoSG:=
00?o0000ogJ9M_mfRGH02omfRGH00ol0003oNHIiogV6N@09ogV6N@03o`000?n?L8ooSg2?00;oSg2?
0_l00009ojiA[P03o`000?oR7N;ohQgR00[ohQgR0ol00004oo/4n`03o`000?ok1?_on`Ck00[on`Ck
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo/4
n`0:oo/4n`03o`000?oS7>?ohacS00SohacS00?o0000okQ7^?nhAkP01onhAkP4o`0000?oUFZE0ol0
0007ohebS@03o`000?mfRGKoMXUf00[oMXUf00?o0000ogV6NOmiQWT02OmiQWT00ol0003oSg2?ohm`
S`04ohm`S`;o00001on^DJh00ol0003ohQgRon8MhP0:on8MhP03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003on`Ckoo/4n`0:oo/4n`03o`000?oS7>?ohacS00OohacS00?o0000okQ7^?nhAkP02?nhAkP0
1?l0003o^4NhokQ7^?nhAkP3o`0000;oYEZU00?o0000ohebSOn=LXd01_n=LXd00ol0003oMXUfogJ9
MP08ogJ9MP03o`000?miQWWoNHIi00[oNHIi00?o0000ohm`Son?L8l01_n?L8l00ol0003o[U6^ojiA
[P04ojiA[P03o`000?oR7N;ohQgR00WohQgR00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4
n`07oo/4n`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_o
n`Ck00_on`Ck00?o0000on<LhooS7><01OoS7><00ol0003o^4NhokQ7^008okQ7^003o`000?nhAkSo
^4Nh00Co^4Nh00Go0000ojEJYOnUFZGoYEZUo`000008ohebS@03o`000?mfRGKoMXUf00OoMXUf00?o
0000ogV6NOmiQWT02_miQWT00ol0003oSg2?ohm`S`07ohm`S`;o00001?n^DJh00ol0003ohQgRon8M
hP08on8MhP03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/01?ok1?/2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on<LhooS7><00ooS7><0
0ol0003o^4NhokQ7^008okQ7^003o`000?nhAkSo^4Nh00Co^4Nh00?o0000ojEJYOnUFZD00_nUFZD0
0ol0003oSG:=ohebS@07ohebS@03o`000?mfRGKoMXUf00KoMXUf00?o0000ogV6NOmiQWT02_miQWT0
0ol0003oSg2?ohm`S`09ohm`S`05o`000?n^DJko[U6^ojiA[_l000002OoR7N800ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ok1?_on`Ck00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo/4nook1?/03Ook1?/5o`0000_o^4Nh00?o0000okQ7^?nhAkP01?nhAkP00ol0003oYEZUojEJY@03
ojEJY@03o`000?n=LXgoSG:=00OoSG:=00?o0000ogJ9M_mfRGH01OmfRGH00ol0003oNHIiogV6N@0:
ogV6N@03o`000?n?L8ooSg2?00WoSg2?1?l00009on8MhP03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003on`Ckoo/4n`0<oo/4n`05o`000?oZ5N[ojQGZ
onXEj_l000002_nhAkP00ol0003o^4NhokQ7^005okQ7^003o`000?nUFZGoYEZU00?oYEZU00?o0000
ohebSOn=LXd02?n=LXd00ol0003oMXUfogJ9MP04ogJ9MP03o`000?miQWWoNHIi00WoNHIi00?o0000
ohm`Son?L8l02?n?L8l2o`0000?ohAkQ00?o0000on8Mh_oR7N801_oR7N800ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ok1?_on`Ck
00_on`Ck00?o0000onXEj_oZ5NX00ooZ5NX00ol0003o^4NhokQ7^006okQ7^003o`000?nhAkSo^4Nh
00Go^4Nh00?o0000ojEJYOnUFZD01?nUFZD00ol0003oSG:=ohebS@09ohebS@03o`000?mfRGKoMXUf
00;oMXUf00?o0000ogV6NOmiQWT02_miQWT00ol0003oSg2?ohm`S`06ohm`S`;o00001_oQ7^48o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo/4nook
1?/02_ok1?/00ol0003ojQGZonXEjP05onXEjP03o`000?nhAkSo^4Nh00Go^4Nh00?o0000okQ7^?nh
AkP01OnhAkP00ol0003oYEZUojEJY@05ojEJY@03o`000?n=LXgoSG:=00WoSG:=00Go0000ogJ9M_mf
RGKoMXUfo`00000<ogV6N@03o`000?n?L8ooSg2?00CoSg2?0_l00008on4Nh@03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oZ5N[ojQGZ00OojQGZ00?o0000okQ7^?nh
AkP00onhAkP00ol0003o^4NhokQ7^006okQ7^003o`000?nUFZGoYEZU00GoYEZU00?o0000ohebSOn=
LXd02_n=LXd00ol0003oMXUfo`000004o`0000WoNHIi00?o0000ohm`Son?L8l00_n?L8l2o`0000[o
hAkQ00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo/4nook1?/02?ok1?/00ol0003ojQGZonXEjP07onXEjP03o`00
0?nhAkSo^4Nh00;o^4Nh00?o0000okQ7^?nhAkP01_nhAkP00ol0003oYEZUojEJY@07ojEJY@;o0000
2on=LXd00ol0003o/Tfbok9=/P03ok9=/POo00000_miQWT00ol0003oSg2?ohm`S`02o`0000_ohAkQ
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000onXEj_oZ5NX02OoZ
5NX01Ol0003o^4NhokQ7^?nhAkSo000000So^4Nh00?o0000ojEJYOnUFZD01onUFZD00ol0003odbcC
o`000002o`0000SoSG:=00?o0000ok9=/_nbCK802_nbCK85o`0000gohAkQ00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ok1?_on`Ck00?on`Ck0ol0000<onXEjP03o`000?nhAkSo000000Wo^4Nh00?o
0000ojEJYOnUFZD01_nUFZD00ol0003odbcCom</d`03om</d`?o00001?n=LXd00ol0003o/Tfbok9=
/P0=ok9=/P03o`000?oQ7^7ohAkQ00gohAkQ00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ok1?_o
000000;o00000ool0o`2o`0000_ojQGZ00?o0000okQ7^?nhAkP01onhAkP00ol0003oYEZUojEJY@07
ojEJY@03o`000?oC;=?odbcC00KodbcC0ol000000on=LXgo0000ok9=/P0>ok9=/P03o`000?oQ7^7o
hAkQ00cohAkQ00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009onXE
jP03o`000?nhAkSo^4Nh00;o^4Nh1_l00008ojEJY@03o`000?oC;=?odbcC00[odbcC00?o0000ok9=
/_nbCK803onbCK800ol0003ohAkQon4Nh@0:on4Nh@;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007onXEjPGo00001_oW6>L00ol0003oYEZUojEJY@05ojEJY@03o`000?oC;=?odbcC00[o
dbcC00?o0000ok9=/_nbCK803onbCK800ol0003ohAkQon4Nh@07on4Nh@?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005onXEjP03o`000?oW6>OoiaSW00WoiaSW00?o0000ojEJYOnU
FZD00onUFZD00ol0003odbcCom</d`0;om</d`03o`000?nbCK;o/Tfb00oo/Tfb00?o0000on4NhOoQ
7^401OoQ7^42o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?ojQGZo`000?l00000
3OoW6>L00ol0003oYEZUojEJY@02ojEJY@03o`000?oC;=?odbcC00_odbcC5?l00004on4Nh@;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on`Cko`00000>onLHi`04o`000?nUFZGoYEZUo`0000kodbcC
00?o0000onXEj_oZ5NX04?oZ5NX00ol0003ohAkQo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ok1?_on`Ckoo/4nol000003_oW6>L00ol0003oYEZUo`00000>om</d`03o`00
0?oZ5N[ojQGZ017ojQGZ00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00_ok1?/00ol0003oiaSWonLHi`0=onLHi`03o`000?oC;=?odbcC00WodbcC1Ol0
000BonXEjP;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/0
0ol0003oiaSWonLHi`0<onLHi`03o`000?oC;=?odbcC00;odbcC1ol00004oo/4n`03o`000?oZ5N[o
jQGZ00oojQGZ00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oW6>OoiaSW00coiaSW1?l0000<oo/4n`03o`000?oZ5N[ojQGZ00cojQGZ0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ok1?_on`Ck00Oo
n`Ck00?o0000onLHiooW6>L03?oW6>L00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oZ5N[ojQGZ00_o
jQGZ00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003oiaSWonLHi`0:onLHi`03o`000?ok1?_on`Ck00kon`Ck00?o0000onXEj_oZ
5NX02OoZ5NX2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ok1?_on`Ck00[on`Ck00?o0000onLHiooW6>L02_oW6>L00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?oZ5N[ojQGZ00KojQGZ0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003on`Ck00gon`Ck3?l0
000Aoo/4n`?o00001_oZ5NX00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000ooZ5NX2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ok1?_o
n`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000onXEj_l000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Oon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo/4nook1?/00ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo/4
n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool02_l00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00co003o0_ooo`06o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0_ooo`0<o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00[o003o0_ooo`0<o`00o`;oool01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`002_l00?l2oooo00Go
003o3?ooo`02o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00[o003o0_ooo`05o`00o`coool0
00?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l0
0?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o
0oooo`04o`00o`;oool02_l00?l2oooo00Go003o00?oool0o`00ool00?l01?l00?l2oooo00Co003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00[o003o0_ooo`06o`00o`03oooo0?l00?oo003o00?o003o
0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol0
0?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool01ol00?l00oooo`3o003o
o`00o`02o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl0
0?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo000:o`00o`;oool01ol0
0?l2oooo00?o003o0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Y
o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04
o`00o`Coool000?o003ooooo0?l00?l00_ooo`0:o`00o`;oool02?l00?l01?ooo`3o003oo`00ool0
0?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05
o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02_l00?l2oooo00Wo003o00?oool0
o`00ool00?l00_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00
o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o003o0_ooo`0:o`00
o`04oooo0?l00?ooool0oooo00Co003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1W
o`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool02_l00?l2oooo
00[o003o00Coool0o`00ooooo`3oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb
</co003oo`00o`07o`00o`;oool02ol00?l3oooo00Go003o0_ooo`04o`00o`;oool01_l00?l00olb
</coool0oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool0
0?l05_l00?l5oooo00Go003o1?ooo`0<o`00o`;oool01_l00?l2oooo00;o003o0_ooo`05o`00o`Go
ool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo02;o003o
0_ooo`0<o`00o`;oool01ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(150) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.985 .015 .985 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.985 .015 .985 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.985 .015 .985 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.984 .016 .984 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.899 .101 .899 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.983 .017 .983 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.895 .105 .895 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.913 .087 .913 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.87 .13 .87 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.98 .02 .98 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.819 .181 .819 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.985 .015 .985 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.74 .26 .74 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.724 .276 .724 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.981 .019 .981 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.986 .014 .986 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.649 .351 .649 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.78 .22 .78 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.979 .021 .979 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.981 .019 .981 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.983 .017 .983 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.883 .117 .883 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.487 .513 .487 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.638 .362 .638 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.519 .481 .519 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.507 .493 .507 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.592 .408 .592 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.835 .165 .835 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.87 .13 .87 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.985 .015 .985 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.529 .471 .529 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.762 .238 .762 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.414 .586 .414 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.839 .161 .839 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.796 .204 .796 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.985 .015 .985 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.701 .299 .701 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.733 .267 .733 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.641 .359 .641 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.839 .161 .839 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.545 .455 .545 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.987 .013 .987 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.891 .109 .891 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.562 .438 .562 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.448 .552 .448 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.423 .577 .423 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.895 .105 .895 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.92 .08 .92 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.68 .32 .68 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.985 .015 .985 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.533 .467 .533 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.456 .544 .456 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.556 .444 .556 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.584 .416 .584 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.33 .67 .33 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.509 .491 .509 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.627 .373 .627 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.985 .015 .985 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.643 .357 .643 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.561 .439 .561 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.888 .112 .888 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.132 .868 .132 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.733 .267 .733 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.712 .288 .712 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.555 .445 .555 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.263 .737 .263 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.314 .686 .314 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.135 .865 .135 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.194 .806 .194 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.484 .516 .484 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.286 .714 .286 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.389 .611 .389 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.734 .266 .734 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.432 .568 .432 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.462 .538 .462 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.587 .413 .587 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.909 .091 .909 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.984 .016 .984 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.249 .751 .249 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.335 .665 .335 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.287 .713 .287 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.984 .016 .984 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.63 .37 .63 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.413 .587 .413 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.212 .788 .212 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.222 .778 .222 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.495 .505 .495 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.328 .672 .328 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.889 .111 .889 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.42 .58 .42 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.145 .855 .145 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.657 .343 .657 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.338 .662 .338 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.277 .723 .277 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.519 .481 .519 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.84 .16 .84 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.481 .519 .481 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.151 .849 .151 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.277 .723 .277 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.503 .497 .503 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.327 .673 .327 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.337 .663 .337 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.835 .165 .835 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.303 .697 .303 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.242 .758 .242 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.196 .804 .196 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.983 .017 .983 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.206 .794 .206 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.379 .621 .379 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.25 .75 .25 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.558 .442 .558 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.448 .552 .448 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.983 .017 .983 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.492 .508 .492 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.394 .606 .394 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.42 .58 .42 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.47 .53 .47 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.326 .674 .326 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.276 .724 .276 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.366 .634 .366 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.451 .549 .451 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.984 .016 .984 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.716 .284 .716 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.434 .566 .434 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.552 .448 .552 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.265 .735 .265 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.884 .116 .884 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.111 .889 .111 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.3 .7 .3 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.292 .708 .292 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.473 .527 .473 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.637 .363 .637 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.207 .793 .207 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.984 .016 .984 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.366 .634 .366 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.709 .291 .709 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.921 .079 .921 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.508 .492 .508 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.466 .534 .466 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.416 .584 .416 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.839 .161 .839 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.214 .786 .214 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.349 .651 .349 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.453 .547 .453 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.687 .313 .687 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.207 .793 .207 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.344 .656 .344 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.442 .558 .442 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.472 .528 .472 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.984 .016 .984 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.269 .731 .269 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.984 .016 .984 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.883 .117 .883 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.517 .483 .517 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.457 .543 .457 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.318 .682 .318 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.573 .427 .573 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.366 .634 .366 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.885 .115 .885 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.501 .499 .501 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.531 .469 .531 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.533 .467 .533 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.507 .493 .507 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.754 .246 .754 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.474 .526 .474 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.319 .681 .319 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.191 .809 .191 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.217 .783 .217 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.427 .573 .427 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.69 .31 .69 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.984 .016 .984 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.886 .114 .886 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.383 .617 .383 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.221 .779 .221 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.479 .521 .479 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.745 .255 .745 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.498 .502 .498 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.984 .016 .984 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.413 .587 .413 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.747 .253 .747 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.89 .11 .89 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.984 .016 .984 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.339 .661 .339 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.402 .598 .402 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.881 .119 .881 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.432 .568 .432 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.475 .525 .475 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.727 .273 .727 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.395 .605 .395 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.581 .419 .581 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.774 .226 .774 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.582 .418 .582 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.569 .431 .569 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.689 .311 .689 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.432 .568 .432 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.915 .085 .915 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.686 .314 .686 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.547 .453 .547 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.508 .492 .508 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.984 .016 .984 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.714 .286 .714 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.429 .571 .429 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.983 .017 .983 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.897 .103 .897 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.77 .23 .77 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.897 .103 .897 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.441 .559 .441 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.877 .123 .877 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.679 .321 .679 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.57 .43 .57 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.985 .015 .985 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.571 .429 .571 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.515 .485 .515 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.985 .015 .985 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.753 .247 .753 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.98 .02 .98 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.986 .014 .986 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.653 .347 .653 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.982 .018 .982 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.512 .488 .512 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.983 .017 .983 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.48 .52 .48 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.739 .261 .739 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.563 .437 .563 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.864 .136 .864 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.876 .124 .876 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.687 .313 .687 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.654 .346 .654 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.682 .318 .682 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.808 .192 .808 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.867 .133 .867 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.79 .21 .79 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.801 .199 .801 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.981 .019 .981 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.656 .344 .656 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.882 .118 .882 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.983 .017 .983 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.913 .087 .913 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.902 .098 .902 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.659 .341 .659 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.898 .102 .898 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.883 .117 .883 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.681 .319 .681 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.983 .017 .983 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.981 .019 .981 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.986 .014 .986 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.88 .12 .88 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.984 .016 .984 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.984 .016 .984 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.983 .017 .983 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.984 .016 .984 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.983 .017 .983 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.984 .016 .984 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ok1?_on`Ckoo/4nol000004Ook
1?/01?l0003ohQgRon8Mh_l0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003on`Ckoo/4n`02oo/4n`03o`000?ok
1?_on`Ck00gon`Ck00?o0000on8Mh_oR7N800_oR7N800ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oR7N;ohQgR00?ohQgR00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck
00[on`Ck00?o0000on8Mh_oR7N801OoR7N800ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ohQgRon8MhP06on8MhP03
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003on`Ckoo/4n`07oo/4n`03o`000?ok1?_on`Ck00Oon`Ck
00?o0000on8Mh_oR7N802?oR7N800ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oS7>?o0000013on`Ck00?o0000oo/4nook1?/02?ok
1?/9o`0000cohQgR00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003on<Lh`03o`000?ok
1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003ohQgRon8MhP05on8MhP03o`000?oR
7N;ohQgR00_ohQgR0ol00003on4Nh@03o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
on<LhooS7><00ooS7><00ol0003on`Ckoo/4n`0;oo/4n`;o00002ook1?/00ol0003ohQgRon8MhP06
on8MhP03o`000?oR7N;ohQgR00[ohQgR00?o0000on4NhOoQ7^401?oQ7^400ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oP7n3oh1oPon0Oh0;o00002_ok1?/2o`000003on0Oh?l0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo/4nook1?/02ook1?/00ol0003ohacSon<Lh`05on<Lh`03o`000?ok1?_o
n`Ck00Won`Ck00?o0000on8Mh_l000002ook1?/00ol0003ohQgRon8MhP06on8MhP03o`000?oR7N;o
hQgR00WohQgR00?o0000on4NhOoQ7^401_oQ7^400ol0003on`Ckoo/4n`08oo/4n`03o`000?oP7n3o
h1oP00Coh1oP0_l00005oo/4n`?o00001?oP7n000ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00Son`Ck0_l00008on<Lh`03o`000?ok1?_on`Ck00Oon`Ck0_l00003on8M
hP03o`000?ok1?_on`Ck00Oon`Ck00?o0000on8Mh_oR7N801ooR7N800ol0003ohQgRon8MhP09on8M
hP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo/4nook1?/01Ook1?/2o`0000Woh1oP0_l000000ook
1?_o0000o`000007on0Oh003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Son`Ck00?o0000on<LhooS
7><02?oS7><00ol0003on`Ckoo/4n`06oo/4n`03o`000?oR7N;ohQgR00?ohQgR00?o0000oo/4nook
1?/01ook1?/00ol0003ohQgRon8MhP08on8MhP03o`000?oR7N;ohQgR00OohQgR00?o0000on4NhOoQ
7^402OoQ7^400ol0003on`Ckoo/4n`03oo/4n`03o`000?oP7n3oh1oP00_oh1oP00?o0000on0Oh?oP
7n001ooP7n000ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003ohacSo`000005oo/4n`;o00002ooS7><2o`0000Kon`Ck
00?o0000on8Mh_oR7N801OoR7N800ol0003on`Ckoo/4n`06oo/4n`03o`000?oR7N;ohQgR00SohQgR
00?o0000on8Mh_oR7N801_oR7N800ol0003ohAkQon4Nh@0;on4Nh@05o`000?ok1?_on`Ckoo/4nol0
00003_oP7n000ol0003oh1oPon0Oh008on0Oh003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oS7>?ohacSon<Lhol0
00000ook1?/00ol0003ohacSon<Lh`0:on<Lh`04o`000?oG:=OoebSGo`0000?on`Ck0_l00008on8M
hP03o`000?ok1?_on`Ck00Kon`Ck00?o0000on8Mh_oR7N802OoR7N800ol0003ohQgRon8MhP05on8M
hP03o`000?oQ7^7ohAkQ00cohAkQ00?o0000oo/4nol000003ooP7n000ol0003oh1oPon0Oh008on0O
h003o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohacSon<Lh`03on<Lh`03o`000?ok1?_o000000_o
hacS0_l00004omLXe`03o`000?ok1?_o000000_ohQgR00?o0000oo/4nook1?/01Ook1?/00ol0003o
hQgRon8MhP09on8MhP03o`000?oR7N;ohQgR00CohQgR00?o0000on4NhOoQ7^403_oQ7^400ol0003o
h1oPon0Oh00>on0Oh003o`000?oP7n3oh1oP00Woh1oP00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000on<LhooS7><0
1?oS7><00ol0003ohacSon<Lh`09on<Lh`03o`000?oG:=OoebSG00GoebSG00?o0000on8Mh_oR7N80
2_oR7N800ol0003on`Ckoo/4n`05oo/4n`03o`000?oR7N;ohQgR00[ohQgR00?o0000on8Mh_oR7N80
0ooR7N800ol0003ohAkQon4Nh@0>on4Nh@03o`000?oP7n3oh1oP00goh1oP00?o0000on0Oh?oP7n00
2_oP7n000ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ohacSon<L
h`05on<Lh`03o`000?oS7>?ohacS00OohacS0_l00008omLXe`03o`000?oR7N;ohQgR00_ohQgR00?o
0000oo/4nook1?/01?ok1?/00ol0003ohQgRon8MhP0:on8MhP04o`000?oR7N;ohQgRon8MhP?o0000
3ooQ7^400ol0003oh1oPon0Oh00>on0Oh003o`000?oP7n3oh1oP00[oh1oP00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oS7>?ohacS00OohacS00?o0000on<LhooS7><01?oS7><2o`0000_oebSG1?l0
0009on8MhP03o`000?ok1?_on`Ck00?on`Ck00?o0000on8Mh_oR7N802ooR7N801?l0003ohQgRo`00
0?l00003oki1_P;o00003?oQ7^42o`00013oh1oP00?o0000on0Oh?oP7n002ooP7n000ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ok1?_on`Ckoo/4n`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003ohacS
on<Lh`07on<Lh`03o`000?oS7>?ohacS00?ohacS00?o0000omLXeooG:=L02ooG:=L01?l0003o]dRg
okM8]ongB;L5o`0000GohQgR00?o0000oo/4nook1?/00_ok1?/00ol0003ohQgRon8MhP0<on8MhP03
o`000?nn@Kko_T6n00Go_T6n0_l00008on4Nh@;o00000_n_D:l00ol0003oh1oPon0Oh00=on0Oh003
o`000?oP7n3oh1oP00_oh1oP00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`05oo/4n`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003ohacSon<Lh`09on<Lh`03o`000?oS7>?ohacS00;o0000
3OoG:=L00ol0003o]dRgokM8]`07okM8]`Ko00000_ok1?/4o`0000gohQgR00?o0000oki1__nn@Kh0
1onn@Kh2o`0000GohAkQ00?o0000ojm@[on_D:l00on_D:l00ol0003oh1oPon0Oh00<on0Oh003o`00
0?oP7n3oh1oP00coh1oP00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oS7>?ohacS00WohacS00?o
0000on<Lhol000003ooG:=L00ol0003o]dRgokM8]`0<okM8]`?o00001?oF:MH3o`0000WohQgR00?o
0000oki1__nn@Kh02_nn@Kh2o`000003on4NhOl0003o000000Oo[e2_00?o0000on0Oh?oP7n002ooP
7n000ol0003oh1oPon0Oh00<on0Oh003o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo/4n`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000
omLXeooG:=L03_oG:=L00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKoeRWF00KoeRWF0ol00005
on8MhP03o`000?nn@Kko_T6n00go_T6n00?o0000ojm@[on_D:l02?n_D:l00ol0003oh1oPon0Oh009
on0Oh003o`000?oP7n3oh1oP00goh1oP00Co0000oo/4nook1?_on`Ck1Ol00003onHIiP03o`000?ok
1?_on`Ck00_on`Ck00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
on<LhooS7><02ooS7><2o`0000ooebSG00?o0000okM8]ongB;L03OngB;L00ol0003oeRWFomHYeP0:
omHYeP?o000000?ohQgRo`000?nn@Kh03onn@Kh00ol0003o[e2_ojm@[`09ojm@[`03o`000?oP7n3o
h1oP00Soh1oP00?o0000on0Oh?oP7n003_oP7n03o`0000SoiQWV00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oS7>?ohacS00SohacS0ol000000onf
BKKo0000omLXe`0>omLXe`03o`000?ngB;Oo]dRg00go]dRg00?o0000omHYe_oF:MH03OoF:MH00ol0
003o_T6noki1_P0?oki1_P03o`000?n_D:oo[e2_00[o[e2_2ol0000;on0Oh0Go00003?oV6NH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oi1_To`000?ol0oco0000
00SohacS0ol00005okI9]P03o`000?oG:=OoebSG00coebSG00?o0000okM8]ongB;L03OngB;L00ol0
003oeRWFomHYeP0=omHYeP;o00004?nn@Kh00ol0003o[e2_ojm@[`0:ojm@[`03o`000?n]DZgo[E:]
00Oo[E:]00?o0000on0Oh?oP7n000_oP7n07o`0000Co[e2_00?o0000onHIi_oV6NH02_oV6NH00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003oi1_Ton@Ki?oT6n@2o`00
00GohacS0ol00009okI9]P;o00002ooG:=L00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKoeRWF
00goeRWF00Co0000ol4n`Oo1?/7o00003onn@Kh00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo
[E:]00Wo[E:]1?l0000;ojm@[`03o`000?oV6NKoiQWV00[oiQWV00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000on@Ki?oT6n@01?oT6n@00ol0003ohacSo`000002o`00
00co]TVf00Co0000oj5NXOl0003o00002OoG:=L00ol0003o]dRgokM8]`0=okM8]`03o`000?oF:MKo
eRWF00goeRWF00Go0000ol4n`Oo1?/7o`Ck1o`00000=oki1_P03o`000?n_D:oo[e2_00[o[e2_00?o
0000ojeB[On]DZd02On]DZd00ol0003o[e2_ojm@[`0<ojm@[`03o`000?oV6NKoiQWV00[oiQWV00?o
0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000on@Ki?oT6n@01_oT6n@0
0ol0003o]TVfokI9]P0<okI9]P03o`000?nQGZ7oXEjQ00;oXEjQ0_l00007omLXe`03o`000?ngB;Oo
]dRg00co]dRg00?o0000omHYe_oF:MH03OoF:MH00ol0003o`Ck1ol4n`@03ol4n`@03o`000?nn@Kko
_T6n00[o_T6n00?o0000ojm@[on_D:l02_n_D:l00ol0003o[E:]ojeB[@09ojeB[@03o`000?n_D:oo
[e2_00co[e2_00?o0000onHIi_oV6NH02ooV6NH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oi1_Ton@Ki006on@Ki003o`000?nfBKKo]TVf00_o]TVf00?o0000oj5N
XOnQGZ401OnQGZ400ol0003oebSGomLXe`03omLXe`03o`000?ngB;Oo]dRg00go]dRg00?o0000omHY
e_oF:MH03OoF:MH00ol0003o`Ck1ol4n`@04ol4n`@03o`000?nn@Kko_T6n00Wo_T6n00?o0000ojm@
[on_D:l02On_D:l00ol0003o[E:]ojeB[@0:ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHI
i_oV6NH02ooV6NH00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
i1_Ton@Ki007on@Ki003o`000?nfBKKo]TVf00_o]TVf00?o0000oj5NXOnQGZ401_nQGZ42o`0000?o
ebSG00?o0000okM8]ongB;L03OngB;L00ol0003oeRWFomHYeP0<omHYeP03o`000?o1?/7o`Ck100Ko
`Ck100?o0000oki1__nn@Kh02?nn@Kh00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo[E:]00[o
[E:]00?o0000ojm@[on_D:l03?n_D:l00ol0003oiQWVonHIiP0;onHIiP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000on@Ki?oT6n@02?oT6n@00ol0003o]TVfokI9]P0:okI9]P03o`00
0?nQGZ7oXEjQ00WoXEjQ0_l000000ooG:=Oo0000okM8]`0<okM8]`?o00003_oF:MH00ol0003o`Ck1
ol4n`@07ol4n`@03o`000?nn@Kko_T6n00Oo_T6n00?o0000ojm@[on_D:l02On_D:l00ol0003o[E:]
ojeB[@0;ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHIi_oV6NH02_oV6NH00ol0003on`Ck
oo/4n`08oo/4n`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000on@Ki?oT6n@02_oT6n@00ol0003o]TVfokI9
]P09okI9]P03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000okM8]ongB;L02_ngB;L2o`0000?oXebS00?o
0000omHYe_oF:MH02_oF:MH00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nn@Kko_T6n00Ko_T6n00?o
0000ojm@[on_D:l02?n_D:l00ol0003o[E:]ojeB[@0<ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o
0000onHIi_oV6NH02_oV6NH00ol0003on`Ckoo/4n`04oo/4n`Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000okI9]_nfBKH02?nfBKH0
0ol0003oXEjQoj5NX@0<oj5NX@03o`000?ngB;Oo]dRg00So]dRg0_l00006oj=LX`;o00002_oF:MH0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?nn@Kko_T6n00Go_T6n00?o0000ojm@[on_D:l02?n_D:l0
0ol0003o[E:]ojeB[@0<ojeB[@03o`000?n_D:oo[e2_00co[e2_00?o0000onHIi_oV6NH02ooV6NH0
0ol0003on`Cko`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
on@Ki003o`000?nfBKKo]TVf00Oo]TVf00?o0000oj5NXOnQGZ403_nQGZ400ol0003o]dRgokM8]`04
okM8]`?o00002_nSG:<00ol0003oeRWFomHYeP07omHYeP03o`000?o1?/7o`Ck100_o`Ck100?o0000
oki1__nn@Kh00onn@Kh00ol0003o[e2_ojm@[`09ojm@[`03o`000?n]DZgo[E:]00co[E:]00?o0000
ojm@[on_D:l03?n_D:l00ol0003oiQWVonHIiP0;onHIiP;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oi1_Ton@Ki00<on@Ki003o`000?nfBKKo]TVf00Oo]TVf00?o0000oj5NXOnQGZ403onQGZ401?l0
003o]dRgokM8]ongB;L2o`0000koXebS0_l00006omHYeP03o`000?o1?/7o`Ck100go`Ck100?o0000
oki1__nn@Kh00_nn@Kh00ol0003o[e2_ojm@[`08ojm@[`03o`000?n]DZgo[E:]00co[E:]0ol0000=
ojm@[`03o`000?oV6NKoiQWV00_oiQWV00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooi1_T00?o0000okI9]_nfBKH01_nfBKH00ol0003oXEjQoj5NX@0@oj5NX@Co00004_nSG:<00ol0
003oeRWFomHYeP03omHYeP03o`000?o1?/7o`Ck100ko`Ck100Go0000oki1__nn@Kko_T6no`000005
ojm@[`Oo00003?n]DZd01Ol0003oPgb3oh=lPon3O8?o000000co[e2_00?o0000onHIi_oV6NH02?oV
6NH3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooi1_T00?o0000okI9]_nfBKH01_nfBKH00ol0003oXEjQoj5NX@0=
oj5NX@?o000000CoOX5no`000?l0003o00004onSG:<2o`0000;oeRWF00?o0000ol4n`Oo1?/404?o1
?/400ol0003o_T6no`000006o`0000Oo]TVf00?o0000ojeB[On]DZd02?n]DZd00ol0003oPgb3oh=l
P`03oh=lP`;o00002?n_D:l3o`0000KoiQWV1?l00002on8MhP03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003ohQgRo`000?ncC;<3o`0000goi1_T00?o0000okI9]_nfBKH01?nfBKH00ol0003oXEjQoj5N
X@0;oj5NX@?o00000omnPGh01Ol0003oP7n0o`000?mmPWgo000001CoXebS00?o0000omHYe_l00000
4oo1?/400ol0003o]TVfokI9]P0=okI9]P03o`000?n]DZgo[E:]00Go[E:]0_l00008oh=lP`03o`00
0?n_D:oo[e2_00Go00000on^DJh00ol0003oiQWVonHIiP03o`0000OohQgR00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oR7N;ohQgRo`0000Co/dbc0ol0000:on@Ki003o`000?nfBKKo]TVf00?o]TVf
00?o0000oj5NXOnQGZ402OnQGZ43o`0000GoOX5n00Co0000oh1oP?n0Oh3o00000_mmPWd00ol0003o
XebSoj=LX`0Boj=LX`03o`000?o1?/7o`Ck101;o`Ck100?o0000okI9]_nfBKH03_nfBKH00ol0003o
[E:]ojeB[@03ojeB[@03o`000?n3O8?oPgb300WoPgb30_l00009ojiA[P;o00002_oR7N800ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000on8Mh_oR7N;ohQgRo`000007ok=</`;o00001ooT6n@5o`0000;o
]TVf00?o0000oj5NXOnQGZ401_nQGZ43o`0000SoOX5n00Co0000oh1oP?n0Oh3o00000ommPWd00ol0
003oXebSoj=LX`0Aoj=LX`03o`000?o1?/7o`Ck1017o`Ck100?o0000okI9]_nfBKH04?nfBKH01Ol0
003o[E:]ojeB[On]DZgo000000coPgb300?o0000ojiA[_n^DJh02?n^DJh00ol0003ohQgRon8MhP0:
on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CohQgR00?o0000ok=</oncC;<01oncC;<3o`00
0004on@Ki?l0003o0000o`0000GoY5^T0_l00006oj5NX@?o00002_mnPGh01Ol0003oP7n0oh1oP?n0
Oh3o000000CoOH9m00?o0000oj=LXonSG:<04?nSG:<00ol0003o`Ck1ol4n`@0Aol4n`@03o`000?nf
BKKo]TVf017o]TVf00?o0000ojeB[Ol000003On3O8<00ol0003o[U6^ojiA[P08ojiA[P03o`000?oR
7N;ohQgR00[ohQgR00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oR7N;ohQgR00CohQgR00?o0000
ok=</oncC;<02_ncC;<00ol0003oY5^TojAKY008ojAKY003o`000?nQGZ7oXEjQ00?o00003OmnPGh0
1Ol0003oP7n0oh1oP?n0Oh3o000000GoOH9m00?o0000oj=LXonSG:<03onSG:<00ol0003o`Ck1ol4n
`@0Aol4n`@03o`000?nfBKKo]TVf01;o]TVf00?o0000oh=lPon3O8<03?n3O8<00ol0003o[U6^ojiA
[P08ojiA[P03o`000?oR7N;ohQgR00_ohQgR00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000on8Mh_oR7N801OoR7N80
0ol0003o/dbcok=</`0:ok=</`03o`000?nTFjCoY5^T00WoY5^T0_l0000?ogj1OP03o`000?n0Oh3o
P7n000;oP7n000?o0000ogf2OOmmPWd01?mmPWd00ol0003oXebSoj=LX`0=oj=LX`?o00004Oo1?/40
0ol0003o]TVfokI9]P0CokI9]P03o`000?n3O8?oPgb300_oPgb300?o0000ojiA[_n^DJh02On^DJh0
0ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo`3o0;o00002?oR7N80
0ol0003o/dbcok=</`0:ok=</`03o`000?nTFjCoY5^T00WoY5^T00?o0000ogj1O_mnPGh03OmnPGh0
0ol0003oP7n0oh1oP003oh1oP003o`000?mmPWgoOH9m00GoOH9m00?o0000oj=LXonSG:<02_nSG:<2
o`0000?o[e2_00?o0000ol4n`Oo1?/403_o1?/400ol0003o]TVfokI9]P0CokI9]P03o`000?n3O8?o
Pgb300_oPgb300?o0000ojiA[_n^DJh02On^DJh00ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Goo0?l00?o0000on8Mh_oR7N801ooR7N82o`0000_o/dbc00?o0000ojAK
Y?nTFj@02onTFj@00ol0003oOX5nogj1OP0<ogj1OP03o`000?n0Oh3oP7n000?oP7n000?o0000ogf2
OOmmPWd01_mmPWd00ol0003oXebSoj=LX`07oj=LX`;o00001_n_D:l2o`0000ko`Ck100?o0000okI9
]_nfBKH04onfBKH00ol0003oPgb3oh=lP`0;oh=lP`03o`000?n^DJko[U6^00Wo[U6^00?o0000on8M
h_oR7N803?oR7N800ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo`3o?ol0ocoo0?lo`000009on8M
hP03o`000?nSG:?o000000_o/dbc00?o0000ojAKY?nTFj@02onTFj@00ol0003oOX5nogj1OP0;ogj1
OP03o`000?n0Oh3oP7n000CoP7n000?o0000ogf2OOmmPWd01ommPWd00ol0003oXebSoj=LX`05oj=L
X`03o`000?n_D:oo[e2_00So[e2_00?o0000ol4n`Oo1?/402_o1?/400ol0003o]TVfokI9]P0DokI9
]P03o`000?n3O8?oPgb300_oPgb300?o0000ojiA[_n^DJh02On^DJh00ol0003ohQgRon8MhP0<on8M
hP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003oo0?lo`000009on8MhP04o`000?nSG:?oXebSo`00
00_o/dbc00?o0000ojAKY?nTFj@02onTFj@00ol0003oOX5nogj1OP0;ogj1OP03o`000?n0Oh3oP7n0
00CoP7n000?o0000ogf2OOmmPWd02?mmPWd00ol0003oXebSoj=LX`02oj=LX`;o00003?n_D:l2o`00
00[o`Ck100?o0000okI9]_nfBKH05?nfBKH00ol0003oPgb3oh=lP`0;oh=lP`03o`000?n^DJko[U6^
00Wo[U6^00?o0000on8Mh_oR7N803OoR7N800ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003ohQgRon8MhP07on8MhP03
o`000?nSG:?oXebS00;oXebS00?o0000ok=</oncC;<02?ncC;<00ol0003oY5^TojAKY00<ojAKY003
o`000?mnPGkoOX5n00WoOX5n00?o0000oh1oP?n0Oh001On0Oh000ol0003oOH9mogf2O@09ogf2O@04
o`000?nSG:?o0000o`00013o[e2_0_l00008ol4n`@03o`000?nfBKKo]TVf01Co]TVf0ol0000;oh=l
P`03o`000?n^DJko[U6^00Wo[U6^00?o0000on8Mh_oR7N803OoR7N801?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003ohQgRon8MhP06on8MhP03o`000?nSG:?oXebS00?oXebS00?o0000ok=<
/oncC;<02?ncC;<00ol0003oY5^TojAKY00;ojAKY0;o00002_mnPGh00ol0003oP7n0oh1oP006oh1o
P003o`000?mmPWgoOH9m00[oOH9m00?o0000ojm@[on_D:l04_n_D:l00ol0003o`Ck1ol4n`@04ol4n
`@03o`000?nfBKKo]TVf01Go]TVf00?o0000ojMHYonWF:L01Ol00005oh=lP`03o`000?n^DJko[U6^
00[o[U6^00?o0000on8Mh_oR7N803_oR7N83o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003ohQgRon8MhP04on8MhP03
o`000?nSG:?oXebS00CoXebS00?o0000ok=</oncC;<01oncC;<00ol0003oY5^TojAKY00;ojAKY004
o`000?n>LHkoSW6>o`0000WoOX5n00?o0000oh1oP?n0Oh001_n0Oh000ol0003oOH9mogf2O@0:ogf2
O@03o`000?n_D:oo[e2_01?o[e2_0_l00003ol4n`@Co00005?nfBKH00ol0003oYeRWojMHY`06ojMH
Y`Co000000?oPgb3o`000?n^DJh02on^DJh00ol0003ohQgRon8MhP0>on8MhP03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003ohQgRon8MhP03on8MhP03o`000?nSG:?oXebS00GoXebS00?o0000ok=</onc
C;<01oncC;<00ol0003oY5^TojAKY009ojAKY0;o00001?n>LHh00ol0003oOX5nogj1OP05ogj1OP03
o`000?n0Oh3oP7n000OoP7n000?o0000ogf2OOmmPWd02_mmPWd00ol0003o[e2_ojm@[`0Eojm@[`03
o`000?o1?/7o000000Co^TFj0ol0000@okI9]P03o`000?nWF:OoYeRW00_oYeRW0_l0000<ojiA[P03
o`000?oR7N;ohQgR00cohQgR0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on8Mh_oR7N800_oR7N800ol0003oXebS
oj=LX`06oj=LX`03o`000?ncC;?o/dbc00Oo/dbc00?o0000ojAKY?nTFj@02?nTFj@00ol0003oSW6>
ohiaSP05ohiaSP03o`000?mnPGkoOX5n00CoOX5n00?o0000oh1oP?n0Oh001on0Oh000ol0003oOH9m
ogf2O@0:ogf2O@03o`000?n_D:oo[e2_01Ko[e2_00?o0000okY5^_njAKX01_njAKX3o`0000co]TVf
00?o0000ojMHYonWF:L03OnWF:L00ol0003o[U6^ojiA[P09ojiA[PGo00002OoR7N82o`000003on4N
hOl0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003on8Mh_l0003oXebS00WoXebS00?o0000ok=</oncC;<01_nc
C;<00ol0003oY5^TojAKY007ojAKY003o`000?n>LHkoSW6>00OoSW6>00?o0000ogj1O_mnPGh00_mn
PGh00ol0003oP7n0oh1oP008oh1oP003o`000?mmPWgoOH9m00WoOH9m00?o0000ojm@[on_D:l05on_
D:l00ol0003o^TFjokY5^P09okY5^P?o00002OnfBKH00ol0003oYeRWojMHY`0>ojMHY`Ko00001?n^
DJh00ol0003oZ5NXojQGZ003ojQGZ0Go00000_oR7N82o`0000CohAkQ00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?oA;]7odBkAom4^dOl000002onSG:<00ol0003o/dbcok=</`06ok=</`03o`000?nT
FjCoY5^T00GoY5^T0_l0000;ohiaSP04o`000?mnPGkoOX5no`0000_oP7n000?o0000ogf2OOmmPWd0
2OmmPWd00ol0003o[e2_ojm@[`0Fojm@[`03o`000?njAK[o^TFj00go^TFj0ol00005okI9]P03o`00
0?nWF:OoYeRW00ooYeRW00?o0000ojMHYonWF:L00onWF:L4o`0000_oZ5NX0_l00006on4Nh@03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003odBkAom4^d@02om4^d@ko00001_ncC;<00ol0003oY5^TojAK
Y005ojAKY003o`000?n>LHkoSW6>00coSW6>00?o0000ogj1O_l000002on0Oh000ol0003oOH9mogf2
O@07ogf2O@?o00006?n_D:l00ol0003o^TFjokY5^P0@okY5^P?o000000?o]TVfo`000?nWF:L04?nW
F:L00ol0003oYeRWojMHY`07ojMHY`03o`000?nXEjSoZ5NX00[oZ5NX00?o0000on4NhOoQ7^401OoQ
7^400ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005om4^d@03o`000?n4NhCoQ7^400_oQ7^40_l00004
ok=</`03o`000?nTFjCoY5^T00?oY5^T0_l0000@ohiaSP03o`000?n0Oh3oP7n000[oP7n000?o0000
ogf2OOmmPWd00ommPWd4o`0000;oKi1_00?o0000ojm@[on_D:l05On_D:l00ol0003o^TFjokY5^P0D
okY5^P03o`000?nWF:OoYeRW013oYeRW00?o0000ojMHYonWF:L01onWF:L00ol0003oZ5NXojQGZ00:
ojQGZ003o`000?oQ7^7ohAkQ00GohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oA;]7odBkA
00GodBkA00?o0000ohAkQ?n4Nh@03On4Nh@6o`0000?oY5^T00?o0000ohiaS_n>LHh04?n>LHh00ol0
003oP7n0oh1oP00:oh1oP003o`000?mmPWgo000000?o00001om_T6l00ol0003o[e2_ojm@[`0Dojm@
[`03o`000?njAK[o^TFj01Co^TFj00?o0000ojMHYonWF:L03onWF:L00ol0003oYeRWojMHY`08ojMH
Y`03o`000?nXEjSoZ5NX00[oZ5NX00?o0000on4NhOoQ7^401OoQ7^400ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000om4^dOoA;]401_oA;]400ol0003oQ7^4ohAkQ00=ohAkQ003o`000?nTFjCoY5^T00?o
Y5^T00?o0000ojAKY?l000004on>LHh4o`0000WoP7n00_l0000<ofn@K`03o`000?n_D:oo[e2_01?o
[e2_00?o0000okY5^_njAKX05OnjAKX00ol0003oYeRWojMHY`0>ojMHY`03o`000?nWF:OoYeRW00So
YeRW00?o0000ojQGZ?nXEjP02OnXEjP00ol0003ohAkQon4Nh@07on4Nh@03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?oA;]7odBkA00SodBkA00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003oY5^TojAKY005ojAKY003o`00
0?n>LHkoSW6>01;oSW6>00Co0000og^4NomkQ7_oNhAk1Ol00003oh1oP003o`000?m_T6ooKi1_00go
Ki1_0ol0000@ojm@[`;o00006?njAKX00ol0003oYeRWojMHY`0=ojMHY`03o`000?nWF:OoYeRW00Wo
YeRW00?o0000ojQGZ?nXEjP02OnXEjP00ol0003ohAkQon4Nh@07on4Nh@03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_odBkA00?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003oY5^TojAKY006ojAKY003o`00
0?n>LHkoSW6>017oSW6>00?o0000og^4NomkQ7/01omkQ7/3o`00013oKi1_00?o0000ofZEJ_mZUFX0
1Ol00009ojm@[`;o000000?oP7n0o`000?njAKX05onjAKX00ol0003oYeRWojMHY`0=ojMHY`03o`00
0?nWF:OoYeRW00WoYeRW00?o0000ojQGZ?nXEjP02?nXEjP2o`0000[ohAkQ00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?oU6^GoiA[U00;oiA[U00?o0000om4^dOoA;]402OoA;]400ol0003oQ7^4ohAk
Q00:ohAkQ003o`000?nTFjCoY5^T00OoY5^T00?o0000ohiaS_n>LHh03on>LHh00ol0003oNhAkog^4
N`0:og^4N`03o`000?m_T6ooKi1_00goKi1_00?o0000ofZEJ_mZUFX01_mZUFX4o`0000Co[e2_00?o
0000oh1oP?n0Oh000_n0Oh000ol0003o^TFjokY5^P0FokY5^P03o`000?nWF:OoYeRW00_oYeRW00?o
0000ojMHYonWF:L02onWF:L00ol0003oZ5NXojQGZ006ojQGZ003o`000?n^DJko000000[ohAkQ00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?oU6^GoiA[U00?oiA[U00?o0000om4^dOoA;]402?oA;]4=
o`0000[oY5^T00?o0000ohiaS_n>LHh03on>LHh00ol0003oNhAkog^4N`0;og^4N`03o`000?m_T6oo
Ki1_00coKi1_00?o0000ofZEJ_mZUFX02_mZUFX4o`0000GoP7n000?o0000okY5^_njAKX05_njAKX0
0ol0003oYeRWojMHY`0:ojMHY`03o`000?nWF:OoYeRW00coYeRW00?o0000ojQGZ?nXEjP01?nXEjP2
o`0000?o[U6^00?o0000on4NhOoQ7^402?oQ7^400ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onDJ
iOoU6^D00ooU6^D00ol0003odBkAom4^d@07om4^d@03o`000?n1OX7oPGj100WoPGj100?o0000ojAK
Y?nTFj@02OnTFj@00ol0003oSW6>ohiaSP0=ohiaSP03o`000?mkQ7_oNhAk00coNhAk00?o0000ofn@
Kom_T6l03?m_T6l00ol0003oJYEZofZEJP0;ofZEJP03o`000?mA[U7o000000KoP7n000?o0000okY5
^_njAKX05_njAKX00ol0003oYeRWojMHY`09ojMHY`03o`000?nWF:OoYeRW00coYeRW00?o0000ojQG
Z?nXEjP00onXEjP00ol0003o[U6^ojiA[P03ojiA[P03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?oU6^GoiA[U00CoiA[U00?o0000om4^dOoA;]401_oA;]400ol0003o
PGj1oh5nP@08oh5nP@03o`000?nTFjCoY5^T00_oY5^T00?o0000ohiaS_n>LHh02?n>LHh4o`0000oo
NhAk00?o0000ofn@Kom_T6l02om_T6l00ol0003oJYEZofZEJP0;ofZEJP04o`000?mA[U7oDJiAo`00
00OoP7n000?o0000okY5^_njAKX05OnjAKX00ol0003oYeRWojMHY`08ojMHY`03o`000?nWF:OoYeRW
00goYeRW00?o0000ojQGZ?nXEjP00_nXEjP00ol0003o[U6^ojiA[P05ojiA[P03o`000?oQ7^7ohAkQ
00OohAkQ00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?oU6^GoiA[U00GoiA[U00?o0000om4^dOoA
;]401OoA;]400ol0003oPGj1oh5nP@08oh5nP@03o`000?nTFjCoY5^T00_oY5^T00?o0000ohiaS_n>
LHh00on>LHh5o`0000?oNhAk00?o0000og^4NomkQ7/03_mkQ7/00ol0003oKi1_ofn@K`0:ofn@K`03
o`000?mZUF[oJYEZ00[oJYEZ00Go0000oe6^DOmA[U7oDJiAo`000007oh1oP003o`000?njAK[o^TFj
01Go^TFj00?o0000ojMHYonWF:L02?nWF:L00ol0003oYeRWojMHY`0=ojMHY`03o`000?nXEjSoZ5NX
00;o00002?n^DJh00ol0003ohAkQon4Nh@08on4Nh@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oiA[UonDJi@05onDJi@03o`000?oA;]7odBkA00Go
dBkA00?o0000oh5nPOn1OX402?n1OX400ol0003oY5^TojAKY00<ojAKY0Go00002OmkQ7/00ol0003o
NhAkog^4N`0<og^4N`;o00003?m_T6l00ol0003oJYEZofZEJP0:ofZEJP05o`000?mA[U7oDJiAoe6^
DOl000002?n0Oh000ol0003o^TFjokY5^P0DokY5^P?o00001onWF:L00ol0003oYeRWojMHY`0>ojMH
Y`03o`000?nXEjSo000000_o[U6^00?o0000on4NhOoQ7^401_oQ7^400ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000onDJiOoU6^D01OoU6^D00ol0003odBkAom4^d@04om4^d@03o`000?n1OX7oPGj100Oo
PGj100?o0000ojAKY?nTFj@03?nTFj@01?l0003oSW6>ohiaS_l0000;og^4N`03o`000?mkQ7_oNhAk
00_oNhAk00Co0000odfbCOm=/Tgo00002_m_T6l00ol0003oJYEZofZEJP0:ofZEJP03o`000?mA[U7o
DJiA00;oDJiA00?o0000oh1oP?n0Oh001_n0Oh000ol0003o^TFjokY5^P0AokY5^P?o00000on<Lh`0
0ol0003oYeRWojMHY`04ojMHY`03o`000?nWF:OoYeRW00goYeRW1?l0000;ojiA[P03o`000?oQ7^7o
hAkQ00GohAkQ00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oU6^GoiA[U00KoiA[U00Co0000om4^
dOoA;]7odBkA1?l00008oh5nP@03o`000?nTFjCoY5^T00_oY5^T00?o0000ohiaS_n>LHh00_n>LHh0
0ol0003oNhAkog^4N`08og^4N`03o`000?mkQ7_oNhAk00[oNhAk00?o0000odfbCOm=/Td00_m=/Td0
0ol0003oKi1_ofn@K`03ofn@K`Go00002omZUFX00ol0003oDJiAoe6^D@03oe6^D@03o`000?n0Oh3o
P7n000OoP7n000?o0000okY5^_njAKX03_njAKX2o`0000OoS7><00?o0000ojMHYonWF:L00_nWF:L0
0ol0003oYeRWojMHY`0=ojMHY`03o`000?nWF:OoYeRW00;oYeRW00?o0000ojiA[_n^DJh02On^DJh0
0ol0003ohAkQon4Nh@03on4Nh@03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiA[UonDJi@07onDJ
i@?o00001?nm@[d00ol0003oPGj1oh5nP@05oh5nP@03o`000?nTFjCoY5^T00[oY5^T00?o0000ohia
S_n>LHh00on>LHh00ol0003oNhAkog^4N`09og^4N`03o`000?mkQ7_oNhAk00SoNhAk00?o0000odfb
COm=/Td01?m=/Td5o`0000Co7><L00?o0000ofZEJ_mZUFX02OmZUFX00ol0003oDJiAoe6^D@03oe6^
D@03o`000?n0Oh3oP7n000SoP7n000?o0000okY5^_njAKX02_njAKX3o`0000[oS7><00Go0000ojMH
YonWF:OoYeRWo`00000>ojMHY`03o`000?nWF:OoYeRW00CoYeRW0_l00009ojiA[P03o`000?oQ7^7o
hAkQ00;ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?oU6^GoiA[U00OoiA[U00?o0000oke2
_Onm@[d01Onm@[d00ol0003oPGj1oh5nP@03oh5nP@03o`000?nTFjCoY5^T00[oY5^T00?o0000ohia
S_n>LHh01?n>LHh00ol0003oNhAkog^4N`09og^4N`03o`000?mkQ7_oNhAk00OoNhAk00?o0000odfb
COm=/Td01Om=/Td00ol0003o7><LoacS7007oacS7003o`000?mZUF[oJYEZ00OoJYEZ00?o0000oe6^
DOmA[U401?mA[U400ol0003oP7n0oh1oP008oh1oP003o`000?njAK[o^TFj00So^TFj0_l0000>ohac
S0Co00003?nWF:L2o`0000WoYeRW00?o0000ojiA[_n^DJh01on^DJh01?l0003ohAkQon4NhOl0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000onDJiOoU6^D01OoU6^D00ol0003o_D:moke2_@07oke2_@;o00000on1OX400ol0
003oY5^TojAKY009ojAKY003o`000?n>LHkoSW6>00KoSW6>00?o0000og^4NomkQ7/02OmkQ7/00ol0
003oNhAkog^4N`05og^4N`03o`000?m=/TgoCK9=00KoCK9=00?o0000oacS7?lLha`02?lLha`00ol0
003oJYEZofZEJP06ofZEJP03o`000?mA[U7oDJiA00CoDJiA00?o0000oh1oP?n0Oh002On0Oh04o`00
00?o^TFj0ol0000@ohacS005o`000?o0?l3o`3o0ol0o`?l000002_nWF:L00ol0003oYeRWojMHY`0:
ojMHY`Ko00000on^DJh00ol0003ohAkQo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000onDJiOoU6^D01?oU6^D00ol0
003o_D:moke2_@0:oke2_@04o`000?n1OX7oPGj1o`0000[oY5^T00?o0000ohiaS_n>LHh01on>LHh0
0ol0003oNhAkog^4N`09og^4N`03o`000?mkQ7_oNhAk00CoNhAk00?o0000odfbCOm=/Td01om=/Td0
0ol0003o7><LoacS7008oacS70;o00001_mZUFX00ol0003oDJiAoe6^D@05oe6^D@03o`000?n0Oh3o
P7n000WoP7n000Co0000ofjAK_m^TFkoKY5^0ol0000BohacS003o`000?o0?l3o`3o000?o`3o00_l0
0006ojMHY`;o00003OnWF:L00ol0003oiA[UonDJi@03onDJi@Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000onDJiOoU6^D00ooU6^D0
0ol0003o_D:moke2_@0<oke2_@;o00002_nTFj@00ol0003oSW6>ohiaSP08ohiaSP03o`000?mkQ7_o
NhAk00[oNhAk00?o0000og^4NomkQ7/00_mkQ7/00ol0003oCK9=odfbC@08odfbC@03o`000?lLhaco
7><L00Ko7><L0_l00002odZeBP03o`000?mZUF[oJYEZ00;oJYEZ00?o0000oe6^DOmA[U401_mA[U40
0ol0003oP7n0oh1oP008oh1oP003o`000?m^TFkoKY5^00CoKY5^00?o0000ohacS?n<Lh`03on<Lh`0
0ol0003o`3o0ol0o`006ol0o`0;o00000onWF:L00ol0003oYeRWojMHY`0=ojMHY`03o`000?oU6^Go
iA[U00OoiA[U0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003oiA[UonDJi@02onDJi@03o`000?nm@[go_D:m
00ko_D:m00?o0000ojAKY?nTFj@01onTFj@00ol0003oSW6>ohiaSP0:ohiaSP03o`000?mkQ7_oNhAk
00WoNhAk00Go0000og^4NomkQ7_oNhAko`00000;odfbC@03o`000?lLhaco7><L00Co7><L0_l00005
odZeBP05o`000?mZUF[oJYEZofZEJ_l000002?mA[U400ol0003oP7n0oh1oP008oh1oP003o`000?m^
TFkoKY5^00GoKY5^00?o0000ohacS?n<Lh`03_n<Lh`00ol0003o`3o0ol0o`008ol0o`003o`000?nW
F:Oo000000ooYeRW00?o0000onDJiOoU6^D02?oU6^D01?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?oU6^GoiA[Uo`00017o_D:m00?o0000ojAKY?nTFj@01_nTFj@00ol0003oSW6>
ohiaSP0;ohiaSP03o`000?mkQ7_oNhAk00WoNhAk00Co0000og^4NomkQ7_o00003?m=/Td00ol0003o
7><LoacS7002oacS70;o00002?m:]DX00ol0003oJYEZo`000009oe6^D@03o`000?n0Oh3oP7n000So
P7n000?o0000ofjAK_m^TFh01Om^TFh00ol0003oS7><ohacS00=ohacS003o`000?o0?l3o`3o000[o
`3o000?o0000ojMHYonWF:L03_nWF:L00ol0003oiA[UonDJi@07onDJi@03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000Boke2_@03o`00
0?nTFjCoY5^T00CoY5^T00?o0000ohiaS_n>LHh03?n>LHh00ol0003oNhAkog^4N`0:og^4N`?o0000
3?m=/Td00ol0003o7><LoacS7002o`0000_oB[E:00?o0000oe6^DOmA[U402?mA[U400ol0003oP7n0
oh1oP007oh1oP003o`000?m^TFkoKY5^00OoKY5^00?o0000ohacS?n<Lh`03?n<Lh`00ol0003o`3o0
ol0o`00;ol0o`0;o00003_nWF:L00ol0003oiA[UonDJi@07onDJi@03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onTFjOoY5^T00ooY5^T00ol0003o_D:moke2_@0?oke2_@?o00000onT
Fj@00ol0003oSW6>ohiaSP0>ohiaSP03o`000?mkQ7_oNhAk00SoNhAk00Co0000oeJYE_mFZEKoEZUF
0_l0000:odfbC@?o00003Om:]DX00ol0003oDJiAoe6^D@08oe6^D@03o`000?n0Oh3oP7n000OoP7n0
00?o0000ofjAK_m^TFh01om^TFh00ol0003oS7><ohacS00;ohacS003o`000?o0?l3o`3o000co`3o0
00?o0000oldbcOl000000_l0000:ojMHY`03o`000?oU6^GoiA[U00SoiA[U00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003ojAKYonTFj@04onTFj@03o`000?nm@[go_D:m00co_D:m0_l0
0003ojIIYP03o`000?nTFjCo0000017oSW6>00?o0000og^4NomkQ7/01omkQ7/00ol0003oEZUFoeJY
EP04oeJYEP;o00002?m=/Td00ol0003oB[E:odZeBP0>odZeBP;o00002?mA[U400ol0003oP7n0oh1o
P006oh1oP003o`000?m^TFkoKY5^00WoKY5^00?o0000ohacS?n<Lh`02On<Lh`00ol0003o`3o0ol0o
`00=ol0o`003o`000?o=</gocC;=00;ocC;=0ol00007ojMHY`03o`000?oU6^GoiA[U00OoiA[U00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojAKYonTFj@05onTFj@03o`000?nm@[go
_D:m00Wo_D:m0_l00006ojIIYP03o`000?n>LHkoSW6>013oSW6>00?o0000og^4NomkQ7/01_mkQ7/0
0ol0003oEZUFoeJYEP07oeJYEP03o`000?m=/TgoCK9=00CoCK9=0ol0000>odZeBP03o`000?ldbcCo
=</d00?o00001OmA[U400ol0003oP7n0oh1oP006oh1oP003o`000?m^TFkoKY5^00[oKY5^00?o0000
ohacS?n<Lh`02?n<Lh`00ol0003o`3o0ol0o`00=ol0o`003o`000?o=</gocC;=00GocC;=0ol00004
ojMHY`03o`000?oU6^GoiA[U00OoiA[U00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ojAKYonTFj@06onTFj@03o`000?nm@[go_D:m00Go_D:m0ol00008ojIIYP03o`000?n>LHkoSW6>
017oSW6>00Co0000og^4NomkQ7_oNhAk1?l0000;oeJYEP;o000000CoCK9=o`000?l0003o00000omT
Vf@2o`0000_oB[E:00?o0000ocC;=?ldbc@01?ldbc@2o`0000?oDJiA00?o0000oh1oP?n0Oh001_n0
Oh000ol0003oKY5^ofjAKP0:ofjAKP03o`000?n<LhcoS7><00OoS7><00?o0000ol0o`?o0?l003_o0
?l000ol0003ocC;=oldbc@08oldbc@Co00002_oU6^D00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ojAKYonTFj@07onTFj@03o`000?nm@[go_D:m00;o_D:m0_l0000<ojIIYP03o`000?n>LHko
SW6>013oSW6>1?l00003ofjAKP03o`000?mFZEKoEZUF00_oEZUF00?o0000ofBKI?mTVf@01_mTVf@0
0ol0003oB[E:odZeBP07odZeBP03o`000?ldbcCo=</d00Oo=</d3?l0000>ofjAKP03o`000?n<Lhco
S7><00KoS7><00?o0000ol0o`?o0?l003_o0?l000ol0003ocC;=oldbc@0;oldbc@03o`000?oU6^Go
iA[U00OoiA[U00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oY5^WojAKY00WojAKY00Co0000oke2
_Ol0003o00003_nVFJH00ol0003oSW6>ohiaSP0?ohiaSP03o`000?m^TFkoKY5^00KoKY5^00?o0000
oeJYE_mFZEH02_mFZEH00ol0003oI9]TofBKI007ofBKI0;o00001_m:]DX00ol0003o=</docC;=008
ocC;=003o`000?n7N8OoQgR700SoQgR700?o0000ofjAK_m^TFh03?m^TFh00ol0003oS7><ohacS005
ohacS003o`000?o0?l3o`3o000oo`3o00_l0000=oldbc@03o`000?oU6^GoiA[U00KoiA[U00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oY5^WojAKY00[ojAKY00?o0000ojIIY_nVFJH03_nVFJH00ol0
003oSW6>ohiaSP0>ohiaSP03o`000?m^TFkoKY5^00OoKY5^00?o0000oeJYE_mFZEH02_mFZEH00ol0
003oI9]TofBKI009ofBKI0;o00000om:]DX00ol0003o=</docC;=009ocC;=003o`000?n7N8OoQgR7
00WoQgR700?o0000ofjAK_m^TFh02_m^TFh4o`0000CoS7><00?o0000ol0o`?o0?l004?o0?l001?l0
003obSG:o`000?l0000<oldbc@03o`000?oU6^GoiA[U00GoiA[U00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?oY5^WojAKY00[ojAKY00?o0000ojIIY_nVFJH03onVFJH@o`0000[oKY5^00?o0000oeJY
E_mFZEH02OmFZEH00ol0003o?L8mo`00000<ofBKI005o`000?m:]D[o0000ocK9=_l000002_ldbc@0
0ol0003oQgR7ohMhQ`09ohMhQ`03o`000?m^TFkoKY5^00OoKY5^0ol00004oiA[U0?o000000?oS7><
o`000?o0?l004Oo0?l001?l0003obSG:olXeb_o:=LX2o`0000_ocC;=00?o0000onDJiOoU6^D00ooU
6^D00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onTFjOoY5^T02_oY5^T00ol0003oYUVVojIIYP0?
ojIIYP03o`000?nEJYGoUFZE00coUFZE00?o0000ofjAK_m^TFh02Om^TFh00ol0003oEZUFoeJYEP07
oeJYEP04o`000?lm`Sgo?L8mo`0000goI9]T00Go0000ocK9=_lfbCKo=/Tfo`000009ocC;=003o`00
0?n7N8OoQgR700[oQgR700?o0000ofjAK_m^TFh00om^TFh3o`0000[oU6^D00?o0000ol0o`?o0?l00
4?o0?l000ol0003obSG:olXebP04olXebP;o00002_o=</d00ol0003oiA[UonDJi@04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cojAKY00?o0000ojIIY_nVFJH03onVFJH00ol0003oUFZEoiEZU@0<oiEZU@03o`000?m^
TFkoKY5^00WoKY5^00?o0000oeJYE_mFZEH01_mFZEH00ol0003o?L8mocg2?@02ocg2?@03o`000?mT
VfCoI9]T00[oI9]T00?o0000ocK9=_lfbCH00_lfbCH00ol0003o=</docC;=006ocC;=003o`000?n7
N8OoQgR700[oQgR700?o0000ofjAK_m^TFh00ol0000=oiA[U003o`000?o0?l3o`3o0013o`3o000?o
0000olXeb_o:=LX01_o:=LX2o`0000WocC;=0_l00004oo/4n`03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000onTFjOoY5^T02_oY5^T00ol0003oYUVVojIIYP0=ojIIYP?o00003onEJYD0
0ol0003oKY5^ofjAKP08ofjAKP03o`000?mFZEKoEZUF00GoEZUF00?o0000ocg2?Olm`Sd00olm`Sd0
0ol0003oI9]TofBKI00:ofBKI003o`000?lfbCKo=/Tf00?o=/Tf00?o0000ocC;=?ldbc@01Oldbc@0
0ol0003oQgR7ohMhQ`0;ohMhQ`;o00004OnDJi@00ol0003o`3o0ol0o`00?ol0o`003o`000?o:=L[o
bSG:00SobSG:0_l00007oldbc@03o`000?ok1?_on`Ck00Con`Ck00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000onTFjOoY5^T02?oY5^T00ol0003oYUVVojIIYP09ojIIYPGo00000_mlPg`00ol0
003oUFZEoiEZU@0=oiEZU@03o`000?m^TFkoKY5^00WoKY5^00?o0000oeJYE_mFZEH01?mFZEH00ol0
003o?L8mocg2?@04ocg2?@03o`000?mTVfCoI9]T00SoI9]T00?o0000ocK9=_lfbCH01OlfbCH00ol0
003o=</docC;=004ocC;=003o`000?n7N8OoQgR700_oQgR700?o0000oiA[U?nDJi@04?nDJi@00ol0
003o`3o0ol0o`00?ol0o`003o`000?o:=L[obSG:00[obSG:0_l00004oldbc@03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003ojAKYonTFj@07onTFj@03o`000?nVFJKoYUVV00CoYUVV1Ol00007ogb3O003
o`000?nEJYGoUFZE00goUFZE00?o0000ofjAK_m^TFh02Om^TFh00ol0003oEZUFoeJYEP03oeJYEP03
o`000?lm`Sgo?L8m00Go?L8m00?o0000ofBKI?mTVf@02?mTVf@00ol0003o=/TfocK9=P06ocK9=P03
o`000?ldbcCo=</d00?o=</d00?o0000ohMhQon7N8L02on7N8L00ol0003oU6^DoiA[U00@oiA[U003
o`000?o0?l3o`3o000oo`3o000?o0000olXeb_o:=LX03?o:=LX2o`000003oldbcOl0003on`Ck00[o
n`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oY5^WojAKY00OojAKY00?o0000ojIIY_l00000
1?l0000<ogb3O003o`000?nEJYGoUFZE00koUFZE00?o0000ofjAK_m^TFh02?m^TFh00ol0003oEZUF
oeJYEP02oeJYEP03o`000?lm`Sgo?L8m00Oo?L8m00?o0000ofBKI?mTVf@01omTVf@00ol0003o=/Tf
ocK9=P07ocK9=P03o`000?ldbcCo=</d00;o=</d00?o0000ohMhQon7N8L02on7N8L00ol0003oU6^D
oiA[U00AoiA[U003o`000?o0?l3o`3o000go`3o000?o0000olXeb_o:=LX03oo:=LX00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onTFjOoY5^T01OoY5^T3o`00017oO8=l00?o0000oiEZUOnEJYD03_nE
JYD00ol0003oKY5^ofjAKP09ofjAKP04o`000?mFZEKoEZUFo`0000[o?L8m00?o0000ofBKI?mTVf@0
1omTVf@00ol0003o=/TfocK9=P08ocK9=P05o`000?ldbcCo=</docC;=?l000003On7N8L00ol0003o
U6^DoiA[U00AoiA[U0?o00003Oo0?l000ol0003obSG:olXebP0?olXebP03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_oY5^T2o`0000;o^DJi00?o0000ogb3O?mlPg`03omlPg`00ol0003o
UFZEoiEZU@0>oiEZU@03o`000?m^TFkoKY5^00SoKY5^1Ol0000;ocg2?@03o`000?mTVfCoI9]T00Ko
I9]T00?o0000ocK9=_lfbCH02OlfbCH01?l0003o=</docC;=?l0000=ohMhQ`03o`000?nDJiCoU6^D
017oU6^D00?o0000og2?L?m`Sg000ol0000:ol0o`0Co00003Oo:=LX00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000onHIi_oV6NKoiQWV0_l00005okU6^@03o`000?mlPgcoO8=l00koO8=l00?o0000oiEZ
UOnEJYD03_nEJYD00ol0003oKY5^ofjAKP07ofjAKP03o`000?m[U6_oJiA[00?oJiA[00?o0000ocg2
?Olm`Sd02?lm`Sd00ol0003oI9]TofBKI005ofBKI003o`000?lfbCKo=/Tf00[o=/Tf1Ol0000<ohMh
Q`03o`000?nDJiCoU6^D013oU6^D00?o0000og2?L?m`Sg001?m`Sg03o`0000Ko`3o000?o0000olha
c_o><Lh00_o><Lh5o`0000SobSG:00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oV6NKoiQWV00?o
iQWV00?o0000okU6^OniA[T01?niA[T00ol0003oO8=logb3O00=ogb3O003o`000?nEJYGoUFZE00oo
UFZE00?o0000ofjAK_m^TFh01?m^TFh2o`0000OoJiA[00?o0000ocg2?Olm`Sd01olm`SdEo`0000Go
A;]400?o0000ohMhQon7N8L02?n7N8L3o`00013oU6^D00?o0000og2?L?m`Sg002?m`Sg03o`0000;o
`3o000?o0000olhac_o><Lh02?o><Lh5o`0000?obSG:00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?oV6NKoiQWV00CoiQWV00?o0000okU6^OniA[T01OniA[T00ol0003oO8=logb3O00;ogb3O0Co0000
3onEJYD00ol0003oKY5^ofjAKP03ofjAKP03o`000?m[U6_oJiA[00SoJiA[00?o0000ocg2?Olm`Sd0
1?lm`Sd2o`0000SoJiA[00?o0000oeVVFOmIYUT02?mIYUT00ol0003oA;]4odBkA005odBkA0;o0000
1_n7N8L2o`0000?oNXEj00?o0000oiA[U?nDJi@03?nDJi@00ol0003oL8m`og2?L00<og2?L0;o0000
4?o><Lh3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oiQWVonHIiP05onHIiP03o`000?niA[Wo^DJi00Ko^DJi00?o
0000ogb3O?mlPg`02OmlPg`00ol0003oJIIYo`000002og:=LP?o00003?nEJYD01?l0003oKY5^ofjA
K_m^TFh2o`0000coJiA[00?o0000ocg2?Olm`Sd00_lm`Sd00ol0003oJiA[of^DJ`08of^DJ`03o`00
0?mIYUWoFJII00SoFJII00?o0000odBkA?m4^d@01om4^d@00ol0003oQgR7ohMhQ`02ohMhQ`03o`00
0?mjQG[oNXEj00CoNXEj0_l0000;oiA[U003o`000?m`Sg3oL8m`00coL8m`00?o0000oi9]T_l00000
4_o><Lh00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003oiQWVonHIiP06onHIiP03o`000?niA[Wo^DJi00Oo^DJi00?o
0000ogb3O?mlPg`01_mlPg`2o`0000;oJIIY00?o0000og:=L_mbSG800ombSG83o`0000[oUFZE00?o
0000ofjAK_l000003om[U6/01?l0003o?L8mo`000?l0000;of^DJ`03o`000?mIYUWoFJII00SoFJII
00?o0000odBkA?m4^d@02?m4^d@01?l0003oQgR7o`000?l00009ogZ5NP03o`000?nDJiCoU6^D00Oo
U6^D00?o0000og2?L?m`Sg003?m`Sg001?l0003oTVfBoi9]T_l0000ColhacP03o`000?ok1?_on`Ck
00con`Ck0ol000000ook1?_o0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000onHIi_oV6NH01ooV6NH00ol0003o^DJiokU6^@08okU6^@03o`000?mlPgcoO8=l00Co
O8=l00?o0000ofVFJOmYUVT00omYUVT00ol0003oLXebog:=LP05og:=LP?o00001_nEJYD4o`00013o
JiA[00?o0000of^DJom[U6/03?m[U6/00ol0003oFJIIoeVVF@07oeVVF@03o`000?m4^dCoA;]400Wo
A;]400?o0000ogZ5N_mjQGX02_mjQGX2o`0000KoU6^D00?o0000og2?L?m`Sg003?m`Sg000ol0003o
TVfBoi9]TP02oi9]TP03o`000?o><LkocS7>00oocS7>00?o0000on4NhOl000002ook1?/2o`0000Co
n`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oiQWVonHIiP08onHIiP03o`000?niA[Wo^DJi00Wo^DJi00Co0000ogb3O?mlPgco
O8=l0_l00006ofVFJ@03o`000?mbSG;oLXeb00SoLXeb0ol000000onEJYGo0000o`000004ogJ9MP03
o`000?m[U6_oJiA[00goJiA[00?o0000of^DJom[U6/03?m[U6/00ol0003oFJIIoeVVF@07oeVVF@03
o`000?m4^dCoA;]400WoA;]400?o0000ogZ5N_mjQGX03?mjQGX00ol0003oU6^DoiA[U003o`0000ko
L8m`00?o0000oi9]T_nBKI800onBKI800ol0003ocS7>olhacP0>olhacP05o`000?oQ7^7ohAkQon4N
hOl000002?ok1?/2o`0000Oon`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003oiQWVonHIiP09onHIiP03o`000?niA[Wo^DJi00[o
^DJi00?o0000ogb3O?l000002?mYUVT00ol0003oLXebog:=LP0;og:=LP03o`000?mfRGKoMXUf00Go
MXUf00?o0000of^DJom[U6/03?m[U6/00ol0003oJiA[of^DJ`0<of^DJ`03o`000?mIYUWoFJII00Oo
FJII00?o0000odBkA?m4^d@02?m4^d@2o`0000ooNXEj0_l00002oh9mPP03o`000?m`Sg3oL8m`00_o
L8m`00?o0000oi9]T_nBKI801?nBKI800ol0003ocS7>olhacP0=olhacP03o`000?oQ7^7ohAkQ00?o
hAkQ00?o0000oo/4nook1?/00_ok1?/3o`0000Won`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onHIiP03o`000?niA[Wo^DJi00_o^DJi00?o0000ofVFJOmYUVT0
1omYUVT00ol0003oLXebog:=LP0;og:=LP03o`000?mfRGKoMXUf00KoMXUf00?o0000of^DJom[U6/0
2om[U6/2o`0000goJiA[00?o0000oeVVFOmIYUT01omIYUT00ol0003oA;]4odBkA007odBkA004o`00
0?mA[U7oDJiAo`0000koNXEj00?o0000oh9mP_n2OH800_n2OH800ol0003oL8m`og2?L009og2?L003
o`000?nBKI;oTVfB00KoTVfB00?o0000olhac_o><Lh02oo><Lh00ol0003ohAkQon4Nh@05on4Nh@04
o`000?ok1?_o0000o`0000con`Ck00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo/4nook1?/00_ok1?/3o`0000SoiQWV00?o0000okU6^OniA[T02_niA[T2o`0000Wo
JIIY00?o0000og:=L_mbSG802ombSG800ol0003oMXUfogJ9MP07ogJ9MP03o`000?m[U6_oJiA[00Wo
JiA[00Co0000ocC;=?ldbcCo00003?m[U6/00ol0003oFJIIoeVVF@07oeVVF@03o`000?m4^dCoA;]4
00KoA;]400Go0000oe6^DOmA[U7oDJiAo`00000>ogZ5NP03o`000?n2OH;oPWf200?oPWf200?o0000
og2?L?m`Sg001om`Sg000ol0003oTVfBoi9]TP07oi9]TP03o`000?o><LkocS7>00[ocS7>00?o0000
on4NhOoQ7^401ooQ7^400ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00Gon`Ck0_l00006onHIiP03o`000?niA[Wo^DJi
00Wo^DJi00Co0000oiMXUonGJ9Oo00002OmYUVT00ol0003oLXebog:=LP09og:=LP03o`000?mfRGKo
MXUf00WoMXUf00?o0000of^DJom[U6/01om[U6/00ol0003o=</docC;=002ocC;=003o`000?m[U6_o
JiA[00WoJiA[00?o0000oeVVFOmIYUT01omIYUT00ol0003oA;]4odBkA005odBkA003o`000?mA[U7o
DJiA00?oDJiA00?o0000ogZ5N_mjQGX02_mjQGX00ol0003oPWf2oh9mPP05oh9mPP03o`000?m`Sg3o
L8m`00GoL8m`00?o0000oi9]T_nBKI802?nBKI800ol0003ocS7>olhacP09olhacP03o`000?oQ7^7o
hAkQ00SohAkQ00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003on`Ckoo/4n`07oo/4n`?o00000_oV6NH3o`0000Wo^DJi00?o0000oiMX
UonGJ9L00_nGJ9L00ol0003oJIIYofVFJ@06ofVFJ@03o`000?mbSG;oLXeb00WoLXeb00?o0000ogJ9
M_mfRGH02_mfRGH00ol0003oJiA[of^DJ`05of^DJ`03o`000?ldbcCo=</d00Co=</d00?o0000of^D
Jom[U6/02?m[U6/00ol0003oFJIIoeVVF@07oeVVF@03o`000?m4^dCoA;]400CoA;]400?o0000oe6^
DOmA[U401?mA[U400ol0003oNXEjogZ5NP0:ogZ5NP03o`000?n2OH;oPWf200KoPWf200?o0000og2?
L?m`Sg000om`Sg000ol0003oTVfBoi9]TP09oi9]TP03o`000?o><LkocS7>00SocS7>00?o0000on4N
hOoQ7^402OoQ7^400ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ok1?_on`Ck00[on`Ck0_l00003omhQgP?o00001OniA[T00ol0003o
UfRGoiMXU`03oiMXU`03o`000?mYUVWoJIIY00KoJIIY00?o0000og:=L_mbSG802OmbSG800ol0003o
MXUfogJ9MP0;ogJ9MP03o`000?m[U6_oJiA[00?oJiA[00?o0000ocC;=?ldbc@01_ldbc@00ol0003o
JiA[of^DJ`08of^DJ`03o`000?mIYUWoFJII00KoFJII00?o0000odBkA?m4^d@00_m4^d@2o`0000So
DJiA00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oPWf2oh9mPP07oh9mPP05o`000?m`Sg3oL8m`og2?
L?l000003OnBKI800ol0003ocS7>olhacP06olhacP03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo/4
nook1?/03Ook1?/00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
n`Ckoo/4n`0:oo/4n`03o`000?oN8MkogR7N00GogR7N0ol000000oniA[Wo0000oiMXU`06oiMXU`03
o`000?mYUVWoJIIY00GoJIIY00?o0000og:=L_mbSG802OmbSG800ol0003oMXUfogJ9MP0<ogJ9MP05
o`000?m[U6_oJiA[of^DJol000002_ldbc@00ol0003oJiA[of^DJ`07of^DJ`03o`000?mIYUWoFJII
00KoFJII00?o0000odBkA?l000000_l000000on4NhCo0000oe6^D@07oe6^D@03o`000?mjQG[oNXEj
00SoNXEj00?o0000oh9mP_n2OH802On2OH800ol0003oL8m`o`00000=oi9]TPCo00001Oo><Lh00ol0
003ohAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo/4nook1?/02ook1?/00ol0003ogR7NomhQgP08omhQgP03
o`000?nGJ9OoUfRG00OoUfRG00?o0000ofVFJOmYUVT01?mYUVT00ol0003oLXebog:=LP09og:=LP03
o`000?mfRGKoMXUf00goMXUf00?o0000of^DJol000003?ldbc@:o`0000OoFJII0ol00005ohAkQ003
o`000?mA[U7oDJiA00KoDJiA00?o0000ogZ5N_mjQGX01omjQGX00ol0003oPWf2oh9mPP0:oh9mPP03
o`000?nBKI;oTVfB00_oTVfB00?o0000oke2_Onm@[d00_nm@[d3o`000003olhac_l0003ohAkQ00_o
hAkQ0ol0000>oo/4n`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ok1?_on`Ck00[on`Ck00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oUfRGoiMXU`07oiMXU`03o`00
0?mYUVWoJIIY00GoJIIY00?o0000og:=L_mbSG801ombSG800ol0003oMXUfogJ9MP0?ogJ9MP;o0000
2oldbc@00ol0003oN8MhogR7N007ogR7N003o`000?mIYUWoFJII00;oFJII0ol00008ohAkQ003o`00
0?mA[U7oDJiA00KoDJiA00?o0000ogZ5N_mjQGX01omjQGX00ol0003oPWf2oh9mPP0:oh9mPP03o`00
0?nBKI;oTVfB00[oTVfB00?o0000oke2_Onm@[d01_nm@[d00ol0003ohAkQon4Nh@08on4Nh@?o0000
0_oY5^T00ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ok1?_on`Ck00[on`Ck00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oUfRGoiMX
U`08oiMXU`03o`000?mYUVWoJIIY00CoJIIY00?o0000og:=L_mbSG801ombSG800ol0003oMXUfogJ9
MP0>ogJ9MP04o`000?m6^DKoA[U6o`0000Wo=</d00?o0000ogR7N?mhQgP02OmhQgP01?l0003oFJII
o`000?l0000<ohAkQ003o`000?mA[U7oDJiA00KoDJiA00?o0000ogZ5N_mjQGX01_mjQGX00ol0003o
PWf2oh9mPP0;oh9mPP03o`000?nBKI;oTVfB00OoTVfB0_l00009oke2_@03o`000?oQ7^7ohAkQ00Co
hAkQ1?l00006onTFj@03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo/4nook1?/02_ok1?/00ol0003ogR7NomhQgP09omhQgP03o`00
0?nGJ9OoUfRG00SoUfRG00?o0000ofVFJOmYUVT00omYUVT>o`0000goMXUf00?o0000odJiA_m6^DH0
0_m6^DH00ol0003o=</docC;=005ocC;=003o`000?mhQgSoN8Mh00_oN8Mh00?o0000ohAkQ?n4Nh@0
3?n4Nh@00ol0003oDJiAoe6^D@06oe6^D@03o`000?mjQG[oNXEj00GoNXEj00?o0000oh9mP_n2OH80
3?n2OH800ol0003oTVfBoi9]TP06oi9]TP03o`000?nm@[go_D:m00[o_D:m00?o0000on4NhOoQ7^40
0ol0000:onTFj@?o00002_ok1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000oiMXUonGJ9L02?nG
J9L01Ol0003oJIIYofVFJOmYUVWo000000_oK9=/00?o0000ob;M8_lRgB800ol00009ogJ9MP03o`00
0?m6^DKoA[U600CoA[U600?o0000ocC;=?ldbc@00oldbc@00ol0003oN8MhogR7N00<ogR7N003o`00
0?n4NhCoQ7^400goQ7^400?o0000oe6^DOmA[U401_mA[U400ol0003oNXEjogZ5NP03ogZ5NP?o0000
3On2OH800ol0003oTVfBoi9]TP05oi9]TP03o`000?nm@[go_D:m00co_D:m0_l0000=onTFj@03o`00
0?ol0ocoo0?l00?o00001ook1?/00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000oiMXUonGJ9L02?nG
J9L4o`0000coK9=/00?o0000ob;M8_lRgB800olRgB83o`0000GoMXUf00?o0000odJiA_m6^DH01_m6
^DH01Ol0003o=</docC;=?ldbcCo000000ooN8Mh00?o0000ohAkQ?n4Nh@03On4Nh@00ol0003oDJiA
oe6^D@06oe6^D@03o`000?mjQG[oNXEj00?o00000omFZEH00ol0003oPWf2oh9mPP0;oh9mPP03o`00
0?nBKI;oTVfB00?oTVfB00?o0000oke2_Onm@[d03Onm@[d00ol0003ojAKYonTFj@0;onTFj@03o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo/4n`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ok1?_on`Ck00Son`Ck00?o0000omhQg_oN8Mh02_oN8Mh3o`0000KoUfRG0ol0
0003ohMhQ`03o`000?m/TfcoK9=/00[oK9=/00?o0000ob;M8_lRgB801_lRgB83o`000003ogJ9M_l0
003oA[U600WoA[U600?o0000ocC;=?l000004?mhQgP00ol0003oQ7^4ohAkQ00=ohAkQ003o`000?mA
[U7oDJiA00OoDJiA0_l00007oeJYEP03o`000?n2OH;oPWf200[oPWf200Co0000oi9]T_nBKI;oTVfB
0ol0000?oke2_@03o`000?oY5^WojAKY00_ojAKY00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000omhQg_oN8Mh02_oN
8Mh01?l0003oacS7olLhaoo7><L2o`000004oiMXUol0003o0000o`0000KoQgR700?o0000ofbCK?m/
Tf`02_m/Tf`00ol0003o8]dRob;M8P09ob;M8P03o`000?m6^DKoA[U600[oA[U600?o0000ogR7N?mh
QgP03omhQgP00ol0003oQ7^4ohAkQ00>ohAkQ003o`000?mA[U7oDJiA00KoDJiA00?o0000oeJYE_mF
ZEH01omFZEH4o`0000SoPWf200Co0000oi9]T_nBKI;o00000omjQGX2o`0000go_D:m00?o0000onTF
jOoY5^T02_oY5^T00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000omhQg_oN8Mh02OoN8Mh00ol0003o
acS7olLha`04olLha`03o`000?n7N8OoQgR700OoQgR700?o0000ofbCK?m/Tf`02Om/Tf`00ol0003o
8]dRob;M8P0:ob;M8P03o`000?m6^DKoA[U600[oA[U600?o0000ogR7N?mhQgP03omhQgP00ol0003o
Q7^4ohAkQ00>ohAkQ003o`000?mA[U7oDJiA00GoDJiA00?o0000oeJYE_mFZEH02?mFZEH01?l0003o
KY5^ofjAK_m^TFh7o`0000;oPWf20_l00006ogZ5NP;o00003?nm@[d00ol0003ojAKYonTFj@09onTF
j@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo/4nook1?/01?ok1?/00ol0003ogR7NomhQgP08omhQgP03o`000?o7><OoacS700Go
acS700?o0000ohMhQon7N8L02?n7N8L00ol0003oK9=/ofbCK008ofbCK003o`000?lRgB;o8]dR00[o
8]dR00?o0000odJiA_m6^DH02om6^DH00ol0003oN8MhogR7N00>ogR7N003o`000?n4NhCoQ7^400ko
Q7^41Ol00002oe6^D@03o`000?mFZEKoEZUF00WoEZUF00?o0000ofjAK_m^TFh02?m^TFh3o`0000Wo
NXEj0_l0000:oke2_@03o`000?oY5^WojAKY00SojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oN8MkogR7N00SogR7N00?o0000olLhaoo7><L01oo7><L00ol0003oQgR7ohMhQ`07ohMhQ`03o`00
0?m/TfcoK9=/00SoK9=/00?o0000ob;M8_lRgB802_lRgB800ol0003oA[U6odJiAP0:odJiAP;o0000
3_mhQgP3o`0000goQ7^40ol00005ohQgR0;o00002omFZEH00ol0003oKY5^ofjAKP0;ofjAKP;o0000
2_mjQGX2o`0000Oo_D:m0ol00009onTFj@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo/4nook1?_on`Ck3?l0000:olLha`03o`00
0?n7N8OoQgR700OoQgR700?o0000ofbCK?m/Tf`02?m/Tf`>o`0000WoA[U60ol000000olVfBKo0000
ogR7N00:ogR7N0?o00000_n=LXd00ol0003oQ7^4ohAkQ009ohAkQ0;o00002On8MhP00ol0003oEZUF
oeJYEP09oeJYEP03o`000?m^TFkoKY5^00_oKY5^00?o0000oh=lPol000002omjQGX2o`0000Co_D:m
00Co0000omdRgOoM8]gogB;M0_l00007onTFj@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo/4nol000002ooj1OX00ol0003oacS7
olLha`09olLha`03o`000?n7N8OoQgR700KoQgR700?o0000ofbCK?m/Tf`02?m/Tf`00ol0003o<Lha
oc7><@0:oc7><@03o`000?m6^DKoA[U600CoA[U60ol00005obKI9P03o`000?mhQgSoN8Mh00CoN8Mh
1?l00006ohebS@03o`000?n4NhCoQ7^400KoQ7^40_l0000;ohQgR003o`000?mFZEKoEZUF00WoEZUF
00?o0000ofjAK_m^TFh02_m^TFh01Ol0003oPgb3oh=lPon3O8?o000000coNXEj0_l000000onm@[go
0000omdRg@05omdRg@03o`000?oY5^WojAKY00?ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o7><OoacS700SoacS700?o0000ohMhQon7N8L01_n7N8L00ol0003oK9=/ofbCK007ofbCK003o`00
0?lacS7o<Lha00_o<Lha00?o0000odJiA_m6^DH00_m6^DH2o`0000Wo9]TV00?o0000ogR7N?mhQgP0
0ol0000;ohebS@03o`000?n4NhCoQ7^400;oQ7^40ol0000>ohQgR003o`000?mFZEKoEZUF00OoEZUF
00?o0000ofjAK_m^TFh02om^TFh00ol0003oPgb3oh=lP`02oh=lP`03o`000?mjQG[oNXEj00_oNXEj
00?o0000omdRgOoM8]d01_oM8]d2o`0000?ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0<ooX5nP03o`000?o7
><OoacS700OoacS700?o0000ohMhQon7N8L01on7N8L00ol0003oK9=/ofbCK005ofbCK0?o00003Ola
cS44o`0000_o9]TV0ol0000?ohebS@04o`000?n4NhCo0000o`00017oR7N800?o0000oeJYE_mFZEH0
1omFZEH00ol0003oKY5^ofjAKP0:ofjAKP03o`000?n3O8?oPgb300CoPgb300?o0000ogZ5N_mjQGX0
1omjQGX3o`0000_ogB;M1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?oj1O[onPGj00conPGj00?o0000olLhaoo7><L02?o7><L00ol0003oQgR7ohMh
Q`06ohMhQ`03o`000?m/TfcoK9=/00;oK9=/0ol00003oeB[E003o`000?lacS7o<Lha00[o<Lha00?o
0000obKI9_lVfBH02olVfBH00ol0003o</dbo`00000AohebS@03o`000?n8MhSoR7N8017oR7N800?o
0000oeJYE_mFZEH01omFZEH00ol0003oKY5^ofjAKP0:ofjAKP03o`000?n3O8?oPgb300GoPgb300Co
0000ogZ5N_mjQG[oNXEj1Ol00002oi1_T003o`000?oM8]gogB;M00WogB;M00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?oj1O[onPGj00konPGj00?o0000olLhaoo7><L01oo7><L00ol0003oQgR7ohMhQ`05ohMhQ`?o0000
00?oK9=/o`000?l000001omDZe@00ol0003o<Lhaoc7><@08oc7><@?o00002_lVfBH2o`0000;o</db
00?o0000ohebSOn=LXd03on=LXd00ol0003oR7N8ohQgR00AohQgR003o`000?mFZEKoEZUF00OoEZUF
00?o0000ofjAK_m^TFh02Om^TFh00ol0003oPgb3oh=lP`07oh=lP`?o00001on@Ki000ol0003ogB;M
omdRg@09omdRg@03o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?oj1O[onPGj00konPGj00?o0000olLhaoo7><L01oo7
><L4o`0000;oQgR70_l00003ohm`S`03o`000?mDZeCoE:]D00SoE:]D0_l00006oc7><@;o00000olh
acP00ol0003o9]TVobKI9P06obKI9P03o`000?lbcC;o</db00?o</db00?o0000ohebSOn=LXd03_n=
LXd00ol0003oR7N8ohQgR00BohQgR003o`000?mFZEKoEZUF00GoEZUF00?o0000ofjAK_m^TFh02Om^
TFh00ol0003oPgb3oh=lP`08oh=lP`03o`000?n@Ki3oT6n@00OoT6n@00?o0000omdRgOoM8]d02?oM
8]d00ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?o7><OoacS700CoacS70_l00004
omDZe@;o00001On?L8l00ol0003oE:]DoeB[E00:oeB[E003o`000?lacS7o<Lha00;o<Lha00?o0000
ocS7>?lhacP01?lhacP00ol0003o9]TVobKI9P04obKI9P03o`000?lbcC;o</db00Co</db00?o0000
ohebSOn=LXd03_n=LXd00ol0003oR7N8ohQgR00BohQgR0[o00002_m^TFh00ol0003oPgb3oh=lP`08
oh=lP`03o`000?n@Ki3oT6n@00OoT6n@00?o0000omdRgOoM8]d02?oM8]d00ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooX5
n_oj1OX03ooj1OX01?l0003oacS7olLhaoo7><L2o`0000OoeB[E00?o0000ohm`Son?L8l01?n?L8l0
0ol0003oE:]DoeB[E00:oeB[E004o`000?lacS7o0000o`0000So><Lh00Co0000obKI9_lVfBKo9]TV
0_l00007oc;=<P03o`000?n=LXgoSG:=00koSG:=00?o0000ohQgR?n8MhP04_n8MhP00ol0003oIYUV
ofJIIP07ofJIIP03o`000?m^TFkoKY5^00KoKY5^00?o0000oh=lPon3O8<02_n3O8<00ol0003oT6n@
oi1_T006oi1_T003o`000?oM8]gogB;M00SogB;M00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003onPGjooX5nP0?ooX5nP04o`000?o7
><Oo0000o`0000WoeB[E00?o0000ohm`Son?L8l01?n?L8l00ol0003oE:]DoeB[E00;oeB[E003o`00
0?lhacSo><Lh00Wo><Lh00?o0000obKI9_l000002OlbcC800ol0003oSG:=ohebS@0>ohebS@;o0000
4_n8MhP00ol0003oIYUVofJIIP09ofJIIP;o00001_m^TFh00ol0003oPgb3oh=lP`0:oh=lP`03o`00
0?n@Ki3oT6n@00KoT6n@00?o0000omdRgOoM8]d02?oM8]d00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?oj1O[onPGj013onPGj00?o
0000omDZeOoE:]D02OoE:]D00ol0003oSg2?ohm`S`05ohm`S`03o`000?mDZeCoE:]D00[oE:]D00?o
0000ocS7>?lhacP02_lhacP2o`0000Wo</db00?o0000ohebSOn=LXd03_n=LXd00ol0003oM8]do`00
0002o`0000ooR7N800?o0000ofJII_mVVFH02omVVFH00ol0003oKY5^ofjAKP03o`0000goPgb300?o
0000oi1_T?n@Ki001_n@Ki000ol0003ogB;MomdRg@07omdRg@03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003oeB[EomDZe@09omDZe@03o`000?n?L8ooSg2?00GoSg2?00?o0000oeB[E?mDZe@02OmDZe@2
o`0000_o><Lh0_l0000;oc;=<P03o`000?n=LXgoSG:=00coSG:=00?o0000ogB;M?mdRg@00omdRg@3
o`0000coR7N800?o0000ofJII_mVVFH03?mVVFH2o`0000;oKI9]00?o0000oh=lPon3O8<03?n3O8<0
0ol0003oT6n@oi1_T005oi1_T003o`000?oM8]gogB;M00OogB;M00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003onPGjooX5nP0>ooX5
nP03o`000?oE:]GoeB[E00[oeB[E00?o0000ohm`Son?L8l01_n?L8l00ol0003oE:]DoeB[E007oeB[
E003o`000?m3_4?o000000[o><Lh00Co0000obGJ9OlUfRGo00002_lbcC800ol0003oSG:=ohebS@0<
ohebS@03o`000?mdRgCoM8]d00KoM8]d0_l00008ohQgR0;o00003omVVFH00ol0003oKI9]offBK@02
offBK@03o`000?n3O8?oPgb300_oPgb300?o0000oi1_T?n@Ki001On@Ki000ol0003ogB;MomdRg@07
omdRg@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oeB[EomDZe@0:omDZe@03o`000?n?L8ooSg2?
00KoSg2?00?o0000oeB[E?mDZe@01_mDZe@01Ol0003o@ka3od>l@om3_4?o000000So><Lh00?o0000
obGJ9OlUfRD00_lUfRD00ol0003o</dboc;=<P06oc;=<PCo00003?n=LXd00ol0003oM8]dogB;M008
ogB;M0?o00000_n8MhP3o`000003of:MH_l0003oIYUV00goIYUV00?o0000offBKOm]TVd01?m]TVd0
0ol0003oPgb3oh=lP`0:oh=lP`03o`000?n@Ki3oT6n@00GoT6n@00?o0000omdRgOoM8]d01_oM8]d0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?oj1O[onPGj00conPGj00?o0000omDZeOoE:]D02ooE:]D00ol0003oSg2?ohm`S`07ohm`
S`03o`000?mDZeCoE:]D00?oE:]D0_l00005od>l@`03o`000?lhacSo><Lh00Co><Lh00?o0000obGJ
9OlUfRD00olUfRD00ol0003o</dboc;=<P05oc;=<P03o`000?mC[5?oDjaC00;oDjaC0ol00007oheb
S@;o00003_mdRg@2o`0000GoHYeR00?o0000ofJII_mVVFH02_mVVFH00ol0003oKI9]offBK@05offB
K@03o`000?n3O8?oPgb300_oPgb300?o0000oi1_T?n@Ki001?n@Ki000ol0003ogB;MomdRg@06omdR
g@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oeB[EomDZe@0;omDZe@03o`000?n?L8ooSg2?00Oo
Sg2?00?o0000oeB[E?mDZe@00_mDZe@00ol0003o@ka3od>l@`06od>l@`03o`000?lhacSo><Lh00;o
><Lh00?o0000obGJ9OlUfRD01OlUfRD00ol0003o</dboc;=<P02oc;=<P;o00002?mC[5<3o`0000;o
SG:=0_l000000omMXUgo0000ogB;M00=ogB;M003o`000?mRWF;oHYeR00GoHYeR00?o0000ofJII_mV
VFH02?mVVFH00ol0003oKI9]offBK@07offBK@03o`000?n3O8?oPgb300[oPgb300?o0000oi1_T?n@
Ki001?n@Ki000ol0003ogB;MomdRg@06omdRg@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooX5n_oj1OX02ooj1OX00ol0003oeB[E
omDZe@0<omDZe@03o`000?n?L8ooSg2?00SoSg2?00Co0000oeB[E?mDZeCo00002Om3_4<01Ol0003o
><LhocS7>?lhacSo000000So9MXU00Go0000oc;=<_lbcC;o</dbo`00000=oe>/D`;o00001?mMXUd0
0ol0003oM8]dogB;M00;ogB;M003o`000?mRWF;oHYeR00KoHYeR00?o0000ofJII_mVVFH01omVVFH0
0ol0003oKI9]offBK@08offBK@Co00002?n3O8<00ol0003oT6n@oi1_T004oi1_T003o`000?oM8]go
gB;M00KogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003onPGjooX5nP0:ooX5nP03o`000?oE:]GoeB[E00_oeB[E0ol00009ohm`
S`03o`000?mDZeCo000000_o@ka300?o0000ocS7>?l000002_lUfRD00ol0003o</dbo`00000?oe>/
D`03o`000?mMXUgoGJ9M00;oGJ9M00?o0000ogB;M?mdRg@02omdRg@00ol0003oHYeRof:MHP06of:M
HP03o`000?mVVFKoIYUV00KoIYUV00?o0000offBKOm]TVd02Om]TVd01?l0003oTFjAoi5^TOnAKY47
o`0000;oPgb300?o0000oi1_T?n@Ki000on@Ki000ol0003ogB;MomdRg@05omdRg@03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooX5
nP03o`000?oE:]GoeB[E00SoeB[E0ol00003ol<l``03o`000?n?L8ooSg2?00OoSg2?00?o0000od>l
@om3_4<02om3_4<00ol0003o9MXUobGJ9@0:obGJ9@03o`000?mC[5?oDjaC00goDjaC00?o0000oefR
GOmMXUd01?mMXUd00ol0003oM8]dogB;M009ogB;M003o`000?mRWF;oHYeR00SoHYeR00?o0000ofJI
I_mVVFH00omVVFH2o`0000coKI9]00?o0000oi5^TOnAKY402?nAKY4<o`0000?ogB;M0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?oj1O[onPGj00Oo
nPGj00?o0000omDZeOoE:]D01_oE:]D3o`0000Oo`cc300?o0000ohm`Son?L8l01_n?L8l00ol0003o
@ka3od>l@`0;od>l@`03o`000?lUfRGo9MXU00Wo9MXU0_l0000>oe>/D`03o`000?mMXUgoGJ9M00Go
GJ9M00?o0000ogB;M?mdRg@02OmdRg@00ol0003oHYeRof:MHP09of:MHP03o`000?mVVFKo000000;o
00000_mUVVD00ol0003oKI9]offBK@08offBK@03o`000?nAKY7oTFjA00coTFjA00?o0000omdRgOoM
8]d01_oM8]d3o`0000?on`Ck0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooX5n_oj1OX01_oj1OX00ol0003oeB[EomDZe@03omDZe@?o00002oo3?<<00ol0003oSg2?
ohm`S`04ohm`S`03o`000?m3_4?o@ka300_o@ka30ol00007obGJ9@?o000000?oA[U6o`000?mC[5<0
3OmC[5<00ol0003oGJ9MoefRG@06oefRG@03o`000?mdRgCoM8]d00SoM8]d00?o0000of:MH_mRWF80
2_mRWF800ol0003oIIYUofFJI@04ofFJI@03o`000?m]TVgoKI9]00OoKI9]00?o0000oi5^TOnAKY40
2onAKY400ol0003ogB;MomdRg@08omdRg@03o`000?ok1?_on`Ck00Con`Ck0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooX5n_oj1OX00ooj1OX4o`000004omDZeOl0
003o0000o`0000oo`cc300?o0000ohm`Son?L8l00on?L8l>o`0000?o?l0o0_l00002obGJ9@?o0000
1Om6^DH00ol0003oDjaCoe>/D`0:oe>/D`03o`000?mMXUgoGJ9M00OoGJ9M00?o0000ogB;M?mdRg@0
2?mdRg@00ol0003oHYeRof:MHP0:of:MHP03o`000?mUVVGoIIYU00GoIIYU00?o0000offBKOm]TVd0
1_m]TVd00ol0003oTFjAoi5^T@0;oi5^T@03o`000?oM8]gogB;M00SogB;M00?o0000oo/4nook1?/0
1ook1?/2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?oj
1O[o000000;o00001?oj1OX2o`0001;o`cc300?o0000ohm`Son?L8l00_n?L8l00ol0003oD:m@oe2_
D00:oe2_D003o`000?lo`3oo?l0o00?o?l0o0_l00009odJiAP03o`000?mC[5?oDjaC00WoDjaC00?o
0000oefRGOmMXUd02?mMXUd2o`0000SoM8]d00?o0000of:MH_mRWF802OmRWF800ol0003oIIYUofFJ
I@07ofFJI@03o`000?m]TVgoKI9]00CoKI9]00?o0000oi5^TOnAKY402onAKY400ol0003ogB;MomdR
g@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003o`cc3ol<l``0?ol<l``?o000000?oSg2?
o`000?m@[e002om@[e000ol0003o?l0ooco0?`04oco0?`03o`000?m6^DKoA[U600WoA[U600?o0000
oe>/DomC[5<01omC[5<00ol0003oGJ9MoefRG@09oefRG@04o`000?mHYeSo0000o`0000KoM8]d00?o
0000of:MH_mRWF802OmRWF800ol0003oIIYUofFJI@08ofFJI@03o`000?m]TVgoKI9]00?oKI9]00?o
0000oi5^TOnAKY402onAKY400ol0003ogB;MomdRg@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003o`cc3ol<l``0<ol<l``;o00000onkA;/2o`0000coD:m@00?o0000oco0?olo`3l01?lo`3l0
0ol0003oA[U6odJiAP0:odJiAPWo00002omMXUd00ol0003oF:MHoeRWF002oeRWF0?o00000_mdRg@0
0ol0003oHYeRof:MHP0:of:MHP03o`000?mUVVGoIIYU00WoIIYU00?o0000offBKOm]TVd00_m]TVd0
0ol0003oTFjAoi5^T@0:oi5^T@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o3?<<2o`0000Go^dBk00?o0000oh9mP_l000002_m@[e000ol0003o?l0ooco0?`06oco0
?`03o`000?m6^DKoA[U600WoA[U600?o0000odJiA_m6^DH01Om6^DH00ol0003oGJ9MoefRG@09oefR
G@03o`000?mHYeSoF:MH00GoF:MH0ol00009of:MHP?o00003OmUVVD01Ol0003oKI9]offBKOm]TVgo
000000coTFjA00?o0000omdRgOoM8]d02OoM8]d00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol<l
`oo3?<<01Oo3?<<2o`0000Oo^dBk00Co0000oh9mP_n2OH;o00002Om@[e000ol0003o?l0ooco0?`06
oco0?`03o`000?m6^DKoA[U600SoA[U600?o0000odJiA_m6^DH01om6^DH00ol0003oGJ9MoefRG@07
oefRG@03o`000?mHYeSoF:MH00SoF:MH0ol00002of:MHPGo00000_lhacP00ol0003oIIYUofFJI@0<
ofFJI@03o`000?m]TVgo000000coTFjA00?o0000omdRgOoM8]d02_oM8]d00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000ol<l`oo3?<<00_o3?<<2o`0000So^dBk00?o0000oh9mP_n2OH800_n2OH85o`00
00CoD:m@00?o0000oco0?olo`3l01_lo`3l00ol0003oA[U6odJiAP08odJiAP03o`000?m6^DKoA[U6
00OoA[U600?o0000oefRGOmMXUd01omMXUd00ol0003oF:MHoeRWF008oeRWF003o`000?l`cc3o<<l`
00;o00002?lhacP00ol0003oIIYUofFJI@0<ofFJI@Co00002_nAKY400ol0003ogB;MomdRg@0:omdR
g@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003o`cc3o`000?l0000:ok]4^`03o`000?n2OH;oPWf2
00;oPWf200?o0000ob7N8OlQgR400_lQgR44o`0000Wo?l0o00?o0000odJiA_m6^DH02?m6^DH00ol0
003oA[U6odJiAP08odJiAP03o`000?mMXUgoGJ9M00GoGJ9M00?o0000oeRWF?mHYeP02?mHYeP01Ol0
003o<<l`oc3?<?l`cc3o000000[o><Lh0ol0000;ofFJI@04o`000?o5>/GoaC[5olDja@Co00001OnA
KY400ol0003ogB;MomdRg@0;omdRg@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o^dBkok]4^`0:
ok]4^`03o`000?n2OH;oPWf200?oPWf200?o0000ob7N8OlQgR401?lQgR400ol0003o?l0ooco0?`07
oco0?`03o`000?m6^DKoA[U600KoA[U60_l0000;odJiAP03o`000?mMXUgoGJ9M00GoGJ9M00?o0000
oeRWF?mHYeP02?mHYeP00ol0003o<<l`oc3?<002oc3?<003o`000?lhacSo><Lh00Oo><Lh00?o0000
ogV6NOmiQWT01?l00006ofFJI@03o`000?o5>/GoaC[500KoaC[50ol00002oi5^T@03o`000?oM8]go
gB;M00_ogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nkA;_o^dBk00Wo^dBk00?o0000oh9m
P_n2OH801?n2OH800ol0003o8MhQob7N8@05ob7N8@03o`000?lo`3oo?l0o00Oo?l0o00?o0000odJi
A_m6^DH00_m6^DH3o`000003oe>/Dol0003oA[U600[oA[U600?o0000oefRGOmMXUd01OmMXUd00ol0
003oF:MHoeRWF007oeRWF003o`000?l`cc3o<<l`00?o<<l`00?o0000ocS7>?lhacP01olhacP00ol0
003oNHIiogV6N@04ogV6N@?o00000_mUVVD00ol0003oaC[5olDja@0:olDja@;o00003_oM8]d00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ok]4^onkA;/02OnkA;/00ol0003oPWf2oh9mPP04oh9mPP03
o`000?lQgR7o8MhQ00Ko8MhQ0_l00007oco0?`03o`000?m6^DKo000000;o00001OmC[5<00ol0003o
A[U6odJiAP08odJiAP?o00001?mMXUd00ol0003oF:MHoeRWF008oeRWF003o`000?l`cc3o<<l`00Co
<<l`00?o0000ocS7>?lhacP01_lhacP00ol0003oNHIiogV6N@07ogV6N@;o00003_o5>/D00ol0003o
gB;MomdRg@0;omdRg@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o^dBkok]4^`08ok]4^`03o`00
0?n2OH;oPWf200GoPWf200?o0000ob7N8OlQgR401?lQgR400ol0003oBKI9odVfB@03o`0000Co?l0o
0_l00008oe>/D`03o`000?m6^DKoA[U600OoA[U600Co0000ogV6NOmiQWWoNHIi0ol000000omMXUgo
0000oeRWF009oeRWF003o`000?l`cc3o<<l`00Co<<l`00?o0000ocS7>?lhacP01OlhacP00ol0003o
NHIiogV6N@09ogV6N@03o`000?o5>/GoaC[500goaC[500?o0000omdRgOoM8]d02_oM8]d00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ok]4^onkA;/01onkA;/00ol0003oPWf2oh9mPP06oh9mPP03o`00
0?lQgR7o8MhQ00?o8MhQ00?o0000odVfBOm9]TT01?m9]TT2o`000003oco0?ol0003oDjaC00[oDjaC
00?o0000odJiA_m6^DH01Om6^DH00ol0003oNHIiogV6N@05ogV6N@03o`000?mHYeSoF:MH00OoF:MH
0ol00007oc3?<003o`000?lhacSo><Lh00Co><Lh00?o0000ogV6NOmiQWT02OmiQWT00ol0003oaC[5
olDja@0=olDja@03o`000?oM8]gogB;M00[ogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nk
A;_o^dBk00Go^dBk0ol00009oh9mPP05o`000?lQgR7o8MhQob7N8Ol000002Om9]TT00ol0003oDjaC
oe>/D`0;oe>/D`03o`000?m6^DKoA[U600?oA[U600?o0000ogV6NOmiQWT01_miQWT00ol0003oF:MH
oeRWF006oeRWF005o`000?mMXUgoGJ9MoefRGOl000001ol`cc000ol0003o><LhocS7>003ocS7>003
o`000?miQWWoNHIi00WoNHIi00?o0000olDjaOo5>/D03_o5>/D00ol0003ogB;MomdRg@09omdRg@03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o^dBko`000004o`0000;oeRWF00?o0000oh9mP_n2OH80
1on2OH801?l0003o8MhQob7N8Ol00009odVfB@;o00003OmC[5<00ol0003oA[U6odJiAP02odJiAP03
o`000?miQWWoNHIi00SoNHIi00?o0000oeRWF?mHYeP00omHYeP2o`0000GoGJ9M00?o0000oc3?<?l`
cc001?l`cc000ol0003o><LhocS7>003ocS7>003o`000?miQWWoNHIi00WoNHIi00?o0000olDjaOo5
>/D03_o5>/D00ol0003ogB;MomdRg@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SoeRWF
00?o0000oh9mP_n2OH801_n2OH800ol0003o8MhQo`000009odVfB@04o`000?mYUVWoJIIYo`0000go
DjaC00Co0000odJiA_m6^DKo00003?miQWT01Ol0003oF:MHoeRWF?mHYeSo000000SoGJ9M0_l00005
oc3?<003o`000?lhacSo><Lh00;o><Lh00?o0000ogV6NOmiQWT02OmiQWT00ol0003oaC[5olDja@0>
olDja@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oF:MKoeRWF
00OoeRWF00?o0000oh9mP_n2OH801on2OH800ol0003oBKI9odVfB@07odVfB@03o`000?mYUVWoJIIY
00;oJIIY00?o0000oe>/DomC[5<02_mC[5<00ol0003oA[U6o`00000>ogV6N@03o`000?mHYeSo0000
00_oGJ9M00?o0000oc3?<?l`cc000_l`cc001Ol0003o><LhocS7>?lhacSo000000coNHIi00?o0000
olDjaOo5>/D03_o5>/D3o`0000WogB;M00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oF:MKoeRWF
00WoeRWF00?o0000oh9mP_n2OH801_n2OH800ol0003oBKI9odVfB@06odVfB@03o`000?mYUVWoJIIY
00?oJIIY00?o0000oe>/DomC[5<02omC[5<00ol0003oNHIiogV6N@0>ogV6N@03o`000?mMXUgoGJ9M
00_oGJ9M0_l00003oc3?<004o`000?lhacSo><Lho`0000[oNHIi0ol0000>olDja@;o00000ooj1OX2
o`0000OogB;M00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oF:MKoeRWF00[oeRWF00?o0000oh9m
P_n2OH801?n2OH800ol0003oBKI9odVfB@06odVfB@03o`000?mYUVWoJIIY00GoJIIY00?o0000oe>/
DomC[5<01omC[5<3o`00017oNHIi00?o0000oefRGOmMXUd03OmMXUd01Ol0003o<<l`oc3?<?l0003o
><Lh00Co00000omiQWT5o`0000;oaSW600?o0000olDjaOo5>/D02_o5>/D2o`0000OonPGj0_l00004
omdRg@03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003oeRWFomHYeP0;omHYeP03o`000?n2OH;oPWf2
00CoPWf200?o0000odVfBOm9]TT01Om9]TT00ol0003oJIIYofVFJ@06ofVFJ@03o`000?mC[5?oDjaC
00CoDjaC0ol00002of6NH@03o`000?miQWWoNHIi00ooNHIi0_l0000?oefRG@04o`000?l`cc3o0000
o`0000CoJIIY0ol00008olHiaP03o`000?o5>/GoaC[500OoaC[50_l0000;ooX5nP;o00000_oM8]d0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omHYe_oF:MH03?oF:MH6o`0000OoBKI900?o0000ofVF
JOmYUVT02?mYUVT00ol0003oDjaCoe>/D`03o`0000KoHIiQ00?o0000ogV6NOmiQWT03OmiQWT01?l0
003oLHiaog6>LOl0000?oefRG@03o`000?mYUVWoJIIY00GoJIIY00?o0000olHia_o6>LH02?o6>LH0
0ol0003oaC[5olDja@05olDja@03o`000?oj1O[onPGj00gonPGj0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oF:MH00ol0003oR7N8ohQgR004ohQg
R003o`000?m9]TWoBKI900?oBKI900?o0000ofVFJOmYUVT02_mYUVT2o`0000[oHIiQ00?o0000ogV6
NOmiQWT02omiQWT00ol0003oLHiaog6>L@02og6>L@03o`000?mMXUgoGJ9M00_oGJ9M0_l00007ofVF
J@03o`000?o6>LKoaSW600WoaSW600?o0000olDjaOo5>/D00_o5>/D2o`0001;onPGj00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omHYe_oF:MH02ooF:MH00ol0003oR7N8ohQgR006ohQgR005o`000?m9]TWoBKI9odVf
BOl000003OmYUVT00ol0003oHIiQof6NH@0:of6NH@03o`000?miQWWoNHIi00WoNHIi00?o0000og6>
LOmaSW401?maSW400ol0003oGJ9MoefRG@08oefRG@;o000000?o=lPgo`000?mYUVT01omYUVT00ol0
003oaSW6olHiaP09olHiaP04o`000?o5>/Go0000o`0001ConPGj00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oF:MKoeRWF
00WoeRWF00?o0000ohQgR?n8MhP02?n8MhP00ol0003oBKI9o`00000=ofVFJ@03o`000?mQWV7oHIiQ
00_oHIiQ00?o0000ogV6NOmiQWT02?miQWT00ol0003oLHiaog6>L@06og6>L@03o`000?mMXUgoGJ9M
00GoGJ9M0_l00003ocO8=`03o`000?mYUVWoJIIY00KoJIIY00?o0000olHia_o6>LH02_o6>LH00ol0
003onPGjooX5nP0EooX5nP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003oeRWFomHYeP07omHYeP03o`000?n8MhSoR7N800[oR7N800?o0000ofVFJOmY
UVT03?mYUVT00ol0003oHIiQof6NH@0<of6NH@03o`000?miQWWoNHIi00KoNHIi00?o0000og6>LOma
SW402?maSW400ol0003oGJ9MoefRG@02oefRG@;o00001_lgb3L00ol0003oJIIYofVFJ@05ofVFJ@03
o`000?o6>LKoaSW600[oaSW600?o0000ooX5n_oj1OX05Ooj1OX00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oF:MKoeRWF00GoeRWF
00?o0000ohQgR?n8MhP03?n8MhP2o`0000coJIIY00?o0000of6NHOmQWV403OmQWV400ol0003oNHIi
ogV6N@04ogV6N@03o`000?maSW7oLHia00[oLHia00Co0000oefRGOl0003o00002?lgb3L00ol0003o
JIIYofVFJ@06ofVFJ@03o`000?o6>LKoaSW600WoaSW600?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oF:MH00ol0003oR7N8ohQgR00=ohQgR003o`000?mSW6?o000000;o00002?mYUVT00ol0003oHIiQ
of6NH@0?of6NH@Ko00003_maSW400ol0003o=lPgocO8=`08ocO8=`03o`000?mYUVWoJIIY00KoJIIY
00?o0000olHia_o6>LH02Oo6>LH00ol0003onPGjooX5nP0DooX5nP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000omHYe_oF:MKoeRWF
0_l0000?ohQgR003o`000?mSW6?oHiaS00?oHiaS0ol00005ofVFJ@;o00004?mQWV401_l0003oC;=<
odbcC?l0003o=</do`0000koLHia00?o0000ocO8=olgb3L02Olgb3L00ol0003oJIIYofVFJ@05ofVF
J@03o`000?o6>LKoaSW600WoaSW600?o0000ooX5n_oj1OX04ooj1OX2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000omHYe_oF:MH00ooF:MH00ol0003o
R7N8ohQgR00=ohQgR003o`000?mSW6?oHiaS00KoHiaS0ol000001?mYUVWo0000oeJYE_mFZEH3o`00
00coHIiQ00Go0000odbcC?m</dcoC;=<o`000002ocC;=003o`000?maSW7oLHia00_oLHia00?o0000
ocO8=olgb3L02Olgb3L00ol0003oJIIYofVFJ@06ofVFJ@03o`000?o6>LKoaSW600SoaSW60_l0000A
ooX5nP?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003oeRWFomHYeP04omHYePoo00003?mSW6<00ol0003oEZUFoeJYEP04oeJY
EP?o00002?mQWV400ol0003oC;=<odbcC002odbcC005o`000?ldbcCo=</docC;=?l000003?maSW40
0ol0003o=lPgocO8=`09ocO8=`03o`000?mYUVWoJIIY00GoJIIY3?l00002onDJi@;o00003Ooj1OX2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003oeRWFomHYeP05omHYeP03o`000?mdRgCoM8]d00_oM8]d00?o0000of>L
HomSW6<02_mSW6<00ol0003oEZUFoeJYEP07oeJYEP;o00001OmQWV400ol0003oC;=<odbcC003odbc
C003o`000?ldbcCo=</d00;o=</d00?o0000og6>LOmaSW402OmaSW400ol0003o=lPgocO8=`0:ocO8
=`03o`000?mYUVWoJIIY00?oJIIY00?o0000oiA[U?nDJi@02OnDJi@00ol0003oiA[UonDJi@02onDJ
i@;o00002Ooj1OX2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003oeRWFomHYeP06omHYeP03o`000?mdRgCoM8]d00[o
M8]d00?o0000of>LHomSW6<02omSW6<00ol0003oEZUFoeJYEP09oeJYEP?o000000?oHIiQo`000?m<
/d`01Om</d`00ol0003o=</docC;=003ocC;=003o`000?maSW7oLHia00SoLHia3_l00003ofVFJ@;o
00002onDJi@00ol0003oiA[UonDJi@05onDJi@03o`000?oj1O[onPGj00?onPGj0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000omHYe_oF:MH01OoF:MH00ol0003oRgB;o`00000;ogB;M003o`000?mSW6?oHiaS00[oHiaS
0_l0000>oeJYEP03o`000?m</dcoC;=<00GoC;=<00?o0000ocC;=?ldbc@00oldbc@00ol0003oLHia
og6>L@08og6>L@03o`000?m]TVgoKI9]00_oKI9]00?o0000ofVFJOl000003OnDJi@00ol0003oiA[U
onDJi@06onDJi@;o000000?onPGjo`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oF:MKoeRWF00KoeRWF00Co
0000oh]dRon;M8_o00002_mdRg@00ol0003oHiaSof>LH`09of>LH`03o`000?mEZUGo000000koEZUF
00?o0000odbcC?m</d`01Om</d`00ol0003o=</docC;=004ocC;=003o`000?maSW7oLHia00KoLHia
00?o0000offBKOm]TVd03Om]TVd00ol0003oU6^DoiA[U00<oiA[U003o`000?oU6^GoiA[U00SoiA[U
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oF:MKoeRWF00GoeRWF00?o0000oh]dRon;M8/00_n;
M8/00ol0003oM8]dogB;M006ogB;M003o`000?mSW6?oHiaS00SoHiaS0_l00003oeFZE@03o`000?mF
ZEKoEZUF00_oEZUF00?o0000odbcC?m</d`01Om</d`00ol0003o=</docC;=005ocC;=003o`000?ma
SW7oLHia00GoLHia00?o0000offBKOm]TVd03Om]TVd00ol0003oU6^DoiA[U00;oiA[U003o`000?oU
6^GoiA[U00WoiA[U00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oF:MKoeRWF00KoeRWF00?o0000
oh]dRon;M8/00on;M8/00ol0003oM8]dogB;M005ogB;M003o`000?mSW6?oHiaS00OoHiaS00?o0000
oeFZEOmEZUD00omEZUD00ol0003oEZUFoeJYEP0:oeJYEP03o`000?m</dcoC;=<00KoC;=<00?o0000
ocC;=?ldbc@01_ldbc@00ol0003oLHiaog6>L@04og6>L@03o`000?m]TVgoKI9]00goKI9]3ol0000;
onDJi@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oF:MKoeRWF00KoeRWF00?o0000oh]dRon;M8/01On;M8/00ol0
003oM8]dogB;M004ogB;M003o`000?mSW6?oHiaS00GoHiaS0_l00006oeFZE@03o`000?mFZEKoEZUF
00WoEZUF0_l00008odbcC003o`000?ldbcCo=</d00Ko=</d1Ol000000omaSW7o0000offBK@0?offB
K@03o`000?nAKY7oTFjA00_oTFjA00?o0000onDJiOoU6^D02OoU6^D00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oF:MKoeRWF00KoeRWF00?o0000oh]dRon;M8/01_n;M8/00ol0003o
M8]dogB;M004o`0000KoHiaS00?o0000oeFZEOmEZUD01omEZUD00ol0003oEZUFoeJYEP05oeJYEP?o
000000?o?kloo`000?m</d`01om</d`00ol0003o=</docC;=005ocC;=003o`000?mcS7?oLhac00?o
Lhac0_l0000?offBK@;o00003OnAKY400ol0003oiA[UonDJi@08onDJi@03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WoeRWF00?o0000oh]dRon;M8/01on;M8/2o`0000CoSg2?00Co0000of>LHomSW6?o
HiaS0_l0000:oeFZE@03o`000?mFZEKoEZUF00;oEZUF0ol00005ocno?`03o`000?m</dcoC;=<00Go
C;=<00?o0000ocC;=?ldbc@01?ldbc@00ol0003oLhacog><L`06og><L`03o`000?m]TVgoKI9]00[o
KI9]0_l00002ogn0O`03o`000?nAKY7oTFjA00[oTFjA00?o0000onDJiOoU6^D02?oU6^D00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000omHYe_oF:MH01_oF:MH00ol0003oRgB;oh]dR`08oh]dR`03o`00
0?n?L8ooSg2?00CoSg2?00?o0000of>LHol000003?mEZUD00ol0003oEZUFo`000002o`0000Wo?klo
00?o0000odbcC?m</d`01?m</d`00ol0003o=</docC;=003ocC;=003o`000?mcS7?oLhac00SoLhac
1_l00004offBK@;o00001OmoP7l00ol0003oTFjAoi5^T@09oi5^T@03o`000?oU6^GoiA[U00SoiA[U
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oF:MKoeRWF00GoeRWF00?o0000oh]dRon;M8/01on;
M8/00ol0003oSg2?ohm`S`06ohm`S`03o`000?mEZUGoEJYE00coEJYE00?o0000ocno?olo_cl02_lo
_cl00ol0003oC;=<odbcC004odbcC004o`000?ldbcCo=</docC;=0;o00002omcS7<00ol0003oNHIi
ogV6N@03ogV6N@Co00002?moP7l00ol0003oTFjAoi5^T@08oi5^T@03o`000?oU6^GoiA[U00OoiA[U
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000omHYe_oF:MH00ooF:MH00ol0003oRgB;oh]dR`07oh]dR`03o`000?n?
L8ooSg2?00OoSg2?00?o0000oeFZEOmEZUD03?mEZUD00ol0003o?kloocno?`0;ocno?`03o`000?m<
/dcoC;=<00?oC;=<00Co0000ocC;=?ldbcCo00003OmcS7<00ol0003oNHIiogV6N@06ogV6N@03o`00
0?moP7ooOh1o00OoOh1o00?o0000oi5^TOnAKY401onAKY400ol0003oiA[UonDJi@06onDJi@04o`00
0?ol0ocoo0?loo`3o0;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oF:MKoeRWF00;oeRWF00?o0000oh]dRon;M8/0
1_n;M8/00ol0003oSg2?ohm`S`09ohm`S`03o`000?mEZUGoEJYE00WoEJYE0_l0000>ocno?`?o0000
0om</d`00ol0003o=</do`00000=og><L`03o`000?miQWWoNHIi00OoNHIi00?o0000ogn0OomoP7l0
2?moP7l:o`0000KoiA[U0_l00006oo`3o003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoRgB;00?o
0000ohm`Son?L8l02_n?L8l00ol0003oEJYEoeFZE@06oeFZE@;o000000?oDjaCo`000?lo_cl02olo
_cl2o`0000?oLXeb1Ol0000>og><L`03o`000?miQWWoNHIi00OoNHIi00?o0000ogn0OomoP7l02?mo
P7l00ol0003o/4n`ok1?/006ok1?/003o`000?oU6^GoiA[U00?oiA[U00?o0000oo`3o?ol0o`01ool
0o`2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003obcC;ol/db`03ol/db`Co00000_n;M8/00ol0003oSg2?ohm`S`0;
ohm`S`03o`000?mEZUGoEJYE00?oEJYE0ol00004oe>/D`03o`000?lo_coo?klo00Oo?klo0_l00008
og:=LP03o`000?mcS7?oLhac00goLhac00?o0000ogV6NOmiQWT02?miQWT00ol0003oOh1oogn0O`07
ogn0O`03o`000?n`Ck3o/4n`00Oo/4n`0ol000000ooU6^Go0000oo`3o00;oo`3o0;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o;=<_obcC;00OobcC;0_l0000?ohm`S`03o`000?mEZUGoEJYE00;o00002?mC[5<00ol0
003o?kloocno?`05ocno?`03o`000?mbSG;oLXeb00SoLXeb00?o0000og><LomcS7<03OmcS7<00ol0
003oNHIiogV6N@08ogV6N@03o`000?moP7ooOh1o00KoOh1o00?o0000ok1?/?n`Ck002?n`Ck001?l0
003oiA[UonDJiOl0000?oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003obcC;ol/db`09ol/d
b`03o`000?n?L8ooSg2?00koSg2?0_l0000;oe>/D`03o`000?lo_coo?klo00;o?klo0_l0000;og:=
LP03o`000?mcS7?oLhac00goLhac00?o0000ogV6NOmiQWT02?miQWT00ol0003oOh1oogn0O`06ogn0
O`03o`000?n`Ck3o/4n`00Oo/4n`00Go0000onDJiOoU6^GoiA[Uo`00000@oo`3o0;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003obcC;ol/db`0:ol/db`03o`000?n?L8ooSg2?00goSg2?0_l0000<oe>/D`04o`000?lo_coo0000
o`0000goLXeb00?o0000og><LomcS7<03?mcS7<00ol0003oNHIiogV6N@09ogV6N@03o`000?moP7oo
Oh1o00KoOh1o00?o0000ok1?/?n`Ck001_n`Ck000ol0003oiA[UonDJi@03onDJi@03o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003obcC;ol/db`0:ol/db`03o`000?n?L8ooSg2?00coSg2?00Co0000ocK9
=_lfbCKo00003?mC[5<00ol0003oLXebog:=LP0>og:=LP03o`000?mcS7?oLhac00SoLhac1?l0000;
ogV6N@03o`000?moP7ooOh1o00KoOh1o00?o0000ok1?/?n`Ck001On`Ck000ol0003oiA[UonDJi@04
onDJi@03o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003obcC;ol/db`0;ol/db`03o`000?n?L8ooSg2?
00_oSg2?00?o0000ocK9=_lfbCH00_lfbCH00ol0003oDjaCoe>/D`09oe>/D`03o`000?mbSG;oLXeb
00koLXeb00Co0000og><LomcS7?oLhac1ol00003ogR7N003o`000?miQWWoNHIi00WoNHIi00?o0000
ogn0OomoP7l01_moP7l00ol0003o/4n`ok1?/004ok1?/003o`000?oU6^GoiA[U00KoiA[U00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?o;=<_obcC;00cobcC;00?o0000ohm`Son?L8l02_n?L8l00ol0
003o=/TfocK9=P03ocK9=P03o`000?mC[5?oDjaC00SoDjaC00?o0000og:=L_mbSG803_mbSG84o`00
00_oN8Mh00?o0000ogV6NOmiQWT02?miQWT00ol0003oOh1oogn0O`05ogn0O`03o`000?n`Ck3o/4n`
00Go/4n`00?o0000onDJiOoU6^D01_oU6^D00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000ol/dboo;
=</03?o;=</7o`0000GoSg2?00?o0000ocK9=_lfbCH01OlfbCH00ol0003oDjaCoe>/D`07oe>/D`03
o`000?mbSG;oLXeb00koLXeb00?o0000ogR7N?mhQgP03OmhQgP00ol0003oNHIiogV6N@08ogV6N@03
o`000?moP7ooOh1o00CoOh1o00?o0000ok1?/?n`Ck001?n`Ck000ol0003oiA[UonDJi@07onDJi@03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003obcC;ol/db`0=ol/db`03o`000?nPGj3oX5nP00CoX5nP
1Ol00009ocK9=P03o`000?mC[5?oDjaC00KoDjaC00?o0000og:=L_mbSG803_mbSG800ol0003oN8Mh
ogR7N00=ogR7N003o`000?miQWWoNHIi00SoNHIi00Co0000ogn0OomoP7ooOh1o1Ol00004ok1?/003
o`000?oU6^GoiA[U00WoiA[U1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=ol/db`03o`000?nPGj3oX5nP00WoX5nP
0_l00009ocK9=P03o`000?mC[5?oDjaC00KoDjaC00?o0000og:=L_mbSG803?mbSG800ol0003oN8Mh
ogR7N00?ogR7N0Ko00001?miQWT4o`0000Go_d2o0_l000000on`Ck3o0000onDJi@0;onDJi@04o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oN8MkogR7NomhQgP?o00002_o;=</00ol0003o
X5nPoj1OX009oj1OX003o`000?m9]TWo000000;o00001olfbCH00ol0003oDjaCoe>/D`05oe>/D`03
o`000?mbSG;oLXeb00SoLXeb1Ol0000AogR7N003o`000?n1OX7oPGj100?oPGj11?l0000;okm0_`03
o`000?oU6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000omhQg_oN8Mh01OoN8Mh2o`0000OobcC;
00?o0000oj1OX?nPGj002_nPGj000ol0003oBKI9odVfB@02odVfB@?o00001OlfbCH00ol0003oDjaC
oe>/D`04oe>/D`04o`000?mbSG;oLXebog:=LPOo00001?mMXUd00ol0003oN8MhogR7N00>ogR7N003
o`000?n1OX7oPGj100OoPGj100?o0000okm0_ono@;l02Ono@;l00ol0003oiA[UonDJi@09onDJi@03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ogR7NomhQgP08omhQgP;o00001?o;=</00ol0003oX5nP
oj1OX00;oj1OX003o`000?m9]TWoBKI900GoBKI90ol00003ocK9=P04o`000?mC[5?oDjaCoe>/D`Ko
00003?mMXUd00ol0003oN8MhogR7N00=ogR7N003o`000?n1OX7oPGj100OoPGj100?o0000okm0_ono
@;l02_no@;l00ol0003oiA[UonDJi@08onDJi@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omhQgP?o000000?obcC;o`000?nPGj00
3?nPGj000ol0003oBKI9odVfB@08odVfB@?o000000Co=/Tfo`000?l0003o00000_n4Nh@00ol0003o
GJ9MoefRG@0=oefRG@03o`000?mhQgSoN8Mh00coN8Mh00?o0000oh5nPOn1OX402?n1OX400ol0003o
_d2ookm0_`0;okm0_`03o`000?oU6^GoiA[U00KoiA[U00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
gR7N00?o0000oj1OX?nPGj003?nPGj000ol0003oBKI9odVfB@0;odVfB@03o`000?n4NhCoQ7^400?o
Q7^400?o0000oefRGOmMXUd03?mMXUd00ol0003o@ka3o`00000=ogR7N003o`000?n1OX7oPGj100So
PGj100?o0000okm0_ono@;l03?no@;l3o`0000GoiA[U00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oN8MkogR7N00cogR7N00?o0000oj1OX?nPGj003?nPGj000ol0003oBKI9odVfB@0:odVfB@03o`00
0?n4NhCoQ7^400GoQ7^400?o0000oefRGOmMXUd02_mMXUd01?l0003o@ka3od>l@om3_4<2o`0000[o
N8Mh00?o0000oh5nPOn1OX402On1OX400ol0003o_d2ookm0_`0<okm0_`03o`000?oZ5N[ojQGZ00?o
000000?oiA[Uo`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oN8MkogR7N00_ogR7N00?o0000oj1OX?nPGj00
3?nPGj000ol0003oBKI9odVfB@09odVfB@03o`000?n4NhCoQ7^400KoQ7^400?o0000oefRGOmMXUd0
2OmMXUd00ol0003o@ka3od>l@`02od>l@`03o`000?n2OH;o000000;o00001omhQgP00ol0003oPGj1
oh5nP@09oh5nP@03o`000?no@;oo_d2o00_o_d2o00?o0000onXEj_oZ5NX01?oZ5NX00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omhQg_oN8Mh02ooN8Mh00ol0003oX5nPoj1OX00;oj1OX003o`000?m9
]TWoBKI900SoBKI900?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oGJ9MoefRG@08oefRG@03o`000?m3
_4?o@ka300?o@ka300?o0000oh9mP_n2OH800_n2OH82o`0000CoN8Mh00?o0000oh5nPOn1OX402_n1
OX400ol0003o_d2ookm0_`0:okm0_`03o`000?oZ5N[ojQGZ00GojQGZ00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oN8MkogR7N00[ogR7N0ol0000;oj1OX0Ko00001?m9]TT00ol0003oQ7^4ohAkQ008
ohAkQ003o`000?mMXUgoGJ9M00OoGJ9M00?o0000od>l@om3_4<00om3_4<00ol0003oPWf2oh9mPP05
oh9mPP?o000000?oN8Mho`000?n1OX402on1OX400ol0003o_d2ookm0_`09okm0_`03o`000?oZ5N[o
jQGZ00OojQGZ00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oN8MkogR7N00WogR7N00?o0000ojiA
[_n^DJh01?l00006oj1OX003o`000?nFJIKoUVVF00CoUVVF1?l0000<ohAkQ003o`000?mMXUgoGJ9M
00GoGJ9M00?o0000od>l@om3_4<01?m3_4<00ol0003oPWf2oh9mPP08oh9mPP03o`000?n1OX7oPGj1
00_oPGj100?o0000okm0_ono@;l02?no@;l00ol0003ojQGZonXEjP08onXEjPGo00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oN8MkogR7N00OogR7N00?o0000ojiA[_n^DJh01On^DJh3o`0000;oX5nP00?o0000oiIYU_nF
JIH02?nFJIH00ol0003oQ7^4ohAkQ00:ohAkQ003o`000?mMXUgoGJ9M00CoGJ9M00?o0000od>l@om3
_4<01Om3_4<00ol0003oPWf2oh9mPP08oh9mPP03o`000?n1OX7oPGj100WoPGj11?l00008okm0_`03
o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ogR7N
omhQgP05omhQgP03o`000?n^DJko[U6^00Wo[U6^0_l0000<oiIYUP03o`000?n4NhCoQ7^400WoQ7^4
00?o0000oefRGOmMXUd00omMXUd00ol0003o@ka3od>l@`05od>l@`03o`000?n2OH;oPWf200[oPWf2
00?o0000oh5nPOn1OX401?n1OX44o`0000Co/4n`00?o0000okm0_ono@;l01?no@;l00ol0003ojQGZ
onXEjP0:onXEjP03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oN8MkogR7N00?ogR7N00?o0000ojiA[_n^DJh02on^
DJh00ol0003oUVVFoiIYUP0:oiIYUP03o`000?n4NhCoQ7^400WoQ7^400?o0000oefRGOmMXUd00_mM
XUd00ol0003o@ka3od>l@`06od>l@`03o`000?n2OH;oPWf200[oPWf200?o0000oh5nPOn1OX401?l0
0009ok1?/0Ko00003?oZ5NX00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omhQg_oN8MkogR7N0_l0
000=ojiA[P03o`000?nFJIKoUVVF00[oUVVF00?o0000ohAkQ?n4Nh@02On4Nh@01Ol0003oGJ9MoefR
GOmMXUgo000000Wo@ka300?o0000oh9mP_n2OH802on2OH82o`0000go/4n`00?o0000on<LhooS7><0
0_oS7><00ol0003ojQGZonXEjP0:onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ogR7No`00
0002onDJi@;o00002on^DJh00ol0003oUVVFoiIYUP0;oiIYUP03o`000?n4NhCoQ7^400WoQ7^400?o
0000oefRGOl000002Om3_4<00ol0003oPWf2oh9mPP0<oh9mPP03o`000?n`Ck3o/4n`00co/4n`00?o
0000on<LhooS7><00ooS7><00ol0003ojQGZonXEjP09onXEjP03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiA[UonDJi@03onDJi@;o00002_n^DJh00ol0003oUVVFoiIYUP0:oiIYUP03o`000?n4NhCo
Q7^400SoQ7^41Ol00008od>l@`03o`000?n2OH;oPWf200coPWf200?o0000ok1?/?n`Ck002on`Ck00
0ol0003ohacSon<Lh`05on<Lh`03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooU6^D2o`0000So[U6^00?o0000oiIYU_nFJIH02_nFJIH00ol0003oQ7^4ohAkQ007ohAk
Q003o`000?mcS7?oLhac00?oLhac0ol00005od>l@`03o`000?n2OH;oPWf200_oPWf200?o0000ok1?
/?n`Ck003?n`Ck000ol0003ohacSon<Lh`06on<Lh`03o`000?oZ5N[ojQGZ00OojQGZ00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ol0oco000000WoiA[U00?o0000ojiA[_n^DJh01On^DJh2o`0000co
UVVF00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003oLhacog><L`07og><L`?o000000?o@ka3o`000?n2
OH803On2OH800ol0003o/4n`ok1?/00<ok1?/003o`000?oS7>?ohacS00KohacS00?o0000onXEj_oZ
5NX01_oZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo`3o003o`000?oU6^GoiA[U00OoiA[U
0_l00004ojiA[P03o`000?nkA;_o^dBk00;o00002_nFJIH00ol0003oQ7^4ohAkQ003ohAkQ0;o0000
3OmcS7<2o`0000goPWf20ol0000=ok1?/003o`000?oS7>?ohacS00OohacS00?o0000onXEj_oZ5NX0
1OoZ5NX00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003oo0?loo`3o004oo`3o003o`000?oU6^GoiA[U00SoiA[U0_l0
00000on^DJko0000ok]4^`04ok]4^`03o`000?nFJIKoUVVF00OoUVVF00Co0000ohAkQ?n4NhCoQ7^4
0_l00002ohiaSP03o`000?mcS7?oLhac00coLhac3Ol00003oi9]TP03o`000?n`Ck3o/4n`00[o/4n`
00?o0000on<LhooS7><02?oS7><01?l0003ojQGZonXEj_oZ5NX4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ol0o`00ol0003oiA[U
onDJi@09onDJi@03o`000?nkA;_o^dBk00Go^dBk0_l00008oiIYUP03o`000?n4NhCo000000GoSW6>
00?o0000og><LomcS7<02omcS7<00ol0003oMhQgogN8M`09ogN8M`03o`000?nBKI;oTVfB00;oTVfB
0_l00009ok1?/003o`000?oS7>?ohacS00[ohacS0ol00004oo/4n`03o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo`3
o00:oo`3o003o`000?oU6^GoiA[U00SoiA[U00?o0000ok]4^onkA;/01onkA;/4o`0000?oUVVF0ol0
0007ohiaSP03o`000?mcS7?oLhac00[oLhac00?o0000ogN8MomgR7L02OmgR7L00ol0003oTVfBoi9]
TP04oi9]TP;o00001on`Ck000ol0003ohacSon<Lh`0:on<Lh`03o`000?ok1?_on`Ck00Gon`Ck00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?oU6^GoiA[U00OoiA[U00?o0000ok]4^onkA;/02?nkA;/0
1?l0003o^dBkok]4^onkA;/3o`0000;oZ5NX00?o0000ohiaS_n>LHh01_n>LHh00ol0003oLhacog><
L`08og><L`03o`000?mgR7OoMhQg00[oMhQg00?o0000oi9]T_nBKI801_nBKI800ol0003o/4n`ok1?
/004ok1?/003o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/01ook1?/00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onDJiOoU6^D01OoU6^D00ol0003o^dBkok]4^`08ok]4^`03o`000?nkA;_o
^dBk00Co^dBk00Go0000ojQGZ?nXEjSoZ5NXo`000008ohiaSP03o`000?mcS7?oLhac00OoLhac00?o
0000ogN8MomgR7L02_mgR7L00ol0003oTVfBoi9]TP07oi9]TP;o00001?n`Ck000ol0003ohacSon<L
h`08on<Lh`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onDJiOoU6^D00ooU6^D0
0ol0003o^dBkok]4^`08ok]4^`03o`000?nkA;_o^dBk00Co^dBk00?o0000ojQGZ?nXEjP00_nXEjP0
0ol0003oSW6>ohiaSP07ohiaSP03o`000?mcS7?oLhac00KoLhac00?o0000ogN8MomgR7L02_mgR7L0
0ol0003oTVfBoi9]TP09oi9]TP05o`000?n`Ck3o/4n`ok1?/?l000002OoS7><00ol0003on`Ckoo/4
n`0;oo/4n`03o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_o^dBk00?o0000ok]4^onkA;/01?nkA;/00ol0003oZ5NXojQGZ003
ojQGZ003o`000?n>LHkoSW6>00OoSW6>00?o0000og><LomcS7<01OmcS7<00ol0003oMhQgogN8M`0:
ogN8M`03o`000?nBKI;oTVfB00WoTVfB1?l00009on<Lh`03o`000?ok1?_on`Ck00gon`Ck0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o[5>_ojaC[
on/Djol000002_nkA;/00ol0003o^dBkok]4^`05ok]4^`03o`000?nXEjSoZ5NX00?oZ5NX00?o0000
ohiaS_n>LHh02?n>LHh00ol0003oLhacog><L`04og><L`03o`000?mgR7OoMhQg00WoMhQg00?o0000
oi9]T_nBKI802?nBKI82o`0000?ohQgR00?o0000on<LhooS7><01_oS7><00ol0003on`Ckoo/4n`0>
oo/4n`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000on/Djoo[5>/00oo[5>/00ol0003o^dBkok]4^`06ok]4^`03o`000?nkA;_o^dBk
00Go^dBk00?o0000ojQGZ?nXEjP01?nXEjP00ol0003oSW6>ohiaSP09ohiaSP03o`000?mcS7?oLhac
00;oLhac00?o0000ogN8MomgR7L02_mgR7L00ol0003oTVfBoi9]TP06oi9]TP;o00001_oR7N88o`00
017on`Ck00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?nkA;_o^dBk00Go^dBk00?o0000ok]4^onk
A;/01OnkA;/00ol0003oZ5NXojQGZ005ojQGZ003o`000?n>LHkoSW6>00WoSW6>00Go0000og><Lomc
S7?oLhaco`00000<ogN8M`03o`000?nBKI;oTVfB00CoTVfB0_l00008on8MhP03o`000?ok1?_on`Ck
00Con`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o[5>_ojaC[00OojaC[00?o0000ok]4^onk
A;/00onkA;/00ol0003o^dBkok]4^`06ok]4^`03o`000?nXEjSoZ5NX00GoZ5NX00?o0000ohiaS_n>
LHh02_n>LHh00ol0003oLhaco`000004o`0000WoMhQg00?o0000oi9]T_nBKI800_nBKI82o`0000[o
hQgR00?o0000oo/4nook1?/01Ook1?/00ol0003on`Ckoo/4n`0<oo/4n`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojaC[on/Dj`07on/Dj`03o`00
0?nkA;_o^dBk00;o^dBk00?o0000ok]4^onkA;/01_nkA;/00ol0003oZ5NXojQGZ007ojQGZ0;o0000
2on>LHh00ol0003o]DZeokE:]@03okE:]@Oo00000_mgR7L00ol0003oTVfBoi9]TP02o`0000_ohQgR
00?o0000oo/4nook1?/01ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on/Djoo[5>/02Oo[
5>/01Ol0003o^dBkok]4^onkA;_o000000So^dBk00?o0000ojQGZ?nXEjP01onXEjP00ol0003oeB[E
o`000002o`0000SoSW6>00?o0000okE:]OneB[D02_neB[D5o`0000gohQgR00?o0000oo/4nook1?/0
2?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<on/Dj`03o`000?nkA;_o000000Wo^dBk00?o
0000ojQGZ?nXEjP01_nXEjP00ol0003oeB[EomDZe@03omDZe@?o00001?n>LHh00ol0003o]DZeokE:
]@0=okE:]@03o`000?oR7N;ohQgR00gohQgR00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4
n`06oo/4n`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000ool0o`2o`0000_ojaC[00?o0000ok]4^onkA;/01onkA;/00ol0003oZ5NXojQGZ007
ojQGZ003o`000?oE:]GoeB[E00KoeB[E0ol000000on>LHko0000okE:]@0>okE:]@03o`000?oR7N;o
hQgR00cohQgR00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009on/D
j`03o`000?nkA;_o^dBk00;o^dBk1_l00008ojQGZ003o`000?oE:]GoeB[E00[oeB[E00?o0000okE:
]OneB[D03oneB[D00ol0003ohQgRon8MhP0:on8MhP;o00003Ook1?/00ol0003on`Ckoo/4n`03oo/4
n`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007on/Dj`Go00001_oX5nP00ol0003oZ5NXojQGZ005ojQGZ003o`000?oE:]GoeB[E00[o
eB[E00?o0000okE:]OneB[D03oneB[D00ol0003ohQgRon8MhP07on8MhP?o000000?on`Cko`000?ok
1?/03Ook1?/01Ol0003on`Ckoo/4nook1?_o000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005on/Dj`03o`000?oX5nSoj1OX00Woj1OX00?o0000ojQGZ?nX
EjP00onXEjP00ol0003oeB[EomDZe@0;omDZe@03o`000?neB[Go]DZe00oo]DZe00?o0000on8Mh_oR
7N801OoR7N82o`0000Gon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Cko`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?ojaC[o`000?l00000
3OoX5nP00ol0003oZ5NXojQGZ002ojQGZ003o`000?oE:]GoeB[E00_oeB[E5?l00004on8MhP;o0000
2?ok1?/00ol0003on`Ckoo/4n`0;oo/4n`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003oo0?lo`00000>onPGj004o`000?nXEjSoZ5NXo`0000koeB[E
00?o0000on/Djoo[5>/04?o[5>/00ol0003ohQgRo`000002o`0000[on`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000003_oX5nP00ol0003oZ5NXo`00000>omDZe@03o`00
0?o[5>_ojaC[017ojaC[00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo`3o?ol0o`00_ol0o`00ol0003oj1OXonPGj00=onPGj003o`000?oE:]GoeB[E00WoeB[E1Ol0
000Bon/Dj`;o00003ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003oj1OXonPGj00<onPGj003o`000?oE:]GoeB[E00;oeB[E1ol00004oo/4n`03o`000?o[5>_o
jaC[00oojaC[00?o0000oo/4nol000004?ok1?/00ol0003on`Ckoo/4n`03oo/4n`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo0?loo`3o006oo`3
o003o`000?oX5nSoj1OX00coj1OX1?l0000<oo/4n`03o`000?o[5>_ojaC[00cojaC[0_l00003oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/00_ok1?/00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Oo
o0?l00?o0000onPGj?oX5nP03?oX5nP00ol0003on`Ckoo/4n`0=oo/4n`03o`000?o[5>_ojaC[00_o
jaC[00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4n`04o`000?ok1?_on`Cko`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`02Ool0o`00ol0003oj1OXonPGj00:onPGj003o`000?ok1?_on`Ck00kon`Ck00?o0000on/Djoo[
5>/02Oo[5>/2o`0000Oon`Ck00?o0000oo/4nook1?/03Ook1?/3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000onPGj?oX5nP02_oX5nP00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?o[5>_ojaC[00KojaC[0_l0000:oo/4n`03o`000?ok1?_on`Ck00_on`Ck
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003oo0?l00goo0?l3?l0
000Aoo/4n`?o00001_o[5>/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Won`Ck0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo/4nook1?/02?ok1?/0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000oo[5>/2o`0000kon`Ck00?o
0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000on/Djol000004Ook1?/00ol0003on`Ckoo/4n`04oo/4n`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00[on`Ck00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4
nook1?/00ook1?/00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ok1?_on`Ck00con`Ck00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ook1?/00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003on`Ckoo/4n`0>oo/4n`04o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0<oo/4n`Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ok1?/3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo/4n`?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01?l00?l6oooo00Wo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Ko003o0oooo`03o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`;oool03Ol00?l2oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000:o`00o`;oool03_l00?l00oooo`3o003oo`00o`02o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000:o`00o`;oool03_l00?l2oooo00?o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
2_l00?l2oooo00ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool02_l00?l2oooo00ko003o0_ooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool03Ol00?l3oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`0<o`00o`?oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
000:o`00o`;oool02_l00?l5oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3
oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`07o`00o`Koool01Ol00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`;oool01ol00?l4oooo00Oo003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool02_l00?l2oooo00So003o00?oool0o`00ool00?l01ol00?l2oooo00Ko
003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1_l00?l2oooo01So003o0_ooo`0:o`00o`;oool02?l00?l00oooo`3o003oo`00o`08o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o0_ooo`08o`00o`03oooo0?l0
0?oo003o00So003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001Wo`00o`7ooooo001W
o`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Go003o1?ooo`09
o`00o`Koool01Ol00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo
0003o`00ooooo`3oool000Goool00ol00?l5oooo02;o003o0_ooo`09o`00o`Ooool01Ol00?l4oooo
07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(160) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.986 .014 .986 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.986 .014 .986 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.986 .014 .986 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.985 .015 .985 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.905 .095 .905 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.984 .016 .984 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.901 .099 .901 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.916 .084 .916 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.875 .125 .875 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.981 .019 .981 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.827 .173 .827 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.985 .015 .985 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.746 .254 .746 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.733 .267 .733 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.987 .013 .987 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.651 .349 .651 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.789 .211 .789 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.979 .021 .979 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.982 .018 .982 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.89 .11 .89 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.479 .521 .479 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.664 .336 .664 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.533 .467 .533 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.521 .479 .521 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.608 .392 .608 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.839 .161 .839 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.875 .125 .875 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.986 .014 .986 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.539 .461 .539 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.771 .229 .771 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.417 .583 .417 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.846 .154 .846 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.802 .198 .802 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.985 .015 .985 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.706 .294 .706 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.744 .256 .744 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.634 .366 .634 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.845 .155 .845 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.558 .442 .558 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.988 .012 .988 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.894 .106 .894 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.564 .436 .564 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.428 .572 .428 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.407 .593 .407 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.903 .097 .903 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.924 .076 .924 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.694 .306 .694 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.985 .015 .985 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.541 .459 .541 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.469 .531 .469 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.538 .462 .538 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.565 .435 .565 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.311 .689 .311 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.515 .485 .515 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.63 .37 .63 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.986 .014 .986 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.642 .358 .642 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.555 .445 .555 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.894 .106 .894 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.139 .861 .139 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.747 .253 .747 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.719 .281 .719 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.537 .463 .537 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.248 .752 .248 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.321 .679 .321 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.113 .887 .113 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.17 .83 .17 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.459 .541 .459 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.278 .722 .278 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.376 .624 .376 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.747 .253 .747 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.407 .593 .407 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.437 .563 .437 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.592 .408 .592 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.912 .088 .912 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.985 .015 .985 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.23 .77 .23 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.314 .686 .314 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.287 .713 .287 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.984 .016 .984 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.626 .374 .626 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.393 .607 .393 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.209 .791 .209 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.197 .803 .197 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.478 .522 .478 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.306 .694 .306 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.895 .105 .895 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.393 .607 .393 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.122 .878 .122 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.67 .33 .67 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.31 .69 .31 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.249 .751 .249 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.509 .491 .509 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.845 .155 .845 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.457 .543 .457 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.125 .875 .125 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.25 .75 .25 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.486 .514 .486 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.3 .7 .3 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.312 .688 .312 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.842 .158 .842 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.275 .725 .275 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.213 .787 .213 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.169 .831 .169 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.983 .017 .983 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.177 .823 .177 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.352 .648 .352 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.224 .776 .224 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.565 .435 .565 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.423 .577 .423 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.983 .017 .983 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.469 .531 .469 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.366 .634 .366 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.392 .608 .392 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.443 .557 .443 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.298 .702 .298 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.248 .752 .248 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.344 .656 .344 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.444 .556 .444 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.984 .016 .984 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.717 .283 .717 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.409 .591 .409 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.528 .472 .528 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.246 .754 .246 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.891 .109 .891 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.085 .915 .085 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.273 .727 .273 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.263 .737 .263 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.448 .552 .448 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.627 .373 .627 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.181 .819 .181 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.985 .015 .985 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.338 .662 .338 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.72 .28 .72 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.924 .076 .924 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.498 .502 .498 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.464 .536 .464 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.389 .611 .389 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.842 .158 .842 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.186 .814 .186 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.321 .679 .321 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.43 .57 .43 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.67 .33 .67 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.179 .821 .179 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.316 .684 .316 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.418 .582 .418 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.451 .549 .451 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.984 .016 .984 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.24 .76 .24 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.984 .016 .984 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.886 .114 .886 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.492 .508 .492 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.431 .569 .431 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.29 .71 .29 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.589 .411 .589 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.342 .658 .342 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.891 .109 .891 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.476 .524 .476 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.507 .493 .507 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.509 .491 .509 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.502 .498 .502 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.749 .251 .749 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.465 .535 .465 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.29 .71 .29 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.171 .829 .171 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.201 .799 .201 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.419 .581 .419 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.698 .302 .698 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.985 .015 .985 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.891 .109 .891 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.358 .642 .358 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.21 .79 .21 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.454 .546 .454 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.748 .252 .748 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.503 .497 .503 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.984 .016 .984 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.409 .591 .409 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.754 .246 .754 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.895 .105 .895 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.985 .015 .985 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.313 .687 .313 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.378 .622 .378 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.885 .115 .885 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.407 .593 .407 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.475 .525 .475 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.712 .288 .712 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.384 .616 .384 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.56 .44 .56 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.782 .218 .782 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.601 .399 .601 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.59 .41 .59 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.705 .295 .705 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.413 .587 .413 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.919 .081 .919 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.69 .31 .69 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.526 .474 .526 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.489 .511 .489 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.985 .015 .985 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.703 .297 .703 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.418 .582 .418 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.984 .016 .984 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.902 .098 .902 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.773 .227 .773 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.901 .099 .901 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.422 .578 .422 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.881 .119 .881 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.681 .319 .681 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.569 .431 .569 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.985 .015 .985 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.568 .432 .568 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.502 .498 .502 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.985 .015 .985 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.747 .253 .747 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.981 .019 .981 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.986 .014 .986 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.639 .361 .639 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.983 .017 .983 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.503 .497 .503 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.984 .016 .984 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.493 .507 .493 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.748 .252 .748 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.574 .426 .574 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.867 .133 .867 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.88 .12 .88 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.691 .309 .691 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.644 .356 .644 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.685 .315 .685 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.812 .188 .812 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.871 .129 .871 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.797 .203 .797 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.81 .19 .81 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.982 .018 .982 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.665 .335 .665 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.888 .112 .888 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.983 .017 .983 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.917 .083 .917 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.905 .095 .905 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.668 .332 .668 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.903 .097 .903 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.886 .114 .886 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.7 .3 .7 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.983 .017 .983 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.981 .019 .981 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.986 .014 .986 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.885 .115 .885 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.985 .015 .985 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.985 .015 .985 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.983 .017 .983 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.984 .016 .984 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.983 .017 .983 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.984 .016 .984 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003on`Ckoo/4n`05oo/4n`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ook1?/3o`000003o`00ool0003on`Ck00kon`Ck00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4
nook1?/03ook1?/01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?ok1?_on`Ck013on`Ck0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?on`Ck0_l0000@oo/4n`03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo/4n`?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ol0ocoo0?loo`3o?l000004Ook
1?/01?l0003oi1_Ton@Ki?l0000>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo/4n`?o000000?o003oo`000?ok1?/03ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?ok
1?_on`Ck00gon`Ck00?o0000on@Ki?oT6n@00_oT6n@00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000
oo`3o?ol0o`01?ol0o`00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oT6nCoi1_T00?oi1_T00?o0000
oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?ok1?_on`Ck
00[on`Ck00?o0000on@Ki?oT6n@01OoT6n@00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo/4nook1?/03ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo/4nook1?/02Ook1?/00ol0003oi1_Ton@Ki006on@Ki003
o`000?ok1?_on`Ck00Kon`Ck00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003on`Ck
oo/4n`0>oo/4n`;o00004?ok1?/00ol0003oo0?loo`3o007oo`3o003o`000?ok1?_on`Ck00Oon`Ck
00?o0000on@Ki?oT6n@02?oT6n@00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oU6^Go0000013on`Ck00?o0000oo`3o?ol0o`02?ol
0o`9o`0000coi1_T00Co0000oo/4nook1?_on`Ck0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ok1?_on`Ck00con`Ck0_l00003onDJi@03o`000?ok
1?_on`Ck00con`Ck00?o0000oo`3o?ol0o`02Ool0o`00ol0003ohQgRon8MhP05on8MhP03o`000?oT
6nCoi1_T00_oi1_T0ol00003on8MhP03o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kon`Ck00?o0000
onDJiOoU6^D00ooU6^D00ol0003on`Ckoo/4n`0;oo/4n`;o00002ool0o`00ol0003ohQgRon8MhP06
on8MhP03o`000?oT6nCoi1_T00[oi1_T00?o0000on8Mh_oR7N801?oR7N800ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oQ7^7ohAkQon4Nh@;o00002_ok1?/2o`000003on4NhOl0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo/4nook1?/02ook1?/00ol0003oiA[UonDJi@05onDJi@03o`000?ok1?_o
n`Ck00Won`Ck00?o0000on@Ki?l000002ool0o`00ol0003ohQgRon8MhP06on8MhP03o`000?oT6nCo
i1_T00Woi1_T00?o0000on8Mh_oR7N801_oR7N800ol0003on`Ckoo/4n`08oo/4n`03o`000?oQ7^7o
hAkQ00CohAkQ0_l00005oo/4n`?o00001?oQ7^400ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00Son`Ck0_l00008onDJi@03o`000?ok1?_on`Ck00Oon`Ck0_l00003on@K
i003o`000?ol0ocoo0?l00Ooo0?l00?o0000on8Mh_oR7N801ooR7N800ol0003oi1_Ton@Ki009on@K
i003o`000?oR7N;ohQgR00OohQgR00?o0000oo/4nook1?/01Ook1?/2o`0000WohAkQ0_l000000ook
1?_o0000o`000007on4Nh@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Son`Ck00?o0000onDJiOoU
6^D02?oU6^D00ol0003on`Ckoo/4n`06oo/4n`03o`000?oT6nCoi1_T00?oi1_T00?o0000oo`3o?ol
0o`01ool0o`00ol0003ohQgRon8MhP08on8MhP03o`000?oT6nCoi1_T00Ooi1_T00?o0000on8Mh_oR
7N802OoR7N800ol0003on`Ckoo/4n`03oo/4n`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000on4NhOoQ
7^401ooQ7^400ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003oi1_To`000005oo/4n`;o00002ooU6^D2o`0000Kon`Ck
00?o0000on@Ki?oT6n@01OoT6n@00ol0003oo0?loo`3o006oo`3o003o`000?oR7N;ohQgR00SohQgR
00?o0000on@Ki?oT6n@01_oT6n@00ol0003ohQgRon8MhP0;on8MhP05o`000?ok1?_on`Ckoo/4nol0
00003_oQ7^400ol0003ohAkQon4Nh@08on4Nh@03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oT6nCoi1_Ton@Ki?l0
00000ook1?/00ol0003oiA[UonDJi@0:onDJi@04o`000?oH9mSof2OHo`0000?on`Ck0_l00008on@K
i003o`000?ol0ocoo0?l00Koo0?l00?o0000on8Mh_oR7N802OoR7N800ol0003oi1_Ton@Ki005on@K
i003o`000?oR7N;ohQgR00cohQgR00?o0000oo/4nol000003ooQ7^400ol0003ohAkQon4Nh@08on4N
h@03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oi1_Ton@Ki003on@Ki003o`000?ok1?_o000000_o
iA[U0_l00004omPWf003o`000?ok1?_o000000_oi1_T00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
hQgRon8MhP09on8MhP03o`000?oT6nCoi1_T00Coi1_T00?o0000on8Mh_oR7N803_oR7N800ol0003o
hAkQon4Nh@0>on4Nh@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000on@Ki?oT6n@0
1?oT6n@00ol0003oiA[UonDJi@09onDJi@03o`000?oH9mSof2OH00Gof2OH00?o0000on@Ki?oT6n@0
2_oT6n@00ol0003oo0?loo`3o005oo`3o003o`000?oR7N;ohQgR00[ohQgR00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003ohQgRon8MhP0>on8MhP03o`000?oQ7^7ohAkQ00gohAkQ00?o0000on4NhOoQ7^40
2_oQ7^400ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oi1_Ton@K
i005on@Ki003o`000?oU6^GoiA[U00OoiA[U0_l00008omPWf003o`000?oT6nCoi1_T00_oi1_T00?o
0000oo`3o?ol0o`01?ol0o`00ol0003ohQgRon8MhP0:on8MhP04o`000?oT6nCoi1_Ton@Ki0?o0000
3ooR7N800ol0003ohAkQon4Nh@0>on4Nh@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oT6nCoi1_T00Ooi1_T00?o0000onDJiOoU6^D01?oU6^D2o`0000_of2OH1?l0
0009on@Ki003o`000?ol0ocoo0?l00?oo0?l00?o0000on8Mh_oR7N802ooR7N801?l0003oi1_To`00
0?l00003okm0_`;o00003?oR7N82o`00013ohAkQ00?o0000on4NhOoQ7^402ooQ7^400ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003oi1_T
on@Ki007on@Ki003o`000?oU6^GoiA[U00?oiA[U00?o0000omPWf?oH9mP02ooH9mP01?l0003o]dRg
okM8]ongB;L5o`0000Goi1_T00?o0000oo`3o?ol0o`00_ol0o`00ol0003ohQgRon8MhP0<on8MhP03
o`000?no@;oo_d2o00Go_d2o0_l00008on8MhP;o00000_n`Ck000ol0003ohAkQon4Nh@0=on4Nh@03
o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oo/4nook1?/03?ok1?/00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003oi1_Ton@Ki009on@Ki003o`000?oU6^GoiA[U00;o0000
3OoH9mP00ol0003o]dRgokM8]`07okM8]`Ko00000_ol0o`4o`0000gohQgR00?o0000okm0_ono@;l0
1ono@;l2o`0000GohQgR00?o0000ok1?/?n`Ck000on`Ck000ol0003ohAkQon4Nh@0<on4Nh@03o`00
0?oQ7^7ohAkQ00cohAkQ00?o0000oo/4nook1?/02_ok1?/00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oT6nCoi1_T00Woi1_T00?o
0000onDJiOl000003ooH9mP00ol0003o]dRgokM8]`0<okM8]`?o00001?oG:=L3o`0000WohQgR00?o
0000okm0_ono@;l02_no@;l2o`000003on8Mh_l0003o000000Oo/4n`00?o0000on4NhOoQ7^402ooQ
7^400ol0003ohAkQon4Nh@0<on4Nh@03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000
omPWf?oH9mP03_oH9mP00ol0003o]dRgokM8]`0=okM8]`03o`000?oG:=OoebSG00KoebSG0ol00005
on8MhP03o`000?no@;oo_d2o00go_d2o00?o0000ok1?/?n`Ck002?n`Ck000ol0003ohAkQon4Nh@09
on4Nh@03o`000?oQ7^7ohAkQ00gohAkQ00Co0000oo/4nook1?_on`Ck1Ol00003onLHi`03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
on@Ki?oT6n@02ooT6n@2o`0000oof2OH00?o0000okM8]ongB;L03OngB;L00ol0003oebSGomLXe`0:
omLXe`?o000000?ohQgRo`000?no@;l03ono@;l00ol0003o/4n`ok1?/009ok1?/003o`000?oQ7^7o
hAkQ00SohAkQ00?o0000on4NhOoQ7^403_oQ7^43o`0000SoiaSW00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oT6nCoi1_T00Soi1_T0ol000000onh
AkSo0000omPWf00>omPWf003o`000?ngB;Oo]dRg00go]dRg00?o0000omLXeooG:=L03OoG:=L00ol0
003o_d2ookm0_`0?okm0_`03o`000?n`Ck3o/4n`00[o/4n`2ol0000;on4Nh@Go00003?oW6>L00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oi1_To`000?ol0oco0000
00Soi1_T0ol00005okQ7^003o`000?oH9mSof2OH00cof2OH00?o0000okM8]ongB;L03OngB;L00ol0
003oebSGomLXe`0=omLXe`;o00004?no@;l00ol0003o/4n`ok1?/00:ok1?/003o`000?n^DJko[U6^
00Oo[U6^00?o0000on4NhOoQ7^400_oQ7^47o`0000Co/4n`00?o0000onLHiooW6>L02_oW6>L00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003oi1_Ton@Ki?oT6n@2o`00
00Goi1_T0ol00009okQ7^0;o00002ooH9mP00ol0003o]dRgokM8]`0=okM8]`03o`000?oG:=OoebSG
00goebSG00Co0000okm0_ono@;oo00003ono@;l00ol0003o/4n`ok1?/009ok1?/003o`000?n^DJko
[U6^00Wo[U6^1?l0000;ok1?/003o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000on@Ki?oT6n@01?oT6n@00ol0003oi1_To`000002o`00
00co^4Nh00Co0000oj1OX?l0003o00002OoH9mP00ol0003o]dRgokM8]`0=okM8]`03o`000?oG:=Oo
ebSG00goebSG00Go0000okm0_ono@;oo_d2oo`00000=okm0_`03o`000?n`Ck3o/4n`00[o/4n`00?o
0000ojiA[_n^DJh02On^DJh00ol0003o/4n`ok1?/00<ok1?/003o`000?oW6>OoiaSW00[oiaSW00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000on@Ki?oT6n@01_oT6n@0
0ol0003o^4NhokQ7^00<okQ7^003o`000?nPGj3oX5nP00;oX5nP0_l00007omPWf003o`000?ngB;Oo
]dRg00co]dRg00?o0000omLXeooG:=L03OoG:=L00ol0003o_d2ookm0_`03okm0_`03o`000?no@;oo
_d2o00[o_d2o00?o0000ok1?/?n`Ck002_n`Ck000ol0003o[U6^ojiA[P09ojiA[P03o`000?n`Ck3o
/4n`00co/4n`00?o0000onLHiooW6>L02ooW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oi1_Ton@Ki006on@Ki003o`000?nhAkSo^4Nh00_o^4Nh00?o0000oj1O
X?nPGj001OnPGj000ol0003of2OHomPWf003omPWf003o`000?ngB;Oo]dRg00go]dRg00?o0000omLX
eooG:=L03OoG:=L00ol0003o_d2ookm0_`04okm0_`03o`000?no@;oo_d2o00Wo_d2o00?o0000ok1?
/?n`Ck002On`Ck000ol0003o[U6^ojiA[P0:ojiA[P03o`000?n`Ck3o/4n`00co/4n`00?o0000onLH
iooW6>L02ooW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
i1_Ton@Ki007on@Ki003o`000?nhAkSo^4Nh00_o^4Nh00?o0000oj1OX?nPGj001_nPGj02o`0000?o
f2OH00?o0000okM8]ongB;L03OngB;L00ol0003oebSGomLXe`0<omLXe`03o`000?no@;oo_d2o00Ko
_d2o00?o0000okm0_ono@;l02?no@;l00ol0003o/4n`ok1?/009ok1?/003o`000?n^DJko[U6^00[o
[U6^00?o0000ok1?/?n`Ck003?n`Ck000ol0003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000on@Ki?oT6n@02?oT6n@00ol0003o^4NhokQ7^00:okQ7^003o`00
0?nPGj3oX5nP00WoX5nP0_l000000ooH9mSo0000okM8]`0<okM8]`?o00003_oG:=L00ol0003o_d2o
okm0_`07okm0_`03o`000?no@;oo_d2o00Oo_d2o00?o0000ok1?/?n`Ck002On`Ck000ol0003o[U6^
ojiA[P0;ojiA[P03o`000?n`Ck3o/4n`00co/4n`00?o0000onLHiooW6>L02_oW6>L00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000on@Ki?oT6n@02_oT6n@00ol0003o^4NhokQ7
^009okQ7^003o`000?nPGj3oX5nP00_oX5nP00?o0000okM8]ongB;L02_ngB;L2o`0000?oX5nP00?o
0000omLXeooG:=L02_oG:=L00ol0003o_d2ookm0_`09okm0_`03o`000?no@;oo_d2o00Ko_d2o00?o
0000ok1?/?n`Ck002?n`Ck000ol0003o[U6^ojiA[P0<ojiA[P03o`000?n`Ck3o/4n`00co/4n`00?o
0000onLHiooW6>L02_oW6>L00ol0003oo0?loo`3o004oo`3o0Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000okQ7^?nhAkP02?nhAkP0
0ol0003oX5nPoj1OX00<oj1OX003o`000?ngB;Oo]dRg00So]dRg0_l00006oj1OX0;o00002_oG:=L0
0ol0003o_d2ookm0_`0:okm0_`03o`000?no@;oo_d2o00Go_d2o00?o0000ok1?/?n`Ck002?n`Ck00
0ol0003o[U6^ojiA[P0<ojiA[P03o`000?n`Ck3o/4n`00co/4n`00?o0000onLHiooW6>L02ooW6>L0
0ol0003oo0?lo`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
on@Ki003o`000?nhAkSo^4Nh00Oo^4Nh00?o0000oj1OX?nPGj003_nPGj000ol0003o]dRgokM8]`04
okM8]`?o00002_nPGj000ol0003oebSGomLXe`07omLXe`03o`000?no@;oo_d2o00_o_d2o00?o0000
okm0_ono@;l00ono@;l00ol0003o/4n`ok1?/009ok1?/003o`000?n^DJko[U6^00co[U6^00?o0000
ok1?/?n`Ck003?n`Ck000ol0003oiaSWonLHi`0;onLHi`;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oi1_Ton@Ki00<on@Ki003o`000?nhAkSo^4Nh00Oo^4Nh00?o0000oj1OX?nPGj003onPGj001?l0
003o]dRgokM8]ongB;L2o`0000koX5nP0_l00006omLXe`03o`000?no@;oo_d2o00go_d2o00?o0000
okm0_ono@;l00_no@;l00ol0003o/4n`ok1?/008ok1?/003o`000?n^DJko[U6^00co[U6^0ol0000=
ok1?/003o`000?oW6>OoiaSW00_oiaSW00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooi1_T00?o0000okQ7^?nhAkP01_nhAkP00ol0003oX5nPoj1OX00@oj1OX0Co00004_nPGj000ol0
003oebSGomLXe`03omLXe`03o`000?no@;oo_d2o00ko_d2o00Go0000okm0_ono@;oo_d2oo`000005
ok1?/0Oo00003?n^DJh01Ol0003oP7n0oh1oP?n0Oh3o000000co/4n`00?o0000onLHiooW6>L02?oW
6>L3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooi1_T00?o0000okQ7^?nhAkP01_nhAkP00ol0003oX5nPoj1OX00=
oj1OX0?o000000CoNXEjo`000?l0003o00004onPGj02o`0000;oebSG00?o0000okm0_ono@;l04?no
@;l00ol0003o_d2oo`000006o`0000Oo/dbc00?o0000ojiA[_n^DJh02?n^DJh00ol0003oP7n0oh1o
P003oh1oP0;o00002?n`Ck03o`0000KoiaSW1?l00002on8MhP03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003ohacSo`000?ndBk@3o`0000goi1_T00?o0000okQ7^?nhAkP01?nhAkP00ol0003oX5nPoj1O
X00;oj1OX0?o00000omjQGX01Ol0003oO8=lo`000?mhQgSo000001CoX5nP00?o0000omLXeol00000
4ono@;l00ol0003o/dbcok=</`0=ok=</`03o`000?n^DJko[U6^00Go[U6^0_l00008oh1oP003o`00
0?n`Ck3o/4n`00Go00000on_D:l00ol0003oiaSWonLHi`03o`0000OohQgR00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oS7>?ohacSo`0000Co]4^d0ol0000:on@Ki003o`000?nhAkSo^4Nh00?o^4Nh
00?o0000oj1OX?nPGj002OnPGj03o`0000GoNXEj00Co0000ogb3O?mlPgco00000_mhQgP00ol0003o
X5nPoj1OX00Boj1OX003o`000?no@;oo_d2o01;o_d2o00?o0000ok=</oncC;<03_ncC;<00ol0003o
[U6^ojiA[P03ojiA[P03o`000?n0Oh3oP7n000WoP7n00_l00009ojm@[`;o00002_oR7N800ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000on<LhooS7>?ohacSo`000007okA;]0;o00001ooT6n@5o`0000;o
^4Nh00?o0000oj1OX?nPGj001_nPGj03o`0000SoNXEj00Co0000ogb3O?mlPgco00000omhQgP00ol0
003oX5nPoj1OX00Aoj1OX003o`000?no@;oo_d2o017o_d2o00?o0000ok=</oncC;<04?ncC;<01Ol0
003o[U6^ojiA[_n^DJko000000coP7n000?o0000ojm@[on_D:l02?n_D:l00ol0003ohQgRon8MhP0:
on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CohacS00?o0000okA;]?ndBk@01ondBk@3o`00
0004on@Ki?l0003o0000o`0000GoY5^T0_l00006oj1OX0?o00002_mjQGX01Ol0003oO8=logb3O?ml
Pgco000000CoN8Mh00?o0000oj1OX?nPGj004?nPGj000ol0003o_d2ookm0_`0Aokm0_`03o`000?nc
C;?o/dbc017o/dbc00?o0000ojiA[_l000003On0Oh000ol0003o[e2_ojm@[`08ojm@[`03o`000?oR
7N;ohQgR00[ohQgR00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oS7>?ohacS00CohacS00?o0000
okA;]?ndBk@02_ndBk@00ol0003oY5^TojAKY008ojAKY003o`000?nPGj3oX5nP00?o00003OmjQGX0
1Ol0003oO8=logb3O?mlPgco000000GoN8Mh00?o0000oj1OX?nPGj003onPGj000ol0003o_d2ookm0
_`0Aokm0_`03o`000?ncC;?o/dbc01;o/dbc00?o0000oh1oP?n0Oh003?n0Oh000ol0003o[e2_ojm@
[`08ojm@[`03o`000?oR7N;ohQgR00_ohQgR00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000on<LhooS7><01OoS7><0
0ol0003o]4^dokA;]00:okA;]003o`000?nTFjCoY5^T00WoY5^T0_l0000?ogZ5NP03o`000?mlPgco
O8=l00;oO8=l00?o0000ogR7N?mhQgP01?mhQgP00ol0003oX5nPoj1OX00=oj1OX0?o00004Ono@;l0
0ol0003o/dbcok=</`0Cok=</`03o`000?n0Oh3oP7n000_oP7n000?o0000ojm@[on_D:l02On_D:l0
0ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo`3o0;o00002?oS7><0
0ol0003o]4^dokA;]00:okA;]003o`000?nTFjCoY5^T00WoY5^T00?o0000ogZ5N_mjQGX03OmjQGX0
0ol0003oO8=logb3O003ogb3O003o`000?mhQgSoN8Mh00GoN8Mh00?o0000oj1OX?nPGj002_nPGj02
o`0000?oZeB[00?o0000okm0_ono@;l03_no@;l00ol0003o/dbcok=</`0Cok=</`03o`000?n0Oh3o
P7n000_oP7n000?o0000ojm@[on_D:l02On_D:l00ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Goo0?l00?o0000on<LhooS7><01ooS7><2o`0000_o]4^d00?o0000ojAK
Y?nTFj@02onTFj@00ol0003oNXEjogZ5NP0<ogZ5NP03o`000?mlPgcoO8=l00?oO8=l00?o0000ogR7
N?mhQgP01_mhQgP00ol0003oX5nPoj1OX007oj1OX0;o00001_n[E:/2o`0000ko_d2o00?o0000ok=<
/oncC;<04oncC;<00ol0003oP7n0oh1oP00;oh1oP003o`000?n_D:oo[e2_00Wo[e2_00?o0000on8M
h_oR7N803?oR7N800ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo`3o?ol0ocoo0?lo`000009on<L
h`03o`000?nYEZWo000000_o]4^d00?o0000ojAKY?nTFj@02onTFj@00ol0003oNXEjogZ5NP0;ogZ5
NP03o`000?mlPgcoO8=l00CoO8=l00?o0000ogR7N?mhQgP01omhQgP00ol0003oX5nPoj1OX005oj1O
X003o`000?n[E:_oZeB[00SoZeB[00?o0000okm0_ono@;l02_no@;l00ol0003o/dbcok=</`0Dok=<
/`03o`000?n0Oh3oP7n000_oP7n000?o0000ojm@[on_D:l02On_D:l00ol0003ohQgRon8MhP0<on8M
hP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003oo0?lo`000009on<Lh`04o`000?nYEZWoZEJYo`00
00_o]4^d00?o0000ojAKY?nTFj@02onTFj@00ol0003oNXEjogZ5NP0;ogZ5NP03o`000?mlPgcoO8=l
00CoO8=l00?o0000ogR7N?mhQgP02?mhQgP00ol0003oX5nPoj1OX002oj1OX0;o00003?n[E:/2o`00
00[o_d2o00?o0000ok=</oncC;<05?ncC;<00ol0003oP7n0oh1oP00;oh1oP003o`000?n_D:oo[e2_
00Wo[e2_00?o0000on8Mh_oR7N803OoR7N800ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003ohacSon<Lh`07on<Lh`03
o`000?nYEZWoZEJY00;oZEJY00?o0000okA;]?ndBk@02?ndBk@00ol0003oY5^TojAKY00<ojAKY003
o`000?mjQG[oNXEj00WoNXEj00?o0000ogb3O?mlPg`01OmlPg`00ol0003oN8MhogR7N009ogR7N004
o`000?nPGj3o0000o`00013oZeB[0_l00008okm0_`03o`000?ncC;?o/dbc01Co/dbc0ol0000;oh1o
P003o`000?n_D:oo[e2_00Wo[e2_00?o0000on8Mh_oR7N803OoR7N801?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003ohacSon<Lh`06on<Lh`03o`000?nYEZWoZEJY00?oZEJY00?o0000okA;
]?ndBk@02?ndBk@00ol0003oY5^TojAKY00;ojAKY0;o00002_mjQGX00ol0003oO8=logb3O006ogb3
O003o`000?mhQgSoN8Mh00[oN8Mh00?o0000oj]DZon[E:/04_n[E:/00ol0003o_d2ookm0_`04okm0
_`03o`000?ncC;?o/dbc01Go/dbc00?o0000oj=LXonSG:<01Ol00005oh1oP003o`000?n_D:oo[e2_
00[o[e2_00?o0000on8Mh_oR7N803_oR7N83o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003ohacSon<Lh`04on<Lh`03
o`000?nYEZWoZEJY00CoZEJY00?o0000okA;]?ndBk@01ondBk@00ol0003oY5^TojAKY00;ojAKY004
o`000?n9MXWoRGJ9o`0000WoNXEj00?o0000ogb3O?mlPg`01_mlPg`00ol0003oN8MhogR7N00:ogR7
N003o`000?n[E:_oZeB[01?oZeB[0_l00003okm0_`Co00005?ncC;<00ol0003oXebSoj=LX`06oj=L
X`Co000000?oP7n0o`000?n_D:l02on_D:l00ol0003ohQgRon8MhP0>on8MhP03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003ohacSon<Lh`03on<Lh`03o`000?nYEZWoZEJY00GoZEJY00?o0000okA;]?nd
Bk@01ondBk@00ol0003oY5^TojAKY009ojAKY0;o00001?n9MXT00ol0003oNXEjogZ5NP05ogZ5NP03
o`000?mlPgcoO8=l00OoO8=l00?o0000ogR7N?mhQgP02_mhQgP00ol0003oZeB[oj]DZ`0Eoj]DZ`03
o`000?no@;oo000000Co]TVf0ol0000@ok=</`03o`000?nSG:?oXebS00_oXebS0_l0000<ojm@[`03
o`000?oR7N;ohQgR00cohQgR0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on<LhooS7><00_oS7><00ol0003oZEJY
ojUFZ@06ojUFZ@03o`000?ndBkCo]4^d00Oo]4^d00?o0000ojAKY?nTFj@02?nTFj@00ol0003oRGJ9
ohUfR@05ohUfR@03o`000?mjQG[oNXEj00CoNXEj00?o0000ogb3O?mlPg`01omlPg`00ol0003oN8Mh
ogR7N00:ogR7N003o`000?n[E:_oZeB[01KoZeB[00?o0000okI9]_nfBKH01_nfBKH3o`0000co/dbc
00?o0000oj=LXonSG:<03OnSG:<00ol0003o[e2_ojm@[`09ojm@[`Go00002OoR7N82o`000003on8M
h_l0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003on<Lhol0003oZEJY00WoZEJY00?o0000okA;]?ndBk@01_nd
Bk@00ol0003oY5^TojAKY007ojAKY003o`000?n9MXWoRGJ900OoRGJ900?o0000ogZ5N_mjQGX00_mj
QGX00ol0003oO8=logb3O008ogb3O003o`000?mhQgSoN8Mh00WoN8Mh00?o0000oj]DZon[E:/05on[
E:/00ol0003o]TVfokI9]P09okI9]P?o00002OncC;<00ol0003oXebSoj=LX`0>oj=LX`Ko00001?n_
D:l00ol0003oZeB[oj]DZ`03oj]DZ`Go00000_oR7N82o`0000CohQgR00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?oC;=?odbcCom</dol000002onYEZT00ol0003o]4^dokA;]006okA;]003o`000?nT
FjCoY5^T00GoY5^T0_l0000;ohUfR@04o`000?mjQG[oNXEjo`0000_oO8=l00?o0000ogR7N?mhQgP0
2OmhQgP00ol0003oZeB[oj]DZ`0Foj]DZ`03o`000?nfBKKo]TVf00go]TVf0ol00005ok=</`03o`00
0?nSG:?oXebS00ooXebS00?o0000ojAKY?nTFj@00onTFj@4o`0000_oZeB[0_l00006on8MhP03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003odbcCom</d`02om</d`ko00001_ndBk@00ol0003oY5^TojAK
Y005ojAKY003o`000?n9MXWoRGJ900coRGJ900?o0000ogZ5N_l000002omlPg`00ol0003oN8MhogR7
N007ogR7N0?o00006?n[E:/00ol0003o]TVfokI9]P0@okI9]P?o000000?o/dbco`000?nSG:<04?nS
G:<00ol0003oY5^TojAKY007ojAKY003o`000?n[E:_oZeB[00[oZeB[00?o0000on8Mh_oR7N801OoR
7N800ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005om</d`03o`000?n8MhSoR7N800_oR7N80_l00004
okA;]003o`000?nTFjCoY5^T00?oY5^T0_l0000@ohUfR@03o`000?mlPgcoO8=l00[oO8=l00?o0000
ogR7N?mhQgP00omhQgP4o`0000;oJ9MX00?o0000oj]DZon[E:/05On[E:/00ol0003o]TVfokI9]P0D
okI9]P03o`000?nSG:?oXebS013oXebS00?o0000ojAKY?nTFj@01onTFj@00ol0003oZeB[oj]DZ`0:
oj]DZ`03o`000?oR7N;ohQgR00GohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oC;=?odbcC
00GodbcC00?o0000ohQgR?n8MhP03On8MhP6o`0000?oY5^T00?o0000ohUfROn9MXT04?n9MXT00ol0
003oO8=logb3O00:ogb3O003o`000?mhQgSo000000?o00001omXUfP00ol0003oZeB[oj]DZ`0Doj]D
Z`03o`000?nfBKKo]TVf01Co]TVf00?o0000oj=LXonSG:<03onSG:<00ol0003oY5^TojAKY008ojAK
Y003o`000?n[E:_oZeB[00[oZeB[00?o0000on8Mh_oR7N801OoR7N800ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000om</dooC;=<01_oC;=<00ol0003oR7N8ohQgR00=ohQgR003o`000?nRGJ;oXUfR00?o
XUfR00?o0000ojAKY?l000004on9MXT4o`0000WoO8=l0_l0000<ofRGJ003o`000?n[E:_oZeB[01?o
ZeB[00?o0000okI9]_nfBKH05OnfBKH00ol0003oXebSoj=LX`0>oj=LX`03o`000?nTFjCoY5^T00So
Y5^T00?o0000oj]DZon[E:/02On[E:/00ol0003ohQgRon8MhP07on8MhP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?oC;=?odbcC00SodbcC00?o0000ohQgR?n8MhP02on8MhP00ol0003oXUfRoj9MXP05oj9MXP03o`00
0?n9MXWoRGJ901;oRGJ900Co0000ogB;M?mdRgCoM8]d1Ol00003ogb3O003o`000?mXUfSoJ9MX00go
J9MX0ol0000@oj]DZ`;o00006?nfBKH00ol0003oXebSoj=LX`0=oj=LX`03o`000?nTFjCoY5^T00Wo
Y5^T00?o0000oj]DZon[E:/02On[E:/00ol0003ohQgRon8MhP07on8MhP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_odbcC00?o0000ohQgR?n8MhP02_n8MhP00ol0003oXUfRoj9MXP06oj9MXP03o`00
0?n9MXWoRGJ9017oRGJ900?o0000ogB;M?mdRg@01omdRg@3o`00013oJ9MX00?o0000of>LHomSW6<0
1Ol00009oj]DZ`;o000000?oNHIio`000?nfBKH05onfBKH00ol0003oXebSoj=LX`0=oj=LX`03o`00
0?nTFjCoY5^T00WoY5^T00?o0000oj]DZon[E:/02?n[E:/2o`0000[ohQgR00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?oV6NKoiQWV00;oiQWV00?o0000om</dooC;=<02OoC;=<00ol0003oR7N8ohQg
R00:ohQgR003o`000?nRGJ;oXUfR00OoXUfR00?o0000ohUfROn9MXT03on9MXT00ol0003oM8]dogB;
M00:ogB;M003o`000?mXUfSoJ9MX00goJ9MX00?o0000of>LHomSW6<01_mSW6<4o`0000CoZeB[00?o
0000ogV6NOmiQWT00_miQWT00ol0003o]TVfokI9]P0FokI9]P03o`000?nSG:?oXebS00_oXebS00?o
0000ojAKY?nTFj@02onTFj@00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?ncC;?o000000[ohQgR00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?oV6NKoiQWV00?oiQWV00?o0000om</dooC;=<02?oC;=<=
o`0000[oXUfR00?o0000ohUfROn9MXT03on9MXT00ol0003oM8]dogB;M00;ogB;M003o`000?mXUfSo
J9MX00coJ9MX00?o0000of>LHomSW6<02_mSW6<4o`0000GoNHIi00?o0000okI9]_nfBKH05_nfBKH0
0ol0003oXebSoj=LX`0:oj=LX`03o`000?nTFjCoY5^T00coY5^T00?o0000oj]DZon[E:/01?n[E:/2
o`0000?o/dbc00?o0000on8Mh_oR7N802?oR7N800ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onHI
i_oV6NH00ooV6NH00ol0003odbcCom</d`07om</d`03o`000?n5NXGoQGZ500WoQGZ500?o0000oj9M
X_nRGJ802OnRGJ800ol0003oRGJ9ohUfR@0=ohUfR@03o`000?mdRgCoM8]d00coM8]d00?o0000ofRG
J?mXUfP03?mXUfP00ol0003oHiaSof>LH`0;of>LH`03o`000?m:]D[o000000KoNHIi00?o0000okI9
]_nfBKH05_nfBKH00ol0003oXebSoj=LX`09oj=LX`03o`000?nTFjCoY5^T00coY5^T00?o0000oj]D
Zon[E:/00on[E:/00ol0003o/dbcok=</`03ok=</`03o`000?oR7N;ohQgR00SohQgR00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?oV6NKoiQWV00CoiQWV00?o0000om</dooC;=<01_oC;=<00ol0003o
QGZ5ohEjQ@08ohEjQ@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ohUfROn9MXT02?n9MXT4o`0000oo
M8]d00?o0000ofRGJ?mXUfP02omXUfP00ol0003oHiaSof>LH`0;of>LH`04o`000?m:]D[oB[E:o`00
00OoNHIi00?o0000okI9]_nfBKH05OnfBKH00ol0003oXebSoj=LX`08oj=LX`03o`000?nTFjCoY5^T
00goY5^T00?o0000oj]DZon[E:/00_n[E:/00ol0003o/dbcok=</`05ok=</`03o`000?oR7N;ohQgR
00OohQgR00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?oV6NKoiQWV00GoiQWV00?o0000om</dooC
;=<01OoC;=<00ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ohUfROn9
MXT00on9MXT5o`0000?oMHYe00?o0000ogB;M?mdRg@03_mdRg@00ol0003oJ9MXofRGJ00:ofRGJ003
o`000?mSW6?oHiaS00[oHiaS00Go0000odZeB_m:]D[oB[E:o`000007ogV6N@03o`000?nfBKKo]TVf
01Go]TVf00?o0000oj=LXonSG:<02?nSG:<00ol0003oY5^TojAKY00=ojAKY003o`000?n[E:_oZeB[
00;o00002?ncC;<00ol0003ohQgRon8MhP08on8MhPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oiQWVonHIiP05onHIiP03o`000?oC;=?odbcC00Go
dbcC00?o0000ohEjQOn5NXD02?n5NXD00ol0003oXUfRoj9MXP0<oj9MXPGo00002OmeRWD00ol0003o
M8]dogB;M00<ogB;M0;o00003?mXUfP00ol0003oHiaSof>LH`0:of>LH`05o`000?m:]D[oB[E:odZe
B_l000002?miQWT00ol0003o]TVfokI9]P0DokI9]P?o00001onSG:<00ol0003oY5^TojAKY00>ojAK
Y003o`000?n[E:_o000000_o/dbc00?o0000on8Mh_oR7N801_oR7N800ol0003on`Ckoo/4n`06oo/4
n`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000onHIi_oV6NH01OoV6NH00ol0003odbcCom</d`04om</d`03o`000?n5NXGoQGZ500Oo
QGZ500?o0000oj9MX_nRGJ803?nRGJ801?l0003oRGJ9ohUfROl0000;ogF:M@03o`000?mdRgCoM8]d
00_oM8]d00Co0000odJiA_m6^DKo00002_mXUfP00ol0003oHiaSof>LH`0:of>LH`03o`000?m:]D[o
B[E:00;oB[E:00?o0000ogV6NOmiQWT01_miQWT00ol0003o]TVfokI9]P0AokI9]P?o00000on6NHH0
0ol0003oXebSoj=LX`04oj=LX`03o`000?nTFjCoY5^T00goY5^T1?l0000;ok=</`03o`000?oR7N;o
hQgR00GohQgR00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oV6NKoiQWV00KoiQWV00Co0000om</
dooC;=?odbcC1?l00008ohEjQ@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ohUfROn9MXT00_n9MXT0
0ol0003oMHYeogF:M@08ogF:M@03o`000?mdRgCoM8]d00[oM8]d00?o0000odJiA_m6^DH00_m6^DH0
0ol0003oJ9MXofRGJ003ofRGJ0Go00002omSW6<00ol0003oB[E:odZeBP03odZeBP03o`000?miQWWo
NHIi00OoNHIi00?o0000okI9]_nfBKH03_nfBKH2o`0000OoQWV600?o0000oj=LXonSG:<00_nSG:<0
0ol0003oY5^TojAKY00=ojAKY003o`000?nZEJ[oZUFZ00;oZUFZ00?o0000ok=</oncC;<02OncC;<0
0ol0003ohQgRon8MhP03on8MhP03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiQWVonHIiP07onHI
iP?o00001?nn@Kh00ol0003oQGZ5ohEjQ@05ohEjQ@03o`000?nRGJ;oXUfR00[oXUfR00?o0000ohUf
ROn9MXT00on9MXT00ol0003oMHYeogF:M@09ogF:M@03o`000?mdRgCoM8]d00SoM8]d00?o0000odJi
A_m6^DH01?m6^DH5o`0000Co5NXE00?o0000of>LHomSW6<02OmSW6<00ol0003oB[E:odZeBP03odZe
BP03o`000?miQWWoNHIi00SoNHIi00?o0000okI9]_nfBKH02_nfBKH3o`0000[oQWV600Go0000oj=L
XonSG:?oXebSo`00000>ojAKY003o`000?nZEJ[oZUFZ00CoZUFZ0_l00009ok=</`03o`000?oR7N;o
hQgR00;ohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?oV6NKoiQWV00OoiQWV00?o0000oki1
__nn@Kh01Onn@Kh00ol0003oQGZ5ohEjQ@03ohEjQ@03o`000?nRGJ;oXUfR00[oXUfR00?o0000ohUf
ROn9MXT01?n9MXT00ol0003oMHYeogF:M@09ogF:M@03o`000?mdRgCoM8]d00OoM8]d00?o0000odJi
A_m6^DH01Om6^DH00ol0003o5NXEoaGZ5@07oaGZ5@03o`000?mSW6?oHiaS00OoHiaS00?o0000odZe
B_m:]DX01?m:]DX00ol0003oNHIiogV6N@08ogV6N@03o`000?nfBKKo]TVf00So]TVf0_l0000>ohIi
QPCo00003?nTFj@2o`0000WoZUFZ00?o0000ok=</oncC;<01oncC;<01?l0003ohQgRon8Mh_l0000?
oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000onHIi_oV6NH01OoV6NH00ol0003o_T6noki1_P07oki1_P;o00000on5NXD00ol0
003oXUfRoj9MXP09oj9MXP03o`000?n9MXWoRGJ900KoRGJ900?o0000ogF:MOmeRWD02OmeRWD00ol0
003oM8]dogB;M005ogB;M003o`000?m6^DKoA[U600KoA[U600?o0000oaGZ5OlEjQD02?lEjQD00ol0
003oHiaSof>LH`06of>LH`03o`000?m:]D[oB[E:00CoB[E:00?o0000ogV6NOmiQWT02OmiQWT4o`00
00?o]TVf0ol0000@ohIiQP05o`000?no@;oo_d2ookm0_ol000002_nTFj@00ol0003oZUFZojYEZP0:
ojYEZPKo00000oncC;<00ol0003ohQgRo`00000@oo/4n`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000onHIi_oV6NH01?oV6NH00ol0
003o_T6noki1_P0:oki1_P04o`000?n5NXGoQGZ5o`0000[oXUfR00?o0000ohUfROn9MXT01on9MXT0
0ol0003oMHYeogF:M@09ogF:M@03o`000?mdRgCoM8]d00CoM8]d00?o0000odJiA_m6^DH01om6^DH0
0ol0003o5NXEoaGZ5@08oaGZ5@;o00001_mSW6<00ol0003oB[E:odZeBP05odZeBP03o`000?miQWWo
NHIi00WoNHIi00Co0000ofRGJ?mXUfSoJ9MX0ol0000BohIiQP03o`000?no@;oo_d2o00?o_d2o0_l0
0006ojAKY0;o00003OnZEJX00ol0003oiaSWonLHi`03onLHi`Go00004Ook1?/00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000onHIi_oV6NH00ooV6NH0
0ol0003o_T6noki1_P0<oki1_P;o00002_nRGJ800ol0003oRGJ9ohUfR@08ohUfR@03o`000?meRWGo
MHYe00[oMHYe00?o0000ogB;M?mdRg@00_mdRg@00ol0003oA[U6odJiAP08odJiAP03o`000?lEjQGo
5NXE00Ko5NXE0_l00002od>l@`03o`000?mSW6?oHiaS00;oHiaS00?o0000odZeB_m:]DX01_m:]DX0
0ol0003oNHIiogV6N@08ogV6N@03o`000?mXUfSoJ9MX00CoJ9MX00?o0000ohIiQ_n6NHH03on6NHH0
0ol0003o_d2ookm0_`06okm0_`;o00000onTFj@00ol0003oZUFZojYEZP0=ojYEZP03o`000?oW6>Oo
iaSW00OoiaSW0_l0000@oo/4n`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003oiQWVonHIiP02onHIiP03o`000?nn@Kko_T6n
00ko_T6n00?o0000oj9MX_nRGJ801onRGJ800ol0003oRGJ9ohUfR@0:ohUfR@03o`000?meRWGoMHYe
00WoMHYe00Go0000ogB;M?mdRgCoM8]do`00000;odJiAP03o`000?lEjQGo5NXE00Co5NXE0_l00005
od>l@`05o`000?mSW6?oHiaSof>LHol000002?m:]DX00ol0003oNHIiogV6N@08ogV6N@03o`000?mX
UfSoJ9MX00GoJ9MX00?o0000ohIiQ_n6NHH03_n6NHH00ol0003o_d2ookm0_`08okm0_`03o`000?nT
FjCo000000ooZUFZ00?o0000onLHiooW6>L02?oW6>L01?l0003on`Cko`000?l0000>oo/4n`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?oV6NKoiQWVo`00017o_T6n00?o0000oj9MX_nRGJ801_nRGJ800ol0003oRGJ9
ohUfR@0;ohUfR@03o`000?meRWGoMHYe00WoMHYe00Co0000ogB;M?mdRgCo00003?m6^DH00ol0003o
5NXEoaGZ5@02oaGZ5@;o00002?m3_4<00ol0003oHiaSo`000009odZeBP03o`000?miQWWoNHIi00So
NHIi00?o0000ofRGJ?mXUfP01OmXUfP00ol0003oQWV6ohIiQP0=ohIiQP03o`000?no@;oo_d2o00[o
_d2o00?o0000ojYEZ_nZEJX03_nZEJX00ol0003oiaSWonLHi`07onLHi`03o`000?ok1?_on`Ck00;o
n`Ck00?o0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000Boki1_P03o`00
0?nRGJ;oXUfR00CoXUfR00?o0000ohUfROn9MXT03?n9MXT00ol0003oMHYeogF:M@0:ogF:M@?o0000
3?m6^DH00ol0003o5NXEoaGZ5@02o`0000_o@ka300?o0000odZeB_m:]DX02?m:]DX00ol0003oNHIi
ogV6N@07ogV6N@03o`000?mXUfSoJ9MX00OoJ9MX00?o0000ohIiQ_n6NHH03?n6NHH00ol0003o_d2o
okm0_`0;okm0_`;o00003_nZEJX00ol0003oiaSWonLHi`07onLHi`03o`000?ok1?_on`Ck00?on`Ck
0_l0000:oo/4n`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX00ooZ5NX00ol0003o_T6noki1_P0?oki1_P?o00000onR
GJ800ol0003oRGJ9ohUfR@0>ohUfR@03o`000?meRWGoMHYe00SoMHYe00Co0000odn`Com?/4ooCk1?
0_l0000:odJiAP?o00003Om3_4<00ol0003oB[E:odZeBP08odZeBP03o`000?miQWWoNHIi00OoNHIi
00?o0000ofRGJ?mXUfP01omXUfP00ol0003oQWV6ohIiQP0;ohIiQP03o`000?no@;oo_d2o00co_d2o
00?o0000oll`col000000_l0000:ojYEZP03o`000?oW6>OoiaSW00SoiaSW00?o0000oo/4nook1?/0
1Ook1?/2o`0000Son`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003ojQGZonXEjP04onXEjP03o`000?nn@Kko_T6n00co_T6n0_l0
0003ojIIYP03o`000?nRGJ;o0000017oRGJ900?o0000ogF:MOmeRWD01omeRWD00ol0003oCk1?odn`
C`04odn`C`;o00002?m6^DH00ol0003o@ka3od>l@`0>od>l@`;o00002?m:]DX00ol0003oNHIiogV6
N@06ogV6N@03o`000?mXUfSoJ9MX00WoJ9MX00?o0000ohIiQ_n6NHH02On6NHH00ol0003o_d2ookm0
_`0=okm0_`03o`000?o?<<oocc3?00;occ3?0ol00007ojYEZP03o`000?oW6>OoiaSW00OoiaSW00?o
0000oo/4nook1?/02?ok1?/2o`0000Kon`Ck00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojQGZonXEjP05onXEjP03o`000?nn@Kko
_T6n00Wo_T6n0_l00006ojIIYP03o`000?n9MXWoRGJ9013oRGJ900?o0000ogF:MOmeRWD01_meRWD0
0ol0003oCk1?odn`C`07odn`C`03o`000?m6^DKoA[U600CoA[U60ol0000>od>l@`03o`000?l]dRgo
;M8]00?o00001Om:]DX00ol0003oNHIiogV6N@06ogV6N@03o`000?mXUfSoJ9MX00[oJ9MX00?o0000
ohIiQ_n6NHH02?n6NHH00ol0003o_d2ookm0_`0=okm0_`03o`000?o?<<oocc3?00Gocc3?0ol00004
ojYEZP03o`000?oW6>OoiaSW00OoiaSW00?o0000oo/4nook1?/02_ok1?/00ol0003on`Ckoo/4n`02
oo/4n`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ojQGZonXEjP06onXEjP03o`000?nn@Kko_T6n00Go_T6n0ol00008ojIIYP03o`000?n9MXWoRGJ9
017oRGJ900Co0000ogF:MOmeRWGoMHYe1?l0000;odn`C`;o000000CoA[U6o`000?l0003o00000omM
XUd2o`0000_o@ka300?o0000obgB;Ol]dRd01?l]dRd2o`0000?oB[E:00?o0000ogV6NOmiQWT01_mi
QWT00ol0003oJ9MXofRGJ00:ofRGJ003o`000?n6NHKoQWV600OoQWV600?o0000okm0_ono@;l03_no
@;l00ol0003occ3?oll`c`08oll`c`Co00002_oW6>L00ol0003on`Ckoo/4n`0;oo/4n`;o000000?o
n`Cko`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ojQGZonXEjP07onXEjP03o`000?nn@Kko_T6n00;o_T6n0_l0000<ojIIYP03o`000?n9MXWo
RGJ9013oRGJ91?l00003ofRGJ003o`000?m?/4ooCk1?00_oCk1?00?o0000oefRGOmMXUd01_mMXUd0
0ol0003o@ka3od>l@`07od>l@`03o`000?l]dRgo;M8]00Oo;M8]3?l0000>ofRGJ003o`000?n6NHKo
QWV600KoQWV600?o0000okm0_ono@;l03_no@;l00ol0003occ3?oll`c`0;oll`c`03o`000?oW6>Oo
iaSW00OoiaSW00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oZ5N[ojQGZ00WojQGZ00Co0000oki1
__l0003o00003_nVFJH00ol0003oRGJ9ohUfR@0?ohUfR@03o`000?mXUfSoJ9MX00KoJ9MX00?o0000
odn`Com?/4l02_m?/4l00ol0003oGJ9MoefRG@07oefRG@;o00001_m3_4<00ol0003o;M8]obgB;@08
obgB;@03o`000?n1OX7oPGj100SoPGj100?o0000ofRGJ?mXUfP03?mXUfP00ol0003oQWV6ohIiQP05
ohIiQP03o`000?no@;oo_d2o00oo_d2o0_l0000=oll`c`03o`000?oW6>OoiaSW00KoiaSW00?o0000
oo/4nook1?/03_ok1?/00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ojIIY_nVFJH03_nVFJH00ol0
003oRGJ9ohUfR@0>ohUfR@03o`000?mXUfSoJ9MX00OoJ9MX00?o0000odn`Com?/4l02_m?/4l00ol0
003oGJ9MoefRG@09oefRG@;o00000om3_4<00ol0003o;M8]obgB;@09obgB;@03o`000?n1OX7oPGj1
00WoPGj100?o0000ofRGJ?mXUfP02_mXUfP4o`0000CoQWV600?o0000okm0_ono@;l04?no@;l01?l0
003oc3?<o`000?l0000<oll`c`03o`000?oW6>OoiaSW00GoiaSW00?o0000oo/4nook1?/03Ook1?/0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ojIIY_nVFJH03onVFJH@o`0000[oJ9MX00?o0000odn`
Com?/4l02Om?/4l00ol0003o=/Tfo`00000<oefRG@05o`000?m3_4?o0000obo@;ol000002_l]dRd0
0ol0003oPGj1oh5nP@09oh5nP@03o`000?mXUfSoJ9MX00OoJ9MX0ol00004ohm`S`?o000000?oQWV6
o`000?no@;l04Ono@;l01?l0003oc3?<ol`cc?o<<l`2o`0000_occ3?00?o0000onLHiooW6>L00ooW
6>L00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oYUVVojIIYP0?
ojIIYP03o`000?n@Ki3oT6n@00coT6n@00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oCk1?odn`C`07
odn`C`04o`000?lfbCKo=/Tfo`0000goGJ9M00Go0000obo@;ol_d2oo;m0_o`000009obgB;@03o`00
0?n1OX7oPGj100[oPGj100?o0000ofRGJ?mXUfP00omXUfP3o`0000[oSg2?00?o0000okm0_ono@;l0
4?no@;l00ol0003oc3?<ol`cc004ol`cc0;o00002_o?<<l00ol0003oiaSWonLHi`04o`0000oon`Ck
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cojQGZ00?o0000ojIIY_nVFJH03onVFJH00ol0003oT6n@oi1_T00<oi1_T003o`000?mX
UfSoJ9MX00WoJ9MX00?o0000odn`Com?/4l01_m?/4l00ol0003o=/TfocK9=P02ocK9=P03o`000?mM
XUgoGJ9M00[oGJ9M00?o0000obo@;ol_d2l00_l_d2l00ol0003o;M8]obgB;@06obgB;@03o`000?n1
OX7oPGj100[oPGj100?o0000ofRGJ?mXUfP00ol0000=ohm`S`03o`000?no@;oo_d2o013o_d2o00?o
0000ol`cc?o<<l`01_o<<l`2o`0000Wocc3?0_l00004oo/4n`03o`000?ok1?_on`Ck00_on`Ck00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oYUVVojIIYP0=ojIIYP?o00003on@Ki00
0ol0003oJ9MXofRGJ008ofRGJ003o`000?m?/4ooCk1?00GoCk1?00?o0000ocK9=_lfbCH00olfbCH0
0ol0003oGJ9MoefRG@0:oefRG@03o`000?l_d2oo;m0_00?o;m0_00?o0000obgB;Ol]dRd01Ol]dRd0
0ol0003oPGj1oh5nP@0;oh5nP@;o00004On?L8l00ol0003o_d2ookm0_`0?okm0_`03o`000?o<<lco
c3?<00Soc3?<0_l00007oll`c`03o`000?ok1?_on`Ck00Con`Ck00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oYUVVojIIYP09ojIIYPGo00000_mjQGX00ol0
003oT6n@oi1_T00=oi1_T003o`000?mXUfSoJ9MX00WoJ9MX00?o0000odn`Com?/4l01?m?/4l00ol0
003o=/TfocK9=P04ocK9=P03o`000?mMXUgoGJ9M00SoGJ9M00?o0000obo@;ol_d2l01Ol_d2l00ol0
003o;M8]obgB;@04obgB;@03o`000?n1OX7oPGj100_oPGj100?o0000ohm`Son?L8l04?n?L8l00ol0
003o_d2ookm0_`0?okm0_`03o`000?o<<lcoc3?<00[oc3?<0_l00004oll`c`03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo/4n`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003ojQGZonXEjP07onXEjP03o`000?nVFJKoYUVV00CoYUVV1Ol00007ogZ5NP03
o`000?n@Ki3oT6n@00goT6n@00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oCk1?odn`C`03odn`C`03
o`000?lfbCKo=/Tf00Go=/Tf00?o0000oefRGOmMXUd02?mMXUd00ol0003o;m0_obo@;`06obo@;`03
o`000?l]dRgo;M8]00?o;M8]00?o0000oh5nPOn1OX402on1OX400ol0003oSg2?ohm`S`0@ohm`S`03
o`000?no@;oo_d2o00oo_d2o00?o0000ol`cc?o<<l`03?o<<l`2o`000003oll`col0003on`Ck00[o
n`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oZ5N[ojQGZ00OojQGZ00?o0000ojIIY_l00000
1?l0000<ogZ5NP03o`000?n@Ki3oT6n@00koT6n@00?o0000ofRGJ?mXUfP02?mXUfP00ol0003oCk1?
odn`C`02odn`C`03o`000?lfbCKo=/Tf00Oo=/Tf00?o0000oefRGOmMXUd01omMXUd00ol0003o;m0_
obo@;`07obo@;`03o`000?l]dRgo;M8]00;o;M8]00?o0000oh5nPOn1OX402on1OX400ol0003oSg2?
ohm`S`0Aohm`S`03o`000?no@;oo_d2o00go_d2o00?o0000ol`cc?o<<l`03oo<<l`00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ook1?/2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX01OoZ5NX3o`00017oNXEj00?o0000oi1_T?n@Ki003_n@
Ki000ol0003oJ9MXofRGJ009ofRGJ004o`000?m?/4ooCk1?o`0000[o=/Tf00?o0000oefRGOmMXUd0
1omMXUd00ol0003o;m0_obo@;`08obo@;`05o`000?l]dRgo;M8]obgB;Ol000003On1OX400ol0003o
Sg2?ohm`S`0Aohm`S`?o00003Ono@;l00ol0003oc3?<ol`cc00?ol`cc003o`000?ok1?_on`Ck00go
n`Ck00Go0000oo/4nook1?_on`Cko`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_oZ5NX2o`0000;o^dBk00?o0000ogZ5N_mjQGX03omjQGX00ol0003o
T6n@oi1_T00>oi1_T003o`000?mXUfSoJ9MX00SoJ9MX1Ol0000;ocK9=P03o`000?mMXUgoGJ9M00Ko
GJ9M00?o0000obo@;ol_d2l02Ol_d2l01?l0003o;M8]obgB;Ol0000=oh5nP@03o`000?n?L8ooSg2?
017oSg2?00?o0000ofbCK?m/Tf`00ol0000:okm0_`Co00003Oo<<l`00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ok1?_o000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000onLHiooW6>OoiaSW0_l00005ok]4^`03o`000?mjQG[oNXEj00koNXEj00?o0000oi1_
T?n@Ki003_n@Ki000ol0003oJ9MXofRGJ007ofRGJ003o`000?mTVfCoI9]T00?oI9]T00?o0000ocK9
=_lfbCH02?lfbCH00ol0003oGJ9MoefRG@05oefRG@03o`000?l_d2oo;m0_00[o;m0_1Ol0000<oh5n
P@03o`000?n?L8ooSg2?013oSg2?00?o0000ofbCK?m/Tf`01?m/Tf`3o`0000Ko_d2o00?o0000oll`
coo?<<l00_o?<<l5o`0000Soc3?<00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oW6>OoiaSW00?o
iaSW00?o0000ok]4^onkA;/01?nkA;/00ol0003oNXEjogZ5NP0=ogZ5NP03o`000?n@Ki3oT6n@00oo
T6n@00?o0000ofRGJ?mXUfP01?mXUfP2o`0000OoI9]T00?o0000ocK9=_lfbCH01olfbCHEo`0000Go
?L8m00?o0000oh5nPOn1OX402?n1OX43o`00013oSg2?00?o0000ofbCK?m/Tf`02?m/Tf`3o`0000;o
_d2o00?o0000oll`coo?<<l02?o?<<l5o`0000?oc3?<00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?oW6>OoiaSW00CoiaSW00?o0000ok]4^onkA;/01OnkA;/00ol0003oNXEjogZ5NP0;ogZ5NPCo0000
3on@Ki000ol0003oJ9MXofRGJ003ofRGJ003o`000?mTVfCoI9]T00SoI9]T00?o0000ocK9=_lfbCH0
1?lfbCH2o`0000SoI9]T00?o0000oe:]D_mB[E802?mB[E800ol0003o?L8mocg2?@05ocg2?@;o0000
1_n1OX42o`0000?oM8]d00?o0000ohm`Son?L8l03?n?L8l00ol0003oK9=/ofbCK00<ofbCK0;o0000
4?o?<<l3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oiaSWonLHi`05onLHi`03o`000?nkA;_o^dBk00Ko^dBk00?o
0000ogZ5N_mjQGX02OmjQGX00ol0003oJYEZo`000002offBK@?o00003?n@Ki001?l0003oJ9MXofRG
J?mXUfP2o`0000coI9]T00?o0000ocK9=_lfbCH00_lfbCH00ol0003oI9]TofBKI008ofBKI003o`00
0?mB[E;oDZeB00SoDZeB00?o0000ocg2?Olm`Sd01olm`Sd00ol0003oPGj1oh5nP@02oh5nP@03o`00
0?mdRgCoM8]d00CoM8]d0_l0000;ohm`S`03o`000?m/TfcoK9=/00coK9=/00?o0000oi5^TOl00000
4_o?<<l00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003oiaSWonLHi`06onLHi`03o`000?nkA;_o^dBk00Oo^dBk00?o
0000ogZ5N_mjQGX01_mjQGX2o`0000;oJYEZ00?o0000offBKOm]TVd00om]TVd3o`0000[oT6n@00?o
0000ofRGJ?l000003omTVf@01?l0003o=/Tfo`000?l0000;ofBKI003o`000?mB[E;oDZeB00SoDZeB
00?o0000ocg2?Olm`Sd02?lm`Sd01?l0003oPGj1o`000?l00009ogB;M003o`000?n?L8ooSg2?00Oo
Sg2?00?o0000ofbCK?m/Tf`03?m/Tf`01?l0003oTFjAoi5^TOl0000Coll`c`03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000onLHiooW6>L01ooW6>L00ol0003o^dBkok]4^`08ok]4^`03o`000?mjQG[oNXEj00Co
NXEj00?o0000ofZEJ_mZUFX00omZUFX00ol0003oKI9]offBK@05offBK@?o00001_n@Ki04o`00013o
I9]T00?o0000ofBKI?mTVf@03?mTVf@00ol0003oDZeBoe:]DP07oe:]DP03o`000?lm`Sgo?L8m00Wo
?L8m00?o0000ogB;M?mdRg@02_mdRg@2o`0000KoSg2?00?o0000ofbCK?m/Tf`03?m/Tf`00ol0003o
TFjAoi5^T@02oi5^T@03o`000?o?<<oocc3?00oocc3?00?o0000on<Lhol000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oiaSWonLHi`08onLHi`03o`000?nkA;_o^dBk00Wo^dBk00Co0000ogZ5N_mjQG[o
NXEj0_l00006ofZEJP03o`000?m]TVgoKI9]00SoKI9]0ol000000on@Ki3o0000o`000004ofn@K`03
o`000?mTVfCoI9]T00goI9]T00?o0000ofBKI?mTVf@03?mTVf@00ol0003oDZeBoe:]DP07oe:]DP03
o`000?lm`Sgo?L8m00Wo?L8m00?o0000ogB;M?mdRg@03?mdRg@00ol0003oSg2?ohm`S`03o`0000ko
K9=/00?o0000oi5^TOnAKY400onAKY400ol0003occ3?oll`c`0>oll`c`05o`000?oS7>?ohacSon<L
hol000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003oiaSWonLHi`09onLHi`03o`000?nkA;_o^dBk00[o
^dBk00?o0000ogZ5N_l000002?mZUFX00ol0003oKI9]offBK@0;offBK@03o`000?m_T6ooKi1_00Go
Ki1_00?o0000ofBKI?mTVf@03?mTVf@00ol0003oI9]TofBKI00<ofBKI003o`000?mB[E;oDZeB00Oo
DZeB00?o0000ocg2?Olm`Sd02?lm`Sd2o`0000ooM8]d0_l00002ogf2O@03o`000?m/TfcoK9=/00_o
K9=/00?o0000oi5^TOnAKY401?nAKY400ol0003occ3?oll`c`0=oll`c`03o`000?oS7>?ohacS00?o
hacS00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onLHi`03o`000?nkA;_o^dBk00_o^dBk00?o0000ofZEJ_mZUFX0
1omZUFX00ol0003oKI9]offBK@0;offBK@03o`000?m_T6ooKi1_00KoKi1_00?o0000ofBKI?mTVf@0
2omTVf@2o`0000goI9]T00?o0000oe:]D_mB[E801omB[E800ol0003o?L8mocg2?@07ocg2?@04o`00
0?m:]D[oB[E:o`0000koM8]d00?o0000ogf2OOmmPWd00_mmPWd00ol0003oK9=/ofbCK009ofbCK003
o`000?nAKY7oTFjA00KoTFjA00?o0000oll`coo?<<l02oo?<<l00ol0003ohacSon<Lh`05on<Lh`04
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000SoiaSW00?o0000ok]4^onkA;/02_nkA;/2o`0000Wo
JYEZ00?o0000offBKOm]TVd02om]TVd00ol0003oKi1_ofn@K`07ofn@K`03o`000?mTVfCoI9]T00Wo
I9]T00Co0000obgB;Ol]dRgo00003?mTVf@00ol0003oDZeBoe:]DP07oe:]DP03o`000?lm`Sgo?L8m
00Ko?L8m00Go0000odZeB_m:]D[oB[E:o`00000>ogB;M003o`000?mmPWgoOH9m00?oOH9m00?o0000
ofbCK?m/Tf`01om/Tf`00ol0003oTFjAoi5^T@07oi5^T@03o`000?o?<<oocc3?00[occ3?00?o0000
on<LhooS7><01ooS7><00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006onLHi`03o`000?nkA;_o^dBk
00Wo^dBk00Co0000oi]TVonKI9_o00002OmZUFX00ol0003oKI9]offBK@09offBK@03o`000?m_T6oo
Ki1_00WoKi1_00?o0000ofBKI?mTVf@01omTVf@00ol0003o;M8]obgB;@02obgB;@03o`000?mTVfCo
I9]T00WoI9]T00?o0000oe:]D_mB[E801omB[E800ol0003o?L8mocg2?@05ocg2?@03o`000?m:]D[o
B[E:00?oB[E:00?o0000ogB;M?mdRg@02_mdRg@00ol0003oOH9mogf2O@05ogf2O@03o`000?m/Tfco
K9=/00GoK9=/00?o0000oi5^TOnAKY402?nAKY400ol0003occ3?oll`c`09oll`c`03o`000?oS7>?o
hacS00SohacS00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_oW6>L3o`0000Wo^dBk00?o0000oi]T
VonKI9/00_nKI9/00ol0003oJYEZofZEJP06ofZEJP03o`000?m]TVgoKI9]00WoKI9]00?o0000ofn@
Kom_T6l02_m_T6l00ol0003oI9]TofBKI005ofBKI003o`000?l]dRgo;M8]00Co;M8]00?o0000ofBK
I?mTVf@02?mTVf@00ol0003oDZeBoe:]DP07oe:]DP03o`000?lm`Sgo?L8m00Co?L8m00?o0000odZe
B_m:]DX01?m:]DX00ol0003oM8]dogB;M00:ogB;M003o`000?mmPWgoOH9m00KoOH9m00?o0000ofbC
K?m/Tf`00om/Tf`00ol0003oTFjAoi5^T@09oi5^T@03o`000?o?<<oocc3?00Socc3?00?o0000on<L
hooS7><02OoS7><00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003omlOg`?o00001OnkA;/00ol0003o
VfBKoi]TV`03oi]TV`03o`000?mZUF[oJYEZ00KoJYEZ00?o0000offBKOm]TVd02Om]TVd00ol0003o
Ki1_ofn@K`0;ofn@K`03o`000?mTVfCoI9]T00?oI9]T00?o0000obgB;Ol]dRd01_l]dRd00ol0003o
I9]TofBKI008ofBKI003o`000?mB[E;oDZeB00KoDZeB00?o0000ocg2?Olm`Sd00_lm`Sd2o`0000So
B[E:00?o0000ogB;M?mdRg@02OmdRg@00ol0003oOH9mogf2O@07ogf2O@05o`000?m/TfcoK9=/ofbC
K?l000003OnAKY400ol0003occ3?oll`c`06oll`c`03o`000?oS7>?ohacS00[ohacS00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oO7moogaoO00GogaoO0ol000000onkA;_o0000oi]TV`06oi]TV`03
o`000?mZUF[oJYEZ00GoJYEZ00?o0000offBKOm]TVd02Om]TVd00ol0003oKi1_ofn@K`0<ofn@K`05
o`000?mTVfCoI9]TofBKI?l000002_l]dRd00ol0003oI9]TofBKI007ofBKI003o`000?mB[E;oDZeB
00KoDZeB00?o0000ocg2?Ol000000_l000000ommPWgo0000odZeBP07odZeBP03o`000?mdRgCoM8]d
00SoM8]d00?o0000ogf2OOmmPWd02OmmPWd00ol0003oK9=/o`00000=oi5^T@Co00001Oo?<<l00ol0
003ohacSon<Lh`0;on<Lh`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ogaoOomlOg`08omlOg`03
o`000?nKI9_oVfBK00OoVfBK00?o0000ofZEJ_mZUFX01?mZUFX00ol0003oKI9]offBK@09offBK@03
o`000?m_T6ooKi1_00goKi1_00?o0000ofBKI?l000003?l]dRd:o`0000OoDZeB0ol00005ogf2O@03
o`000?m:]D[oB[E:00KoB[E:00?o0000ogB;M?mdRg@01omdRg@00ol0003oOH9mogf2O@0:ogf2O@03
o`000?nAKY7oTFjA00_oTFjA00?o0000okm0_ono@;l00_no@;l3o`000003oll`col0003ohacS00_o
hacS0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000omlOgooO7ml02OoO7ml00ol0003oVfBKoi]TV`07oi]TV`03o`00
0?mZUF[oJYEZ00GoJYEZ00?o0000offBKOm]TVd01om]TVd00ol0003oKi1_ofn@K`0?ofn@K`;o0000
2ol]dRd00ol0003oLHiaog6>L@07og6>L@03o`000?mB[E;oDZeB00;oDZeB0ol00008ogf2O@03o`00
0?m:]D[oB[E:00KoB[E:00?o0000ogB;M?mdRg@01omdRg@00ol0003oOH9mogf2O@0:ogf2O@03o`00
0?nAKY7oTFjA00[oTFjA00?o0000okm0_ono@;l01_no@;l00ol0003ohacSon<Lh`08on<Lh`?o0000
0_oZ5NX00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000omlOgooO7ml02OoO7ml00ol0003oVfBKoi]T
V`08oi]TV`03o`000?mZUF[oJYEZ00CoJYEZ00?o0000offBKOm]TVd01om]TVd00ol0003oKi1_ofn@
K`0>ofn@K`04o`000?lo`3oo?l0oo`0000Wo;M8]00?o0000og6>LOmaSW402OmaSW401?l0003oDZeB
o`000?l0000<ogf2O@03o`000?m:]D[oB[E:00KoB[E:00?o0000ogB;M?mdRg@01_mdRg@00ol0003o
OH9mogf2O@0;ogf2O@03o`000?nAKY7oTFjA00OoTFjA0_l00009okm0_`03o`000?oS7>?ohacS00Co
hacS1?l00006onXEjP03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ogaoOomlOg`09omlOg`03o`00
0?nKI9_oVfBK00SoVfBK00?o0000ofZEJ_mZUFX00omZUFX>o`0000goKi1_00?o0000oco0?olo`3l0
0_lo`3l00ol0003o;M8]obgB;@05obgB;@03o`000?maSW7oLHia00_oLHia00?o0000ogf2OOmmPWd0
3?mmPWd00ol0003oB[E:odZeBP06odZeBP03o`000?mdRgCoM8]d00GoM8]d00?o0000ogf2OOmmPWd0
3?mmPWd00ol0003oTFjAoi5^T@06oi5^T@03o`000?no@;oo_d2o00[o_d2o00?o0000on<LhooS7><0
0ol0000:onXEjP?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oO7moogaoO00_ogaoO00?o0000oi]TVonKI9/02?nK
I9/01Ol0003oJYEZofZEJ_mZUF[o000000_oJ9MX00?o0000oacS7?lLha`00ol00009ofn@K`03o`00
0?lo`3oo?l0o00Co?l0o00?o0000obgB;Ol]dRd00ol]dRd00ol0003oLHiaog6>L@0<og6>L@03o`00
0?mmPWgoOH9m00goOH9m00?o0000odZeB_m:]DX01_m:]DX00ol0003oM8]dogB;M003ogB;M0?o0000
3OmmPWd00ol0003oTFjAoi5^T@05oi5^T@03o`000?no@;oo_d2o00co_d2o0_l0000=onXEjP03o`00
0?ol0ocoo0?l00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oO7moogaoO00_ogaoO00?o0000oi]TVonKI9/02?nK
I9/4o`0000coJ9MX00?o0000oacS7?lLha`00olLha`3o`0000GoKi1_00?o0000oco0?olo`3l01_lo
`3l01Ol0003o;M8]obgB;Ol]dRgo000000ooLHia00?o0000ogf2OOmmPWd03OmmPWd00ol0003oB[E:
odZeBP06odZeBP03o`000?mdRgCoM8]d00?o00000om@[e000ol0003oOH9mogf2O@0;ogf2O@03o`00
0?nAKY7oTFjA00?oTFjA00?o0000okm0_ono@;l03Ono@;l00ol0003ojQGZonXEjP0;onXEjP03o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000omlOgooO7ml02_oO7ml3o`0000KoVfBK0ol0
0003ohUfR@03o`000?mXUfSoJ9MX00[oJ9MX00?o0000oacS7?lLha`01_lLha`3o`000003ofn@Kol0
003o?l0o00Wo?l0o00?o0000obgB;Ol000004?maSW400ol0003oOH9mogf2O@0=ogf2O@03o`000?m:
]D[oB[E:00OoB[E:0_l00007oe2_D003o`000?mmPWgoOH9m00[oOH9m00Co0000oi5^TOnAKY7oTFjA
0ol0000?okm0_`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000omlOgooO7ml02_oO
7ml01?l0003obCK9olTfbOo9=/T2o`000004oi]TVol0003o0000o`0000KoRGJ900?o0000ofRGJ?mX
UfP02_mXUfP00ol0003o7><LoacS7009oacS7003o`000?lo`3oo?l0o00[o?l0o00?o0000og6>LOma
SW403omaSW400ol0003oOH9mogf2O@0>ogf2O@03o`000?m:]D[oB[E:00KoB[E:00?o0000oe2_D?m@
[e001om@[e04o`0000SoOH9m00Co0000oi5^TOnAKY7o00000omnPGh2o`0000go_d2o00?o0000onXE
j_oZ5NX02_oZ5NX00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000omlOgooO7ml02OoO7ml00ol0003o
bCK9olTfb@04olTfb@03o`000?n9MXWoRGJ900OoRGJ900?o0000ofRGJ?mXUfP02OmXUfP00ol0003o
7><LoacS700:oacS7003o`000?lo`3oo?l0o00[o?l0o00?o0000og6>LOmaSW403omaSW400ol0003o
OH9mogf2O@0>ogf2O@03o`000?m:]D[oB[E:00GoB[E:00?o0000oe2_D?m@[e002?m@[e001?l0003o
JIIYofVFJOmYUVT7o`0000;oOH9m0_l00006ogj1OP;o00003?no@;l00ol0003ojQGZonXEjP09onXE
jP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ogaoOomlOg`08omlOg`03o`000?o9=/WobCK900Go
bCK900?o0000ohUfROn9MXT02?n9MXT00ol0003oJ9MXofRGJ008ofRGJ003o`000?lLhaco7><L00[o
7><L00?o0000oco0?olo`3l02olo`3l00ol0003oLHiaog6>L@0>og6>L@03o`000?mmPWgoOH9m00ko
OH9m1Ol00002odZeBP03o`000?m@[e3oD:m@00WoD:m@00?o0000ofVFJOmYUVT02?mYUVT3o`0000Wo
OX5n0_l0000:okm0_`03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oO7moogaoO00SogaoO00?o0000olTfbOo9=/T01oo9=/T00ol0003oRGJ9ohUfR@07ohUfR@03o`00
0?mXUfSoJ9MX00SoJ9MX00?o0000oacS7?lLha`02_lLha`00ol0003o?l0ooco0?`0:oco0?`;o0000
3_maSW43o`0000goOH9m0ol00005oh9mPP;o00002om@[e000ol0003oJIIYofVFJ@0;ofVFJ@;o0000
2_mnPGh2o`0000Oo_d2o0ol00009onXEjP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:olTfb@03o`00
0?n9MXWoRGJ900OoRGJ900?o0000ofRGJ?mXUfP02?mXUfP>o`0000Wo?l0o0ol000000olOgaoo0000
og6>L@0:og6>L@?o00000_n7N8L00ol0003oOH9mogf2O@09ogf2O@;o00002On2OH800ol0003oD:m@
oe2_D009oe2_D003o`000?mYUVWoJIIY00_oJIIY00?o0000oh1oP?l000002omnPGh2o`0000Co_d2o
00Co0000omhQg_oN8MkogR7N0_l00007onXEjP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003obCK9
olTfb@09olTfb@03o`000?n9MXWoRGJ900KoRGJ900?o0000ofRGJ?mXUfP02?mXUfP00ol0003o:m@[
ob_D:`0:ob_D:`03o`000?lo`3oo?l0o00Co?l0o0ol00005oaoO7`03o`000?maSW7oLHia00CoLHia
1?l00006ohMhQ`03o`000?mmPWgoOH9m00KoOH9m0_l0000;oh9mPP03o`000?m@[e3oD:m@00WoD:m@
00?o0000ofVFJOmYUVT02_mYUVT01Ol0003oP7n0oh1oP?n0Oh3o000000coOX5n0_l000000ono@;oo
0000omhQgP05omhQgP03o`000?oZ5N[ojQGZ00?ojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?o9=/WobCK900SobCK900?o0000ohUfROn9MXT01_n9MXT00ol0003oJ9MXofRGJ007ofRGJ003o`00
0?l[e2_o:m@[00_o:m@[00?o0000oco0?olo`3l00_lo`3l2o`0000Wo7mlO00?o0000og6>LOmaSW40
0ol0000;ohMhQ`03o`000?mmPWgoOH9m00;oOH9m0ol0000>oh9mPP03o`000?m@[e3oD:m@00OoD:m@
00?o0000ofVFJOmYUVT02omYUVT00ol0003oP7n0oh1oP002oh1oP003o`000?mnPGkoOX5n00_oOX5n
00?o0000omhQg_oN8Mh01_oN8Mh2o`0000?ojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o9
=/WobCK900OobCK900?o0000ohUfROn9MXT01on9MXT00ol0003oJ9MXofRGJ005ofRGJ0?o00003Ol[
e2/4o`0000_o7mlO0ol0000?ohMhQ`04o`000?mmPWgo0000o`00017oPWf200?o0000oe2_D?m@[e00
1om@[e000ol0003oJIIYofVFJ@0:ofVFJ@03o`000?n0Oh3oP7n000CoP7n000?o0000ogj1O_mnPGh0
1omnPGh3o`0000_ogR7N1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000olTfbOo9=/T02?o9=/T00ol0003oRGJ9ohUf
R@06ohUfR@03o`000?mXUfSoJ9MX00;oJ9MX0ol00003odn`C`03o`000?l[e2_o:m@[00[o:m@[00?o
0000oaoO7olOgal02olOgal00ol0003o:m@[o`00000AohMhQ`03o`000?n2OH;oPWf2017oPWf200?o
0000oe2_D?m@[e001om@[e000ol0003oJIIYofVFJ@0:ofVFJ@03o`000?n0Oh3oP7n000GoP7n000Co
0000ogj1O_mnPGkoOX5n1Ol00002oi9]TP03o`000?oN8MkogR7N00WogR7N00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000olTfbOo9=/T01oo9=/T00ol0003oRGJ9ohUfR@05ohUfR@?o0000
00?oJ9MXo`000?l000001om?/4l00ol0003o:m@[ob_D:`08ob_D:`?o00002_lOgal2o`0000;o:m@[
00?o0000ohMhQon7N8L03on7N8L00ol0003oPWf2oh9mPP0Aoh9mPP03o`000?m@[e3oD:m@00OoD:m@
00?o0000ofVFJOmYUVT02OmYUVT00ol0003oP7n0oh1oP007oh1oP0?o00001onBKI800ol0003ogR7N
omhQgP09omhQgP03o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000olTfbOo9=/T01oo9
=/T4o`0000;oRGJ90_l00003oi1_T003o`000?m?/4ooCk1?00SoCk1?0_l00006ob_D:`;o00000olb
cC800ol0003o7mlOoaoO7`06oaoO7`03o`000?l[e2_o:m@[00?o:m@[00?o0000ohMhQon7N8L03_n7
N8L00ol0003oPWf2oh9mPP0Boh9mPP03o`000?m@[e3oD:m@00GoD:m@00?o0000ofVFJOmYUVT02OmY
UVT00ol0003oP7n0oh1oP008oh1oP003o`000?nBKI;oTVfB00OoTVfB00?o0000omhQg_oN8Mh02?oN
8Mh00ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o9=/WobCK900CobCK90_l00004
omHYeP;o00001On@Ki000ol0003oCk1?odn`C`0:odn`C`03o`000?l[e2_o:m@[00;o:m@[00?o0000
oc;=<_lbcC801?lbcC800ol0003o7mlOoaoO7`04oaoO7`03o`000?l[e2_o:m@[00Co:m@[00?o0000
ohMhQon7N8L03_n7N8L00ol0003oPWf2oh9mPP0Boh9mPP[o00002_mYUVT00ol0003oP7n0oh1oP008
oh1oP003o`000?nBKI;oTVfB00OoTVfB00?o0000omhQg_oN8Mh02?oN8Mh00ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003obCK9olTfbOo9=/T2o`0000OoeRWF00?o0000oi1_T?n@Ki001?n@Ki00
0ol0003oCk1?odn`C`0:odn`C`04o`000?l[e2_o0000o`0000So</db00Co0000oaoO7olOgaoo7mlO
0_l00007ob_D:`03o`000?n7N8OoQgR700koQgR700?o0000oh9mP_n2OH804_n2OH800ol0003oH9mP
of2OH007of2OH003o`000?mYUVWoJIIY00KoJIIY00?o0000oh1oP?n0Oh002_n0Oh000ol0003oTVfB
oi9]TP06oi9]TP03o`000?oN8MkogR7N00SogR7N00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?o9
=/Wo0000o`0000WoeRWF00?o0000oi1_T?n@Ki001?n@Ki000ol0003oCk1?odn`C`0;odn`C`03o`00
0?lbcC;o</db00Wo</db00?o0000oaoO7ol000002Ol[e2/00ol0003oQgR7ohMhQ`0>ohMhQ`;o0000
4_n2OH800ol0003oH9mPof2OH009of2OH0;o00001_mYUVT00ol0003oP7n0oh1oP00:oh1oP003o`00
0?nBKI;oTVfB00KoTVfB00?o0000omhQg_oN8Mh02?oN8Mh00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omHYe_oF:MH02OoF:MH00ol0003oT6n@oi1_T005oi1_T003o`000?m?/4ooCk1?00[oCk1?00?o
0000oc;=<_lbcC802_lbcC82o`0000Wo:m@[00?o0000ohMhQon7N8L03_n7N8L00ol0003oKY5^o`00
0002o`0000ooPWf200?o0000of2OH?mPWf002omPWf000ol0003oJIIYofVFJ@03o`0000goP7n000?o
0000oi9]T_nBKI801_nBKI800ol0003ogR7NomhQgP07omhQgP03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003oeRWFomHYeP09omHYeP03o`000?n@Ki3oT6n@00GoT6n@00?o0000odn`Com?/4l02Om?/4l2
o`0000_o</db0_l0000;ob_D:`03o`000?n7N8OoQgR700coQgR700?o0000ofjAK_m^TFh00om^TFh3
o`0000coPWf200?o0000of2OH?mPWf003?mPWf02o`0000;oJiA[00?o0000oh1oP?n0Oh003?n0Oh00
0ol0003oTVfBoi9]TP05oi9]TP03o`000?oN8MkogR7N00OogR7N00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oF:MKoeRWF00[oeRWF00?o0000oi1_T?n@Ki001_n@Ki000ol0003oCk1?odn`C`07odn`
C`03o`000?lo`3oo000000[o</db00Co0000oaoP7olOh1oo00002_l[e2/00ol0003oQgR7ohMhQ`0<
ohMhQ`03o`000?m^TFkoKY5^00KoKY5^0_l00008oh9mPP;o00003omPWf000ol0003oJiA[of^DJ`02
of^DJ`03o`000?n0Oh3oP7n000_oP7n000?o0000oi9]T_nBKI801OnBKI800ol0003ogR7NomhQgP07
omhQgP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oeRWFomHYeP0:omHYeP03o`000?n@Ki3oT6n@
00KoT6n@00?o0000odn`Com?/4l01_m?/4l01Ol0003o?l0ooco0?olo`3oo000000So</db00?o0000
oaoP7olOh1l00_lOh1l00ol0003o:m@[ob_D:`06ob_D:`Co00003?n7N8L00ol0003oKY5^ofjAKP08
ofjAKP?o00000_n2OH83o`000003oe^TFol0003oH9mP00goH9mP00?o0000of^DJom[U6/01?m[U6/0
0ol0003oP7n0oh1oP00:oh1oP003o`000?nBKI;oTVfB00GoTVfB00?o0000omhQg_oN8Mh01_oN8Mh0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omHYe_oF:MH02ooF:MH00ol0003oT6n@oi1_T007oi1_
T003o`000?m?/4ooCk1?00?oCk1?0_l00005oco0?`03o`000?lbcC;o</db00Co</db00?o0000oaoP
7olOh1l00olOh1l00ol0003o:m@[ob_D:`05ob_D:`03o`000?m</dcoC;=<00;oC;=<0ol00007ohMh
Q`;o00003_m^TFh2o`0000GoFjAK00?o0000of2OH?mPWf002_mPWf000ol0003oJiA[of^DJ`05of^D
J`03o`000?n0Oh3oP7n000_oP7n000?o0000oi9]T_nBKI801?nBKI800ol0003ogR7NomhQgP06omhQ
gP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003oeRWFomHYeP0;omHYeP03o`000?n@Ki3oT6n@00Oo
T6n@00?o0000odn`Com?/4l00_m?/4l00ol0003o?l0ooco0?`06oco0?`03o`000?lbcC;o</db00;o
</db00?o0000oaoP7olOh1l01OlOh1l00ol0003o:m@[ob_D:`02ob_D:`;o00002?m</d`3o`0000;o
QgR70_l000000omFZEKo0000ofjAKP0=ofjAKP03o`000?mKY5_oFjAK00GoFjAK00?o0000of2OH?mP
Wf002?mPWf000ol0003oJiA[of^DJ`07of^DJ`03o`000?n0Oh3oP7n000[oP7n000?o0000oi9]T_nB
KI801?nBKI800ol0003ogR7NomhQgP06omhQgP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003oeRWF
omHYeP0<omHYeP03o`000?n@Ki3oT6n@00SoT6n@00Co0000odn`Com?/4oo00002Olo`3l01Ol0003o
</dboc;=<_lbcC;o000000So7n0O00Go0000ob_D:ol[e2_o:m@[o`00000=odbcC0;o00001?mFZEH0
0ol0003oKY5^ofjAKP0;ofjAKP03o`000?mKY5_oFjAK00KoFjAK00?o0000of2OH?mPWf001omPWf00
0ol0003oJiA[of^DJ`08of^DJ`Co00002?n0Oh000ol0003oTVfBoi9]TP04oi9]TP03o`000?oN8Mko
gR7N00KogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oF:MKoeRWF00_oeRWF0ol00009oi1_
T003o`000?m?/4oo000000_o?l0o00?o0000oc;=<_l000002_lOh1l00ol0003o:m@[o`00000?odbc
C003o`000?mFZEKoEZUF00;oEZUF00?o0000ofjAK_m^TFh02om^TFh00ol0003oFjAKoe^TF`06oe^T
F`03o`000?mPWf3oH9mP00KoH9mP00?o0000of^DJom[U6/02Om[U6/01?l0003oTFjAoi5^TOnAKY47
o`0000;oP7n000?o0000oi9]T_nBKI800onBKI800ol0003ogR7NomhQgP05omhQgP03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oF:MKoeRWF00SoeRWF0ol00003olDja@03o`000?n@Ki3oT6n@00OoT6n@00?o0000oco0
?olo`3l02olo`3l00ol0003o7n0OoaoP7`0:oaoP7`03o`000?m</dcoC;=<00goC;=<00?o0000oeJY
E_mFZEH01?mFZEH00ol0003oKY5^ofjAKP09ofjAKP03o`000?mKY5_oFjAK00SoFjAK00?o0000of2O
H?mPWf000omPWf02o`0000coJiA[00?o0000oi5^TOnAKY402?nAKY4<o`0000?ogR7N0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omHYe_oF:MH01_oF:MH3o`0000OoaC[500?o0000oi1_T?n@Ki001_n@Ki000ol0003o
?l0ooco0?`0;oco0?`03o`000?lOh1oo7n0O00Wo7n0O0_l0000>odbcC003o`000?mFZEKoEZUF00Go
EZUF00?o0000ofjAK_m^TFh02Om^TFh00ol0003oFjAKoe^TF`09oe^TF`03o`000?mPWf3o000000;o
00000_mRWF800ol0003oJiA[of^DJ`08of^DJ`03o`000?nAKY7oTFjA00coTFjA00?o0000omdRgOoM
8]d01_oM8]d3o`0000?on`Ck0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003oeRWFomHYeP03omHYeP?o00002oo5>/D00ol0003oT6n@
oi1_T004oi1_T003o`000?lo`3oo?l0o00_o?l0o0ol00007oaoP7`?o000000?o?kloo`000?m</d`0
3Om</d`00ol0003oEZUFoeJYEP06oeJYEP03o`000?m^TFkoKY5^00SoKY5^00?o0000oe^TFomKY5/0
2_mKY5/00ol0003oHYeRof:MHP04of:MHP03o`000?m[U6_oJiA[00OoJiA[00?o0000oi5^TOnAKY40
2onAKY400ol0003ogB;MomdRg@08omdRg@03o`000?ok1?_on`Ck00Con`Ck0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omHYe_l0
003o0000o`0000ooaC[500?o0000oi1_T?n@Ki000on@Ki0>o`0000?o>/Dj0_l00002oaoP7`?o0000
1Olo_cl00ol0003oC;=<odbcC00:odbcC003o`000?mFZEKoEZUF00OoEZUF00?o0000ofjAK_m^TFh0
2?m^TFh00ol0003oFjAKoe^TF`0:oe^TF`03o`000?mRWF;oHYeR00GoHYeR00?o0000of^DJom[U6/0
1_m[U6/00ol0003oTFjAoi5^T@0;oi5^T@03o`000?oM8]gogB;M00SogB;M00?o0000oo/4nook1?/0
1ook1?/2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?oj1OX2o`0001;oaC[500?o0000oi1_T?n@Ki000_n@Ki000ol0003oDZeBoe:]
DP0:oe:]DP03o`000?ljaC[o>/Dj00?o>/Dj0_l00009ocno?`03o`000?m</dcoC;=<00WoC;=<00?o
0000oeJYE_mFZEH02?mFZEH2o`0000SoKY5^00?o0000oe^TFomKY5/02OmKY5/00ol0003oHYeRof:M
HP07of:MHP03o`000?m[U6_oJiA[00CoJiA[00?o0000oi5^TOnAKY402onAKY400ol0003ogB;MomdR
g@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oaC[5olDja@0?olDja@?o000000?oT6n@
o`000?mB[E802omB[E800ol0003o>/Djoc[5>P04oc[5>P03o`000?lo_coo?klo00Wo?klo00?o0000
odbcC?m</d`01om</d`00ol0003oEZUFoeJYEP09oeJYEP04o`000?m@[e3o0000o`0000KoKY5^00?o
0000oe^TFomKY5/02OmKY5/00ol0003oHYeRof:MHP08of:MHP03o`000?m[U6_oJiA[00?oJiA[00?o
0000oi5^TOnAKY402onAKY400ol0003ogB;MomdRg@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oaC[5olDja@0<olDja@;o00000onn@Kh2o`0000coDZeB00?o0000oc[5>_ljaCX01?ljaCX0
0ol0003o?kloocno?`0:ocno?`Wo00002omFZEH00ol0003oD:m@oe2_D002oe2_D0?o00000_m^TFh0
0ol0003oFjAKoe^TF`0:oe^TF`03o`000?mRWF;oHYeR00WoHYeR00?o0000of^DJom[U6/00_m[U6/0
0ol0003oTFjAoi5^T@0:oi5^T@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o5>/D2o`0000Go_T6n00?o0000oh=lPol000002_mB[E800ol0003o>/Djoc[5>P06oc[5
>P03o`000?lo_coo?klo00Wo?klo00?o0000oco0?olo`3l01Olo`3l00ol0003oEZUFoeJYEP09oeJY
EP03o`000?m@[e3oD:m@00GoD:m@0ol00009oe^TF`?o00003OmRWF801Ol0003oJiA[of^DJom[U6_o
000000coTFjA00?o0000omdRgOoM8]d02OoM8]d00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000olDj
aOo5>/D01Oo5>/D2o`0000Oo_T6n00Co0000oh=lPon3O8?o00002OmB[E800ol0003o>/Djoc[5>P06
oc[5>P03o`000?lo_coo?klo00So?klo00?o0000oco0?olo`3l01olo`3l00ol0003oEZUFoeJYEP07
oeJYEP03o`000?m@[e3oD:m@00SoD:m@0ol00002oe^TF`Go00000_lebSD00ol0003oHYeRof:MHP0<
of:MHP03o`000?m[U6_o000000coTFjA00?o0000omdRgOoM8]d02_oM8]d00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000olDjaOo5>/D00_o5>/D2o`0000So_T6n00?o0000oh=lPon3O8<00_n3O8<5o`00
00CoDZeB00?o0000oc[5>_ljaCX01_ljaCX00ol0003o?kloocno?`08ocno?`03o`000?lo`3oo?l0o
00Oo?l0o00?o0000oeJYE_mFZEH01omFZEH00ol0003oD:m@oe2_D008oe2_D003o`000?l[e2_o:m@[
00;o00002?lebSD00ol0003oHYeRof:MHP0<of:MHPCo00002_nAKY400ol0003ogB;MomdRg@0:omdR
g@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oaC[5o`000?l0000:oki1_P03o`000?n3O8?oPgb3
00;oPgb300?o0000ob?L8olSg2<00_lSg2<4o`0000Wo>/Dj00?o0000ocno?olo_cl02?lo_cl00ol0
003o?l0ooco0?`08oco0?`03o`000?mFZEKoEZUF00GoEZUF00?o0000oe2_D?m@[e002?m@[e001Ol0
003o:m@[ob_D:ol[e2_o000000[o=LXe0ol0000;of:MHP04o`000?o5>/GoaC[5olDja@Co00001OnA
KY400ol0003ogB;MomdRg@0;omdRg@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o_T6noki1_P0:
oki1_P03o`000?n3O8?oPgb300?oPgb300?o0000ob?L8olSg2<01?lSg2<00ol0003o>/Djoc[5>P07
oc[5>P03o`000?lo_coo?klo00Ko?klo0_l0000;oco0?`03o`000?mFZEKoEZUF00GoEZUF00?o0000
oe2_D?m@[e002?m@[e000ol0003o:m@[ob_D:`02ob_D:`03o`000?lebSGo=LXe00Oo=LXe00?o0000
ogV6NOmiQWT01?l00006of:MHP03o`000?o5>/GoaC[500KoaC[50ol00002oi5^T@03o`000?oM8]go
gB;M00_ogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nn@Kko_T6n00Wo_T6n00?o0000oh=l
Pon3O8<01?n3O8<00ol0003o8m`Sob?L8`05ob?L8`03o`000?ljaC[o>/Dj00Oo>/Dj00?o0000ocno
?olo_cl00_lo_cl3o`000003odbcC?l0003o?l0o00[o?l0o00?o0000oeJYE_mFZEH01OmFZEH00ol0
003oD:m@oe2_D007oe2_D003o`000?l[e2_o:m@[00?o:m@[00?o0000ocG:=OlebSD01olebSD00ol0
003oNHIiogV6N@04ogV6N@?o00000_mRWF800ol0003oaC[5olDja@0:olDja@;o00003_oM8]d00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000oki1__nn@Kh02Onn@Kh00ol0003oPgb3oh=lP`04oh=lP`03
o`000?lSg2?o8m`S00Ko8m`S0_l00007oc[5>P03o`000?lo_coo000000;o00001Om</d`00ol0003o
?l0ooco0?`08oco0?`?o00001?mFZEH00ol0003oD:m@oe2_D008oe2_D003o`000?l[e2_o:m@[00Co
:m@[00?o0000ocG:=OlebSD01_lebSD00ol0003oNHIiogV6N@07ogV6N@;o00003_o5>/D00ol0003o
gB;MomdRg@0;omdRg@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o_T6noki1_P08oki1_P03o`00
0?n3O8?oPgb300GoPgb300?o0000ob?L8olSg2<01?lSg2<00ol0003oAkQ7odNhA`03o`0000Co>/Dj
0_l00008odbcC003o`000?lo`3oo?l0o00Oo?l0o00Co0000og:=L_mbSG;oLXeb0ol000000omFZEKo
0000oe2_D009oe2_D003o`000?l[e2_o:m@[00Co:m@[00?o0000ocG:=OlebSD01OlebSD00ol0003o
NHIiogV6N@09ogV6N@03o`000?o5>/GoaC[500goaC[500?o0000omdRgOoM8]d02_oM8]d00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000oki1__nn@Kh01onn@Kh00ol0003oPgb3oh=lP`06oh=lP`03o`00
0?lSg2?o8m`S00?o8m`S00?o0000odNhAom7^4L01?m7^4L2o`000003oc[5>_l0003oC;=<00[oC;=<
00?o0000oco0?olo`3l01Olo`3l00ol0003oLXebog:=LP05og:=LP03o`000?m@[e3oD:m@00OoD:m@
0ol00007ob_D:`03o`000?lebSGo=LXe00Co=LXe00?o0000ogV6NOmiQWT02OmiQWT00ol0003oaC[5
olDja@0=olDja@03o`000?oM8]gogB;M00[ogB;M00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?nn
@Kko_T6n00Go_T6n0ol00009oh=lP`05o`000?lSg2?o8m`Sob?L8ol000002Om7^4L00ol0003oC;=<
odbcC00;odbcC003o`000?lo`3oo?l0o00?o?l0o00?o0000og:=L_mbSG801_mbSG800ol0003oD:m@
oe2_D006oe2_D005o`000?mGZ5OoEjQGoeNXEol000001ol[e2/00ol0003o=LXeocG:=@03ocG:=@03
o`000?miQWWoNHIi00WoNHIi00?o0000olDjaOo5>/D03_o5>/D00ol0003ogB;MomdRg@09omdRg@03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o_T6no`000004o`0000;of2OH00?o0000oh=lPon3O8<0
1on3O8<01?l0003o8m`Sob?L8ol00009odNhA`;o00003Om</d`00ol0003o?l0ooco0?`02oco0?`03
o`000?mbSG;oLXeb00SoLXeb00?o0000oe2_D?m@[e000om@[e02o`0000GoEjQG00?o0000ob_D:ol[
e2/01?l[e2/00ol0003o=LXeocG:=@03ocG:=@03o`000?miQWWoNHIi00WoNHIi00?o0000olDjaOo5
>/D03_o5>/D00ol0003ogB;MomdRg@09omdRg@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Sof2OH
00?o0000oh=lPon3O8<01_n3O8<00ol0003o8m`So`000009odNhA`04o`000?mTVfCoI9]To`0000go
C;=<00Co0000oco0?olo`3oo00003?mbSG801Ol0003oD:m@oe2_D?m@[e3o000000SoEjQG0_l00005
ob_D:`03o`000?lebSGo=LXe00;o=LXe00?o0000ogV6NOmiQWT02OmiQWT00ol0003oaC[5olDja@0>
olDja@03o`000?oM8]gogB;M00WogB;M00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oH9mSof2OH
00Oof2OH00?o0000oh=lPon3O8<01on3O8<00ol0003oAkQ7odNhA`07odNhA`03o`000?mTVfCoI9]T
00;oI9]T00?o0000odbcC?m</d`02_m</d`00ol0003o?l0oo`00000>og:=LP03o`000?m@[e3o0000
00_oEjQG00?o0000ob_D:ol[e2/00_l[e2/01Ol0003o=LXeocG:=OlebSGo000000coNHIi00?o0000
olDjaOo5>/D03_o5>/D3o`0000WogB;M00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oH9mSof2OH
00Wof2OH00?o0000oh=lPon3O8<01_n3O8<00ol0003oAkQ7odNhA`06odNhA`03o`000?mTVfCoI9]T
00?oI9]T00?o0000odbcC?m</d`02om</d`00ol0003oLXebog:=LP0>og:=LP03o`000?mGZ5OoEjQG
00_oEjQG0_l00003ob_D:`04o`000?lebSGo=LXeo`0000[oNHIi0ol0000>olDja@;o00000ook1?/2
o`0000OogB;M00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oH9mSof2OH00[of2OH00?o0000oh=l
Pon3O8<01?n3O8<00ol0003oAkQ7odNhA`06odNhA`03o`000?mTVfCoI9]T00GoI9]T00?o0000odbc
C?m</d`01om</d`3o`00017oLXeb00?o0000oeNXEomGZ5L03OmGZ5L01Ol0003o:m@[ob_D:ol0003o
=LXe00Co00000omiQWT5o`0000;ob3O800?o0000olDjaOo5>/D02_o5>/D2o`0000Oon`Ck0_l00004
omdRg@03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003of2OHomPWf00;omPWf003o`000?n3O8?oPgb3
00CoPgb300?o0000odNhAom7^4L01Om7^4L00ol0003oI9]TofBKI006ofBKI003o`000?m</dcoC;=<
00CoC;=<0ol00002oeZUFP03o`000?mbSG;oLXeb00ooLXeb0_l0000?oeNXE`04o`000?l[e2_o0000
o`0000CoJ9MX0ol00008olPgb003o`000?o5>/GoaC[500OoaC[50_l0000;oo/4n`;o00000_oM8]d0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omPWf?oH9mP03?oH9mP6o`0000OoAkQ700?o0000ofBK
I?mTVf@02?mTVf@00ol0003oC;=<odbcC003o`0000KoFZEJ00?o0000og:=L_mbSG803OmbSG801?l0
003oJiA[of^DJol0000?oeNXE`03o`000?mXUfSoJ9MX00GoJ9MX00?o0000olPgb?o8=lP02?o8=lP0
0ol0003oaC[5olDja@05olDja@03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oH9mP00ol0003oRWF:ohYeRP04ohYe
RP03o`000?m7^4OoAkQ700?oAkQ700?o0000ofBKI?mTVf@02_mTVf@2o`0000[oFZEJ00?o0000og:=
L_mbSG802ombSG800ol0003oJiA[of^DJ`02of^DJ`03o`000?mGZ5OoEjQG00_oEjQG0_l00007ofRG
J003o`000?o8=lSob3O800Wob3O800?o0000olDjaOo5>/D00_o5>/D2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omPWf?oH9mP02ooH9mP00ol0003oRWF:ohYeRP06ohYeRP05o`000?m7^4OoAkQ7odNh
Aol000003OmTVf@00ol0003oFZEJoeZUFP0:oeZUFP03o`000?mbSG;oLXeb00WoLXeb00?o0000of^D
Jom[U6/01?m[U6/00ol0003oEjQGoeNXE`08oeNXE`;o000000?o<l`co`000?mXUfP01omXUfP00ol0
003ob3O8olPgb009olPgb004o`000?o5>/Go0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oH9mSof2OH
00Wof2OH00?o0000ohYeR_n:MHX02?n:MHX00ol0003oAkQ7o`00000=ofBKI003o`000?mJYE[oFZEJ
00_oFZEJ00?o0000og:=L_mbSG802?mbSG800ol0003oJiA[of^DJ`06of^DJ`03o`000?mGZ5OoEjQG
00GoEjQG0_l00003oc?<<`03o`000?mXUfSoJ9MX00KoJ9MX00?o0000olPgb?o8=lP02_o8=lP00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003of2OHomPWf007omPWf003o`000?n:MH[oRWF:00[oRWF:00?o0000ofBKI?mT
Vf@03?mTVf@00ol0003oFZEJoeZUFP0<oeZUFP03o`000?mbSG;oLXeb00KoLXeb00?o0000of^DJom[
U6/02?m[U6/00ol0003oEjQGoeNXE`02oeNXE`;o00001_lcc3<00ol0003oJ9MXofRGJ005ofRGJ003
o`000?o8=lSob3O800[ob3O800?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oH9mSof2OH00Gof2OH
00?o0000ohYeR_n:MHX03?n:MHX2o`0000coI9]T00?o0000oeZUF_mJYEX03OmJYEX00ol0003oLXeb
og:=LP04og:=LP03o`000?m[U6_oJiA[00[oJiA[00Co0000oeNXEol0003o00002?lcc3<00ol0003o
J9MXofRGJ006ofRGJ003o`000?o8=lSob3O800Wob3O800?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oH9mP00ol0003oRWF:ohYeRP0=ohYeRP03o`000?mPWf3o000000;o00002?mTVf@00ol0003oFZEJ
oeZUFP0?oeZUFPKo00003_m[U6/00ol0003o<l`coc?<<`08oc?<<`03o`000?mXUfSoJ9MX00KoJ9MX
00?o0000olPgb?o8=lP02Oo8=lP00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000omPWf?oH9mSof2OH
0_l0000?ohYeRP03o`000?mPWf3oH9mP00?oH9mP0ol00005ofBKI0;o00004?mJYEX01_l0003oAKY5
odFjAOl0003o;]4^o`0000koJiA[00?o0000oc?<<olcc3<02Olcc3<00ol0003oJ9MXofRGJ005ofRG
J003o`000?o8=lSob3O800Wob3O800?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000omPWf?oH9mP00ooH9mP00ol0003o
RWF:ohYeRP0=ohYeRP03o`000?mPWf3oH9mP00KoH9mP0ol000001?mTVfCo0000odn`Com?/4l3o`00
00coFZEJ00Go0000odFjAOm5^TGoAKY5o`000002obkA;P03o`000?m[U6_oJiA[00_oJiA[00?o0000
oc?<<olcc3<02Olcc3<00ol0003oJ9MXofRGJ006ofRGJ003o`000?o8=lSob3O800Sob3O80_l0000A
oo/4n`?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003of2OHomPWf004omPWf0oo00003?mPWf000ol0003oCk1?odn`C`04odn`
C`?o00002?mJYEX00ol0003oAKY5odFjA@02odFjA@05o`000?l^dBko;]4^obkA;_l000003?m[U6/0
0ol0003o<l`coc?<<`09oc?<<`03o`000?mXUfSoJ9MX00GoJ9MX3?l00002onHIiP;o00003Ook1?/2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003of2OHomPWf005omPWf003o`000?mhQgSoN8Mh00_oN8Mh00?o0000of2O
H?mPWf002_mPWf000ol0003oCk1?odn`C`07odn`C`;o00001OmJYEX00ol0003oAKY5odFjA@03odFj
A@03o`000?l^dBko;]4^00;o;]4^00?o0000of^DJom[U6/02Om[U6/00ol0003o<l`coc?<<`0:oc?<
<`03o`000?mXUfSoJ9MX00?oJ9MX00?o0000oiUVVOnIIYT02OnIIYT00ol0003oiQWVonHIiP02onHI
iP;o00002Ook1?/2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003of2OHomPWf006omPWf003o`000?mhQgSoN8Mh00[o
N8Mh00?o0000of2OH?mPWf002omPWf000ol0003oCk1?odn`C`09odn`C`?o000000?oFZEJo`000?m5
^TD01Om5^TD00ol0003o;]4^obkA;P03obkA;P03o`000?m[U6_oJiA[00SoJiA[3_l00003ofRGJ0;o
00002onIIYT00ol0003oiQWVonHIiP05onHIiP03o`000?ok1?_on`Ck00?on`Ck0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000omPWf?oH9mP01OoH9mP00ol0003oSW6>o`00000;ogR7N003o`000?mPWf3oH9mP00[oH9mP
0_l0000>odn`C`03o`000?m5^TGoAKY500GoAKY500?o0000obkA;_l^dBh00ol^dBh00ol0003oJiA[
of^DJ`08of^DJ`03o`000?m[U6_oJiA[00_oJiA[00?o0000ofRGJ?l000003OnIIYT00ol0003oiQWV
onHIiP06onHIiP;o000000?on`Cko`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oH9mSof2OH00Kof2OH00Co
0000ohiaS_n>LHko00002_mhQgP00ol0003oH9mPof2OH009of2OH003o`000?m@[e3o000000koCk1?
00?o0000odFjAOm5^TD01Om5^TD00ol0003o;]4^obkA;P04obkA;P03o`000?m[U6_oJiA[00KoJiA[
00?o0000of^DJom[U6/03Om[U6/00ol0003oVFJIoiUVV@0<oiUVV@03o`000?oV6NKoiQWV00SoiQWV
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oH9mSof2OH00Gof2OH00?o0000ohiaS_n>LHh00_n>
LHh00ol0003oN8MhogR7N006ogR7N003o`000?mPWf3oH9mP00SoH9mP0_l00003oe2_D003o`000?m?
/4ooCk1?00_oCk1?00?o0000odFjAOm5^TD01Om5^TD00ol0003o;]4^obkA;P05obkA;P03o`000?m[
U6_oJiA[00GoJiA[00?o0000of^DJom[U6/03Om[U6/00ol0003oVFJIoiUVV@0;oiUVV@03o`000?oV
6NKoiQWV00WoiQWV00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oH9mSof2OH00Kof2OH00?o0000
ohiaS_n>LHh00on>LHh00ol0003oN8MhogR7N005ogR7N003o`000?mPWf3oH9mP00OoH9mP00?o0000
oe2_D?m@[e000om@[e000ol0003oCk1?odn`C`0:odn`C`03o`000?m5^TGoAKY500KoAKY500?o0000
obkA;_l^dBh01_l^dBh00ol0003oJiA[of^DJ`04of^DJ`03o`000?m[U6_oJiA[00goJiA[3ol0000;
onHIiP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oH9mSof2OH00Kof2OH00?o0000ohiaS_n>LHh01On>LHh00ol0
003oN8MhogR7N004ogR7N003o`000?mPWf3oH9mP00GoH9mP0_l00006oe2_D003o`000?m?/4ooCk1?
00WoCk1?0_l00008odFjA@03o`000?l^dBko;]4^00Ko;]4^1Ol000000om[U6_o0000of^DJ`0?of^D
J`03o`000?nGJ9OoUfRG00_oUfRG00?o0000onHIi_oV6NH02OoV6NH00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oH9mSof2OH00Kof2OH00?o0000ohiaS_n>LHh01_n>LHh00ol0003o
N8MhogR7N004o`0000KoH9mP00?o0000oe2_D?m@[e001om@[e000ol0003oCk1?odn`C`05odn`C`?o
000000?o>LHio`000?m5^TD01om5^TD00ol0003o;]4^obkA;P05obkA;P03o`000?m^TFkoKY5^00?o
KY5^0_l0000?of^DJ`;o00003OnGJ9L00ol0003oiQWVonHIiP08onHIiP03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000Wof2OH00?o0000ohiaS_n>LHh01on>LHh2o`0000CoSW6>00Co0000of2OH?mPWf3o
H9mP0_l0000:oe2_D003o`000?m?/4ooCk1?00;oCk1?0ol00005ocW6>@03o`000?m5^TGoAKY500Go
AKY500?o0000obkA;_l^dBh01?l^dBh00ol0003oKY5^ofjAKP06ofjAKP03o`000?m[U6_oJiA[00[o
JiA[0_l00002oh1oP003o`000?nGJ9OoUfRG00[oUfRG00?o0000onHIi_oV6NH02?oV6NH00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000omPWf?oH9mP01_oH9mP00ol0003oSW6>ohiaSP08ohiaSP03o`00
0?n>LHkoSW6>00CoSW6>00?o0000of2OH?l000003?m@[e000ol0003oCk1?o`000002o`0000Wo>LHi
00?o0000odFjAOm5^TD01?m5^TD00ol0003o;]4^obkA;P03obkA;P03o`000?m^TFkoKY5^00SoKY5^
1_l00004of^DJ`;o00001On0Oh000ol0003oUfRGoiMXU`09oiMXU`03o`000?oV6NKoiQWV00SoiQWV
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oH9mSof2OH00Gof2OH00?o0000ohiaS_n>LHh01on>
LHh00ol0003oSW6>ohiaSP06ohiaSP03o`000?m@[e3oD:m@00coD:m@00?o0000ocW6>OliaST02_li
aST00ol0003oAKY5odFjA@04odFjA@04o`000?l^dBko;]4^obkA;P;o00002om^TFh00ol0003oMhQg
ogN8M`03ogN8M`Co00002?n0Oh000ol0003oUfRGoiMXU`08oiMXU`03o`000?oV6NKoiQWV00OoiQWV
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000omPWf?oH9mP00ooH9mP00ol0003oSW6>ohiaSP07ohiaSP03o`000?n>
LHkoSW6>00OoSW6>00?o0000oe2_D?m@[e003?m@[e000ol0003o>LHiocW6>@0;ocW6>@03o`000?m5
^TGoAKY500?oAKY500Co0000obkA;_l^dBko00003Om^TFh00ol0003oMhQgogN8M`06ogN8M`03o`00
0?n0Oh3oP7n000OoP7n000?o0000oiMXUonGJ9L01onGJ9L00ol0003oiQWVonHIiP06onHIiP04o`00
0?ol0ocoo0?loo`3o0;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oH9mSof2OH00;of2OH00?o0000ohiaS_n>LHh0
1_n>LHh00ol0003oSW6>ohiaSP09ohiaSP03o`000?m@[e3oD:m@00WoD:m@0_l0000>ocW6>@?o0000
0om5^TD00ol0003o;]4^o`00000=ofjAKP03o`000?mgR7OoMhQg00OoMhQg00?o0000oh1oP?n0Oh00
2?n0Oh0:o`0000KoiQWV0_l00006oo`3o003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoSW6>00?o
0000ohiaS_n>LHh02_n>LHh00ol0003oD:m@oe2_D006oe2_D0;o000000?oC[5>o`000?liaST02oli
aST2o`0000?oK9=/1Ol0000>ofjAKP03o`000?mgR7OoMhQg00OoMhQg00?o0000oh1oP?n0Oh002?n0
Oh000ol0003o]4^dokA;]006okA;]003o`000?oV6NKoiQWV00?oiQWV00?o0000oo`3o?ol0o`01ool
0o`2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003ocC;=oldbc@03oldbc@Co00000_n>LHh00ol0003oSW6>ohiaSP0;
ohiaSP03o`000?m@[e3oD:m@00?oD:m@0ol00004odjaCP03o`000?liaSWo>LHi00Oo>LHi0_l00008
ofbCK003o`000?m^TFkoKY5^00goKY5^00?o0000ogN8MomgR7L02?mgR7L00ol0003oP7n0oh1oP007
oh1oP003o`000?ndBkCo]4^d00Oo]4^d0ol000000ooV6NKo0000oo`3o00;oo`3o0;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o=</gocC;=00OocC;=0_l0000?ohiaSP03o`000?m@[e3oD:m@00;o00002?m>/Dh00ol0
003o>LHiocW6>@05ocW6>@03o`000?m/TfcoK9=/00SoK9=/00?o0000ofjAK_m^TFh03Om^TFh00ol0
003oMhQgogN8M`08ogN8M`03o`000?n0Oh3oP7n000KoP7n000?o0000okA;]?ndBk@02?ndBk@01?l0
003oiQWVonHIi_l0000?oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003ocC;=oldbc@09oldb
c@03o`000?n>LHkoSW6>00koSW6>0_l0000;odjaCP03o`000?liaSWo>LHi00;o>LHi0_l0000;ofbC
K003o`000?m^TFkoKY5^00goKY5^00?o0000ogN8MomgR7L02?mgR7L00ol0003oP7n0oh1oP006oh1o
P003o`000?ndBkCo]4^d00Oo]4^d00Go0000onHIi_oV6NKoiQWVo`00000@oo`3o0;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003ocC;=oldbc@0:oldbc@03o`000?n>LHkoSW6>00goSW6>0_l0000<odjaCP04o`000?liaSWo0000
o`0000goK9=/00?o0000ofjAK_m^TFh03?m^TFh00ol0003oMhQgogN8M`09ogN8M`03o`000?n0Oh3o
P7n000KoP7n000?o0000okA;]?ndBk@01_ndBk@00ol0003oiQWVonHIiP03onHIiP03o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003ocC;=oldbc@0:oldbc@03o`000?n>LHkoSW6>00coSW6>00Co0000ocG:
=OlebSGo00003?m>/Dh00ol0003oK9=/ofbCK00>ofbCK003o`000?m^TFkoKY5^00SoKY5^1?l0000;
ogN8M`03o`000?n0Oh3oP7n000KoP7n000?o0000okA;]?ndBk@01OndBk@00ol0003oiQWVonHIiP04
onHIiP03o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003ocC;=oldbc@0;oldbc@03o`000?n>LHkoSW6>
00_oSW6>00?o0000ocG:=OlebSD00_lebSD00ol0003oC[5>odjaCP09odjaCP03o`000?m/TfcoK9=/
00koK9=/00Co0000ofjAK_m^TFkoKY5^1ol00003og><L`03o`000?mgR7OoMhQg00WoMhQg00?o0000
oh1oP?n0Oh001_n0Oh000ol0003o]4^dokA;]004okA;]003o`000?oV6NKoiQWV00KoiQWV00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?o=</gocC;=00cocC;=00?o0000ohiaS_n>LHh02_n>LHh00ol0
003o=LXeocG:=@03ocG:=@03o`000?m>/DkoC[5>00SoC[5>00?o0000ofbCK?m/Tf`03_m/Tf`4o`00
00_oLhac00?o0000ogN8MomgR7L02?mgR7L00ol0003oP7n0oh1oP005oh1oP003o`000?ndBkCo]4^d
00Go]4^d00?o0000onHIi_oV6NH01_oV6NH00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000oldbcOo=
</d03?o=</d7o`0000GoSW6>00?o0000ocG:=OlebSD01OlebSD00ol0003oC[5>odjaCP07odjaCP03
o`000?m/TfcoK9=/00koK9=/00?o0000og><LomcS7<03OmcS7<00ol0003oMhQgogN8M`08ogN8M`03
o`000?n0Oh3oP7n000CoP7n000?o0000okA;]?ndBk@01?ndBk@00ol0003oiQWVonHIiP07onHIiP03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003ocC;=oldbc@0=oldbc@03o`000?nQGZ7oXEjQ00CoXEjQ
1Ol00009ocG:=@03o`000?m>/DkoC[5>00KoC[5>00?o0000ofbCK?m/Tf`03_m/Tf`00ol0003oLhac
og><L`0=og><L`03o`000?mgR7OoMhQg00SoMhQg00Co0000oh1oP?n0Oh3oP7n01Ol00004okA;]003
o`000?oV6NKoiQWV00WoiQWV1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=oldbc@03o`000?nQGZ7oXEjQ00WoXEjQ
0_l00009ocG:=@03o`000?m>/DkoC[5>00KoC[5>00?o0000ofbCK?m/Tf`03?m/Tf`00ol0003oLhac
og><L`0?og><L`Ko00001?mgR7L4o`0000Go`Ck10_l000000ondBkCo0000onHIiP0;onHIiP04o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oO7moogaoOomlOg`?o00002_o=</d00ol0003o
XEjQoj5NX@09oj5NX@03o`000?m9]TWo000000;o00001olebSD00ol0003oC[5>odjaCP05odjaCP03
o`000?m/TfcoK9=/00SoK9=/1Ol0000Aog><L`03o`000?n0Oh3oP7n000?oP7n01?l0000;ol4n`@03
o`000?oV6NKoiQWV00[oiQWV00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000omlOgooO7ml01OoO7ml2o`0000OocC;=
00?o0000oj5NXOnQGZ402_nQGZ400ol0003oBKI9odVfB@02odVfB@?o00001OlebSD00ol0003oC[5>
odjaCP04odjaCP04o`000?m/TfcoK9=/ofbCK0Oo00001?mHYeP00ol0003oLhacog><L`0>og><L`03
o`000?n0Oh3oP7n000OoP7n000?o0000ol4n`Oo1?/402Oo1?/400ol0003oiQWVonHIiP09onHIiP03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ogaoOomlOg`08omlOg`;o00001?o=</d00ol0003oXEjQ
oj5NX@0;oj5NX@03o`000?m9]TWoBKI900GoBKI90ol00003ocG:=@04o`000?m>/DkoC[5>odjaCPKo
00003?mHYeP00ol0003oLhacog><L`0=og><L`03o`000?n0Oh3oP7n000OoP7n000?o0000ol4n`Oo1
?/402_o1?/400ol0003oiQWVonHIiP08onHIiP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=omlOg`?o000000?ocC;=o`000?nQGZ40
3?nQGZ400ol0003oBKI9odVfB@08odVfB@?o000000Co=LXeo`000?l0003o00000_n2OH800ol0003o
F:MHoeRWF00=oeRWF003o`000?mcS7?oLhac00coLhac00?o0000oh1oP?n0Oh002?n0Oh000ol0003o
`Ck1ol4n`@0;ol4n`@03o`000?oV6NKoiQWV00KoiQWV00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
gaoO00?o0000oj5NXOnQGZ403?nQGZ400ol0003oBKI9odVfB@0;odVfB@03o`000?n2OH;oPWf200?o
PWf200?o0000oeRWF?mHYeP03?mHYeP00ol0003o?/4no`00000=og><L`03o`000?n0Oh3oP7n000So
P7n000?o0000ol4n`Oo1?/403?o1?/43o`0000GoiQWV00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oO7moogaoO00cogaoO00?o0000oj5NXOnQGZ403?nQGZ400ol0003oBKI9odVfB@0:odVfB@03o`00
0?n2OH;oPWf200GoPWf200?o0000oeRWF?mHYeP02_mHYeP01?l0003o?/4nock1?_ln`Ch2o`0000[o
Lhac00?o0000oh1oP?n0Oh002On0Oh000ol0003o`Ck1ol4n`@0<ol4n`@03o`000?o[5>_ojaC[00?o
000000?oiQWVo`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oO7moogaoO00_ogaoO00?o0000oj5NXOnQGZ40
3?nQGZ400ol0003oBKI9odVfB@09odVfB@03o`000?n2OH;oPWf200KoPWf200?o0000oeRWF?mHYeP0
2OmHYeP00ol0003o?/4nock1?P02ock1?P03o`000?moP7oo000000;o00001omcS7<00ol0003oP7n0
oh1oP009oh1oP003o`000?o1?/7o`Ck100_o`Ck100?o0000on/Djoo[5>/01?o[5>/00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000omlOgooO7ml02ooO7ml00ol0003oXEjQoj5NX@0;oj5NX@03o`000?m9
]TWoBKI900SoBKI900?o0000oh9mP_n2OH801on2OH800ol0003oF:MHoeRWF008oeRWF003o`000?ln
`Cko?/4n00?o?/4n00?o0000ogn0OomoP7l00_moP7l2o`0000CoLhac00?o0000oh1oP?n0Oh002_n0
Oh000ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o[5>_ojaC[00GojaC[00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oO7moogaoO00[ogaoO0ol0000;oj5NX@Ko00001?m9]TT00ol0003oPWf2oh9mPP08
oh9mPP03o`000?mHYeSoF:MH00OoF:MH00?o0000ock1?_ln`Ch00oln`Ch00ol0003oOh1oogn0O`05
ogn0O`?o000000?oLhaco`000?n0Oh002on0Oh000ol0003o`Ck1ol4n`@09ol4n`@03o`000?o[5>_o
jaC[00OojaC[00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oO7moogaoO00WogaoO00?o0000ok5>
/OnaC[401?l00006oj5NX@03o`000?nGJ9OoUfRG00CoUfRG1?l0000<oh9mPP03o`000?mHYeSoF:MH
00GoF:MH00?o0000ock1?_ln`Ch01?ln`Ch00ol0003oOh1oogn0O`08ogn0O`03o`000?n0Oh3oP7n0
00_oP7n000?o0000ol4n`Oo1?/402?o1?/400ol0003ojaC[on/Dj`08on/Dj`Go00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oO7moogaoO00OogaoO00?o0000ok5>/OnaC[401OnaC[43o`0000;oXEjQ00?o0000oiMXUonG
J9L02?nGJ9L00ol0003oPWf2oh9mPP0:oh9mPP03o`000?mHYeSoF:MH00CoF:MH00?o0000ock1?_ln
`Ch01Oln`Ch00ol0003oOh1oogn0O`08ogn0O`03o`000?n0Oh3oP7n000WoP7n01?l00008ol4n`@03
o`000?o[5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ogaoO
omlOg`05omlOg`03o`000?naC[7o/Dja00Wo/Dja0_l0000<oiMXU`03o`000?n2OH;oPWf200WoPWf2
00?o0000oeRWF?mHYeP00omHYeP00ol0003o?/4nock1?P05ock1?P03o`000?moP7ooOh1o00[oOh1o
00?o0000oh1oP?n0Oh001?n0Oh04o`0000Co/Tfb00?o0000ol4n`Oo1?/401?o1?/400ol0003ojaC[
on/Dj`0:on/Dj`03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oO7moogaoO00?ogaoO00?o0000ok5>/OnaC[402ona
C[400ol0003oUfRGoiMXU`0:oiMXU`03o`000?n2OH;oPWf200WoPWf200?o0000oeRWF?mHYeP00_mH
YeP00ol0003o?/4nock1?P06ock1?P03o`000?moP7ooOh1o00[oOh1o00?o0000oh1oP?n0Oh001?l0
0009ok9=/PKo00003?o[5>/00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000omlOgooO7moogaoO0_l0
000=ok5>/@03o`000?nGJ9OoUfRG00[oUfRG00?o0000oh9mP_n2OH802On2OH801Ol0003oF:MHoeRW
F?mHYeSo000000Wo?/4n00?o0000ogn0OomoP7l02omoP7l2o`0000go/Tfb00?o0000onDJiOoU6^D0
0_oU6^D00ol0003ojaC[on/Dj`0:on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ogaoOo`00
0002onLHi`;o00002onaC[400ol0003oUfRGoiMXU`0;oiMXU`03o`000?n2OH;oPWf200WoPWf200?o
0000oeRWF?l000002Oln`Ch00ol0003oOh1oogn0O`0<ogn0O`03o`000?nbCK;o/Tfb00co/Tfb00?o
0000onDJiOoU6^D00ooU6^D00ol0003ojaC[on/Dj`09on/Dj`03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oiaSWonLHi`03onLHi`;o00002_naC[400ol0003oUfRGoiMXU`0:oiMXU`03o`000?n2OH;o
PWf200SoPWf21Ol00008ock1?P03o`000?moP7ooOh1o00coOh1o00?o0000ok9=/_nbCK802onbCK80
0ol0003oiA[UonDJi@05onDJi@03o`000?o[5>_ojaC[00SojaC[00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooW6>L2o`0000So/Dja00?o0000oiMXUonGJ9L02_nGJ9L00ol0003oPWf2oh9mPP07oh9m
PP03o`000?maSW7oLHia00?oLHia0ol00005ock1?P03o`000?moP7ooOh1o00_oOh1o00?o0000ok9=
/_nbCK803?nbCK800ol0003oiA[UonDJi@06onDJi@03o`000?o[5>_ojaC[00OojaC[00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ol0oco000000WoiaSW00?o0000ok5>/OnaC[401OnaC[42o`0000co
UfRG00?o0000oh9mP_n2OH801On2OH800ol0003oLHiaog6>L@07og6>L@?o000000?o?/4no`000?mo
P7l03OmoP7l00ol0003o/Tfbok9=/P0<ok9=/P03o`000?oU6^GoiA[U00KoiA[U00?o0000on/Djoo[
5>/01_o[5>/00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo`3o003o`000?oW6>OoiaSW00OoiaSW
0_l00004ok5>/@03o`000?no@;oo_d2o00;o00002_nGJ9L00ol0003oPWf2oh9mPP03oh9mPP;o0000
3OmaSW42o`0000goOh1o0ol0000=ok9=/P03o`000?oU6^GoiA[U00OoiA[U00?o0000on/Djoo[5>/0
1Oo[5>/00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003oo0?loo`3o004oo`3o003o`000?oW6>OoiaSW00SoiaSW0_l0
00000onaC[7o0000okm0_`04okm0_`03o`000?nGJ9OoUfRG00OoUfRG00Co0000oh9mP_n2OH;oPWf2
0_l00002oi1_T003o`000?maSW7oLHia00coLHia3Ol00003oiIYUP03o`000?nbCK;o/Tfb00[o/Tfb
00?o0000onDJiOoU6^D02?oU6^D01?l0003ojaC[on/Djoo[5>/4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ol0o`00ol0003oiaSW
onLHi`09onLHi`03o`000?no@;oo_d2o00Go_d2o0_l00008oiMXU`03o`000?n2OH;o000000GoT6n@
00?o0000og6>LOmaSW402omaSW400ol0003oMXUfogJ9MP09ogJ9MP03o`000?nFJIKoUVVF00;oUVVF
0_l00009ok9=/P03o`000?oU6^GoiA[U00[oiA[U0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo`3
o00:oo`3o003o`000?oW6>OoiaSW00SoiaSW00?o0000okm0_ono@;l01ono@;l4o`0000?oUfRG0ol0
0007oi1_T003o`000?maSW7oLHia00[oLHia00?o0000ogJ9M_mfRGH02OmfRGH00ol0003oUVVFoiIY
UP04oiIYUP;o00001onbCK800ol0003oiA[UonDJi@0:onDJi@03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?oW6>OoiaSW00OoiaSW00?o0000okm0_ono@;l02?no@;l0
1?l0003o_d2ookm0_ono@;l3o`0000;oZeB[00?o0000oi1_T?n@Ki001_n@Ki000ol0003oLHiaog6>
L@08og6>L@03o`000?mfRGKoMXUf00[oMXUf00?o0000oiIYU_nFJIH01_nFJIH00ol0003o/Tfbok9=
/P04ok9=/P03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onLHiooW6>L01OoW6>L00ol0003o_d2ookm0_`08okm0_`03o`000?no@;oo
_d2o00Co_d2o00Go0000oj]DZon[E:_oZeB[o`000008oi1_T003o`000?maSW7oLHia00OoLHia00?o
0000ogJ9M_mfRGH02_mfRGH00ol0003oUVVFoiIYUP07oiIYUP;o00001?nbCK800ol0003oiA[UonDJ
i@08onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onLHiooW6>L00ooW6>L0
0ol0003o_d2ookm0_`08okm0_`03o`000?no@;oo_d2o00Co_d2o00?o0000oj]DZon[E:/00_n[E:/0
0ol0003oT6n@oi1_T007oi1_T003o`000?maSW7oLHia00KoLHia00?o0000ogJ9M_mfRGH02_mfRGH0
0ol0003oUVVFoiIYUP09oiIYUP05o`000?nbCK;o/Tfbok9=/_l000002OoU6^D00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_o_d2o00?o0000okm0_ono@;l01?no@;l00ol0003oZeB[oj]DZ`03
oj]DZ`03o`000?n@Ki3oT6n@00OoT6n@00?o0000og6>LOmaSW401OmaSW400ol0003oMXUfogJ9MP0:
ogJ9MP03o`000?nFJIKoUVVF00WoUVVF1?l00009onDJi@03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o/4ncok1?/
on`Ck?l000002_no@;l00ol0003o_d2ookm0_`05okm0_`03o`000?n[E:_oZeB[00?oZeB[00?o0000
oi1_T?n@Ki002?n@Ki000ol0003oLHiaog6>L@04og6>L@03o`000?mfRGKoMXUf00WoMXUf00?o0000
oiIYU_nFJIH02?nFJIH2o`0000?oi1_T00?o0000onDJiOoU6^D01_oU6^D00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000on`Ck?o/4n`00oo/4n`00ol0003o_d2ookm0_`06okm0_`03o`000?no@;oo_d2o
00Go_d2o00?o0000oj]DZon[E:/01?n[E:/00ol0003oT6n@oi1_T009oi1_T003o`000?maSW7oLHia
00;oLHia00?o0000ogJ9M_mfRGH02_mfRGH00ol0003oUVVFoiIYUP06oiIYUP;o00001_oT6n@8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003ok1?/on`Ck005on`Ck003o`000?no@;oo_d2o00Go_d2o00?o0000okm0_ono
@;l01Ono@;l00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?n@Ki3oT6n@00WoT6n@00Go0000og6>LOma
SW7oLHiao`00000<ogJ9MP03o`000?nFJIKoUVVF00CoUVVF0_l00008on@Ki003o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o/4ncok1?/00Ook1?/00?o0000okm0_ono
@;l00ono@;l00ol0003o_d2ookm0_`06okm0_`03o`000?n[E:_oZeB[00GoZeB[00?o0000oi1_T?n@
Ki002_n@Ki000ol0003oLHiao`000004o`0000WoMXUf00?o0000oiIYU_nFJIH00_nFJIH2o`0000[o
i1_T00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ok1?/on`Ck007on`Ck003o`00
0?no@;oo_d2o00;o_d2o00?o0000okm0_ono@;l01_no@;l00ol0003oZeB[oj]DZ`07oj]DZ`;o0000
2on@Ki000ol0003o^4NhokQ7^003okQ7^0Oo00000_mfRGH00ol0003oUVVFoiIYUP02o`0000_oi1_T
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on`Ck?o/4n`02Oo/
4n`01Ol0003o_d2ookm0_ono@;oo000000So_d2o00?o0000oj]DZon[E:/01on[E:/00ol0003oebSG
o`000002o`0000SoT6n@00?o0000okQ7^?nhAkP02_nhAkP5o`0000goi1_T00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<on`Ck003o`000?no@;oo000000Wo_d2o00?o
0000oj]DZon[E:/01_n[E:/00ol0003oebSGomLXe`03omLXe`?o00001?n@Ki000ol0003o^4NhokQ7
^00=okQ7^003o`000?oT6nCoi1_T00goi1_T00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000ool0o`2o`0000_ok1?/00?o0000okm0_ono@;l01ono@;l00ol0003oZeB[oj]DZ`07
oj]DZ`03o`000?oG:=OoebSG00KoebSG0ol000000on@Ki3o0000okQ7^00>okQ7^003o`000?oT6nCo
i1_T00coi1_T00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009on`C
k003o`000?no@;oo_d2o00;o_d2o1_l00008oj]DZ`03o`000?oG:=OoebSG00[oebSG00?o0000okQ7
^?nhAkP03onhAkP00ol0003oi1_Ton@Ki00:on@Ki0;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007on`Ck0Go00001_oY5^T00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?oG:=OoebSG00[o
ebSG00?o0000okQ7^?nhAkP03onhAkP00ol0003oi1_Ton@Ki007on@Ki0?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005on`Ck003o`000?oY5^WojAKY00WojAKY00?o0000oj]DZon[
E:/00on[E:/00ol0003oebSGomLXe`0;omLXe`03o`000?nhAkSo^4Nh00oo^4Nh00?o0000on@Ki?oT
6n@01OoT6n@2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?ok1?/o`000?l00000
3OoY5^T00ol0003oZeB[oj]DZ`02oj]DZ`03o`000?oG:=OoebSG00_oebSG5?l00004on@Ki0;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003oo0?lo`00000>onTFj@04o`000?n[E:_oZeB[o`0000koebSG
00?o0000on`Ck?o/4n`04?o/4n`00ol0003oi1_To`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000003_oY5^T00ol0003oZeB[o`00000>omLXe`03o`00
0?o/4ncok1?/017ok1?/00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo`3o?ol0o`00_ol0o`00ol0003ojAKYonTFj@0=onTFj@03o`000?oG:=OoebSG00WoebSG1Ol0
000Bon`Ck0;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ojAKYonTFj@0<onTFj@03o`000?oG:=OoebSG00;oebSG1ol00004oo/4n`03o`000?o/4nco
k1?/00ook1?/00?o0000oo/4nol000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo0?loo`3o006oo`3
o003o`000?oY5^WojAKY00cojAKY1?l0000<oo/4n`03o`000?o/4ncok1?/00cok1?/0_l00003oo/4
n`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Oo
o0?l00?o0000onTFjOoY5^T03?oY5^T00ol0003on`Ckoo/4n`0=oo/4n`03o`000?o/4ncok1?/00_o
k1?/00?o0000oo/4nook1?/01?ok1?/00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`02Ool0o`00ol0003ojAKYonTFj@0:onTFj@03o`000?ok1?_on`Ck00kon`Ck00?o0000on`Ck?o/
4n`02Oo/4n`2o`0000Oon`Ck00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000onTFjOoY5^T02_oY5^T00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?o/4ncok1?/00Kok1?/0_l0000:oo/4n`03o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003oo0?l00goo0?l3?l0
000Aoo/4n`?o00001_o/4n`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ok1?_on`Ckoo/4nol000000oo/4n`2o`0000kon`Ck00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ok1?_o
n`Ck00?on`Ck00?o0000on`Ck?l000004Ook1?/00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4
nook1?/02ook1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?ok1?_on`Ck013on`Ck00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000oo/4nook1?/04Ook1?/5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`08oo/4n`03o`00
0?ok1?_on`Ck013on`Ck00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003on`Ckoo/4
n`07oo/4n`;o00002ook1?/00ol0003on`Ckoo/4n`0?oo/4n`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo/4nook1?/02ook1?/00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ok1?_on`Ck00kon`Ck00?o0000oo/4nook1?/02ook1?/2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/0
3ook1?/00ol0003on`Ckoo/4n`09oo/4n`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ok1?_on`Cko`0001?on`Ck
1Ol00004oo/4n`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ook1?/2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo/4n`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000kon`Ck0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_on`Ck00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003on`Ck
oo/4n`07oo/4n`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo/4n`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01ol00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00So003o0_ooo`03o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`;oool01ol00?l2oooo00Go003o00?oool0o`00ool00?l00_l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`07o`00o`;oool01Ol00?l2oooo
00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00?o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`06o`00o`;oool01Ol00?l3oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`06o`00o`?oool00ol00?l3oooo00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`002_l00?l2oooo00Ko003o0_ooo`000ol00?ooool0oooo0003oooo00Co003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00[o003o0_ooo`07o`00o`03oooo0?l00?oo003o00So003o0_ooo`06o`00o`;oool01_l00?l2
oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00
o`;oool02_l00?l2oooo00Oo003o0_ooo`09o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o
003o0_ooo`08o`00o`03oooo0?l00?oo003o00Oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool0
2_l00?l2oooo00So003o0_ooo`09o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo
001Xo`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l0
0?oo003o00Oo003o0_ooo`09o`00o`;oool02?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool01Ol00?l4oooo00_o003o0_ooo`07o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1W
o`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08_l00?l2oooo
00go003o0oooo`05o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(170) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.986 .014 .986 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.986 .014 .986 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.986 .014 .986 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.985 .015 .985 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.91 .09 .91 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.984 .016 .984 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.907 .093 .907 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.919 .081 .919 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.88 .12 .88 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.981 .019 .981 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.835 .165 .835 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.986 .014 .986 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.753 .247 .753 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.743 .257 .743 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.987 .013 .987 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.656 .344 .656 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.798 .202 .798 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.98 .02 .98 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.982 .018 .982 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.897 .103 .897 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.475 .525 .475 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.689 .311 .689 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.549 .451 .549 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.537 .463 .537 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.624 .376 .624 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.844 .156 .844 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.88 .12 .88 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.986 .014 .986 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.55 .45 .55 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.78 .22 .78 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.423 .577 .423 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.853 .147 .853 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.808 .192 .808 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.986 .014 .986 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.712 .288 .712 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.754 .246 .754 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.63 .37 .63 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.851 .149 .851 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.573 .427 .573 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.988 .012 .988 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.898 .102 .898 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.568 .432 .568 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.41 .59 .41 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.395 .605 .395 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.909 .091 .909 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.929 .071 .929 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.708 .292 .708 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.986 .014 .986 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.551 .449 .551 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.485 .515 .485 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.521 .479 .521 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.549 .451 .549 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.295 .705 .295 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.524 .476 .524 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.635 .365 .635 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.986 .014 .986 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.643 .357 .643 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.551 .449 .551 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.899 .101 .899 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.149 .851 .149 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.76 .24 .76 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.727 .273 .727 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.52 .48 .52 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.236 .764 .236 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.332 .668 .332 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.094 .906 .094 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.15 .85 .15 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.436 .564 .436 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.274 .726 .274 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.366 .634 .366 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.76 .24 .76 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.383 .617 .383 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.413 .587 .413 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.599 .401 .599 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.916 .084 .916 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.985 .015 .985 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.215 .785 .215 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.296 .704 .296 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.291 .709 .291 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.985 .015 .985 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.624 .376 .624 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.375 .625 .375 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.212 .788 .212 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.175 .825 .175 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.462 .538 .462 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.286 .714 .286 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.901 .099 .901 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.367 .633 .367 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.102 .898 .102 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.683 .317 .683 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.284 .716 .284 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.224 .776 .224 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.502 .498 .502 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.849 .151 .849 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.434 .566 .434 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.101 .899 .101 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.225 .775 .225 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.471 .529 .471 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.276 .724 .276 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.289 .711 .289 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.849 .151 .849 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.249 .751 .249 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.187 .813 .187 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.145 .855 .145 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.984 .016 .984 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.151 .849 .151 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.327 .673 .327 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.201 .799 .201 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.575 .425 .575 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.399 .601 .399 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.984 .016 .984 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.448 .552 .448 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.339 .661 .339 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.366 .634 .366 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.418 .582 .418 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.272 .728 .272 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.221 .779 .221 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.325 .675 .325 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.44 .56 .44 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.985 .015 .985 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.719 .281 .719 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.385 .615 .385 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.505 .495 .505 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.231 .769 .231 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.898 .102 .898 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.063 .937 .063 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.248 .752 .248 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.237 .763 .237 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.423 .577 .423 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.618 .382 .618 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.157 .843 .157 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.985 .015 .985 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.312 .688 .312 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.731 .269 .731 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.928 .072 .928 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.492 .508 .492 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.464 .536 .464 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.363 .637 .363 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.846 .154 .846 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.159 .841 .159 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.294 .706 .294 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.409 .591 .409 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.654 .346 .654 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.153 .847 .153 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.291 .709 .291 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.396 .604 .396 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.433 .567 .433 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.985 .015 .985 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.214 .786 .214 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.985 .015 .985 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.89 .11 .89 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.468 .532 .468 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.406 .594 .406 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.264 .736 .264 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.605 .395 .605 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.32 .68 .32 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.896 .104 .896 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.453 .547 .453 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.484 .516 .484 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.486 .514 .486 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.5 .5 .5 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.745 .255 .745 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.459 .541 .459 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.264 .736 .264 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.154 .846 .154 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.188 .812 .188 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.415 .585 .415 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.707 .293 .707 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.985 .015 .985 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.895 .105 .895 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.336 .664 .336 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.202 .798 .202 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.43 .57 .43 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.752 .248 .752 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.512 .488 .512 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.985 .015 .985 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.408 .592 .408 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.762 .238 .762 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.9 .1 .9 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.985 .015 .985 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.289 .711 .289 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.358 .642 .358 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.889 .111 .889 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.382 .618 .382 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.478 .522 .478 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.698 .302 .698 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.376 .624 .376 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.541 .459 .541 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.791 .209 .791 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.62 .38 .62 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.612 .388 .612 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.721 .279 .721 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.397 .603 .397 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.923 .077 .923 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.695 .305 .695 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.507 .493 .507 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.471 .529 .471 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.985 .015 .985 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.694 .306 .694 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.411 .589 .411 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.984 .016 .984 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.907 .093 .907 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.777 .223 .777 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.906 .094 .906 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.406 .594 .406 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.884 .116 .884 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.684 .316 .684 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.571 .429 .571 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.986 .014 .986 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.566 .434 .566 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.493 .507 .493 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.986 .014 .986 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.742 .258 .742 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.981 .019 .981 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.987 .013 .987 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.626 .374 .626 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.983 .017 .983 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.499 .501 .499 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.984 .016 .984 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.507 .493 .507 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.757 .243 .757 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.587 .413 .587 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.869 .131 .869 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.883 .117 .883 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.697 .303 .697 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.637 .363 .637 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.689 .311 .689 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.817 .183 .817 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.875 .125 .875 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.805 .195 .805 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.818 .182 .818 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.982 .018 .982 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.674 .326 .674 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.894 .106 .894 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.983 .017 .983 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.921 .079 .921 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.908 .092 .908 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.679 .321 .679 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.908 .092 .908 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.889 .111 .889 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.718 .282 .718 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.984 .016 .984 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.982 .018 .982 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.987 .013 .987 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.889 .111 .889 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.985 .015 .985 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.985 .015 .985 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.984 .016 .984 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.985 .015 .985 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.984 .016 .984 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.985 .015 .985 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo/4n`03o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo/4nook1?/01_ok1?/00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003on`Ck
oo/4n`07oo/4n`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?oo0?l0_l0000@oo`3o003o`000?ok1?_on`Ck00Oon`Ck00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003oiA[UonDJiOl0000>oo`3o003o`000?ok1?_on`Ck00Won`Ck00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ok1?/03ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onDJiOoU6^D00_oU6^D00ol0003oo0?loo`3o00;oo`3o003o`000?ok
1?_on`Ck00Won`Ck00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ok1?_on`Ck00kon`Ck00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oU6^GoiA[U00?oiA[U00?o0000
oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onDJiOoU6^D01OoU6^D00ol0003oo0?loo`3o008oo`3o003o`000?ok1?_on`Ck
00_on`Ck00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiA[UonDJi@06onDJi@03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo/4nook1?/03?ok1?/00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ok1?/00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onDJiOoU6^D02?oU6^D00ol0003oo0?loo`3o005oo`3o003o`000?ok1?_on`Ck00con`Ck
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oV6NKo0000013on`Ck00?o0000oo`3o?ol0o`02?ol
0o`9o`0000coiA[U00Co0000oo`3o?ol0ocoo0?l0ol0000@oo/4n`03o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onHIiP03o`000?ok
1?_on`Ck00con`Ck00?o0000oo`3o?ol0o`02Ool0o`00ol0003ohacSon<Lh`05on<Lh`03o`000?oU
6^GoiA[U00_oiA[U0ol00003on<Lh`03o`000?ok1?_on`Ck00con`Ck0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onHIi_oV6NH00ooV6NH00ol0003on`Ckoo/4n`0;oo/4n`;o00002ool0o`00ol0003ohacSon<Lh`06
on<Lh`03o`000?oU6^GoiA[U00[oiA[U00?o0000on<LhooS7><01?oS7><00ol0003on`Ckoo/4n`0:
oo/4n`04o`000?oR7N;ohQgRon8MhP;o00002_ok1?/2o`000003on8Mh_l0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWVonHIiP05onHIiP03o`000?ok1?_o
n`Ck00Won`Ck00?o0000onDJiOl000002ool0o`00ol0003ohacSon<Lh`06on<Lh`03o`000?oU6^Go
iA[U00WoiA[U00?o0000on<LhooS7><01_oS7><00ol0003on`Ckoo/4n`08oo/4n`03o`000?oR7N;o
hQgR00CohQgR0_l00005oo/4n`?o00001?oR7N800ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008onHIiP03o`000?ok1?_on`Ck00Oon`Ck0_l00003onDJ
i@03o`000?ol0ocoo0?l00Ooo0?l00?o0000on<LhooS7><01ooS7><00ol0003oiA[UonDJi@09onDJ
i@03o`000?oS7>?ohacS00OohacS00?o0000oo/4nook1?/01Ook1?/2o`0000WohQgR0_l000000ook
1?_o0000o`000007on8MhP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000onHIi_oV
6NH02?oV6NH00ol0003on`Ckoo/4n`06oo/4n`03o`000?oU6^GoiA[U00?oiA[U00?o0000oo`3o?ol
0o`01ool0o`00ol0003ohacSon<Lh`08on<Lh`03o`000?oU6^GoiA[U00OoiA[U00?o0000on<LhooS
7><02OoS7><00ol0003on`Ckoo/4n`03oo/4n`03o`000?oR7N;ohQgR00_ohQgR00?o0000on8Mh_oR
7N801ooR7N800ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWVo`000005oo`3o0;o00002ooV6NH2o`0000Kon`Ck
00?o0000onDJiOoU6^D01OoU6^D00ol0003oo0?loo`3o006oo`3o003o`000?oS7>?ohacS00SohacS
00?o0000onDJiOoU6^D01_oU6^D00ol0003ohacSon<Lh`0;on<Lh`05o`000?ok1?_on`Ckoo/4nol0
00003_oR7N800ol0003ohQgRon8MhP08on8MhP03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oV6NKoiQWVonHIi_l0
00000ool0o`00ol0003oiQWVonHIiP0:onHIiP04o`000?oI9]WofBKIo`0000?on`Ck0_l00008onDJ
i@03o`000?ol0ocoo0?l00Koo0?l00?o0000on<LhooS7><02OoS7><00ol0003oiA[UonDJi@05onDJ
i@03o`000?oS7>?ohacS00cohacS00?o0000oo/4nol000003ooR7N800ol0003ohQgRon8MhP08on8M
hP03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWVonHIiP03onHIiP03o`000?ol0oco000000_o
iQWV0_l00004omTVf@03o`000?ok1?_o000000_oiA[U00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
hacSon<Lh`09on<Lh`03o`000?oU6^GoiA[U00CoiA[U00?o0000on<LhooS7><03_oS7><00ol0003o
hQgRon8MhP0>on8MhP03o`000?oR7N;ohQgR00WohQgR00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000onHIi_oV6NH0
1?oV6NH00ol0003oiQWVonHIiP09onHIiP03o`000?oI9]WofBKI00GofBKI00?o0000onDJiOoU6^D0
2_oU6^D00ol0003oo0?loo`3o005oo`3o003o`000?oS7>?ohacS00[ohacS00?o0000onDJiOoU6^D0
0ooU6^D00ol0003ohacSon<Lh`0>on<Lh`03o`000?oR7N;ohQgR00gohQgR00?o0000on8Mh_oR7N80
2_oR7N800ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWVonHI
iP05onHIiP03o`000?oV6NKoiQWV00OoiQWV0_l00008omTVf@03o`000?oU6^GoiA[U00_oiA[U00?o
0000oo`3o?ol0o`01?ol0o`00ol0003ohacSon<Lh`0:on<Lh`04o`000?oU6^GoiA[UonDJi@?o0000
3ooS7><00ol0003ohQgRon8MhP0>on8MhP03o`000?oR7N;ohQgR00[ohQgR00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oV6NKoiQWV00OoiQWV00?o0000onHIi_oV6NH01?oV6NH2o`0000_ofBKI1?l0
0009onDJi@03o`000?ol0ocoo0?l00?oo0?l00?o0000on<LhooS7><02ooS7><01?l0003oiA[Uo`00
0?l00003ol0o`0;o00003?oS7><2o`00013ohQgR00?o0000on8Mh_oR7N802ooR7N800ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003oiQWV
onHIiP07onHIiP03o`000?oV6NKoiQWV00?oiQWV00?o0000omTVfOoI9]T02ooI9]T01?l0003o^4Nh
okQ7^?nhAkP5o`0000GoiA[U00?o0000oo`3o?ol0o`00_ol0o`00ol0003ohacSon<Lh`0<on<Lh`03
o`000?o0?l3o`3o000Go`3o00_l00008on<Lh`;o00000_naC[400ol0003ohQgRon8MhP0=on8MhP03
o`000?oR7N;ohQgR00_ohQgR00?o0000oo/4nook1?/03?ok1?/00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003oiQWVonHIiP09onHIiP03o`000?oV6NKoiQWV00;o0000
3OoI9]T00ol0003o^4NhokQ7^007okQ7^0Ko00000_ol0o`4o`0000gohacS00?o0000ol0o`?o0?l00
1oo0?l02o`0000GohacS00?o0000ok5>/OnaC[400onaC[400ol0003ohQgRon8MhP0<on8MhP03o`00
0?oR7N;ohQgR00cohQgR00?o0000oo/4nook1?/02_ok1?/00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oV6NKoiQWV00WoiQWV00?o
0000onHIi_l000003ooI9]T00ol0003o^4NhokQ7^00<okQ7^0?o00001?oH9mP3o`0000WohacS00?o
0000ol0o`?o0?l002_o0?l02o`000003on<Lhol0003o000000Oo/Dja00?o0000on8Mh_oR7N802ooR
7N800ol0003ohQgRon8MhP0<on8MhP03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000
omTVfOoI9]T03_oI9]T00ol0003o^4NhokQ7^00=okQ7^003o`000?oH9mSof2OH00Kof2OH0ol00005
on<Lh`03o`000?o0?l3o`3o000go`3o000?o0000ok5>/OnaC[402?naC[400ol0003ohQgRon8MhP09
on8MhP03o`000?oR7N;ohQgR00gohQgR00Co0000oo/4nook1?_on`Ck1Ol00003onPGj003o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
onHIi_oV6NH02ooV6NH2o`0000oofBKI00?o0000okQ7^?nhAkP03OnhAkP00ol0003of2OHomPWf00:
omPWf0?o000000?ohacSo`000?o0?l003oo0?l000ol0003o/Djaok5>/@09ok5>/@03o`000?oR7N;o
hQgR00SohQgR00?o0000on8Mh_oR7N803_oR7N83o`0000Soj1OX00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oV6NKoiQWV00SoiQWV0ol000000onj
AK[o0000omTVf@0>omTVf@03o`000?nhAkSo^4Nh00go^4Nh00?o0000omPWf?oH9mP03OoH9mP00ol0
003o`3o0ol0o`00?ol0o`003o`000?naC[7o/Dja00[o/Dja2ol0000;on8MhPGo00003?oX5nP00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oiA[Uo`000?ol0oco0000
00SoiQWV0ol00005okY5^P03o`000?oI9]WofBKI00cofBKI00?o0000okQ7^?nhAkP03OnhAkP00ol0
003of2OHomPWf00=omPWf0;o00004?o0?l000ol0003o/Djaok5>/@0:ok5>/@03o`000?n_D:oo[e2_
00Oo[e2_00?o0000on8Mh_oR7N800_oR7N87o`0000Co/Tfb00?o0000onPGj?oX5nP02_oX5nP00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003oiA[UonDJiOoU6^D2o`00
00GoiQWV0ol00009okY5^P;o00002ooI9]T00ol0003o^4NhokQ7^00=okQ7^003o`000?oH9mSof2OH
00gof2OH00Co0000oki1__nn@Kko00003oo0?l000ol0003o/Djaok5>/@09ok5>/@03o`000?n_D:oo
[e2_00Wo[e2_1?l0000;ok9=/P03o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000onDJiOoU6^D01?oU6^D00ol0003oiQWVo`000002o`00
00co^TFj00Co0000oimPWol0003o00002OoI9]T00ol0003o^4NhokQ7^00=okQ7^003o`000?oH9mSo
f2OH00gof2OH00Go0000oki1__nn@Kko_T6no`00000=ol0o`003o`000?naC[7o/Dja00[o/Dja00?o
0000ojm@[on_D:l02On_D:l00ol0003o/Tfbok9=/P0<ok9=/P03o`000?oX5nSoj1OX00[oj1OX00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000onDJiOoU6^D01_oU6^D0
0ol0003o^TFjokY5^P0<okY5^P03o`000?nOH9ooWf2O00;oWf2O0_l00007omTVf@03o`000?nhAkSo
^4Nh00co^4Nh00?o0000omPWf?oH9mP03OoH9mP00ol0003o_T6noki1_P03oki1_P03o`000?o0?l3o
`3o000[o`3o000?o0000ok5>/OnaC[402_naC[400ol0003o[e2_ojm@[`09ojm@[`03o`000?nbCK;o
/Tfb00co/Tfb00?o0000onPGj?oX5nP02ooX5nP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oiA[UonDJi@06onDJi@03o`000?njAK[o^TFj00_o^TFj00?o0000oimP
WonOH9l01OnOH9l00ol0003ofBKIomTVf@03omTVf@03o`000?nhAkSo^4Nh00go^4Nh00?o0000omPW
f?oH9mP03OoH9mP00ol0003o_T6noki1_P04oki1_P03o`000?o0?l3o`3o000Wo`3o000?o0000ok5>
/OnaC[402OnaC[400ol0003o[e2_ojm@[`0:ojm@[`03o`000?nbCK;o/Tfb00co/Tfb00?o0000onPG
j?oX5nP02ooX5nP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iA[UonDJi@07onDJi@03o`000?njAK[o^TFj00_o^TFj00?o0000oimPWonOH9l01_nOH9l2o`0000?o
fBKI00?o0000okQ7^?nhAkP03OnhAkP00ol0003of2OHomPWf00<omPWf003o`000?nn@Kko_T6n00Ko
_T6n00?o0000ol0o`?o0?l002?o0?l000ol0003o/Djaok5>/@09ok5>/@03o`000?n_D:oo[e2_00[o
[e2_00?o0000ok9=/_nbCK803?nbCK800ol0003oj1OXonPGj00;onPGj003o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000onDJiOoU6^D02?oU6^D00ol0003o^TFjokY5^P0:okY5^P03o`00
0?nOH9ooWf2O00WoWf2O0_l000000ooI9]Wo0000okQ7^00<okQ7^0?o00003_oH9mP00ol0003o_T6n
oki1_P07oki1_P03o`000?o0?l3o`3o000Oo`3o000?o0000ok5>/OnaC[402OnaC[400ol0003o[e2_
ojm@[`0;ojm@[`03o`000?nbCK;o/Tfb00co/Tfb00?o0000onPGj?oX5nP02_oX5nP00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000onDJiOoU6^D02_oU6^D00ol0003o^TFjokY5
^P09okY5^P03o`000?nOH9ooWf2O00_oWf2O00?o0000okQ7^?nhAkP02_nhAkP2o`0000?oWV6N00?o
0000omPWf?oH9mP02_oH9mP00ol0003o_T6noki1_P09oki1_P03o`000?o0?l3o`3o000Ko`3o000?o
0000ok5>/OnaC[402?naC[400ol0003o[e2_ojm@[`0<ojm@[`03o`000?nbCK;o/Tfb00co/Tfb00?o
0000onPGj?oX5nP02_oX5nP00ol0003oo0?loo`3o004oo`3o0Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000okY5^_njAKX02?njAKX0
0ol0003oWf2OoimPW`0<oimPW`03o`000?nhAkSo^4Nh00So^4Nh0_l00006oiiQWP;o00002_oH9mP0
0ol0003o_T6noki1_P0:oki1_P03o`000?o0?l3o`3o000Go`3o000?o0000ok5>/OnaC[402?naC[40
0ol0003o[e2_ojm@[`0<ojm@[`03o`000?nbCK;o/Tfb00co/Tfb00?o0000onPGj?oX5nP02ooX5nP0
0ol0003oo0?lo`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
onDJi@03o`000?njAK[o^TFj00Oo^TFj00?o0000oimPWonOH9l03_nOH9l00ol0003o^4NhokQ7^004
okQ7^0?o00002_nNHIh00ol0003of2OHomPWf007omPWf003o`000?nn@Kko_T6n00_o_T6n00?o0000
ol0o`?o0?l000oo0?l000ol0003o/Djaok5>/@09ok5>/@03o`000?n_D:oo[e2_00co[e2_00?o0000
ok9=/_nbCK803?nbCK800ol0003oj1OXonPGj00;onPGj0;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oiA[UonDJi@0<onDJi@03o`000?njAK[o^TFj00Oo^TFj00?o0000oimPWonOH9l03onOH9l01?l0
003o^4NhokQ7^?nhAkP2o`0000koWV6N0_l00006omPWf003o`000?nn@Kko_T6n00go_T6n00?o0000
ol0o`?o0?l000_o0?l000ol0003o/Djaok5>/@08ok5>/@03o`000?n_D:oo[e2_00co[e2_0ol0000=
ok9=/P03o`000?oX5nSoj1OX00_oj1OX00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooiA[U00?o0000okY5^_njAKX01_njAKX00ol0003oWf2OoimPW`0@oimPW`Co00004_nNHIh00ol0
003of2OHomPWf003omPWf003o`000?nn@Kko_T6n00ko_T6n00Go0000ol0o`?o0?l3o`3o0o`000005
ok5>/@Oo00003?n_D:l01Ol0003oOh1oogn0OomoP7oo000000co/Tfb00?o0000onPGj?oX5nP02?oX
5nP3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooiA[U00?o0000okY5^_njAKX01_njAKX00ol0003oWf2OoimPW`0=
oimPW`?o000000CoMXUfo`000?l0003o00004onNHIh2o`0000;of2OH00?o0000oki1__nn@Kh04?nn
@Kh00ol0003o`3o0o`000006o`0000Oo/Dja00?o0000ojm@[on_D:l02?n_D:l00ol0003oOh1oogn0
O`03ogn0O`;o00002?nbCK83o`0000Koj1OX1?l00002on<Lh`03o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003oiA[Uo`000?nfBKH3o`0000goiA[U00?o0000okY5^_njAKX01?njAKX00ol0003oWf2OoimP
W`0;oimPW`?o00000omfRGH01Ol0003oN8Mho`000?mbSG;o000001CoWV6N00?o0000omPWf?l00000
4onn@Kh00ol0003o/Djaok5>/@0=ok5>/@03o`000?n_D:oo[e2_00Go[e2_0_l00008ogn0O`03o`00
0?nbCK;o/Tfb00Go00000on`Ck000ol0003oj1OXonPGj003o`0000OohacS00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oU6^GoiA[Uo`0000Co]TVf0ol0000:onDJi@03o`000?njAK[o^TFj00?o^TFj
00?o0000oimPWonOH9l02OnOH9l3o`0000GoMXUf00Co0000ogR7N?mhQgSo00000_mbSG800ol0003o
WV6NoiiQWP0BoiiQWP03o`000?nn@Kko_T6n01;o_T6n00?o0000ok5>/OnaC[403_naC[400ol0003o
[e2_ojm@[`03ojm@[`03o`000?moP7ooOh1o00WoOh1o0_l00009ok1?/0;o00002_oS7><00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000onDJiOoU6^GoiA[Uo`000007okI9]P;o00001ooU6^D5o`0000;o
^TFj00?o0000oimPWonOH9l01_nOH9l3o`0000SoMXUf00Co0000ogR7N?mhQgSo00000ombSG800ol0
003oWV6NoiiQWP0AoiiQWP03o`000?nn@Kko_T6n017o_T6n00?o0000ok5>/OnaC[404?naC[401Ol0
003o[e2_ojm@[on_D:oo000000coOh1o00?o0000ok1?/?n`Ck002?n`Ck000ol0003ohacSon<Lh`0:
on<Lh`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CoiA[U00?o0000okI9]_nfBKH01onfBKH3o`00
0004onDJiOl0003o0000o`0000GoY5^T0_l00006oimPW`?o00002_mfRGH01Ol0003oN8MhogR7N?mh
QgSo000000CoLXeb00?o0000oiiQW_nNHIh04?nNHIh00ol0003o_T6noki1_P0Aoki1_P03o`000?na
C[7o/Dja017o/Dja00?o0000ojm@[ol000003OmoP7l00ol0003o/4n`ok1?/008ok1?/003o`000?oS
7>?ohacS00[ohacS00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oU6^GoiA[U00CoiA[U00?o0000
okI9]_nfBKH02_nfBKH00ol0003oY5^TojAKY008ojAKY003o`000?nOH9ooWf2O00?o00003OmfRGH0
1Ol0003oN8MhogR7N?mhQgSo000000GoLXeb00?o0000oiiQW_nNHIh03onNHIh00ol0003o_T6noki1
_P0Aoki1_P03o`000?naC[7o/Dja01;o/Dja00?o0000ogn0OomoP7l03?moP7l00ol0003o/4n`ok1?
/008ok1?/003o`000?oS7>?ohacS00_ohacS00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000onDJiOoU6^D01OoU6^D0
0ol0003o]TVfokI9]P0:okI9]P03o`000?nTFjCoY5^T00WoY5^T0_l0000?ogJ9MP03o`000?mhQgSo
N8Mh00;oN8Mh00?o0000og:=L_mbSG801?mbSG800ol0003oWV6NoiiQWP0=oiiQWP?o00004Onn@Kh0
0ol0003o/Djaok5>/@0Cok5>/@03o`000?moP7ooOh1o00_oOh1o00?o0000ok1?/?n`Ck002On`Ck00
0ol0003ohacSon<Lh`0;on<Lh`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo/4nook1?_on`Cko`000008oo`3o0;o00002?oU6^D0
0ol0003o]TVfokI9]P0:okI9]P03o`000?nTFjCoY5^T00WoY5^T00?o0000ogJ9M_mfRGH03OmfRGH0
0ol0003oN8MhogR7N003ogR7N003o`000?mbSG;oLXeb00GoLXeb00?o0000oiiQW_nNHIh02_nNHIh2
o`0000?oYeRW00?o0000oki1__nn@Kh03_nn@Kh00ol0003o/Djaok5>/@0Cok5>/@03o`000?moP7oo
Oh1o00_oOh1o00?o0000ok1?/?n`Ck002On`Ck000ol0003ohacSon<Lh`0;on<Lh`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo/4
nook1?/00ook1?/2o`0000Goo0?l00?o0000onDJiOoU6^D01ooU6^D2o`0000_o]TVf00?o0000ojAK
Y?nTFj@02onTFj@00ol0003oMXUfogJ9MP0<ogJ9MP03o`000?mhQgSoN8Mh00?oN8Mh00?o0000og:=
L_mbSG801_mbSG800ol0003oWV6NoiiQWP07oiiQWP;o00001_nWF:L2o`0000ko_T6n00?o0000ok5>
/OnaC[404onaC[400ol0003oOh1oogn0O`0;ogn0O`03o`000?n`Ck3o/4n`00Wo/4n`00?o0000on<L
hooS7><03?oS7><00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ok1?_on`Ck00Kon`Ck00Go0000oo`3o?ol0ocoo0?lo`000009onDJ
i@03o`000?n`Ck3o000000_o]TVf00?o0000ojAKY?nTFj@02onTFj@00ol0003oMXUfogJ9MP0;ogJ9
MP03o`000?mhQgSoN8Mh00CoN8Mh00?o0000og:=L_mbSG801ombSG800ol0003oWV6NoiiQWP05oiiQ
WP03o`000?nWF:OoYeRW00SoYeRW00?o0000oki1__nn@Kh02_nn@Kh00ol0003o/Djaok5>/@0Dok5>
/@03o`000?moP7ooOh1o00_oOh1o00?o0000ok1?/?n`Ck002On`Ck000ol0003ohacSon<Lh`0<on<L
h`03o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo/4nook1?/01ook1?/00ol0003oo0?lo`000009onDJi@04o`000?n`Ck3o/4n`o`00
00_o]TVf00?o0000ojAKY?nTFj@02onTFj@00ol0003oMXUfogJ9MP0;ogJ9MP03o`000?mhQgSoN8Mh
00CoN8Mh00?o0000og:=L_mbSG802?mbSG800ol0003oWV6NoiiQWP02oiiQWP;o00003?nWF:L2o`00
00[o_T6n00?o0000ok5>/OnaC[405?naC[400ol0003oOh1oogn0O`0;ogn0O`03o`000?n`Ck3o/4n`
00Wo/4n`00?o0000on<LhooS7><03OoS7><00ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo/4nook1?/02Ook1?/00ol0003oiA[UonDJi@07onDJi@03
o`000?n`Ck3o/4n`00;o/4n`00?o0000okI9]_nfBKH02?nfBKH00ol0003oY5^TojAKY00<ojAKY003
o`000?mfRGKoMXUf00WoMXUf00?o0000ogR7N?mhQgP01OmhQgP00ol0003oLXebog:=LP09og:=LP04
o`000?nNHIko0000o`00013oYeRW0_l00008oki1_P03o`000?naC[7o/Dja01Co/Dja0ol0000;ogn0
O`03o`000?n`Ck3o/4n`00Wo/4n`00?o0000on<LhooS7><03OoS7><01?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo/4
nook1?/02Ook1?/00ol0003oiA[UonDJi@06onDJi@03o`000?n`Ck3o/4n`00?o/4n`00?o0000okI9
]_nfBKH02?nfBKH00ol0003oY5^TojAKY00;ojAKY0;o00002_mfRGH00ol0003oN8MhogR7N006ogR7
N003o`000?mbSG;oLXeb00[oLXeb00?o0000ojMHYonWF:L04_nWF:L00ol0003o_T6noki1_P04oki1
_P03o`000?naC[7o/Dja01Go/Dja00?o0000oj1OX?nPGj001Ol00005ogn0O`03o`000?n`Ck3o/4n`
00[o/4n`00?o0000on<LhooS7><03_oS7><3o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo/4nook1?/02ook1?/00ol0003oiA[UonDJi@04onDJi@03
o`000?n`Ck3o/4n`00Co/4n`00?o0000okI9]_nfBKH01onfBKH00ol0003oY5^TojAKY00;ojAKY004
o`000?n5NXGoQGZ5o`0000WoMXUf00?o0000ogR7N?mhQgP01_mhQgP00ol0003oLXebog:=LP0:og:=
LP03o`000?nWF:OoYeRW01?oYeRW0_l00003oki1_PCo00005?naC[400ol0003oX5nPoj1OX006oj1O
X0Co000000?oOh1oo`000?n`Ck002on`Ck000ol0003ohacSon<Lh`0>on<Lh`03o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo/4nook
1?/02ook1?/00ol0003oiA[UonDJi@03onDJi@03o`000?n`Ck3o/4n`00Go/4n`00?o0000okI9]_nf
BKH01onfBKH00ol0003oY5^TojAKY009ojAKY0;o00001?n5NXD00ol0003oMXUfogJ9MP05ogJ9MP03
o`000?mhQgSoN8Mh00OoN8Mh00?o0000og:=L_mbSG802_mbSG800ol0003oYeRWojMHY`0EojMHY`03
o`000?nn@Kko000000Co/Tfb0ol0000@ok5>/@03o`000?nPGj3oX5nP00_oX5nP0_l0000<ok1?/003
o`000?oS7>?ohacS00cohacS0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000onDJiOoU6^D00_oU6^D00ol0003o/4n`
ok1?/006ok1?/003o`000?nfBKKo]TVf00Oo]TVf00?o0000ojAKY?nTFj@02?nTFj@00ol0003oQGZ5
ohEjQ@05ohEjQ@03o`000?mfRGKoMXUf00CoMXUf00?o0000ogR7N?mhQgP01omhQgP00ol0003oLXeb
og:=LP0:og:=LP03o`000?nWF:OoYeRW01KoYeRW00?o0000ok9=/_nbCK801_nbCK83o`0000co/Dja
00?o0000oj1OX?nPGj003OnPGj000ol0003o/4n`ok1?/009ok1?/0Go00002OoS7><2o`000003on<L
hol0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo/4nook1?/03?ok1?/3o`000003onDJiOl0003o/4n`00Wo/4n`00?o0000okI9]_nfBKH01_nf
BKH00ol0003oY5^TojAKY007ojAKY003o`000?n5NXGoQGZ500OoQGZ500?o0000ogJ9M_mfRGH00_mf
RGH00ol0003oN8MhogR7N008ogR7N003o`000?mbSG;oLXeb00WoLXeb00?o0000ojMHYonWF:L05onW
F:L00ol0003o/Tfbok9=/P09ok9=/P?o00002OnaC[400ol0003oX5nPoj1OX00>oj1OX0Ko00001?n`
Ck000ol0003o[E:]ojeB[@03ojeB[@Go00000_oS7><2o`0000CohacS00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`0<
oo/4n`05o`000?oE:]GoeB[EomDZeOl000002on`Ck000ol0003o]TVfokI9]P06okI9]P03o`000?nT
FjCoY5^T00GoY5^T0_l0000;ohEjQ@04o`000?mfRGKoMXUfo`0000_oN8Mh00?o0000og:=L_mbSG80
2OmbSG800ol0003oYeRWojMHY`0FojMHY`03o`000?nbCK;o/Tfb00go/Tfb0ol00005ok5>/@03o`00
0?nPGj3oX5nP00ooX5nP00?o0000oj=LXonSG:<00onSG:<4o`0000_o[E:]0_l00006on<Lh`03o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo/4nook1?/02ook1?/00ol0003oeB[EomDZe@02omDZe@ko00001_nfBKH00ol0003oY5^TojAK
Y005ojAKY003o`000?n5NXGoQGZ500coQGZ500?o0000ogJ9M_l000002omhQgP00ol0003oLXebog:=
LP07og:=LP?o00006?nWF:L00ol0003o/Tfbok9=/P0@ok9=/P?o000000?o/Djao`000?nPGj004?nP
Gj000ol0003oXebSoj=LX`07oj=LX`03o`000?n]DZgo[E:]00[o[E:]00?o0000on<LhooS7><01OoS
7><00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ok1?_on`Ck00Won`Ck0_l00005omDZe@03o`000?n<LhcoS7><00_oS7><0_l00004
okI9]P03o`000?nTFjCoY5^T00?oY5^T0_l0000@ohEjQ@03o`000?mhQgSoN8Mh00[oN8Mh00?o0000
og:=L_mbSG800ombSG84o`0000;oHYeR00?o0000ojMHYonWF:L05OnWF:L00ol0003o/Tfbok9=/P0D
ok9=/P03o`000?nPGj3oX5nP013oX5nP00?o0000oj=LXonSG:<01onSG:<00ol0003o[E:]ojeB[@0:
ojeB[@03o`000?oS7>?ohacS00GohacS00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oE:]GoeB[E
00GoeB[E00?o0000ohacS?n<Lh`03On<Lh`6o`0000?oY5^T00?o0000ohEjQOn5NXD04?n5NXD00ol0
003oN8MhogR7N00:ogR7N003o`000?mbSG;o000000?o00001omRWF800ol0003oYeRWojMHY`0DojMH
Y`03o`000?nbCK;o/Tfb01Co/Tfb00?o0000oj1OX?nPGj003onPGj000ol0003oXebSoj=LX`08oj=L
X`03o`000?n]DZgo[E:]00[o[E:]00?o0000on<LhooS7><01OoS7><00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omDZeOoE:]D01_oE:]D00ol0003oS7><ohacS00=ohacS003o`000?nQGZ7oXEjQ00?o
XEjQ00?o0000ojAKY?l000004on5NXD4o`0000WoN8Mh0_l0000<of:MHP03o`000?nWF:OoYeRW01?o
YeRW00?o0000ok9=/_nbCK805OnbCK800ol0003oX5nPoj1OX00>oj1OX003o`000?nSG:?oXebS00So
XebS00?o0000ojeB[On]DZd02On]DZd00ol0003ohacSon<Lh`07on<Lh`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo/4n`03o`00
0?oE:]GoeB[E00SoeB[E00?o0000ohacS?n<Lh`02on<Lh`00ol0003oXEjQoj5NX@05oj5NX@03o`00
0?n5NXGoQGZ501;oQGZ500Co0000ofn@Kom_T6ooKi1_1Ol00003ogR7N003o`000?mRWF;oHYeR00go
HYeR0ol0000@ojMHY`;o00006?nbCK800ol0003oX5nPoj1OX00=oj1OX003o`000?nSG:?oXebS00Wo
XebS00?o0000ojeB[On]DZd02On]DZd00ol0003ohacSon<Lh`07on<Lh`03o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_oeB[E00?o0000ohacS?n<Lh`02_n<Lh`00ol0003oXEjQoj5NX@06oj5NX@03o`00
0?n5NXGoQGZ5017oQGZ500?o0000ofn@Kom_T6l01om_T6l3o`00013oHYeR00?o0000oebSG?mLXe`0
1Ol00009ojMHY`;o000000?oLhaco`000?nbCK805onbCK800ol0003oX5nPoj1OX00=oj1OX003o`00
0?nSG:?oXebS00WoXebS00?o0000ojeB[On]DZd02?n]DZd2o`0000[ohacS00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?oX5nSoj1OX00;oj1OX00?o0000omDZeOoE:]D02OoE:]D00ol0003oS7><ohac
S00:ohacS003o`000?nQGZ7oXEjQ00OoXEjQ00?o0000ohEjQOn5NXD03on5NXD00ol0003oKi1_ofn@
K`0:ofn@K`03o`000?mRWF;oHYeR00goHYeR00?o0000oebSG?mLXe`01_mLXe`4o`0000CoYeRW00?o
0000og><LomcS7<00_mcS7<00ol0003o/Tfbok9=/P0Fok9=/P03o`000?nPGj3oX5nP00_oX5nP00?o
0000oj=LXonSG:<02onSG:<00ol0003o[E:]ojeB[@06ojeB[@03o`000?ngB;Oo000000[ohacS00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?oX5nSoj1OX00?oj1OX00?o0000omDZeOoE:]D02?oE:]D=
o`0000[oXEjQ00?o0000ohEjQOn5NXD03on5NXD00ol0003oKi1_ofn@K`0;ofn@K`03o`000?mRWF;o
HYeR00coHYeR00?o0000oebSG?mLXe`02_mLXe`4o`0000GoLhac00?o0000ok9=/_nbCK805_nbCK80
0ol0003oX5nPoj1OX00:oj1OX003o`000?nSG:?oXebS00coXebS00?o0000ojeB[On]DZd01?n]DZd2
o`0000?o]dRg00?o0000on<LhooS7><02?oS7><00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onPG
j?oX5nP00ooX5nP00ol0003oeB[EomDZe@07omDZe@03o`000?n9MXWoRGJ900WoRGJ900?o0000oj5N
XOnQGZ402OnQGZ400ol0003oQGZ5ohEjQ@0=ohEjQ@03o`000?m_T6ooKi1_00coKi1_00?o0000of:M
H_mRWF803?mRWF800ol0003oG:=LoebSG00;oebSG003o`000?m3_4?o000000KoLhac00?o0000ok9=
/_nbCK805_nbCK800ol0003oX5nPoj1OX009oj1OX003o`000?nSG:?oXebS00coXebS00?o0000ojeB
[On]DZd00on]DZd00ol0003o]dRgokM8]`03okM8]`03o`000?oS7>?ohacS00SohacS00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?oX5nSoj1OX00Coj1OX00?o0000omDZeOoE:]D01_oE:]D00ol0003o
RGJ9ohUfR@08ohUfR@03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ohEjQOn5NXD02?n5NXD4o`0000oo
Ki1_00?o0000of:MH_mRWF802omRWF800ol0003oG:=LoebSG00;oebSG004o`000?m3_4?o@ka3o`00
00OoLhac00?o0000ok9=/_nbCK805OnbCK800ol0003oX5nPoj1OX008oj1OX003o`000?nSG:?oXebS
00goXebS00?o0000ojeB[On]DZd00_n]DZd00ol0003o]dRgokM8]`05okM8]`03o`000?oS7>?ohacS
00OohacS00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?oX5nSoj1OX00Goj1OX00?o0000omDZeOoE
:]D01OoE:]D00ol0003oRGJ9ohUfR@08ohUfR@03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ohEjQOn5
NXD00on5NXD5o`0000?oKi1_00?o0000ofn@Kom_T6l03_m_T6l00ol0003oHYeRof:MHP0:of:MHP03
o`000?mLXecoG:=L00[oG:=L00Go0000od>l@om3_4?o@ka3o`000007og><L`03o`000?nbCK;o/Tfb
01Go/Tfb00?o0000oj1OX?nPGj002?nPGj000ol0003oXebSoj=LX`0=oj=LX`03o`000?n]DZgo[E:]
00;o00002?ngB;L00ol0003ohacSon<Lh`08on<Lh`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oj1OXonPGj005onPGj003o`000?oE:]GoeB[E00Go
eB[E00?o0000ohUfROn9MXT02?n9MXT00ol0003oXEjQoj5NX@0<oj5NX@Go00002Om_T6l00ol0003o
Ki1_ofn@K`0<ofn@K`;o00003?mRWF800ol0003oG:=LoebSG00:oebSG005o`000?m3_4?o@ka3od>l
@ol000002?mcS7<00ol0003o/Tfbok9=/P0Dok9=/P?o00001onPGj000ol0003oXebSoj=LX`0>oj=L
X`03o`000?n]DZgo000000_o]dRg00?o0000on<LhooS7><01_oS7><00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000onPGj?oX5nP01OoX5nP00ol0003oeB[EomDZe@04omDZe@03o`000?n9MXWoRGJ900Oo
RGJ900?o0000oj5NXOnQGZ403?nQGZ401?l0003oQGZ5ohEjQOl0000;ofn@K`03o`000?m_T6ooKi1_
00_oKi1_00Co0000oco0?olo`3oo00002_mRWF800ol0003oG:=LoebSG00:oebSG003o`000?m3_4?o
@ka300;o@ka300?o0000og><LomcS7<01_mcS7<00ol0003o/Tfbok9=/P0Aok9=/P?o00000on1OX40
0ol0003oX5nPoj1OX004oj1OX003o`000?nSG:?oXebS00goXebS1?l0000;okM8]`03o`000?oS7>?o
hacS00GohacS00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oX5nSoj1OX00Koj1OX00Co0000omDZ
eOoE:]GoeB[E1?l00008ohUfR@03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ohEjQOn5NXD00_n5NXD0
0ol0003oKi1_ofn@K`08ofn@K`03o`000?m_T6ooKi1_00[oKi1_00?o0000oco0?olo`3l00_lo`3l0
0ol0003oHYeRof:MHP03of:MHPGo00002omLXe`00ol0003o@ka3od>l@`03od>l@`03o`000?mcS7?o
Lhac00OoLhac00?o0000ok9=/_nbCK803_nbCK82o`0000OoPGj100?o0000oj1OX?nPGj000_nPGj00
0ol0003oXebSoj=LX`0=oj=LX`03o`000?n/Djco[5>/00;o[5>/00?o0000okM8]ongB;L02OngB;L0
0ol0003ohacSon<Lh`03on<Lh`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj007onPG
j0?o00001?o0?l000ol0003oRGJ9ohUfR@05ohUfR@03o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ohEj
QOn5NXD00on5NXD00ol0003oKi1_ofn@K`09ofn@K`03o`000?m_T6ooKi1_00SoKi1_00?o0000oco0
?olo`3l01?lo`3l5o`0000Co4>l@00?o0000oebSG?mLXe`02OmLXe`00ol0003o@ka3od>l@`03od>l
@`03o`000?mcS7?oLhac00SoLhac00?o0000ok9=/_nbCK802_nbCK83o`0000[oPGj100Go0000oj1O
X?nPGj3oX5nPo`00000>oj=LX`03o`000?n/Djco[5>/00Co[5>/0_l00009okM8]`03o`000?oS7>?o
hacS00;ohacS00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?oX5nSoj1OX00Ooj1OX00?o0000ol0o
`?o0?l001Oo0?l000ol0003oRGJ9ohUfR@03ohUfR@03o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ohEj
QOn5NXD01?n5NXD00ol0003oKi1_ofn@K`09ofn@K`03o`000?m_T6ooKi1_00OoKi1_00?o0000oco0
?olo`3l01Olo`3l00ol0003o4>l@oa3_4007oa3_4003o`000?mLXecoG:=L00OoG:=L00?o0000od>l
@om3_4<01?m3_4<00ol0003oLhacog><L`08og><L`03o`000?nbCK;o/Tfb00So/Tfb0_l0000>oh5n
P@Co00003?nSG:<2o`0000Wo[5>/00?o0000okM8]ongB;L01ongB;L01?l0003ohacSon<Lhol0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000onPGj?oX5nP01OoX5nP00ol0003o`3o0ol0o`007ol0o`0;o00000on9MXT00ol0
003oXEjQoj5NX@09oj5NX@03o`000?n5NXGoQGZ500KoQGZ500?o0000ofn@Kom_T6l02Om_T6l00ol0
003oKi1_ofn@K`05ofn@K`03o`000?lo`3oo?l0o00Ko?l0o00?o0000oa3_4?l@ka002?l@ka000ol0
003oG:=LoebSG006oebSG003o`000?m3_4?o@ka300Co@ka300?o0000og><LomcS7<02OmcS7<4o`00
00?o/Tfb0ol0000@oh5nP@05o`000?nm@[go_D:moke2_Ol000002_nSG:<00ol0003o[5>/ojaC[00:
ojaC[0Ko00000ongB;L00ol0003ohacSo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000onPGj?oX5nP01?oX5nP00ol0
003o`3o0ol0o`00:ol0o`004o`000?n9MXWoRGJ9o`0000[oXEjQ00?o0000ohEjQOn5NXD01on5NXD0
0ol0003oKi1_ofn@K`09ofn@K`03o`000?m_T6ooKi1_00CoKi1_00?o0000oco0?olo`3l01olo`3l0
0ol0003o4>l@oa3_4008oa3_40;o00001_mLXe`00ol0003o@ka3od>l@`05od>l@`03o`000?mcS7?o
Lhac00WoLhac00Co0000of6NHOmQWV7oHIiQ0ol0000Boh5nP@03o`000?nm@[go_D:m00?o_D:m0_l0
0006oj=LX`;o00003On/Dj`00ol0003oj1OXonPGj003onPGj0Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000onPGj?oX5nP00ooX5nP0
0ol0003o`3o0ol0o`00<ol0o`0;o00002_nQGZ400ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?m_T6oo
Ki1_00[oKi1_00?o0000ofn@Kom_T6l00_m_T6l00ol0003o?l0ooco0?`08oco0?`03o`000?l@ka3o
4>l@00Ko4>l@0_l00002occ3?003o`000?mLXecoG:=L00;oG:=L00?o0000od>l@om3_4<01_m3_4<0
0ol0003oLhacog><L`08og><L`03o`000?mQWV7oHIiQ00CoHIiQ00?o0000oh5nPOn1OX403on1OX40
0ol0003o_D:moke2_@06oke2_@;o00000onSG:<00ol0003o[5>/ojaC[00=ojaC[003o`000?oX5nSo
j1OX00Ooj1OX0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003oj1OXonPGj002onPGj003o`000?o0?l3o`3o0
00ko`3o000?o0000oj5NXOnQGZ401onQGZ400ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?m_T6ooKi1_
00WoKi1_00Go0000ofn@Kom_T6ooKi1_o`00000;oco0?`03o`000?l@ka3o4>l@00Co4>l@0_l00005
occ3?005o`000?mLXecoG:=LoebSG?l000002?m3_4<00ol0003oLhacog><L`08og><L`03o`000?mQ
WV7oHIiQ00GoHIiQ00?o0000oh5nPOn1OX403_n1OX400ol0003o_D:moke2_@08oke2_@03o`000?nS
G:?o000000oo[5>/00?o0000onPGj?oX5nP02?oX5nP01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?oX5nSoj1OXo`00017o`3o000?o0000oj5NXOnQGZ401_nQGZ400ol0003oQGZ5
ohEjQ@0;ohEjQ@03o`000?m_T6ooKi1_00WoKi1_00Co0000ofn@Kom_T6oo00003?lo`3l00ol0003o
4>l@oa3_4002oa3_40;o00002?ll`c`00ol0003oG:=Lo`000009od>l@`03o`000?mcS7?oLhac00So
Lhac00?o0000of6NHOmQWV401OmQWV400ol0003oPGj1oh5nP@0=oh5nP@03o`000?nm@[go_D:m00[o
_D:m00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003oj1OXonPGj007onPGj003o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000Bol0o`003o`00
0?nQGZ7oXEjQ00CoXEjQ00?o0000ohEjQOn5NXD03?n5NXD00ol0003oKi1_ofn@K`0:ofn@K`?o0000
3?lo`3l00ol0003o4>l@oa3_4002o`0000_o?<<l00?o0000od>l@om3_4<02?m3_4<00ol0003oLhac
og><L`07og><L`03o`000?mQWV7oHIiQ00OoHIiQ00?o0000oh5nPOn1OX403?n1OX400ol0003o_D:m
oke2_@0;oke2_@;o00003_n/Dj`00ol0003oj1OXonPGj007onPGj003o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000on/Djoo[5>/00oo[5>/00ol0003o`3o0ol0o`00?ol0o`0?o00000onQ
GZ400ol0003oQGZ5ohEjQ@0>ohEjQ@03o`000?m_T6ooKi1_00SoKi1_00Co0000odRgB?m8]dSoB;M8
0_l0000:oco0?`?o00003Oll`c`00ol0003o@ka3od>l@`08od>l@`03o`000?mcS7?oLhac00OoLhac
00?o0000of6NHOmQWV401omQWV400ol0003oPGj1oh5nP@0;oh5nP@03o`000?nm@[go_D:m00co_D:m
00?o0000om4^dOl000000_l0000:ojaC[003o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003ojaC[on/Dj`04on/Dj`03o`000?o0?l3o`3o000co`3o00_l0
0003ojMHY`03o`000?nQGZ7o0000017oQGZ500?o0000ofn@Kom_T6l01om_T6l00ol0003oB;M8odRg
B004odRgB0;o00002?lo`3l00ol0003o?<<locc3?00>occ3?0;o00002?m3_4<00ol0003oLhacog><
L`06og><L`03o`000?mQWV7oHIiQ00WoHIiQ00?o0000oh5nPOn1OX402On1OX400ol0003o_D:moke2
_@0=oke2_@03o`000?oA;]7odBkA00;odBkA0ol00007ojaC[003o`000?oX5nSoj1OX00Ooj1OX00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?o0?l3o
`3o000Wo`3o00_l00006ojMHY`03o`000?n5NXGoQGZ5013oQGZ500?o0000ofn@Kom_T6l01_m_T6l0
0ol0003oB;M8odRgB007odRgB003o`000?lo`3oo?l0o00Co?l0o0ol0000>occ3?003o`000?lWf2Oo
9mPW00?o00001Om3_4<00ol0003oLhacog><L`06og><L`03o`000?mQWV7oHIiQ00[oHIiQ00?o0000
oh5nPOn1OX402?n1OX400ol0003o_D:moke2_@0=oke2_@03o`000?oA;]7odBkA00GodBkA0ol00004
ojaC[003o`000?oX5nSoj1OX00Ooj1OX00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ojaC[on/Dj`06on/Dj`03o`000?o0?l3o`3o000Go`3o00ol00008ojMHY`03o`000?n5NXGoQGZ5
017oQGZ500Co0000ofn@Kom_T6ooKi1_1?l0000;odRgB0;o000000Co?l0oo`000?l0003o00000omF
ZEH2o`0000_o?<<l00?o0000obOH9olWf2L01?lWf2L2o`0000?o@ka300?o0000og><LomcS7<01_mc
S7<00ol0003oHIiQof6NH@0:of6NH@03o`000?n1OX7oPGj100OoPGj100?o0000oke2_Onm@[d03_nm
@[d00ol0003odBkAom4^d@08om4^d@Co00002_oX5nP00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ojaC[on/Dj`07on/Dj`03o`000?o0?l3o`3o000;o`3o00_l0000<ojMHY`03o`000?n5NXGo
QGZ5013oQGZ51?l00003of:MHP03o`000?m8]dSoB;M800_oB;M800?o0000oeJYE_mFZEH01_mFZEH0
0ol0003o?<<locc3?007occ3?003o`000?lWf2Oo9mPW00Oo9mPW3?l0000>of6NH@03o`000?n1OX7o
PGj100KoPGj100?o0000oke2_Onm@[d03_nm@[d00ol0003odBkAom4^d@0;om4^d@03o`000?oX5nSo
j1OX00Ooj1OX00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o[5>_ojaC[00WojaC[00Co0000ol0o
`?l0003o00003_nWF:L00ol0003oQGZ5ohEjQ@0?ohEjQ@03o`000?mRWF;oHYeR00KoHYeR00?o0000
odRgB?m8]dP02_m8]dP00ol0003oEZUFoeJYEP07oeJYEP;o00001_ll`c`00ol0003o9mPWobOH9`08
obOH9`03o`000?mkQ7_oNhAk00SoNhAk00?o0000of6NHOmQWV403?mQWV400ol0003oPGj1oh5nP@05
oh5nP@03o`000?nm@[go_D:m00oo_D:m0_l0000=om4^d@03o`000?oX5nSoj1OX00Koj1OX00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o[5>_ojaC[00[ojaC[00?o0000ojMHYonWF:L03_nWF:L00ol0
003oQGZ5ohEjQ@0>ohEjQ@03o`000?mRWF;oHYeR00OoHYeR00?o0000odRgB?m8]dP02_m8]dP00ol0
003oEZUFoeJYEP09oeJYEP;o00000oll`c`00ol0003o9mPWobOH9`09obOH9`03o`000?mkQ7_oNhAk
00WoNhAk00?o0000of6NHOmQWV402_mQWV44o`0000CoPGj100?o0000oke2_Onm@[d04?nm@[d01?l0
003ocS7>o`000?l0000<om4^d@03o`000?oX5nSoj1OX00Goj1OX00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o[5>_ojaC[00[ojaC[00?o0000ojMHYonWF:L03onWF:L@o`0000[oHYeR00?o0000odRg
B?m8]dP02Om8]dP00ol0003o;m0_o`00000<oeJYEP05o`000?ll`cco0000obSG:?l000002_lWf2L0
0ol0003oNhAkog^4N`09og^4N`03o`000?mQWV7oHIiQ00OoHIiQ0ol00004ohYeRP?o000000?oPGj1
o`000?nm@[d04Onm@[d01?l0003ocS7>olhac_o><Lh2o`0000_odBkA00?o0000onPGj?oX5nP00ooX
5nP00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/02_o[5>/00ol0003oYeRWojMHY`0?
ojMHY`03o`000?n<LhcoS7><00coS7><00?o0000of:MH_mRWF802OmRWF800ol0003oB;M8odRgB007
odRgB004o`000?l_d2oo;m0_o`0000goEZUF00Go0000obSG:?lXebSo:=LXo`000009obOH9`03o`00
0?mkQ7_oNhAk00[oNhAk00?o0000of6NHOmQWV400omQWV43o`0000[oRWF:00?o0000oke2_Onm@[d0
4?nm@[d00ol0003ocS7>olhacP04olhacP;o00002_oA;]400ol0003oj1OXonPGj004o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cojaC[00?o0000ojMHYonWF:L03onWF:L00ol0003oS7><ohacS00<ohacS003o`000?mR
WF;oHYeR00WoHYeR00?o0000odRgB?m8]dP01_m8]dP00ol0003o;m0_obo@;`02obo@;`03o`000?mF
ZEKoEZUF00[oEZUF00?o0000obSG:?lXebP00_lXebP00ol0003o9mPWobOH9`06obOH9`03o`000?mk
Q7_oNhAk00[oNhAk00?o0000of6NHOmQWV400ol0000=ohYeRP03o`000?nm@[go_D:m013o_D:m00?o
0000olhac_o><Lh01_o><Lh2o`0000WodBkA0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000on/Djoo[5>/02_o[5>/00ol0003oYeRWojMHY`0=ojMHY`?o00003on<Lh`0
0ol0003oHYeRof:MHP08of:MHP03o`000?m8]dSoB;M800GoB;M800?o0000obo@;ol_d2l00ol_d2l0
0ol0003oEZUFoeJYEP0:oeJYEP03o`000?lXebSo:=LX00?o:=LX00?o0000obOH9olWf2L01OlWf2L0
0ol0003oNhAkog^4N`0;og^4N`;o00004On:MHX00ol0003o_D:moke2_@0?oke2_@03o`000?o><Lko
cS7>00SocS7>0_l00007om4^d@03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000on/Djoo[5>/02?o[5>/00ol0003oYeRWojMHY`09ojMHY`Go00000_miQWT00ol0
003oS7><ohacS00=ohacS003o`000?mRWF;oHYeR00WoHYeR00?o0000odRgB?m8]dP01?m8]dP00ol0
003o;m0_obo@;`04obo@;`03o`000?mFZEKoEZUF00SoEZUF00?o0000obSG:?lXebP01OlXebP00ol0
003o9mPWobOH9`04obOH9`03o`000?mkQ7_oNhAk00_oNhAk00?o0000ohYeR_n:MHX04?n:MHX00ol0
003o_D:moke2_@0?oke2_@03o`000?o><LkocS7>00[ocS7>0_l00004om4^d@03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003ojaC[on/Dj`07on/Dj`03o`000?nWF:OoYeRW00CoYeRW1Ol00007ogV6N@03
o`000?n<LhcoS7><00goS7><00?o0000of:MH_mRWF802OmRWF800ol0003oB;M8odRgB003odRgB003
o`000?l_d2oo;m0_00Go;m0_00?o0000oeJYE_mFZEH02?mFZEH00ol0003o:=LXobSG:006obSG:003
o`000?lWf2Oo9mPW00?o9mPW00?o0000og^4NomkQ7/02omkQ7/00ol0003oRWF:ohYeRP0@ohYeRP03
o`000?nm@[go_D:m00oo_D:m00?o0000olhac_o><Lh03?o><Lh2o`000003om4^dOl0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o[5>_ojaC[00OojaC[00?o0000ojMHYol00000
1?l0000<ogV6N@03o`000?n<LhcoS7><00koS7><00?o0000of:MH_mRWF802?mRWF800ol0003oB;M8
odRgB002odRgB003o`000?l_d2oo;m0_00Oo;m0_00?o0000oeJYE_mFZEH01omFZEH00ol0003o:=LX
obSG:007obSG:003o`000?lWf2Oo9mPW00;o9mPW00?o0000og^4NomkQ7/02omkQ7/00ol0003oRWF:
ohYeRP0AohYeRP03o`000?nm@[go_D:m00go_D:m00?o0000olhac_o><Lh03oo><Lh00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000on/Djoo[5>/01Oo[5>/3o`00017oNHIi00?o0000ohacS?n<Lh`03_n<
Lh`00ol0003oHYeRof:MHP09of:MHP04o`000?m8]dSoB;M8o`0000[o;m0_00?o0000oeJYE_mFZEH0
1omFZEH00ol0003o:=LXobSG:008obSG:005o`000?lWf2Oo9mPWobOH9ol000003OmkQ7/00ol0003o
RWF:ohYeRP0AohYeRP?o00003Onm@[d00ol0003ocS7>olhacP0?olhacP03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_o[5>/2o`0000;o_T6n00?o0000ogV6NOmiQWT03omiQWT00ol0003o
S7><ohacS00>ohacS003o`000?mRWF;oHYeR00SoHYeR1Ol0000;obo@;`03o`000?mFZEKoEZUF00Ko
EZUF00?o0000obSG:?lXebP02OlXebP01?l0003o9mPWobOH9ol0000=og^4N`03o`000?n:MH[oRWF:
017oRWF:00?o0000ofNHIomWV6L00ol0000:oke2_@Co00003Oo><Lh00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000onPGj?oX5nSoj1OX0_l00005oki1_P03o`000?miQWWoNHIi00koNHIi00?o0000ohac
S?n<Lh`03_n<Lh`00ol0003oHYeRof:MHP07of:MHP03o`000?mMXUgoGJ9M00?oGJ9M00?o0000obo@
;ol_d2l02?l_d2l00ol0003oEZUFoeJYEP05oeJYEP03o`000?lXebSo:=LX00[o:=LX1Ol0000<og^4
N`03o`000?n:MH[oRWF:013oRWF:00?o0000ofNHIomWV6L01?mWV6L3o`0000Ko_D:m00?o0000om4^
dOoA;]400_oA;]45o`0000SocS7>00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oX5nSoj1OX00?o
j1OX00?o0000oki1__nn@Kh01?nn@Kh00ol0003oNHIiogV6N@0=ogV6N@03o`000?n<LhcoS7><00oo
S7><00?o0000of:MH_mRWF801?mRWF82o`0000OoGJ9M00?o0000obo@;ol_d2l01ol_d2lEo`0000Go
=/Tf00?o0000og^4NomkQ7/02?mkQ7/3o`00013oRWF:00?o0000ofNHIomWV6L02?mWV6L3o`0000;o
_D:m00?o0000om4^dOoA;]402?oA;]45o`0000?ocS7>00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?oX5nSoj1OX00Coj1OX00?o0000oki1__nn@Kh01Onn@Kh00ol0003oNHIiogV6N@0;ogV6N@Co0000
3on<Lh`00ol0003oHYeRof:MHP03of:MHP03o`000?mMXUgoGJ9M00SoGJ9M00?o0000obo@;ol_d2l0
1?l_d2l2o`0000SoGJ9M00?o0000od^dBom;]4/02?m;]4/00ol0003o=/TfocK9=P05ocK9=P;o0000
1_mkQ7/2o`0000?oKY5^00?o0000ohYeR_n:MHX03?n:MHX00ol0003oIiQWofNHI`0<ofNHI`;o0000
4?oA;]43o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj005onPGj003o`000?nn@Kko_T6n00Ko_T6n00?o
0000ogV6NOmiQWT02OmiQWT00ol0003oK9=/o`000002ofRGJ0?o00003?n<Lh`01?l0003oHYeRof:M
H_mRWF82o`0000coGJ9M00?o0000obo@;ol_d2l00_l_d2l00ol0003oGJ9MoefRG@08oefRG@03o`00
0?m;]4_oBkA;00SoBkA;00?o0000ocK9=_lfbCH01olfbCH00ol0003oNhAkog^4N`02og^4N`03o`00
0?m^TFkoKY5^00CoKY5^0_l0000;ohYeRP03o`000?mWV6OoIiQW00coIiQW00?o0000oi1_T?l00000
4_oA;]400ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003oj1OXonPGj006onPGj003o`000?nn@Kko_T6n00Oo_T6n00?o
0000ogV6NOmiQWT01_miQWT2o`0000;oK9=/00?o0000ofRGJ?mXUfP00omXUfP3o`0000[oS7><00?o
0000of:MH_l000003omMXUd01?l0003o;m0_o`000?l0000;oefRG@03o`000?m;]4_oBkA;00SoBkA;
00?o0000ocK9=_lfbCH02?lfbCH01?l0003oNhAko`000?l00009ofjAKP03o`000?n:MH[oRWF:00Oo
RWF:00?o0000ofNHIomWV6L03?mWV6L01?l0003oT6n@oi1_T?l0000Com4^d@03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000onPGj?oX5nP01ooX5nP00ol0003o_T6noki1_P08oki1_P03o`000?miQWWoNHIi00Co
NHIi00?o0000ofbCK?m/Tf`00om/Tf`00ol0003oJ9MXofRGJ005ofRGJ0?o00001_n<Lh`4o`00013o
GJ9M00?o0000oefRGOmMXUd03?mMXUd00ol0003oBkA;od^dB`07od^dB`03o`000?lfbCKo=/Tf00Wo
=/Tf00?o0000ofjAK_m^TFh02_m^TFh2o`0000KoRWF:00?o0000ofNHIomWV6L03?mWV6L00ol0003o
T6n@oi1_T002oi1_T003o`000?oA;]7odBkA00oodBkA00?o0000on@Ki?l000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oj1OXonPGj008onPGj003o`000?nn@Kko_T6n00Wo_T6n00Co0000ogV6NOmiQWWo
NHIi0_l00006ofbCK003o`000?mXUfSoJ9MX00SoJ9MX0ol000000on<Lhco0000o`000004ofVFJ@03
o`000?mMXUgoGJ9M00goGJ9M00?o0000oefRGOmMXUd03?mMXUd00ol0003oBkA;od^dB`07od^dB`03
o`000?lfbCKo=/Tf00Wo=/Tf00?o0000ofjAK_m^TFh03?m^TFh00ol0003oRWF:ohYeRP03o`0000ko
IiQW00?o0000oi1_T?n@Ki000on@Ki000ol0003odBkAom4^d@0>om4^d@05o`000?oT6nCoi1_Ton@K
i?l000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003oj1OXonPGj009onPGj003o`000?nn@Kko_T6n00[o
_T6n00?o0000ogV6NOl000002?m/Tf`00ol0003oJ9MXofRGJ00;ofRGJ003o`000?mYUVWoJIIY00Go
JIIY00?o0000oefRGOmMXUd03?mMXUd00ol0003oGJ9MoefRG@0<oefRG@03o`000?m;]4_oBkA;00Oo
BkA;00?o0000ocK9=_lfbCH02?lfbCH2o`0000ooKY5^0_l00002ogR7N003o`000?mWV6OoIiQW00_o
IiQW00?o0000oi1_T?n@Ki001?n@Ki000ol0003odBkAom4^d@0=om4^d@03o`000?oT6nCoi1_T00?o
i1_T00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onPGj003o`000?nn@Kko_T6n00_o_T6n00?o0000ofbCK?m/Tf`0
1om/Tf`00ol0003oJ9MXofRGJ00;ofRGJ003o`000?mYUVWoJIIY00KoJIIY00?o0000oefRGOmMXUd0
2omMXUd2o`0000goGJ9M00?o0000od^dBom;]4/01om;]4/00ol0003o=/TfocK9=P07ocK9=P04o`00
0?m3_4?o@ka3o`0000koKY5^00?o0000ogR7N?mhQgP00_mhQgP00ol0003oIiQWofNHI`09ofNHI`03
o`000?n@Ki3oT6n@00KoT6n@00?o0000om4^dOoA;]402ooA;]400ol0003oi1_Ton@Ki005on@Ki004
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000Soj1OX00?o0000oki1__nn@Kh02_nn@Kh2o`0000Wo
K9=/00?o0000ofRGJ?mXUfP02omXUfP00ol0003oJIIYofVFJ@07ofVFJ@03o`000?mMXUgoGJ9M00Wo
GJ9M00Co0000obKI9_lVfBKo00003?mMXUd00ol0003oBkA;od^dB`07od^dB`03o`000?lfbCKo=/Tf
00Ko=/Tf00Go0000od>l@om3_4?o@ka3o`00000>ofjAKP03o`000?mhQgSoN8Mh00?oN8Mh00?o0000
ofNHIomWV6L01omWV6L00ol0003oT6n@oi1_T007oi1_T003o`000?oA;]7odBkA00[odBkA00?o0000
on@Ki?oT6n@01ooT6n@00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006onPGj003o`000?nn@Kko_T6n
00Wo_T6n00Co0000oimPWonOH9oo00002Om/Tf`00ol0003oJ9MXofRGJ009ofRGJ003o`000?mYUVWo
JIIY00WoJIIY00?o0000oefRGOmMXUd01omMXUd00ol0003o9]TVobKI9P02obKI9P03o`000?mMXUgo
GJ9M00WoGJ9M00?o0000od^dBom;]4/01om;]4/00ol0003o=/TfocK9=P05ocK9=P03o`000?m3_4?o
@ka300?o@ka300?o0000ofjAK_m^TFh02_m^TFh00ol0003oN8MhogR7N005ogR7N003o`000?mWV6Oo
IiQW00GoIiQW00?o0000oi1_T?n@Ki002?n@Ki000ol0003odBkAom4^d@09om4^d@03o`000?oT6nCo
i1_T00Soi1_T00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_oX5nP3o`0000Wo_T6n00?o0000oimP
WonOH9l00_nOH9l00ol0003oK9=/ofbCK006ofbCK003o`000?mXUfSoJ9MX00WoJ9MX00?o0000ofVF
JOmYUVT02_mYUVT00ol0003oGJ9MoefRG@05oefRG@03o`000?lVfBKo9]TV00Co9]TV00?o0000oefR
GOmMXUd02?mMXUd00ol0003oBkA;od^dB`07od^dB`03o`000?lfbCKo=/Tf00Co=/Tf00?o0000od>l
@om3_4<01?m3_4<00ol0003oKY5^ofjAKP0:ofjAKP03o`000?mhQgSoN8Mh00KoN8Mh00?o0000ofNH
IomWV6L00omWV6L00ol0003oT6n@oi1_T009oi1_T003o`000?oA;]7odBkA00SodBkA00?o0000on@K
i?oT6n@02OoT6n@00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003on4Nh@?o00001Onn@Kh00ol0003o
Wf2OoimPW`03oimPW`03o`000?m/TfcoK9=/00KoK9=/00?o0000ofRGJ?mXUfP02OmXUfP00ol0003o
JIIYofVFJ@0;ofVFJ@03o`000?mMXUgoGJ9M00?oGJ9M00?o0000obKI9_lVfBH01_lVfBH00ol0003o
GJ9MoefRG@08oefRG@03o`000?m;]4_oBkA;00KoBkA;00?o0000ocK9=_lfbCH00_lfbCH2o`0000So
@ka300?o0000ofjAK_m^TFh02Om^TFh00ol0003oN8MhogR7N007ogR7N005o`000?mWV6OoIiQWofNH
Iol000003On@Ki000ol0003odBkAom4^d@06om4^d@03o`000?oT6nCoi1_T00[oi1_T00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oQ7^7ohAkQ00GohAkQ0ol000000onn@Kko0000oimPW`06oimPW`03
o`000?m/TfcoK9=/00GoK9=/00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oJIIYofVFJ@0<ofVFJ@05
o`000?mMXUgoGJ9MoefRGOl000002_lVfBH00ol0003oGJ9MoefRG@07oefRG@03o`000?m;]4_oBkA;
00KoBkA;00?o0000ocK9=_l000000_l000000omgR7Oo0000od>l@`07od>l@`03o`000?m^TFkoKY5^
00SoKY5^00?o0000ogR7N?mhQgP02OmhQgP00ol0003oIiQWo`00000=oi1_T0Co00001OoA;]400ol0
003oi1_Ton@Ki00;on@Ki003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohAkQon4Nh@08on4Nh@03
o`000?nOH9ooWf2O00OoWf2O00?o0000ofbCK?m/Tf`01?m/Tf`00ol0003oJ9MXofRGJ009ofRGJ003
o`000?mYUVWoJIIY00goJIIY00?o0000oefRGOl000003?lVfBH:o`0000OoBkA;0ol00005ogN8M`03
o`000?m3_4?o@ka300Ko@ka300?o0000ofjAK_m^TFh01om^TFh00ol0003oN8MhogR7N00:ogR7N003
o`000?n@Ki3oT6n@00_oT6n@00?o0000ol4n`Oo1?/400_o1?/43o`000003om4^dOl0003oi1_T00_o
i1_T0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000on4NhOoQ7^402OoQ7^400ol0003oWf2OoimPW`07oimPW`03o`00
0?m/TfcoK9=/00GoK9=/00?o0000ofRGJ?mXUfP01omXUfP00ol0003oJIIYofVFJ@0?ofVFJ@;o0000
2olVfBH00ol0003oJiA[of^DJ`07of^DJ`03o`000?m;]4_oBkA;00;oBkA;0ol00008ogN8M`03o`00
0?m3_4?o@ka300Ko@ka300?o0000ofjAK_m^TFh01om^TFh00ol0003oN8MhogR7N00:ogR7N003o`00
0?n@Ki3oT6n@00[oT6n@00?o0000ol4n`Oo1?/401_o1?/400ol0003oi1_Ton@Ki008on@Ki0?o0000
0_o[5>/00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on4NhOoQ7^402OoQ7^400ol0003oWf2OoimP
W`08oimPW`03o`000?m/TfcoK9=/00CoK9=/00?o0000ofRGJ?mXUfP01omXUfP00ol0003oJIIYofVF
J@0>ofVFJ@04o`000?liaSWo>LHio`0000Wo9]TV00?o0000of^DJom[U6/02Om[U6/01?l0003oBkA;
o`000?l0000<ogN8M`03o`000?m3_4?o@ka300Ko@ka300?o0000ofjAK_m^TFh01_m^TFh00ol0003o
N8MhogR7N00;ogR7N003o`000?n@Ki3oT6n@00OoT6n@0_l00009ol4n`@03o`000?oT6nCoi1_T00Co
i1_T1?l00006on/Dj`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohAkQon4Nh@09on4Nh@03o`00
0?nOH9ooWf2O00SoWf2O00?o0000ofbCK?m/Tf`00om/Tf`>o`0000goJIIY00?o0000ocW6>OliaST0
0_liaST00ol0003o9]TVobKI9P05obKI9P03o`000?m[U6_oJiA[00_oJiA[00?o0000ogN8MomgR7L0
3?mgR7L00ol0003o@ka3od>l@`06od>l@`03o`000?m^TFkoKY5^00GoKY5^00?o0000ogR7N?mhQgP0
3?mhQgP00ol0003oT6n@oi1_T006oi1_T003o`000?o1?/7o`Ck100[o`Ck100?o0000on@Ki?oT6n@0
0ol0000:on/Dj`?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oimPWonOH9l02?nO
H9l01Ol0003oK9=/ofbCK?m/Tfco000000_oIIYU00?o0000oaSW6?lHiaP00ol00009ofVFJ@03o`00
0?liaSWo>LHi00Co>LHi00?o0000obKI9_lVfBH00olVfBH00ol0003oJiA[of^DJ`0<of^DJ`03o`00
0?mgR7OoMhQg00goMhQg00?o0000od>l@om3_4<01_m3_4<00ol0003oKY5^ofjAKP03ofjAKP?o0000
3OmhQgP00ol0003oT6n@oi1_T005oi1_T003o`000?o1?/7o`Ck100co`Ck10_l0000=on/Dj`03o`00
0?ol0ocoo0?l00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oimPWonOH9l02?nO
H9l4o`0000coIIYU00?o0000oaSW6?lHiaP00olHiaP3o`0000GoJIIY00?o0000ocW6>OliaST01_li
aST01Ol0003o9]TVobKI9_lVfBKo000000ooJiA[00?o0000ogN8MomgR7L03OmgR7L00ol0003o@ka3
od>l@`06od>l@`03o`000?m^TFkoKY5^00?o00000om9]TT00ol0003oN8MhogR7N00;ogR7N003o`00
0?n@Ki3oT6n@00?oT6n@00?o0000ol4n`Oo1?/403Oo1?/400ol0003ojaC[on/Dj`0;on/Dj`03o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000on4NhOoQ7^402_oQ7^43o`0000KoWf2O0ol0
0003ohacS003o`000?mUVVGoIIYU00[oIIYU00?o0000oaSW6?lHiaP01_lHiaP3o`000003ofVFJOl0
003o>LHi00Wo>LHi00?o0000obKI9_l000004?m[U6/00ol0003oMhQgogN8M`0=ogN8M`03o`000?m3
_4?o@ka300Oo@ka30_l00007odVfB@03o`000?mhQgSoN8Mh00[oN8Mh00Co0000oi1_T?n@Ki3oT6n@
0ol0000?ol4n`@03o`000?o[5>_ojaC[00_ojaC[00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on4NhOoQ7^402_oQ
7^401?l0003oc3?<ol`cc?o<<l`2o`000004oimPWol0003o0000o`0000KoS7><00?o0000ofFJIOmU
VVD02_mUVVD00ol0003o6>LHoaSW6009oaSW6003o`000?liaSWo>LHi00[o>LHi00?o0000of^DJom[
U6/03om[U6/00ol0003oMhQgogN8M`0>ogN8M`03o`000?m3_4?o@ka300Ko@ka300?o0000odVfBOm9
]TT01om9]TT4o`0000SoN8Mh00Co0000oi1_T?n@Ki3o00000on1OX42o`0000go`Ck100?o0000on/D
joo[5>/02_o[5>/00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on4NhOoQ7^402OoQ7^400ol0003o
c3?<ol`cc004ol`cc003o`000?n<LhcoS7><00OoS7><00?o0000ofFJIOmUVVD02OmUVVD00ol0003o
6>LHoaSW600:oaSW6003o`000?liaSWo>LHi00[o>LHi00?o0000of^DJom[U6/03om[U6/00ol0003o
MhQgogN8M`0>ogN8M`03o`000?m3_4?o@ka300Go@ka300?o0000odVfBOm9]TT02?m9]TT01?l0003o
IIYUofFJIOmUVVD7o`0000;oN8Mh0_l00006oh5nP@;o00003?o1?/400ol0003ojaC[on/Dj`09on/D
j`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ohAkQon4Nh@08on4Nh@03o`000?o<<lcoc3?<00Go
c3?<00?o0000ohacS?n<Lh`02?n<Lh`00ol0003oIIYUofFJI@08ofFJI@03o`000?lHiaSo6>LH00[o
6>LH00?o0000ocW6>OliaST02oliaST00ol0003oJiA[of^DJ`0>of^DJ`03o`000?mgR7OoMhQg00ko
MhQg1Ol00002od>l@`03o`000?m9]TWoBKI900WoBKI900?o0000ofFJIOmUVVD02?mUVVD3o`0000Wo
PGj10_l0000:ol4n`@03o`000?o[5>_ojaC[00SojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oQ7^7ohAkQ00SohAkQ00?o0000ol`cc?o<<l`01oo<<l`00ol0003oS7><ohacS007ohacS003o`00
0?mUVVGoIIYU00SoIIYU00?o0000oaSW6?lHiaP02_lHiaP00ol0003o>LHiocW6>@0:ocW6>@;o0000
3_m[U6/3o`0000goMhQg0ol00005ogb3O0;o00002om9]TT00ol0003oIIYUofFJI@0;ofFJI@;o0000
2_n1OX42o`0000Oo`Ck10ol00009on/Dj`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:ol`cc003o`00
0?n<LhcoS7><00OoS7><00?o0000ofFJIOmUVVD02?mUVVD>o`0000Wo>LHi0ol000000olIiQWo0000
of^DJ`0:of^DJ`?o00000_n1OX400ol0003oMhQgogN8M`09ogN8M`;o00002OmlPg`00ol0003oBKI9
odVfB@09odVfB@03o`000?mUVVGoIIYU00_oIIYU00?o0000ogj1O_l000002on1OX42o`0000Co`Ck1
00Co0000omlOgooO7moogaoO0_l00007on/Dj`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003oc3?<
ol`cc009ol`cc003o`000?n<LhcoS7><00KoS7><00?o0000ofFJIOmUVVD02?mUVVD00ol0003o9]TV
obKI9P0:obKI9P03o`000?liaSWo>LHi00Co>LHi0ol00005oaWV6@03o`000?m[U6_oJiA[00CoJiA[
1?l00006oh5nP@03o`000?mgR7OoMhQg00KoMhQg0_l0000;ogb3O003o`000?m9]TWoBKI900WoBKI9
00?o0000ofFJIOmUVVD02_mUVVD01Ol0003oOX5nogj1O_mnPGko000000coPGj10_l000000oo1?/7o
0000omlOg`05omlOg`03o`000?o[5>_ojaC[00?ojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?o<<lcoc3?<00Soc3?<00?o0000ohacS?n<Lh`01_n<Lh`00ol0003oIIYUofFJI@07ofFJI@03o`00
0?lVfBKo9]TV00_o9]TV00?o0000ocW6>OliaST00_liaST2o`0000Wo6NHI00?o0000of^DJom[U6/0
0ol0000;oh5nP@03o`000?mgR7OoMhQg00;oMhQg0ol0000>ogb3O003o`000?m9]TWoBKI900OoBKI9
00?o0000ofFJIOmUVVD02omUVVD00ol0003oOX5nogj1OP02ogj1OP03o`000?n1OX7oPGj100_oPGj1
00?o0000omlOgooO7ml01_oO7ml2o`0000?ojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o<
<lcoc3?<00Ooc3?<00?o0000ohacS?n<Lh`01on<Lh`00ol0003oIIYUofFJI@05ofFJI@?o00003OlV
fBH4o`0000_o6NHI0ol0000?oh5nP@04o`000?mgR7Oo0000o`00017oO8=l00?o0000odVfBOm9]TT0
1om9]TT00ol0003oIIYUofFJI@0:ofFJI@03o`000?mnPGkoOX5n00CoOX5n00?o0000oh5nPOn1OX40
1on1OX43o`0000_ogaoO1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000ol`cc?o<<l`02?o<<l`00ol0003oS7><ohac
S006ohacS003o`000?mUVVGoIIYU00;oIIYU0ol00003od^dB`03o`000?lVfBKo9]TV00[o9]TV00?o
0000oaWV6OlIiQT02olIiQT00ol0003o9MXUo`00000Aoh5nP@03o`000?mlPgcoO8=l017oO8=l00?o
0000odVfBOm9]TT01om9]TT00ol0003oIIYUofFJI@0:ofFJI@03o`000?mnPGkoOX5n00GoOX5n00Co
0000oh5nPOn1OX7oPGj11Ol00002oiIYUP03o`000?oO7moogaoO00WogaoO00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000ol`cc?o<<l`01oo<<l`00ol0003oS7><ohacS005ohacS0?o0000
00?oIIYUo`000?l000001om;]4/00ol0003o9]TVobKI9P08obKI9P?o00002_lIiQT2o`0000;o9MXU
00?o0000oh5nPOn1OX403on1OX400ol0003oO8=logb3O00Aogb3O003o`000?m9]TWoBKI900OoBKI9
00?o0000ofFJIOmUVVD02OmUVVD00ol0003oOX5nogj1OP07ogj1OP?o00001onFJIH00ol0003ogaoO
omlOg`09omlOg`03o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000ol`cc?o<<l`01oo<
<l`4o`0000;oS7><0_l00003oi5^T@03o`000?m;]4_oBkA;00SoBkA;0_l00006obKI9P;o00000ol/
db`00ol0003o6NHIoaWV6@06oaWV6@03o`000?lUfRGo9MXU00?o9MXU00?o0000oh5nPOn1OX403_n1
OX400ol0003oO8=logb3O00Bogb3O003o`000?m9]TWoBKI900GoBKI900?o0000ofFJIOmUVVD02OmU
VVD00ol0003oOX5nogj1OP08ogj1OP03o`000?nFJIKoUVVF00OoUVVF00?o0000omlOgooO7ml02?oO
7ml00ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o<<lcoc3?<00Coc3?<0_l00004
omPWf0;o00001OnAKY400ol0003oBkA;od^dB`0:od^dB`03o`000?lVfBKo9]TV00;o9]TV00?o0000
obcC;?l/db`01?l/db`00ol0003o6NHIoaWV6@04oaWV6@03o`000?lUfRGo9MXU00Co9MXU00?o0000
oh5nPOn1OX403_n1OX400ol0003oO8=logb3O00Bogb3O0[o00002_mUVVD00ol0003oOX5nogj1OP08
ogj1OP03o`000?nFJIKoUVVF00OoUVVF00?o0000omlOgooO7ml02?oO7ml00ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003oc3?<ol`cc?o<<l`2o`0000Oof2OH00?o0000oi5^TOnAKY401?nAKY40
0ol0003oBkA;od^dB`0:od^dB`04o`000?lVfBKo0000o`0000So;=</00Co0000oaWV6OlIiQWo6NHI
0_l00007obGJ9@03o`000?n1OX7oPGj100koPGj100?o0000ogb3O?mlPg`04_mlPg`00ol0003oFjAK
oe^TF`07oe^TF`03o`000?mUVVGoIIYU00KoIIYU00?o0000ogj1O_mnPGh02_mnPGh00ol0003oUVVF
oiIYUP06oiIYUP03o`000?oO7moogaoO00SogaoO00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?o<
<lco0000o`0000Wof2OH00?o0000oi5^TOnAKY401?nAKY400ol0003oBkA;od^dB`0;od^dB`03o`00
0?l/dbco;=</00Wo;=</00?o0000oaWV6Ol000002OlUfRD00ol0003oPGj1oh5nP@0>oh5nP@;o0000
4_mlPg`00ol0003oFjAKoe^TF`09oe^TF`;o00001_mUVVD00ol0003oOX5nogj1OP0:ogj1OP03o`00
0?nFJIKoUVVF00KoUVVF00?o0000omlOgooO7ml02?oO7ml00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omPWf?oH9mP02OoH9mP00ol0003oTFjAoi5^T@05oi5^T@03o`000?m;]4_oBkA;00[oBkA;00?o
0000obcC;?l/db`02_l/db`2o`0000Wo9MXU00?o0000oh5nPOn1OX403_n1OX400ol0003oIiQWo`00
0002o`0000ooO8=l00?o0000oe^TFomKY5/02omKY5/00ol0003oIIYUofFJI@03o`0000goOX5n00?o
0000oiIYU_nFJIH01_nFJIH00ol0003ogaoOomlOg`07omlOg`03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003of2OHomPWf009omPWf003o`000?nAKY7oTFjA00GoTFjA00?o0000od^dBom;]4/02Om;]4/2
o`0000_o;=</0_l0000;obGJ9@03o`000?n1OX7oPGj100coPGj100?o0000ofNHIomWV6L00omWV6L3
o`0000coO8=l00?o0000oe^TFomKY5/03?mKY5/2o`0000;oJIIY00?o0000ogj1O_mnPGh03?mnPGh0
0ol0003oUVVFoiIYUP05oiIYUP03o`000?oO7moogaoO00OogaoO00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oH9mSof2OH00[of2OH00?o0000oi5^TOnAKY401_nAKY400ol0003oBkA;od^dB`07od^d
B`03o`000?ll`cco000000[o;=</00Co0000oa[U6_lJiA[o00002_lUfRD00ol0003oPGj1oh5nP@0<
oh5nP@03o`000?mWV6OoIiQW00KoIiQW0_l00008ogb3O0;o00003omKY5/00ol0003oJIIYofVFJ@02
ofVFJ@03o`000?mnPGkoOX5n00_oOX5n00?o0000oiIYU_nFJIH01OnFJIH00ol0003ogaoOomlOg`07
omlOg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003of2OHomPWf00:omPWf003o`000?nAKY7oTFjA
00KoTFjA00?o0000od^dBom;]4/01_m;]4/01Ol0003o?<<locc3??ll`cco000000So;=</00?o0000
oa[U6_lJiAX00_lJiAX00ol0003o9MXUobGJ9@06obGJ9@Co00003?n1OX400ol0003oIiQWofNHI`08
ofNHI`?o00000_mlPg`3o`000003oeJYE_l0003oFjAK00goFjAK00?o0000ofVFJOmYUVT01?mYUVT0
0ol0003oOX5nogj1OP0:ogj1OP03o`000?nFJIKoUVVF00GoUVVF00?o0000omlOgooO7ml01_oO7ml0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omPWf?oH9mP02ooH9mP00ol0003oTFjAoi5^T@07oi5^
T@03o`000?m;]4_oBkA;00?oBkA;0_l00005occ3?003o`000?l/dbco;=</00Co;=</00?o0000oa[U
6_lJiAX00olJiAX00ol0003o9MXUobGJ9@05obGJ9@03o`000?m5^TGoAKY500;oAKY50ol00007oh5n
P@;o00003_mWV6L2o`0000GoEZUF00?o0000oe^TFomKY5/02_mKY5/00ol0003oJIIYofVFJ@05ofVF
J@03o`000?mnPGkoOX5n00_oOX5n00?o0000oiIYU_nFJIH01?nFJIH00ol0003ogaoOomlOg`06omlO
g`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003of2OHomPWf00;omPWf003o`000?nAKY7oTFjA00Oo
TFjA00?o0000od^dBom;]4/00_m;]4/00ol0003o?<<locc3?006occ3?003o`000?l/dbco;=</00;o
;=</00?o0000oa[U6_lJiAX01OlJiAX00ol0003o9MXUobGJ9@02obGJ9@;o00002?m5^TD3o`0000;o
PGj10_l000000om?/4oo0000ofNHI`0=ofNHI`03o`000?mFZEKoEZUF00GoEZUF00?o0000oe^TFomK
Y5/02?mKY5/00ol0003oJIIYofVFJ@07ofVFJ@03o`000?mnPGkoOX5n00[oOX5n00?o0000oiIYU_nF
JIH01?nFJIH00ol0003ogaoOomlOg`06omlOg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003of2OH
omPWf00<omPWf003o`000?nAKY7oTFjA00SoTFjA00Co0000od^dBom;]4_o00002Oll`c`01Ol0003o
;=</obcC;?l/dbco000000So6^DJ00Go0000obGJ9OlUfRGo9MXUo`00000=odFjA@;o00001?m?/4l0
0ol0003oIiQWofNHI`0;ofNHI`03o`000?mFZEKoEZUF00KoEZUF00?o0000oe^TFomKY5/01omKY5/0
0ol0003oJIIYofVFJ@08ofVFJ@Co00002?mnPGh00ol0003oUVVFoiIYUP04oiIYUP03o`000?oO7moo
gaoO00KogaoO00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oH9mSof2OH00_of2OH0ol00009oi5^
T@03o`000?m;]4_o000000_o?<<l00?o0000obcC;?l000002_lJiAX00ol0003o9MXUo`00000?odFj
A@03o`000?m?/4ooCk1?00;oCk1?00?o0000ofNHIomWV6L02omWV6L00ol0003oEZUFoeJYEP06oeJY
EP03o`000?mKY5_oFjAK00KoFjAK00?o0000ofVFJOmYUVT02OmYUVT01?l0003oTVfBoi9]T_nBKI87
o`0000;oOX5n00?o0000oiIYU_nFJIH00onFJIH00ol0003ogaoOomlOg`05omlOg`03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oH9mSof2OH00Sof2OH0ol00003olLha`03o`000?nAKY7oTFjA00OoTFjA00?o0000occ3
??ll`c`02oll`c`00ol0003o6^DJoa[U6P0:oa[U6P03o`000?m5^TGoAKY500goAKY500?o0000odn`
Com?/4l01?m?/4l00ol0003oIiQWofNHI`09ofNHI`03o`000?mFZEKoEZUF00SoEZUF00?o0000oe^T
FomKY5/00omKY5/2o`0000coJIIY00?o0000oi9]T_nBKI802?nBKI8<o`0000?ogaoO0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omPWf?oH9mP01_oH9mP3o`0000OoacS700?o0000oi5^TOnAKY401_nAKY400ol0003o
?<<locc3?00;occ3?003o`000?lJiA[o6^DJ00Wo6^DJ0_l0000>odFjA@03o`000?m?/4ooCk1?00Go
Ck1?00?o0000ofNHIomWV6L02OmWV6L00ol0003oEZUFoeJYEP09oeJYEP03o`000?mKY5_o000000;o
00000_mPWf000ol0003oJIIYofVFJ@08ofVFJ@03o`000?nBKI;oTVfB00coTVfB00?o0000omhQg_oN
8Mh01_oN8Mh3o`0000?on`Ck0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003of2OHomPWf003omPWf0?o00002oo7><L00ol0003oTFjA
oi5^T@04oi5^T@03o`000?ll`cco?<<l00_o?<<l0ol00007oa[U6P?o000000?o>LHio`000?m5^TD0
3Om5^TD00ol0003oCk1?odn`C`06odn`C`03o`000?mWV6OoIiQW00SoIiQW00?o0000oeJYE_mFZEH0
2_mFZEH00ol0003oH9mPof2OH004of2OH003o`000?mYUVWoJIIY00OoJIIY00?o0000oi9]T_nBKI80
2onBKI800ol0003ogR7NomhQgP08omhQgP03o`000?ok1?_on`Ck00Con`Ck0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omPWf?l0
003o0000o`0000ooacS700?o0000oi5^TOnAKY400onAKY4>o`0000?o=lPg0_l00002oa[U6P?o0000
1OliaST00ol0003oAKY5odFjA@0:odFjA@03o`000?m?/4ooCk1?00OoCk1?00?o0000ofNHIomWV6L0
2?mWV6L00ol0003oEZUFoeJYEP0:oeJYEP03o`000?mPWf3oH9mP00GoH9mP00?o0000ofVFJOmYUVT0
1_mYUVT00ol0003oTVfBoi9]TP0;oi9]TP03o`000?oN8MkogR7N00SogR7N00?o0000oo/4nook1?/0
1ook1?/2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?oj1OX2o`0001;oacS700?o0000oi5^TOnAKY400_nAKY400ol0003oE:]DoeB[
E00:oeB[E003o`000?lgb3Oo=lPg00?o=lPg0_l00009ocW6>@03o`000?m5^TGoAKY500WoAKY500?o
0000odn`Com?/4l02?m?/4l2o`0000SoIiQW00?o0000oeJYE_mFZEH02OmFZEH00ol0003oH9mPof2O
H007of2OH003o`000?mYUVWoJIIY00CoJIIY00?o0000oi9]T_nBKI802onBKI800ol0003ogR7NomhQ
gP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oacS7olLha`0?olLha`?o000000?oTFjA
o`000?mDZe@02omDZe@00ol0003o=lPgocO8=`04ocO8=`03o`000?liaSWo>LHi00Wo>LHi00?o0000
odFjAOm5^TD01om5^TD00ol0003oCk1?odn`C`09odn`C`04o`000?m:]D[o0000o`0000KoIiQW00?o
0000oeJYE_mFZEH02OmFZEH00ol0003oH9mPof2OH008of2OH003o`000?mYUVWoJIIY00?oJIIY00?o
0000oi9]T_nBKI802onBKI800ol0003ogR7NomhQgP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oacS7olLha`0<olLha`;o00000oo1?/42o`0000coE:]D00?o0000ocO8=olgb3L01?lgb3L0
0ol0003o>LHiocW6>@0:ocW6>@Wo00002om?/4l00ol0003oB[E:odZeBP02odZeBP?o00000_mWV6L0
0ol0003oEZUFoeJYEP0:oeJYEP03o`000?mPWf3oH9mP00WoH9mP00?o0000ofVFJOmYUVT00_mYUVT0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o7><L2o`0000Go`Ck100?o0000ohIiQ_l000002_mDZe@00ol0003o=lPgocO8=`06ocO8
=`03o`000?liaSWo>LHi00Wo>LHi00?o0000ocS7>?lhacP01OlhacP00ol0003oCk1?odn`C`09odn`
C`03o`000?m:]D[oB[E:00GoB[E:0ol00009oeJYEP?o00003OmPWf001Ol0003oJIIYofVFJOmYUVWo
000000coTVfB00?o0000omhQg_oN8Mh02OoN8Mh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000olLh
aoo7><L01Oo7><L2o`0000Oo`Ck100Co0000ohIiQ_n6NHKo00002OmDZe@00ol0003o=lPgocO8=`06
ocO8=`03o`000?liaSWo>LHi00So>LHi00?o0000ocS7>?lhacP01olhacP00ol0003oCk1?odn`C`07
odn`C`03o`000?m:]D[oB[E:00SoB[E:0ol00002oeJYEPGo00000_lcc3<00ol0003oH9mPof2OH00<
of2OH003o`000?mYUVWo000000coTVfB00?o0000omhQg_oN8Mh02_oN8Mh00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000olLhaoo7><L00_o7><L2o`0000So`Ck100?o0000ohIiQ_n6NHH00_n6NHH5o`00
00CoE:]D00?o0000ocO8=olgb3L01_lgb3L00ol0003o>LHiocW6>@08ocW6>@03o`000?lhacSo><Lh
00Oo><Lh00?o0000odn`Com?/4l01om?/4l00ol0003oB[E:odZeBP08odZeBP03o`000?lWf2Oo9mPW
00;o00002?lcc3<00ol0003oH9mPof2OH00<of2OH0Co00002_nBKI800ol0003ogR7NomhQgP0:omhQ
gP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oacS7o`000?l0000:ol4n`@03o`000?n6NHKoQWV6
00;oQWV600?o0000obKI9_lVfBH00_lVfBH4o`0000Wo=lPg00?o0000ocW6>OliaST02?liaST00ol0
003o><LhocS7>008ocS7>003o`000?m?/4ooCk1?00GoCk1?00?o0000odZeB_m:]DX02?m:]DX01Ol0
003o9mPWobOH9olWf2Oo000000[o<l`c0ol0000;of2OH004o`000?o6>LKoaSW6olHiaPCo00001OnB
KI800ol0003ogR7NomhQgP0;omhQgP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o`Ck1ol4n`@0:
ol4n`@03o`000?n6NHKoQWV600?oQWV600?o0000obKI9_lVfBH01?lVfBH00ol0003o=lPgocO8=`07
ocO8=`03o`000?liaSWo>LHi00Ko>LHi0_l0000;ocS7>003o`000?m?/4ooCk1?00GoCk1?00?o0000
odZeB_m:]DX02?m:]DX00ol0003o9mPWobOH9`02obOH9`03o`000?lcc3?o<l`c00Oo<l`c00?o0000
ogZ5N_mjQGX01?l00006of2OH003o`000?o6>LKoaSW600KoaSW60ol00002oi9]TP03o`000?oN8Mko
gR7N00_ogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o1?/7o`Ck100Wo`Ck100?o0000ohIi
Q_n6NHH01?n6NHH00ol0003o9]TVobKI9P05obKI9P03o`000?lgb3Oo=lPg00Oo=lPg00?o0000ocW6
>OliaST00_liaST3o`000003odJiA_l0003o><Lh00[o><Lh00?o0000odn`Com?/4l01Om?/4l00ol0
003oB[E:odZeBP07odZeBP03o`000?lWf2Oo9mPW00?o9mPW00?o0000oc?<<olcc3<01olcc3<00ol0
003oNXEjogZ5NP04ogZ5NP?o00000_mPWf000ol0003oaSW6olHiaP0:olHiaP;o00003_oN8Mh00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ol4n`Oo1?/402Oo1?/400ol0003oQWV6ohIiQP04ohIiQP03
o`000?lVfBKo9]TV00Ko9]TV0_l00007ocO8=`03o`000?liaSWo000000;o00001Om6^DH00ol0003o
><LhocS7>008ocS7>0?o00001?m?/4l00ol0003oB[E:odZeBP08odZeBP03o`000?lWf2Oo9mPW00Co
9mPW00?o0000oc?<<olcc3<01_lcc3<00ol0003oNXEjogZ5NP07ogZ5NP;o00003_o6>LH00ol0003o
gR7NomhQgP0;omhQgP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o`Ck1ol4n`@08ol4n`@03o`00
0?n6NHKoQWV600GoQWV600?o0000obKI9_lVfBH01?lVfBH00ol0003oA[U6odJiAP03o`0000Co=lPg
0_l00008odJiAP03o`000?lhacSo><Lh00Oo><Lh00Co0000ofbCK?m/TfcoK9=/0ol000000om?/4oo
0000odZeBP09odZeBP03o`000?lWf2Oo9mPW00Co9mPW00?o0000oc?<<olcc3<01Olcc3<00ol0003o
NXEjogZ5NP09ogZ5NP03o`000?o6>LKoaSW600goaSW600?o0000omhQg_oN8Mh02_oN8Mh00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ol4n`Oo1?/401oo1?/400ol0003oQWV6ohIiQP06ohIiQP03o`00
0?lVfBKo9]TV00?o9]TV00?o0000odJiA_m6^DH01?m6^DH2o`000003ocO8=ol0003oA[U600[oA[U6
00?o0000ocS7>?lhacP01OlhacP00ol0003oK9=/ofbCK005ofbCK003o`000?m:]D[oB[E:00OoB[E:
0ol00007obOH9`03o`000?lcc3?o<l`c00Co<l`c00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oaSW6
olHiaP0=olHiaP03o`000?oN8MkogR7N00[ogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o1
?/7o`Ck100Go`Ck10ol00009ohIiQP05o`000?lVfBKo9]TVobKI9_l000002Om6^DH00ol0003oA[U6
odJiAP0;odJiAP03o`000?lhacSo><Lh00?o><Lh00?o0000ofbCK?m/Tf`01_m/Tf`00ol0003oB[E:
odZeBP06odZeBP05o`000?mA[U7oDJiAoe6^DOl000001olWf2L00ol0003o<l`coc?<<`03oc?<<`03
o`000?mjQG[oNXEj00WoNXEj00?o0000olHia_o6>LH03_o6>LH00ol0003ogR7NomhQgP09omhQgP03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o`Ck1o`000004o`0000;ofBKI00?o0000ohIiQ_n6NHH0
1on6NHH01?l0003o9]TVobKI9_l00009odJiAP;o00003Om6^DH00ol0003o><LhocS7>002ocS7>003
o`000?m/TfcoK9=/00SoK9=/00?o0000odZeB_m:]DX00om:]DX2o`0000GoDJiA00?o0000obOH9olW
f2L01?lWf2L00ol0003o<l`coc?<<`03oc?<<`03o`000?mjQG[oNXEj00WoNXEj00?o0000olHia_o6
>LH03_o6>LH00ol0003ogR7NomhQgP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SofBKI
00?o0000ohIiQ_n6NHH01_n6NHH00ol0003o9]TVo`000009odJiAP04o`000?mOWeooGimOo`0000go
A[U600Co0000ocS7>?lhacSo00003?m/Tf`01Ol0003oB[E:odZeB_m:]D[o000000SoDJiA0_l00005
obOH9`03o`000?lcc3?o<l`c00;o<l`c00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oaSW6olHiaP0>
olHiaP03o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oI9]WofBKI
00OofBKI00?o0000ohIiQ_n6NHH01on6NHH00ol0003oA[U6odJiAP07odJiAP03o`000?mOWeooGimO
00;oGimO00?o0000odJiA_m6^DH02_m6^DH00ol0003o><Lho`00000>ofbCK003o`000?m:]D[o0000
00_oDJiA00?o0000obOH9olWf2L00_lWf2L01Ol0003o<l`coc?<<olcc3?o000000coNXEj00?o0000
olHia_o6>LH03_o6>LH3o`0000WogR7N00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oI9]WofBKI
00WofBKI00?o0000ohIiQ_n6NHH01_n6NHH00ol0003oA[U6odJiAP06odJiAP03o`000?mOWeooGimO
00?oGimO00?o0000odJiA_m6^DH02om6^DH00ol0003oK9=/ofbCK00>ofbCK003o`000?mA[U7oDJiA
00_oDJiA0_l00003obOH9`04o`000?lcc3?o<l`co`0000[oNXEj0ol0000>olHiaP;o00000ook1?/2
o`0000OogR7N00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oI9]WofBKI00[ofBKI00?o0000ohIi
Q_n6NHH01?n6NHH00ol0003oA[U6odJiAP06odJiAP03o`000?mOWeooGimO00GoGimO00?o0000odJi
A_m6^DH01om6^DH3o`00017oK9=/00?o0000oe6^DOmA[U403OmA[U401Ol0003o9mPWobOH9ol0003o
<l`c00Co00000omjQGX5o`0000;obSG:00?o0000olHia_o6>LH02_o6>LH2o`0000Oon`Ck0_l00004
omhQgP03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003ofBKIomTVf@0;omTVf@03o`000?n6NHKoQWV6
00CoQWV600?o0000odJiA_m6^DH01Om6^DH00ol0003oGimOoenOG`06oenOG`03o`000?m6^DKoA[U6
00CoA[U60ol00002oe>/D`03o`000?m/TfcoK9=/00ooK9=/0_l0000?oe6^D@04o`000?lWf2Oo0000
o`0000CoJ9MX0ol00008olXebP03o`000?o6>LKoaSW600OoaSW60_l0000;oo/4n`;o00000_oN8Mh0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000omTVfOoI9]T03?oI9]T6o`0000OoA[U600?o0000oenO
GomOWel02?mOWel00ol0003oA[U6odJiAP03o`0000KoDjaC00?o0000ofbCK?m/Tf`03Om/Tf`01?l0
003oIIYUofFJIOl0000?oe6^D@03o`000?mXUfSoJ9MX00GoJ9MX00?o0000olXeb_o:=LX02?o:=LX0
0ol0003oaSW6olHiaP05olHiaP03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oI9]T00ol0003oSG:=ohebS@04oheb
S@03o`000?m6^DKoA[U600?oA[U600?o0000oenOGomOWel02_mOWel2o`0000[oDjaC00?o0000ofbC
K?m/Tf`02om/Tf`00ol0003oIIYUofFJI@02ofFJI@03o`000?mA[U7oDJiA00_oDJiA0_l00007ofRG
J003o`000?o:=L[obSG:00WobSG:00?o0000olHia_o6>LH00_o6>LH2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omTVfOoI9]T02ooI9]T00ol0003oSG:=ohebS@06ohebS@05o`000?m6^DKoA[U6odJi
A_l000003OmOWel00ol0003oDjaCoe>/D`0:oe>/D`03o`000?m/TfcoK9=/00WoK9=/00?o0000ofFJ
IOmUVVD01?mUVVD00ol0003oDJiAoe6^D@08oe6^D@;o000000?o<<l`o`000?mXUfP01omXUfP00ol0
003obSG:olXebP09olXebP04o`000?o6>LKo0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oI9]WofBKI
00WofBKI00?o0000ohebSOn=LXd02?n=LXd00ol0003oA[U6o`00000=oenOG`03o`000?mC[5?oDjaC
00_oDjaC00?o0000ofbCK?m/Tf`02?m/Tf`00ol0003oIIYUofFJI@06ofFJI@03o`000?mA[U7oDJiA
00GoDJiA0_l00003oc3?<003o`000?mXUfSoJ9MX00KoJ9MX00?o0000olXeb_o:=LX02_o:=LX00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003ofBKIomTVf@07omTVf@03o`000?n=LXgoSG:=00[oSG:=00?o0000oenOGomO
Wel03?mOWel00ol0003oDjaCoe>/D`0<oe>/D`03o`000?m/TfcoK9=/00KoK9=/00?o0000ofFJIOmU
VVD02?mUVVD00ol0003oDJiAoe6^D@02oe6^D@;o00001_l`cc000ol0003oJ9MXofRGJ005ofRGJ003
o`000?o:=L[obSG:00[obSG:00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oI9]WofBKI00GofBKI
00?o0000ohebSOn=LXd03?n=LXd2o`0000coGimO00?o0000oe>/DomC[5<03OmC[5<00ol0003oK9=/
ofbCK004ofbCK003o`000?mUVVGoIIYU00[oIIYU00Co0000oe6^DOl0003o00002?l`cc000ol0003o
J9MXofRGJ006ofRGJ003o`000?o:=L[obSG:00WobSG:00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oI9]T00ol0003oSG:=ohebS@0=ohebS@03o`000?mMXUgo000000;o00002?mOWel00ol0003oDjaC
oe>/D`0?oe>/D`Ko00003_mUVVD00ol0003o<<l`oc3?<008oc3?<003o`000?mXUfSoJ9MX00KoJ9MX
00?o0000olXeb_o:=LX02Oo:=LX00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000omXUf_oJ9M[ofRGJ
0_l0000?ohebS@03o`000?mMXUgoGJ9M00?oGJ9M0ol00005oenOG`;o00004?mC[5<01_l0003o?l0o
oco0?ol0003o:=LXo`0000koIIYU00?o0000oc3?<?l`cc002Ol`cc000ol0003oJ9MXofRGJ005ofRG
J003o`000?o:=L[obSG:00WobSG:00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000omXUf_oJ9MX00ooJ9MX00ol0003o
SG:=ohebS@0=ohebS@03o`000?mMXUgoGJ9M00KoGJ9M0ol000001?mOWeoo0000odVfBOm9]TT3o`00
00coDjaC00Go0000oco0?olo`3oo?l0oo`000002obSG:003o`000?mUVVGoIIYU00_oIIYU00?o0000
oc3?<?l`cc002Ol`cc000ol0003oJ9MXofRGJ006ofRGJ003o`000?o:=L[obSG:00SobSG:0_l0000A
oo/4n`?o000000?on`Cko`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ofRGJomXUfP04omXUfPoo00003?mMXUd00ol0003oBKI9odVfB@04odVf
B@?o00002?mC[5<00ol0003o?l0ooco0?`02oco0?`05o`000?lXebSo:=LXobSG:?l000003?mUVVD0
0ol0003o<<l`oc3?<009oc3?<003o`000?mXUfSoJ9MX00GoJ9MX3?l00002onLHi`;o00003Ook1?/2
o`0000Gon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ofRGJomXUfP05omXUfP03o`000?mlPgcoO8=l00_oO8=l00?o0000oefR
GOmMXUd02_mMXUd00ol0003oBKI9odVfB@07odVfB@;o00001OmC[5<00ol0003o?l0ooco0?`03oco0
?`03o`000?lXebSo:=LX00;o:=LX00?o0000ofFJIOmUVVD02OmUVVD00ol0003o<<l`oc3?<00:oc3?
<003o`000?mXUfSoJ9MX00?oJ9MX00?o0000oiiQW_nNHIh02OnNHIh00ol0003oiaSWonLHi`02onLH
i`;o00002Ook1?/2o`0000Oon`Ck00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ofRGJomXUfP06omXUfP03o`000?mlPgcoO8=l00[o
O8=l00?o0000oefRGOmMXUd02omMXUd00ol0003oBKI9odVfB@09odVfB@?o000000?oDjaCo`000?lo
`3l01Olo`3l00ol0003o:=LXobSG:003obSG:003o`000?mUVVGoIIYU00SoIIYU3_l00003ofRGJ0;o
00002onNHIh00ol0003oiaSWonLHi`05onLHi`03o`000?ok1?_on`Ck00?on`Ck0ol00009oo/4n`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000omXUf_oJ9MX01OoJ9MX00ol0003oTVfBo`00000;ogb3O003o`000?mMXUgoGJ9M00[oGJ9M
0_l0000>odVfB@03o`000?lo`3oo?l0o00Go?l0o00?o0000obSG:?lXebP00olXebP00ol0003oIIYU
ofFJI@08ofFJI@03o`000?mZUF[oJYEZ00_oJYEZ00?o0000ofRGJ?l000003OnNHIh00ol0003oiaSW
onLHi`06onLHi`;o000000?on`Cko`000?l000003Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oJ9M[ofRGJ00KofRGJ00Co
0000oi9]T_nBKI;o00002_mlPg`00ol0003oGJ9MoefRG@09oefRG@03o`000?m;]4_o000000koBKI9
00?o0000oco0?olo`3l01Olo`3l00ol0003o:=LXobSG:004obSG:003o`000?mUVVGoIIYU00KoIIYU
00?o0000ofZEJ_mZUFX03OmZUFX00ol0003oWV6NoiiQWP0<oiiQWP03o`000?oW6>OoiaSW00SoiaSW
00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000oi9]T_nBKI800_nB
KI800ol0003oO8=logb3O006ogb3O003o`000?mMXUgoGJ9M00SoGJ9M0_l00003od^dB`03o`000?m9
]TWoBKI900_oBKI900?o0000oco0?olo`3l01Olo`3l00ol0003o:=LXobSG:005obSG:003o`000?mU
VVGoIIYU00GoIIYU00?o0000ofZEJ_mZUFX03OmZUFX00ol0003oWV6NoiiQWP0;oiiQWP03o`000?oW
6>OoiaSW00WoiaSW00?o0000oo/4nook1?/03Ook1?/00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oJ9M[ofRGJ00KofRGJ00?o0000
oi9]T_nBKI800onBKI800ol0003oO8=logb3O005ogb3O003o`000?mMXUgoGJ9M00OoGJ9M00?o0000
od^dBom;]4/00om;]4/00ol0003oBKI9odVfB@0:odVfB@03o`000?lo`3oo?l0o00Ko?l0o00?o0000
obSG:?lXebP01_lXebP00ol0003oIIYUofFJI@04ofFJI@03o`000?mZUF[oJYEZ00goJYEZ3ol0000;
onLHi`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oJ9M[ofRGJ00KofRGJ00?o0000oi9]T_nBKI801OnBKI800ol0
003oO8=logb3O004ogb3O003o`000?mMXUgoGJ9M00GoGJ9M0_l00006od^dB`03o`000?m9]TWoBKI9
00WoBKI90_l00008oco0?`03o`000?lXebSo:=LX00Ko:=LX1Ol000000omUVVGo0000ofZEJP0?ofZE
JP03o`000?nLHicoW6>L00_oW6>L00?o0000onLHiooW6>L02OoW6>L00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oJ9M[ofRGJ00KofRGJ00?o0000oi9]T_nBKI801_nBKI800ol0003o
O8=logb3O004o`0000KoGJ9M00?o0000od^dBom;]4/01om;]4/00ol0003oBKI9odVfB@05odVfB@?o
000000?o<l`co`000?lo`3l01olo`3l00ol0003o:=LXobSG:005obSG:003o`000?mXUfSoJ9MX00?o
J9MX0_l0000?ofZEJP;o00003OnLHi`00ol0003oiaSWonLHi`08onLHi`03o`000?ok1?_on`Ck00go
n`Ck00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WofRGJ00?o0000oi9]T_nBKI801onBKI82o`0000CoSG:=00Co0000oefRGOmMXUgo
GJ9M0_l0000:od^dB`03o`000?m9]TWoBKI900;oBKI90ol00005oc?<<`03o`000?lo`3oo?l0o00Go
?l0o00?o0000obSG:?lXebP01?lXebP00ol0003oJ9MXofRGJ006ofRGJ003o`000?mZUF[oJYEZ00[o
JYEZ0_l00002oh=lP`03o`000?nLHicoW6>L00[oW6>L00?o0000onLHiooW6>L02?oW6>L00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000omXUf_oJ9MX01_oJ9MX00ol0003oTVfBoi9]TP08oi9]TP03o`00
0?n=LXgoSG:=00CoSG:=00?o0000oefRGOl000003?m;]4/00ol0003oBKI9o`000002o`0000Wo<l`c
00?o0000oco0?olo`3l01?lo`3l00ol0003o:=LXobSG:003obSG:003o`000?mXUfSoJ9MX00SoJ9MX
1_l00004ofZEJP;o00001On3O8<00ol0003oW6>LoiaSW009oiaSW003o`000?oW6>OoiaSW00SoiaSW
00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000oi9]T_nBKI801onB
KI800ol0003oSG:=ohebS@06ohebS@03o`000?m;]4_oBkA;00coBkA;00?o0000oc?<<olcc3<02_lc
c3<00ol0003o?l0ooco0?`04oco0?`04o`000?lXebSo:=LXobSG:0;o00002omXUfP00ol0003oMHYe
ogF:M@03ogF:M@Co00002?n3O8<00ol0003oW6>LoiaSW008oiaSW003o`000?oW6>OoiaSW00OoiaSW
0ol0000=oo/4n`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000omXUf_oJ9MX00ooJ9MX00ol0003oTVfBoi9]TP07oi9]TP03o`000?n=
LXgoSG:=00OoSG:=00?o0000od^dBom;]4/03?m;]4/00ol0003o<l`coc?<<`0;oc?<<`03o`000?lo
`3oo?l0o00?o?l0o00Co0000obSG:?lXebSo00003OmXUfP00ol0003oMHYeogF:M@06ogF:M@03o`00
0?n3O8?oPgb300OoPgb300?o0000oiaSW?nLHi`01onLHi`00ol0003oiaSWonLHi`06onLHi`04o`00
0?ol0ocoo0?loo`3o0;o00002ook1?/00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oJ9M[ofRGJ00;ofRGJ00?o0000oi9]T_nBKI80
1_nBKI800ol0003oSG:=ohebS@09ohebS@03o`000?m;]4_oBkA;00WoBkA;0_l0000>oc?<<`?o0000
0olo`3l00ol0003o:=LXo`00000=ofRGJ003o`000?meRWGoMHYe00OoMHYe00?o0000oh=lPon3O8<0
2?n3O8<:o`0000KoiaSW0_l00006oo`3o003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoTVfB00?o
0000ohebSOn=LXd02_n=LXd00ol0003oBkA;od^dB`06od^dB`;o000000?oBKI9o`000?lcc3<02olc
c3<2o`0000?oIYUV1Ol0000>ofRGJ003o`000?meRWGoMHYe00OoMHYe00?o0000oh=lPon3O8<02?n3
O8<00ol0003o^4NhokQ7^006okQ7^003o`000?oW6>OoiaSW00?oiaSW00?o0000oo`3o?ol0o`01ool
0o`2o`0000Son`Ck00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003ocS7>olhacP03olhacPCo00000_nBKI800ol0003oSG:=ohebS@0;
ohebS@03o`000?m;]4_oBkA;00?oBkA;0ol00004odVfB@03o`000?lcc3?o<l`c00Oo<l`c0_l00008
ofJIIP03o`000?mXUfSoJ9MX00goJ9MX00?o0000ogF:MOmeRWD02?meRWD00ol0003oPgb3oh=lP`07
oh=lP`03o`000?nhAkSo^4Nh00Oo^4Nh0ol000000ooW6>Oo0000oo`3o00;oo`3o0;o00001Ook1?/0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o><LkocS7>00OocS7>0_l0000?ohebS@03o`000?m;]4_oBkA;00;o00002?m9]TT00ol0
003o<l`coc?<<`05oc?<<`03o`000?mVVFKoIYUV00SoIYUV00?o0000ofRGJ?mXUfP03OmXUfP00ol0
003oMHYeogF:M@08ogF:M@03o`000?n3O8?oPgb300KoPgb300?o0000okQ7^?nhAkP02?nhAkP01?l0
003oj1OXonPGj?l0000?oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003ocS7>olhacP09olha
cP03o`000?n=LXgoSG:=00koSG:=0_l0000;odVfB@03o`000?lcc3?o<l`c00;o<l`c0_l0000;ofJI
IP03o`000?mXUfSoJ9MX00goJ9MX00?o0000ogF:MOmeRWD02?meRWD00ol0003oPgb3oh=lP`06oh=l
P`03o`000?nhAkSo^4Nh00Oo^4Nh00Go0000onPGj?oX5nSoj1OXo`00000@oo`3o0;o000000?on`Ck
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003ocS7>olhacP0:olhacP03o`000?n=LXgoSG:=00goSG:=0_l0000<odVfB@04o`000?lcc3?o0000
o`0000goIYUV00?o0000ofRGJ?mXUfP03?mXUfP00ol0003oMHYeogF:M@09ogF:M@03o`000?n3O8?o
Pgb300KoPgb300?o0000okQ7^?nhAkP01_nhAkP00ol0003oj1OXonPGj003onPGj003o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003ocS7>olhacP0:olhacP03o`000?n=LXgoSG:=00coSG:=00Co0000ocK9
=_lfbCKo00003?m9]TT00ol0003oIYUVofJIIP0>ofJIIP03o`000?mXUfSoJ9MX00SoJ9MX1?l0000;
ogF:M@03o`000?n3O8?oPgb300KoPgb300?o0000okQ7^?nhAkP01OnhAkP00ol0003oj1OXonPGj004
onPGj003o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003ocS7>olhacP0;olhacP03o`000?n=LXgoSG:=
00_oSG:=00?o0000ocK9=_lfbCH00_lfbCH00ol0003oBKI9odVfB@09odVfB@03o`000?mVVFKoIYUV
00koIYUV00Co0000ofRGJ?mXUfSoJ9MX1ol00003ofjAKP03o`000?meRWGoMHYe00WoMHYe00?o0000
oh=lPon3O8<01_n3O8<00ol0003o^4NhokQ7^004okQ7^003o`000?oX5nSoj1OX00Koj1OX00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?o><LkocS7>00cocS7>00?o0000ohebSOn=LXd02_n=LXd00ol0
003o=/TfocK9=P03ocK9=P03o`000?m9]TWoBKI900SoBKI900?o0000ofJII_mVVFH03_mVVFH4o`00
00_oKY5^00?o0000ogF:MOmeRWD02?meRWD00ol0003oPgb3oh=lP`05oh=lP`03o`000?nhAkSo^4Nh
00Go^4Nh00?o0000onPGj?oX5nP01_oX5nP00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000olhac_o>
<Lh03?o><Lh7o`0000GoSG:=00?o0000ocK9=_lfbCH01OlfbCH00ol0003oBKI9odVfB@07odVfB@03
o`000?mVVFKoIYUV00koIYUV00?o0000ofjAK_m^TFh03Om^TFh00ol0003oMHYeogF:M@08ogF:M@03
o`000?n3O8?oPgb300CoPgb300?o0000okQ7^?nhAkP01?nhAkP00ol0003oj1OXonPGj007onPGj003
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003ocS7>olhacP0=olhacP03o`000?nRGJ;oXUfR00CoXUfR
1Ol00009ocK9=P03o`000?m9]TWoBKI900KoBKI900?o0000ofJII_mVVFH03_mVVFH00ol0003oKY5^
ofjAKP0=ofjAKP03o`000?meRWGoMHYe00SoMHYe00Co0000oh=lPon3O8?oPgb31Ol00004okQ7^003
o`000?oX5nSoj1OX00Woj1OX1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=olhacP03o`000?nRGJ;oXUfR00WoXUfR
0_l00009ocK9=P03o`000?m9]TWoBKI900KoBKI900?o0000ofJII_mVVFH03?mVVFH00ol0003oKY5^
ofjAKP0?ofjAKPKo00001?meRWD4o`0000Go`cc30_l000000onhAkSo0000onPGj00;onPGj004o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oQ7^7ohAkQon4Nh@?o00002_o><Lh00ol0003o
XUfRoj9MXP09oj9MXP03o`000?m:]D[o000000;o00001olfbCH00ol0003oBKI9odVfB@05odVfB@03
o`000?mVVFKoIYUV00SoIYUV1Ol0000AofjAKP03o`000?moOgooOgmo00?oOgmo1?l0000;ol<l``03
o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000on4NhOoQ7^401OoQ7^42o`0000OocS7>
00?o0000oj9MX_nRGJ802_nRGJ800ol0003oB[E:odZeBP02odZeBP?o00001OlfbCH00ol0003oBKI9
odVfB@04odVfB@04o`000?mVVFKoIYUVofJIIPOo00001?mC[5<00ol0003oKY5^ofjAKP0>ofjAKP03
o`000?moOgooOgmo00OoOgmo00?o0000ol<l`oo3?<<02Oo3?<<00ol0003oj1OXonPGj009onPGj003
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ohAkQon4Nh@08on4Nh@;o00001?o><Lh00ol0003oXUfR
oj9MXP0;oj9MXP03o`000?m:]D[oB[E:00GoB[E:0ol00003ocK9=P04o`000?m9]TWoBKI9odVfB@Ko
00003?mC[5<00ol0003oKY5^ofjAKP0=ofjAKP03o`000?moOgooOgmo00OoOgmo00?o0000ol<l`oo3
?<<02_o3?<<00ol0003oj1OXonPGj008onPGj003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=on4Nh@?o000000?ocS7>o`000?nRGJ80
3?nRGJ800ol0003oB[E:odZeBP08odZeBP?o000000Co=/Tfo`000?l0003o00000_n0Oh000ol0003o
DjaCoe>/D`0=oe>/D`03o`000?m^TFkoKY5^00coKY5^00?o0000ogmoOomoOgl02?moOgl00ol0003o
`cc3ol<l``0;ol<l``03o`000?oX5nSoj1OX00Koj1OX00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003on`Ckoo/4nook1?_o000000oo
hAkQ00?o0000oj9MX_nRGJ803?nRGJ800ol0003oB[E:odZeBP0;odZeBP03o`000?n0Oh3oP7n000?o
P7n000?o0000oe>/DomC[5<03?mC[5<00ol0003o>l@ko`00000=ofjAKP03o`000?moOgooOgmo00So
Ogmo00?o0000ol<l`oo3?<<03?o3?<<3o`0000Goj1OX00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`03oo/4n`03o`00
0?oQ7^7ohAkQ00cohAkQ00?o0000oj9MX_nRGJ803?nRGJ800ol0003oB[E:odZeBP0:odZeBP03o`00
0?n0Oh3oP7n000GoP7n000?o0000oe>/DomC[5<02_mC[5<01?l0003o>l@koc_4>olka3/2o`0000[o
KY5^00?o0000ogmoOomoOgl02OmoOgl00ol0003o`cc3ol<l``0<ol<l``03o`000?o/4ncok1?/00?o
000000?oj1OXo`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003on`Ckoo/4n`04oo/4n`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000oj9MX_nRGJ80
3?nRGJ800ol0003oB[E:odZeBP09odZeBP03o`000?n0Oh3oP7n000KoP7n000?o0000oe>/DomC[5<0
2OmC[5<00ol0003o>l@koc_4>`02oc_4>`03o`000?mmPWgo000000;o00001om^TFh00ol0003oOgmo
ogmoO`09ogmoO`03o`000?o3?<?o`cc300_o`cc300?o0000on`Ck?o/4n`01?o/4n`00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ok
1?_on`Ck00Kon`Ck00?o0000on4NhOoQ7^402ooQ7^400ol0003oXUfRoj9MXP0;oj9MXP03o`000?m:
]D[oB[E:00SoB[E:00?o0000oh1oP?n0Oh001on0Oh000ol0003oDjaCoe>/D`08oe>/D`03o`000?lk
a3_o>l@k00?o>l@k00?o0000ogf2OOmmPWd00_mmPWd2o`0000CoKY5^00?o0000ogmoOomoOgl02_mo
Ogl00ol0003o`cc3ol<l``0:ol<l``03o`000?o/4ncok1?/00Gok1?/00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oQ7^7ohAkQ00[ohAkQ0ol0000;oj9MXPKo00001?m:]DX00ol0003oP7n0oh1oP008
oh1oP003o`000?mC[5?oDjaC00OoDjaC00?o0000oc_4>olka3/00olka3/00ol0003oOH9mogf2O@05
ogf2O@?o000000?oKY5^o`000?moOgl02omoOgl00ol0003o`cc3ol<l``09ol<l``03o`000?o/4nco
k1?/00Ook1?/00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000okE:
]OneB[D01?l00006oj9MXP03o`000?nIIYWoVFJI00CoVFJI1?l0000<oh1oP003o`000?mC[5?oDjaC
00GoDjaC00?o0000oc_4>olka3/01?lka3/00ol0003oOH9mogf2O@08ogf2O@03o`000?moOgooOgmo
00_oOgmo00?o0000ol<l`oo3?<<02?o3?<<00ol0003ok1?/on`Ck008on`Ck0Go00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003on`Ckoo/4n`0:oo/4n`03
o`000?oQ7^7ohAkQ00OohAkQ00?o0000okE:]OneB[D01OneB[D3o`0000;oXUfR00?o0000oiUVVOnI
IYT02?nIIYT00ol0003oP7n0oh1oP00:oh1oP003o`000?mC[5?oDjaC00CoDjaC00?o0000oc_4>olk
a3/01Olka3/00ol0003oOH9mogf2O@08ogf2O@03o`000?moOgooOgmo00WoOgmo1?l00008ol<l``03
o`000?o/4ncok1?/00Wok1?/00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo/4nook1?/02ook1?/00ol0003ohAkQ
on4Nh@05on4Nh@03o`000?neB[Go]DZe00Wo]DZe0_l0000<oiUVV@03o`000?n0Oh3oP7n000WoP7n0
00?o0000oe>/DomC[5<00omC[5<00ol0003o>l@koc_4>`05oc_4>`03o`000?mmPWgoOH9m00[oOH9m
00?o0000ogmoOomoOgl01?moOgl4o`0000Co]4^d00?o0000ol<l`oo3?<<01?o3?<<00ol0003ok1?/
on`Ck00:on`Ck003o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000okE:]OneB[D02one
B[D00ol0003oVFJIoiUVV@0:oiUVV@03o`000?n0Oh3oP7n000WoP7n000?o0000oe>/DomC[5<00_mC
[5<00ol0003o>l@koc_4>`06oc_4>`03o`000?mmPWgoOH9m00[oOH9m00?o0000ogmoOomoOgl01?l0
0009okA;]0Ko00003?o/4n`00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ok1?_on`Ck00con`Ck00Co0000on4NhOoQ7^7ohAkQ0_l0
000=okE:]@03o`000?nIIYWoVFJI00[oVFJI00?o0000oh1oP?n0Oh002On0Oh001Ol0003oDjaCoe>/
DomC[5?o000000Wo>l@k00?o0000ogf2OOmmPWd02ommPWd2o`0000go]4^d00?o0000onHIi_oV6NH0
0_oV6NH00ol0003ok1?/on`Ck00:on`Ck003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo/4nook1?/03Ook1?/00ol0003ohAkQo`00
0002onPGj0;o00002oneB[D00ol0003oVFJIoiUVV@0;oiUVV@03o`000?n0Oh3oP7n000WoP7n000?o
0000oe>/Dol000002Olka3/00ol0003oOH9mogf2O@0<ogf2O@03o`000?ndBkCo]4^d00co]4^d00?o
0000onHIi_oV6NH00ooV6NH00ol0003ok1?/on`Ck009on`Ck003o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo/4nook1?/03Ook1?/0
0ol0003oj1OXonPGj003onPGj0;o00002_neB[D00ol0003oVFJIoiUVV@0:oiUVV@03o`000?n0Oh3o
P7n000SoP7n01Ol00008oc_4>`03o`000?mmPWgoOH9m00coOH9m00?o0000okA;]?ndBk@02ondBk@0
0ol0003oiQWVonHIiP05onHIiP03o`000?o/4ncok1?/00Sok1?/00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003on`Ckoo/4n`0<oo/4
n`;o00001ooX5nP2o`0000So]DZe00?o0000oiUVVOnIIYT02_nIIYT00ol0003oP7n0oh1oP007oh1o
P003o`000?m`Sg3oL8m`00?oL8m`0ol00005oc_4>`03o`000?mmPWgoOH9m00_oOH9m00?o0000okA;
]?ndBk@03?ndBk@00ol0003oiQWVonHIiP06onHIiP03o`000?o/4ncok1?/00Ook1?/00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?ol0oco000000Woj1OX00?o0000okE:]OneB[D01OneB[D2o`0000co
VFJI00?o0000oh1oP?n0Oh001On0Oh000ol0003oL8m`og2?L007og2?L0?o000000?o>l@ko`000?mm
PWd03OmmPWd00ol0003o]4^dokA;]00<okA;]003o`000?oV6NKoiQWV00KoiQWV00?o0000on`Ck?o/
4n`01_o/4n`00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ok1?_on`Ck00Son`Ck0_l00003oo`3o003o`000?oX5nSoj1OX00Ooj1OX
0_l00004okE:]@03o`000?o2?L;o`Sg200;o00002_nIIYT00ol0003oP7n0oh1oP003oh1oP0;o0000
3Om`Sg02o`0000goOH9m0ol0000=okA;]003o`000?oV6NKoiQWV00OoiQWV00?o0000on`Ck?o/4n`0
1Oo/4n`00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ok1?/00ol0003oo0?loo`3o004oo`3o003o`000?oX5nSoj1OX00Soj1OX0_l0
00000oneB[Go0000ol8m`P04ol8m`P03o`000?nIIYWoVFJI00OoVFJI00Co0000oh1oP?n0Oh3oP7n0
0_l00002oi=/T`03o`000?m`Sg3oL8m`00coL8m`3Ol00003oiYUVP03o`000?ndBkCo]4^d00[o]4^d
00?o0000onHIi_oV6NH02?oV6NH01?l0003ok1?/on`Ck?o/4n`4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo/4n`;o00002?ol0o`00ol0003oj1OX
onPGj009onPGj003o`000?o2?L;o`Sg200Go`Sg20_l00008oiUVV@03o`000?n0Oh3o000000GoTfbC
00?o0000og2?L?m`Sg002om`Sg000ol0003oMXUfogJ9MP09ogJ9MP03o`000?nJII[oVVFJ00;oVVFJ
0_l00009okA;]003o`000?oV6NKoiQWV00[oiQWV0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ook1?_o0000oo`3
o00:oo`3o003o`000?oX5nSoj1OX00Soj1OX00?o0000ol8m`_o2?L801oo2?L84o`0000?oVFJI0ol0
0007oi=/T`03o`000?m`Sg3oL8m`00[oL8m`00?o0000ogJ9M_mfRGH02OmfRGH00ol0003oVVFJoiYU
VP04oiYUVP;o00001ondBk@00ol0003oiQWVonHIiP0:onHIiP03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?oX5nSoj1OX00Ooj1OX00?o0000ol8m`_o2?L802?o2?L80
1?l0003o`Sg2ol8m`_o2?L83o`0000;o[U6^00?o0000oi=/TonCK9<01_nCK9<00ol0003oL8m`og2?
L008og2?L003o`000?mfRGKoMXUf00[oMXUf00?o0000oiYUV_nJIIX01_nJIIX00ol0003o]4^dokA;
]004okA;]003o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onPGj?oX5nP01OoX5nP00ol0003o`Sg2ol8m`P08ol8m`P03o`000?o2?L;o
`Sg200Co`Sg200Go0000ojiA[_n^DJko[U6^o`000008oi=/T`03o`000?m`Sg3oL8m`00OoL8m`00?o
0000ogJ9M_mfRGH02_mfRGH00ol0003oVVFJoiYUVP07oiYUVP;o00001?ndBk@00ol0003oiQWVonHI
iP08onHIiP03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onPGj?oX5nP00ooX5nP0
0ol0003o`Sg2ol8m`P08ol8m`P03o`000?o2?L;o`Sg200Co`Sg200?o0000ojiA[_n^DJh00_n^DJh0
0ol0003oTfbCoi=/T`07oi=/T`03o`000?m`Sg3oL8m`00KoL8m`00?o0000ogJ9M_mfRGH02_mfRGH0
0ol0003oVVFJoiYUVP09oiYUVP05o`000?ndBkCo]4^dokA;]?l000002OoV6NH00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_o`Sg200?o0000ol8m`_o2?L801?o2?L800ol0003o[U6^ojiA[P03
ojiA[P03o`000?nCK9?oTfbC00OoTfbC00?o0000og2?L?m`Sg001Om`Sg000ol0003oMXUfogJ9MP0:
ogJ9MP03o`000?nJII[oVVFJ00WoVVFJ1?l00009onHIiP03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o]4^gokA;]
ondBkOl000002_o2?L800ol0003o`Sg2ol8m`P05ol8m`P03o`000?n^DJko[U6^00?o[U6^00?o0000
oi=/TonCK9<02?nCK9<00ol0003oL8m`og2?L004og2?L003o`000?mfRGKoMXUf00WoMXUf00?o0000
oiYUV_nJIIX02?nJIIX2o`0000?oiA[U00?o0000onHIi_oV6NH01_oV6NH00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003o`Sg2ol8m`P06ol8m`P03o`000?o2?L;o`Sg2
00Go`Sg200?o0000ojiA[_n^DJh01?n^DJh00ol0003oTfbCoi=/T`09oi=/T`03o`000?m`Sg3oL8m`
00;oL8m`00?o0000ogJ9M_mfRGH02_mfRGH00ol0003oVVFJoiYUVP06oiYUVP;o00001_oU6^D8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003okA;]ondBk@05ondBk@03o`000?o2?L;o`Sg200Go`Sg200?o0000ol8m`_o2
?L801Oo2?L800ol0003o[U6^ojiA[P05ojiA[P03o`000?nCK9?oTfbC00WoTfbC00Go0000og2?L?m`
Sg3oL8m`o`00000<ogJ9MP03o`000?nJII[oVVFJ00CoVVFJ0_l00008onDJi@03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o]4^gokA;]00OokA;]00?o0000ol8m`_o2
?L800oo2?L800ol0003o`Sg2ol8m`P06ol8m`P03o`000?n^DJko[U6^00Go[U6^00?o0000oi=/TonC
K9<02_nCK9<00ol0003oL8m`o`000004o`0000WoMXUf00?o0000oiYUV_nJIIX00_nJIIX2o`0000[o
iA[U00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003okA;]ondBk@07ondBk@03o`00
0?o2?L;o`Sg200;o`Sg200?o0000ol8m`_o2?L801_o2?L800ol0003o[U6^ojiA[P07ojiA[P;o0000
2onCK9<00ol0003o^dBkok]4^`03ok]4^`Oo00000_mfRGH00ol0003oVVFJoiYUVP02o`0000_oiA[U
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000ondBkOo]4^d02Oo]
4^d01Ol0003o`Sg2ol8m`_o2?L;o000000So`Sg200?o0000ojiA[_n^DJh01on^DJh00ol0003ofBKI
o`000002o`0000SoTfbC00?o0000ok]4^onkA;/02_nkA;/5o`0000goiA[U00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<ondBk@03o`000?o2?L;o000000Wo`Sg200?o
0000ojiA[_n^DJh01_n^DJh00ol0003ofBKIomTVf@03omTVf@?o00001?nCK9<00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oU6^GoiA[U00goiA[U00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000ool0o`2o`0000_okA;]00?o0000ol8m`_o2?L801oo2?L800ol0003o[U6^ojiA[P07
ojiA[P03o`000?oI9]WofBKI00KofBKI0ol000000onCK9?o0000ok]4^`0>ok]4^`03o`000?oU6^Go
iA[U00coiA[U00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00Koo0?l0_l00009ondB
k@03o`000?o2?L;o`Sg200;o`Sg21_l00008ojiA[P03o`000?oI9]WofBKI00[ofBKI00?o0000ok]4
^onkA;/03onkA;/00ol0003oiA[UonDJi@0:onDJi@;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00So
o0?l0_l00007ondBk@Go00001_oZ5NX00ol0003o[U6^ojiA[P05ojiA[P03o`000?oI9]WofBKI00[o
fBKI00?o0000ok]4^onkA;/03onkA;/00ol0003oiA[UonDJi@07onDJi@?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?ol0ocoo0?l00[oo0?l0_l00005ondBk@03o`000?oZ5N[ojQGZ00WojQGZ00?o0000ojiA[_n^
DJh00on^DJh00ol0003ofBKIomTVf@0;omTVf@03o`000?nkA;_o^dBk00oo^dBk00?o0000onDJiOoU
6^D01OoU6^D2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3o00<oo`3o0;o000000?okA;]o`000?l00000
3OoZ5NX00ol0003o[U6^ojiA[P02ojiA[P03o`000?oI9]WofBKI00_ofBKI5?l00004onDJi@;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000oo`3o?ol0o`03_ol0o`00ol0003oo0?lo`00000>onXEjP04o`000?n^DJko[U6^o`0000kofBKI
00?o0000ondBkOo]4^d04?o]4^d00ol0003oiA[Uo`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo0?loo`3
o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000003_oZ5NX00ol0003o[U6^o`00000>omTVf@03o`00
0?o]4^gokA;]017okA;]00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?ol0ocoo0?l00coo0?l00?o
0000oo`3o?ol0o`00_ol0o`00ol0003ojQGZonXEjP0=onXEjP03o`000?oI9]WofBKI00WofBKI1Ol0
000BondBk@;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ojQGZonXEjP0<onXEjP03o`000?oI9]WofBKI00;ofBKI1ol00004oo/4n`03o`000?o]4^go
kA;]00ookA;]00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo0?loo`3o006oo`3
o003o`000?oZ5N[ojQGZ00cojQGZ1?l0000<oo/4n`03o`000?o]4^gokA;]00cokA;]0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Oo
o0?l00?o0000onXEj_oZ5NX03?oZ5NX00ol0003on`Ckoo/4n`0=oo/4n`03o`000?o]4^gokA;]00_o
kA;]00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`02Ool0o`00ol0003ojQGZonXEjP0:onXEjP03o`000?ok1?_on`Ck00kon`Ck00?o0000ondBkOo]
4^d02Oo]4^d2o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000onXEj_oZ5NX02_oZ5NX00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?o]4^gokA;]00KokA;]0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003oo`3o?l0003oo0?l00goo0?l3?l0
000Aoo/4n`?o00001_o]4^d00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ol0ocoo0?loo`3o?l000000oo]4^d2o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ol0oco
o0?l00?oo0?l00?o0000ondBkOl000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4
nook1?/02ook1?/00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo/4nook1?/02Ook1?/00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003on`Ckoo/4
n`07oo/4n`;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ok1?_on`Cko`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool02?l00?l00oooo`3o003oo`00o`08o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`0:o`00o`03oooo0?l0
0?oo003o00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00[o003o00?oool0o`00ool00?l01_l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`0;o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000[o003o0_ooo`0;o`00o`03oooo0?l00?oo003o00Go
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l2oooo00_o003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`0<o`00o`03oooo0?l00?oo003o00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`0<o`00o`03oooo0?l00?oo003o00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00[o003o0_ooo`0<o`00o`03oooo0?l00?oo003o00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`002_l00?l2oooo00go003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02_l00?l2
oooo00go003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00
o`;oool03Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o
003o0_ooo`0>o`00o`04oooo0?l00?oo003oo`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00
o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00[o
003o0_ooo`05o`00o`03oooo0?l00?oo003o00Ko003o00?oool0o`00ool00?l00_l00?l2oooo00Co
003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo
0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`07o`00o`;oool01_l00?l00oooo`3o003o
o`00o`05o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00Go003o1?ooo`06o`00o`[oool01?l00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol0
0?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo02;o003o0_ooo`06
o`00o`[oool01Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(180) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.987 .013 .987 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.987 .013 .987 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.987 .013 .987 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.986 .014 .986 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.915 .085 .915 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.985 .015 .985 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.913 .087 .913 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.923 .077 .923 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.885 .115 .885 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.981 .019 .981 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.843 .157 .843 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.986 .014 .986 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.76 .24 .76 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.753 .247 .753 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.982 .018 .982 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.988 .012 .988 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.661 .339 .661 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.807 .193 .807 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.98 .02 .98 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.982 .018 .982 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.985 .015 .985 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.903 .097 .903 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.473 .527 .473 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.712 .288 .712 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.567 .433 .567 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.554 .446 .554 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.64 .36 .64 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.848 .152 .848 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.885 .115 .885 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.987 .013 .987 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.564 .436 .564 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.789 .211 .789 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.432 .568 .432 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.86 .14 .86 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.814 .186 .814 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.986 .014 .986 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.719 .281 .719 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.764 .236 .764 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.627 .373 .627 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.856 .144 .856 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.588 .412 .588 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.989 .011 .989 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.901 .099 .901 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.574 .426 .574 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.395 .605 .395 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.385 .615 .385 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.916 .084 .916 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.933 .067 .933 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.722 .278 .722 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.986 .014 .986 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.562 .438 .562 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.501 .499 .501 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.506 .494 .506 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.534 .466 .534 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.281 .719 .281 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.534 .466 .534 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.641 .359 .641 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.987 .013 .987 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.645 .355 .645 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.549 .451 .549 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.903 .097 .903 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.163 .837 .163 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.774 .226 .774 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.735 .265 .735 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.505 .495 .505 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.227 .773 .227 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.345 .655 .345 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.078 .922 .078 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.132 .868 .132 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.414 .586 .414 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.273 .727 .273 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.358 .642 .358 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.772 .228 .772 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.36 .64 .36 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.391 .609 .391 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.607 .393 .607 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.919 .081 .919 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.986 .014 .986 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.203 .797 .203 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.281 .719 .281 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.3 .7 .3 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.985 .015 .985 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.623 .377 .623 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.36 .64 .36 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.218 .782 .218 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.156 .844 .156 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.45 .55 .45 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.269 .731 .269 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.906 .094 .906 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.343 .657 .343 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.085 .915 .085 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.696 .304 .696 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.259 .741 .259 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.2 .8 .2 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.497 .503 .497 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.854 .146 .854 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.412 .588 .412 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.08 .92 .08 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.202 .798 .202 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.458 .542 .458 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.253 .747 .253 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.269 .731 .269 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.856 .144 .856 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.224 .776 .224 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.162 .838 .162 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.122 .878 .122 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.984 .016 .984 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.127 .873 .127 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.304 .696 .304 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.18 .82 .18 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.587 .413 .587 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.378 .622 .378 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.984 .016 .984 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.428 .572 .428 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.314 .686 .314 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.341 .659 .341 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.394 .606 .394 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.247 .753 .247 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.197 .803 .197 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.309 .691 .309 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.439 .561 .439 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.985 .015 .985 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.721 .279 .721 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.362 .638 .362 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.483 .517 .483 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.22 .78 .22 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.904 .096 .904 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.042 .958 .042 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.225 .775 .225 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.212 .788 .212 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.4 .6 .4 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.611 .389 .611 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.136 .864 .136 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.986 .014 .986 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.287 .713 .287 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.742 .258 .742 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.931 .069 .931 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.488 .512 .488 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.468 .532 .468 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.339 .661 .339 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.849 .151 .849 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.135 .865 .135 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.268 .732 .268 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.39 .61 .39 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.639 .361 .639 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.129 .871 .129 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.267 .733 .267 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.376 .624 .376 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.417 .583 .417 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.985 .015 .985 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.189 .811 .189 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.985 .015 .985 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.894 .106 .894 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.444 .556 .444 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.383 .617 .383 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.24 .76 .24 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.622 .378 .622 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.3 .7 .3 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.902 .098 .902 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.43 .57 .43 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.461 .539 .461 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.464 .536 .464 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.5 .5 .5 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.741 .259 .741 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.456 .544 .456 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.239 .761 .239 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.14 .86 .14 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.178 .822 .178 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.414 .586 .414 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.716 .284 .716 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.986 .014 .986 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.9 .1 .9 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.316 .684 .316 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.197 .803 .197 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.407 .593 .407 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.757 .243 .757 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.522 .478 .522 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.985 .015 .985 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.41 .59 .41 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.77 .23 .77 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.904 .096 .904 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.986 .014 .986 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.268 .732 .268 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.339 .661 .339 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.893 .107 .893 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.359 .641 .359 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.483 .517 .483 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.684 .316 .684 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.37 .63 .37 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.523 .477 .523 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.799 .201 .799 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.64 .36 .64 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.634 .366 .634 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.736 .264 .736 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.383 .617 .383 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.926 .074 .926 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.701 .299 .701 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.489 .511 .489 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.456 .544 .456 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.986 .014 .986 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.687 .313 .687 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.406 .594 .406 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.985 .015 .985 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.911 .089 .911 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.781 .219 .781 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.91 .09 .91 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.392 .608 .392 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.888 .112 .888 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.688 .312 .688 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.574 .426 .574 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.986 .014 .986 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.567 .433 .567 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.486 .514 .486 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.986 .014 .986 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.738 .262 .738 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.981 .019 .981 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.987 .013 .987 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.614 .386 .614 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.984 .016 .984 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.497 .503 .497 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.985 .015 .985 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.523 .477 .523 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.767 .233 .767 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.601 .399 .601 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.871 .129 .871 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.887 .113 .887 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.703 .297 .703 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.631 .369 .631 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.694 .306 .694 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.821 .179 .821 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.879 .121 .879 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.813 .187 .813 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.826 .174 .826 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.982 .018 .982 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.684 .316 .684 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.9 .1 .9 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.984 .016 .984 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.925 .075 .925 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.911 .089 .911 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.69 .31 .69 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.912 .088 .912 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.892 .108 .892 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.735 .265 .735 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.984 .016 .984 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.982 .018 .982 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.894 .106 .894 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.986 .014 .986 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.986 .014 .986 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.984 .016 .984 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.985 .015 .985 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.984 .016 .984 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.985 .015 .985 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ok
1?/4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003on`Ckoo/4n`0=oo/4n`05o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003oiQWVonHIi_l0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ok1?/03ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onHIi_oV6NH00_oV6NH00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ok1?_on`Ck00kon`Ck00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oV6NKoiQWV00?oiQWV00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onHIi_oV6NH01OoV6NH00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiQWVonHIiP06onHIiP03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ok1?/00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onHIi_oV6NH02?oV6NH00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oW6>Oo0000013on`Ck00?o0000oo`3o?ol0o`02?ol
0o`9o`0000coiQWV00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onLHi`03o`000?ok
1?_on`Ck00con`Ck00?o0000oo`3o?ol0o`02Ool0o`00ol0003oi1_Ton@Ki005on@Ki003o`000?oV
6NKoiQWV00_oiQWV0ol00003on@Ki003o`000?ol0ocoo0?l00coo0?l0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onLHiooW6>L00ooW6>L00ol0003on`Ckoo/4n`0;oo/4n`;o00002ool0o`00ol0003oi1_Ton@Ki006
on@Ki003o`000?oV6NKoiQWV00[oiQWV00?o0000on@Ki?oT6n@01?oT6n@00ol0003oo0?loo`3o00:
oo`3o004o`000?oS7>?ohacSon<Lh`;o00002_ok1?/2o`000003on<Lhol0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWonLHi`05onLHi`03o`000?ok1?_o
n`Ck00Won`Ck00?o0000onLHiol000002ool0o`00ol0003oi1_Ton@Ki006on@Ki003o`000?oV6NKo
iQWV00WoiQWV00?o0000on@Ki?oT6n@01_oT6n@00ol0003oo0?loo`3o008oo`3o003o`000?oS7>?o
hacS00CohacS0_l00005oo/4n`?o00001?oS7><00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008onLHi`03o`000?ok1?_on`Ck00Oon`Ck0_l00003onLH
i`03o`000?ol0ocoo0?l00Ooo0?l00?o0000on@Ki?oT6n@01ooT6n@00ol0003oiQWVonHIiP09onHI
iP03o`000?oT6nCoi1_T00Ooi1_T00?o0000oo`3o?ol0o`01Ool0o`2o`0000WohacS0_l000000ook
1?_o0000o`000007on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000onLHiooW
6>L02?oW6>L00ol0003on`Ckoo/4n`06oo/4n`03o`000?oW6>OoiaSW00?oiaSW00?o0000oo`3o?ol
0o`01ool0o`00ol0003oi1_Ton@Ki008on@Ki003o`000?oV6NKoiQWV00OoiQWV00?o0000on@Ki?oT
6n@02OoT6n@00ol0003oo0?loo`3o003oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000on<LhooS
7><01ooS7><00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWo`000005oo`3o0;o00002ooW6>L2o`0000Kon`Ck
00?o0000onLHiooW6>L01OoW6>L00ol0003oo0?loo`3o006oo`3o003o`000?oT6nCoi1_T00Soi1_T
00?o0000onHIi_oV6NH01_oV6NH00ol0003oi1_Ton@Ki00;on@Ki005o`000?ol0ocoo0?loo`3o?l0
00003_oS7><00ol0003ohacSon<Lh`08on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oW6>OoiaSWonLHiol0
00000ool0o`00ol0003oiaSWonLHi`0:onLHi`04o`000?oJ9M[ofRGJo`0000?on`Ck0_l00008onLH
i`03o`000?ol0ocoo0?l00Koo0?l00?o0000on@Ki?oT6n@02OoT6n@00ol0003oiQWVonHIiP05onHI
iP03o`000?oT6nCoi1_T00coi1_T00?o0000oo`3o?l000003ooS7><00ol0003ohacSon<Lh`08on<L
h`03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWonLHi`03onLHi`03o`000?ol0oco000000_o
iaSW0_l00004omXUfP03o`000?ok1?_o000000_oiaSW00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
i1_Ton@Ki009on@Ki003o`000?oV6NKoiQWV00CoiQWV00?o0000on@Ki?oT6n@03_oT6n@00ol0003o
hacSon<Lh`0>on<Lh`03o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000onLHiooW6>L0
1?oW6>L00ol0003oiaSWonLHi`09onLHi`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000onLHiooW6>L0
2_oW6>L00ol0003oo0?loo`3o005oo`3o003o`000?oT6nCoi1_T00[oi1_T00?o0000onHIi_oV6NH0
0ooV6NH00ol0003oi1_Ton@Ki00>on@Ki003o`000?oS7>?ohacS00gohacS00?o0000on<LhooS7><0
2_oS7><00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWonLH
i`05onLHi`03o`000?oW6>OoiaSW00OoiaSW0_l00008omXUfP03o`000?oW6>OoiaSW00_oiaSW00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oi1_Ton@Ki00:on@Ki004o`000?oV6NKoiQWVonHIiP?o0000
3ooT6n@00ol0003ohacSon<Lh`0>on<Lh`03o`000?oS7>?ohacS00[ohacS00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oW6>OoiaSW00OoiaSW00?o0000onLHiooW6>L01?oW6>L2o`0000_ofRGJ1?l0
0009onLHi`03o`000?ol0ocoo0?l00?oo0?l00?o0000on@Ki?oT6n@02ooT6n@01?l0003oiQWVo`00
0?l00003ol4n`@;o00003?oT6n@2o`00013ohacS00?o0000on<LhooS7><02ooS7><00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003oiaSW
onLHi`07onLHi`03o`000?oW6>OoiaSW00?oiaSW00?o0000omXUf_oJ9MX02ooJ9MX01?l0003o^4Nh
okQ7^?nhAkP5o`0000GoiaSW00?o0000oo`3o?ol0o`00_ol0o`00ol0003oi1_Ton@Ki00<on@Ki003
o`000?o1?/7o`Ck100Go`Ck10_l00008on@Ki0;o00000_ncC;<00ol0003ohacSon<Lh`0=on<Lh`03
o`000?oS7>?ohacS00_ohacS00?o0000oo/4nook1?/03?ok1?/00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003oiaSWonLHi`09onLHi`03o`000?oW6>OoiaSW00;o0000
3OoJ9MX00ol0003o^4NhokQ7^007okQ7^0Ko00000_ol0o`4o`0000goi1_T00?o0000ol4n`Oo1?/40
1oo1?/42o`0000Goi1_T00?o0000ok=</oncC;<00oncC;<00ol0003ohacSon<Lh`0<on<Lh`03o`00
0?oS7>?ohacS00cohacS00?o0000oo/4nook1?/02_ok1?/00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oW6>OoiaSW00WoiaSW00?o
0000onLHiol000003ooJ9MX00ol0003o^4NhokQ7^00<okQ7^0?o00001?oI9]T3o`0000Woi1_T00?o
0000ol4n`Oo1?/402_o1?/42o`000003on@Ki?l0003o000000Oo/dbc00?o0000on<LhooS7><02ooS
7><00ol0003ohacSon<Lh`0<on<Lh`03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000
omXUf_oJ9MX03_oJ9MX00ol0003o^4NhokQ7^00=okQ7^003o`000?oI9]WofBKI00KofBKI0ol00005
on@Ki003o`000?o1?/7o`Ck100go`Ck100?o0000ok=</oncC;<02?ncC;<00ol0003ohacSon<Lh`09
on<Lh`03o`000?oS7>?ohacS00gohacS00Co0000oo/4nook1?_on`Ck1Ol00003onTFj@03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
onLHiooW6>L02ooW6>L2o`0000oofRGJ00?o0000okQ7^?nhAkP03OnhAkP00ol0003ofBKIomTVf@0:
omTVf@?o000000?oi1_To`000?o1?/403oo1?/400ol0003o/dbcok=</`09ok=</`03o`000?oS7>?o
hacS00SohacS00?o0000on<LhooS7><03_oS7><3o`0000SojAKY00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oW6>OoiaSW00SoiaSW0ol000000onl
@kco0000omXUfP0>omXUfP03o`000?nhAkSo^4Nh00go^4Nh00?o0000omTVfOoI9]T03OoI9]T00ol0
003o`Ck1ol4n`@0?ol4n`@03o`000?ncC;?o/dbc00[o/dbc2ol0000;on<Lh`Go00003?oY5^T00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oiQWVo`000?ol0oco0000
00SoiaSW0ol00005oka3_003o`000?oJ9M[ofRGJ00cofRGJ00?o0000okQ7^?nhAkP03OnhAkP00ol0
003ofBKIomTVf@0=omTVf@;o00004?o1?/400ol0003o/dbcok=</`0:ok=</`03o`000?n`Ck3o/4n`
00Oo/4n`00?o0000on<LhooS7><00_oS7><7o`0000Co/dbc00?o0000onTFjOoY5^T02_oY5^T00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003oiQWVonHIi_oV6NH2o`00
00GoiaSW0ol00009oka3_0;o00002ooJ9MX00ol0003o^4NhokQ7^00=okQ7^003o`000?oI9]WofBKI
00gofBKI00Co0000oke2_Onm@[go00003oo1?/400ol0003o/dbcok=</`09ok=</`03o`000?n`Ck3o
/4n`00Wo/4n`1?l0000;ok=</`03o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000onHIi_oV6NH01?oV6NH00ol0003oiaSWo`000002o`00
00co_4>l00Co0000oimPWol0003o00002OoJ9MX00ol0003o^4NhokQ7^00=okQ7^003o`000?oI9]Wo
fBKI00gofBKI00Go0000oke2_Onm@[go_D:mo`00000=ol4n`@03o`000?ncC;?o/dbc00[o/dbc00?o
0000ok1?/?n`Ck002On`Ck000ol0003o/dbcok=</`0<ok=</`03o`000?oY5^WojAKY00[ojAKY00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000onHIi_oV6NH01_oV6NH0
0ol0003o_4>loka3_00<oka3_003o`000?nOH9ooWf2O00;oWf2O0_l00007omXUfP03o`000?nhAkSo
^4Nh00co^4Nh00?o0000omTVfOoI9]T03OoI9]T00ol0003o_D:moke2_@03oke2_@03o`000?o1?/7o
`Ck100[o`Ck100?o0000ok=</oncC;<02_ncC;<00ol0003o/4n`ok1?/009ok1?/003o`000?ncC;?o
/dbc00co/dbc00?o0000onTFjOoY5^T02ooY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oiQWVonHIiP06onHIiP03o`000?nl@kco_4>l00_o_4>l00?o0000oimP
WonOH9l01OnOH9l00ol0003ofRGJomXUfP03omXUfP03o`000?nhAkSo^4Nh00go^4Nh00?o0000omTV
fOoI9]T03OoI9]T00ol0003o_D:moke2_@04oke2_@03o`000?o1?/7o`Ck100Wo`Ck100?o0000ok=<
/oncC;<02OncC;<00ol0003o/4n`ok1?/00:ok1?/003o`000?ncC;?o/dbc00co/dbc00?o0000onTF
jOoY5^T02ooY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iQWVonHIiP07onHIiP03o`000?nl@kco_4>l00_o_4>l00?o0000oimPWonOH9l01_nOH9l2o`0000?o
fRGJ00?o0000okQ7^?nhAkP03OnhAkP00ol0003ofBKIomTVf@0<omTVf@03o`000?nm@[go_D:m00Ko
_D:m00?o0000ol4n`Oo1?/402?o1?/400ol0003o/dbcok=</`09ok=</`03o`000?n`Ck3o/4n`00[o
/4n`00?o0000ok=</oncC;<03?ncC;<00ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000onHIi_oV6NH02?oV6NH00ol0003o_4>loka3_00:oka3_003o`00
0?nOH9ooWf2O00WoWf2O0_l000000ooJ9M[o0000okQ7^00<okQ7^0?o00003_oI9]T00ol0003o_D:m
oke2_@07oke2_@03o`000?o1?/7o`Ck100Oo`Ck100?o0000ok=</oncC;<02OncC;<00ol0003o/4n`
ok1?/00;ok1?/003o`000?ncC;?o/dbc00co/dbc00?o0000onTFjOoY5^T02_oY5^T00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000onHIi_oV6NH02_oV6NH00ol0003o_4>loka3
_009oka3_003o`000?nOH9ooWf2O00_oWf2O00?o0000okQ7^?nhAkP02_nhAkP2o`0000?oW6>L00?o
0000omTVfOoI9]T02_oI9]T00ol0003o_D:moke2_@09oke2_@03o`000?o1?/7o`Ck100Ko`Ck100?o
0000ok=</oncC;<02?ncC;<00ol0003o/4n`ok1?/00<ok1?/003o`000?ncC;?o/dbc00co/dbc00?o
0000onTFjOoY5^T02_oY5^T00ol0003oo0?loo`3o004oo`3o0Co00000ook1?/00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000oka3_?nl@k`02?nl@k`0
0ol0003oWf2OoimPW`0<oimPW`03o`000?nhAkSo^4Nh00So^4Nh0_l00006oiaSW0;o00002_oI9]T0
0ol0003o_D:moke2_@0:oke2_@03o`000?o1?/7o`Ck100Go`Ck100?o0000ok=</oncC;<02?ncC;<0
0ol0003o/4n`ok1?/00<ok1?/003o`000?ncC;?o/dbc00co/dbc00?o0000onTFjOoY5^T02ooY5^T0
0ol0003oo0?lo`000003o`0000Son`Ck00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
onHIiP03o`000?nl@kco_4>l00Oo_4>l00?o0000oimPWonOH9l03_nOH9l00ol0003o^4NhokQ7^004
okQ7^0?o00002_nLHi`00ol0003ofBKIomTVf@07omTVf@03o`000?nm@[go_D:m00_o_D:m00?o0000
ol4n`Oo1?/400oo1?/400ol0003o/dbcok=</`09ok=</`03o`000?n`Ck3o/4n`00co/4n`00?o0000
ok=</oncC;<03?ncC;<00ol0003ojAKYonTFj@0;onTFj@;o00003Ook1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oiQWVonHIiP0<onHIiP03o`000?nl@kco_4>l00Oo_4>l00?o0000oimPWonOH9l03onOH9l01?l0
003o^4NhokQ7^?nhAkP2o`0000koW6>L0_l00006omTVf@03o`000?nm@[go_D:m00go_D:m00?o0000
ol4n`Oo1?/400_o1?/400ol0003o/dbcok=</`08ok=</`03o`000?n`Ck3o/4n`00co/4n`0ol0000=
ok=</`03o`000?oY5^WojAKY00_ojAKY00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooiQWV00?o0000oka3_?nl@k`01_nl@k`00ol0003oWf2OoimPW`0@oimPW`Co00004_nLHi`00ol0
003ofBKIomTVf@03omTVf@03o`000?nm@[go_D:m00ko_D:m00Go0000ol4n`Oo1?/7o`Ck1o`000005
ok=</`Oo00003?n`Ck001Ol0003oOh1oogn0OomoP7oo000000co/dbc00?o0000onTFjOoY5^T02?oY
5^T3o`0000oon`Ck00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooiQWV00?o0000oka3_?nl@k`01_nl@k`00ol0003oWf2OoimPW`0=
oimPW`?o000000CoLhaco`000?l0003o00004onLHi`2o`0000;ofBKI00?o0000oke2_Onm@[d04?nm
@[d00ol0003o`Ck1o`000006o`0000Oo[e2_00?o0000ok1?/?n`Ck002?n`Ck000ol0003oOh1oogn0
O`03ogn0O`;o00002?ncC;<3o`0000KojAKY1?l00002on@Ki003o`000?ok1?_on`Ck00kon`Ck00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003oiaSWo`000?nhAkP3o`0000goiQWV00?o0000oka3_?nl@k`01?nl@k`00ol0003oWf2OoimP
W`0;oimPW`?o00000omcS7<01Ol0003oMHYeo`000?m]TVgo000001CoW6>L00?o0000omTVfOl00000
4onm@[d00ol0003o[e2_ojm@[`0=ojm@[`03o`000?n`Ck3o/4n`00Go/4n`0_l00008ogn0O`03o`00
0?ncC;?o/dbc00Go00000onaC[400ol0003ojAKYonTFj@03o`0000Ooi1_T00?o0000oo/4nook1?/0
3Ook1?/00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oW6>OoiaSWo`0000Co^4Nh0ol0000:onHIiP03o`000?nl@kco_4>l00?o_4>l
00?o0000oimPWonOH9l02OnOH9l3o`0000GoLhac00Co0000ogF:MOmeRWGo00000_m]TVd00ol0003o
W6>LoiaSW00BoiaSW003o`000?nm@[go_D:m01;o_D:m00?o0000ojm@[on_D:l03_n_D:l00ol0003o
/4n`ok1?/003ok1?/003o`000?moP7ooOh1o00WoOh1o0_l00009ok5>/@;o00002_oT6n@00ol0003o
n`Ckoo/4n`0=oo/4n`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000onLHiooW6>OoiaSWo`000007okQ7^0;o00001ooV6NH5o`0000;o
_4>l00?o0000oimPWonOH9l01_nOH9l3o`0000SoLhac00Co0000ogF:MOmeRWGo00000om]TVd00ol0
003oW6>LoiaSW00AoiaSW003o`000?nm@[go_D:m017o_D:m00?o0000ojm@[on_D:l04?n_D:l01Ol0
003o/4n`ok1?/?n`Ck3o000000coOh1o00?o0000ok5>/OnaC[402?naC[400ol0003oi1_Ton@Ki00:
on@Ki003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CoiaSW00?o0000okQ7^?nhAkP01onhAkP3o`00
0004onHIi_l0003o0000o`0000GoYEZU0_l00006oimPW`?o00002_mcS7<01Ol0003oMHYeogF:MOme
RWGo000000CoKI9]00?o0000oiaSW?nLHi`04?nLHi`00ol0003o_D:moke2_@0Aoke2_@03o`000?n_
D:oo[e2_017o[e2_00?o0000ok1?/?l000003OmoP7l00ol0003o/Djaok5>/@08ok5>/@03o`000?oT
6nCoi1_T00[oi1_T00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oW6>OoiaSW00CoiaSW00?o0000
okQ7^?nhAkP02_nhAkP00ol0003oYEZUojEJY@08ojEJY@03o`000?nOH9ooWf2O00?o00003OmcS7<0
1Ol0003oMHYeogF:MOmeRWGo000000GoKI9]00?o0000oiaSW?nLHi`03onLHi`00ol0003o_D:moke2
_@0Aoke2_@03o`000?n_D:oo[e2_01;o[e2_00?o0000ogn0OomoP7l03?moP7l00ol0003o/Djaok5>
/@08ok5>/@03o`000?oT6nCoi1_T00_oi1_T00?o0000oo/4nook1?/03?ok1?/00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000onLHiooW6>L01OoW6>L0
0ol0003o^4NhokQ7^00:okQ7^003o`000?nUFZGoYEZU00WoYEZU0_l0000?og><L`03o`000?meRWGo
MHYe00;oMHYe00?o0000offBKOm]TVd01?m]TVd00ol0003oW6>LoiaSW00=oiaSW0?o00004Onm@[d0
0ol0003o[e2_ojm@[`0Cojm@[`03o`000?moP7ooOh1o00_oOh1o00?o0000ok5>/OnaC[402OnaC[40
0ol0003oi1_Ton@Ki00;on@Ki003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?oW6>L0
0ol0003o^4NhokQ7^00:okQ7^003o`000?nUFZGoYEZU00WoYEZU00?o0000og><LomcS7<03OmcS7<0
0ol0003oMHYeogF:M@03ogF:M@03o`000?m]TVgoKI9]00GoKI9]00?o0000oiaSW?nLHi`02_nLHi`2
o`0000?oXebS00?o0000oke2_Onm@[d03_nm@[d00ol0003o[e2_ojm@[`0Cojm@[`03o`000?moP7oo
Oh1o00_oOh1o00?o0000ok5>/OnaC[402OnaC[400ol0003oi1_Ton@Ki00;on@Ki003o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000onLHiooW6>L01ooW6>L2o`0000_o^4Nh00?o0000ojEJ
YOnUFZD02onUFZD00ol0003oLhacog><L`0<og><L`03o`000?meRWGoMHYe00?oMHYe00?o0000offB
KOm]TVd01_m]TVd00ol0003oW6>LoiaSW007oiaSW0;o00001_nSG:<2o`0000ko_D:m00?o0000ojm@
[on_D:l04on_D:l00ol0003oOh1oogn0O`0;ogn0O`03o`000?naC[7o/Dja00Wo/Dja00?o0000on@K
i?oT6n@03?oT6n@00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009onLH
i`03o`000?nfBKKo000000_o^4Nh00?o0000ojEJYOnUFZD02onUFZD00ol0003oLhacog><L`0;og><
L`03o`000?meRWGoMHYe00CoMHYe00?o0000offBKOm]TVd01om]TVd00ol0003oW6>LoiaSW005oiaS
W003o`000?nSG:?oXebS00SoXebS00?o0000oke2_Onm@[d02_nm@[d00ol0003o[e2_ojm@[`0Dojm@
[`03o`000?moP7ooOh1o00_oOh1o00?o0000ok5>/OnaC[402OnaC[400ol0003oi1_Ton@Ki00<on@K
i003o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009onLHi`04o`000?nfBKKo]TVfo`00
00_o^4Nh00?o0000ojEJYOnUFZD02onUFZD00ol0003oLhacog><L`0;og><L`03o`000?meRWGoMHYe
00CoMHYe00?o0000offBKOm]TVd02?m]TVd00ol0003oW6>LoiaSW002oiaSW0;o00003?nSG:<2o`00
00[o_D:m00?o0000ojm@[on_D:l05?n_D:l00ol0003oOh1oogn0O`0;ogn0O`03o`000?naC[7o/Dja
00Wo/Dja00?o0000on@Ki?oT6n@03OoT6n@00ol0003on`Ckoo/4n`06oo/4n`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiaSWonLHi`07onLHi`03
o`000?nfBKKo]TVf00;o]TVf00?o0000okQ7^?nhAkP02?nhAkP00ol0003oYEZUojEJY@0<ojEJY@03
o`000?mcS7?oLhac00WoLhac00?o0000ogF:MOmeRWD01OmeRWD00ol0003oKI9]offBK@09offBK@04
o`000?nLHico0000o`00013oXebS0_l00008oke2_@03o`000?n_D:oo[e2_01Co[e2_0ol0000;ogn0
O`03o`000?naC[7o/Dja00Wo/Dja00?o0000on@Ki?oT6n@03OoT6n@01?l0003on`Ckoo/4nook1?/5
o`0000?on`Ck00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oiaSWonLHi`06onLHi`03o`000?nfBKKo]TVf00?o]TVf00?o0000okQ7
^?nhAkP02?nhAkP00ol0003oYEZUojEJY@0;ojEJY@;o00002_mcS7<00ol0003oMHYeogF:M@06ogF:
M@03o`000?m]TVgoKI9]00[oKI9]00?o0000oj=LXonSG:<04_nSG:<00ol0003o_D:moke2_@04oke2
_@03o`000?n_D:oo[e2_01Go[e2_00?o0000oieRWOnMHYd01Ol00005ogn0O`03o`000?naC[7o/Dja
00[o/Dja00?o0000on@Ki?oT6n@03_oT6n@3o`0000Won`Ck00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWonLHi`04onLHi`03
o`000?nfBKKo]TVf00Co]TVf00?o0000okQ7^?nhAkP01onhAkP00ol0003oYEZUojEJY@0;ojEJY@04
o`000?n1OX7oPGj1o`0000WoLhac00?o0000ogF:MOmeRWD01_meRWD00ol0003oKI9]offBK@0:offB
K@03o`000?nSG:?oXebS01?oXebS0_l00003oke2_@Co00005?n_D:l00ol0003oWF:MoieRW@06oieR
W@Co000000?oOh1oo`000?naC[402onaC[400ol0003oi1_Ton@Ki00>on@Ki003o`000?ok1?_on`Ck
00[on`Ck00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003oiaSWonLHi`03onLHi`03o`000?nfBKKo]TVf00Go]TVf00?o0000okQ7^?nh
AkP01onhAkP00ol0003oYEZUojEJY@09ojEJY@;o00001?n1OX400ol0003oLhacog><L`05og><L`03
o`000?meRWGoMHYe00OoMHYe00?o0000offBKOm]TVd02_m]TVd00ol0003oXebSoj=LX`0Eoj=LX`03
o`000?nm@[go000000Co[e2_0ol0000@ojm@[`03o`000?nMHYgoWF:M00_oWF:M0_l0000<ok5>/@03
o`000?oT6nCoi1_T00coi1_T0_l0000>oo/4n`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onLHiooW6>L00_oW6>L00ol0003o]TVf
okI9]P06okI9]P03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ojEJYOnUFZD02?nUFZD00ol0003oPGj1
oh5nP@05oh5nP@03o`000?mcS7?oLhac00CoLhac00?o0000ogF:MOmeRWD01omeRWD00ol0003oKI9]
offBK@0:offBK@03o`000?nSG:?oXebS01KoXebS00?o0000ojm@[on_D:l01_n_D:l3o`0000co[e2_
00?o0000oieRWOnMHYd03OnMHYd00ol0003o/Djaok5>/@09ok5>/@Go00002OoT6n@2o`000003on@K
i?l0003on`Ck00kon`Ck00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003onLHiol0003o]TVf00Wo]TVf00?o0000okQ7^?nhAkP01_nh
AkP00ol0003oYEZUojEJY@07ojEJY@03o`000?n1OX7oPGj100OoPGj100?o0000og><LomcS7<00_mc
S7<00ol0003oMHYeogF:M@08ogF:M@03o`000?m]TVgoKI9]00WoKI9]00?o0000oj=LXonSG:<05onS
G:<00ol0003o[e2_ojm@[`09ojm@[`?o00002On_D:l00ol0003oWF:MoieRW@0>oieRW@Ko00001?na
C[400ol0003o/4n`ok1?/003ok1?/0Go00000_oT6n@2o`0000Coi1_T00?o0000oo/4nook1?/03?ok
1?/00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oG:=OoebSGomLXeol000002onfBKH00ol0003o^4NhokQ7^006okQ7^003o`000?nU
FZGoYEZU00GoYEZU0_l0000;oh5nP@04o`000?mcS7?oLhaco`0000_oMHYe00?o0000offBKOm]TVd0
2Om]TVd00ol0003oXebSoj=LX`0Foj=LX`03o`000?n_D:oo[e2_00go[e2_0ol00005ojm@[`03o`00
0?nMHYgoWF:M00ooWF:M00?o0000oj5NXOnQGZ400onQGZ44o`0000_o/4n`0_l00006on@Ki003o`00
0?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003oebSGomLXe`02omLXe`ko00001_nhAkP00ol0003oYEZUojEJ
Y@05ojEJY@03o`000?n1OX7oPGj100coPGj100?o0000og><Lol000002omeRWD00ol0003oKI9]offB
K@07offBK@?o00006?nSG:<00ol0003o[e2_ojm@[`0@ojm@[`?o000000?o[e2_o`000?nMHYd04?nM
HYd00ol0003oXEjQoj5NX@07oj5NX@03o`000?n`Ck3o/4n`00[o/4n`00?o0000on@Ki?oT6n@01OoT
6n@00ol0003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005omLXe`03o`000?nAKY7oTFjA00_oTFjA0_l00004
okQ7^003o`000?nUFZGoYEZU00?oYEZU0_l0000@oh5nP@03o`000?meRWGoMHYe00[oMHYe00?o0000
offBKOm]TVd00om]TVd4o`0000;oG:=L00?o0000oj=LXonSG:<05OnSG:<00ol0003o[e2_ojm@[`0D
ojm@[`03o`000?nMHYgoWF:M013oWF:M00?o0000oj5NXOnQGZ401onQGZ400ol0003o/4n`ok1?/00:
ok1?/003o`000?oT6nCoi1_T00Goi1_T00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oG:=OoebSG
00GoebSG00?o0000oi5^TOnAKY403OnAKY46o`0000?oYEZU00?o0000oh5nPOn1OX404?n1OX400ol0
003oMHYeogF:M@0:ogF:M@03o`000?m]TVgo000000?o00001omLXe`00ol0003oXebSoj=LX`0Doj=L
X`03o`000?n_D:oo[e2_01Co[e2_00?o0000oieRWOnMHYd03onMHYd00ol0003oXEjQoj5NX@08oj5N
X@03o`000?n`Ck3o/4n`00[o/4n`00?o0000on@Ki?oT6n@01OoT6n@00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000omLXeooG:=L01_oG:=L00ol0003oTFjAoi5^T@0=oi5^T@03o`000?nPGj3oX5nP00?o
X5nP00?o0000ojEJYOl000004on1OX44o`0000WoMHYe0_l0000<oebSG003o`000?nSG:?oXebS01?o
XebS00?o0000ojm@[on_D:l05On_D:l00ol0003oWF:MoieRW@0>oieRW@03o`000?nQGZ7oXEjQ00So
XEjQ00?o0000ok1?/?n`Ck002On`Ck000ol0003oi1_Ton@Ki007on@Ki003o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oG:=OoebSG00SoebSG00?o0000oi5^TOnAKY402onAKY400ol0003oX5nPoj1OX005oj1OX003o`00
0?n1OX7oPGj101;oPGj100Co0000ofVFJOmYUVWoJIIY1Ol00003ogF:M@03o`000?mLXecoG:=L00go
G:=L0ol0000@oj=LX`;o00006?n_D:l00ol0003oWF:MoieRW@0=oieRW@03o`000?nQGZ7oXEjQ00Wo
XEjQ00?o0000ok1?/?n`Ck002On`Ck000ol0003oi1_Ton@Ki007on@Ki003o`000?ok1?_on`Ck00_o
n`Ck00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_oebSG00?o0000oi5^TOnAKY402_nAKY400ol0003oX5nPoj1OX006oj1OX003o`00
0?n1OX7oPGj1017oPGj100?o0000ofVFJOmYUVT01omYUVT3o`00013oG:=L00?o0000oeJYE_mFZEH0
1Ol00009oj=LX`;o000000?oKY5^o`000?n_D:l05on_D:l00ol0003oWF:MoieRW@0=oieRW@03o`00
0?nQGZ7oXEjQ00WoXEjQ00?o0000ok1?/?n`Ck002?n`Ck02o`0000[oi1_T00?o0000oo/4nook1?/0
2_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?oY5^WojAKY00;ojAKY00?o0000omLXeooG:=L02OoG:=L00ol0003oTFjAoi5^
T@0:oi5^T@03o`000?nPGj3oX5nP00OoX5nP00?o0000oh5nPOn1OX403on1OX400ol0003oJIIYofVF
J@0:ofVFJ@03o`000?mLXecoG:=L00goG:=L00?o0000oeJYE_mFZEH01_mFZEH4o`0000CoXebS00?o
0000ofjAK_m^TFh00_m^TFh00ol0003o[e2_ojm@[`0Fojm@[`03o`000?nMHYgoWF:M00_oWF:M00?o
0000oj5NXOnQGZ402onQGZ400ol0003o/4n`ok1?/006ok1?/003o`000?nl@kco000000[oi1_T00?o
0000oo/4nook1?/02_ok1?/00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?oY5^WojAKY00?ojAKY00?o0000omLXeooG:=L02?oG:=L=
o`0000[oX5nP00?o0000oh5nPOn1OX403on1OX400ol0003oJIIYofVFJ@0;ofVFJ@03o`000?mLXeco
G:=L00coG:=L00?o0000oeJYE_mFZEH02_mFZEH4o`0000GoKY5^00?o0000ojm@[on_D:l05_n_D:l0
0ol0003oWF:MoieRW@0:oieRW@03o`000?nQGZ7oXEjQ00coXEjQ00?o0000ok1?/?n`Ck001?n`Ck02
o`0000?o_4>l00?o0000on@Ki?oT6n@02?oT6n@00ol0003on`Ckoo/4n`08oo/4n`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onTF
jOoY5^T00ooY5^T00ol0003oebSGomLXe`07omLXe`03o`000?n=LXgoSG:=00WoSG:=00?o0000oj1O
X?nPGj002OnPGj000ol0003oPGj1oh5nP@0=oh5nP@03o`000?mYUVWoJIIY00coJIIY00?o0000oebS
G?mLXe`03?mLXe`00ol0003oEZUFoeJYEP0;oeJYEP03o`000?lm`Sgo000000KoKY5^00?o0000ojm@
[on_D:l05_n_D:l00ol0003oWF:MoieRW@09oieRW@03o`000?nQGZ7oXEjQ00coXEjQ00?o0000ok1?
/?n`Ck000on`Ck000ol0003o_4>loka3_003oka3_003o`000?oT6nCoi1_T00Soi1_T00?o0000oo/4
nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?oY5^WojAKY00CojAKY00?o0000omLXeooG:=L01_oG:=L00ol0003o
SG:=ohebS@08ohebS@03o`000?nPGj3oX5nP00_oX5nP00?o0000oh5nPOn1OX402?n1OX44o`0000oo
JIIY00?o0000oebSG?mLXe`02omLXe`00ol0003oEZUFoeJYEP0;oeJYEP04o`000?lm`Sgo?L8mo`00
00OoKY5^00?o0000ojm@[on_D:l05On_D:l00ol0003oWF:MoieRW@08oieRW@03o`000?nQGZ7oXEjQ
00goXEjQ00?o0000ok1?/?n`Ck000_n`Ck000ol0003o_4>loka3_005oka3_003o`000?oT6nCoi1_T
00Ooi1_T00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?oY5^WojAKY00GojAKY00?o0000omLXeooG
:=L01OoG:=L00ol0003oSG:=ohebS@08ohebS@03o`000?nPGj3oX5nP00_oX5nP00?o0000oh5nPOn1
OX400on1OX45o`0000?oJIIY00?o0000ofVFJOmYUVT03_mYUVT00ol0003oG:=LoebSG00:oebSG003
o`000?mFZEKoEZUF00[oEZUF00Go0000ocg2?Olm`Sgo?L8mo`000007ofjAKP03o`000?n_D:oo[e2_
01Go[e2_00?o0000oieRWOnMHYd02?nMHYd00ol0003oXEjQoj5NX@0=oj5NX@03o`000?n`Ck3o/4n`
00;o00002?nl@k`00ol0003oi1_Ton@Ki008on@Ki0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ojAKYonTFj@05onTFj@03o`000?oG:=OoebSG00Go
ebSG00?o0000ohebSOn=LXd02?n=LXd00ol0003oX5nPoj1OX00<oj1OX0Go00002OmYUVT00ol0003o
JIIYofVFJ@0<ofVFJ@;o00003?mLXe`00ol0003oEZUFoeJYEP0:oeJYEP05o`000?lm`Sgo?L8mocg2
?Ol000002?m^TFh00ol0003o[e2_ojm@[`0Dojm@[`?o00001onMHYd00ol0003oXEjQoj5NX@0>oj5N
X@03o`000?n`Ck3o000000_o_4>l00?o0000on@Ki?oT6n@01_oT6n@00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000onTFjOoY5^T01OoY5^T00ol0003oebSGomLXe`04omLXe`03o`000?n=LXgoSG:=00Oo
SG:=00?o0000oj1OX?nPGj003?nPGj001?l0003oPGj1oh5nPOl0000;ofVFJ@03o`000?mYUVWoJIIY
00_oJIIY00Co0000ocW6>OliaSWo00002_mLXe`00ol0003oEZUFoeJYEP0:oeJYEP03o`000?lm`Sgo
?L8m00;o?L8m00?o0000ofjAK_m^TFh01_m^TFh00ol0003o[e2_ojm@[`0Aojm@[`?o00000ommPWd0
0ol0003oWF:MoieRW@04oieRW@03o`000?nQGZ7oXEjQ00goXEjQ1?l0000;oka3_003o`000?oT6nCo
i1_T00Goi1_T00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oY5^WojAKY00KojAKY00Co0000omLX
eooG:=OoebSG1?l00008ohebS@03o`000?nPGj3oX5nP00_oX5nP00?o0000oh5nPOn1OX400_n1OX40
0ol0003oJIIYofVFJ@08ofVFJ@03o`000?mYUVWoJIIY00[oJIIY00?o0000ocW6>OliaST00_liaST0
0ol0003oG:=LoebSG003oebSG0Go00002omFZEH00ol0003o?L8mocg2?@03ocg2?@03o`000?m^TFko
KY5^00OoKY5^00?o0000ojm@[on_D:l03_n_D:l2o`0000OoOH9m00?o0000oieRWOnMHYd00_nMHYd0
0ol0003oXEjQoj5NX@0=oj5NX@03o`000?n_D:oo[e2_00;o[e2_00?o0000oka3_?nl@k`02Onl@k`0
0ol0003oi1_Ton@Ki003on@Ki003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojAKYonTFj@07onTF
j@?o00001?o2?L800ol0003oSG:=ohebS@05ohebS@03o`000?nPGj3oX5nP00[oX5nP00?o0000oh5n
POn1OX400on1OX400ol0003oJIIYofVFJ@09ofVFJ@03o`000?mYUVWoJIIY00SoJIIY00?o0000ocW6
>OliaST01?liaST5o`0000Co2_D:00?o0000oeJYE_mFZEH02OmFZEH00ol0003o?L8mocg2?@03ocg2
?@03o`000?m^TFkoKY5^00SoKY5^00?o0000ojm@[on_D:l02_n_D:l3o`0000[oOH9m00Go0000oieR
WOnMHYgoWF:Mo`00000>oj5NX@03o`000?n_D:oo[e2_00Co[e2_0_l00009oka3_003o`000?oT6nCo
i1_T00;oi1_T00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?oY5^WojAKY00OojAKY00?o0000ol8m
`_o2?L801Oo2?L800ol0003oSG:=ohebS@03ohebS@03o`000?nPGj3oX5nP00[oX5nP00?o0000oh5n
POn1OX401?n1OX400ol0003oJIIYofVFJ@09ofVFJ@03o`000?mYUVWoJIIY00OoJIIY00?o0000ocW6
>OliaST01OliaST00ol0003o2_D:o`[e2P07o`[e2P03o`000?mFZEKoEZUF00OoEZUF00?o0000ocg2
?Olm`Sd01?lm`Sd00ol0003oKY5^ofjAKP08ofjAKP03o`000?n_D:oo[e2_00So[e2_0_l0000>ogf2
O@Co00003?nQGZ42o`0000Wo[e2_00?o0000oka3_?nl@k`01onl@k`01?l0003oi1_Ton@Ki?l0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000onTFjOoY5^T01OoY5^T00ol0003o`Sg2ol8m`P07ol8m`P;o00000on=LXd00ol0
003oX5nPoj1OX009oj1OX003o`000?n1OX7oPGj100KoPGj100?o0000ofVFJOmYUVT02OmYUVT00ol0
003oJIIYofVFJ@05ofVFJ@03o`000?liaSWo>LHi00Ko>LHi00?o0000o`[e2_l:m@X02?l:m@X00ol0
003oEZUFoeJYEP06oeJYEP03o`000?lm`Sgo?L8m00Co?L8m00?o0000ofjAK_m^TFh02Om^TFh4o`00
00?o[e2_0ol0000@ogf2O@05o`000?nl@kco_4>loka3_?l000002_nQGZ400ol0003o[e2_ojm@[`0:
ojm@[`Ko00000onl@k`00ol0003oi1_To`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000onTFjOoY5^T01?oY5^T00ol0
003o`Sg2ol8m`P0:ol8m`P04o`000?n=LXgoSG:=o`0000[oX5nP00?o0000oh5nPOn1OX401on1OX40
0ol0003oJIIYofVFJ@09ofVFJ@03o`000?mYUVWoJIIY00CoJIIY00?o0000ocW6>OliaST01oliaST0
0ol0003o2_D:o`[e2P08o`[e2P;o00001_mFZEH00ol0003o?L8mocg2?@05ocg2?@03o`000?m^TFko
KY5^00WoKY5^00Co0000oe^TFomKY5_oFjAK0ol0000Bogf2O@03o`000?nl@kco_4>l00?o_4>l0_l0
0006oj5NX@;o00003On_D:l00ol0003ojAKYonTFj@03onTFj@Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000onTFjOoY5^T00ooY5^T0
0ol0003o`Sg2ol8m`P0<ol8m`P;o00002_nPGj000ol0003oPGj1oh5nP@08oh5nP@03o`000?mYUVWo
JIIY00[oJIIY00?o0000ofVFJOmYUVT00_mYUVT00ol0003o>LHiocW6>@08ocW6>@03o`000?l:m@[o
2_D:00Ko2_D:0_l00002ocK9=P03o`000?mFZEKoEZUF00;oEZUF00?o0000ocg2?Olm`Sd01_lm`Sd0
0ol0003oKY5^ofjAKP08ofjAKP03o`000?mKY5_oFjAK00CoFjAK00?o0000ogf2OOmmPWd03ommPWd0
0ol0003o_4>loka3_006oka3_0;o00000onQGZ400ol0003o[e2_ojm@[`0=ojm@[`03o`000?oY5^Wo
jAKY00OojAKY0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003ojAKYonTFj@02onTFj@03o`000?o2?L;o`Sg2
00ko`Sg200?o0000oj1OX?nPGj001onPGj000ol0003oPGj1oh5nP@0:oh5nP@03o`000?mYUVWoJIIY
00WoJIIY00Go0000ofVFJOmYUVWoJIIYo`00000;ocW6>@03o`000?l:m@[o2_D:00Co2_D:0_l00005
ocK9=P05o`000?mFZEKoEZUFoeJYE_l000002?lm`Sd00ol0003oKY5^ofjAKP08ofjAKP03o`000?mK
Y5_oFjAK00GoFjAK00?o0000ogf2OOmmPWd03_mmPWd00ol0003o_4>loka3_008oka3_003o`000?nQ
GZ7o000000oo[e2_00?o0000onTFjOoY5^T02?oY5^T01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?oY5^WojAKYo`00017o`Sg200?o0000oj1OX?nPGj001_nPGj000ol0003oPGj1
oh5nP@0;oh5nP@03o`000?mYUVWoJIIY00WoJIIY00Co0000ofVFJOmYUVWo00003?liaST00ol0003o
2_D:o`[e2P02o`[e2P;o00002?lfbCH00ol0003oEZUFo`000009ocg2?@03o`000?m^TFkoKY5^00So
KY5^00?o0000oe^TFomKY5/01OmKY5/00ol0003oOH9mogf2O@0=ogf2O@03o`000?nl@kco_4>l00[o
_4>l00?o0000ojm@[on_D:l03_n_D:l00ol0003ojAKYonTFj@07onTFj@03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000Bol8m`P03o`00
0?nPGj3oX5nP00CoX5nP00?o0000oh5nPOn1OX403?n1OX400ol0003oJIIYofVFJ@0:ofVFJ@?o0000
3?liaST00ol0003o2_D:o`[e2P02o`0000_o=/Tf00?o0000ocg2?Olm`Sd02?lm`Sd00ol0003oKY5^
ofjAKP07ofjAKP03o`000?mKY5_oFjAK00OoFjAK00?o0000ogf2OOmmPWd03?mmPWd00ol0003o_4>l
oka3_00;oka3_0;o00003_n_D:l00ol0003ojAKYonTFj@07onTFj@03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`00oo/4n`00ol0003o`Sg2ol8m`P0?ol8m`P?o00000onP
Gj000ol0003oPGj1oh5nP@0>oh5nP@03o`000?mYUVWoJIIY00SoJIIY00Co0000od:m@_m2_D;o@[e2
0_l0000:ocW6>@?o00003OlfbCH00ol0003o?L8mocg2?@08ocg2?@03o`000?m^TFkoKY5^00OoKY5^
00?o0000oe^TFomKY5/01omKY5/00ol0003oOH9mogf2O@0;ogf2O@03o`000?nl@kco_4>l00co_4>l
00?o0000om</dol000000_l0000:ojm@[`03o`000?oY5^WojAKY00SojAKY00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003ok1?/on`Ck004on`Ck003o`000?o2?L;o`Sg200co`Sg20_l0
0003ojUFZ@03o`000?nPGj3o0000017oPGj100?o0000ofVFJOmYUVT01omYUVT00ol0003o@[e2od:m
@P04od:m@P;o00002?liaST00ol0003o=/TfocK9=P0>ocK9=P;o00002?lm`Sd00ol0003oKY5^ofjA
KP06ofjAKP03o`000?mKY5_oFjAK00WoFjAK00?o0000ogf2OOmmPWd02OmmPWd00ol0003o_4>loka3
_00=oka3_003o`000?oC;=?odbcC00;odbcC0ol00007ojm@[`03o`000?oY5^WojAKY00OojAKY00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ok1?/on`Ck005on`Ck003o`000?o2?L;o
`Sg200Wo`Sg20_l00006ojUFZ@03o`000?n1OX7oPGj1013oPGj100?o0000ofVFJOmYUVT01_mYUVT0
0ol0003o@[e2od:m@P07od:m@P03o`000?liaSWo>LHi00Co>LHi0ol0000>ocK9=P03o`000?lQgR7o
8MhQ00?o00001Olm`Sd00ol0003oKY5^ofjAKP06ofjAKP03o`000?mKY5_oFjAK00[oFjAK00?o0000
ogf2OOmmPWd02?mmPWd00ol0003o_4>loka3_00=oka3_003o`000?oC;=?odbcC00GodbcC0ol00004
ojm@[`03o`000?oY5^WojAKY00OojAKY00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ok1?/on`Ck006on`Ck003o`000?o2?L;o`Sg200Go`Sg20ol00008ojUFZ@03o`000?n1OX7oPGj1
017oPGj100Co0000ofVFJOmYUVWoJIIY1?l0000;od:m@P;o000000Co>LHio`000?l0003o00000om@
[e02o`0000_o=/Tf00?o0000ob7N8OlQgR401?lQgR42o`0000?o?L8m00?o0000ofjAK_m^TFh01_m^
TFh00ol0003oFjAKoe^TF`0:oe^TF`03o`000?mmPWgoOH9m00OoOH9m00?o0000oka3_?nl@k`03_nl
@k`00ol0003odbcCom</d`08om</d`Co00002_oY5^T00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ok1?/on`Ck007on`Ck003o`000?o2?L;o`Sg200;o`Sg20_l0000<ojUFZ@03o`000?n1OX7o
PGj1013oPGj11?l00003oebSG003o`000?m2_D;o@[e200_o@[e200?o0000oe2_D?m@[e001_m@[e00
0ol0003o=/TfocK9=P07ocK9=P03o`000?lQgR7o8MhQ00Oo8MhQ3?l0000>oe^TF`03o`000?mmPWgo
OH9m00KoOH9m00?o0000oka3_?nl@k`03_nl@k`00ol0003odbcCom</d`0;om</d`03o`000?oY5^Wo
jAKY00OojAKY00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o/4ncok1?/00Wok1?/00Co0000ol8m
`_l0003o00003_nYEZT00ol0003oPGj1oh5nP@0?oh5nP@03o`000?mLXecoG:=L00KoG:=L00?o0000
od:m@_m2_D802_m2_D800ol0003oD:m@oe2_D007oe2_D0;o00001_lfbCH00ol0003o8MhQob7N8@08
ob7N8@03o`000?mfRGKoMXUf00SoMXUf00?o0000oe^TFomKY5/03?mKY5/00ol0003oOH9mogf2O@05
ogf2O@03o`000?nl@kco_4>l00oo_4>l0_l0000=om</d`03o`000?oY5^WojAKY00KojAKY00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o/4ncok1?/00[ok1?/00?o0000ojUFZOnYEZT03_nYEZT00ol0
003oPGj1oh5nP@0>oh5nP@03o`000?mLXecoG:=L00OoG:=L00?o0000od:m@_m2_D802_m2_D800ol0
003oD:m@oe2_D009oe2_D0;o00000olfbCH00ol0003o8MhQob7N8@09ob7N8@03o`000?mfRGKoMXUf
00WoMXUf00?o0000oe^TFomKY5/02_mKY5/4o`0000CoOH9m00?o0000oka3_?nl@k`04?nl@k`01?l0
003od2o@o`000?l0000<om</d`03o`000?oY5^WojAKY00GojAKY00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o/4ncok1?/00[ok1?/00?o0000ojUFZOnYEZT03onYEZT@o`0000[oG:=L00?o0000od:m
@_m2_D802Om2_D800ol0003o:MHYo`00000<oe2_D005o`000?lfbCKo0000ob;M8_l000002_lQgR40
0ol0003oMXUfogJ9MP09ogJ9MP03o`000?mKY5_oFjAK00OoFjAK0ol00004ohEjQ@?o000000?oOH9m
o`000?nl@k`04Onl@k`01?l0003od2o@om0_d?o@;m02o`0000_odbcC00?o0000onTFjOoY5^T00ooY
5^T00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`02_o/4n`00ol0003oZEJYojUFZ@0?
ojUFZ@03o`000?n8MhSoR7N800coR7N800?o0000oebSG?mLXe`02OmLXe`00ol0003o@[e2od:m@P07
od:m@P04o`000?lYeRWo:MHYo`0000goD:m@00Go0000ob;M8_lRgB;o8]dRo`000009ob7N8@03o`00
0?mfRGKoMXUf00[oMXUf00?o0000oe^TFomKY5/00omKY5/3o`0000[oQGZ500?o0000oka3_?nl@k`0
4?nl@k`00ol0003od2o@om0_d004om0_d0;o00002_oC;=<00ol0003ojAKYonTFj@04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cok1?/00?o0000ojUFZOnYEZT03onYEZT00ol0003oR7N8ohQgR00<ohQgR003o`000?mL
XecoG:=L00WoG:=L00?o0000od:m@_m2_D801_m2_D800ol0003o:MHYobWF:@02obWF:@03o`000?m@
[e3oD:m@00[oD:m@00?o0000ob;M8_lRgB800_lRgB800ol0003o8MhQob7N8@06ob7N8@03o`000?mf
RGKoMXUf00[oMXUf00?o0000oe^TFomKY5/00ol0000=ohEjQ@03o`000?nl@kco_4>l013o_4>l00?o
0000om0_d?o@;m001_o@;m02o`0000WodbcC0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000on`Ck?o/4n`02_o/4n`00ol0003oZEJYojUFZ@0=ojUFZ@?o00003on8MhP0
0ol0003oG:=LoebSG008oebSG003o`000?m2_D;o@[e200Go@[e200?o0000obWF:OlYeRT00olYeRT0
0ol0003oD:m@oe2_D00:oe2_D003o`000?lRgB;o8]dR00?o8]dR00?o0000ob7N8OlQgR401OlQgR40
0ol0003oMXUfogJ9MP0;ogJ9MP;o00004On5NXD00ol0003o_4>loka3_00?oka3_003o`000?o@;m3o
d2o@00Sod2o@0_l00007om</d`03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000on`Ck?o/4n`02?o/4n`00ol0003oZEJYojUFZ@09ojUFZ@Go00000_miQWT00ol0
003oR7N8ohQgR00=ohQgR003o`000?mLXecoG:=L00WoG:=L00?o0000od:m@_m2_D801?m2_D800ol0
003o:MHYobWF:@04obWF:@03o`000?m@[e3oD:m@00SoD:m@00?o0000ob;M8_lRgB801OlRgB800ol0
003o8MhQob7N8@04ob7N8@03o`000?mfRGKoMXUf00_oMXUf00?o0000ohEjQOn5NXD04?n5NXD00ol0
003o_4>loka3_00?oka3_003o`000?o@;m3od2o@00[od2o@0_l00004om</d`03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003ok1?/on`Ck007on`Ck003o`000?nYEZWoZEJY00CoZEJY1Ol00007ogV6N@03
o`000?n8MhSoR7N800goR7N800?o0000oebSG?mLXe`02OmLXe`00ol0003o@[e2od:m@P03od:m@P03
o`000?lYeRWo:MHY00Go:MHY00?o0000oe2_D?m@[e002?m@[e000ol0003o8]dRob;M8P06ob;M8P03
o`000?lQgR7o8MhQ00?o8MhQ00?o0000ogJ9M_mfRGH02omfRGH00ol0003oQGZ5ohEjQ@0@ohEjQ@03
o`000?nl@kco_4>l00oo_4>l00?o0000om0_d?o@;m003?o@;m02o`000003om</dol0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o/4ncok1?/00Ook1?/00?o0000ojUFZOl00000
1?l0000<ogV6N@03o`000?n8MhSoR7N800koR7N800?o0000oebSG?mLXe`02?mLXe`00ol0003o@[e2
od:m@P02od:m@P03o`000?lYeRWo:MHY00Oo:MHY00?o0000oe2_D?m@[e001om@[e000ol0003o8]dR
ob;M8P07ob;M8P03o`000?lQgR7o8MhQ00;o8MhQ00?o0000ogJ9M_mfRGH02omfRGH00ol0003oQGZ5
ohEjQ@0AohEjQ@03o`000?nl@kco_4>l00go_4>l00?o0000om0_d?o@;m003oo@;m000ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`01Oo/4n`3o`00017oNHIi00?o0000ohQgR?n8MhP03_n8
MhP00ol0003oG:=LoebSG009oebSG004o`000?m2_D;o@[e2o`0000[o:MHY00?o0000oe2_D?m@[e00
1om@[e000ol0003o8]dRob;M8P08ob;M8P05o`000?lQgR7o8MhQob7N8Ol000003OmfRGH00ol0003o
QGZ5ohEjQ@0AohEjQ@?o00003Onl@k`00ol0003od2o@om0_d00?om0_d003o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_o/4n`2o`0000;o`3o000?o0000ogV6NOmiQWT03omiQWT00ol0003o
R7N8ohQgR00>ohQgR003o`000?mLXecoG:=L00SoG:=L1Ol0000;obWF:@03o`000?m@[e3oD:m@00Ko
D:m@00?o0000ob;M8_lRgB802OlRgB801?l0003o8MhQob7N8Ol0000=ogJ9MP03o`000?n5NXGoQGZ5
017oQGZ500?o0000ofBKI?mTVf@00ol0000:oka3_0Co00003Oo@;m000ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000onXEj_oZ5N[ojQGZ0_l00005ol0o`003o`000?miQWWoNHIi00koNHIi00?o0000ohQg
R?n8MhP03_n8MhP00ol0003oG:=LoebSG007oebSG003o`000?mGZ5OoEjQG00?oEjQG00?o0000obWF
:OlYeRT02?lYeRT00ol0003oD:m@oe2_D005oe2_D003o`000?lRgB;o8]dR00[o8]dR1Ol0000<ogJ9
MP03o`000?n5NXGoQGZ5013oQGZ500?o0000ofBKI?mTVf@01?mTVf@3o`0000Ko_4>l00?o0000om8]
d_oB;M800_oB;M85o`0000Sod2o@00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oZ5N[ojQGZ00?o
jQGZ00?o0000ol0o`?o0?l001?o0?l000ol0003oNHIiogV6N@0=ogV6N@03o`000?n8MhSoR7N800oo
R7N800?o0000oebSG?mLXe`01?mLXe`2o`0000OoEjQG00?o0000obWF:OlYeRT01olYeRTEo`0000Go
<<l`00?o0000ogJ9M_mfRGH02?mfRGH3o`00013oQGZ500?o0000ofBKI?mTVf@02?mTVf@3o`0000;o
_4>l00?o0000om8]d_oB;M802?oB;M85o`0000?od2o@00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?oZ5N[ojQGZ00CojQGZ00?o0000ol0o`?o0?l001Oo0?l000ol0003oNHIiogV6N@0;ogV6N@Co0000
3on8MhP00ol0003oG:=LoebSG003oebSG003o`000?mGZ5OoEjQG00SoEjQG00?o0000obWF:OlYeRT0
1?lYeRT2o`0000SoEjQG00?o0000odBkA?m4^d@02?m4^d@00ol0003o<<l`oc3?<005oc3?<0;o0000
1_mfRGH2o`0000?oJ9MX00?o0000ohEjQOn5NXD03?n5NXD00ol0003oI9]TofBKI00<ofBKI0;o0000
4?oB;M83o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003ojQGZonXEjP05onXEjP03o`000?o0?l3o`3o000Ko`3o000?o
0000ogV6NOmiQWT02OmiQWT00ol0003oKY5^o`000002ofFJI@?o00003?n8MhP01?l0003oG:=LoebS
G?mLXe`2o`0000coEjQG00?o0000obWF:OlYeRT00_lYeRT00ol0003oEjQGoeNXE`08oeNXE`03o`00
0?m4^dCoA;]400SoA;]400?o0000oc3?<?l`cc001ol`cc000ol0003oMXUfogJ9MP02ogJ9MP03o`00
0?mXUfSoJ9MX00CoJ9MX0_l0000;ohEjQ@03o`000?mTVfCoI9]T00coI9]T00?o0000oi5^TOl00000
4_oB;M800ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003ojQGZonXEjP06onXEjP03o`000?o0?l3o`3o000Oo`3o000?o
0000ogV6NOmiQWT01_miQWT2o`0000;oKY5^00?o0000ofFJIOmUVVD00omUVVD3o`0000[oR7N800?o
0000oebSG?l000003omGZ5L01?l0003o:MHYo`000?l0000;oeNXE`03o`000?m4^dCoA;]400SoA;]4
00?o0000oc3?<?l`cc002?l`cc001?l0003oMXUfo`000?l00009ofRGJ003o`000?n5NXGoQGZ500Oo
QGZ500?o0000ofBKI?mTVf@03?mTVf@01?l0003oTFjAoi5^TOl0000Com8]dP03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000onXEj_oZ5NX01ooZ5NX00ol0003o`3o0ol0o`008ol0o`003o`000?miQWWoNHIi00Co
NHIi00?o0000ofjAK_m^TFh00om^TFh00ol0003oIIYUofFJI@05ofFJI@?o00001_n8MhP4o`00013o
EjQG00?o0000oeNXEomGZ5L03?mGZ5L00ol0003oA;]4odBkA007odBkA003o`000?l`cc3o<<l`00Wo
<<l`00?o0000ofRGJ?mXUfP02_mXUfP2o`0000KoQGZ500?o0000ofBKI?mTVf@03?mTVf@00ol0003o
TFjAoi5^T@02oi5^T@03o`000?oB;M;odRgB00oodRgB00?o0000onHIi_l000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003ojQGZonXEjP08onXEjP03o`000?o0?l3o`3o000Wo`3o000Co0000ogV6NOmiQWWo
NHIi0_l00006ofjAKP03o`000?mUVVGoIIYU00SoIIYU0ol000000on8MhSo0000o`000004ofBKI003
o`000?mGZ5OoEjQG00goEjQG00?o0000oeNXEomGZ5L03?mGZ5L00ol0003oA;]4odBkA007odBkA003
o`000?l`cc3o<<l`00Wo<<l`00?o0000ofRGJ?mXUfP03?mXUfP00ol0003oQGZ5ohEjQ@03o`0000ko
I9]T00?o0000oi5^TOnAKY400onAKY400ol0003odRgBom8]dP0>om8]dP05o`000?oV6NKoiQWVonHI
i_l000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003ojQGZonXEjP09onXEjP03o`000?o0?l3o`3o000[o
`3o000?o0000ogV6NOl000002?m^TFh00ol0003oIIYUofFJI@0;ofFJI@03o`000?mTVfCoI9]T00Go
I9]T00?o0000oeNXEomGZ5L03?mGZ5L00ol0003oEjQGoeNXE`0<oeNXE`03o`000?m4^dCoA;]400Oo
A;]400?o0000oc3?<?l`cc002?l`cc02o`0000ooJ9MX0_l00002ogB;M003o`000?mTVfCoI9]T00_o
I9]T00?o0000oi5^TOnAKY401?nAKY400ol0003odRgBom8]dP0=om8]dP03o`000?oV6NKoiQWV00?o
iQWV00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onXEjP03o`000?o0?l3o`3o000_o`3o000?o0000ofjAK_m^TFh0
1om^TFh00ol0003oIIYUofFJI@0;ofFJI@03o`000?mTVfCoI9]T00KoI9]T00?o0000oeNXEomGZ5L0
2omGZ5L2o`0000goEjQG00?o0000odBkA?m4^d@01om4^d@00ol0003o<<l`oc3?<007oc3?<004o`00
0?lm`Sgo?L8mo`0000koJ9MX00?o0000ogB;M?mdRg@00_mdRg@00ol0003oI9]TofBKI009ofBKI003
o`000?nAKY7oTFjA00KoTFjA00?o0000om8]d_oB;M802ooB;M800ol0003oiQWVonHIiP05onHIiP04
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000SojQGZ00?o0000ol0o`?o0?l002_o0?l02o`0000Wo
KY5^00?o0000ofFJIOmUVVD02omUVVD00ol0003oI9]TofBKI007ofBKI003o`000?mGZ5OoEjQG00Wo
EjQG00Co0000ob3O8?lPgb3o00003?mGZ5L00ol0003oA;]4odBkA007odBkA003o`000?l`cc3o<<l`
00Ko<<l`00Go0000ocg2?Olm`Sgo?L8mo`00000>ofRGJ003o`000?mdRgCoM8]d00?oM8]d00?o0000
ofBKI?mTVf@01omTVf@00ol0003oTFjAoi5^T@07oi5^T@03o`000?oB;M;odRgB00[odRgB00?o0000
onHIi_oV6NH01ooV6NH00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006onXEjP03o`000?o0?l3o`3o0
00Wo`3o000Co0000oj=LXonSG:?o00002Om^TFh00ol0003oIIYUofFJI@09ofFJI@03o`000?mTVfCo
I9]T00WoI9]T00?o0000oeNXEomGZ5L01omGZ5L00ol0003o8=lPob3O8002ob3O8003o`000?mGZ5Oo
EjQG00WoEjQG00?o0000odBkA?m4^d@01om4^d@00ol0003o<<l`oc3?<005oc3?<003o`000?lm`Sgo
?L8m00?o?L8m00?o0000ofRGJ?mXUfP02_mXUfP00ol0003oM8]dogB;M005ogB;M003o`000?mTVfCo
I9]T00GoI9]T00?o0000oi5^TOnAKY402?nAKY400ol0003odRgBom8]dP09om8]dP03o`000?oV6NKo
iQWV00SoiQWV00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_oZ5NX3o`0000Wo`3o000?o0000oj=L
XonSG:<00_nSG:<00ol0003oKY5^ofjAKP06ofjAKP03o`000?mUVVGoIIYU00WoIIYU00?o0000ofBK
I?mTVf@02_mTVf@00ol0003oEjQGoeNXE`05oeNXE`03o`000?lPgb3o8=lP00Co8=lP00?o0000oeNX
EomGZ5L02?mGZ5L00ol0003oA;]4odBkA007odBkA003o`000?l`cc3o<<l`00Co<<l`00?o0000ocg2
?Olm`Sd01?lm`Sd00ol0003oJ9MXofRGJ00:ofRGJ003o`000?mdRgCoM8]d00KoM8]d00?o0000ofBK
I?mTVf@00omTVf@00ol0003oTFjAoi5^T@09oi5^T@03o`000?oB;M;odRgB00SodRgB00?o0000onHI
i_oV6NH02OoV6NH00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003on8MhP?o00001Oo0?l000ol0003o
XebSoj=LX`03oj=LX`03o`000?m^TFkoKY5^00KoKY5^00?o0000ofFJIOmUVVD02OmUVVD00ol0003o
I9]TofBKI00;ofBKI003o`000?mGZ5OoEjQG00?oEjQG00?o0000ob3O8?lPgb001_lPgb000ol0003o
EjQGoeNXE`08oeNXE`03o`000?m4^dCoA;]400KoA;]400?o0000oc3?<?l`cc000_l`cc02o`0000So
?L8m00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oM8]dogB;M007ogB;M005o`000?mTVfCoI9]TofBK
I?l000003OnAKY400ol0003odRgBom8]dP06om8]dP03o`000?oV6NKoiQWV00[oiQWV00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oR7N;ohQgR00GohQgR0ol000000oo0?l3o0000oj=LX`06oj=LX`03
o`000?m^TFkoKY5^00GoKY5^00?o0000ofFJIOmUVVD02OmUVVD00ol0003oI9]TofBKI00<ofBKI005
o`000?mGZ5OoEjQGoeNXEol000002_lPgb000ol0003oEjQGoeNXE`07oeNXE`03o`000?m4^dCoA;]4
00KoA;]400?o0000oc3?<?l000000_l000000omaSW7o0000ocg2?@07ocg2?@03o`000?mXUfSoJ9MX
00SoJ9MX00?o0000ogB;M?mdRg@02OmdRg@00ol0003oI9]To`00000=oi5^T@Co00001OoB;M800ol0
003oiQWVonHIiP0;onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohQgRon8MhP08on8MhP03
o`000?nSG:?oXebS00OoXebS00?o0000ofjAK_m^TFh01?m^TFh00ol0003oIIYUofFJI@09ofFJI@03
o`000?mTVfCoI9]T00goI9]T00?o0000oeNXEol000003?lPgb0:o`0000OoA;]40ol00005og6>L@03
o`000?lm`Sgo?L8m00Ko?L8m00?o0000ofRGJ?mXUfP01omXUfP00ol0003oM8]dogB;M00:ogB;M003
o`000?nAKY7oTFjA00_oTFjA00?o0000ol@ka?o4>l@00_o4>l@3o`000003om8]d_l0003oiQWV00_o
iQWV0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000on8Mh_oR7N802OoR7N800ol0003oXebSoj=LX`07oj=LX`03o`00
0?m^TFkoKY5^00GoKY5^00?o0000ofFJIOmUVVD01omUVVD00ol0003oI9]TofBKI00?ofBKI0;o0000
2olPgb000ol0003oI9]TofBKI007ofBKI003o`000?m4^dCoA;]400;oA;]40ol00008og6>L@03o`00
0?lm`Sgo?L8m00Ko?L8m00?o0000ofRGJ?mXUfP01omXUfP00ol0003oM8]dogB;M00:ogB;M003o`00
0?nAKY7oTFjA00[oTFjA00?o0000ol@ka?o4>l@01_o4>l@00ol0003oiQWVonHIiP08onHIiP?o0000
0_o/4n`00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on8Mh_oR7N802OoR7N800ol0003oXebSoj=L
X`08oj=LX`03o`000?m^TFkoKY5^00CoKY5^00?o0000ofFJIOmUVVD01omUVVD00ol0003oI9]TofBK
I00>ofBKI004o`000?lcc3?o<l`co`0000Wo8=lP00?o0000ofBKI?mTVf@02OmTVf@01?l0003oA;]4
o`000?l0000<og6>L@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000ofRGJ?mXUfP01_mXUfP00ol0003o
M8]dogB;M00;ogB;M003o`000?nAKY7oTFjA00OoTFjA0_l00009ol@ka003o`000?oV6NKoiQWV00Co
iQWV1?l00006on`Ck003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohQgRon8MhP09on8MhP03o`00
0?nSG:?oXebS00SoXebS00?o0000ofjAK_m^TFh00om^TFh>o`0000goI9]T00?o0000oc?<<olcc3<0
0_lcc3<00ol0003o8=lPob3O8005ob3O8003o`000?mTVfCoI9]T00_oI9]T00?o0000og6>LOmaSW40
3?maSW400ol0003o?L8mocg2?@06ocg2?@03o`000?mXUfSoJ9MX00GoJ9MX00?o0000ogB;M?mdRg@0
3?mdRg@00ol0003oTFjAoi5^T@06oi5^T@03o`000?o4>lCoa3_400[oa3_400?o0000onHIi_oV6NH0
0ol0000:on`Ck0?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oR7N;ohQgR00_ohQgR00?o0000oj=LXonSG:<02?nS
G:<01Ol0003oKY5^ofjAK_m^TFko000000_oHYeR00?o0000oa?/4olCk1<00ol00009ofBKI003o`00
0?lcc3?o<l`c00Co<l`c00?o0000ob3O8?lPgb000olPgb000ol0003oI9]TofBKI00<ofBKI003o`00
0?maSW7oLHia00goLHia00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003oJ9MXofRGJ003ofRGJ0?o0000
3OmdRg@00ol0003oTFjAoi5^T@05oi5^T@03o`000?o4>lCoa3_400coa3_40_l0000=on`Ck003o`00
0?ol0ocoo0?l00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oR7N;ohQgR00_ohQgR00?o0000oj=LXonSG:<02?nS
G:<4o`0000coHYeR00?o0000oa?/4olCk1<00olCk1<3o`0000GoI9]T00?o0000oc?<<olcc3<01_lc
c3<01Ol0003o8=lPob3O8?lPgb3o000000ooI9]T00?o0000og6>LOmaSW403OmaSW400ol0003o?L8m
ocg2?@06ocg2?@03o`000?mXUfSoJ9MX00?o00000om4^d@00ol0003oM8]dogB;M00;ogB;M003o`00
0?nAKY7oTFjA00?oTFjA00?o0000ol@ka?o4>l@03Oo4>l@00ol0003ok1?/on`Ck00;on`Ck003o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000on8Mh_oR7N802_oR7N83o`0000KoXebS0ol0
0003oi1_T003o`000?mRWF;oHYeR00[oHYeR00?o0000oa?/4olCk1<01_lCk1<3o`000003ofBKI?l0
003o<l`c00Wo<l`c00?o0000ob3O8?l000004?mTVf@00ol0003oLHiaog6>L@0=og6>L@03o`000?lm
`Sgo?L8m00Oo?L8m0_l00007odBkA003o`000?mdRgCoM8]d00[oM8]d00Co0000oi5^TOnAKY7oTFjA
0ol0000?ol@ka003o`000?o/4ncok1?/00_ok1?/00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on8Mh_oR7N802_oR
7N801?l0003ocS7>olhac_o><Lh2o`000004oj=LXol0003o0000o`0000KoT6n@00?o0000of:MH_mR
WF802_mRWF800ol0003o4n`Coa?/4`09oa?/4`03o`000?lcc3?o<l`c00[o<l`c00?o0000ofBKI?mT
Vf@03omTVf@00ol0003oLHiaog6>L@0>og6>L@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000odBkA?m4
^d@01om4^d@4o`0000SoM8]d00Co0000oi5^TOnAKY7o00000on5NXD2o`0000goa3_400?o0000on`C
k?o/4n`02_o/4n`00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on8Mh_oR7N802OoR7N800ol0003o
cS7>olhacP04olhacP03o`000?n@Ki3oT6n@00OoT6n@00?o0000of:MH_mRWF802OmRWF800ol0003o
4n`Coa?/4`0:oa?/4`03o`000?lcc3?o<l`c00[o<l`c00?o0000ofBKI?mTVf@03omTVf@00ol0003o
LHiaog6>L@0>og6>L@03o`000?lm`Sgo?L8m00Go?L8m00?o0000odBkA?m4^d@02?m4^d@01?l0003o
HYeRof:MH_mRWF87o`0000;oM8]d0_l00006ohEjQ@;o00003?o4>l@00ol0003ok1?/on`Ck009on`C
k003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ohQgRon8MhP08on8MhP03o`000?o><LkocS7>00Go
cS7>00?o0000oi1_T?n@Ki002?n@Ki000ol0003oHYeRof:MHP08of:MHP03o`000?lCk1?o4n`C00[o
4n`C00?o0000oc?<<olcc3<02olcc3<00ol0003oI9]TofBKI00>ofBKI003o`000?maSW7oLHia00ko
LHia1Ol00002ocg2?@03o`000?m4^dCoA;]400WoA;]400?o0000of:MH_mRWF802?mRWF83o`0000Wo
QGZ50_l0000:ol@ka003o`000?o/4ncok1?/00Sok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oR7N;ohQgR00SohQgR00?o0000olhac_o><Lh01oo><Lh00ol0003oT6n@oi1_T007oi1_T003o`00
0?mRWF;oHYeR00SoHYeR00?o0000oa?/4olCk1<02_lCk1<00ol0003o<l`coc?<<`0:oc?<<`;o0000
3_mTVf@3o`0000goLHia0ol00005ogJ9MP;o00002om4^d@00ol0003oHYeRof:MHP0;of:MHP;o0000
2_n5NXD2o`0000Ooa3_40ol00009on`Ck003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:olhacP03o`00
0?n@Ki3oT6n@00OoT6n@00?o0000of:MH_mRWF802?mRWF8>o`0000Wo<l`c0ol000000olDjaCo0000
ofBKI00:ofBKI0?o00000_mkQ7/00ol0003oLHiaog6>L@09og6>L@;o00002OmfRGH00ol0003oA;]4
odBkA009odBkA003o`000?mRWF;oHYeR00_oHYeR00?o0000ogb3O?l000002on5NXD2o`0000Coa3_4
00Co0000on4NhOoQ7^7ohAkQ0_l00007on`Ck003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003ocS7>
olhacP09olhacP03o`000?n@Ki3oT6n@00KoT6n@00?o0000of:MH_mRWF802?mRWF800ol0003o8MhQ
ob7N8@0:ob7N8@03o`000?lcc3?o<l`c00Co<l`c0ol00005oaC[5003o`000?mTVfCoI9]T00CoI9]T
1?l00006og^4N`03o`000?maSW7oLHia00KoLHia0_l0000;ogJ9MP03o`000?m4^dCoA;]400WoA;]4
00?o0000of:MH_mRWF802_mRWF801Ol0003oO8=logb3O?mlPgco000000coQGZ50_l000000oo4>lCo
0000on4Nh@05on4Nh@03o`000?o/4ncok1?/00?ok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?o><LkocS7>00SocS7>00?o0000oi1_T?n@Ki001_n@Ki000ol0003oHYeRof:MHP07of:MHP03o`00
0?lQgR7o8MhQ00_o8MhQ00?o0000oc?<<olcc3<00_lcc3<2o`0000Wo5>/D00?o0000ofBKI?mTVf@0
0ol0000;og^4N`03o`000?maSW7oLHia00;oLHia0ol0000>ogJ9MP03o`000?m4^dCoA;]400OoA;]4
00?o0000of:MH_mRWF802omRWF800ol0003oO8=logb3O002ogb3O003o`000?n5NXGoQGZ500_oQGZ5
00?o0000on4NhOoQ7^401_oQ7^42o`0000?ok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o>
<LkocS7>00OocS7>00?o0000oi1_T?n@Ki001on@Ki000ol0003oHYeRof:MHP05of:MHP?o00003OlQ
gR44o`0000_o5>/D0ol0000?og^4N`04o`000?maSW7o0000o`00017oMXUf00?o0000odBkA?m4^d@0
1om4^d@00ol0003oHYeRof:MHP0:of:MHP03o`000?mlPgcoO8=l00CoO8=l00?o0000ohEjQOn5NXD0
1on5NXD3o`0000_ohAkQ1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000olhac_o><Lh02?o><Lh00ol0003oT6n@oi1_
T006oi1_T003o`000?mRWF;oHYeR00;oHYeR0ol00003odNhA`03o`000?lQgR7o8MhQ00[o8MhQ00?o
0000oaC[5?lDja@02olDja@00ol0003o7n0Oo`00000Aog^4N`03o`000?mfRGKoMXUf017oMXUf00?o
0000odBkA?m4^d@01om4^d@00ol0003oHYeRof:MHP0:of:MHP03o`000?mlPgcoO8=l00GoO8=l00Co
0000ohEjQOn5NXGoQGZ51Ol00002oiUVV@03o`000?oQ7^7ohAkQ00WohAkQ00Co0000oo/4nook1?_o
n`Ck0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000olhac_o><Lh01oo><Lh00ol0003oT6n@oi1_T005oi1_T0?o0000
00?oHYeRo`000?l000001om7^4L00ol0003o8MhQob7N8@08ob7N8@?o00002_lDja@2o`0000;o7n0O
00?o0000og^4NomkQ7/03omkQ7/00ol0003oMXUfogJ9MP0AogJ9MP03o`000?m4^dCoA;]400OoA;]4
00?o0000of:MH_mRWF802OmRWF800ol0003oO8=logb3O007ogb3O0?o00001onIIYT00ol0003ohAkQ
on4Nh@09on4Nh@03o`000?ok1?_on`Ck00Con`Ck0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000olhac_o><Lh01oo>
<Lh4o`0000;oT6n@0_l00003oi9]TP03o`000?m7^4OoAkQ700SoAkQ70_l00006ob7N8@;o00000olW
f2L00ol0003o5>/DoaC[5006oaC[5003o`000?lOh1oo7n0O00?o7n0O00?o0000og^4NomkQ7/03_mk
Q7/00ol0003oMXUfogJ9MP0BogJ9MP03o`000?m4^dCoA;]400GoA;]400?o0000of:MH_mRWF802OmR
WF800ol0003oO8=logb3O008ogb3O003o`000?nIIYWoVFJI00OoVFJI00?o0000on4NhOoQ7^402?oQ
7^400ol0003on`Ckoo/4n`07oo/4n`;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o><LkocS7>00CocS7>0_l00004
omTVf@;o00001OnBKI800ol0003oAkQ7odNhA`0:odNhA`03o`000?lQgR7o8MhQ00;o8MhQ00?o0000
obOH9olWf2L01?lWf2L00ol0003o5>/DoaC[5004oaC[5003o`000?lOh1oo7n0O00Co7n0O00?o0000
og^4NomkQ7/03_mkQ7/00ol0003oMXUfogJ9MP0BogJ9MP[o00002_mRWF800ol0003oO8=logb3O008
ogb3O003o`000?nIIYWoVFJI00OoVFJI00?o0000on4NhOoQ7^402?oQ7^400ol0003on`Ckoo/4n`09
oo/4n`?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003ocS7>olhac_o><Lh2o`0000OofBKI00?o0000oi9]T_nBKI801?nBKI80
0ol0003oAkQ7odNhA`0:odNhA`04o`000?lQgR7o0000o`0000So9mPW00Co0000oaC[5?lDjaCo5>/D
0_l00007oaoP7`03o`000?mkQ7_oNhAk00koNhAk00?o0000ogJ9M_mfRGH04_mfRGH00ol0003oEZUF
oeJYEP07oeJYEP03o`000?mRWF;oHYeR00KoHYeR00?o0000ogb3O?mlPg`02_mlPg`00ol0003oVFJI
oiUVV@06oiUVV@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4nook1?/03?ok1?/00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?o>
<Lko0000o`0000WofBKI00?o0000oi9]T_nBKI801?nBKI800ol0003oAkQ7odNhA`0;odNhA`03o`00
0?lWf2Oo9mPW00Wo9mPW00?o0000oaC[5?l000002OlOh1l00ol0003oNhAkog^4N`0>og^4N`;o0000
4_mfRGH00ol0003oEZUFoeJYEP09oeJYEP;o00001_mRWF800ol0003oO8=logb3O00:ogb3O003o`00
0?nIIYWoVFJI00KoVFJI00?o0000on4NhOoQ7^402?oQ7^400ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omTVfOoI9]T02OoI9]T00ol0003oTVfBoi9]TP05oi9]TP03o`000?m7^4OoAkQ700[oAkQ700?o
0000obOH9olWf2L02_lWf2L2o`0000Wo7n0O00?o0000og^4NomkQ7/03_mkQ7/00ol0003oHYeRo`00
0002o`0000ooMXUf00?o0000oeJYE_mFZEH02omFZEH00ol0003oHYeRof:MHP03o`0000goO8=l00?o
0000oiUVVOnIIYT01_nIIYT00ol0003ohAkQon4Nh@07on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ofBKIomTVf@09omTVf@03o`000?nBKI;oTVfB00GoTVfB00?o0000odNhAom7^4L02Om7^4L2
o`0000_o9mPW0_l0000;oaoP7`03o`000?mkQ7_oNhAk00coNhAk00?o0000of:MH_mRWF800omRWF83
o`0000coMXUf00?o0000oeJYE_mFZEH03?mFZEH2o`0000;oIiQW00?o0000ogb3O?mlPg`03?mlPg`0
0ol0003oVFJIoiUVV@05oiUVV@03o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo/4nook1?/03?ok1?/0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oI9]WofBKI00[ofBKI00?o0000oi9]T_nBKI801_nBKI800ol0003oAkQ7odNhA`07odNh
A`03o`000?ljaC[o000000[o9mPW00Co0000oaGZ5OlEjQGo00002_lOh1l00ol0003oNhAkog^4N`0<
og^4N`03o`000?mRWF;oHYeR00KoHYeR0_l00008ogJ9MP;o00003omFZEH00ol0003oIiQWofNHI`02
ofNHI`03o`000?mlPgcoO8=l00_oO8=l00?o0000oiUVVOnIIYT01OnIIYT00ol0003ohAkQon4Nh@07
on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ofBKIomTVf@0:omTVf@03o`000?nBKI;oTVfB
00KoTVfB00?o0000odNhAom7^4L01_m7^4L01Ol0003o>/Djoc[5>_ljaC[o000000So9mPW00?o0000
oaGZ5OlEjQD00_lEjQD00ol0003o7n0OoaoP7`06oaoP7`Co00003?mkQ7/00ol0003oHYeRof:MHP08
of:MHP?o00000_mfRGH3o`000003oe2_D?l0003oEZUF00goEZUF00?o0000ofNHIomWV6L01?mWV6L0
0ol0003oO8=logb3O00:ogb3O003o`000?nIIYWoVFJI00GoVFJI00?o0000on4NhOoQ7^401_oQ7^40
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omTVfOoI9]T02ooI9]T00ol0003oTVfBoi9]TP07oi9]
TP03o`000?m7^4OoAkQ700?oAkQ70_l00005oc[5>P03o`000?lWf2Oo9mPW00Co9mPW00?o0000oaGZ
5OlEjQD00olEjQD00ol0003o7n0OoaoP7`05oaoP7`03o`000?lo`3oo?l0o00;o?l0o0ol00007og^4
N`;o00003_mRWF82o`0000GoD:m@00?o0000oeJYE_mFZEH02_mFZEH00ol0003oIiQWofNHI`05ofNH
I`03o`000?mlPgcoO8=l00_oO8=l00?o0000oiUVVOnIIYT01?nIIYT00ol0003ohAkQon4Nh@06on4N
h@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ofBKIomTVf@0;omTVf@03o`000?nBKI;oTVfB00Oo
TVfB00?o0000odNhAom7^4L00_m7^4L00ol0003o>/Djoc[5>P06oc[5>P03o`000?lWf2Oo9mPW00;o
9mPW00?o0000oaGZ5OlEjQD01OlEjQD00ol0003o7n0OoaoP7`02oaoP7`;o00002?lo`3l3o`0000;o
NhAk0_l000000om9]TWo0000of:MHP0=of:MHP03o`000?m@[e3oD:m@00GoD:m@00?o0000oeJYE_mF
ZEH02?mFZEH00ol0003oIiQWofNHI`07ofNHI`03o`000?mlPgcoO8=l00[oO8=l00?o0000oiUVVOnI
IYT01?nIIYT00ol0003ohAkQon4Nh@06on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ofBKI
omTVf@0<omTVf@03o`000?nBKI;oTVfB00SoTVfB00Co0000odNhAom7^4Oo00002OljaCX01Ol0003o
9mPWobOH9olWf2Oo000000So5NXE00Go0000oaoP7olOh1oo7n0Oo`00000=oco0?`;o00001?m9]TT0
0ol0003oHYeRof:MHP0;of:MHP03o`000?m@[e3oD:m@00KoD:m@00?o0000oeJYE_mFZEH01omFZEH0
0ol0003oIiQWofNHI`08ofNHI`Co00002?mlPg`00ol0003oVFJIoiUVV@04oiUVV@03o`000?oQ7^7o
hAkQ00KohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oI9]WofBKI00_ofBKI0ol00009oi9]
TP03o`000?m7^4Oo000000_o>/Dj00?o0000obOH9ol000002_lEjQD00ol0003o7n0Oo`00000?oco0
?`03o`000?m9]TWoBKI900;oBKI900?o0000of:MH_mRWF802omRWF800ol0003oD:m@oe2_D006oe2_
D003o`000?mFZEKoEZUF00KoEZUF00?o0000ofNHIomWV6L02OmWV6L01?l0003oTVfBoi9]T_nBKI87
o`0000;oO8=l00?o0000oiUVVOnIIYT00onIIYT00ol0003ohAkQon4Nh@05on4Nh@03o`000?ok1?_o
n`Ck00con`Ck00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oI9]WofBKI00SofBKI0ol00003olTfb@03o`000?nBKI;oTVfB00OoTVfB00?o0000oc[5
>_ljaCX02oljaCX00ol0003o5NXEoaGZ5@0:oaGZ5@03o`000?lo`3oo?l0o00go?l0o00?o0000odVf
BOm9]TT01?m9]TT00ol0003oHYeRof:MHP09of:MHP03o`000?m@[e3oD:m@00SoD:m@00?o0000oeJY
E_mFZEH00omFZEH2o`0000coIiQW00?o0000oi9]T_nBKI802?nBKI8<o`0000?ohAkQ0ol0000=oo/4
n`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omTVfOoI9]T01_oI9]T3o`0000OobCK900?o0000oi9]T_nBKI801_nBKI800ol0003o
>/Djoc[5>P0;oc[5>P03o`000?lEjQGo5NXE00Wo5NXE0_l0000>oco0?`03o`000?m9]TWoBKI900Go
BKI900?o0000of:MH_mRWF802OmRWF800ol0003oD:m@oe2_D009oe2_D003o`000?mFZEKo000000;o
00000_mNXEh00ol0003oIiQWofNHI`08ofNHI`03o`000?nBKI;oTVfB00coTVfB00?o0000omhQg_oN
8Mh01_oN8Mh3o`0000?on`Ck0_l00009oo/4n`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ofBKIomTVf@03omTVf@?o00002oo9=/T00ol0003oTVfB
oi9]TP04oi9]TP03o`000?ljaC[o>/Dj00_o>/Dj0ol00007oaGZ5@?o000000?o<l`co`000?lo`3l0
3Olo`3l00ol0003oBKI9odVfB@06odVfB@03o`000?mRWF;oHYeR00SoHYeR00?o0000oe2_D?m@[e00
2_m@[e000ol0003oGZ5NoejQGP04oejQGP03o`000?mWV6OoIiQW00OoIiQW00?o0000oi9]T_nBKI80
2onBKI800ol0003ogR7NomhQgP08omhQgP03o`000?ok1?_on`Ck00Con`Ck0ol00004oo/4n`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omTVfOl0
003o0000o`0000oobCK900?o0000oi9]T_nBKI800onBKI8>o`0000?o<l`c0_l00002oaGZ5@?o0000
1Olcc3<00ol0003o?l0ooco0?`0:oco0?`03o`000?m9]TWoBKI900OoBKI900?o0000of:MH_mRWF80
2?mRWF800ol0003oD:m@oe2_D00:oe2_D003o`000?mNXEkoGZ5N00GoGZ5N00?o0000ofNHIomWV6L0
1_mWV6L00ol0003oTVfBoi9]TP0;oi9]TP03o`000?oN8MkogR7N00SogR7N00?o0000oo/4nook1?/0
1ook1?/2o`000003oo/4nol0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?oj1OX2o`0001;obCK900?o0000oi9]T_nBKI800_nBKI800ol0003oF:MHoeRW
F00:oeRWF003o`000?lcc3?o<l`c00?o<l`c0_l00009oc?<<`03o`000?lo`3oo?l0o00Wo?l0o00?o
0000odVfBOm9]TT02?m9]TT2o`0000SoHYeR00?o0000oe2_D?m@[e002Om@[e000ol0003oGZ5NoejQ
GP07oejQGP03o`000?mWV6OoIiQW00CoIiQW00?o0000oi9]T_nBKI802onBKI800ol0003ogR7NomhQ
gP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003obCK9olTfb@0?olTfb@?o000000?oTVfB
o`000?mHYeP02omHYeP00ol0003o<l`coc?<<`04oc?<<`03o`000?lcc3?o<l`c00Wo<l`c00?o0000
oco0?olo`3l01olo`3l00ol0003oBKI9odVfB@09odVfB@04o`000?m4^dCo0000o`0000KoHYeR00?o
0000oe2_D?m@[e002Om@[e000ol0003oGZ5NoejQGP08oejQGP03o`000?mWV6OoIiQW00?oIiQW00?o
0000oi9]T_nBKI802onBKI800ol0003ogR7NomhQgP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003obCK9olTfb@0<olTfb@;o00000oo3?<<2o`0000coF:MH00?o0000oc?<<olcc3<01?lcc3<0
0ol0003o<l`coc?<<`0:oc?<<`Wo00002om9]TT00ol0003oA;]4odBkA002odBkA0?o00000_mRWF80
0ol0003oD:m@oe2_D00:oe2_D003o`000?mNXEkoGZ5N00WoGZ5N00?o0000ofNHIomWV6L00_mWV6L0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o9=/T2o`0000Go`cc300?o0000ohQgR?l000002_mHYeP00ol0003o<l`coc?<<`06oc?<
<`03o`000?lcc3?o<l`c00Wo<l`c00?o0000oc;=<_lbcC801OlbcC800ol0003oBKI9odVfB@09odVf
B@03o`000?m4^dCoA;]400GoA;]40ol00009oe2_D0?o00003OmNXEh01Ol0003oIiQWofNHIomWV6Oo
000000coTVfB00?o0000omhQg_oN8Mh02OoN8Mh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000olTf
bOo9=/T01Oo9=/T2o`0000Oo`cc300Co0000ohQgR?n8MhSo00002OmHYeP00ol0003o<l`coc?<<`06
oc?<<`03o`000?lcc3?o<l`c00So<l`c00?o0000oc;=<_lbcC801olbcC800ol0003oBKI9odVfB@07
odVfB@03o`000?m4^dCoA;]400SoA;]40ol00002oe2_D0Go00000_lbcC800ol0003oGZ5NoejQGP0<
oejQGP03o`000?mWV6Oo000000coTVfB00?o0000omhQg_oN8Mh02_oN8Mh00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000olTfbOo9=/T00_o9=/T2o`0000So`cc300?o0000ohQgR?n8MhP00_n8MhP5o`00
00CoF:MH00?o0000oc?<<olcc3<01_lcc3<00ol0003o<l`coc?<<`08oc?<<`03o`000?lbcC;o</db
00Oo</db00?o0000odVfBOm9]TT01om9]TT00ol0003oA;]4odBkA008odBkA003o`000?lSg2?o8m`S
00;o00002?lbcC800ol0003oGZ5NoejQGP0<oejQGPCo00002_nBKI800ol0003ogR7NomhQgP0:omhQ
gP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003obCK9o`000?l0000:ol<l``03o`000?n8MhSoR7N8
00;oR7N800?o0000obWF:OlYeRT00_lYeRT4o`0000Wo<l`c00?o0000oc?<<olcc3<02?lcc3<00ol0
003o</dboc;=<P08oc;=<P03o`000?m9]TWoBKI900GoBKI900?o0000odBkA?m4^d@02?m4^d@01Ol0
003o8m`Sob?L8olSg2?o000000[o</db0ol0000;oejQGP04o`000?o7><OoacS7olLha`Co00001OnB
KI800ol0003ogR7NomhQgP0;omhQgP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003o`cc3ol<l``0:
ol<l``03o`000?n8MhSoR7N800?oR7N800?o0000obWF:OlYeRT01?lYeRT00ol0003o<l`coc?<<`07
oc?<<`03o`000?lcc3?o<l`c00Ko<l`c0_l0000;oc;=<P03o`000?m9]TWoBKI900GoBKI900?o0000
odBkA?m4^d@02?m4^d@00ol0003o8m`Sob?L8`02ob?L8`03o`000?lbcC;o</db00Oo</db00?o0000
og^4NomkQ7/01?l00006oejQGP03o`000?o7><OoacS700KoacS70ol00002oi9]TP03o`000?oN8Mko
gR7N00_ogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o3?<?o`cc300Wo`cc300?o0000ohQg
R?n8MhP01?n8MhP00ol0003o:MHYobWF:@05obWF:@03o`000?lcc3?o<l`c00Oo<l`c00?o0000oc?<
<olcc3<00_lcc3<3o`000003od2o@?l0003o</db00[o</db00?o0000odVfBOm9]TT01Om9]TT00ol0
003oA;]4odBkA007odBkA003o`000?lSg2?o8m`S00?o8m`S00?o0000oc;=<_lbcC801olbcC800ol0
003oNhAkog^4N`04og^4N`?o00000_mNXEh00ol0003oacS7olLha`0:olLha`;o00003_oN8Mh00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000ol<l`oo3?<<02Oo3?<<00ol0003oR7N8ohQgR004ohQgR003
o`000?lYeRWo:MHY00Ko:MHY0_l00007oc?<<`03o`000?lcc3?o000000;o00001Om0_d000ol0003o
</dboc;=<P08oc;=<P?o00001?m9]TT00ol0003oA;]4odBkA008odBkA003o`000?lSg2?o8m`S00Co
8m`S00?o0000oc;=<_lbcC801_lbcC800ol0003oNhAkog^4N`07og^4N`;o00003_o7><L00ol0003o
gR7NomhQgP0;omhQgP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o`cc3ol<l``08ol<l``03o`00
0?n8MhSoR7N800GoR7N800?o0000obWF:OlYeRT01?lYeRT00ol0003oAKY5odFjA@03o`0000Co<l`c
0_l00008od2o@003o`000?lbcC;o</db00Oo</db00Co0000ofJII_mVVFKoIYUV0ol000000om9]TWo
0000odBkA009odBkA003o`000?lSg2?o8m`S00Co8m`S00?o0000oc;=<_lbcC801OlbcC800ol0003o
NhAkog^4N`09og^4N`03o`000?o7><OoacS700goacS700?o0000omhQg_oN8Mh02_oN8Mh00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000ol<l`oo3?<<01oo3?<<00ol0003oR7N8ohQgR006ohQgR003o`00
0?lYeRWo:MHY00?o:MHY00?o0000odFjAOm5^TD01?m5^TD2o`000003oc?<<ol0003o@;m000[o@;m0
00?o0000oc;=<_lbcC801OlbcC800ol0003oIYUVofJIIP05ofJIIP03o`000?m4^dCoA;]400OoA;]4
0ol00007ob?L8`03o`000?lbcC;o</db00Co</db00?o0000og^4NomkQ7/02OmkQ7/00ol0003oacS7
olLha`0=olLha`03o`000?oN8MkogR7N00[ogR7N00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o3
?<?o`cc300Go`cc30ol00009ohQgR005o`000?lYeRWo:MHYobWF:Ol000002Om5^TD00ol0003o@;m0
od2o@00;od2o@003o`000?lbcC;o</db00?o</db00?o0000ofJII_mVVFH01_mVVFH00ol0003oA;]4
odBkA006odBkA005o`000?m</dcoC;=<odbcC?l000001olSg2<00ol0003o</dboc;=<P03oc;=<P03
o`000?mkQ7_oNhAk00WoNhAk00?o0000olLhaoo7><L03_o7><L00ol0003ogR7NomhQgP09omhQgP03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003o`cc3o`000004o`0000;ofbCK00?o0000ohQgR?n8MhP0
1on8MhP01?l0003o:MHYobWF:Ol00009odFjA@;o00003Om0_d000ol0003o</dboc;=<P02oc;=<P03
o`000?mVVFKoIYUV00SoIYUV00?o0000odBkA?m4^d@00om4^d@2o`0000GoC;=<00?o0000ob?L8olS
g2<01?lSg2<00ol0003o</dboc;=<P03oc;=<P03o`000?mkQ7_oNhAk00WoNhAk00?o0000olLhaoo7
><L03_o7><L00ol0003ogR7NomhQgP09omhQgP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000SofbCK
00?o0000ohQgR?n8MhP01_n8MhP00ol0003o:MHYo`000009odFjA@04o`000?mLXecoG:=Lo`0000go
@;m000Co0000oc;=<_lbcC;o00003?mVVFH01Ol0003oA;]4odBkA?m4^dCo000000SoC;=<0_l00005
ob?L8`03o`000?lbcC;o</db00;o</db00?o0000og^4NomkQ7/02OmkQ7/00ol0003oacS7olLha`0>
olLha`03o`000?oN8MkogR7N00WogR7N00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oK9=_ofbCK
00OofbCK00?o0000ohQgR?n8MhP01on8MhP00ol0003oAKY5odFjA@07odFjA@03o`000?mLXecoG:=L
00;oG:=L00?o0000od2o@?m0_d002_m0_d000ol0003o</dbo`00000>ofJIIP03o`000?m4^dCo0000
00_oC;=<00?o0000ob?L8olSg2<00_lSg2<01Ol0003o</dboc;=<_lbcC;o000000coNhAk00?o0000
olLhaoo7><L03_o7><L3o`0000WogR7N00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oK9=_ofbCK
00WofbCK00?o0000ohQgR?n8MhP01_n8MhP00ol0003oAKY5odFjA@06odFjA@03o`000?mLXecoG:=L
00?oG:=L00?o0000od2o@?m0_d002om0_d000ol0003oIYUVofJIIP0>ofJIIP03o`000?m</dcoC;=<
00_oC;=<0_l00003ob?L8`04o`000?lbcC;o</dbo`0000[oNhAk0ol0000>olLha`;o00000ook1?/2
o`0000OogR7N00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oK9=_ofbCK00[ofbCK00?o0000ohQg
R?n8MhP01?n8MhP00ol0003oAKY5odFjA@06odFjA@03o`000?mLXecoG:=L00GoG:=L00?o0000od2o
@?m0_d001om0_d03o`00017oIYUV00?o0000odbcC?m</d`03Om</d`01Ol0003o8m`Sob?L8ol0003o
</db00Co00000omkQ7/5o`0000;oc3?<00?o0000olLhaoo7><L02_o7><L2o`0000Oon`Ck0_l00004
omhQgP03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003ofbCKom/Tf`0;om/Tf`03o`000?n8MhSoR7N8
00CoR7N800?o0000odFjAOm5^TD01Om5^TD00ol0003oG:=LoebSG006oebSG003o`000?m0_d3o@;m0
00Co@;m00ol00002odfbC@03o`000?mVVFKoIYUV00ooIYUV0_l0000?odbcC004o`000?lSg2?o0000
o`0000CoJ9MX0ol00008ol`cc003o`000?o7><OoacS700OoacS70_l0000;oo/4n`;o00000_oN8Mh0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om/TfooK9=/03?oK9=/6o`0000OoAKY500?o0000oebS
G?mLXe`02?mLXe`00ol0003o@;m0od2o@003o`0000KoCK9=00?o0000ofJII_mVVFH03OmVVFH01?l0
003oH9mPof2OH?l0000?odbcC003o`000?mXUfSoJ9MX00GoJ9MX00?o0000ol`cc?o<<l`02?o<<l`0
0ol0003oacS7olLha`05olLha`03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oK9=/00ol0003oSg2?ohm`S`04ohm`
S`03o`000?m5^TGoAKY500?oAKY500?o0000oebSG?mLXe`02_mLXe`2o`0000[oCK9=00?o0000ofJI
I_mVVFH02omVVFH00ol0003oH9mPof2OH002of2OH003o`000?m</dcoC;=<00_oC;=<0_l00007ofRG
J003o`000?o<<lcoc3?<00Woc3?<00?o0000olLhaoo7><L00_o7><L2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000om/TfooK9=/02ooK9=/00ol0003oSg2?ohm`S`06ohm`S`05o`000?m5^TGoAKY5odFj
AOl000003OmLXe`00ol0003oCK9=odfbC@0:odfbC@03o`000?mVVFKoIYUV00WoIYUV00?o0000of2O
H?mPWf001?mPWf000ol0003oC;=<odbcC008odbcC0;o000000?o;M8]o`000?mXUfP01omXUfP00ol0
003oc3?<ol`cc009ol`cc004o`000?o7><Oo0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oK9=_ofbCK
00WofbCK00?o0000ohm`Son?L8l02?n?L8l00ol0003oAKY5o`00000=oebSG003o`000?m=/TgoCK9=
00_oCK9=00?o0000ofJII_mVVFH02?mVVFH00ol0003oH9mPof2OH006of2OH003o`000?m</dcoC;=<
00GoC;=<0_l00003obgB;@03o`000?mXUfSoJ9MX00KoJ9MX00?o0000ol`cc?o<<l`02_o<<l`00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003ofbCKom/Tf`07om/Tf`03o`000?n?L8ooSg2?00[oSg2?00?o0000oebSG?mL
Xe`03?mLXe`00ol0003oCK9=odfbC@0<odfbC@03o`000?mVVFKoIYUV00KoIYUV00?o0000of2OH?mP
Wf002?mPWf000ol0003oC;=<odbcC002odbcC0;o00001_l]dRd00ol0003oJ9MXofRGJ005ofRGJ003
o`000?o<<lcoc3?<00[oc3?<00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oK9=_ofbCK00GofbCK
00?o0000ohm`Son?L8l03?n?L8l2o`0000coG:=L00?o0000odfbCOm=/Td03Om=/Td00ol0003oIYUV
ofJIIP04ofJIIP03o`000?mPWf3oH9mP00[oH9mP00Co0000odbcC?l0003o00002?l]dRd00ol0003o
J9MXofRGJ006ofRGJ003o`000?o<<lcoc3?<00Woc3?<00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oK9=/00ol0003oSg2?ohm`S`0=ohm`S`03o`000?mKY5_o000000;o00002?mLXe`00ol0003oCK9=
odfbC@0?odfbC@Ko00003_mPWf000ol0003o;M8]obgB;@08obgB;@03o`000?mXUfSoJ9MX00KoJ9MX
00?o0000ol`cc?o<<l`02Oo<<l`00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000om`Sg?oL8mcog2?L
0_l0000?ohm`S`03o`000?mKY5_oFjAK00?oFjAK0ol00005oebSG0;o00004?m=/Td01_l0003o>LHi
ocW6>Ol0003o8]dRo`0000koH9mP00?o0000obgB;Ol]dRd02Ol]dRd00ol0003oJ9MXofRGJ005ofRG
J003o`000?o<<lcoc3?<00Woc3?<00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000om`Sg?oL8m`00ooL8m`00ol0003o
Sg2?ohm`S`0=ohm`S`03o`000?mKY5_oFjAK00KoFjAK0ol000001?mLXeco0000odBkA?m4^d@3o`00
00coCK9=00Go0000ocW6>OliaSWo>LHio`000002ob;M8P03o`000?mPWf3oH9mP00_oH9mP00?o0000
obgB;Ol]dRd02Ol]dRd00ol0003oJ9MXofRGJ006ofRGJ003o`000?o<<lcoc3?<00Soc3?<0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003og2?Lom`Sg004om`Sg0oo00003?mKY5/00ol0003oA;]4odBkA004odBk
A0?o00002?m=/Td00ol0003o>LHiocW6>@02ocW6>@05o`000?lRgB;o8]dRob;M8_l000003?mPWf00
0ol0003o;M8]obgB;@09obgB;@03o`000?mXUfSoJ9MX00GoJ9MX3?l00002onPGj0;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003og2?Lom`Sg005om`Sg003o`000?n0Oh3oP7n000_oP7n000?o0000oe^T
FomKY5/02_mKY5/00ol0003oA;]4odBkA007odBkA0;o00001Om=/Td00ol0003o>LHiocW6>@03ocW6
>@03o`000?lRgB;o8]dR00;o8]dR00?o0000of2OH?mPWf002OmPWf000ol0003o;M8]obgB;@0:obgB
;@03o`000?mXUfSoJ9MX00?oJ9MX00?o0000oj=LXonSG:<02OnSG:<00ol0003oj1OXonPGj002onPG
j0;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003og2?Lom`Sg006om`Sg003o`000?n0Oh3oP7n000[o
P7n000?o0000oe^TFomKY5/02omKY5/00ol0003oA;]4odBkA009odBkA0?o000000?oCK9=o`000?li
aST01OliaST00ol0003o8]dRob;M8P03ob;M8P03o`000?mPWf3oH9mP00SoH9mP3_l00003ofRGJ0;o
00002onSG:<00ol0003oj1OXonPGj005onPGj003o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000om`Sg?oL8m`01OoL8m`00ol0003oUVVFo`00000;oh1oP003o`000?mKY5_oFjAK00[oFjAK
0_l0000>odBkA003o`000?liaSWo>LHi00Go>LHi00?o0000ob;M8_lRgB800olRgB800ol0003oH9mP
of2OH008of2OH003o`000?mYUVWoJIIY00_oJIIY00?o0000ofRGJ?l000003OnSG:<00ol0003oj1OX
onPGj006onPGj0;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oL8mcog2?L00Kog2?L00Co
0000oiIYU_nFJIKo00002_n0Oh000ol0003oFjAKoe^TF`09oe^TF`03o`000?m7^4Oo000000koA;]4
00?o0000ocW6>OliaST01OliaST00ol0003o8]dRob;M8P04ob;M8P03o`000?mPWf3oH9mP00KoH9mP
00?o0000ofVFJOmYUVT03OmYUVT00ol0003oXebSoj=LX`0<oj=LX`03o`000?oX5nSoj1OX00Soj1OX
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oL8mcog2?L00Gog2?L00?o0000oiIYU_nFJIH00_nF
JIH00ol0003oP7n0oh1oP006oh1oP003o`000?mKY5_oFjAK00SoFjAK0_l00003odNhA`03o`000?m4
^dCoA;]400_oA;]400?o0000ocW6>OliaST01OliaST00ol0003o8]dRob;M8P05ob;M8P03o`000?mP
Wf3oH9mP00GoH9mP00?o0000ofVFJOmYUVT03OmYUVT00ol0003oXebSoj=LX`0;oj=LX`03o`000?oX
5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oL8mcog2?L00Kog2?L00?o0000
oiIYU_nFJIH00onFJIH00ol0003oP7n0oh1oP005oh1oP003o`000?mKY5_oFjAK00OoFjAK00?o0000
odNhAom7^4L00om7^4L00ol0003oA;]4odBkA00:odBkA003o`000?liaSWo>LHi00Ko>LHi00?o0000
ob;M8_lRgB801_lRgB800ol0003oH9mPof2OH004of2OH003o`000?mYUVWoJIIY00goJIIY3ol0000;
onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oL8mcog2?L00Kog2?L00?o0000oiIYU_nFJIH01OnFJIH00ol0
003oP7n0oh1oP004oh1oP003o`000?mKY5_oFjAK00GoFjAK0_l00006odNhA`03o`000?m4^dCoA;]4
00WoA;]40_l00008ocW6>@03o`000?lRgB;o8]dR00Ko8]dR1Ol000000omPWf3o0000ofVFJ@0?ofVF
J@03o`000?nRGJ;oXUfR00_oXUfR00?o0000onPGj?oX5nP02OoX5nP00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oL8mcog2?L00Kog2?L00?o0000oiIYU_nFJIH01_nFJIH00ol0003o
P7n0oh1oP004o`0000KoFjAK00?o0000odNhAom7^4L01om7^4L00ol0003oA;]4odBkA005odBkA0?o
000000?o;]4^o`000?liaST01oliaST00ol0003o8]dRob;M8P05ob;M8P03o`000?mSW6?oHiaS00?o
HiaS0_l0000?ofVFJ@;o00003OnRGJ800ol0003oj1OXonPGj008onPGj003o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000Wog2?L00?o0000oiIYU_nFJIH01onFJIH2o`0000CoS7><00Co0000oe^TFomKY5_o
FjAK0_l0000:odNhA`03o`000?m4^dCoA;]400;oA;]40ol00005obkA;P03o`000?liaSWo>LHi00Go
>LHi00?o0000ob;M8_lRgB801?lRgB800ol0003oHiaSof>LH`06of>LH`03o`000?mYUVWoJIIY00[o
JIIY0_l00002ohEjQ@03o`000?nRGJ;oXUfR00[oXUfR00?o0000onPGj?oX5nP02?oX5nP00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000om`Sg?oL8m`01_oL8m`00ol0003oUVVFoiIYUP08oiIYUP03o`00
0?n<LhcoS7><00CoS7><00?o0000oe^TFol000003?m7^4L00ol0003oA;]4o`000002o`0000Wo;]4^
00?o0000ocW6>OliaST01?liaST00ol0003o8]dRob;M8P03ob;M8P03o`000?mSW6?oHiaS00SoHiaS
1_l00004ofVFJ@;o00001On5NXD00ol0003oXUfRoj9MXP09oj9MXP03o`000?oX5nSoj1OX00Soj1OX
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oL8mcog2?L00Gog2?L00?o0000oiIYU_nFJIH01onF
JIH00ol0003oS7><ohacS006ohacS003o`000?m7^4OoAkQ700coAkQ700?o0000obkA;_l^dBh02_l^
dBh00ol0003o>LHiocW6>@04ocW6>@04o`000?lRgB;o8]dRob;M8P;o00002omSW6<00ol0003oM8]d
ogB;M003ogB;M0Co00002?n5NXD00ol0003oXUfRoj9MXP08oj9MXP03o`000?oX5nSoj1OX00Ooj1OX
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000om`Sg?oL8m`00ooL8m`00ol0003oUVVFoiIYUP07oiIYUP03o`000?n<
LhcoS7><00OoS7><00?o0000odNhAom7^4L03?m7^4L00ol0003o;]4^obkA;P0;obkA;P03o`000?li
aSWo>LHi00?o>LHi00Co0000ob;M8_lRgB;o00003OmSW6<00ol0003oM8]dogB;M006ogB;M003o`00
0?n5NXGoQGZ500OoQGZ500?o0000oj9MX_nRGJ801onRGJ800ol0003oj1OXonPGj006onPGj004o`00
0?ol0ocoo0?loo`3o0;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oL8mcog2?L00;og2?L00?o0000oiIYU_nFJIH0
1_nFJIH00ol0003oS7><ohacS009ohacS003o`000?m7^4OoAkQ700WoAkQ70_l0000>obkA;P?o0000
0oliaST00ol0003o8]dRo`00000=of>LH`03o`000?mdRgCoM8]d00OoM8]d00?o0000ohEjQOn5NXD0
2?n5NXD:o`0000Koj1OX0_l00006oo`3o003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoUVVF00?o
0000ohacS?n<Lh`02_n<Lh`00ol0003oAkQ7odNhA`06odNhA`;o000000?oA;]4o`000?l^dBh02ol^
dBh2o`0000?oH9mP1Ol0000>of>LH`03o`000?mdRgCoM8]d00OoM8]d00?o0000ohEjQOn5NXD02?n5
NXD00ol0003o_4>loka3_006oka3_003o`000?oX5nSoj1OX00?oj1OX00?o0000oo`3o?ol0o`01ool
0o`2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003od2o@om0_d003om0_d0Co00000_nFJIH00ol0003oS7><ohacS00;
ohacS003o`000?m7^4OoAkQ700?oAkQ70ol00004odBkA003o`000?l^dBko;]4^00Oo;]4^0_l00008
of2OH003o`000?mSW6?oHiaS00goHiaS00?o0000ogB;M?mdRg@02?mdRg@00ol0003oQGZ5ohEjQ@07
ohEjQ@03o`000?nl@kco_4>l00Oo_4>l0ol000000ooX5nSo0000oo`3o00;oo`3o0;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o@;m3od2o@00Ood2o@0_l0000?ohacS003o`000?m7^4OoAkQ700;o00002?m4^d@00ol0
003o;]4^obkA;P05obkA;P03o`000?mPWf3oH9mP00SoH9mP00?o0000of>LHomSW6<03OmSW6<00ol0
003oM8]dogB;M008ogB;M003o`000?n5NXGoQGZ500KoQGZ500?o0000oka3_?nl@k`02?nl@k`01?l0
003ojAKYonTFjOl0000?oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003od2o@om0_d009om0_
d003o`000?n<LhcoS7><00koS7><0_l0000;odBkA003o`000?l^dBko;]4^00;o;]4^0_l0000;of2O
H003o`000?mSW6?oHiaS00goHiaS00?o0000ogB;M?mdRg@02?mdRg@00ol0003oQGZ5ohEjQ@06ohEj
Q@03o`000?nl@kco_4>l00Oo_4>l00Go0000onTFjOoY5^WojAKYo`00000@oo`3o0;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003od2o@om0_d00:om0_d003o`000?n<LhcoS7><00goS7><0_l0000<odBkA004o`000?l^dBko0000
o`0000goH9mP00?o0000of>LHomSW6<03?mSW6<00ol0003oM8]dogB;M009ogB;M003o`000?n5NXGo
QGZ500KoQGZ500?o0000oka3_?nl@k`01_nl@k`00ol0003ojAKYonTFj@03onTFj@03o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003od2o@om0_d00:om0_d003o`000?n<LhcoS7><00coS7><00Co0000ocO8
=olgb3Oo00003?m4^d@00ol0003oH9mPof2OH00>of2OH003o`000?mSW6?oHiaS00SoHiaS1?l0000;
ogB;M003o`000?n5NXGoQGZ500KoQGZ500?o0000oka3_?nl@k`01Onl@k`00ol0003ojAKYonTFj@04
onTFj@03o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003od2o@om0_d00;om0_d003o`000?n<LhcoS7><
00_oS7><00?o0000ocO8=olgb3L00_lgb3L00ol0003oA;]4odBkA009odBkA003o`000?mPWf3oH9mP
00koH9mP00Co0000of>LHomSW6?oHiaS1ol00003ofZEJP03o`000?mdRgCoM8]d00WoM8]d00?o0000
ohEjQOn5NXD01_n5NXD00ol0003o_4>loka3_004oka3_003o`000?oY5^WojAKY00KojAKY00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?o@;m3od2o@00cod2o@00?o0000ohacS?n<Lh`02_n<Lh`00ol0
003o=lPgocO8=`03ocO8=`03o`000?m4^dCoA;]400SoA;]400?o0000of2OH?mPWf003_mPWf04o`00
00_oJYEZ00?o0000ogB;M?mdRg@02?mdRg@00ol0003oQGZ5ohEjQ@05ohEjQ@03o`000?nl@kco_4>l
00Go_4>l00?o0000onTFjOoY5^T01_oY5^T00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om0_d?o@
;m003?o@;m07o`0000GoS7><00?o0000ocO8=olgb3L01Olgb3L00ol0003oA;]4odBkA007odBkA003
o`000?mPWf3oH9mP00koH9mP00?o0000ofZEJ_mZUFX03OmZUFX00ol0003oM8]dogB;M008ogB;M003
o`000?n5NXGoQGZ500CoQGZ500?o0000oka3_?nl@k`01?nl@k`00ol0003ojAKYonTFj@07onTFj@03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003od2o@om0_d00=om0_d003o`000?nTFjCoY5^T00CoY5^T
1Ol00009ocO8=`03o`000?m4^dCoA;]400KoA;]400?o0000of2OH?mPWf003_mPWf000ol0003oJYEZ
ofZEJP0=ofZEJP03o`000?mdRgCoM8]d00SoM8]d00Co0000ohEjQOn5NXGoQGZ51Ol00004oka3_003
o`000?oY5^WojAKY00WojAKY1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=om0_d003o`000?nTFjCoY5^T00WoY5^T
0_l00009ocO8=`03o`000?m4^dCoA;]400KoA;]400?o0000of2OH?mPWf003?mPWf000ol0003oJYEZ
ofZEJP0?ofZEJPKo00001?mdRg@4o`0000GoaC[50_l000000onl@kco0000onTFj@0;onTFj@04o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oR7N;ohQgRon8MhP?o00002_o@;m000ol0003o
Y5^TojAKY009ojAKY003o`000?m</dco000000;o00001olgb3L00ol0003oA;]4odBkA005odBkA003
o`000?mPWf3oH9mP00SoH9mP1Ol0000AofZEJP03o`000?moOgooOgmo00?oOgmo1?l0000;olDja@03
o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000on8Mh_oR7N801OoR7N82o`0000Ood2o@
00?o0000ojAKY?nTFj@02_nTFj@00ol0003oC;=<odbcC002odbcC0?o00001Olgb3L00ol0003oA;]4
odBkA004odBkA004o`000?mPWf3oH9mPof2OH0Oo00001?m?/4l00ol0003oJYEZofZEJP0>ofZEJP03
o`000?moOgooOgmo00OoOgmo00?o0000olDjaOo5>/D02Oo5>/D00ol0003ojAKYonTFj@09onTFj@03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ohQgRon8MhP08on8MhP;o00001?o@;m000ol0003oY5^T
ojAKY00;ojAKY003o`000?m</dcoC;=<00GoC;=<0ol00003ocO8=`04o`000?m4^dCoA;]4odBkA0Ko
00003?m?/4l00ol0003oJYEZofZEJP0=ofZEJP03o`000?moOgooOgmo00OoOgmo00?o0000olDjaOo5
>/D02_o5>/D00ol0003ojAKYonTFj@08onTFj@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=on8MhP?o000000?od2o@o`000?nTFj@0
3?nTFj@00ol0003oC;=<odbcC008odbcC0?o000000Co=lPgo`000?l0003o00000_moP7l00ol0003o
Ck1?odn`C`0=odn`C`03o`000?mZUF[oJYEZ00coJYEZ00?o0000ogmoOomoOgl02?moOgl00ol0003o
aC[5olDja@0;olDja@03o`000?oY5^WojAKY00KojAKY00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
hQgR00?o0000ojAKY?nTFj@03?nTFj@00ol0003oC;=<odbcC00;odbcC003o`000?moP7ooOh1o00?o
Oh1o00?o0000odn`Com?/4l03?m?/4l00ol0003o><Lho`00000=ofZEJP03o`000?moOgooOgmo00So
Ogmo00?o0000olDjaOo5>/D03?o5>/D3o`0000GojAKY00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oR7N;ohQgR00cohQgR00?o0000ojAKY?nTFj@03?nTFj@00ol0003oC;=<odbcC00:odbcC003o`00
0?moP7ooOh1o00GoOh1o00?o0000odn`Com?/4l02_m?/4l01?l0003o><LhocS7>?lhacP2o`0000[o
JYEZ00?o0000ogmoOomoOgl02OmoOgl00ol0003oaC[5olDja@0<olDja@03o`000?o]4^gokA;]00?o
000000?ojAKYo`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oR7N;ohQgR00_ohQgR00?o0000ojAKY?nTFj@0
3?nTFj@00ol0003oC;=<odbcC009odbcC003o`000?moP7ooOh1o00KoOh1o00?o0000odn`Com?/4l0
2Om?/4l00ol0003o><LhocS7>002ocS7>003o`000?mlPgco000000;o00001omZUFX00ol0003oOgmo
ogmoO`09ogmoO`03o`000?o5>/GoaC[500_oaC[500?o0000ondBkOo]4^d01?o]4^d00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000on8Mh_oR7N802ooR7N800ol0003oY5^TojAKY00;ojAKY003o`000?m<
/dcoC;=<00SoC;=<00?o0000ogn0OomoP7l01omoP7l00ol0003oCk1?odn`C`08odn`C`03o`000?lh
acSo><Lh00?o><Lh00?o0000ogb3O?mlPg`00_mlPg`2o`0000CoJYEZ00?o0000ogmoOomoOgl02_mo
Ogl00ol0003oaC[5olDja@0:olDja@03o`000?o]4^gokA;]00GokA;]00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oR7N;ohQgR00[ohQgR0ol0000;ojAKY0Ko00001?m</d`00ol0003oOh1oogn0O`08
ogn0O`03o`000?m?/4ooCk1?00OoCk1?00?o0000ocS7>?lhacP00olhacP00ol0003oO8=logb3O005
ogb3O0?o000000?oJYEZo`000?moOgl02omoOgl00ol0003oaC[5olDja@09olDja@03o`000?o]4^go
kA;]00OokA;]00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oR7N;ohQgR00WohQgR00?o0000okQ7
^?nhAkP01?l00006ojAKY003o`000?nKI9_oVfBK00CoVfBK1?l0000<ogn0O`03o`000?m?/4ooCk1?
00GoCk1?00?o0000ocS7>?lhacP01?lhacP00ol0003oO8=logb3O008ogb3O003o`000?moOgooOgmo
00_oOgmo00?o0000olDjaOo5>/D02?o5>/D00ol0003okA;]ondBk@08ondBk@Go00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oR7N;ohQgR00OohQgR00?o0000okQ7^?nhAkP01OnhAkP3o`0000;oY5^T00?o0000oi]TVonK
I9/02?nKI9/00ol0003oOh1oogn0O`0:ogn0O`03o`000?m?/4ooCk1?00CoCk1?00?o0000ocS7>?lh
acP01OlhacP00ol0003oO8=logb3O008ogb3O003o`000?moOgooOgmo00WoOgmo1?l00008olDja@03
o`000?o]4^gokA;]00WokA;]00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohQgR
on8MhP05on8MhP03o`000?nhAkSo^4Nh00Wo^4Nh0_l0000<oi]TV`03o`000?moP7ooOh1o00WoOh1o
00?o0000odn`Com?/4l00om?/4l00ol0003o><LhocS7>005ocS7>003o`000?mlPgcoO8=l00[oO8=l
00?o0000ogmoOomoOgl01?moOgl4o`0000Co]dRg00?o0000olDjaOo5>/D01?o5>/D00ol0003okA;]
ondBk@0:ondBk@03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oR7N;ohQgR00?ohQgR00?o0000okQ7^?nhAkP02onh
AkP00ol0003oVfBKoi]TV`0:oi]TV`03o`000?moP7ooOh1o00WoOh1o00?o0000odn`Com?/4l00_m?
/4l00ol0003o><LhocS7>006ocS7>003o`000?mlPgcoO8=l00[oO8=l00?o0000ogmoOomoOgl01?l0
0009okM8]`Ko00003?o]4^d00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000on8Mh_oR7N;ohQgR0_l0
000=okQ7^003o`000?nKI9_oVfBK00[oVfBK00?o0000ogn0OomoP7l02OmoP7l01Ol0003oCk1?odn`
Com?/4oo000000Wo><Lh00?o0000ogb3O?mlPg`02omlPg`2o`0000go]dRg00?o0000onLHiooW6>L0
0_oW6>L00ol0003okA;]ondBk@0:ondBk@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ohQgRo`00
0002onXEjP;o00002onhAkP00ol0003oVfBKoi]TV`0;oi]TV`03o`000?moP7ooOh1o00WoOh1o00?o
0000odn`Col000002OlhacP00ol0003oO8=logb3O00<ogb3O003o`000?ngB;Oo]dRg00co]dRg00?o
0000onLHiooW6>L00ooW6>L00ol0003okA;]ondBk@09ondBk@03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ojQGZonXEjP03onXEjP;o00002_nhAkP00ol0003oVfBKoi]TV`0:oi]TV`03o`000?moP7oo
Oh1o00SoOh1o1Ol00008ocS7>003o`000?mlPgcoO8=l00coO8=l00?o0000okM8]ongB;L02ongB;L0
0ol0003oiaSWonLHi`05onLHi`03o`000?o]4^gokA;]00SokA;]00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001ooZ5NX2o`0000So^4Nh00?o0000oi]TVonKI9/02_nKI9/00ol0003oOh1oogn0O`07ogn0
O`03o`000?m`Sg3oL8m`00?oL8m`0ol00005ocS7>003o`000?mlPgcoO8=l00_oO8=l00?o0000okM8
]ongB;L03?ngB;L00ol0003oiaSWonLHi`06onLHi`03o`000?o]4^gokA;]00OokA;]00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?ol0oco000000WojQGZ00?o0000okQ7^?nhAkP01OnhAkP2o`0000co
VfBK00?o0000ogn0OomoP7l01OmoP7l00ol0003oL8m`og2?L007og2?L0?o000000?o><Lho`000?ml
Pg`03OmlPg`00ol0003o]dRgokM8]`0<okM8]`03o`000?oW6>OoiaSW00KoiaSW00?o0000ondBkOo]
4^d01_o]4^d00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003oo`3o003o`000?oZ5N[ojQGZ00OojQGZ
0_l00004okQ7^003o`000?o6>LKoaSW600;o00002_nKI9/00ol0003oOh1oogn0O`03ogn0O`;o0000
3Om`Sg02o`0000goO8=l0ol0000=okM8]`03o`000?oW6>OoiaSW00OoiaSW00?o0000ondBkOo]4^d0
1Oo]4^d00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo0?loo`3o004oo`3o003o`000?oZ5N[ojQGZ00SojQGZ0_l0
00000onhAkSo0000olHiaP04olHiaP03o`000?nKI9_oVfBK00OoVfBK00Co0000ogn0OomoP7ooOh1o
0_l00002oiIYUP03o`000?m`Sg3oL8m`00coL8m`3Ol00003oimPW`03o`000?ngB;Oo]dRg00[o]dRg
00?o0000onLHiooW6>L02?oW6>L01?l0003okA;]ondBkOo]4^d4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?ol0o`00ol0003ojQGZ
onXEjP09onXEjP03o`000?o6>LKoaSW600GoaSW60_l00008oi]TV`03o`000?moP7oo000000GoUVVF
00?o0000og2?L?m`Sg002om`Sg000ol0003oMhQgogN8M`09ogN8M`03o`000?nOH9ooWf2O00;oWf2O
0_l00009okM8]`03o`000?oW6>OoiaSW00[oiaSW0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000oo`3
o00:oo`3o003o`000?oZ5N[ojQGZ00SojQGZ00?o0000olHia_o6>LH01oo6>LH4o`0000?oVfBK0ol0
0007oiIYUP03o`000?m`Sg3oL8m`00[oL8m`00?o0000ogN8MomgR7L02OmgR7L00ol0003oWf2OoimP
W`04oimPW`;o00001ongB;L00ol0003oiaSWonLHi`0:onLHi`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?oZ5N[ojQGZ00OojQGZ00?o0000olHia_o6>LH02?o6>LH0
1?l0003oaC[5olDjaOo5>/D3o`0000;o/Tfb00?o0000oiIYU_nFJIH01_nFJIH00ol0003oL8m`og2?
L008og2?L003o`000?mgR7OoMhQg00[oMhQg00?o0000oimPWonOH9l01_nOH9l00ol0003o]dRgokM8
]`04okM8]`03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onXEj_oZ5NX01OoZ5NX00ol0003oaSW6olHiaP08olHiaP03o`000?o5>/Go
aC[500CoaC[500Go0000ok9=/_nbCK;o/Tfbo`000008oiIYUP03o`000?m`Sg3oL8m`00OoL8m`00?o
0000ogN8MomgR7L02_mgR7L00ol0003oWf2OoimPW`07oimPW`;o00001?ngB;L00ol0003oiaSWonLH
i`08onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX00ooZ5NX0
0ol0003oaSW6olHiaP08olHiaP03o`000?o5>/GoaC[500CoaC[500?o0000ok9=/_nbCK800_nbCK80
0ol0003oUVVFoiIYUP07oiIYUP03o`000?m`Sg3oL8m`00KoL8m`00?o0000ogN8MomgR7L02_mgR7L0
0ol0003oWf2OoimPW`09oimPW`05o`000?ngB;Oo]dRgokM8]ol000002OoW6>L00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_oaSW600?o0000olDjaOo5>/D01?o5>/D00ol0003o/Tfbok9=/P03
ok9=/P03o`000?nFJIKoUVVF00OoUVVF00?o0000og2?L?m`Sg001Om`Sg000ol0003oMhQgogN8M`0:
ogN8M`03o`000?nOH9ooWf2O00WoWf2O1?l00009onLHi`03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o^4NkokQ7^
onhAk_l000002_o6>LH00ol0003oaC[5olDja@05olDja@03o`000?nbCK;o/Tfb00?o/Tfb00?o0000
oiIYU_nFJIH02?nFJIH00ol0003oL8m`og2?L004og2?L003o`000?mgR7OoMhQg00WoMhQg00?o0000
oimPWonOH9l02?nOH9l2o`0000?oiQWV00?o0000onLHiooW6>L01_oW6>L00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oaSW6olHiaP06olHiaP03o`000?o5>/GoaC[5
00GoaC[500?o0000ok9=/_nbCK801?nbCK800ol0003oUVVFoiIYUP09oiIYUP03o`000?m`Sg3oL8m`
00;oL8m`00?o0000ogN8MomgR7L02_mgR7L00ol0003oWf2OoimPW`06oimPW`;o00001_oV6NH8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003okQ7^onhAkP05onhAkP03o`000?o6>LKoaSW600GoaSW600?o0000olDjaOo5
>/D01Oo5>/D00ol0003o/Tfbok9=/P05ok9=/P03o`000?nFJIKoUVVF00WoUVVF00Go0000og2?L?m`
Sg3oL8m`o`00000<ogN8M`03o`000?nOH9ooWf2O00CoWf2O0_l00008onHIiP03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o^4NkokQ7^00OokQ7^00?o0000olHia_o6
>LH00oo6>LH00ol0003oaC[5olDja@06olDja@03o`000?nbCK;o/Tfb00Go/Tfb00?o0000oiIYU_nF
JIH02_nFJIH00ol0003oL8m`o`000004o`0000WoMhQg00?o0000oimPWonOH9l00_nOH9l2o`0000[o
iQWV00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003okQ7^onhAkP07onhAkP03o`00
0?o6>LKoaSW600;oaSW600?o0000olDjaOo5>/D01_o5>/D00ol0003o/Tfbok9=/P07ok9=/P;o0000
2onFJIH00ol0003o_D:moke2_@03oke2_@Oo00000_mgR7L00ol0003oWf2OoimPW`02o`0000_oiQWV
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000onhAk_o^4Nh02Oo^
4Nh01Ol0003oaSW6olHia_o6>LKo000000SoaC[500?o0000ok9=/_nbCK801onbCK800ol0003ofbCK
o`000002o`0000SoUVVF00?o0000oke2_Onm@[d02_nm@[d5o`0000goiQWV00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<onhAkP03o`000?o6>LKo000000WoaC[500?o
0000ok9=/_nbCK801_nbCK800ol0003ofbCKom/Tf`03om/Tf`?o00001?nFJIH00ol0003o_D:moke2
_@0=oke2_@03o`000?oV6NKoiQWV00goiQWV00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000oom0_d2o`0000_okQ7^00?o0000olDjaOo5>/D01oo5>/D00ol0003o/Tfbok9=/P07
ok9=/P03o`000?oK9=_ofbCK00KofbCK0ol000000onFJIKo0000oke2_@0>oke2_@03o`000?oV6NKo
iQWV00coiQWV00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009onhA
kP03o`000?o5>/GoaC[500;oaC[51_l00008ok9=/P03o`000?oK9=_ofbCK00[ofbCK00?o0000oke2
_Onm@[d03onm@[d00ol0003oiQWVonHIiP0:onHIiP;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007onhAkPGo00001_o[5>/00ol0003o/Tfbok9=/P05ok9=/P03o`000?oK9=_ofbCK00[o
fbCK00?o0000oke2_Onm@[d03onm@[d00ol0003oiQWVonHIiP07onHIiP?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005onhAkP03o`000?o[5>_ojaC[00WojaC[00?o0000ok9=/_nb
CK800onbCK800ol0003ofbCKom/Tf`0;om/Tf`03o`000?nm@[go_D:m00oo_D:m00?o0000onHIi_oV
6NH01OoV6NH2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?okQ7^o`000?l00000
3Oo[5>/00ol0003o/Tfbok9=/P02ok9=/P03o`000?oK9=_ofbCK00_ofbCK5?l00004onHIiP;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo0?lo`00000>on/Dj`04o`000?nbCK;o/Tfbo`0000kofbCK
00?o0000onhAk_o^4Nh04?o^4Nh00ol0003oiQWVo`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?ol0ocoo0?loo`3o?l000003_o[5>/00ol0003o/Tfbo`00000>om/Tf`03o`00
0?o^4NkokQ7^017okQ7^00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000oo`3o?ol0o`00_ol0o`00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oK9=_ofbCK00WofbCK1Ol0
000BonhAkP;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ojaC[on/Dj`0<on/Dj`03o`000?oK9=_ofbCK00;ofbCK1ol00004oo/4n`03o`000?o^4Nko
kQ7^00ookQ7^00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o006oo`3
o003o`000?o[5>_ojaC[00cojaC[1?l0000<oo/4n`03o`000?o^4NkokQ7^00cokQ7^0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on/Djoo[5>/03?o[5>/00ol0003on`Ckoo/4n`0=oo/4n`03o`000?o^4NkokQ7^00_o
kQ7^00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo`3o?ol
0o`02Ool0o`00ol0003ojaC[on/Dj`0:on/Dj`03o`000?ok1?_on`Ck00kon`Ck00?o0000onhAk_o^
4Nh02Oo^4Nh2o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000on/Djoo[5>/02_o[5>/00ol0003on`Ck
oo/4n`0?oo/4n`03o`000?o^4NkokQ7^00KokQ7^0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo0?l00goo0?l3?l0
000Aoo/4n`?o00001_o^4Nh00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003on`Ckoo/4n`0>oo/4n`05o`000?ol0ocoo0?loo`3o?l000000oo^4Nh2o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0=oo/4n`03o`000?ol0oco
o0?l00?oo0?l00?o0000onhAk_l000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4
nook1?/02ook1?/00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4n`0:oo/4n`03o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo/4nook1?/02Ook1?/00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003on`Ckoo/4
n`07oo/4n`;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_o
n`Ck00Gon`Ck00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
n`Ckoo/4n`03oo/4n`03o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00;on`Ck00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ok1?_on`Cko`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01_l00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`03o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00ol00?l2oooo
00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?oo
ool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Co
ool000?o003ooooo0?ooo`002_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Go003o0oooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00
ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool0
2_l00?l2oooo00Oo003o0_ooo`03o`00o`?oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2_l00?l2oooo00So003o00?oool0o`00ool00?l00oooo`04o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`0:o`00o`;oool02Ol00?l4oooo00Go003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`002_l0
0?l2oooo00So003o1?ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Y
o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04
o`00o`Coool000?o003ooooo0?l00?l00_ooo`0:o`00o`;oool01ol00?l3oooo00;o003o0_ooo`04
o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo
00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o003o0_ooo`06o`00o`?oool01?l00?l2oooo
00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?o
ool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;o
ool00_l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o
0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`0:o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`03o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l0
0?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Oo003o0_oo
o`06o`00o`;oool01_l00?l2oooo00?o003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo
001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5
oooo00Go003o1?ooo`07o`00o`;oool01?l00?l2oooo00Go003o0_ooo`02o`00o`;oool01Ol00?l5
oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Ro`00
o`;oool02Ol00?l5oooo00Oo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o
;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(190) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.987 .013 .987 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.988 .012 .988 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.987 .013 .987 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.986 .014 .986 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.92 .08 .92 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.985 .015 .985 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.918 .082 .918 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.926 .074 .926 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.889 .111 .889 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.982 .018 .982 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.851 .149 .851 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.987 .013 .987 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.767 .233 .767 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.763 .237 .763 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.983 .017 .983 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.988 .012 .988 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.668 .332 .668 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.816 .184 .816 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.98 .02 .98 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.983 .017 .983 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.985 .015 .985 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.909 .091 .909 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.473 .527 .473 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.734 .266 .734 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.585 .415 .585 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.573 .427 .573 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.657 .343 .657 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.853 .147 .853 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.89 .11 .89 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.987 .013 .987 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.578 .422 .578 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.797 .203 .797 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.443 .557 .443 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.867 .133 .867 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.82 .18 .82 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.987 .013 .987 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.726 .274 .726 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.775 .225 .775 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.627 .373 .627 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.862 .138 .862 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.604 .396 .604 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.989 .011 .989 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.904 .096 .904 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.581 .419 .581 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.381 .619 .381 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.378 .622 .378 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.921 .079 .921 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.936 .064 .936 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.736 .264 .736 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.987 .013 .987 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.574 .426 .574 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.519 .481 .519 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.493 .507 .493 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.52 .48 .52 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.271 .729 .271 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.545 .455 .545 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.648 .352 .648 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.987 .013 .987 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.648 .352 .648 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.55 .45 .55 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.908 .092 .908 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.18 .82 .18 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.786 .214 .786 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.744 .256 .744 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.491 .509 .491 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.221 .779 .221 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.36 .64 .36 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.064 .936 .064 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.117 .883 .117 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.394 .606 .394 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.276 .724 .276 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.354 .646 .354 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.784 .216 .784 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.339 .661 .339 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.37 .63 .37 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.617 .383 .617 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.923 .077 .923 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.986 .014 .986 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.193 .807 .193 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.269 .731 .269 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.312 .688 .312 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.986 .014 .986 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.625 .375 .625 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.347 .653 .347 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.228 .772 .228 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.139 .861 .139 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.439 .561 .439 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.254 .746 .254 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.911 .089 .911 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.319 .681 .319 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.071 .929 .071 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.71 .29 .71 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.236 .764 .236 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.178 .822 .178 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.495 .505 .495 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.859 .141 .859 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.391 .609 .391 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.062 .938 .062 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.181 .819 .181 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.447 .553 .447 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.233 .767 .233 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.251 .749 .251 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.862 .138 .862 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.201 .799 .201 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.139 .861 .139 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.102 .898 .102 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.985 .015 .985 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.105 .895 .105 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.283 .717 .283 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.161 .839 .161 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.599 .401 .599 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.357 .643 .357 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.985 .015 .985 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.41 .59 .41 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.29 .71 .29 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.317 .683 .317 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.371 .629 .371 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.224 .776 .224 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.175 .825 .175 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.295 .705 .295 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.441 .559 .441 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.986 .014 .986 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.724 .276 .724 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.341 .659 .341 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.461 .539 .461 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.212 .788 .212 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.91 .09 .91 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.024 .976 .024 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.204 .796 .204 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.188 .812 .188 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.379 .621 .379 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.606 .394 .606 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.117 .883 .117 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.986 .014 .986 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.263 .737 .263 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.754 .246 .754 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.934 .066 .934 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.487 .513 .487 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.474 .526 .474 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.316 .684 .316 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.853 .147 .853 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.113 .887 .113 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.244 .756 .244 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.373 .627 .373 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.624 .376 .624 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.107 .893 .107 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.245 .755 .245 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.357 .643 .357 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.403 .597 .403 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.986 .014 .986 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.166 .834 .166 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.986 .014 .986 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.897 .103 .897 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.422 .578 .422 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.361 .639 .361 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.217 .783 .217 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.64 .36 .64 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.283 .717 .283 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.907 .093 .907 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.408 .592 .408 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.44 .56 .44 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.443 .557 .443 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.504 .496 .504 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.739 .261 .739 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.456 .544 .456 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.216 .784 .216 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.129 .871 .129 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.171 .829 .171 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.415 .585 .415 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.725 .275 .725 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.986 .014 .986 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.904 .096 .904 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.298 .702 .298 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.195 .805 .195 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.386 .614 .386 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.762 .238 .762 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.534 .466 .534 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.986 .014 .986 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.414 .586 .414 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.778 .222 .778 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.909 .091 .909 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.986 .014 .986 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.248 .752 .248 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.322 .678 .322 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.897 .103 .897 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.338 .662 .338 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.491 .509 .491 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.671 .329 .671 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.367 .633 .367 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.506 .494 .506 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.807 .193 .807 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.659 .341 .659 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.655 .345 .655 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.751 .249 .751 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.371 .629 .371 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.93 .07 .93 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.708 .292 .708 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.472 .528 .472 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.443 .557 .443 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.986 .014 .986 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.681 .319 .681 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.403 .597 .403 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.985 .015 .985 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.916 .084 .916 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.785 .215 .785 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.914 .086 .914 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.38 .62 .38 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.891 .109 .891 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.694 .306 .694 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.579 .421 .579 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.987 .013 .987 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.57 .43 .57 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.481 .519 .481 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.987 .013 .987 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.736 .264 .736 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.982 .018 .982 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.988 .012 .988 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.604 .396 .604 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.984 .016 .984 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.497 .503 .497 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.985 .015 .985 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.54 .46 .54 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.776 .224 .776 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.615 .385 .615 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.874 .126 .874 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.89 .11 .89 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.71 .29 .71 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.628 .372 .628 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.7 .3 .7 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.826 .174 .826 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.883 .117 .883 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.82 .18 .82 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.834 .166 .834 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.983 .017 .983 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.695 .305 .695 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.905 .095 .905 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.984 .016 .984 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.929 .071 .929 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.914 .086 .914 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.701 .299 .701 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.916 .084 .916 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.895 .105 .895 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.752 .248 .752 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.985 .015 .985 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.982 .018 .982 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.898 .102 .898 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.986 .014 .986 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.986 .014 .986 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.985 .015 .985 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.986 .014 .986 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.985 .015 .985 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.986 .014 .986 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo/4n`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ok1?/2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook1?/03_ok
1?/00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003oiaSWonLHiol0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo/4nook1?/0
3_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onLHiooW6>L00_oW6>L00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oW6>OoiaSW00?oiaSW00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ok1?_on`Ck00oon`Ck00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onLHiooW6>L01OoW6>L00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo/4nook1?/03ook1?/00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiaSWonLHi`06onLHi`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003on`Ckoo/4n`0@oo/4n`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onLHiooW6>L02?oW6>L00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo/4nook1?/04?ok1?/<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oY5^Wo0000013oo0?l00?o0000oo`3o?ol0o`02?ol
0o`9o`0000coiaSW00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ok1?_on`Ck00oon`Ck
00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onTFj@03o`000?ol
0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiA[UonDJi@05onDJi@03o`000?oW
6>OoiaSW00_oiaSW0ol00003onDJi@03o`000?ol0ocoo0?l00coo0?l0ol0000>oo/4n`;o00003Ook
1?/2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onTFjOoY5^T00ooY5^T00ol0003oo0?loo`3o00;oo`3o0;o00002ool0o`00ol0003oiA[UonDJi@06
onDJi@03o`000?oW6>OoiaSW00[oiaSW00?o0000onDJiOoU6^D01?oU6^D00ol0003oo0?loo`3o00:
oo`3o004o`000?oT6nCoi1_Ton@Ki0;o00002_ok1?/2o`000003on<Lhol0003on`Ck00kon`Ck00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKYonTFj@05onTFj@03o`000?ol0oco
o0?l00Woo0?l00?o0000onPGj?l000002ool0o`00ol0003oiA[UonDJi@06onDJi@03o`000?oW6>Oo
iaSW00WoiaSW00?o0000onDJiOoU6^D01_oU6^D00ol0003oo0?loo`3o008oo`3o003o`000?oT6nCo
i1_T00Coi1_T0_l00005oo/4n`?o00001?oS7><00ol0003on`Ckoo/4n`0=oo/4n`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008onTFj@03o`000?ol0ocoo0?l00Ooo0?l0_l00003onPG
j003o`000?ol0ocoo0?l00Ooo0?l00?o0000onDJiOoU6^D01ooU6^D00ol0003oiaSWonLHi`09onLH
i`03o`000?oU6^GoiA[U00OoiA[U00?o0000oo`3o?ol0o`01Ool0o`2o`0000Woi1_T0_l000000ook
1?_o0000o`000007on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000onTFjOoY
5^T02?oY5^T00ol0003oo0?loo`3o006oo`3o003o`000?oX5nSoj1OX00?oj1OX00?o0000oo`3o?ol
0o`01ool0o`00ol0003oiA[UonDJi@08onDJi@03o`000?oW6>OoiaSW00OoiaSW00?o0000onDJiOoU
6^D02OoU6^D00ol0003oo0?loo`3o003oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000on<LhooS
7><01ooS7><00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OXo`000005oo`3o0;o00002ooY5^T2o`0000Koo0?l
00?o0000onPGj?oX5nP01OoX5nP00ol0003oo0?loo`3o006oo`3o003o`000?oU6^GoiA[U00SoiA[U
00?o0000onLHiooW6>L01_oW6>L00ol0003oiA[UonDJi@0;onDJi@05o`000?ol0ocoo0?loo`3o?l0
00003_oT6n@00ol0003ohacSon<Lh`08on<Lh`03o`000?ok1?_on`Ck00gon`Ck00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oX5nSoj1OXonPGj?l0
00000ool0o`00ol0003ojAKYonTFj@0:onTFj@04o`000?oK9=_ofbCKo`0000?oo0?l0_l00008onPG
j003o`000?ol0ocoo0?l00Koo0?l00?o0000onDJiOoU6^D02OoU6^D00ol0003oiaSWonLHi`05onLH
i`03o`000?oU6^GoiA[U00coiA[U00?o0000oo`3o?l000003ooT6n@00ol0003ohacSon<Lh`08on<L
h`03o`000?ok1?_on`Ck00kon`Ck00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OXonPGj003onPGj003o`000?ol0oco000000_o
jAKY0_l00004om/Tf`03o`000?ol0oco000000_oj1OX00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iA[UonDJi@09onDJi@03o`000?oW6>OoiaSW00CoiaSW00?o0000onDJiOoU6^D03_oU6^D00ol0003o
i1_Ton@Ki00>on@Ki003o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/03_ok1?/00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000onPGj?oX5nP0
1?oX5nP00ol0003ojAKYonTFj@09onTFj@03o`000?oK9=_ofbCK00GofbCK00?o0000onPGj?oX5nP0
2_oX5nP00ol0003oo0?loo`3o005oo`3o003o`000?oU6^GoiA[U00[oiA[U00?o0000onLHiooW6>L0
0ooW6>L00ol0003oiA[UonDJi@0>onDJi@03o`000?oT6nCoi1_T00goi1_T00?o0000on<LhooS7><0
2_oS7><00ol0003on`Ckoo/4n`0>oo/4n`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OXonPG
j005onPGj003o`000?oY5^WojAKY00OojAKY0_l00008om/Tf`03o`000?oX5nSoj1OX00_oj1OX00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oiA[UonDJi@0:onDJi@04o`000?oW6>OoiaSWonLHi`?o0000
3ooU6^D00ol0003oi1_Ton@Ki00>on@Ki003o`000?oS7>?ohacS00[ohacS00?o0000oo/4nook1?/0
3ook1?/3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oX5nSoj1OX00Ooj1OX00?o0000onTFjOoY5^T01?oY5^T2o`0000_ofbCK1?l0
0009onPGj003o`000?ol0ocoo0?l00?oo0?l00?o0000onDJiOoU6^D02ooU6^D01?l0003oiaSWo`00
0?l00003ol<l``;o00003?oU6^D2o`00013oi1_T00?o0000on<LhooS7><02ooS7><00ol0003on`Ck
oo/4n`0=oo/4n`04o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003oj1OX
onPGj007onPGj003o`000?oY5^WojAKY00?ojAKY00?o0000om/TfooK9=/02ooK9=/01?l0003o^DJi
okU6^OniA[T5o`0000Goj1OX00?o0000oo`3o?ol0o`00_ol0o`00ol0003oiA[UonDJi@0<onDJi@03
o`000?o3?<?o`cc300Go`cc30_l00008onDJi@;o00000_neB[D00ol0003oi1_Ton@Ki00=on@Ki003
o`000?oS7>?ohacS00_ohacS00?o0000oo/4nook1?/03?ok1?/00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003oj1OXonPGj009onPGj003o`000?oY5^WojAKY00;o0000
3OoK9=/00ol0003o^DJiokU6^@07okU6^@Ko00000_ol0o`4o`0000goiA[U00?o0000ol<l`oo3?<<0
1oo3?<<2o`0000GoiA[U00?o0000okE:]OneB[D00oneB[D00ol0003oi1_Ton@Ki00<on@Ki003o`00
0?oS7>?ohacS00cohacS00?o0000oo/4nook1?/02_ok1?/00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oX5nSoj1OX00Woj1OX00?o
0000onTFjOl000003ooK9=/00ol0003o^DJiokU6^@0<okU6^@?o00001?oJ9MX3o`0000WoiA[U00?o
0000ol<l`oo3?<<02_o3?<<2o`000003onDJiOl0003o000000Oo]DZe00?o0000on@Ki?oT6n@02ooT
6n@00ol0003ohacSon<Lh`0<on<Lh`03o`000?ok1?_on`Ck00Kon`Ck1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oX5nSoj1OX00_oj1OX00?o0000
om/TfooK9=/03_oK9=/00ol0003o^DJiokU6^@0=okU6^@03o`000?oJ9M[ofRGJ00KofRGJ0ol00005
onDJi@03o`000?o3?<?o`cc300go`cc300?o0000okE:]OneB[D02?neB[D00ol0003oi1_Ton@Ki009
on@Ki003o`000?oS7>?ohacS00gohacS00Co0000oo/4nook1?_on`Ck1Ol00003onTFj@03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
onPGj?oX5nP02ooX5nP2o`0000oofbCK00?o0000okU6^OniA[T03OniA[T00ol0003ofRGJomXUfP0:
omXUfP?o000000?oiA[Uo`000?o3?<<03oo3?<<00ol0003o]DZeokE:]@09okE:]@03o`000?oT6nCo
i1_T00Soi1_T00?o0000on<LhooS7><03_oS7><3o`0000SojAKY00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oX5nSoj1OX00Soj1OX0ol000000onn
@Kko0000om/Tf`0>om/Tf`03o`000?niA[Wo^DJi00go^DJi00?o0000omXUf_oJ9MX03OoJ9MX00ol0
003o`cc3ol<l``0?ol<l``03o`000?neB[Go]DZe00[o]DZe2ol0000;on<Lh`Go00003?oY5^T00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oiaSWo`000?ol0oco0000
00Soj1OX0ol00005oki1_P03o`000?oK9=_ofbCK00cofbCK00?o0000okU6^OniA[T03OniA[T00ol0
003ofRGJomXUfP0=omXUfP;o00004?o3?<<00ol0003o]DZeokE:]@0:okE:]@03o`000?naC[7o/Dja
00Oo/Dja00?o0000on<LhooS7><00_oS7><7o`0000Co]DZe00?o0000onTFjOoY5^T02_oY5^T00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol0o`02Ool0o`01?l0003oiaSWonLHiooW6>L2o`00
00Goj1OX0ol00009oki1_P;o00002ooK9=/00ol0003o^DJiokU6^@0=okU6^@03o`000?oJ9M[ofRGJ
00gofRGJ00Co0000oke2_Onm@[go00003oo3?<<00ol0003o]DZeokE:]@09okE:]@03o`000?naC[7o
/Dja00Wo/Dja1?l0000;okE:]@03o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3
o003o`000?ol0ocoo0?l00Soo0?l00?o0000onLHiooW6>L01?oW6>L00ol0003oj1OXo`000002o`00
00co_T6n00Co0000oimOWol0003o00002OoK9=/00ol0003o^DJiokU6^@0=okU6^@03o`000?oJ9M[o
fRGJ00gofRGJ00Go0000oke2_Onm@[go_D:mo`00000=ol<l``03o`000?neB[Go]DZe00[o]DZe00?o
0000ok5>/OnaC[402OnaC[400ol0003o]DZeokE:]@0<okE:]@03o`000?oY5^WojAKY00[ojAKY00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000onLHiooW6>L01_oW6>L0
0ol0003o_T6noki1_P0<oki1_P03o`000?nOGiooWenO00;oWenO0_l00007om/Tf`03o`000?niA[Wo
^DJi00co^DJi00?o0000omXUf_oJ9MX03OoJ9MX00ol0003o_D:moke2_@03oke2_@03o`000?o3?<?o
`cc300[o`cc300?o0000okE:]OneB[D02_neB[D00ol0003o/Djaok5>/@09ok5>/@03o`000?neB[Go
]DZe00co]DZe00?o0000onTFjOoY5^T02ooY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oiaSWonLHi`06onLHi`03o`000?nn@Kko_T6n00_o_T6n00?o0000oimO
WonOGil01OnOGil00ol0003ofbCKom/Tf`03om/Tf`03o`000?niA[Wo^DJi00go^DJi00?o0000omXU
f_oJ9MX03OoJ9MX00ol0003o_D:moke2_@04oke2_@03o`000?o3?<?o`cc300Wo`cc300?o0000okE:
]OneB[D02OneB[D00ol0003o/Djaok5>/@0:ok5>/@03o`000?neB[Go]DZe00co]DZe00?o0000onTF
jOoY5^T02ooY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iaSWonLHi`07onLHi`03o`000?nn@Kko_T6n00_o_T6n00?o0000oimOWonOGil01_nOGil2o`0000?o
fbCK00?o0000okU6^OniA[T03OniA[T00ol0003ofRGJomXUfP0<omXUfP03o`000?nm@[go_D:m00Ko
_D:m00?o0000ol<l`oo3?<<02?o3?<<00ol0003o]DZeokE:]@09okE:]@03o`000?naC[7o/Dja00[o
/Dja00?o0000okE:]OneB[D03?neB[D00ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;oo`3o003o`00
0?ol0ocoo0?l00Coo0?l00?o0000onLHiooW6>L02?oW6>L00ol0003o_T6noki1_P0:oki1_P03o`00
0?nOGiooWenO00WoWenO0_l000000ooK9=_o0000okU6^@0<okU6^@?o00003_oJ9MX00ol0003o_D:m
oke2_@07oke2_@03o`000?o3?<?o`cc300Oo`cc300?o0000okE:]OneB[D02OneB[D00ol0003o/Dja
ok5>/@0;ok5>/@03o`000?neB[Go]DZe00co]DZe00?o0000onTFjOoY5^T02_oY5^T00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000onLHiooW6>L02_oW6>L00ol0003o_T6noki1
_P09oki1_P03o`000?nOGiooWenO00_oWenO00?o0000okU6^OniA[T02_niA[T2o`0000?oVfBK00?o
0000omXUf_oJ9MX02_oJ9MX00ol0003o_D:moke2_@09oke2_@03o`000?o3?<?o`cc300Ko`cc300?o
0000okE:]OneB[D02?neB[D00ol0003o/Djaok5>/@0<ok5>/@03o`000?neB[Go]DZe00co]DZe00?o
0000onTFjOoY5^T02_oY5^T00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Ool0o`0
0ol0003oo0?loo`3o002oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000oki1__nn@Kh02?nn@Kh0
0ol0003oWenOoimOW`0<oimOW`03o`000?niA[Wo^DJi00So^DJi0_l00006oi]TV`;o00002_oJ9MX0
0ol0003o_D:moke2_@0:oke2_@03o`000?o3?<?o`cc300Go`cc300?o0000okE:]OneB[D02?neB[D0
0ol0003o/Djaok5>/@0<ok5>/@03o`000?neB[Go]DZe00co]DZe00?o0000onTFjOoY5^T02ooY5^T0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo0?l00Go0000oo`3o?ol0ocoo0?lo`00000=
onLHi`03o`000?nn@Kko_T6n00Oo_T6n00?o0000oimOWonOGil03_nOGil00ol0003o^DJiokU6^@04
okU6^@?o00002_nKI9/00ol0003ofRGJomXUfP07omXUfP03o`000?nm@[go_D:m00_o_D:m00?o0000
ol<l`oo3?<<00oo3?<<00ol0003o]DZeokE:]@09okE:]@03o`000?naC[7o/Dja00co/Dja00?o0000
okE:]OneB[D03?neB[D00ol0003ojAKYonTFj@0;onTFj@;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oiaSWonLHi`0<onLHi`03o`000?nn@Kko_T6n00Oo_T6n00?o0000oimOWonOGil03onOGil01?l0
003o^DJiokU6^OniA[T2o`0000koVfBK0_l00006omXUfP03o`000?nm@[go_D:m00go_D:m00?o0000
ol<l`oo3?<<00_o3?<<00ol0003o]DZeokE:]@08okE:]@03o`000?naC[7o/Dja00co/Dja0ol0000=
okE:]@03o`000?oY5^WojAKY00_ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooiaSW00?o0000oki1__nn@Kh01_nn@Kh00ol0003oWenOoimOW`0@oimOW`Co00004_nKI9/00ol0
003ofRGJomXUfP03omXUfP03o`000?nm@[go_D:m00ko_D:m00Go0000ol<l`oo3?<?o`cc3o`000005
okE:]@Oo00003?naC[401Ol0003oOh1oogn0OomoP7oo000000co]DZe00?o0000onTFjOoY5^T02?oY
5^T3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooiaSW00?o0000oki1__nn@Kh01_nn@Kh00ol0003oWenOoimOW`0=
oimOW`?o000000CoL8m`o`000?l0003o00004onKI9/2o`0000;ofRGJ00?o0000oke2_Onm@[d04?nm
@[d00ol0003o`cc3o`000006o`0000Oo[U6^00?o0000ok5>/OnaC[402?naC[400ol0003oOh1oogn0
O`03ogn0O`;o00002?neB[D3o`0000KojAKY1?l00002onDJi@03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003oj1OXo`000?niA[T3o`0000goiaSW00?o0000oki1__nn@Kh01?nn@Kh00ol0003oWenOoimO
W`0;oimOW`?o00000om`Sg001Ol0003oLXebo`000?mXUfSo000001CoVfBK00?o0000omXUf_l00000
4onm@[d00ol0003o[U6^ojiA[P0=ojiA[P03o`000?naC[7o/Dja00Go/Dja0_l00008ogn0O`03o`00
0?neB[Go]DZe00Go00000oncC;<00ol0003ojAKYonTFj@03o`0000OoiA[U00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oX5nSoj1OXo`0000Co^DJi0ol0000:onLHi`03o`000?nn@Kko_T6n00?o_T6n
00?o0000oimOWonOGil02OnOGil3o`0000GoL8m`00Co0000og:=L_mbSG;o00000_mXUfP00ol0003o
VfBKoi]TV`0Boi]TV`03o`000?nm@[go_D:m01;o_D:m00?o0000ojiA[_n^DJh03_n^DJh00ol0003o
/Djaok5>/@03ok5>/@03o`000?moP7ooOh1o00WoOh1o0_l00009ok=</`;o00002_oU6^D00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000onPGj?oX5nSoj1OXo`000007okU6^@;o00001ooW6>L5o`0000;o
_T6n00?o0000oimOWonOGil01_nOGil3o`0000SoL8m`00Co0000og:=L_mbSG;o00000omXUfP00ol0
003oVfBKoi]TV`0Aoi]TV`03o`000?nm@[go_D:m017o_D:m00?o0000ojiA[_n^DJh04?n^DJh01Ol0
003o/Djaok5>/OnaC[7o000000coOh1o00?o0000ok=</oncC;<02?ncC;<00ol0003oiA[UonDJi@0:
onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000Coj1OX00?o0000okU6^OniA[T01oniA[T3o`00
0004onLHiol0003o0000o`0000GoYEZU0_l00006oimOW`?o00002_m`Sg001Ol0003oLXebog:=L_mb
SG;o000000CoJ9MX00?o0000oi]TVonKI9/04?nKI9/00ol0003o_D:moke2_@0Aoke2_@03o`000?n^
DJko[U6^017o[U6^00?o0000ok5>/Ol000003OmoP7l00ol0003o/dbcok=</`08ok=</`03o`000?oU
6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oX5nSoj1OX00Coj1OX00?o0000
okU6^OniA[T02_niA[T00ol0003oYEZUojEJY@08ojEJY@03o`000?nOGiooWenO00?o00003Om`Sg00
1Ol0003oLXebog:=L_mbSG;o000000GoJ9MX00?o0000oi]TVonKI9/03onKI9/00ol0003o_D:moke2
_@0Aoke2_@03o`000?n^DJko[U6^01;o[U6^00?o0000ogn0OomoP7l03?moP7l00ol0003o/dbcok=<
/`08ok=</`03o`000?oU6^GoiA[U00_oiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000onPGj?oX5nP01OoX5nP0
0ol0003o^DJiokU6^@0:okU6^@03o`000?nUFZGoYEZU00WoYEZU0_l0000?og2?L003o`000?mbSG;o
LXeb00;oLXeb00?o0000ofRGJ?mXUfP01?mXUfP00ol0003oVfBKoi]TV`0=oi]TV`?o00004Onm@[d0
0ol0003o[U6^ojiA[P0CojiA[P03o`000?moP7ooOh1o00_oOh1o00?o0000ok=</oncC;<02OncC;<0
0ol0003oiA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?oX5nP0
0ol0003o^DJiokU6^@0:okU6^@03o`000?nUFZGoYEZU00WoYEZU00?o0000og2?L?m`Sg003Om`Sg00
0ol0003oLXebog:=LP03og:=LP03o`000?mXUfSoJ9MX00GoJ9MX00?o0000oi]TVonKI9/02_nKI9/2
o`0000?oWf2O00?o0000oke2_Onm@[d03_nm@[d00ol0003o[U6^ojiA[P0CojiA[P03o`000?moP7oo
Oh1o00_oOh1o00?o0000ok=</oncC;<02OncC;<00ol0003oiA[UonDJi@0;onDJi@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000onPGj?oX5nP01ooX5nP2o`0000_o^DJi00?o0000ojEJ
YOnUFZD02onUFZD00ol0003oL8m`og2?L00<og2?L003o`000?mbSG;oLXeb00?oLXeb00?o0000ofRG
J?mXUfP01_mXUfP00ol0003oVfBKoi]TV`07oi]TV`;o00001_nOH9l2o`0000ko_D:m00?o0000ojiA
[_n^DJh04on^DJh00ol0003oOh1oogn0O`0;ogn0O`03o`000?ncC;?o/dbc00Wo/dbc00?o0000onDJ
iOoU6^D03?oU6^D00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009onPG
j003o`000?nkA;_o000000_o^DJi00?o0000ojEJYOnUFZD02onUFZD00ol0003oL8m`og2?L00;og2?
L003o`000?mbSG;oLXeb00CoLXeb00?o0000ofRGJ?mXUfP01omXUfP00ol0003oVfBKoi]TV`05oi]T
V`03o`000?nOH9ooWf2O00SoWf2O00?o0000oke2_Onm@[d02_nm@[d00ol0003o[U6^ojiA[P0DojiA
[P03o`000?moP7ooOh1o00_oOh1o00?o0000ok=</oncC;<02OncC;<00ol0003oiA[UonDJi@0<onDJ
i@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009onPGj004o`000?nkA;_o^dBko`00
00_o^DJi00?o0000ojEJYOnUFZD02onUFZD00ol0003oL8m`og2?L00;og2?L003o`000?mbSG;oLXeb
00CoLXeb00?o0000ofRGJ?mXUfP02?mXUfP00ol0003oVfBKoi]TV`02oi]TV`;o00003?nOH9l2o`00
00[o_D:m00?o0000ojiA[_n^DJh05?n^DJh00ol0003oOh1oogn0O`0;ogn0O`03o`000?ncC;?o/dbc
00Wo/dbc00?o0000onDJiOoU6^D03OoU6^D00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj007onPGj003
o`000?nkA;_o^dBk00;o^dBk00?o0000okU6^OniA[T02?niA[T00ol0003oYEZUojEJY@0<ojEJY@03
o`000?m`Sg3oL8m`00WoL8m`00?o0000og:=L_mbSG801OmbSG800ol0003oJ9MXofRGJ009ofRGJ004
o`000?nKI9_o0000o`00013oWf2O0_l00008oke2_@03o`000?n^DJko[U6^01Co[U6^0ol0000;ogn0
O`03o`000?ncC;?o/dbc00Wo/dbc00?o0000onDJiOoU6^D03OoU6^D01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oj1OXonPGj006onPGj003o`000?nkA;_o^dBk00?o^dBk00?o0000okU6
^OniA[T02?niA[T00ol0003oYEZUojEJY@0;ojEJY@;o00002_m`Sg000ol0003oLXebog:=LP06og:=
LP03o`000?mXUfSoJ9MX00[oJ9MX00?o0000oimPWonOH9l04_nOH9l00ol0003o_D:moke2_@04oke2
_@03o`000?n^DJko[U6^01Go[U6^00?o0000oiYUV_nJIIX01Ol00005ogn0O`03o`000?ncC;?o/dbc
00[o/dbc00?o0000onDJiOoU6^D03_oU6^D3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OXonPGj004onPGj003
o`000?nkA;_o^dBk00Co^dBk00?o0000okU6^OniA[T01oniA[T00ol0003oYEZUojEJY@0;ojEJY@04
o`000?mmPWgoOH9mo`0000WoL8m`00?o0000og:=L_mbSG801_mbSG800ol0003oJ9MXofRGJ00:ofRG
J003o`000?nOH9ooWf2O01?oWf2O0_l00003oke2_@Co00005?n^DJh00ol0003oVVFJoiYUVP06oiYU
VPCo000000?oOh1oo`000?ncC;<02oncC;<00ol0003oiA[UonDJi@0>onDJi@03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003oj1OXonPGj003onPGj003o`000?nkA;_o^dBk00Go^dBk00?o0000okU6^Oni
A[T01oniA[T00ol0003oYEZUojEJY@09ojEJY@;o00001?mmPWd00ol0003oL8m`og2?L005og2?L003
o`000?mbSG;oLXeb00OoLXeb00?o0000ofRGJ?mXUfP02_mXUfP00ol0003oWf2OoimPW`0EoimPW`03
o`000?nm@[go000000CoZeB[0ol0000@ojiA[P03o`000?nJII[oVVFJ00_oVVFJ0_l0000<ok=</`03
o`000?oU6^GoiA[U00coiA[U0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onPGj?oX5nP00_oX5nP00ol0003o^dBk
ok]4^`06ok]4^`03o`000?niA[Wo^DJi00Oo^DJi00?o0000ojEJYOnUFZD02?nUFZD00ol0003oOH9m
ogf2O@05ogf2O@03o`000?m`Sg3oL8m`00CoL8m`00?o0000og:=L_mbSG801ombSG800ol0003oJ9MX
ofRGJ00:ofRGJ003o`000?nOH9ooWf2O01KoWf2O00?o0000oj]DZon[E:/01_n[E:/3o`0000co[U6^
00?o0000oiYUV_nJIIX03OnJIIX00ol0003o/dbcok=</`09ok=</`Go00002OoU6^D2o`000003onDJ
iOl0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003onPGj?l0003o^dBk00Wo^dBk00?o0000okU6^OniA[T01_ni
A[T00ol0003oYEZUojEJY@07ojEJY@03o`000?mmPWgoOH9m00OoOH9m00?o0000og2?L?m`Sg000_m`
Sg000ol0003oLXebog:=LP08og:=LP03o`000?mXUfSoJ9MX00WoJ9MX00?o0000oimPWonOH9l05onO
H9l00ol0003oZeB[oj]DZ`09oj]DZ`?o00002On^DJh00ol0003oVVFJoiYUVP0>oiYUVPKo00001?nc
C;<00ol0003o/dbcok=</`03ok=</`Go00000_oU6^D2o`0000CoiA[U00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oI9]WofBKIomTVfOl000002onkA;/00ol0003o^DJiokU6^@06okU6^@03o`000?nU
FZGoYEZU00GoYEZU0_l0000;ogf2O@04o`000?m`Sg3oL8m`o`0000_oLXeb00?o0000ofRGJ?mXUfP0
2OmXUfP00ol0003oWf2OoimPW`0FoimPW`03o`000?n[E:_oZeB[00goZeB[0ol00005ojiA[P03o`00
0?nJII[oVVFJ00ooVVFJ00?o0000oj1OX?nPGj000onPGj04o`0000_o/dbc0_l00006onDJi@03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ofBKIomTVf@02omTVf@ko00001_niA[T00ol0003oYEZUojEJ
Y@05ojEJY@03o`000?mmPWgoOH9m00coOH9m00?o0000og2?L?l000002ombSG800ol0003oJ9MXofRG
J007ofRGJ0?o00006?nOH9l00ol0003oZeB[oj]DZ`0@oj]DZ`?o000000?o[U6^o`000?nJIIX04?nJ
IIX00ol0003oX5nPoj1OX007oj1OX003o`000?ncC;?o/dbc00[o/dbc00?o0000onDJiOoU6^D01OoU
6^D00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005omTVf@03o`000?nEJYGoUFZE00_oUFZE0_l00004
okU6^@03o`000?nUFZGoYEZU00?oYEZU0_l0000@ogf2O@03o`000?mbSG;oLXeb00[oLXeb00?o0000
ofRGJ?mXUfP00omXUfP4o`0000;oEjQG00?o0000oimPWonOH9l05OnOH9l00ol0003oZeB[oj]DZ`0D
oj]DZ`03o`000?nJII[oVVFJ013oVVFJ00?o0000oj1OX?nPGj001onPGj000ol0003o/dbcok=</`0:
ok=</`03o`000?oU6^GoiA[U00GoiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oI9]WofBKI
00GofBKI00?o0000oiEZUOnEJYD03OnEJYD6o`0000?oYEZU00?o0000ogf2OOmmPWd04?mmPWd00ol0
003oLXebog:=LP0:og:=LP03o`000?mXUfSo000000?o00001omGZ5L00ol0003oWf2OoimPW`0DoimP
W`03o`000?n[E:_oZeB[01CoZeB[00?o0000oiYUV_nJIIX03onJIIX00ol0003oX5nPoj1OX008oj1O
X003o`000?ncC;?o/dbc00[o/dbc00?o0000onDJiOoU6^D01OoU6^D00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000omTVfOoI9]T01_oI9]T00ol0003oUFZEoiEZU@0=oiEZU@03o`000?nPGj3oX5nP00?o
X5nP00?o0000ojEJYOl000004ommPWd4o`0000WoLXeb0_l0000<oeNXE`03o`000?nOH9ooWf2O01?o
Wf2O00?o0000oj]DZon[E:/05On[E:/00ol0003oVVFJoiYUVP0>oiYUVP03o`000?nPGj3oX5nP00So
X5nP00?o0000ok=</oncC;<02OncC;<00ol0003oiA[UonDJi@07onDJi@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oI9]WofBKI00SofBKI00?o0000oiEZUOnEJYD02onEJYD00ol0003oX5nPoj1OX005oj1OX003o`00
0?mmPWgoOH9m01;oOH9m00Co0000ofBKI?mTVfCoI9]T1Ol00003og:=LP03o`000?mGZ5OoEjQG00go
EjQG0ol0000@oimPW`;o00006?n[E:/00ol0003oVVFJoiYUVP0=oiYUVP03o`000?nPGj3oX5nP00Wo
X5nP00?o0000ok=</oncC;<02OncC;<00ol0003oiA[UonDJi@07onDJi@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_ofBKI00?o0000oiEZUOnEJYD02_nEJYD00ol0003oX5nPoj1OX006oj1OX003o`00
0?mmPWgoOH9m017oOH9m00?o0000ofBKI?mTVf@01omTVf@3o`00013oEjQG00?o0000oe2_D?m@[e00
1Ol00009oimPW`;o000000?oJ9MXo`000?n[E:/05on[E:/00ol0003oVVFJoiYUVP0=oiYUVP03o`00
0?nPGj3oX5nP00WoX5nP00?o0000ok=</oncC;<02?ncC;<2o`0000[oiA[U00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?o[5>_ojaC[00;ojaC[00?o0000omTVfOoI9]T02OoI9]T00ol0003oUFZEoiEZ
U@0:oiEZU@03o`000?nPGj3oX5nP00OoX5nP00?o0000ogf2OOmmPWd03ommPWd00ol0003oI9]TofBK
I00:ofBKI003o`000?mGZ5OoEjQG00goEjQG00?o0000oe2_D?m@[e001_m@[e04o`0000CoWf2O00?o
0000ofRGJ?mXUfP00_mXUfP00ol0003oZeB[oj]DZ`0Foj]DZ`03o`000?nJII[oVVFJ00_oVVFJ00?o
0000oj1OX?nPGj002onPGj000ol0003o/dbcok=</`06ok=</`03o`000?o0?l3o000000[oiA[U00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?o[5>_ojaC[00?ojaC[00?o0000omTVfOoI9]T02?oI9]T=
o`0000[oX5nP00?o0000ogf2OOmmPWd03ommPWd00ol0003oI9]TofBKI00;ofBKI003o`000?mGZ5Oo
EjQG00coEjQG00?o0000oe2_D?m@[e002_m@[e04o`0000GoJ9MX00?o0000oj]DZon[E:/05_n[E:/0
0ol0003oVVFJoiYUVP0:oiYUVP03o`000?nPGj3oX5nP00coX5nP00?o0000ok=</oncC;<01?ncC;<2
o`0000?o`3o000?o0000onDJiOoU6^D02?oU6^D00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on/D
joo[5>/00oo[5>/00ol0003ofBKIomTVf@07omTVf@03o`000?nBKI;oTVfB00WoTVfB00?o0000oj1O
X?nPGj002OnPGj000ol0003oOH9mogf2O@0=ogf2O@03o`000?mTVfCoI9]T00coI9]T00?o0000oeNX
EomGZ5L03?mGZ5L00ol0003oD:m@oe2_D00;oe2_D003o`000?lgb3Oo000000KoJ9MX00?o0000oj]D
Zon[E:/05_n[E:/00ol0003oVVFJoiYUVP09oiYUVP03o`000?nPGj3oX5nP00coX5nP00?o0000ok=<
/oncC;<00oncC;<00ol0003o`3o0ol0o`003ol0o`003o`000?oU6^GoiA[U00SoiA[U00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?o[5>_ojaC[00CojaC[00?o0000omTVfOoI9]T01_oI9]T00ol0003o
TVfBoi9]TP08oi9]TP03o`000?nPGj3oX5nP00_oX5nP00?o0000ogf2OOmmPWd02?mmPWd4o`0000oo
I9]T00?o0000oeNXEomGZ5L02omGZ5L00ol0003oD:m@oe2_D00;oe2_D004o`000?lgb3Oo=lPgo`00
00OoJ9MX00?o0000oj]DZon[E:/05On[E:/00ol0003oVVFJoiYUVP08oiYUVP03o`000?nPGj3oX5nP
00goX5nP00?o0000ok=</oncC;<00_ncC;<00ol0003o`3o0ol0o`005ol0o`003o`000?oU6^GoiA[U
00OoiA[U00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?o[5>_ojaC[00GojaC[00?o0000omTVfOoI
9]T01OoI9]T00ol0003oTVfBoi9]TP08oi9]TP03o`000?nPGj3oX5nP00_oX5nP00?o0000ogf2OOmm
PWd00ommPWd5o`0000?oI9]T00?o0000ofBKI?mTVf@03_mTVf@00ol0003oEjQGoeNXE`0:oeNXE`03
o`000?m@[e3oD:m@00[oD:m@00Go0000ocO8=olgb3Oo=lPgo`000007ofRGJ003o`000?n[E:_oZeB[
01GoZeB[00?o0000oiYUV_nJIIX02?nJIIX00ol0003oX5nPoj1OX00=oj1OX003o`000?ncC;?o/dbc
00;o00002?o0?l000ol0003oiA[UonDJi@08onDJi@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?oI9]WofBKI00Go
fBKI00?o0000oi9]T_nBKI802?nBKI800ol0003oX5nPoj1OX00<oj1OX0Go00002OmTVf@00ol0003o
I9]TofBKI00<ofBKI0;o00003?mGZ5L00ol0003oD:m@oe2_D00:oe2_D005o`000?lgb3Oo=lPgocO8
=ol000002?mXUfP00ol0003oZeB[oj]DZ`0Doj]DZ`?o00001onJIIX00ol0003oX5nPoj1OX00>oj1O
X003o`000?ncC;?o000000_o`3o000?o0000onDJiOoU6^D01_oU6^D00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000on/Djoo[5>/01Oo[5>/00ol0003ofBKIomTVf@04omTVf@03o`000?nBKI;oTVfB00Oo
TVfB00?o0000oj1OX?nPGj003?nPGj001?l0003oOX5nogj1O_l0000;ofBKI003o`000?mTVfCoI9]T
00_oI9]T00Co0000oc?<<olcc3?o00002_mGZ5L00ol0003oD:m@oe2_D00:oe2_D003o`000?lgb3Oo
=lPg00;o=lPg00?o0000ofRGJ?mXUfP01_mXUfP00ol0003oZeB[oj]DZ`0Aoj]DZ`?o00000omhQgP0
0ol0003oVVFJoiYUVP04oiYUVP03o`000?nPGj3oX5nP00goX5nP1?l0000;ol0o`003o`000?oU6^Go
iA[U00GoiA[U00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?o[5>_ojaC[00KojaC[00Co0000omTV
fOoI9]WofBKI1?l00008oi9]TP03o`000?nPGj3oX5nP00_oX5nP00?o0000ogj1O_mnPGh00_mnPGh0
0ol0003oI9]TofBKI008ofBKI003o`000?mTVfCoI9]T00[oI9]T00?o0000oc?<<olcc3<00_lcc3<0
0ol0003oEjQGoeNXE`03oeNXE`Go00002om@[e000ol0003o=lPgocO8=`03ocO8=`03o`000?mXUfSo
J9MX00OoJ9MX00?o0000oj]DZon[E:/03_n[E:/2o`0000OoN8Mh00?o0000oiYUV_nJIIX00_nJIIX0
0ol0003oX5nPoj1OX00=oj1OX003o`000?naC[7o/Dja00;o/Dja00?o0000ol0o`?o0?l002Oo0?l00
0ol0003oiA[UonDJi@03onDJi@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojaC[on/Dj`07on/D
j`?o00001?o4>l@00ol0003oTVfBoi9]TP05oi9]TP03o`000?nPGj3oX5nP00[oX5nP00?o0000ogj1
O_mnPGh00omnPGh00ol0003oI9]TofBKI009ofBKI003o`000?mTVfCoI9]T00SoI9]T00?o0000oc?<
<olcc3<01?lcc3<5o`0000Co1_T600?o0000oe2_D?m@[e002Om@[e000ol0003o=lPgocO8=`03ocO8
=`03o`000?mXUfSoJ9MX00SoJ9MX00?o0000oj]DZon[E:/02_n[E:/3o`0000[oN8Mh00Go0000oiYU
V_nJII[oVVFJo`00000>oj1OX003o`000?naC[7o/Dja00Co/Dja0_l00009ol0o`003o`000?oU6^Go
iA[U00;oiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?o[5>_ojaC[00OojaC[00?o0000ol@k
a?o4>l@01Oo4>l@00ol0003oTVfBoi9]TP03oi9]TP03o`000?nPGj3oX5nP00[oX5nP00?o0000ogj1
O_mnPGh01?mnPGh00ol0003oI9]TofBKI009ofBKI003o`000?mTVfCoI9]T00OoI9]T00?o0000oc?<
<olcc3<01Olcc3<00ol0003o1_T6o`Ki1P07o`Ki1P03o`000?m@[e3oD:m@00OoD:m@00?o0000ocO8
=olgb3L01?lgb3L00ol0003oJ9MXofRGJ008ofRGJ003o`000?n[E:_oZeB[00SoZeB[0_l0000>ogR7
N0Co00003?nPGj02o`0000Wo/Dja00?o0000ol0o`?o0?l001oo0?l001?l0003oiA[UonDJiOl0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000on/Djoo[5>/01Oo[5>/00ol0003oa3_4ol@ka007ol@ka0;o00000onBKI800ol0
003oX5nPoj1OX009oj1OX003o`000?mnPGkoOX5n00KoOX5n00?o0000ofBKI?mTVf@02OmTVf@00ol0
003oI9]TofBKI005ofBKI003o`000?lcc3?o<l`c00Ko<l`c00?o0000o`Ki1_l6n@H02?l6n@H00ol0
003oD:m@oe2_D006oe2_D003o`000?lgb3Oo=lPg00Co=lPg00?o0000ofRGJ?mXUfP02OmXUfP4o`00
00?oZeB[0ol0000@ogR7N005o`000?nl@kco_4>loka3_?l000002_nPGj000ol0003o/Djaok5>/@0:
ok5>/@Ko00000oo0?l000ol0003oiA[Uo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000on/Djoo[5>/01?o[5>/00ol0
003oa3_4ol@ka00:ol@ka004o`000?nBKI;oTVfBo`0000[oX5nP00?o0000ogj1O_mnPGh01omnPGh0
0ol0003oI9]TofBKI009ofBKI003o`000?mTVfCoI9]T00CoI9]T00?o0000oc?<<olcc3<01olcc3<0
0ol0003o1_T6o`Ki1P08o`Ki1P;o00001_m@[e000ol0003o=lPgocO8=`05ocO8=`03o`000?mXUfSo
J9MX00WoJ9MX00Co0000oeJYE_mFZEKoEZUF0ol0000BogR7N003o`000?nl@kco_4>l00?o_4>l0_l0
0006oj1OX0;o00003OnaC[400ol0003ojQGZonXEjP03onXEjPGo00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000on/Djoo[5>/00oo[5>/0
0ol0003oa3_4ol@ka00<ol@ka0;o00002_nPGj000ol0003oOX5nogj1OP08ogj1OP03o`000?mTVfCo
I9]T00[oI9]T00?o0000ofBKI?mTVf@00_mTVf@00ol0003o<l`coc?<<`08oc?<<`03o`000?l6n@Ko
1_T600Ko1_T60_l00002oc3?<003o`000?m@[e3oD:m@00;oD:m@00?o0000ocO8=olgb3L01_lgb3L0
0ol0003oJ9MXofRGJ008ofRGJ003o`000?mFZEKoEZUF00CoEZUF00?o0000ogR7N?mhQgP03omhQgP0
0ol0003o_4>loka3_006oka3_0;o00000onPGj000ol0003o/Djaok5>/@0=ok5>/@03o`000?oZ5N[o
jQGZ00OojQGZ0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003ojaC[on/Dj`02on/Dj`03o`000?o4>lCoa3_4
00koa3_400?o0000oj1OX?nPGj001onPGj000ol0003oOX5nogj1OP0:ogj1OP03o`000?mTVfCoI9]T
00WoI9]T00Go0000ofBKI?mTVfCoI9]To`00000;oc?<<`03o`000?l6n@Ko1_T600Co1_T60_l00005
oc3?<005o`000?m@[e3oD:m@oe2_D?l000002?lgb3L00ol0003oJ9MXofRGJ008ofRGJ003o`000?mF
ZEKoEZUF00GoEZUF00?o0000ogR7N?mhQgP03_mhQgP00ol0003o_4>loka3_008oka3_003o`000?nP
Gj3o000000oo/Dja00?o0000onXEj_oZ5NX02?oZ5NX01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?o[5>_ojaC[o`00017oa3_400?o0000oj1OX?nPGj001_nPGj000ol0003oOX5n
ogj1OP0;ogj1OP03o`000?mTVfCoI9]T00WoI9]T00Co0000ofBKI?mTVfCo00003?lcc3<00ol0003o
1_T6o`Ki1P02o`Ki1P;o00002?l`cc000ol0003oD:m@o`000009ocO8=`03o`000?mXUfSoJ9MX00So
J9MX00?o0000oeJYE_mFZEH01OmFZEH00ol0003oN8MhogR7N00=ogR7N003o`000?nl@kco_4>l00[o
_4>l00?o0000ok5>/OnaC[403_naC[400ol0003ojQGZonXEjP07onXEjP03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000Bol@ka003o`00
0?nPGj3oX5nP00CoX5nP00?o0000ogj1O_mnPGh03?mnPGh00ol0003oI9]TofBKI00:ofBKI0?o0000
3?lcc3<00ol0003o1_T6o`Ki1P02o`0000_o<<l`00?o0000ocO8=olgb3L02?lgb3L00ol0003oJ9MX
ofRGJ007ofRGJ003o`000?mFZEKoEZUF00OoEZUF00?o0000ogR7N?mhQgP03?mhQgP00ol0003o_4>l
oka3_00;oka3_0;o00003_naC[400ol0003ojQGZonXEjP07onXEjP03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003oa3_4ol@ka00?ol@ka0?o00000onP
Gj000ol0003oOX5nogj1OP0>ogj1OP03o`000?mTVfCoI9]T00SoI9]T00Co0000occ3??ll`cco?<<l
0_l0000:oc?<<`?o00003Ol`cc000ol0003o=lPgocO8=`08ocO8=`03o`000?mXUfSoJ9MX00OoJ9MX
00?o0000oeJYE_mFZEH01omFZEH00ol0003oN8MhogR7N00;ogR7N003o`000?nl@kco_4>l00co_4>l
00?o0000omDZeOl000000_l0000:ok5>/@03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@04ondBk@03o`000?o4>lCoa3_400coa3_40_l0
0003oj]DZ`03o`000?nPGj3o0000017oOX5n00?o0000ofBKI?mTVf@01omTVf@00ol0003o?<<locc3
?004occ3?0;o00002?lcc3<00ol0003o<<l`oc3?<00>oc3?<0;o00002?lgb3L00ol0003oJ9MXofRG
J006ofRGJ003o`000?mFZEKoEZUF00WoEZUF00?o0000ogR7N?mhQgP02OmhQgP00ol0003o_4>loka3
_00=oka3_003o`000?oE:]GoeB[E00;oeB[E0ol00007ok5>/@03o`000?oZ5N[ojQGZ00OojQGZ00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@05ondBk@03o`000?o4>lCo
a3_400Woa3_40_l00006oj]DZ`03o`000?mnPGkoOX5n013oOX5n00?o0000ofBKI?mTVf@01_mTVf@0
0ol0003o?<<locc3?007occ3?003o`000?lcc3?o<l`c00Co<l`c0ol0000>oc3?<003o`000?lKi1_o
6n@K00?o00001Olgb3L00ol0003oJ9MXofRGJ006ofRGJ003o`000?mFZEKoEZUF00[oEZUF00?o0000
ogR7N?mhQgP02?mhQgP00ol0003o_4>loka3_00=oka3_003o`000?oE:]GoeB[E00GoeB[E0ol00004
ok5>/@03o`000?oZ5N[ojQGZ00OojQGZ00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003okA;]ondBk@06ondBk@03o`000?o4>lCoa3_400Goa3_40ol00008oj]DZ`03o`000?mnPGkoOX5n
017oOX5n00Co0000ofBKI?mTVfCoI9]T1?l0000;occ3?0;o000000Co<l`co`000?l0003o00000om:
]DX2o`0000_o<<l`00?o0000oa_T6olKi1/01?lKi1/2o`0000?o=lPg00?o0000ofRGJ?mXUfP01_mX
UfP00ol0003oEZUFoeJYEP0:oeJYEP03o`000?mhQgSoN8Mh00OoN8Mh00?o0000oka3_?nl@k`03_nl
@k`00ol0003oeB[EomDZe@08omDZe@Co00002_oZ5NX00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003okA;]ondBk@07ondBk@03o`000?o4>lCoa3_400;oa3_40_l0000<oj]DZ`03o`000?mnPGko
OX5n013oOX5n1?l00003oeJYEP03o`000?ll`cco?<<l00_o?<<l00?o0000odZeB_m:]DX01_m:]DX0
0ol0003o<<l`oc3?<007oc3?<003o`000?lKi1_o6n@K00Oo6n@K3?l0000>oeJYEP03o`000?mhQgSo
N8Mh00KoN8Mh00?o0000oka3_?nl@k`03_nl@k`00ol0003oeB[EomDZe@0;omDZe@03o`000?oZ5N[o
jQGZ00OojQGZ00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00WokA;]00Co0000ol@k
a?l0003o00003_n[E:/00ol0003oOX5nogj1OP0?ogj1OP03o`000?mFZEKoEZUF00KoEZUF00?o0000
occ3??ll`c`02_ll`c`00ol0003oB[E:odZeBP07odZeBP;o00001_l`cc000ol0003o6n@Koa_T6`08
oa_T6`03o`000?m`Sg3oL8m`00SoL8m`00?o0000oeJYE_mFZEH03?mFZEH00ol0003oN8MhogR7N005
ogR7N003o`000?nl@kco_4>l00oo_4>l0_l0000=omDZe@03o`000?oZ5N[ojQGZ00KojQGZ00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00[okA;]00?o0000oj]DZon[E:/03_n[E:/00ol0
003oOX5nogj1OP0>ogj1OP03o`000?mFZEKoEZUF00OoEZUF00?o0000occ3??ll`c`02_ll`c`00ol0
003oB[E:odZeBP09odZeBP;o00000ol`cc000ol0003o6n@Koa_T6`09oa_T6`03o`000?m`Sg3oL8m`
00WoL8m`00?o0000oeJYE_mFZEH02_mFZEH4o`0000CoN8Mh00?o0000oka3_?nl@k`04?nl@k`01?l0
003odBkAo`000?l0000<omDZe@03o`000?oZ5N[ojQGZ00GojQGZ00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o]4^gokA;]00[okA;]00?o0000oj]DZon[E:/03on[E:/@o`0000[oEZUF00?o0000occ3
??ll`c`02Oll`c`00ol0003o8m`So`00000<odZeBP05o`000?l`cc3o0000oacS7?l000002_lKi1/0
0ol0003oL8m`og2?L009og2?L003o`000?mFZEKoEZUF00OoEZUF0ol00004oh5nP@?o000000?oN8Mh
o`000?nl@k`04Onl@k`01?l0003odBkAom4^dOoA;]42o`0000_oeB[E00?o0000onXEj_oZ5NX00ooZ
5NX00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003oZeB[oj]DZ`0?
oj]DZ`03o`000?n5NXGoQGZ500coQGZ500?o0000oeJYE_mFZEH02OmFZEH00ol0003o?<<locc3?007
occ3?004o`000?lSg2?o8m`So`0000goB[E:00Go0000oacS7?lLhaco7><Lo`000009oa_T6`03o`00
0?m`Sg3oL8m`00[oL8m`00?o0000oeJYE_mFZEH00omFZEH3o`0000[oPGj100?o0000oka3_?nl@k`0
4?nl@k`00ol0003odBkAom4^d@04om4^d@;o00002_oE:]D00ol0003ojQGZonXEjP04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cokA;]00?o0000oj]DZon[E:/03on[E:/00ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?mF
ZEKoEZUF00WoEZUF00?o0000occ3??ll`c`01_ll`c`00ol0003o8m`Sob?L8`02ob?L8`03o`000?m:
]D[oB[E:00[oB[E:00?o0000oacS7?lLha`00_lLha`00ol0003o6n@Koa_T6`06oa_T6`03o`000?m`
Sg3oL8m`00[oL8m`00?o0000oeJYE_mFZEH00ol0000=oh5nP@03o`000?nl@kco_4>l013o_4>l00?o
0000om4^dOoA;]401_oA;]42o`0000WoeB[E0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003oZeB[oj]DZ`0=oj]DZ`?o00003on5NXD0
0ol0003oEZUFoeJYEP08oeJYEP03o`000?ll`cco?<<l00Go?<<l00?o0000ob?L8olSg2<00olSg2<0
0ol0003oB[E:odZeBP0:odZeBP03o`000?lLhaco7><L00?o7><L00?o0000oa_T6olKi1/01OlKi1/0
0ol0003oL8m`og2?L00;og2?L0;o00004On1OX400ol0003o_4>loka3_00?oka3_003o`000?oA;]7o
dBkA00SodBkA0_l00007omDZe@03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000ondBkOo]4^d02?o]4^d00ol0003oZeB[oj]DZ`09oj]DZ`Go00000_miQWT00ol0
003oQGZ5ohEjQ@0=ohEjQ@03o`000?mFZEKoEZUF00WoEZUF00?o0000occ3??ll`c`01?ll`c`00ol0
003o8m`Sob?L8`04ob?L8`03o`000?m:]D[oB[E:00SoB[E:00?o0000oacS7?lLha`01OlLha`00ol0
003o6n@Koa_T6`04oa_T6`03o`000?m`Sg3oL8m`00_oL8m`00?o0000oh5nPOn1OX404?n1OX400ol0
003o_4>loka3_00?oka3_003o`000?oA;]7odBkA00[odBkA0_l00004omDZe@03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003okA;]ondBk@07ondBk@03o`000?n[E:_oZeB[00CoZeB[1Ol00007ogV6N@03
o`000?n5NXGoQGZ500goQGZ500?o0000oeJYE_mFZEH02OmFZEH00ol0003o?<<locc3?003occ3?003
o`000?lSg2?o8m`S00Go8m`S00?o0000odZeB_m:]DX02?m:]DX00ol0003o7><LoacS7006oacS7003
o`000?lKi1_o6n@K00?o6n@K00?o0000og2?L?m`Sg002om`Sg000ol0003oPGj1oh5nP@0@oh5nP@03
o`000?nl@kco_4>l00oo_4>l00?o0000om4^dOoA;]403?oA;]42o`000003omDZeOl0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00OokA;]00?o0000oj]DZol00000
1?l0000<ogV6N@03o`000?n5NXGoQGZ500koQGZ500?o0000oeJYE_mFZEH02?mFZEH00ol0003o?<<l
occ3?002occ3?003o`000?lSg2?o8m`S00Oo8m`S00?o0000odZeB_m:]DX01om:]DX00ol0003o7><L
oacS7007oacS7003o`000?lKi1_o6n@K00;o6n@K00?o0000og2?L?m`Sg002om`Sg000ol0003oPGj1
oh5nP@0Aoh5nP@03o`000?nl@kco_4>l00go_4>l00?o0000om4^dOoA;]403ooA;]400ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000ondBkOo]4^d01Oo]4^d3o`00017oNHIi00?o0000ohEjQOn5NXD03_n5
NXD00ol0003oEZUFoeJYEP09oeJYEP04o`000?ll`cco?<<lo`0000[o8m`S00?o0000odZeB_m:]DX0
1om:]DX00ol0003o7><LoacS7008oacS7005o`000?lKi1_o6n@Koa_T6ol000003Om`Sg000ol0003o
PGj1oh5nP@0Aoh5nP@?o00003Onl@k`00ol0003odBkAom4^d@0?om4^d@03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_o]4^d2o`0000;o`cc300?o0000ogV6NOmiQWT03omiQWT00ol0003o
QGZ5ohEjQ@0>ohEjQ@03o`000?mFZEKoEZUF00SoEZUF1Ol0000;ob?L8`03o`000?m:]D[oB[E:00Ko
B[E:00?o0000oacS7?lLha`02OlLha`01?l0003o6n@Koa_T6ol0000=og2?L003o`000?n1OX7oPGj1
017oPGj100?o0000of6NHOmQWV400ol0000:oka3_0Co00003OoA;]400ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000on/Djoo[5>_ojaC[0_l00005ol<l``03o`000?miQWWoNHIi00koNHIi00?o0000ohEj
QOn5NXD03_n5NXD00ol0003oEZUFoeJYEP07oeJYEP03o`000?mA[U7oDJiA00?oDJiA00?o0000ob?L
8olSg2<02?lSg2<00ol0003oB[E:odZeBP05odZeBP03o`000?lLhaco7><L00[o7><L1Ol0000<og2?
L003o`000?n1OX7oPGj1013oPGj100?o0000of6NHOmQWV401?mQWV43o`0000Ko_4>l00?o0000om</
dooC;=<00_oC;=<5o`0000SodBkA00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o[5>_ojaC[00?o
jaC[00?o0000ol<l`oo3?<<01?o3?<<00ol0003oNHIiogV6N@0=ogV6N@03o`000?n5NXGoQGZ500oo
QGZ500?o0000oeJYE_mFZEH01?mFZEH2o`0000OoDJiA00?o0000ob?L8olSg2<01olSg2<Eo`0000Go
:]DZ00?o0000og2?L?m`Sg002?m`Sg03o`00013oPGj100?o0000of6NHOmQWV402?mQWV43o`0000;o
_4>l00?o0000om</dooC;=<02?oC;=<5o`0000?odBkA00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?o[5>_ojaC[00CojaC[00?o0000ol<l`oo3?<<01Oo3?<<00ol0003oNHIiogV6N@0;ogV6N@Co0000
3on5NXD00ol0003oEZUFoeJYEP03oeJYEP03o`000?mA[U7oDJiA00SoDJiA00?o0000ob?L8olSg2<0
1?lSg2<2o`0000SoDJiA00?o0000ock1?_ln`Ch02?ln`Ch00ol0003o:]DZob[E:P05ob[E:P;o0000
1_m`Sg02o`0000?oHYeR00?o0000oh5nPOn1OX403?n1OX400ol0003oHIiQof6NH@0<of6NH@;o0000
4?oC;=<3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?o3?<?o`cc300Ko`cc300?o
0000ogV6NOmiQWT02OmiQWT00ol0003oLHiao`000002of6NH@?o00003?n5NXD01?l0003oEZUFoeJY
E_mFZEH2o`0000coDJiA00?o0000ob?L8olSg2<00_lSg2<00ol0003oDJiAoe6^D@08oe6^D@03o`00
0?ln`Cko?/4n00So?/4n00?o0000ob[E:_lZeBX01olZeBX00ol0003oL8m`og2?L002og2?L003o`00
0?mRWF;oHYeR00CoHYeR0_l0000;oh5nP@03o`000?mQWV7oHIiQ00coHIiQ00?o0000oi5^TOl00000
4_oC;=<00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003ojaC[on/Dj`06on/Dj`03o`000?o3?<?o`cc300Oo`cc300?o
0000ogV6NOmiQWT01_miQWT2o`0000;oLHia00?o0000of6NHOmQWV400omQWV43o`0000[oQGZ500?o
0000oeJYE_l000003omA[U401?l0003o8m`So`000?l0000;oe6^D@03o`000?ln`Cko?/4n00So?/4n
00?o0000ob[E:_lZeBX02?lZeBX01?l0003oL8m`o`000?l00009of:MHP03o`000?n1OX7oPGj100Oo
PGj100?o0000of6NHOmQWV403?mQWV401?l0003oTFjAoi5^TOl0000Com</d`03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000on/Djoo[5>/01oo[5>/00ol0003o`cc3ol<l``08ol<l``03o`000?miQWWoNHIi00Co
NHIi00?o0000og6>LOmaSW400omaSW400ol0003oHIiQof6NH@05of6NH@?o00001_n5NXD4o`00013o
DJiA00?o0000oe6^DOmA[U403?mA[U400ol0003o?/4nock1?P07ock1?P03o`000?lZeB[o:]DZ00Wo
:]DZ00?o0000of:MH_mRWF802_mRWF82o`0000KoPGj100?o0000of6NHOmQWV403?mQWV400ol0003o
TFjAoi5^T@02oi5^T@03o`000?oC;=?odbcC00oodbcC00?o0000onLHiol000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003ojaC[on/Dj`08on/Dj`03o`000?o3?<?o`cc300Wo`cc300Co0000ogV6NOmiQWWo
NHIi0_l00006og6>L@03o`000?mQWV7oHIiQ00SoHIiQ0ol000000on5NXGo0000o`000004oejQGP03
o`000?mA[U7oDJiA00goDJiA00?o0000oe6^DOmA[U403?mA[U400ol0003o?/4nock1?P07ock1?P03
o`000?lZeB[o:]DZ00Wo:]DZ00?o0000of:MH_mRWF803?mRWF800ol0003oPGj1oh5nP@03o`0000ko
HIiQ00?o0000oi5^TOnAKY400onAKY400ol0003odbcCom</d`0>om</d`05o`000?oW6>OoiaSWonLH
iol000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003ojaC[on/Dj`09on/Dj`03o`000?o3?<?o`cc300[o
`cc300?o0000ogV6NOl000002?maSW400ol0003oHIiQof6NH@0;of6NH@03o`000?mNXEkoGZ5N00Go
GZ5N00?o0000oe6^DOmA[U403?mA[U400ol0003oDJiAoe6^D@0<oe6^D@03o`000?ln`Cko?/4n00Oo
?/4n00?o0000ob[E:_lZeBX02?lZeBX2o`0000ooHYeR0_l00002og6>L@03o`000?mQWV7oHIiQ00_o
HIiQ00?o0000oi5^TOnAKY401?nAKY400ol0003odbcCom</d`0=om</d`03o`000?oW6>OoiaSW00?o
iaSW00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on/Dj`03o`000?o3?<?o`cc300_o`cc300?o0000og6>LOmaSW40
1omaSW400ol0003oHIiQof6NH@0;of6NH@03o`000?mNXEkoGZ5N00KoGZ5N00?o0000oe6^DOmA[U40
2omA[U42o`0000goDJiA00?o0000ock1?_ln`Ch01oln`Ch00ol0003o:]DZob[E:P07ob[E:P04o`00
0?lgb3Oo=lPgo`0000koHYeR00?o0000og6>LOmaSW400_maSW400ol0003oHIiQof6NH@09of6NH@03
o`000?nAKY7oTFjA00KoTFjA00?o0000om</dooC;=<02ooC;=<00ol0003oiaSWonLHi`05onLHi`04
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000SojaC[00?o0000ol<l`oo3?<<02_o3?<<2o`0000Wo
LHia00?o0000of6NHOmQWV402omQWV400ol0003oGZ5NoejQGP07oejQGP03o`000?mA[U7oDJiA00Wo
DJiA00Co0000oa[U6_lJiA[o00003?mA[U400ol0003o?/4nock1?P07ock1?P03o`000?lZeB[o:]DZ
00Ko:]DZ00Go0000ocO8=olgb3Oo=lPgo`00000>of:MHP03o`000?maSW7oLHia00?oLHia00?o0000
of6NHOmQWV401omQWV400ol0003oTFjAoi5^T@07oi5^T@03o`000?oC;=?odbcC00[odbcC00?o0000
onLHiooW6>L01ooW6>L00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006on/Dj`03o`000?o3?<?o`cc3
00Wo`cc300Co0000ojQGZ?nXEjSo00002OmaSW400ol0003oHIiQof6NH@09of6NH@03o`000?mNXEko
GZ5N00WoGZ5N00?o0000oe6^DOmA[U401omA[U400ol0003o6^DJoa[U6P02oa[U6P03o`000?mA[U7o
DJiA00WoDJiA00?o0000ock1?_ln`Ch01oln`Ch00ol0003o:]DZob[E:P05ob[E:P03o`000?lgb3Oo
=lPg00?o=lPg00?o0000of:MH_mRWF802_mRWF800ol0003oLHiaog6>L@05og6>L@03o`000?mQWV7o
HIiQ00GoHIiQ00?o0000oi5^TOnAKY402?nAKY400ol0003odbcCom</d`09om</d`03o`000?oW6>Oo
iaSW00SoiaSW00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_o[5>/3o`0000Wo`cc300?o0000ojQG
Z?nXEjP00_nXEjP00ol0003oLHiaog6>L@06og6>L@03o`000?mQWV7oHIiQ00WoHIiQ00?o0000oejQ
G_mNXEh02_mNXEh00ol0003oDJiAoe6^D@05oe6^D@03o`000?lJiA[o6^DJ00Co6^DJ00?o0000oe6^
DOmA[U402?mA[U400ol0003o?/4nock1?P07ock1?P03o`000?lZeB[o:]DZ00Co:]DZ00?o0000ocO8
=olgb3L01?lgb3L00ol0003oHYeRof:MHP0:of:MHP03o`000?maSW7oLHia00KoLHia00?o0000of6N
HOmQWV400omQWV400ol0003oTFjAoi5^T@09oi5^T@03o`000?oC;=?odbcC00SodbcC00?o0000onLH
iooW6>L02OoW6>L00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003on<Lh`?o00001Oo3?<<00ol0003o
Z5NXojQGZ003ojQGZ003o`000?maSW7oLHia00KoLHia00?o0000of6NHOmQWV402OmQWV400ol0003o
GZ5NoejQGP0;oejQGP03o`000?mA[U7oDJiA00?oDJiA00?o0000oa[U6_lJiAX01_lJiAX00ol0003o
DJiAoe6^D@08oe6^D@03o`000?ln`Cko?/4n00Ko?/4n00?o0000ob[E:_lZeBX00_lZeBX2o`0000So
=lPg00?o0000of:MH_mRWF802OmRWF800ol0003oLHiaog6>L@07og6>L@05o`000?mQWV7oHIiQof6N
HOl000003OnAKY400ol0003odbcCom</d`06om</d`03o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oS7>?ohacS00GohacS0ol000000oo3?<?o0000ojQGZ006ojQGZ003
o`000?maSW7oLHia00GoLHia00?o0000of6NHOmQWV402OmQWV400ol0003oGZ5NoejQGP0<oejQGP05
o`000?mA[U7oDJiAoe6^DOl000002_lJiAX00ol0003oDJiAoe6^D@07oe6^D@03o`000?ln`Cko?/4n
00Ko?/4n00?o0000ob[E:_l000000_l000000om/Tfco0000ocO8=`07ocO8=`03o`000?mRWF;oHYeR
00SoHYeR00?o0000og6>LOmaSW402OmaSW400ol0003oHIiQo`00000=oi5^T@Co00001OoC;=<00ol0
003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohacSon<Lh`08on<Lh`03
o`000?nXEjSoZ5NX00OoZ5NX00?o0000og6>LOmaSW401?maSW400ol0003oHIiQof6NH@09of6NH@03
o`000?mNXEkoGZ5N00goGZ5N00?o0000oe6^DOl000003?lJiAX:o`0000Oo?/4n0ol00005ofbCK003
o`000?lgb3Oo=lPg00Ko=lPg00?o0000of:MH_mRWF801omRWF800ol0003oLHiaog6>L@0:og6>L@03
o`000?nAKY7oTFjA00_oTFjA00?o0000olHia_o6>LH00_o6>LH3o`000003om</dol0003oiaSW00_o
iaSW0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000on<LhooS7><02OoS7><00ol0003oZ5NXojQGZ007ojQGZ003o`00
0?maSW7oLHia00GoLHia00?o0000of6NHOmQWV401omQWV400ol0003oGZ5NoejQGP0?oejQGP;o0000
2olJiAX00ol0003oGZ5NoejQGP07oejQGP03o`000?ln`Cko?/4n00;o?/4n0ol00008ofbCK003o`00
0?lgb3Oo=lPg00Ko=lPg00?o0000of:MH_mRWF801omRWF800ol0003oLHiaog6>L@0:og6>L@03o`00
0?nAKY7oTFjA00[oTFjA00?o0000olHia_o6>LH01_o6>LH00ol0003oiaSWonLHi`08onLHi`?o0000
0_o]4^d00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on<LhooS7><02OoS7><00ol0003oZ5NXojQG
Z008ojQGZ003o`000?maSW7oLHia00CoLHia00?o0000of6NHOmQWV401omQWV400ol0003oGZ5NoejQ
GP0>oejQGP04o`000?l]dRgo;M8]o`0000Wo6^DJ00?o0000oejQG_mNXEh02OmNXEh01?l0003o?/4n
o`000?l0000<ofbCK003o`000?lgb3Oo=lPg00Ko=lPg00?o0000of:MH_mRWF801_mRWF800ol0003o
LHiaog6>L@0;og6>L@03o`000?nAKY7oTFjA00OoTFjA0_l00009olHiaP03o`000?oW6>OoiaSW00Co
iaSW1?l00006ondBk@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohacSon<Lh`09on<Lh`03o`00
0?nXEjSoZ5NX00SoZ5NX00?o0000og6>LOmaSW400omaSW4>o`0000goGZ5N00?o0000obgB;Ol]dRd0
0_l]dRd00ol0003o6^DJoa[U6P05oa[U6P03o`000?mNXEkoGZ5N00_oGZ5N00?o0000ofbCK?m/Tf`0
3?m/Tf`00ol0003o=lPgocO8=`06ocO8=`03o`000?mRWF;oHYeR00GoHYeR00?o0000og6>LOmaSW40
3?maSW400ol0003oTFjAoi5^T@06oi5^T@03o`000?o6>LKoaSW600[oaSW600?o0000onLHiooW6>L0
0ol0000:ondBk@?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000ojQGZ?nXEjP02?nX
EjP01Ol0003oLHiaog6>LOmaSW7o000000_oH9mP00?o0000oa3_4?l@ka000ol00009oejQGP03o`00
0?l]dRgo;M8]00Co;M8]00?o0000oa[U6_lJiAX00olJiAX00ol0003oGZ5NoejQGP0<oejQGP03o`00
0?m/TfcoK9=/00goK9=/00?o0000ocO8=olgb3L01_lgb3L00ol0003oHYeRof:MHP03of:MHP?o0000
3OmaSW400ol0003oTFjAoi5^T@05oi5^T@03o`000?o6>LKoaSW600coaSW60_l0000=ondBk@03o`00
0?ol0ocoo0?l00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000ojQGZ?nXEjP02?nX
EjP4o`0000coH9mP00?o0000oa3_4?l@ka000ol@ka03o`0000GoGZ5N00?o0000obgB;Ol]dRd01_l]
dRd01Ol0003o6^DJoa[U6_lJiA[o000000ooGZ5N00?o0000ofbCK?m/Tf`03Om/Tf`00ol0003o=lPg
ocO8=`06ocO8=`03o`000?mRWF;oHYeR00?o00000olo`3l00ol0003oLHiaog6>L@0;og6>L@03o`00
0?nAKY7oTFjA00?oTFjA00?o0000olHia_o6>LH03Oo6>LH00ol0003okA;]ondBk@0;ondBk@03o`00
0?ol0ocoo0?l00Coo0?l0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000on<LhooS7><02_oS7><3o`0000KoZ5NX0ol0
0003oi=/T`03o`000?mPWf3oH9mP00[oH9mP00?o0000oa3_4?l@ka001_l@ka03o`000003oejQG_l0
003o;M8]00Wo;M8]00?o0000oa[U6_l000004?mNXEh00ol0003oK9=/ofbCK00=ofbCK003o`000?lg
b3Oo=lPg00Oo=lPg0_l00007oco0?`03o`000?maSW7oLHia00[oLHia00Co0000oi5^TOnAKY7oTFjA
0ol0000?olHiaP03o`000?o]4^gokA;]00_okA;]00?o0000oo`3o?ol0o`01ool0o`4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on<LhooS7><02_oS
7><01?l0003od2o@om0_d?o@;m02o`000004ojQGZ?l0003o0000o`0000KoTfbC00?o0000of2OH?mP
Wf002_mPWf000ol0003o4>l@oa3_4009oa3_4003o`000?l]dRgo;M8]00[o;M8]00?o0000oejQG_mN
XEh03omNXEh00ol0003oK9=/ofbCK00>ofbCK003o`000?lgb3Oo=lPg00Ko=lPg00?o0000oco0?olo
`3l01olo`3l4o`0000SoLHia00Co0000oi5^TOnAKY7o00000on:MHX2o`0000goaSW600?o0000ondB
kOo]4^d02_o]4^d00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on<LhooS7><02OoS7><00ol0003o
d2o@om0_d004om0_d003o`000?nCK9?oTfbC00OoTfbC00?o0000of2OH?mPWf002OmPWf000ol0003o
4>l@oa3_400:oa3_4003o`000?l]dRgo;M8]00[o;M8]00?o0000oejQG_mNXEh03omNXEh00ol0003o
K9=/ofbCK00>ofbCK003o`000?lgb3Oo=lPg00Go=lPg00?o0000oco0?olo`3l02?lo`3l01?l0003o
GZ5NoejQG_mNXEh7o`0000;oLHia0_l00006ohYeRP;o00003?o6>LH00ol0003okA;]ondBk@09ondB
k@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ohacSon<Lh`08on<Lh`03o`000?o@;m3od2o@00Go
d2o@00?o0000oi=/TonCK9<02?nCK9<00ol0003oH9mPof2OH008of2OH003o`000?l@ka3o4>l@00[o
4>l@00?o0000obgB;Ol]dRd02ol]dRd00ol0003oGZ5NoejQGP0>oejQGP03o`000?m/TfcoK9=/00ko
K9=/1Ol00002ocO8=`03o`000?lo`3oo?l0o00Wo?l0o00?o0000oejQG_mNXEh02?mNXEh3o`0000Wo
RWF:0_l0000:olHiaP03o`000?o]4^gokA;]00SokA;]00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oS7>?ohacS00SohacS00?o0000om0_d?o@;m001oo@;m000ol0003oTfbCoi=/T`07oi=/T`03o`00
0?mPWf3oH9mP00SoH9mP00?o0000oa3_4?l@ka002_l@ka000ol0003o;M8]obgB;@0:obgB;@;o0000
3_mNXEh3o`0000goK9=/0ol00005og6>L@;o00002olo`3l00ol0003oGZ5NoejQGP0;oejQGP;o0000
2_n:MHX2o`0000OoaSW60ol00009ondBk@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:om0_d003o`00
0?nCK9?oTfbC00OoTfbC00?o0000of2OH?mPWf002?mPWf0>o`0000Wo;M8]0ol000000ol?l0oo0000
oejQGP0:oejQGP?o00000_mfRGH00ol0003oK9=/ofbCK009ofbCK0;o00002OmaSW400ol0003o?l0o
oco0?`09oco0?`03o`000?mNXEkoGZ5N00_oGZ5N00?o0000og^4Nol000002on:MHX2o`0000CoaSW6
00Co0000on8Mh_oR7N;ohQgR0_l00007ondBk@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003od2o@
om0_d009om0_d003o`000?nCK9?oTfbC00KoTfbC00?o0000of2OH?mPWf002?mPWf000ol0003o7N8M
oagR7@0:oagR7@03o`000?l]dRgo;M8]00Co;M8]0ol00005o`o`3`03o`000?mNXEkoGZ5N00CoGZ5N
1?l00006ogJ9MP03o`000?m/TfcoK9=/00KoK9=/0_l0000;og6>L@03o`000?lo`3oo?l0o00Wo?l0o
00?o0000oejQG_mNXEh02_mNXEh01Ol0003oNhAkog^4NomkQ7_o000000coRWF:0_l000000oo6>LKo
0000on8MhP05on8MhP03o`000?o]4^gokA;]00?okA;]00?o0000oo`3o?ol0o`02ool0o`00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?o@;m3od2o@00Sod2o@00?o0000oi=/TonCK9<01_nCK9<00ol0003oH9mPof2OH007of2OH003o`00
0?lMhQgo7N8M00_o7N8M00?o0000obgB;Ol]dRd00_l]dRd2o`0000Wo3o0?00?o0000oejQG_mNXEh0
0ol0000;ogJ9MP03o`000?m/TfcoK9=/00;oK9=/0ol0000>og6>L@03o`000?lo`3oo?l0o00Oo?l0o
00?o0000oejQG_mNXEh02omNXEh00ol0003oNhAkog^4N`02og^4N`03o`000?n:MH[oRWF:00_oRWF:
00?o0000on8Mh_oR7N801_oR7N82o`0000?okA;]00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o@
;m3od2o@00Ood2o@00?o0000oi=/TonCK9<01onCK9<00ol0003oH9mPof2OH005of2OH0?o00003OlM
hQd4o`0000_o3o0?0ol0000?ogJ9MP04o`000?m/Tfco0000o`00017oLHia00?o0000oco0?olo`3l0
1olo`3l00ol0003oGZ5NoejQGP0:oejQGP03o`000?mkQ7_oNhAk00CoNhAk00?o0000ohYeR_n:MHX0
1on:MHX3o`0000_ohQgR1?l0000=oo`3o003o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om0_d?o@;m002?o@;m000ol0003oTfbCoi=/
T`06oi=/T`03o`000?mPWf3oH9mP00;oH9mP0ol00003odFjA@03o`000?lMhQgo7N8M00[o7N8M00?o
0000o`o`3ol?l0l02ol?l0l00ol0003o6^DJo`00000AogJ9MP03o`000?maSW7oLHia017oLHia00?o
0000oco0?olo`3l01olo`3l00ol0003oGZ5NoejQGP0:oejQGP03o`000?mkQ7_oNhAk00GoNhAk00Co
0000ohYeR_n:MH[oRWF:1Ol00002oieRW@03o`000?oR7N;ohQgR00WohQgR00Co0000oo`3o?ol0oco
o0?l0ol00009oo`3o003o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000om0_d?o@;m001oo@;m000ol0003oTfbCoi=/T`05oi=/T`?o0000
00?oH9mPo`000?l000001om5^TD00ol0003o7N8MoagR7@08oagR7@?o00002_l?l0l2o`0000;o6^DJ
00?o0000ogJ9M_mfRGH03omfRGH00ol0003oLHiaog6>L@0Aog6>L@03o`000?lo`3oo?l0o00Oo?l0o
00?o0000oejQG_mNXEh02OmNXEh00ol0003oNhAkog^4N`07og^4N`?o00001onMHYd00ol0003ohQgR
on8MhP09on8MhP03o`000?ol0ocoo0?l00Coo0?l0_l00007oo`3o003o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000om0_d?o@;m001oo@
;m04o`0000;oTfbC0_l00003oiA[U003o`000?m5^TGoAKY500SoAKY50_l00006oagR7@;o00000olS
g2<00ol0003o3o0?o`o`3`06o`o`3`03o`000?lJiA[o6^DJ00?o6^DJ00?o0000ogJ9M_mfRGH03_mf
RGH00ol0003oLHiaog6>L@0Bog6>L@03o`000?lo`3oo?l0o00Go?l0o00?o0000oejQG_mNXEh02OmN
XEh00ol0003oNhAkog^4N`08og^4N`03o`000?nMHYgoWF:M00OoWF:M00?o0000on8Mh_oR7N802?oR
7N800ol0003oo0?loo`3o007oo`3o0;o00001Ool0o`00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o@;m3od2o@00Cod2o@0_l00004
omXUfP;o00001OnDJi@00ol0003oAKY5odFjA@0:odFjA@03o`000?lMhQgo7N8M00;o7N8M00?o0000
ob?L8olSg2<01?lSg2<00ol0003o3o0?o`o`3`04o`o`3`03o`000?lJiA[o6^DJ00Co6^DJ00?o0000
ogJ9M_mfRGH03_mfRGH00ol0003oLHiaog6>L@0Bog6>L@[o00002_mNXEh00ol0003oNhAkog^4N`08
og^4N`03o`000?nMHYgoWF:M00OoWF:M00?o0000on8Mh_oR7N802?oR7N800ol0003oo0?loo`3o009
oo`3o0?o000000?oo0?lo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003od2o@om0_d?o@;m02o`0000OofRGJ00?o0000oiA[U?nDJi@01?nDJi@0
0ol0003oAKY5odFjA@0:odFjA@04o`000?lMhQgo0000o`0000So8m`S00Co0000o`o`3ol?l0oo3o0?
0_l00007oa[U6P03o`000?mfRGKoMXUf00koMXUf00?o0000og6>LOmaSW404_maSW400ol0003oDZeB
oe:]DP07oe:]DP03o`000?mNXEkoGZ5N00KoGZ5N00?o0000og^4NomkQ7/02_mkQ7/00ol0003oWF:M
oieRW@06oieRW@03o`000?oR7N;ohQgR00SohQgR00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?o@
;m3o0000o`0000WofRGJ00?o0000oiA[U?nDJi@01?nDJi@00ol0003oAKY5odFjA@0;odFjA@03o`00
0?lSg2?o8m`S00Wo8m`S00?o0000o`o`3ol000002OlJiAX00ol0003oMXUfogJ9MP0>ogJ9MP;o0000
4_maSW400ol0003oDZeBoe:]DP09oe:]DP;o00001_mNXEh00ol0003oNhAkog^4N`0:og^4N`03o`00
0?nMHYgoWF:M00KoWF:M00?o0000on8Mh_oR7N802?oR7N800ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omXUf_oJ9MX02OoJ9MX00ol0003oU6^DoiA[U005oiA[U003o`000?m5^TGoAKY500[oAKY500?o
0000ob?L8olSg2<02_lSg2<2o`0000Wo6^DJ00?o0000ogJ9M_mfRGH03_mfRGH00ol0003oG:=Lo`00
0002o`0000ooLHia00?o0000oe:]D_mB[E802omB[E800ol0003oGZ5NoejQGP03o`0000goNhAk00?o
0000oieRWOnMHYd01_nMHYd00ol0003ohQgRon8MhP07on8MhP03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ofRGJomXUfP09omXUfP03o`000?nDJiCoU6^D00GoU6^D00?o0000odFjAOm5^TD02Om5^TD2
o`0000_o8m`S0_l0000;oa[U6P03o`000?mfRGKoMXUf00coMXUf00?o0000oebSG?mLXe`00omLXe`3
o`0000coLHia00?o0000oe:]D_mB[E803?mB[E82o`0000;oIiQW00?o0000og^4NomkQ7/03?mkQ7/0
0ol0003oWF:MoieRW@05oieRW@03o`000?oR7N;ohQgR00OohQgR00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oiA[U?nDJi@01_nDJi@00ol0003oAKY5odFjA@07odFj
A@03o`000?lhacSo000000[o8m`S00Co0000oa;]4_lBkA;o00002_lJiAX00ol0003oMXUfogJ9MP0<
ogJ9MP03o`000?mLXecoG:=L00KoG:=L0_l00008og6>L@;o00003omB[E800ol0003oIiQWofNHI`02
ofNHI`03o`000?mkQ7_oNhAk00_oNhAk00?o0000oieRWOnMHYd01OnMHYd00ol0003ohQgRon8MhP07
on8MhP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ofRGJomXUfP0:omXUfP03o`000?nDJiCoU6^D
00KoU6^D00?o0000odFjAOm5^TD01_m5^TD01Ol0003o><LhocS7>?lhacSo000000So8m`S00?o0000
oa;]4_lBkA800_lBkA800ol0003o6^DJoa[U6P06oa[U6PCo00003?mfRGH00ol0003oG:=LoebSG008
oebSG0?o00000_maSW43o`000003odbcC?l0003oDZeB00goDZeB00?o0000ofNHIomWV6L01?mWV6L0
0ol0003oNhAkog^4N`0:og^4N`03o`000?nMHYgoWF:M00GoWF:M00?o0000on8Mh_oR7N801_oR7N80
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omXUf_oJ9MX02ooJ9MX00ol0003oU6^DoiA[U007oiA[
U003o`000?m5^TGoAKY500?oAKY50_l00005ocS7>003o`000?lSg2?o8m`S00Co8m`S00?o0000oa;]
4_lBkA800olBkA800ol0003o6^DJoa[U6P05oa[U6P03o`000?liaSWo>LHi00;o>LHi0ol00007ogJ9
MP;o00003_mLXe`2o`0000GoC;=<00?o0000oe:]D_mB[E802_mB[E800ol0003oIiQWofNHI`05ofNH
I`03o`000?mkQ7_oNhAk00_oNhAk00?o0000oieRWOnMHYd01?nMHYd00ol0003ohQgRon8MhP06on8M
hP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ofRGJomXUfP0;omXUfP03o`000?nDJiCoU6^D00Oo
U6^D00?o0000odFjAOm5^TD00_m5^TD00ol0003o><LhocS7>006ocS7>003o`000?lSg2?o8m`S00;o
8m`S00?o0000oa;]4_lBkA801OlBkA800ol0003o6^DJoa[U6P02oa[U6P;o00002?liaST3o`0000;o
MXUf0_l000000om3_4?o0000oebSG00=oebSG003o`000?m</dcoC;=<00GoC;=<00?o0000oe:]D_mB
[E802?mB[E800ol0003oIiQWofNHI`07ofNHI`03o`000?mkQ7_oNhAk00[oNhAk00?o0000oieRWOnM
HYd01?nMHYd00ol0003ohQgRon8MhP06on8MhP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ofRGJ
omXUfP0<omXUfP03o`000?nDJiCoU6^D00SoU6^D00Co0000odFjAOm5^TGo00002OlhacP01Ol0003o
8m`Sob?L8olSg2?o000000So4^dB00Go0000oa[U6_lJiA[o6^DJo`00000=ocW6>@;o00001?m3_4<0
0ol0003oG:=LoebSG00;oebSG003o`000?m</dcoC;=<00KoC;=<00?o0000oe:]D_mB[E801omB[E80
0ol0003oIiQWofNHI`08ofNHI`Co00002?mkQ7/00ol0003oWF:MoieRW@04oieRW@03o`000?oR7N;o
hQgR00KohQgR00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oJ9M[ofRGJ00_ofRGJ0ol00009oiA[
U003o`000?m5^TGo000000_o><Lh00?o0000ob?L8ol000002_lBkA800ol0003o6^DJo`00000?ocW6
>@03o`000?m3_4?o@ka300;o@ka300?o0000oebSG?mLXe`02omLXe`00ol0003oC;=<odbcC006odbc
C003o`000?mB[E;oDZeB00KoDZeB00?o0000ofNHIomWV6L02OmWV6L01?l0003oU6^DoiA[U?nDJi@7
o`0000;oNhAk00?o0000oieRWOnMHYd00onMHYd00ol0003ohQgRon8MhP05on8MhP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oJ9M[ofRGJ00SofRGJ0ol00003ol`cc003o`000?nDJiCoU6^D00OoU6^D00?o0000ocS7
>?lhacP02olhacP00ol0003o4^dBoa;]4P0:oa;]4P03o`000?liaSWo>LHi00go>LHi00?o0000od>l
@om3_4<01?m3_4<00ol0003oG:=LoebSG009oebSG003o`000?m</dcoC;=<00SoC;=<00?o0000oe:]
D_mB[E800omB[E82o`0000coIiQW00?o0000oiA[U?nDJi@02?nDJi@<o`0000?ohQgR0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omXUf_oJ9MX01_oJ9MX3o`0000Ooc3?<00?o0000oiA[U?nDJi@01_nDJi@00ol0003o
><LhocS7>00;ocS7>003o`000?lBkA;o4^dB00Wo4^dB0_l0000>ocW6>@03o`000?m3_4?o@ka300Go
@ka300?o0000oebSG?mLXe`02OmLXe`00ol0003oC;=<odbcC009odbcC003o`000?mB[E;o000000;o
00000_mMXUd00ol0003oIiQWofNHI`08ofNHI`03o`000?nDJiCoU6^D00coU6^D00?o0000omlPgooO
8=l01_oO8=l3o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ofRGJomXUfP03omXUfP?o00002oo<<l`00ol0003oU6^D
oiA[U004oiA[U003o`000?lhacSo><Lh00_o><Lh0ol00007oa;]4P?o000000?o;]4^o`000?liaST0
3OliaST00ol0003o@ka3od>l@`06od>l@`03o`000?mLXecoG:=L00SoG:=L00?o0000odbcC?m</d`0
2_m</d`00ol0003oGJ9MoefRG@04oefRG@03o`000?mWV6OoIiQW00OoIiQW00?o0000oiA[U?nDJi@0
2onDJi@00ol0003ogb3OomlPg`08omlPg`03o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omXUf_l0
003o0000o`0000ooc3?<00?o0000oiA[U?nDJi@00onDJi@>o`0000?o<Lha0_l00002oa;]4P?o0000
1Ol^dBh00ol0003o>LHiocW6>@0:ocW6>@03o`000?m3_4?o@ka300Oo@ka300?o0000oebSG?mLXe`0
2?mLXe`00ol0003oC;=<odbcC00:odbcC003o`000?mMXUgoGJ9M00GoGJ9M00?o0000ofNHIomWV6L0
1_mWV6L00ol0003oU6^DoiA[U00;oiA[U003o`000?oO8=oogb3O00Sogb3O00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?oj1OX2o`0001;oc3?<00?o0000oiA[U?nDJi@00_nDJi@00ol0003oG:=LoebS
G00:oebSG003o`000?lacS7o<Lha00?o<Lha0_l00009obkA;P03o`000?liaSWo>LHi00Wo>LHi00?o
0000od>l@om3_4<02?m3_4<2o`0000SoG:=L00?o0000odbcC?m</d`02Om</d`00ol0003oGJ9MoefR
G@07oefRG@03o`000?mWV6OoIiQW00CoIiQW00?o0000oiA[U?nDJi@02onDJi@00ol0003ogb3OomlP
g`09omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oc3?<ol`cc00?ol`cc0?o000000?oU6^D
o`000?mLXe`02omLXe`00ol0003o<Lhaoc7><@04oc7><@03o`000?l^dBko;]4^00Wo;]4^00?o0000
ocW6>OliaST01oliaST00ol0003o@ka3od>l@`09od>l@`04o`000?ln`Cko0000o`0000KoG:=L00?o
0000odbcC?m</d`02Om</d`00ol0003oGJ9MoefRG@08oefRG@03o`000?mWV6OoIiQW00?oIiQW00?o
0000oiA[U?nDJi@02onDJi@00ol0003ogb3OomlPg`09omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oc3?<ol`cc00<ol`cc0;o00000oo6>LH2o`0000coG:=L00?o0000oc7><OlacS401?lacS40
0ol0003o;]4^obkA;P0:obkA;PWo00002om3_4<00ol0003o?/4nock1?P02ock1?P?o00000_mLXe`0
0ol0003oC;=<odbcC00:odbcC003o`000?mMXUgoGJ9M00WoGJ9M00?o0000ofNHIomWV6L00_mWV6L0
0ol0003oU6^DoiA[U00:oiA[U003o`000?oO8=oogb3O00Wogb3O00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP09ooX5
nP;o00002_o<<l`2o`0000GoaSW600?o0000oh]dRol000002_mLXe`00ol0003o<Lhaoc7><@06oc7>
<@03o`000?l^dBko;]4^00Wo;]4^00?o0000obcC;?l/db`01Ol/db`00ol0003o@ka3od>l@`09od>l
@`03o`000?ln`Cko?/4n00Go?/4n0ol00009odbcC0?o00003OmMXUd01Ol0003oIiQWofNHIomWV6Oo
000000coU6^D00?o0000omlPgooO8=l02OoO8=l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj00conPGj00?o0000ol`c
c?o<<l`01Oo<<l`2o`0000OoaSW600Co0000oh]dRon;M8_o00002OmLXe`00ol0003o<Lhaoc7><@06
oc7><@03o`000?l^dBko;]4^00So;]4^00?o0000obcC;?l/db`01ol/db`00ol0003o@ka3od>l@`07
od>l@`03o`000?ln`Cko?/4n00So?/4n0ol00002odbcC0Go00000_lacS400ol0003oGJ9MoefRG@0<
oefRG@03o`000?mWV6Oo000000coU6^D00?o0000omlPgooO8=l02_oO8=l00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?oj1O[onPGj
00gonPGj00?o0000ol`cc?o<<l`00_o<<l`2o`0000SoaSW600?o0000oh]dRon;M8/00_n;M8/5o`00
00CoG:=L00?o0000oc7><OlacS401_lacS400ol0003o;]4^obkA;P08obkA;P03o`000?l/dbco;=</
00Oo;=</00?o0000od>l@om3_4<01om3_4<00ol0003o?/4nock1?P08ock1?P03o`000?lQgR7o8MhQ
00;o00002?lacS400ol0003oGJ9MoefRG@0<oefRG@Co00002_nDJi@00ol0003ogb3OomlPg`0:omlP
g`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooX5n_oj1OX03_oj1OX01?l0003oc3?<o`000?l0000:olHiaP03o`000?n;M8_oRgB;
00;oRgB;00?o0000obkA;_l^dBh00_l^dBh4o`0000Wo<Lha00?o0000obkA;_l^dBh02?l^dBh00ol0
003o;=</obcC;008obcC;003o`000?m3_4?o@ka300Go@ka300?o0000ock1?_ln`Ch02?ln`Ch01Ol0
003o8MhQob7N8OlQgR7o000000[o<Lha0ol0000;oefRG@04o`000?o8=lSob3O8olPgb0Co00001OnD
Ji@00ol0003ogb3OomlPg`0;omlPg`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX03ooj1OX00ol0003oaSW6olHiaP0:
olHiaP03o`000?n;M8_oRgB;00?oRgB;00?o0000obkA;_l^dBh01?l^dBh00ol0003o<Lhaoc7><@07
oc7><@03o`000?l^dBko;]4^00Ko;]4^0_l0000;obcC;003o`000?m3_4?o@ka300Go@ka300?o0000
ock1?_ln`Ch02?ln`Ch00ol0003o8MhQob7N8@02ob7N8@03o`000?lacS7o<Lha00Oo<Lha00?o0000
ogf2OOmmPWd01?l00006oefRG@03o`000?o8=lSob3O800Kob3O80ol00002oiA[U003o`000?oO8=oo
gb3O00_ogb3O00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o6>LKoaSW600WoaSW600?o0000oh]d
Ron;M8/01?n;M8/00ol0003o;]4^obkA;P05obkA;P03o`000?lacS7o<Lha00Oo<Lha00?o0000obkA
;_l^dBh00_l^dBh3o`000003oc_4>ol0003o;=</00[o;=</00?o0000od>l@om3_4<01Om3_4<00ol0
003o?/4nock1?P07ock1?P03o`000?lQgR7o8MhQ00?o8MhQ00?o0000oc7><OlacS401olacS400ol0
003oOH9mogf2O@04ogf2O@?o00000_mMXUd00ol0003ob3O8olPgb00:olPgb0;o00003_oO8=l00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?oj1O[onPGj013onPGj00?o0000olHia_o6>LH02Oo6>LH00ol0003oRgB;oh]dR`04oh]dR`03
o`000?l^dBko;]4^00Ko;]4^0_l00007oc7><@03o`000?l^dBko000000;o00001Olka3/00ol0003o
;=</obcC;008obcC;0?o00001?m3_4<00ol0003o?/4nock1?P08ock1?P03o`000?lQgR7o8MhQ00Co
8MhQ00?o0000oc7><OlacS401_lacS400ol0003oOH9mogf2O@07ogf2O@;o00003_o8=lP00ol0003o
gb3OomlPg`0;omlPg`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooX5n_oj1OX04Ooj1OX00ol0003oaSW6olHiaP08olHiaP03o`00
0?n;M8_oRgB;00GoRgB;00?o0000obkA;_l^dBh01?l^dBh00ol0003oA[U6odJiAP03o`0000Co<Lha
0_l00008oc_4>`03o`000?l/dbco;=</00Oo;=</00Co0000of6NHOmQWV7oHIiQ0ol000000om3_4?o
0000ock1?P09ock1?P03o`000?lQgR7o8MhQ00Co8MhQ00?o0000oc7><OlacS401OlacS400ol0003o
OH9mogf2O@09ogf2O@03o`000?o8=lSob3O800gob3O800?o0000omlPgooO8=l02_oO8=l00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?oj1O[onPGj017onPGj00?o0000olHia_o6>LH01oo6>LH00ol0003oRgB;oh]dR`06oh]dR`03o`00
0?l^dBko;]4^00?o;]4^00?o0000odJiA_m6^DH01?m6^DH2o`000003oc7><Ol0003o>l@k00[o>l@k
00?o0000obcC;?l/db`01Ol/db`00ol0003oHIiQof6NH@05of6NH@03o`000?ln`Cko?/4n00Oo?/4n
0ol00007ob7N8@03o`000?lacS7o<Lha00Co<Lha00?o0000ogf2OOmmPWd02OmmPWd00ol0003ob3O8
olPgb00=olPgb003o`000?oO8=oogb3O00[ogb3O00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?o6
>LKoaSW600GoaSW60ol00009oh]dR`05o`000?l^dBko;]4^obkA;_l000002Om6^DH00ol0003o>l@k
oc_4>`0;oc_4>`03o`000?l/dbco;=</00?o;=</00?o0000of6NHOmQWV401_mQWV400ol0003o?/4n
ock1?P06ock1?P05o`000?m8]dSoB;M8odRgB?l000001olQgR400ol0003o<Lhaoc7><@03oc7><@03
o`000?mmPWgoOH9m00WoOH9m00?o0000olPgb?o8=lP03_o8=lP00ol0003ogb3OomlPg`09omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooX5n_oj1OX04Ooj1OX00ol0003oaSW6o`000004o`0000;og2?L00?o0000oh]dRon;M8/0
1on;M8/01?l0003o;]4^obkA;_l00009odJiAP;o00003Olka3/00ol0003o;=</obcC;002obcC;003
o`000?mQWV7oHIiQ00SoHIiQ00?o0000ock1?_ln`Ch00oln`Ch2o`0000GoB;M800?o0000ob7N8OlQ
gR401?lQgR400ol0003o<Lhaoc7><@03oc7><@03o`000?mmPWgoOH9m00WoOH9m00?o0000olPgb?o8
=lP03_o8=lP00ol0003ogb3OomlPg`09omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooX5n_oj1OX04Ooj1OX2o`0000Sog2?L
00?o0000oh]dRon;M8/01_n;M8/00ol0003o;]4^o`000009odJiAP04o`000?mHYeSoF:MHo`0000go
>l@k00Co0000obcC;?l/dbco00003?mQWV401Ol0003o?/4nock1?_ln`Cko000000SoB;M80_l00005
ob7N8@03o`000?lacS7o<Lha00;o<Lha00?o0000ogf2OOmmPWd02OmmPWd00ol0003ob3O8olPgb00>
olPgb003o`000?oO8=oogb3O00Wogb3O00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0@ooX5nP03o`000?oL8mcog2?L
00Oog2?L00?o0000oh]dRon;M8/01on;M8/00ol0003oA[U6odJiAP07odJiAP03o`000?mHYeSoF:MH
00;oF:MH00?o0000oc_4>olka3/02_lka3/00ol0003o;=</o`00000>of6NH@03o`000?ln`Cko0000
00_oB;M800?o0000ob7N8OlQgR400_lQgR401Ol0003o<Lhaoc7><OlacS7o000000coOH9m00?o0000
olPgb?o8=lP03_o8=lP3o`0000Wogb3O00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oL8mcog2?L
00Wog2?L00?o0000oh]dRon;M8/01_n;M8/00ol0003oA[U6odJiAP06odJiAP03o`000?mHYeSoF:MH
00?oF:MH00?o0000oc_4>olka3/02olka3/00ol0003oHIiQof6NH@0>of6NH@03o`000?m8]dSoB;M8
00_oB;M80_l00003ob7N8@04o`000?lacS7o<Lhao`0000[oOH9m0ol0000>olPgb0;o00000ook1?/2
o`0000Oogb3O00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003onPGjooX5nP0?ooX5nP03o`000?oL8mcog2?L00[og2?L00?o0000oh]d
Ron;M8/01?n;M8/00ol0003oA[U6odJiAP06odJiAP03o`000?mHYeSoF:MH00GoF:MH00?o0000oc_4
>olka3/01olka3/3o`00017oHIiQ00?o0000odRgB?m8]dP03Om8]dP01Ol0003o8MhQob7N8Ol0003o
<Lha00Co00000ommPWd5o`0000;ocS7>00?o0000olPgb?o8=lP02_o8=lP2o`0000Oon`Ck0_l00004
omlPg`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooX5n_oj1OX03_oj1OX00ol0003og2?Lom`Sg00;om`Sg003o`000?n;M8_oRgB;
00CoRgB;00?o0000odJiA_m6^DH01Om6^DH00ol0003oF:MHoeRWF006oeRWF003o`000?lka3_o>l@k
00Co>l@k0ol00002odRgB003o`000?mQWV7oHIiQ00ooHIiQ0_l0000?odRgB004o`000?lQgR7o0000
o`0000CoJIIY0ol00008olhacP03o`000?o8=lSob3O800Oob3O80_l0000;oo/4n`;o00000_oO8=l0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?oj1O[onPGj00gonPGj00?o0000om`Sg?oL8m`03?oL8m`6o`0000OoA[U600?o0000oeRW
F?mHYeP02?mHYeP00ol0003o>l@koc_4>`03o`0000KoB;M800?o0000of6NHOmQWV403OmQWV401?l0
003oFjAKoe^TFol0000?odRgB003o`000?mYUVWoJIIY00GoJIIY00?o0000olhac_o><Lh02?o><Lh0
0ol0003ob3O8olPgb005olPgb003o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oL8m`00ol0003oTVfBoi9]TP04oi9]
TP03o`000?m6^DKoA[U600?oA[U600?o0000oeRWF?mHYeP02_mHYeP2o`0000[oB;M800?o0000of6N
HOmQWV402omQWV400ol0003oFjAKoe^TF`02oe^TF`03o`000?m8]dSoB;M800_oB;M80_l00007ofVF
J@03o`000?o><LkocS7>00WocS7>00?o0000olPgb?o8=lP00_o8=lP2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000om`Sg?oL8m`02ooL8m`00ol0003oTVfBoi9]TP06oi9]TP05o`000?m6^DKoA[U6odJi
A_l000003OmHYeP00ol0003oB;M8odRgB00:odRgB003o`000?mQWV7oHIiQ00WoHIiQ00?o0000oe^T
FomKY5/01?mKY5/00ol0003oB;M8odRgB008odRgB0;o000000?o:m@[o`000?mYUVT01omYUVT00ol0
003ocS7>olhacP09olhacP04o`000?o8=lSo0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oL8mcog2?L
00Wog2?L00?o0000oi9]T_nBKI802?nBKI800ol0003oA[U6o`00000=oeRWF003o`000?m8]dSoB;M8
00_oB;M800?o0000of6NHOmQWV402?mQWV400ol0003oFjAKoe^TF`06oe^TF`03o`000?m8]dSoB;M8
00GoB;M80_l00003ob_D:`03o`000?mYUVWoJIIY00KoJIIY00?o0000olhac_o><Lh02_o><Lh00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003og2?Lom`Sg007om`Sg003o`000?nBKI;oTVfB00[oTVfB00?o0000oeRWF?mH
YeP03?mHYeP00ol0003oB;M8odRgB00<odRgB003o`000?mQWV7oHIiQ00KoHIiQ00?o0000oe^TFomK
Y5/02?mKY5/00ol0003oB;M8odRgB002odRgB0;o00001_l[e2/00ol0003oJIIYofVFJ@05ofVFJ@03
o`000?o><LkocS7>00[ocS7>00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oL8mcog2?L00Gog2?L
00?o0000oi9]T_nBKI803?nBKI82o`0000coF:MH00?o0000odRgB?m8]dP03Om8]dP00ol0003oHIiQ
of6NH@04of6NH@03o`000?mKY5_oFjAK00[oFjAK00Co0000odRgB?l0003o00002?l[e2/00ol0003o
JIIYofVFJ@06ofVFJ@03o`000?o><LkocS7>00WocS7>00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oL8m`00ol0003oTVfBoi9]TP0=oi9]TP03o`000?mJYE[o000000;o00002?mHYeP00ol0003oB;M8
odRgB00?odRgB0Ko00003_mKY5/00ol0003o:m@[ob_D:`08ob_D:`03o`000?mYUVWoJIIY00KoJIIY
00?o0000olhac_o><Lh02Oo><Lh00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000omdRgOoM8]gogB;M
0_l0000?oi9]TP03o`000?mJYE[oFZEJ00?oFZEJ0ol00005oeRWF0;o00004?m8]dP01_l0003o=</d
ocC;=?l0003o7N8Mo`0000koFjAK00?o0000ob_D:ol[e2/02Ol[e2/00ol0003oJIIYofVFJ@05ofVF
J@03o`000?o><LkocS7>00WocS7>00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000omdRgOoM8]d00ooM8]d00ol0003o
TVfBoi9]TP0=oi9]TP03o`000?mJYE[oFZEJ00KoFZEJ0ol000001?mHYeSo0000od2o@?m0_d03o`00
00coB;M800Go0000ocC;=?ldbcCo=</do`000002oagR7@03o`000?mKY5_oFjAK00_oFjAK00?o0000
ob_D:ol[e2/02Ol[e2/00ol0003oJIIYofVFJ@06ofVFJ@03o`000?o><LkocS7>00SocS7>0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ogB;MomdRg@04omdRg@oo00003?mJYEX00ol0003o@;m0od2o@004od2o
@0?o00002?m8]dP00ol0003o=</docC;=002ocC;=005o`000?lMhQgo7N8MoagR7Ol000003?mKY5/0
0ol0003o:m@[ob_D:`09ob_D:`03o`000?mYUVWoJIIY00GoJIIY3?l00002onTFj@;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ogB;MomdRg@05omdRg@03o`000?n4NhCoQ7^400_oQ7^400?o0000oeZU
F_mJYEX02_mJYEX00ol0003o@;m0od2o@007od2o@0;o00001Om8]dP00ol0003o=</docC;=003ocC;
=003o`000?lMhQgo7N8M00;o7N8M00?o0000oe^TFomKY5/02OmKY5/00ol0003o:m@[ob_D:`0:ob_D
:`03o`000?mYUVWoJIIY00?oJIIY00?o0000ojQGZ?nXEjP02OnXEjP00ol0003ojAKYonTFj@02onTF
j@;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ogB;MomdRg@06omdRg@03o`000?n4NhCoQ7^400[o
Q7^400?o0000oeZUF_mJYEX02omJYEX00ol0003o@;m0od2o@009od2o@0?o000000?oB;M8o`000?ld
bc@01Oldbc@00ol0003o7N8MoagR7@03oagR7@03o`000?mKY5_oFjAK00SoFjAK3_l00003ofVFJ@;o
00002onXEjP00ol0003ojAKYonTFj@05onTFj@03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000omdRgOoM8]d01OoM8]d00ol0003oVVFJo`00000;ohAkQ003o`000?mJYE[oFZEJ00[oFZEJ
0_l0000>od2o@003o`000?ldbcCo=</d00Go=</d00?o0000oagR7OlMhQd00olMhQd00ol0003oFjAK
oe^TF`08oe^TF`03o`000?mZUF[oJYEZ00_oJYEZ00?o0000ofVFJOl000003OnXEjP00ol0003ojAKY
onTFj@06onTFj@;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oM8]gogB;M00KogB;M00Co
0000oiYUV_nJII[o00002_n4Nh@00ol0003oFZEJoeZUFP09oeZUFP03o`000?m4^dCo000000ko@;m0
00?o0000ocC;=?ldbc@01Oldbc@00ol0003o7N8MoagR7@04oagR7@03o`000?mKY5_oFjAK00KoFjAK
00?o0000ofZEJ_mZUFX03OmZUFX00ol0003oZ5NXojQGZ00<ojQGZ003o`000?oY5^WojAKY00SojAKY
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oM8]gogB;M00GogB;M00?o0000oiYUV_nJIIX00_nJ
IIX00ol0003oQ7^4ohAkQ006ohAkQ003o`000?mJYE[oFZEJ00SoFZEJ0_l00003odBkA003o`000?m0
_d3o@;m000_o@;m000?o0000ocC;=?ldbc@01Oldbc@00ol0003o7N8MoagR7@05oagR7@03o`000?mK
Y5_oFjAK00GoFjAK00?o0000ofZEJ_mZUFX03OmZUFX00ol0003oZ5NXojQGZ00;ojQGZ003o`000?oY
5^WojAKY00WojAKY00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oM8]gogB;M00KogB;M00?o0000
oiYUV_nJIIX00onJIIX00ol0003oQ7^4ohAkQ005ohAkQ003o`000?mJYE[oFZEJ00OoFZEJ00?o0000
odBkA?m4^d@00om4^d@00ol0003o@;m0od2o@00:od2o@003o`000?ldbcCo=</d00Ko=</d00?o0000
oagR7OlMhQd01_lMhQd00ol0003oFjAKoe^TF`04oe^TF`03o`000?mZUF[oJYEZ00goJYEZ3ol0000;
onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oM8]gogB;M00KogB;M00?o0000oiYUV_nJIIX01OnJIIX00ol0
003oQ7^4ohAkQ004ohAkQ003o`000?mJYE[oFZEJ00GoFZEJ0_l00006odBkA003o`000?m0_d3o@;m0
00Wo@;m00_l00008ocC;=003o`000?lMhQgo7N8M00Ko7N8M1Ol000000omKY5_o0000ofZEJP0?ofZE
JP03o`000?nWF:OoYeRW00_oYeRW00?o0000onTFjOoY5^T02OoY5^T00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oM8]gogB;M00KogB;M00?o0000oiYUV_nJIIX01_nJIIX00ol0003o
Q7^4ohAkQ004o`0000KoFZEJ00?o0000odBkA?m4^d@01om4^d@00ol0003o@;m0od2o@005od2o@0?o
000000?o:MHYo`000?ldbc@01oldbc@00ol0003o7N8MoagR7@05oagR7@03o`000?mOX5ooGj1O00?o
Gj1O0_l0000?ofZEJP;o00003OnWF:L00ol0003ojAKYonTFj@08onTFj@03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WogB;M00?o0000oiYUV_nJIIX01onJIIX2o`0000CoS7><00Co0000oeZUF_mJYE[o
FZEJ0_l0000:odBkA003o`000?m0_d3o@;m000;o@;m00ol00005obWF:@03o`000?ldbcCo=</d00Go
=</d00?o0000oagR7OlMhQd01?lMhQd00ol0003oGj1OoenPG`06oenPG`03o`000?mZUF[oJYEZ00[o
JYEZ0_l00002ohQgR003o`000?nWF:OoYeRW00[oYeRW00?o0000onTFjOoY5^T02?oY5^T00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000omdRgOoM8]d01_oM8]d00ol0003oVVFJoiYUVP08oiYUVP03o`00
0?n<LhcoS7><00CoS7><00?o0000oeZUF_l000003?m4^d@00ol0003o@;m0o`000002o`0000Wo:MHY
00?o0000ocC;=?ldbc@01?ldbc@00ol0003o7N8MoagR7@03oagR7@03o`000?mOX5ooGj1O00SoGj1O
1_l00004ofZEJP;o00001On8MhP00ol0003oYeRWojMHY`09ojMHY`03o`000?oY5^WojAKY00SojAKY
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oM8]gogB;M00GogB;M00?o0000oiYUV_nJIIX01onJ
IIX00ol0003oS7><ohacS006ohacS003o`000?m4^dCoA;]400coA;]400?o0000obWF:OlYeRT02_lY
eRT00ol0003o=</docC;=004ocC;=004o`000?lMhQgo7N8MoagR7@;o00002omOX5l00ol0003oM8]d
ogB;M003ogB;M0Co00002?n8MhP00ol0003oYeRWojMHY`08ojMHY`03o`000?oY5^WojAKY00OojAKY
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000omdRgOoM8]d00ooM8]d00ol0003oVVFJoiYUVP07oiYUVP03o`000?n<
LhcoS7><00OoS7><00?o0000odBkA?m4^d@03?m4^d@00ol0003o:MHYobWF:@0;obWF:@03o`000?ld
bcCo=</d00?o=</d00Co0000oagR7OlMhQgo00003OmOX5l00ol0003oM8]dogB;M006ogB;M003o`00
0?n8MhSoR7N800OoR7N800?o0000ojMHYonWF:L01onWF:L00ol0003ojAKYonTFj@06onTFj@04o`00
0?ol0ocoo0?loo`3o0;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oM8]gogB;M00;ogB;M00?o0000oiYUV_nJIIX0
1_nJIIX00ol0003oS7><ohacS009ohacS003o`000?m4^dCoA;]400WoA;]40_l0000>obWF:@?o0000
0oldbc@00ol0003o7N8Mo`00000=oenPG`03o`000?mdRgCoM8]d00OoM8]d00?o0000ohQgR?n8MhP0
2?n8MhP:o`0000KojAKY0_l00006oo`3o003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoVVFJ00?o
0000ohacS?n<Lh`02_n<Lh`00ol0003oA;]4odBkA006odBkA0;o000000?o@Ki1o`000?lYeRT02olY
eRT2o`0000?oFjAK1Ol0000>oenPG`03o`000?mdRgCoM8]d00OoM8]d00?o0000ohQgR?n8MhP02?n8
MhP00ol0003o`3o0ol0o`006ol0o`003o`000?oY5^WojAKY00?ojAKY00?o0000oo`3o?ol0o`01ool
0o`2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003odBkAom4^d@03om4^d@Co00000_nJIIX00ol0003oS7><ohacS00;
ohacS003o`000?m4^dCoA;]400?oA;]40ol00004od6n@@03o`000?lYeRWo:MHY00Oo:MHY0_l00008
oe^TF`03o`000?mOX5ooGj1O00goGj1O00?o0000ogB;M?mdRg@02?mdRg@00ol0003oR7N8ohQgR007
ohQgR003o`000?o0?l3o`3o000Oo`3o00ol000000ooY5^Wo0000oo`3o00;oo`3o0;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oA;]7odBkA00OodBkA0_l0000?ohacS003o`000?m4^dCoA;]400;o00002?m1_T400ol0
003o:MHYobWF:@05obWF:@03o`000?mKY5_oFjAK00SoFjAK00?o0000oenPGomOX5l03OmOX5l00ol0
003oM8]dogB;M008ogB;M003o`000?n8MhSoR7N800KoR7N800?o0000ol0o`?o0?l002?o0?l001?l0
003ojQGZonXEj_l0000?oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003odBkAom4^d@09om4^
d@03o`000?n<LhcoS7><00koS7><0_l0000;od6n@@03o`000?lYeRWo:MHY00;o:MHY0_l0000;oe^T
F`03o`000?mOX5ooGj1O00goGj1O00?o0000ogB;M?mdRg@02?mdRg@00ol0003oR7N8ohQgR006ohQg
R003o`000?o0?l3o`3o000Oo`3o000Go0000onXEj_oZ5N[ojQGZo`00000@oo`3o0;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003odBkAom4^d@0:om4^d@03o`000?n<LhcoS7><00goS7><0_l0000<od6n@@04o`000?lYeRWo0000
o`0000goFjAK00?o0000oenPGomOX5l03?mOX5l00ol0003oM8]dogB;M009ogB;M003o`000?n8MhSo
R7N800KoR7N800?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP03onXEjP03o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003odBkAom4^d@0:om4^d@03o`000?n<LhcoS7><00coS7><00Co0000oc[5
>_ljaC[o00003?m1_T400ol0003oFjAKoe^TF`0>oe^TF`03o`000?mOX5ooGj1O00SoGj1O1?l0000;
ogB;M003o`000?n8MhSoR7N800KoR7N800?o0000ol0o`?o0?l001Oo0?l000ol0003ojQGZonXEjP04
onXEjP03o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003odBkAom4^d@0;om4^d@03o`000?n<LhcoS7><
00_oS7><00?o0000oc[5>_ljaCX00_ljaCX00ol0003o@Ki1od6n@@09od6n@@03o`000?mKY5_oFjAK
00koFjAK00Co0000oenPGomOX5ooGj1O1ol00003ofNHI`03o`000?mdRgCoM8]d00WoM8]d00?o0000
ohQgR?n8MhP01_n8MhP00ol0003o`3o0ol0o`004ol0o`003o`000?oZ5N[ojQGZ00KojQGZ00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oA;]7odBkA00codBkA00?o0000ohacS?n<Lh`02_n<Lh`00ol0
003o>/Djoc[5>P03oc[5>P03o`000?m1_T7o@Ki100So@Ki100?o0000oe^TFomKY5/03_mKY5/4o`00
00_oIiQW00?o0000ogB;M?mdRg@02?mdRg@00ol0003oR7N8ohQgR005ohQgR003o`000?o0?l3o`3o0
00Go`3o000?o0000onXEj_oZ5NX01_oZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om4^dOoA
;]403?oA;]47o`0000GoS7><00?o0000oc[5>_ljaCX01OljaCX00ol0003o@Ki1od6n@@07od6n@@03
o`000?mKY5_oFjAK00koFjAK00?o0000ofNHIomWV6L03OmWV6L00ol0003oM8]dogB;M008ogB;M003
o`000?n8MhSoR7N800CoR7N800?o0000ol0o`?o0?l001?o0?l000ol0003ojQGZonXEjP07onXEjP03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003odBkAom4^d@0=om4^d@03o`000?nUFZGoYEZU00CoYEZU
1Ol00009oc[5>P03o`000?m1_T7o@Ki100Ko@Ki100?o0000oe^TFomKY5/03_mKY5/00ol0003oIiQW
ofNHI`0=ofNHI`03o`000?mdRgCoM8]d00SoM8]d00Co0000ohQgR?n8MhSoR7N81Ol00004ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=om4^d@03o`000?nUFZGoYEZU00WoYEZU
0_l00009oc[5>P03o`000?m1_T7o@Ki100Ko@Ki100?o0000oe^TFomKY5/03?mKY5/00ol0003oIiQW
ofNHI`0?ofNHI`Ko00001?mdRg@4o`0000GoacS70_l000000oo0?l3o0000onXEjP0;onXEjP04o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oS7>?ohacSon<Lh`?o00002_oA;]400ol0003o
YEZUojEJY@09ojEJY@03o`000?m?/4oo000000;o00001oljaCX00ol0003o@Ki1od6n@@05od6n@@03
o`000?mKY5_oFjAK00SoFjAK1Ol0000AofNHI`03o`000?n1OX7oPGj100?oPGj11?l0000;olLha`03
o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000on<LhooS7><01OoS7><2o`0000OodBkA
00?o0000ojEJYOnUFZD02_nUFZD00ol0003oCk1?odn`C`02odn`C`?o00001OljaCX00ol0003o@Ki1
od6n@@04od6n@@04o`000?mKY5_oFjAKoe^TF`Oo00001?m;]4/00ol0003oIiQWofNHI`0>ofNHI`03
o`000?n1OX7oPGj100OoPGj100?o0000olLhaoo7><L02Oo7><L00ol0003ojQGZonXEjP09onXEjP03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003ohacSon<Lh`08on<Lh`;o00001?oA;]400ol0003oYEZU
ojEJY@0;ojEJY@03o`000?m?/4ooCk1?00GoCk1?0ol00003oc[5>P04o`000?m1_T7o@Ki1od6n@@Ko
00003?m;]4/00ol0003oIiQWofNHI`0=ofNHI`03o`000?n1OX7oPGj100OoPGj100?o0000olLhaoo7
><L02_o7><L00ol0003ojQGZonXEjP08onXEjP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=on<Lh`?o000000?odBkAo`000?nUFZD0
3?nUFZD00ol0003oCk1?odn`C`08odn`C`?o000000Co>/Djo`000?l0003o00000_mnPGh00ol0003o
BkA;od^dB`0=od^dB`03o`000?mWV6OoIiQW00coIiQW00?o0000oh5nPOn1OX402?n1OX400ol0003o
acS7olLha`0;olLha`03o`000?oZ5N[ojQGZ00KojQGZ00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
hacS00?o0000ojEJYOnUFZD03?nUFZD00ol0003oCk1?odn`C`0;odn`C`03o`000?mnPGkoOX5n00?o
OX5n00?o0000od^dBom;]4/03?m;]4/00ol0003o=/Tfo`00000=ofNHI`03o`000?n1OX7oPGj100So
PGj100?o0000olLhaoo7><L03?o7><L3o`0000GojQGZ00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oS7>?ohacS00cohacS00?o0000ojEJYOnUFZD03?nUFZD00ol0003oCk1?odn`C`0:odn`C`03o`00
0?mnPGkoOX5n00GoOX5n00?o0000od^dBom;]4/02_m;]4/01?l0003o=/TfocK9=_lfbCH2o`0000[o
IiQW00?o0000oh5nPOn1OX402On1OX400ol0003oacS7olLha`0<olLha`03o`000?o^4NkokQ7^00?o
000000?ojQGZo`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oS7>?ohacS00_ohacS00?o0000ojEJYOnUFZD0
3?nUFZD00ol0003oCk1?odn`C`09odn`C`03o`000?mnPGkoOX5n00KoOX5n00?o0000od^dBom;]4/0
2Om;]4/00ol0003o=/TfocK9=P02ocK9=P03o`000?mlPgco000000;o00001omWV6L00ol0003oPGj1
oh5nP@09oh5nP@03o`000?o7><OoacS700_oacS700?o0000onhAk_o^4Nh01?o^4Nh00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000on<LhooS7><02ooS7><00ol0003oYEZUojEJY@0;ojEJY@03o`000?m?
/4ooCk1?00SoCk1?00?o0000ogj1O_mnPGh01omnPGh00ol0003oBkA;od^dB`08od^dB`03o`000?lf
bCKo=/Tf00?o=/Tf00?o0000ogb3O?mlPg`00_mlPg`2o`0000CoIiQW00?o0000oh5nPOn1OX402_n1
OX400ol0003oacS7olLha`0:olLha`03o`000?o^4NkokQ7^00GokQ7^00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oS7>?ohacS00[ohacS0ol0000;ojEJY@Ko00001?m?/4l00ol0003oOX5nogj1OP08
ogj1OP03o`000?m;]4_oBkA;00OoBkA;00?o0000ocK9=_lfbCH00olfbCH00ol0003oO8=logb3O005
ogb3O0?o000000?oIiQWo`000?n1OX402on1OX400ol0003oacS7olLha`09olLha`03o`000?o^4Nko
kQ7^00OokQ7^00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oS7>?ohacS00WohacS00?o0000oka3
_?nl@k`01?l00006ojEJY@03o`000?nMHYgoWF:M00CoWF:M1?l0000<ogj1OP03o`000?m;]4_oBkA;
00GoBkA;00?o0000ocK9=_lfbCH01?lfbCH00ol0003oO8=logb3O008ogb3O003o`000?n1OX7oPGj1
00_oPGj100?o0000olLhaoo7><L02?o7><L00ol0003okQ7^onhAkP08onhAkPGo00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oS7>?ohacS00OohacS00?o0000oka3_?nl@k`01Onl@k`3o`0000;oYEZU00?o0000oieRWOnM
HYd02?nMHYd00ol0003oOX5nogj1OP0:ogj1OP03o`000?m;]4_oBkA;00CoBkA;00?o0000ocK9=_lf
bCH01OlfbCH00ol0003oO8=logb3O008ogb3O003o`000?n1OX7oPGj100WoPGj11?l00008olLha`03
o`000?o^4NkokQ7^00WokQ7^00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ohacS
on<Lh`05on<Lh`03o`000?nl@kco_4>l00Wo_4>l0_l0000<oieRW@03o`000?mnPGkoOX5n00WoOX5n
00?o0000od^dBom;]4/00om;]4/00ol0003o=/TfocK9=P05ocK9=P03o`000?mlPgcoO8=l00[oO8=l
00?o0000oh5nPOn1OX401?n1OX44o`0000Co^DJi00?o0000olLhaoo7><L01?o7><L00ol0003okQ7^
onhAkP0:onhAkP03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oS7>?ohacS00?ohacS00?o0000oka3_?nl@k`02onl
@k`00ol0003oWF:MoieRW@0:oieRW@03o`000?mnPGkoOX5n00WoOX5n00?o0000od^dBom;]4/00_m;
]4/00ol0003o=/TfocK9=P06ocK9=P03o`000?mlPgcoO8=l00[oO8=l00?o0000oh5nPOn1OX401?l0
0009okU6^@Ko00003?o^4Nh00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000on<LhooS7>?ohacS0_l0
000=oka3_003o`000?nMHYgoWF:M00[oWF:M00?o0000ogj1O_mnPGh02OmnPGh01Ol0003oBkA;od^d
Bom;]4_o000000Wo=/Tf00?o0000ogb3O?mlPg`02omlPg`2o`0000go^DJi00?o0000onPGj?oX5nP0
0_oX5nP00ol0003okQ7^onhAkP0:onhAkP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ohacSo`00
0002on/Dj`;o00002onl@k`00ol0003oWF:MoieRW@0;oieRW@03o`000?mnPGkoOX5n00WoOX5n00?o
0000od^dBol000002OlfbCH00ol0003oO8=logb3O00<ogb3O003o`000?niA[Wo^DJi00co^DJi00?o
0000onPGj?oX5nP00ooX5nP00ol0003okQ7^onhAkP09onhAkP03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ojaC[on/Dj`03on/Dj`;o00002_nl@k`00ol0003oWF:MoieRW@0:oieRW@03o`000?mnPGko
OX5n00SoOX5n1Ol00008ocK9=P03o`000?mlPgcoO8=l00coO8=l00?o0000okU6^OniA[T02oniA[T0
0ol0003oj1OXonPGj005onPGj003o`000?o^4NkokQ7^00SokQ7^00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oo[5>/2o`0000So_4>l00?o0000oieRWOnMHYd02_nMHYd00ol0003oOX5nogj1OP07ogj1
OP03o`000?m`Sg3oL8m`00?oL8m`0ol00005ocK9=P03o`000?mlPgcoO8=l00_oO8=l00?o0000okU6
^OniA[T03?niA[T00ol0003oj1OXonPGj006onPGj003o`000?o^4NkokQ7^00OokQ7^00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?ol0oco000000WojaC[00?o0000oka3_?nl@k`01Onl@k`2o`0000co
WF:M00?o0000ogj1O_mnPGh01OmnPGh00ol0003oL8m`og2?L007og2?L0?o000000?o=/Tfo`000?ml
Pg`03OmlPg`00ol0003o^DJiokU6^@0<okU6^@03o`000?oX5nSoj1OX00Koj1OX00?o0000onhAk_o^
4Nh01_o^4Nh00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003oo`3o003o`000?o[5>_ojaC[00OojaC[
0_l00004oka3_003o`000?o9=/WobCK900;o00002_nMHYd00ol0003oOX5nogj1OP03ogj1OP;o0000
3Om`Sg02o`0000goO8=l0ol0000=okU6^@03o`000?oX5nSoj1OX00Ooj1OX00?o0000onhAk_o^4Nh0
1Oo^4Nh00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo0?loo`3o004oo`3o003o`000?o[5>_ojaC[00SojaC[0_l0
00000onl@kco0000olTfb@04olTfb@03o`000?nMHYgoWF:M00OoWF:M00Co0000ogj1O_mnPGkoOX5n
0_l00002oiUVV@03o`000?m`Sg3oL8m`00coL8m`3Ol00003oj=LX`03o`000?niA[Wo^DJi00[o^DJi
00?o0000onPGj?oX5nP02?oX5nP01?l0003okQ7^onhAk_o^4Nh4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?ol0o`00ol0003ojaC[
on/Dj`09on/Dj`03o`000?o9=/WobCK900GobCK90_l00008oieRW@03o`000?mnPGko000000GoVFJI
00?o0000og2?L?m`Sg002om`Sg000ol0003oNHIiogV6N@09ogV6N@03o`000?nSG:?oXebS00;oXebS
0_l00009okU6^@03o`000?oX5nSoj1OX00[oj1OX0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000oo`3
o00:oo`3o003o`000?o[5>_ojaC[00SojaC[00?o0000olTfbOo9=/T01oo9=/T4o`0000?oWF:M0ol0
0007oiUVV@03o`000?m`Sg3oL8m`00[oL8m`00?o0000ogV6NOmiQWT02OmiQWT00ol0003oXebSoj=L
X`04oj=LX`;o00001oniA[T00ol0003oj1OXonPGj00:onPGj003o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?o[5>_ojaC[00OojaC[00?o0000olTfbOo9=/T02?o9=/T0
1?l0003ob3O8olPgb?o8=lP3o`0000;o]DZe00?o0000oiUVVOnIIYT01_nIIYT00ol0003oL8m`og2?
L008og2?L003o`000?miQWWoNHIi00[oNHIi00?o0000oj=LXonSG:<01_nSG:<00ol0003o^DJiokU6
^@04okU6^@03o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000on/Djoo[5>/01Oo[5>/00ol0003obCK9olTfb@08olTfb@03o`000?o8=lSo
b3O800Cob3O800Go0000okE:]OneB[Go]DZeo`000008oiUVV@03o`000?m`Sg3oL8m`00OoL8m`00?o
0000ogV6NOmiQWT02_miQWT00ol0003oXebSoj=LX`07oj=LX`;o00001?niA[T00ol0003oj1OXonPG
j008onPGj003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/00oo[5>/0
0ol0003obCK9olTfb@08olTfb@03o`000?o8=lSob3O800Cob3O800?o0000okE:]OneB[D00_neB[D0
0ol0003oVFJIoiUVV@07oiUVV@03o`000?m`Sg3oL8m`00KoL8m`00?o0000ogV6NOmiQWT02_miQWT0
0ol0003oXebSoj=LX`09oj=LX`05o`000?niA[Wo^DJiokU6^Ol000002OoX5nP00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_obCK900?o0000olPgb?o8=lP01?o8=lP00ol0003o]DZeokE:]@03
okE:]@03o`000?nIIYWoVFJI00OoVFJI00?o0000og2?L?m`Sg001Om`Sg000ol0003oNHIiogV6N@0:
ogV6N@03o`000?nSG:?oXebS00WoXebS1?l00009onPGj003o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o_4>ooka3_
onl@kol000002_o9=/T00ol0003ob3O8olPgb005olPgb003o`000?neB[Go]DZe00?o]DZe00?o0000
oiUVVOnIIYT02?nIIYT00ol0003oL8m`og2?L004og2?L003o`000?miQWWoNHIi00WoNHIi00?o0000
oj=LXonSG:<02?nSG:<2o`0000?oj1OX00?o0000onPGj?oX5nP01_oX5nP00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000onl@koo_4>l00oo_4>l00ol0003obCK9olTfb@06olTfb@03o`000?o8=lSob3O8
00Gob3O800?o0000okE:]OneB[D01?neB[D00ol0003oVFJIoiUVV@09oiUVV@03o`000?m`Sg3oL8m`
00;oL8m`00?o0000ogV6NOmiQWT02_miQWT00ol0003oXebSoj=LX`06oj=LX`;o00001_oX5nP8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003oka3_onl@k`05onl@k`03o`000?o9=/WobCK900GobCK900?o0000olPgb?o8
=lP01Oo8=lP00ol0003o]DZeokE:]@05okE:]@03o`000?nIIYWoVFJI00WoVFJI00Go0000og2?L?m`
Sg3oL8m`o`00000<ogV6N@03o`000?nSG:?oXebS00CoXebS0_l00008onPGj003o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o_4>ooka3_00Ooka3_00?o0000olTfbOo9
=/T00oo9=/T00ol0003ob3O8olPgb006olPgb003o`000?neB[Go]DZe00Go]DZe00?o0000oiUVVOnI
IYT02_nIIYT00ol0003oL8m`o`000004o`0000WoNHIi00?o0000oj=LXonSG:<00_nSG:<2o`0000[o
j1OX00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003oka3_onl@k`07onl@k`03o`00
0?o9=/WobCK900;obCK900?o0000olPgb?o8=lP01_o8=lP00ol0003o]DZeokE:]@07okE:]@;o0000
2onIIYT00ol0003o`Ck1ol4n`@03ol4n`@Oo00000_miQWT00ol0003oXebSoj=LX`02o`0000_oj1OX
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000onl@koo_4>l02Oo_
4>l01Ol0003obCK9olTfbOo9=/Wo000000Sob3O800?o0000okE:]OneB[D01oneB[D00ol0003og2?L
o`000002o`0000SoVFJI00?o0000ol4n`Oo1?/402_o1?/45o`0000goj1OX00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<onl@k`03o`000?o9=/Wo000000Wob3O800?o
0000okE:]OneB[D01_neB[D00ol0003og2?Lom`Sg003om`Sg0?o00001?nIIYT00ol0003o`Ck1ol4n
`@0=ol4n`@03o`000?oX5nSoj1OX00goj1OX00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000oom0_d2o`0000_oka3_00?o0000olPgb?o8=lP01oo8=lP00ol0003o]DZeokE:]@07
okE:]@03o`000?oL8mcog2?L00Kog2?L0ol000000onIIYWo0000ol4n`@0>ol4n`@03o`000?oX5nSo
j1OX00coj1OX00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009onl@
k`03o`000?o8=lSob3O800;ob3O81_l00008okE:]@03o`000?oL8mcog2?L00[og2?L00?o0000ol4n
`Oo1?/403oo1?/400ol0003oj1OXonPGj00:onPGj0;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007onl@k`Go00001_o/4n`00ol0003o]DZeokE:]@05okE:]@03o`000?oL8mcog2?L00[o
g2?L00?o0000ol4n`Oo1?/403oo1?/400ol0003oj1OXonPGj007onPGj0?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005onl@k`03o`000?o/4ncok1?/00Wok1?/00?o0000okE:]One
B[D00oneB[D00ol0003og2?Lom`Sg00;om`Sg003o`000?o1?/7o`Ck100oo`Ck100?o0000onPGj?oX
5nP01OoX5nP2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?oka3_o`000?l00000
3Oo/4n`00ol0003o]DZeokE:]@02okE:]@03o`000?oL8mcog2?L00_og2?L5?l00004onPGj0;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo0?lo`00000>on`Ck004o`000?neB[Go]DZeo`0000kog2?L
00?o0000onl@koo_4>l04?o_4>l00ol0003oj1OXo`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?ol0ocoo0?loo`3o?l000003_o/4n`00ol0003o]DZeo`00000>om`Sg003o`00
0?o_4>ooka3_017oka3_00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000oo`3o?ol0o`00_ol0o`00ol0003ok1?/on`Ck00=on`Ck003o`000?oL8mcog2?L00Wog2?L1Ol0
000Bonl@k`;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ok1?/on`Ck00<on`Ck003o`000?oL8mcog2?L00;og2?L1ol00004oo`3o003o`000?o_4>oo
ka3_00ooka3_00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o006oo`3
o003o`000?o/4ncok1?/00cok1?/1?l0000<oo`3o003o`000?o_4>ooka3_00coka3_0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on`Ck?o/4n`03?o/4n`00ol0003oo0?loo`3o00=oo`3o003o`000?o_4>ooka3_00_o
ka3_00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo`3o?ol
0o`02Ool0o`00ol0003ok1?/on`Ck00:on`Ck003o`000?ol0ocoo0?l00koo0?l00?o0000onl@koo_
4>l02Oo_4>l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000on`Ck?o/4n`02_o/4n`00ol0003oo0?l
oo`3o00?oo`3o003o`000?o_4>ooka3_00Koka3_0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo0?l00goo0?l3?l0
000Aoo`3o0?o00001_o_4>l00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000oo_4>l2o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000onl@kol000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01?l00?l3oooo00co003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002_l00?l2oooo00So003o0oooo`09o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0_ooo`0:o`00o`?oool01_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00[o003o0_ooo`0;o`00o`?oool01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`002_l00?l2oooo00co
003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00[o003o0_ooo`0=o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`0=o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2_l00?l2oooo00So003o1Oooo`000ol00?ooool0oooo0002o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`0:o`00o`;oool01ol00?l2oooo00Co003o0oooo`02o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo0002oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol00?l2oooo0003o`00oooo
o`3oool000[o003o0_ooo`06o`00o`?oool01Ol00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`06
o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool0
06Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02_l00?l2oooo
00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`;o
ool01_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;o
ool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00[o003o
0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Oo003o
0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l2oooo0003oc8bc?l00?oo003o00Oo003o0_ooo`07o`00o`03oooo0?l00?oo003o00?o003o0_oo
o`04o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3
oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05o`00o`Coool01ol00?l2
oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00
o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08_l00?l2oooo00Wo003o1?ooo`08o`00
o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(200) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.987 .013 .987 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.988 .012 .988 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.988 .012 .988 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.987 .013 .987 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.925 .075 .925 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.986 .014 .986 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.923 .077 .923 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.929 .071 .929 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.894 .106 .894 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.982 .018 .982 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.858 .142 .858 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.987 .013 .987 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.774 .226 .774 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.772 .228 .772 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.983 .017 .983 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.989 .011 .989 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.675 .325 .675 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.825 .175 .825 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.981 .019 .981 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.983 .017 .983 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.986 .014 .986 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.914 .086 .914 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.476 .524 .476 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.755 .245 .755 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.603 .397 .603 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.591 .409 .591 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.673 .327 .673 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.858 .142 .858 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.895 .105 .895 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.988 .012 .988 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.593 .407 .593 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.806 .194 .806 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.456 .544 .456 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.873 .127 .873 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.826 .174 .826 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.987 .013 .987 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.733 .267 .733 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.785 .215 .785 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.627 .373 .627 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.867 .133 .867 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.62 .38 .62 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.99 .01 .99 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.908 .092 .908 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.589 .411 .589 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.37 .63 .37 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.374 .626 .374 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.927 .073 .927 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.94 .06 .94 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.75 .25 .75 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.987 .013 .987 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.587 .413 .587 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.538 .462 .538 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.482 .518 .482 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.508 .492 .508 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.262 .738 .262 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.558 .442 .558 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.655 .345 .655 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.988 .012 .988 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.653 .347 .653 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.552 .448 .552 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.913 .087 .913 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.199 .801 .199 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.798 .202 .798 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.752 .248 .752 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.48 .52 .48 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.218 .782 .218 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.377 .623 .377 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.054 .946 .054 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.104 .896 .104 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.375 .625 .375 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.281 .719 .281 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.352 .648 .352 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.796 .204 .796 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.32 .68 .32 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.351 .649 .351 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.627 .373 .627 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.926 .074 .926 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.986 .014 .986 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.186 .814 .186 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.259 .741 .259 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.327 .673 .327 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.986 .014 .986 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.627 .373 .627 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.336 .664 .336 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.242 .758 .242 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.124 .876 .124 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.431 .569 .431 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.242 .758 .242 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.916 .084 .916 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.297 .703 .297 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.058 .942 .058 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.723 .277 .723 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.215 .785 .215 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.158 .842 .158 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.495 .505 .495 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.863 .137 .863 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.372 .628 .372 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.045 .955 .045 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.162 .838 .162 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.438 .562 .438 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.214 .786 .214 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.235 .765 .235 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.869 .131 .869 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.18 .82 .18 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.118 .882 .118 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.083 .917 .083 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.985 .015 .985 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.085 .915 .085 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.263 .737 .263 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.145 .855 .145 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.612 .388 .612 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.339 .661 .339 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.985 .015 .985 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.394 .606 .394 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.268 .732 .268 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.295 .705 .295 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.349 .651 .349 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.203 .797 .203 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.154 .846 .154 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.284 .716 .284 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.445 .555 .445 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.986 .014 .986 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.728 .272 .728 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.321 .679 .321 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.441 .559 .441 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.208 .792 .208 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.915 .085 .915 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.008 .992 .008 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.185 .815 .185 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.166 .834 .166 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.358 .642 .358 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.602 .398 .602 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.1 .9 .1 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.987 .013 .987 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.241 .759 .241 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.765 .235 .765 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.937 .063 .937 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.488 .512 .488 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.483 .517 .483 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.295 .705 .295 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.856 .144 .856 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.092 .908 .092 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.221 .779 .221 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.358 .642 .358 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.61 .39 .61 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.087 .913 .087 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.225 .775 .225 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.34 .66 .34 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.392 .608 .392 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.986 .014 .986 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.144 .856 .144 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.986 .014 .986 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.901 .099 .901 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.4 .6 .4 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.34 .66 .34 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.196 .804 .196 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.657 .343 .657 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.267 .733 .267 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.911 .089 .911 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.388 .612 .388 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.419 .581 .419 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.423 .577 .423 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.509 .491 .509 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.738 .262 .738 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.458 .542 .458 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.195 .805 .195 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.12 .88 .12 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.167 .833 .167 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.419 .581 .419 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.734 .266 .734 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.987 .013 .987 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.908 .092 .908 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.281 .719 .281 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.196 .804 .196 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.366 .634 .366 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.767 .233 .767 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.547 .453 .547 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.986 .014 .986 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.421 .579 .421 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.786 .214 .786 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.913 .087 .913 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.987 .013 .987 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.23 .77 .23 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.307 .693 .307 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.901 .099 .901 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.317 .683 .317 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.499 .501 .499 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.658 .342 .658 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.367 .633 .367 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.49 .51 .49 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.815 .185 .815 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.678 .322 .678 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.676 .324 .676 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.765 .235 .765 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.362 .638 .362 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.933 .067 .933 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.715 .285 .715 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.457 .543 .457 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.432 .568 .432 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.987 .013 .987 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.676 .324 .676 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.404 .596 .404 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.986 .014 .986 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.92 .08 .92 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.79 .21 .79 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.917 .083 .917 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.371 .629 .371 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.895 .105 .895 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.7 .3 .7 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.585 .415 .585 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.987 .013 .987 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.574 .426 .574 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.479 .521 .479 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.987 .013 .987 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.734 .266 .734 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.982 .018 .982 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.988 .012 .988 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.596 .404 .596 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.985 .015 .985 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.501 .499 .501 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.986 .014 .986 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.558 .442 .558 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.785 .215 .785 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.63 .37 .63 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.877 .123 .877 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.893 .107 .893 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.717 .283 .717 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.625 .375 .625 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.707 .293 .707 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.831 .169 .831 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.887 .113 .887 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.828 .172 .828 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.841 .159 .841 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.983 .017 .983 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.705 .295 .705 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.91 .09 .91 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.985 .015 .985 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.932 .068 .932 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.917 .083 .917 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.713 .287 .713 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.92 .08 .92 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.898 .102 .898 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.768 .232 .768 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.985 .015 .985 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.983 .017 .983 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.903 .097 .903 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.987 .013 .987 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.987 .013 .987 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.985 .015 .985 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.986 .014 .986 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.985 .015 .985 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.986 .014 .986 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003oj1OXonPGj?l0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onPGj?oX5nP00_oX5nP00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oX5nSoj1OX00?oj1OX00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onPGj?oX5nP01OoX5nP00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj006onPGj003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onPGj?oX5nP02?oX5nP00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oZ5N[o0000013oo0?l00?o0000oo`3o?ol0o`02?ol
0o`9o`0000coj1OX00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onXEjP03o`000?ol
0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiQWVonHIiP05onHIiP03o`000?oX
5nSoj1OX00_oj1OX0ol00003onHIiP03o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onXEj_oZ5NX00ooZ5NX00ol0003oo0?loo`3o00;oo`3o0;o00002ool0o`00ol0003oiQWVonHIiP06
onHIiP03o`000?oX5nSoj1OX00[oj1OX00?o0000onHIi_oV6NH01?oV6NH00ol0003oo0?loo`3o00:
oo`3o004o`000?oU6^GoiA[UonDJi@;o00002_ol0o`2o`000003on@Ki?l0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZonXEjP05onXEjP03o`000?ol0oco
o0?l00Woo0?l00?o0000onXEj_l000002ool0o`00ol0003oiQWVonHIiP06onHIiP03o`000?oX5nSo
j1OX00Woj1OX00?o0000onHIi_oV6NH01_oV6NH00ol0003oo0?loo`3o008oo`3o003o`000?oU6^Go
iA[U00CoiA[U0_l00005oo`3o0?o00001?oT6n@00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008onXEjP03o`000?ol0ocoo0?l00Ooo0?l0_l00003onXE
jP03o`000?ol0ocoo0?l00Ooo0?l00?o0000onHIi_oV6NH01ooV6NH00ol0003oj1OXonPGj009onPG
j003o`000?oV6NKoiQWV00OoiQWV00?o0000oo`3o?ol0o`01Ool0o`2o`0000WoiA[U0_l000000ool
0oco0000o`000007on@Ki003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000onXEj_oZ
5NX02?oZ5NX00ol0003oo0?loo`3o006oo`3o003o`000?oZ5N[ojQGZ00?ojQGZ00?o0000oo`3o?ol
0o`01ool0o`00ol0003oiQWVonHIiP08onHIiP03o`000?oX5nSoj1OX00Ooj1OX00?o0000onHIi_oV
6NH02OoV6NH00ol0003oo0?loo`3o003oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000on@Ki?oT
6n@01ooT6n@00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKYo`000005oo`3o0;o00002ooZ5NX2o`0000Koo0?l
00?o0000onXEj_oZ5NX01OoZ5NX00ol0003oo0?loo`3o006oo`3o003o`000?oV6NKoiQWV00SoiQWV
00?o0000onPGj?oX5nP01_oX5nP00ol0003oiQWVonHIiP0;onHIiP05o`000?ol0ocoo0?loo`3o?l0
00003_oU6^D00ol0003oi1_Ton@Ki008on@Ki003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oY5^WojAKYonTFjOl0
00000ool0o`00ol0003ojQGZonXEjP0:onXEjP04o`000?oL8mcog2?Lo`0000?oo0?l0_l00008onXE
jP03o`000?ol0ocoo0?l00Koo0?l00?o0000onHIi_oV6NH02OoV6NH00ol0003oj1OXonPGj005onPG
j003o`000?oV6NKoiQWV00coiQWV00?o0000oo`3o?l000003ooU6^D00ol0003oi1_Ton@Ki008on@K
i003o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKYonTFj@03onTFj@03o`000?ol0oco000000_o
jQGZ0_l00004om`Sg003o`000?ol0oco000000_ojQGZ00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iQWVonHIiP09onHIiP03o`000?oX5nSoj1OX00Coj1OX00?o0000onHIi_oV6NH03_oV6NH00ol0003o
iA[UonDJi@0>onDJi@03o`000?oT6nCoi1_T00Woi1_T00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000onTFjOoY5^T0
1?oY5^T00ol0003ojQGZonXEjP09onXEjP03o`000?oL8mcog2?L00Gog2?L00?o0000onXEj_oZ5NX0
2_oZ5NX00ol0003oo0?loo`3o005oo`3o003o`000?oV6NKoiQWV00[oiQWV00?o0000onPGj?oX5nP0
0ooX5nP00ol0003oiQWVonHIiP0>onHIiP03o`000?oU6^GoiA[U00goiA[U00?o0000on@Ki?oT6n@0
2_oT6n@00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKYonTF
j@05onTFj@03o`000?oZ5N[ojQGZ00OojQGZ0_l00008om`Sg003o`000?oZ5N[ojQGZ00_ojQGZ00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oiQWVonHIiP0:onHIiP04o`000?oX5nSoj1OXonPGj0?o0000
3ooV6NH00ol0003oiA[UonDJi@0>onDJi@03o`000?oT6nCoi1_T00[oi1_T00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oY5^WojAKY00OojAKY00?o0000onXEj_oZ5NX01?oZ5NX2o`0000_og2?L1?l0
0009onXEjP03o`000?ol0ocoo0?l00?oo0?l00?o0000onHIi_oV6NH02ooV6NH01?l0003oj1OXo`00
0?l00003ol@ka0;o00003?oV6NH2o`00013oiA[U00?o0000on@Ki?oT6n@02ooT6n@00ol0003oo0?l
oo`3o00=oo`3o004o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojAKY
onTFj@07onTFj@03o`000?oZ5N[ojQGZ00?ojQGZ00?o0000om`Sg?oL8m`02ooL8m`01?l0003o^TFj
okY5^_njAKX5o`0000GojQGZ00?o0000oo`3o?ol0o`00_ol0o`00ol0003oiQWVonHIiP0<onHIiP03
o`000?o4>lCoa3_400Goa3_40_l00008onHIiP;o00000_ngB;L00ol0003oiA[UonDJi@0=onDJi@03
o`000?oT6nCoi1_T00_oi1_T00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003ojAKYonTFj@09onTFj@03o`000?oZ5N[ojQGZ00;o0000
3OoL8m`00ol0003o^TFjokY5^P07okY5^PKo00000_ol0o`4o`0000goiQWV00?o0000ol@ka?o4>l@0
1oo4>l@2o`0000GoiQWV00?o0000okM8]ongB;L00ongB;L00ol0003oiA[UonDJi@0<onDJi@03o`00
0?oT6nCoi1_T00coi1_T00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oY5^WojAKY00WojAKY00?o
0000onXEj_l000003ooL8m`00ol0003o^TFjokY5^P0<okY5^P?o00001?oK9=/3o`0000WoiQWV00?o
0000ol@ka?o4>l@02_o4>l@2o`000003onHIi_l0003o000000Oo]dRg00?o0000onDJiOoU6^D02ooU
6^D00ol0003oi1_Ton@Ki00<on@Ki003o`000?ol0ocoo0?l00Koo0?l1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oY5^WojAKY00_ojAKY00?o0000
om`Sg?oL8m`03_oL8m`00ol0003o^TFjokY5^P0=okY5^P03o`000?oK9=_ofbCK00KofbCK0ol00005
onHIiP03o`000?o4>lCoa3_400goa3_400?o0000okM8]ongB;L02?ngB;L00ol0003oiA[UonDJi@09
onDJi@03o`000?oT6nCoi1_T00goi1_T00Co0000oo`3o?ol0ocoo0?l1Ol00003onXEjP03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
onTFjOoY5^T02ooY5^T2o`0000oog2?L00?o0000okY5^_njAKX03OnjAKX00ol0003ofbCKom/Tf`0:
om/Tf`?o000000?oiQWVo`000?o4>l@03oo4>l@00ol0003o]dRgokM8]`09okM8]`03o`000?oU6^Go
iA[U00SoiA[U00?o0000on@Ki?oT6n@03_oT6n@3o`0000SojQGZ00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oY5^WojAKY00SojAKY0ol000000oo0
?l3o0000om`Sg00>om`Sg003o`000?njAK[o^TFj00go^TFj00?o0000om/TfooK9=/03OoK9=/00ol0
003oa3_4ol@ka00?ol@ka003o`000?ngB;Oo]dRg00[o]dRg2ol0000;on@Ki0Go00003?oZ5NX00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`02_ol0o`01Ol0003oj1OXo`000?ol0oco0000
00SojAKY0ol00005ol0o`003o`000?oL8mcog2?L00cog2?L00?o0000okY5^_njAKX03OnjAKX00ol0
003ofbCKom/Tf`0=om/Tf`;o00004?o4>l@00ol0003o]dRgokM8]`0:okM8]`03o`000?ncC;?o/dbc
00Oo/dbc00?o0000on@Ki?oT6n@00_oT6n@7o`0000Co]dRg00?o0000onXEj_oZ5NX02_oZ5NX00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`02Ool0o`01?l0003oj1OXonPGj?oX5nP2o`00
00GojAKY0ol00009ol0o`0;o00002ooL8m`00ol0003o^TFjokY5^P0=okY5^P03o`000?oK9=_ofbCK
00gofbCK00Co0000oka3_?nl@kco00003oo4>l@00ol0003o]dRgokM8]`09okM8]`03o`000?ncC;?o
/dbc00Wo/dbc1?l0000;okM8]`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?ol0ocoo0?l00Soo0?l00?o0000onPGj?oX5nP01?oX5nP00ol0003ojAKYo`000002o`00
00co`3o000Co0000oj1OX?l0003o00002OoL8m`00ol0003o^TFjokY5^P0=okY5^P03o`000?oK9=_o
fbCK00gofbCK00Go0000oka3_?nl@kco_4>lo`00000=ol@ka003o`000?ngB;Oo]dRg00[o]dRg00?o
0000ok=</oncC;<02OncC;<00ol0003o]dRgokM8]`0<okM8]`03o`000?oZ5N[ojQGZ00[ojQGZ00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00Ooo0?l00?o0000onPGj?oX5nP01_oX5nP0
0ol0003o`3o0ol0o`00<ol0o`003o`000?nPGj3oX5nP00;oX5nP0_l00007om`Sg003o`000?njAK[o
^TFj00co^TFj00?o0000om/TfooK9=/03OoK9=/00ol0003o_4>loka3_003oka3_003o`000?o4>lCo
a3_400[oa3_400?o0000okM8]ongB;L02_ngB;L00ol0003o/dbcok=</`09ok=</`03o`000?ngB;Oo
]dRg00co]dRg00?o0000onXEj_oZ5NX02ooZ5NX00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000oo`3
o?ol0o`01_ol0o`00ol0003oj1OXonPGj006onPGj003o`000?o0?l3o`3o000_o`3o000?o0000oj1O
X?nPGj001OnPGj000ol0003og2?Lom`Sg003om`Sg003o`000?njAK[o^TFj00go^TFj00?o0000om/T
fooK9=/03OoK9=/00ol0003o_4>loka3_004oka3_003o`000?o4>lCoa3_400Woa3_400?o0000okM8
]ongB;L02OngB;L00ol0003o/dbcok=</`0:ok=</`03o`000?ngB;Oo]dRg00co]dRg00?o0000onXE
j_oZ5NX02ooZ5NX00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
j1OXonPGj007onPGj003o`000?o0?l3o`3o000_o`3o000?o0000oj1OX?nPGj001_nPGj02o`0000?o
g2?L00?o0000okY5^_njAKX03OnjAKX00ol0003ofbCKom/Tf`0<om/Tf`03o`000?nl@kco_4>l00Ko
_4>l00?o0000ol@ka?o4>l@02?o4>l@00ol0003o]dRgokM8]`09okM8]`03o`000?ncC;?o/dbc00[o
/dbc00?o0000okM8]ongB;L03?ngB;L00ol0003ojQGZonXEjP0;onXEjP03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?ol0ocoo0?l00Coo0?l00?o0000onPGj?oX5nP02?oX5nP00ol0003o`3o0ol0o`00:ol0o`003o`00
0?nPGj3oX5nP00WoX5nP0_l000000ooL8mco0000okY5^P0<okY5^P?o00003_oK9=/00ol0003o_4>l
oka3_007oka3_003o`000?o4>lCoa3_400Ooa3_400?o0000okM8]ongB;L02OngB;L00ol0003o/dbc
ok=</`0;ok=</`03o`000?ngB;Oo]dRg00co]dRg00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008ood2o@03o`000?ol0ocoo0?l00?oo0?l00?o0000onPGj?oX5nP02_oX5nP00ol0003o`3o0ol0o
`009ol0o`003o`000?nPGj3oX5nP00_oX5nP00?o0000okY5^_njAKX02_njAKX2o`0000?oVVFJ00?o
0000om/TfooK9=/02_oK9=/00ol0003o_4>loka3_009oka3_003o`000?o4>lCoa3_400Koa3_400?o
0000okM8]ongB;L02?ngB;L00ol0003o/dbcok=</`0<ok=</`03o`000?ngB;Oo]dRg00co]dRg00?o
0000onXEj_oZ5NX02_oZ5NX00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Oom0_d0
0ol0003oo0?loo`3o002oo`3o003o`000?oX5nSoj1OX00_oj1OX00?o0000ol0o`?o0?l002?o0?l00
0ol0003oX5nPoj1OX00<oj1OX003o`000?njAK[o^TFj00So^TFj0_l00006oiYUVP;o00002_oK9=/0
0ol0003o_4>loka3_00:oka3_003o`000?o4>lCoa3_400Goa3_400?o0000okM8]ongB;L02?ngB;L0
0ol0003o/dbcok=</`0<ok=</`03o`000?ngB;Oo]dRg00co]dRg00?o0000onXEj_oZ5NX02ooZ5NX0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo@;m00Go0000oo`3o?ol0ocoo0?lo`00000=
onPGj003o`000?o0?l3o`3o000Oo`3o000?o0000oj1OX?nPGj003_nPGj000ol0003o^TFjokY5^P04
okY5^P?o00002_nJIIX00ol0003ofbCKom/Tf`07om/Tf`03o`000?nl@kco_4>l00_o_4>l00?o0000
ol@ka?o4>l@00oo4>l@00ol0003o]dRgokM8]`09okM8]`03o`000?ncC;?o/dbc00co/dbc00?o0000
okM8]ongB;L03?ngB;L00ol0003ojQGZonXEjP0;onXEjP;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003oj1OXonPGj00<onPGj003o`000?o0?l3o`3o000Oo`3o000?o0000oj1OX?nPGj003onPGj001?l0
003o^TFjokY5^_njAKX2o`0000koVVFJ0_l00006om/Tf`03o`000?nl@kco_4>l00go_4>l00?o0000
ol@ka?o4>l@00_o4>l@00ol0003o]dRgokM8]`08okM8]`03o`000?ncC;?o/dbc00co/dbc0ol0000=
okM8]`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00ooj1OX00?o0000ol0o`?o0?l001_o0?l000ol0003oX5nPoj1OX00@oj1OX0Co00004_nJIIX00ol0
003ofbCKom/Tf`03om/Tf`03o`000?nl@kco_4>l00ko_4>l00Go0000ol@ka?o4>lCoa3_4o`000005
okM8]`Oo00003?ncC;<01Ol0003oP7n0oh1oP?n0Oh3o000000co]dRg00?o0000onXEj_oZ5NX02?oZ
5NX3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000ooj1OX00?o0000ol0o`?o0?l001_o0?l000ol0003oX5nPoj1OX00=
oj1OX0?o000000CoKY5^o`000?l0003o00004onJIIX2o`0000;ofbCK00?o0000oka3_?nl@k`04?nl
@k`00ol0003oa3_4o`000006o`0000Oo[E:]00?o0000ok=</oncC;<02?ncC;<00ol0003oP7n0oh1o
P003oh1oP0;o00002?ngB;L3o`0000KojQGZ1?l00002onDJi@03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003ojAKYo`000?nkA;/3o`0000goj1OX00?o0000ol0o`?o0?l001?o0?l000ol0003oX5nPoj1O
X00;oj1OX0?o00000om^TFh01Ol0003oL8m`o`000?mTVfCo000001CoVVFJ00?o0000om/Tfol00000
4onl@k`00ol0003o[E:]ojeB[@0=ojeB[@03o`000?ncC;?o/dbc00Go/dbc0_l00008oh1oP003o`00
0?ngB;Oo]dRg00Go00000ondBk@00ol0003ojQGZonXEjP03o`0000OoiA[U00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?oY5^WojAKYo`0000Co^dBk0ol0000:onPGj003o`000?o0?l3o`3o000?o`3o0
00?o0000oj1OX?nPGj002OnPGj03o`0000GoKY5^00Co0000og2?L?m`Sg3o00000_mTVf@00ol0003o
VVFJoiYUVP0BoiYUVP03o`000?nl@kco_4>l01;o_4>l00?o0000ojeB[On]DZd03_n]DZd00ol0003o
/dbcok=</`03ok=</`03o`000?n0Oh3oP7n000WoP7n00_l00009okA;]0;o00002_oU6^D00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000onTFjOoY5^WojAKYo`000007ok]4^`;o00001ooX5nP5o`0000;o
`3o000?o0000oj1OX?nPGj001_nPGj03o`0000SoKY5^00Co0000og2?L?m`Sg3o00000omTVf@00ol0
003oVVFJoiYUVP0AoiYUVP03o`000?nl@kco_4>l017o_4>l00?o0000ojeB[On]DZd04?n]DZd01Ol0
003o/dbcok=</oncC;?o000000coP7n000?o0000okA;]?ndBk@02?ndBk@00ol0003oiA[UonDJi@0:
onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CojAKY00?o0000ok]4^onkA;/01onkA;/3o`00
0004onPGj?l0003o0000o`0000GoYeRW0_l00006oj1OX0?o00002_m^TFh01Ol0003oL8m`og2?L?m`
Sg3o000000CoI9]T00?o0000oiYUV_nJIIX04?nJIIX00ol0003o_4>loka3_00Aoka3_003o`000?n]
DZgo[E:]017o[E:]00?o0000ok=</ol000003On0Oh000ol0003o]4^dokA;]008okA;]003o`000?oU
6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?oY5^WojAKY00CojAKY00?o0000
ok]4^onkA;/02_nkA;/00ol0003oYeRWojMHY`08ojMHY`03o`000?nPGj3oX5nP00?o00003Om^TFh0
1Ol0003oL8m`og2?L?m`Sg3o000000GoI9]T00?o0000oiYUV_nJIIX03onJIIX00ol0003o_4>loka3
_00Aoka3_003o`000?n]DZgo[E:]01;o[E:]00?o0000oh1oP?n0Oh003?n0Oh000ol0003o]4^dokA;
]008okA;]003o`000?oU6^GoiA[U00_oiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000onTFjOoY5^T01OoY5^T0
0ol0003o^dBkok]4^`0:ok]4^`03o`000?nWF:OoYeRW00WoYeRW0_l0000?ofjAKP03o`000?m`Sg3o
L8m`00;oL8m`00?o0000ofBKI?mTVf@01?mTVf@00ol0003oVVFJoiYUVP0=oiYUVP?o00004Onl@k`0
0ol0003o[E:]ojeB[@0CojeB[@03o`000?n0Oh3oP7n000_oP7n000?o0000okA;]?ndBk@02OndBk@0
0ol0003oiA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?oY5^T0
0ol0003o^dBkok]4^`0:ok]4^`03o`000?nWF:OoYeRW00WoYeRW00?o0000ofjAK_m^TFh03Om^TFh0
0ol0003oL8m`og2?L003og2?L003o`000?mTVfCoI9]T00GoI9]T00?o0000oiYUV_nJIIX02_nJIIX2
o`0000?oW6>L00?o0000oka3_?nl@k`03_nl@k`00ol0003o[E:]ojeB[@0CojeB[@03o`000?n0Oh3o
P7n000_oP7n000?o0000okA;]?ndBk@02OndBk@00ol0003oiA[UonDJi@0;onDJi@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000onTFjOoY5^T01ooY5^T2o`0000_o^dBk00?o0000ojMH
YonWF:L02onWF:L00ol0003oKY5^ofjAKP0<ofjAKP03o`000?m`Sg3oL8m`00?oL8m`00?o0000ofBK
I?mTVf@01_mTVf@00ol0003oVVFJoiYUVP07oiYUVP;o00001_nLHi`2o`0000ko_4>l00?o0000ojeB
[On]DZd04on]DZd00ol0003oP7n0oh1oP00;oh1oP003o`000?ndBkCo]4^d00Wo]4^d00?o0000onDJ
iOoU6^D03?oU6^D00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009onTF
j@03o`000?o1?/7o000000_o^dBk00?o0000ojMHYonWF:L02onWF:L00ol0003oKY5^ofjAKP0;ofjA
KP03o`000?m`Sg3oL8m`00CoL8m`00?o0000ofBKI?mTVf@01omTVf@00ol0003oVVFJoiYUVP05oiYU
VP03o`000?nLHicoW6>L00SoW6>L00?o0000oka3_?nl@k`02_nl@k`00ol0003o[E:]ojeB[@0DojeB
[@03o`000?n0Oh3oP7n000_oP7n000?o0000okA;]?ndBk@02OndBk@00ol0003oiA[UonDJi@0<onDJ
i@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009onTFj@04o`000?o1?/7o`Ck1o`00
00_o^dBk00?o0000ojMHYonWF:L02onWF:L00ol0003oKY5^ofjAKP0;ofjAKP03o`000?m`Sg3oL8m`
00CoL8m`00?o0000ofBKI?mTVf@02?mTVf@00ol0003oVVFJoiYUVP02oiYUVP;o00003?nLHi`2o`00
00[o_4>l00?o0000ojeB[On]DZd05?n]DZd00ol0003oP7n0oh1oP00;oh1oP003o`000?ndBkCo]4^d
00Wo]4^d00?o0000onDJiOoU6^D03OoU6^D00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojAKYonTFj@07onTFj@03
o`000?o1?/7o`Ck100;o`Ck100?o0000ok]4^onkA;/02?nkA;/00ol0003oYeRWojMHY`0<ojMHY`03
o`000?m^TFkoKY5^00WoKY5^00?o0000og2?L?m`Sg001Om`Sg000ol0003oI9]TofBKI009ofBKI004
o`000?nJII[o0000o`00013oW6>L0_l00008oka3_003o`000?n]DZgo[E:]01Co[E:]0ol0000;oh1o
P003o`000?ndBkCo]4^d00Wo]4^d00?o0000onDJiOoU6^D03OoU6^D01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ojAKYonTFj@06onTFj@03o`000?o1?/7o`Ck100?o`Ck100?o0000ok]4
^onkA;/02?nkA;/00ol0003oYeRWojMHY`0;ojMHY`;o00002_m^TFh00ol0003oL8m`og2?L006og2?
L003o`000?mTVfCoI9]T00[oI9]T00?o0000oiaSW?nLHi`04_nLHi`00ol0003o_4>loka3_004oka3
_003o`000?n]DZgo[E:]01Go[E:]00?o0000oiQWV?nHIiP01Ol00005oh1oP003o`000?ndBkCo]4^d
00[o]4^d00?o0000onDJiOoU6^D03_oU6^D3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKYonTFj@04onTFj@03
o`000?o1?/7o`Ck100Co`Ck100?o0000ok]4^onkA;/01onkA;/00ol0003oYeRWojMHY`0;ojMHY`04
o`000?mjQG[oNXEjo`0000WoKY5^00?o0000og2?L?m`Sg001_m`Sg000ol0003oI9]TofBKI00:ofBK
I003o`000?nLHicoW6>L01?oW6>L0_l00003oka3_0Co00005?n]DZd00ol0003oV6NHoiQWV006oiQW
V0Co000000?oP7n0o`000?ndBk@02ondBk@00ol0003oiA[UonDJi@0>onDJi@03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003ojAKYonTFj@03onTFj@03o`000?o1?/7o`Ck100Go`Ck100?o0000ok]4^onk
A;/01onkA;/00ol0003oYeRWojMHY`09ojMHY`;o00001?mjQGX00ol0003oKY5^ofjAKP05ofjAKP03
o`000?m`Sg3oL8m`00OoL8m`00?o0000ofBKI?mTVf@02_mTVf@00ol0003oW6>LoiaSW00EoiaSW003
o`000?nl@kco000000CoZ5NX0ol0000@ojeB[@03o`000?nHIiSoV6NH00_oV6NH0_l0000<okA;]003
o`000?oU6^GoiA[U00coiA[U0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onTFjOoY5^T00_oY5^T00ol0003o`Ck1
ol4n`@06ol4n`@03o`000?nkA;_o^dBk00Oo^dBk00?o0000ojMHYonWF:L02?nWF:L00ol0003oNXEj
ogZ5NP05ogZ5NP03o`000?m^TFkoKY5^00CoKY5^00?o0000og2?L?m`Sg001om`Sg000ol0003oI9]T
ofBKI00:ofBKI003o`000?nLHicoW6>L01KoW6>L00?o0000ojQGZ?nXEjP01_nXEjP3o`0000co[E:]
00?o0000oiQWV?nHIiP03OnHIiP00ol0003o]4^dokA;]009okA;]0Go00002OoU6^D2o`000003onLH
iol0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003onTFjOl0003o`Ck100Wo`Ck100?o0000ok]4^onkA;/01_nk
A;/00ol0003oYeRWojMHY`07ojMHY`03o`000?mjQG[oNXEj00OoNXEj00?o0000ofjAK_m^TFh00_m^
TFh00ol0003oL8m`og2?L008og2?L003o`000?mTVfCoI9]T00WoI9]T00?o0000oiaSW?nLHi`05onL
Hi`00ol0003oZ5NXojQGZ009ojQGZ0?o00002On]DZd00ol0003oV6NHoiQWV00>oiQWV0Ko00001?nd
Bk@00ol0003o]TVfokI9]P03okI9]PGo00000_oU6^D2o`0000CoiaSW00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oK9=_ofbCKom/Tfol000002oo1?/400ol0003o^dBkok]4^`06ok]4^`03o`000?nW
F:OoYeRW00GoYeRW0_l0000;ogZ5NP04o`000?m^TFkoKY5^o`0000_oL8m`00?o0000ofBKI?mTVf@0
2OmTVf@00ol0003oW6>LoiaSW00FoiaSW003o`000?nXEjSoZ5NX00goZ5NX0ol00005ojeB[@03o`00
0?nHIiSoV6NH00ooV6NH00?o0000oimOWonOGil00onOGil4o`0000_o]TVf0_l00006onLHi`03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ofbCKom/Tf`02om/Tf`ko00001_nkA;/00ol0003oYeRWojMH
Y`05ojMHY`03o`000?mjQG[oNXEj00coNXEj00?o0000ofjAK_l000002om`Sg000ol0003oI9]TofBK
I007ofBKI0?o00006?nLHi`00ol0003oZ5NXojQGZ00@ojQGZ0?o000000?o[E:]o`000?nHIiP04?nH
IiP00ol0003oWenOoimOW`07oimOW`03o`000?nfBKKo]TVf00[o]TVf00?o0000onLHiooW6>L01OoW
6>L00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005om/Tf`03o`000?nJII[oVVFJ00_oVVFJ0_l00004
ok]4^`03o`000?nWF:OoYeRW00?oYeRW0_l0000@ogZ5NP03o`000?m`Sg3oL8m`00[oL8m`00?o0000
ofBKI?mTVf@00omTVf@4o`0000;oDZeB00?o0000oiaSW?nLHi`05OnLHi`00ol0003oZ5NXojQGZ00D
ojQGZ003o`000?nHIiSoV6NH013oV6NH00?o0000oimOWonOGil01onOGil00ol0003o]TVfokI9]P0:
okI9]P03o`000?oW6>OoiaSW00GoiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oK9=_ofbCK
00GofbCK00?o0000oiYUV_nJIIX03OnJIIX6o`0000?oYeRW00?o0000ogZ5N_mjQGX04?mjQGX00ol0
003oL8m`og2?L00:og2?L003o`000?mTVfCo000000?o00001omB[E800ol0003oW6>LoiaSW00DoiaS
W003o`000?nXEjSoZ5NX01CoZ5NX00?o0000oiQWV?nHIiP03onHIiP00ol0003oWenOoimOW`08oimO
W`03o`000?nfBKKo]TVf00[o]TVf00?o0000onLHiooW6>L01OoW6>L00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000om/TfooK9=/01_oK9=/00ol0003oVVFJoiYUVP0=oiYUVP03o`000?nPGj3oX5nP00?o
X5nP00?o0000ojMHYol000004omjQGX4o`0000WoL8m`0_l0000<oe:]DP03o`000?nLHicoW6>L01?o
W6>L00?o0000ojQGZ?nXEjP05OnXEjP00ol0003oV6NHoiQWV00>oiQWV003o`000?nOGiooWenO00So
WenO00?o0000okI9]_nfBKH02OnfBKH00ol0003oiaSWonLHi`07onLHi`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oK9=_ofbCK00SofbCK00?o0000oiYUV_nJIIX02onJIIX00ol0003oX5nPoj1OX005oj1OX003o`00
0?mjQG[oNXEj01;oNXEj00Co0000oenPGomOX5ooGj1O1Ol00003og2?L003o`000?mB[E;oDZeB00go
DZeB0ol0000@oiaSW0;o00006?nXEjP00ol0003oV6NHoiQWV00=oiQWV003o`000?nOGiooWenO00Wo
WenO00?o0000okI9]_nfBKH02OnfBKH00ol0003oiaSWonLHi`07onLHi`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_ofbCK00?o0000oiYUV_nJIIX02_nJIIX00ol0003oX5nPoj1OX006oj1OX003o`00
0?mjQG[oNXEj017oNXEj00?o0000oenPGomOX5l01omOX5l3o`00013oDZeB00?o0000od^dBom;]4/0
1Ol00009oiaSW0;o000000?oHiaSo`000?nXEjP05onXEjP00ol0003oV6NHoiQWV00=oiQWV003o`00
0?nOGiooWenO00WoWenO00?o0000okI9]_nfBKH02?nfBKH2o`0000[oiaSW00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?o/4ncok1?/00;ok1?/00?o0000om/TfooK9=/02OoK9=/00ol0003oVVFJoiYU
VP0:oiYUVP03o`000?nPGj3oX5nP00OoX5nP00?o0000ogZ5N_mjQGX03omjQGX00ol0003oGj1OoenP
G`0:oenPG`03o`000?mB[E;oDZeB00goDZeB00?o0000od^dBom;]4/01_m;]4/4o`0000CoW6>L00?o
0000of>LHomSW6<00_mSW6<00ol0003oZ5NXojQGZ00FojQGZ003o`000?nHIiSoV6NH00_oV6NH00?o
0000oimOWonOGil02onOGil00ol0003o]TVfokI9]P06okI9]P03o`000?o4>lCo000000[oiaSW00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?o/4ncok1?/00?ok1?/00?o0000om/TfooK9=/02?oK9=/=
o`0000[oX5nP00?o0000ogZ5N_mjQGX03omjQGX00ol0003oGj1OoenPG`0;oenPG`03o`000?mB[E;o
DZeB00coDZeB00?o0000od^dBom;]4/02_m;]4/4o`0000GoHiaS00?o0000ojQGZ?nXEjP05_nXEjP0
0ol0003oV6NHoiQWV00:oiQWV003o`000?nOGiooWenO00coWenO00?o0000okI9]_nfBKH01?nfBKH2
o`0000?oa3_400?o0000onLHiooW6>L02?oW6>L00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on`C
k?o/4n`00oo/4n`00ol0003ofbCKom/Tf`07om/Tf`03o`000?nGJ9OoUfRG00WoUfRG00?o0000oj1O
X?nPGj002OnPGj000ol0003oNXEjogZ5NP0=ogZ5NP03o`000?mOX5ooGj1O00coGj1O00?o0000oe:]
D_mB[E803?mB[E800ol0003oBkA;od^dB`0;od^dB`03o`000?lbcC;o000000KoHiaS00?o0000ojQG
Z?nXEjP05_nXEjP00ol0003oV6NHoiQWV009oiQWV003o`000?nOGiooWenO00coWenO00?o0000okI9
]_nfBKH00onfBKH00ol0003oa3_4ol@ka003ol@ka003o`000?oW6>OoiaSW00SoiaSW00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?o/4ncok1?/00Cok1?/00?o0000om/TfooK9=/01_oK9=/00ol0003o
UfRGoiMXU`08oiMXU`03o`000?nPGj3oX5nP00_oX5nP00?o0000ogZ5N_mjQGX02?mjQGX4o`0000oo
Gj1O00?o0000oe:]D_mB[E802omB[E800ol0003oBkA;od^dB`0;od^dB`04o`000?lbcC;o</dbo`00
00OoHiaS00?o0000ojQGZ?nXEjP05OnXEjP00ol0003oV6NHoiQWV008oiQWV003o`000?nOGiooWenO
00goWenO00?o0000okI9]_nfBKH00_nfBKH00ol0003oa3_4ol@ka005ol@ka003o`000?oW6>OoiaSW
00OoiaSW00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?o/4ncok1?/00Gok1?/00?o0000om/TfooK
9=/01OoK9=/00ol0003oUfRGoiMXU`08oiMXU`03o`000?nPGj3oX5nP00_oX5nP00?o0000ogZ5N_mj
QGX00omjQGX5o`0000?oGimO00?o0000oenPGomOX5l03_mOX5l00ol0003oDZeBoe:]DP0:oe:]DP03
o`000?m;]4_oBkA;00[oBkA;00Go0000oc;=<_lbcC;o</dbo`000007of>LH`03o`000?nXEjSoZ5NX
01GoZ5NX00?o0000oiQWV?nHIiP02?nHIiP00ol0003oWenOoimOW`0=oimOW`03o`000?nfBKKo]TVf
00;o00002?o4>l@00ol0003oiaSWonLHi`08onLHi`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ok1?/on`Ck005on`Ck003o`000?oK9=_ofbCK00Go
fbCK00?o0000oiMXUonGJ9L02?nGJ9L00ol0003oX5nPoj1OX00<oj1OX0Go00002OmOWel00ol0003o
Gj1OoenPG`0<oenPG`;o00003?mB[E800ol0003oBkA;od^dB`0:od^dB`05o`000?lbcC;o</dboc;=
<_l000002?mSW6<00ol0003oZ5NXojQGZ00DojQGZ0?o00001onHIiP00ol0003oWenOoimOW`0>oimO
W`03o`000?nfBKKo000000_oa3_400?o0000onLHiooW6>L01_oW6>L00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000on`Ck?o/4n`01Oo/4n`00ol0003ofbCKom/Tf`04om/Tf`03o`000?nGJ9OoUfRG00Oo
UfRG00?o0000oj1OX?nPGj003?nPGj001?l0003oNhAkog^4Nol0000;oenOG`03o`000?mOX5ooGj1O
00_oGj1O00Co0000obkA;_l^dBko00002_mB[E800ol0003oBkA;od^dB`0:od^dB`03o`000?lbcC;o
</db00;o</db00?o0000of>LHomSW6<01_mSW6<00ol0003oZ5NXojQGZ00AojQGZ0?o00000omdRg@0
0ol0003oV6NHoiQWV004oiQWV003o`000?nOGiooWenO00goWenO1?l0000;ol@ka003o`000?oW6>Oo
iaSW00GoiaSW00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?o/4ncok1?/00Kok1?/00Co0000om/T
fooK9=_ofbCK1?l00008oiMXU`03o`000?nPGj3oX5nP00_oX5nP00?o0000og^4NomkQ7/00_mkQ7/0
0ol0003oGimOoenOG`08oenOG`03o`000?mOX5ooGj1O00[oGj1O00?o0000obkA;_l^dBh00_l^dBh0
0ol0003oDZeBoe:]DP03oe:]DPGo00002om;]4/00ol0003o</dboc;=<P03oc;=<P03o`000?mSW6?o
HiaS00OoHiaS00?o0000ojQGZ?nXEjP03_nXEjP2o`0000OoM8]d00?o0000oiQWV?nHIiP00_nHIiP0
0ol0003oWenOoimOW`0=oimOW`03o`000?ndBkCo]4^d00;o]4^d00?o0000ol@ka?o4>l@02Oo4>l@0
0ol0003oiaSWonLHi`03onLHi`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ok1?/on`Ck007on`C
k0?o00001?o6>LH00ol0003oUfRGoiMXU`05oiMXU`03o`000?nPGj3oX5nP00[oX5nP00?o0000og^4
NomkQ7/00omkQ7/00ol0003oGimOoenOG`09oenOG`03o`000?mOX5ooGj1O00SoGj1O00?o0000obkA
;_l^dBh01?l^dBh5o`0000Co0_d200?o0000od^dBom;]4/02Om;]4/00ol0003o</dboc;=<P03oc;=
<P03o`000?mSW6?oHiaS00SoHiaS00?o0000ojQGZ?nXEjP02_nXEjP3o`0000[oM8]d00Go0000oiQW
V?nHIiSoV6NHo`00000>oimOW`03o`000?ndBkCo]4^d00Co]4^d0_l00009ol@ka003o`000?oW6>Oo
iaSW00;oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?o/4ncok1?/00Ook1?/00?o0000olHi
a_o6>LH01Oo6>LH00ol0003oUfRGoiMXU`03oiMXU`03o`000?nPGj3oX5nP00[oX5nP00?o0000og^4
NomkQ7/01?mkQ7/00ol0003oGimOoenOG`09oenOG`03o`000?mOX5ooGj1O00OoGj1O00?o0000obkA
;_l^dBh01Ol^dBh00ol0003o0_d2o`;m0P07o`;m0P03o`000?m;]4_oBkA;00OoBkA;00?o0000oc;=
<_lbcC801?lbcC800ol0003oHiaSof>LH`08of>LH`03o`000?nXEjSoZ5NX00SoZ5NX0_l0000>ogB;
M0Co00003?nOGil2o`0000Wo]4^d00?o0000ol@ka?o4>l@01oo4>l@01?l0003oiaSWonLHiol0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000on`Ck?o/4n`01Oo/4n`00ol0003oaSW6olHiaP07olHiaP;o00000onGJ9L00ol0
003oX5nPoj1OX009oj1OX003o`000?mkQ7_oNhAk00KoNhAk00?o0000oenOGomOWel02OmOWel00ol0
003oGj1OoenPG`05oenPG`03o`000?l^dBko;]4^00Ko;]4^00?o0000o`;m0_l2o@802?l2o@800ol0
003oBkA;od^dB`06od^dB`03o`000?lbcC;o</db00Co</db00?o0000of>LHomSW6<02OmSW6<4o`00
00?oZ5NX0ol0000@ogB;M005o`000?nkA;_o^dBkok]4^ol000002_nOGil00ol0003o]4^dokA;]00:
okA;]0Ko00000oo4>l@00ol0003oiaSWo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000on`Ck?o/4n`01?o/4n`00ol0
003oaSW6olHiaP0:olHiaP04o`000?nGJ9OoUfRGo`0000[oX5nP00?o0000og^4NomkQ7/01omkQ7/0
0ol0003oGimOoenOG`09oenOG`03o`000?mOX5ooGj1O00CoGj1O00?o0000obkA;_l^dBh01ol^dBh0
0ol0003o0_d2o`;m0P08o`;m0P;o00001_m;]4/00ol0003o</dboc;=<P05oc;=<P03o`000?mSW6?o
HiaS00WoHiaS00Co0000oe6^DOmA[U7oDJiA0ol0000BogB;M003o`000?nkA;_o^dBk00?o^dBk0_l0
0006oimOW`;o00003OndBk@00ol0003ojaC[on/Dj`03on/Dj`Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000on`Ck?o/4n`00oo/4n`0
0ol0003oaSW6olHiaP0<olHiaP;o00002_nPGj000ol0003oNhAkog^4N`08og^4N`03o`000?mOWeoo
GimO00[oGimO00?o0000oenPGomOX5l00_mOX5l00ol0003o;]4^obkA;P08obkA;P03o`000?l2o@;o
0_d200Ko0_d20_l00002ob[E:P03o`000?m;]4_oBkA;00;oBkA;00?o0000oc;=<_lbcC801_lbcC80
0ol0003oHiaSof>LH`08of>LH`03o`000?mA[U7oDJiA00CoDJiA00?o0000ogB;M?mdRg@03omdRg@0
0ol0003o^dBkok]4^`06ok]4^`;o00000onOGil00ol0003o]4^dokA;]00=okA;]003o`000?o[5>_o
jaC[00OojaC[0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003ok1?/on`Ck002on`Ck003o`000?o6>LKoaSW6
00koaSW600?o0000oj1OX?nPGj001onPGj000ol0003oNhAkog^4N`0:og^4N`03o`000?mOWeooGimO
00WoGimO00Go0000oenPGomOX5ooGj1Oo`00000;obkA;P03o`000?l2o@;o0_d200Co0_d20_l00005
ob[E:P05o`000?m;]4_oBkA;od^dBol000002?lbcC800ol0003oHiaSof>LH`08of>LH`03o`000?mA
[U7oDJiA00GoDJiA00?o0000ogB;M?mdRg@03_mdRg@00ol0003o^dBkok]4^`08ok]4^`03o`000?nO
Gioo000000oo]4^d00?o0000on/Djoo[5>/02?o[5>/01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?o/4ncok1?/o`00017oaSW600?o0000oj1OX?nPGj001_nPGj000ol0003oNhAk
og^4N`0;og^4N`03o`000?mOWeooGimO00WoGimO00Co0000oenPGomOX5oo00003?l^dBh00ol0003o
0_d2o`;m0P02o`;m0P;o00002?lZeBX00ol0003oBkA;o`000009oc;=<P03o`000?mSW6?oHiaS00So
HiaS00?o0000oe6^DOmA[U401OmA[U400ol0003oM8]dogB;M00=ogB;M003o`000?nkA;_o^dBk00[o
^dBk00?o0000okA;]?ndBk@03_ndBk@00ol0003ojaC[on/Dj`07on/Dj`03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000BolHiaP03o`00
0?nPGj3oX5nP00CoX5nP00?o0000og^4NomkQ7/03?mkQ7/00ol0003oGimOoenOG`0:oenOG`?o0000
3?l^dBh00ol0003o0_d2o`;m0P02o`0000_o:]DZ00?o0000oc;=<_lbcC802?lbcC800ol0003oHiaS
of>LH`07of>LH`03o`000?mA[U7oDJiA00OoDJiA00?o0000ogB;M?mdRg@03?mdRg@00ol0003o^dBk
ok]4^`0;ok]4^`;o00003_ndBk@00ol0003ojaC[on/Dj`07on/Dj`03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003oaSW6olHiaP0?olHiaP?o00000onP
Gj000ol0003oNhAkog^4N`0>og^4N`03o`000?mOWeooGimO00SoGimO00Co0000ocO8=olgb3Oo=lPg
0_l0000:obkA;P?o00003OlZeBX00ol0003o</dboc;=<P08oc;=<P03o`000?mSW6?oHiaS00OoHiaS
00?o0000oe6^DOmA[U401omA[U400ol0003oM8]dogB;M00;ogB;M003o`000?nkA;_o^dBk00co^dBk
00?o0000omLXeol000000_l0000:okA;]003o`000?o[5>_ojaC[00SojaC[00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@04ondBk@03o`000?o6>LKoaSW600coaSW60_l0
0003ojaC[003o`000?nPGj3o0000017oNhAk00?o0000oenOGomOWel01omOWel00ol0003o=lPgocO8
=`04ocO8=`;o00002?l^dBh00ol0003o:]DZob[E:P0>ob[E:P;o00002?lbcC800ol0003oHiaSof>L
H`06of>LH`03o`000?mA[U7oDJiA00WoDJiA00?o0000ogB;M?mdRg@02OmdRg@00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oG:=OoebSG00;oebSG0ol00007okA;]003o`000?o[5>_ojaC[00OojaC[00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@05ondBk@03o`000?o6>LKo
aSW600WoaSW60_l00006ojaC[003o`000?mkQ7_oNhAk013oNhAk00?o0000oenOGomOWel01_mOWel0
0ol0003o=lPgocO8=`07ocO8=`03o`000?l^dBko;]4^00Co;]4^0ol0000>ob[E:P03o`000?lFjAKo
5^TF00?o00001OlbcC800ol0003oHiaSof>LH`06of>LH`03o`000?mA[U7oDJiA00[oDJiA00?o0000
ogB;M?mdRg@02?mdRg@00ol0003o^dBkok]4^`0=ok]4^`03o`000?oG:=OoebSG00GoebSG0ol00004
okA;]003o`000?o[5>_ojaC[00OojaC[00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003okA;]ondBk@06ondBk@03o`000?o6>LKoaSW600GoaSW60ol00008ojaC[003o`000?mkQ7_oNhAk
017oNhAk00Co0000oenOGomOWeooGimO1?l0000;ocO8=`;o000000Co;]4^o`000?l0003o00000om4
^d@2o`0000_o:]DZ00?o0000oaKY5_lFjAH01?lFjAH2o`0000?o</db00?o0000of>LHomSW6<01_mS
W6<00ol0003oDJiAoe6^D@0:oe6^D@03o`000?mdRgCoM8]d00OoM8]d00?o0000ok]4^onkA;/03_nk
A;/00ol0003oebSGomLXe`08omLXe`Co00002_o[5>/00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003okA;]ondBk@07ondBk@03o`000?o6>LKoaSW600;oaSW60_l0000<ojaC[003o`000?mkQ7_o
NhAk013oNhAk1?l00003oe6^D@03o`000?lgb3Oo=lPg00_o=lPg00?o0000odBkA?m4^d@01_m4^d@0
0ol0003o:]DZob[E:P07ob[E:P03o`000?lFjAKo5^TF00Oo5^TF3?l0000>oe6^D@03o`000?mdRgCo
M8]d00KoM8]d00?o0000ok]4^onkA;/03_nkA;/00ol0003oebSGomLXe`0;omLXe`03o`000?o[5>_o
jaC[00OojaC[00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00WokA;]00Co0000olHi
a_l0003o00003_n/Dj`00ol0003oNhAkog^4N`0?og^4N`03o`000?mA[U7oDJiA00KoDJiA00?o0000
ocO8=olgb3L02_lgb3L00ol0003oA;]4odBkA007odBkA0;o00001_lZeBX00ol0003o5^TFoaKY5P08
oaKY5P03o`000?m[U6_oJiA[00SoJiA[00?o0000oe6^DOmA[U403?mA[U400ol0003oM8]dogB;M005
ogB;M003o`000?nkA;_o^dBk00oo^dBk0_l0000=omLXe`03o`000?o[5>_ojaC[00KojaC[00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00[okA;]00?o0000ojaC[?n/Dj`03_n/Dj`00ol0
003oNhAkog^4N`0>og^4N`03o`000?mA[U7oDJiA00OoDJiA00?o0000ocO8=olgb3L02_lgb3L00ol0
003oA;]4odBkA009odBkA0;o00000olZeBX00ol0003o5^TFoaKY5P09oaKY5P03o`000?m[U6_oJiA[
00WoJiA[00?o0000oe6^DOmA[U402_mA[U44o`0000CoM8]d00?o0000ok]4^onkA;/04?nkA;/01?l0
003odbcCo`000?l0000<omLXe`03o`000?o[5>_ojaC[00GojaC[00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o]4^gokA;]00[okA;]00?o0000ojaC[?n/Dj`03on/Dj`@o`0000[oDJiA00?o0000ocO8
=olgb3L02Olgb3L00ol0003o7^4No`00000<odBkA005o`000?lZeB[o0000oaOX5ol000002_lFjAH0
0ol0003oJiA[of^DJ`09of^DJ`03o`000?mA[U7oDJiA00OoDJiA0ol00004ogf2O@?o000000?oM8]d
o`000?nkA;/04OnkA;/01?l0003odbcCom</dooC;=<2o`0000_oebSG00?o0000on/Djoo[5>/00oo[
5>/00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003o[5>/ojaC[00?
ojaC[003o`000?n2OH;oPWf200coPWf200?o0000oe6^DOmA[U402OmA[U400ol0003o=lPgocO8=`07
ocO8=`04o`000?lNhAko7^4No`0000goA;]400Go0000oaOX5olGj1Oo5nPGo`000009oaKY5P03o`00
0?m[U6_oJiA[00[oJiA[00?o0000oe6^DOmA[U400omA[U43o`0000[oOH9m00?o0000ok]4^onkA;/0
4?nkA;/00ol0003odbcCom</d`04om</d`;o00002_oG:=L00ol0003ojaC[on/Dj`04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cokA;]00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oPWf2oh9mPP0<oh9mPP03o`000?mA
[U7oDJiA00WoDJiA00?o0000ocO8=olgb3L01_lgb3L00ol0003o7^4NoakQ7P02oakQ7P03o`000?m4
^dCoA;]400[oA;]400?o0000oaOX5olGj1L00_lGj1L00ol0003o5^TFoaKY5P06oaKY5P03o`000?m[
U6_oJiA[00[oJiA[00?o0000oe6^DOmA[U400ol0000=ogf2O@03o`000?nkA;_o^dBk013o^dBk00?o
0000om</dooC;=<01_oC;=<2o`0000WoebSG0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003o[5>/ojaC[00=ojaC[0?o00003on2OH80
0ol0003oDJiAoe6^D@08oe6^D@03o`000?lgb3Oo=lPg00Go=lPg00?o0000oakQ7_lNhAh00olNhAh0
0ol0003oA;]4odBkA00:odBkA003o`000?lGj1Oo5nPG00?o5nPG00?o0000oaKY5_lFjAH01OlFjAH0
0ol0003oJiA[of^DJ`0;of^DJ`;o00004OmmPWd00ol0003o^dBkok]4^`0?ok]4^`03o`000?oC;=?o
dbcC00SodbcC0_l00007omLXe`03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000ondBkOo]4^d02?o]4^d00ol0003o[5>/ojaC[009ojaC[0Go00000_miQWT00ol0
003oPWf2oh9mPP0=oh9mPP03o`000?mA[U7oDJiA00WoDJiA00?o0000ocO8=olgb3L01?lgb3L00ol0
003o7^4NoakQ7P04oakQ7P03o`000?m4^dCoA;]400SoA;]400?o0000oaOX5olGj1L01OlGj1L00ol0
003o5^TFoaKY5P04oaKY5P03o`000?m[U6_oJiA[00_oJiA[00?o0000ogf2OOmmPWd04?mmPWd00ol0
003o^dBkok]4^`0?ok]4^`03o`000?oC;=?odbcC00[odbcC0_l00004omLXe`03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003okA;]ondBk@07ondBk@03o`000?n/Djco[5>/00Co[5>/1Ol00007ogV6N@03
o`000?n2OH;oPWf200goPWf200?o0000oe6^DOmA[U402OmA[U400ol0003o=lPgocO8=`03ocO8=`03
o`000?lNhAko7^4N00Go7^4N00?o0000odBkA?m4^d@02?m4^d@00ol0003o5nPGoaOX5`06oaOX5`03
o`000?lFjAKo5^TF00?o5^TF00?o0000of^DJom[U6/02om[U6/00ol0003oOH9mogf2O@0@ogf2O@03
o`000?nkA;_o^dBk00oo^dBk00?o0000om</dooC;=<03?oC;=<2o`000003omLXeol0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00OokA;]00?o0000ojaC[?l00000
1?l0000<ogV6N@03o`000?n2OH;oPWf200koPWf200?o0000oe6^DOmA[U402?mA[U400ol0003o=lPg
ocO8=`02ocO8=`03o`000?lNhAko7^4N00Oo7^4N00?o0000odBkA?m4^d@01om4^d@00ol0003o5nPG
oaOX5`07oaOX5`03o`000?lFjAKo5^TF00;o5^TF00?o0000of^DJom[U6/02om[U6/00ol0003oOH9m
ogf2O@0Aogf2O@03o`000?nkA;_o^dBk00go^dBk00?o0000om</dooC;=<03ooC;=<00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000ondBkOo]4^d01Oo]4^d3o`00017oNHIi00?o0000oh9mP_n2OH803_n2
OH800ol0003oDJiAoe6^D@09oe6^D@04o`000?lgb3Oo=lPgo`0000[o7^4N00?o0000odBkA?m4^d@0
1om4^d@00ol0003o5nPGoaOX5`08oaOX5`05o`000?lFjAKo5^TFoaKY5_l000003Om[U6/00ol0003o
OH9mogf2O@0Aogf2O@?o00003OnkA;/00ol0003odbcCom</d`0?om</d`03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_o]4^d2o`0000;oaC[500?o0000ogV6NOmiQWT03omiQWT00ol0003o
PWf2oh9mPP0>oh9mPP03o`000?mA[U7oDJiA00SoDJiA1Ol0000;oakQ7P03o`000?m4^dCoA;]400Ko
A;]400?o0000oaOX5olGj1L02OlGj1L01?l0003o5^TFoaKY5_l0000=of^DJ`03o`000?mmPWgoOH9m
017oOH9m00?o0000oejQG_mNXEh00ol0000:ok]4^`Co00003OoC;=<00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000on`Ck?o/4ncok1?/0_l00005olDja@03o`000?miQWWoNHIi00koNHIi00?o0000oh9m
P_n2OH803_n2OH800ol0003oDJiAoe6^D@07oe6^D@03o`000?m</dcoC;=<00?oC;=<00?o0000oakQ
7_lNhAh02?lNhAh00ol0003oA;]4odBkA005odBkA003o`000?lGj1Oo5nPG00[o5nPG1Ol0000<of^D
J`03o`000?mmPWgoOH9m013oOH9m00?o0000oejQG_mNXEh01?mNXEh3o`0000Ko^dBk00?o0000om@[
e?oD:m@00_oD:m@5o`0000SodbcC00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o/4ncok1?/00?o
k1?/00?o0000olDjaOo5>/D01?o5>/D00ol0003oNHIiogV6N@0=ogV6N@03o`000?n2OH;oPWf200oo
PWf200?o0000oe6^DOmA[U401?mA[U42o`0000OoC;=<00?o0000oakQ7_lNhAh01olNhAhEo`0000Go
9=/T00?o0000of^DJom[U6/02?m[U6/3o`00013oOH9m00?o0000oejQG_mNXEh02?mNXEh3o`0000;o
^dBk00?o0000om@[e?oD:m@02?oD:m@5o`0000?odbcC00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?o/4ncok1?/00Cok1?/00?o0000olDjaOo5>/D01Oo5>/D00ol0003oNHIiogV6N@0;ogV6N@Co0000
3on2OH800ol0003oDJiAoe6^D@03oe6^D@03o`000?m</dcoC;=<00SoC;=<00?o0000oakQ7_lNhAh0
1?lNhAh2o`0000SoBkA;00?o0000ocS7>?lhacP02?lhacP00ol0003o9=/TobCK9005obCK90;o0000
1_m[U6/2o`0000?oGJ9M00?o0000ogf2OOmmPWd03?mmPWd00ol0003oGZ5NoejQGP0<oejQGP;o0000
4?oD:m@3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003ok1?/on`Ck005on`Ck003o`000?o5>/GoaC[500KoaC[500?o
0000ogV6NOmiQWT02OmiQWT00ol0003oM8]do`000002oejQGP?o00003?n2OH801?l0003oDJiAoe6^
DOmA[U42o`0000coC;=<00?o0000oakQ7_lNhAh00_lNhAh00ol0003oBkA;od^dB`08od^dB`03o`00
0?lhacSo><Lh00So><Lh00?o0000obCK9?lTfb@01olTfb@00ol0003oJiA[of^DJ`02of^DJ`03o`00
0?mMXUgoGJ9M00CoGJ9M0_l0000;ogf2O@03o`000?mNXEkoGZ5N00coGZ5N00?o0000oi9]T_l00000
4_oD:m@00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003ok1?/on`Ck006on`Ck003o`000?o5>/GoaC[500OoaC[500?o
0000ogV6NOmiQWT01_miQWT2o`0000;oM8]d00?o0000oejQG_mNXEh00omNXEh3o`0000[oPWf200?o
0000oe6^DOl000003om</d`01?l0003o7^4No`000?l0000;od^dB`03o`000?lhacSo><Lh00So><Lh
00?o0000obCK9?lTfb@02?lTfb@01?l0003oJiA[o`000?l00009oefRG@03o`000?mmPWgoOH9m00Oo
OH9m00?o0000oejQG_mNXEh03?mNXEh01?l0003oTVfBoi9]T_l0000Com@[e003o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000on`Ck?o/4n`01oo/4n`00ol0003oaC[5olDja@08olDja@03o`000?miQWWoNHIi00Co
NHIi00?o0000ogB;M?mdRg@00omdRg@00ol0003oGZ5NoejQGP05oejQGP?o00001_n2OH84o`00013o
C;=<00?o0000od^dBom;]4/03?m;]4/00ol0003o><LhocS7>007ocS7>003o`000?lTfbCo9=/T00Wo
9=/T00?o0000oefRGOmMXUd02_mMXUd2o`0000KoOH9m00?o0000oejQG_mNXEh03?mNXEh00ol0003o
TVfBoi9]TP02oi9]TP03o`000?oD:mCoe2_D00ooe2_D00?o0000onPGj?l000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003ok1?/on`Ck008on`Ck003o`000?o5>/GoaC[500WoaC[500Co0000ogV6NOmiQWWo
NHIi0_l00006ogB;M003o`000?mNXEkoGZ5N00SoGZ5N0ol000000on2OH;o0000o`000004oeVVF@03
o`000?m</dcoC;=<00goC;=<00?o0000od^dBom;]4/03?m;]4/00ol0003o><LhocS7>007ocS7>003
o`000?lTfbCo9=/T00Wo9=/T00?o0000oefRGOmMXUd03?mMXUd00ol0003oOH9mogf2O@03o`0000ko
GZ5N00?o0000oi9]T_nBKI800onBKI800ol0003oe2_Dom@[e00>om@[e005o`000?oX5nSoj1OXonPG
j?l000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003ok1?/on`Ck009on`Ck003o`000?o5>/GoaC[500[o
aC[500?o0000ogV6NOl000002?mdRg@00ol0003oGZ5NoejQGP0;oejQGP03o`000?mIYUWoFJII00Go
FJII00?o0000odbcC?m</d`03?m</d`00ol0003oBkA;od^dB`0<od^dB`03o`000?lhacSo><Lh00Oo
><Lh00?o0000obCK9?lTfb@02?lTfb@2o`0000ooGJ9M0_l00002ofjAKP03o`000?mNXEkoGZ5N00_o
GZ5N00?o0000oi9]T_nBKI801?nBKI800ol0003oe2_Dom@[e00=om@[e003o`000?oX5nSoj1OX00?o
j1OX00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;on`Ck003o`000?o5>/GoaC[500_oaC[500?o0000ogB;M?mdRg@0
1omdRg@00ol0003oGZ5NoejQGP0;oejQGP03o`000?mIYUWoFJII00KoFJII00?o0000odbcC?m</d`0
2om</d`2o`0000goBkA;00?o0000ocS7>?lhacP01olhacP00ol0003o9=/TobCK9007obCK9004o`00
0?lacS7o<Lhao`0000koGJ9M00?o0000ofjAK_m^TFh00_m^TFh00ol0003oGZ5NoejQGP09oejQGP03
o`000?nBKI;oTVfB00KoTVfB00?o0000om@[e?oD:m@02ooD:m@00ol0003oj1OXonPGj005onPGj004
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000Sok1?/00?o0000olDjaOo5>/D02_o5>/D2o`0000Wo
M8]d00?o0000oejQG_mNXEh02omNXEh00ol0003oFJIIoeVVF@07oeVVF@03o`000?m</dcoC;=<00Wo
C;=<00Co0000oaGZ5OlEjQGo00003?m;]4/00ol0003o><LhocS7>007ocS7>003o`000?lTfbCo9=/T
00Ko9=/T00Go0000oc7><OlacS7o<Lhao`00000>oefRG@03o`000?m^TFkoKY5^00?oKY5^00?o0000
oejQG_mNXEh01omNXEh00ol0003oTVfBoi9]TP07oi9]TP03o`000?oD:mCoe2_D00[oe2_D00?o0000
onPGj?oX5nP01ooX5nP00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006on`Ck003o`000?o5>/GoaC[5
00WoaC[500Co0000ojaC[?n/Djco00002OmdRg@00ol0003oGZ5NoejQGP09oejQGP03o`000?mIYUWo
FJII00WoFJII00?o0000odbcC?m</d`01om</d`00ol0003o5NXEoaGZ5@02oaGZ5@03o`000?m;]4_o
BkA;00WoBkA;00?o0000ocS7>?lhacP01olhacP00ol0003o9=/TobCK9005obCK9003o`000?lacS7o
<Lha00?o<Lha00?o0000oefRGOmMXUd02_mMXUd00ol0003oKY5^ofjAKP05ofjAKP03o`000?mNXEko
GZ5N00GoGZ5N00?o0000oi9]T_nBKI802?nBKI800ol0003oe2_Dom@[e009om@[e003o`000?oX5nSo
j1OX00Soj1OX00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_o/4n`3o`0000WoaC[500?o0000ojaC
[?n/Dj`00_n/Dj`00ol0003oM8]dogB;M006ogB;M003o`000?mNXEkoGZ5N00WoGZ5N00?o0000oeVV
FOmIYUT02_mIYUT00ol0003oC;=<odbcC005odbcC003o`000?lEjQGo5NXE00Co5NXE00?o0000od^d
Bom;]4/02?m;]4/00ol0003o><LhocS7>007ocS7>003o`000?lTfbCo9=/T00Co9=/T00?o0000oc7>
<OlacS401?lacS400ol0003oGJ9MoefRG@0:oefRG@03o`000?m^TFkoKY5^00KoKY5^00?o0000oejQ
G_mNXEh00omNXEh00ol0003oTVfBoi9]TP09oi9]TP03o`000?oD:mCoe2_D00Soe2_D00?o0000onPG
j?oX5nP02OoX5nP00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003on@Ki0?o00001Oo5>/D00ol0003o
[5>/ojaC[003ojaC[003o`000?mdRgCoM8]d00KoM8]d00?o0000oejQG_mNXEh02OmNXEh00ol0003o
FJIIoeVVF@0;oeVVF@03o`000?m</dcoC;=<00?oC;=<00?o0000oaGZ5OlEjQD01_lEjQD00ol0003o
BkA;od^dB`08od^dB`03o`000?lhacSo><Lh00Ko><Lh00?o0000obCK9?lTfb@00_lTfb@2o`0000So
<Lha00?o0000oefRGOmMXUd02OmMXUd00ol0003oKY5^ofjAKP07ofjAKP05o`000?mNXEkoGZ5NoejQ
G_l000003OnBKI800ol0003oe2_Dom@[e006om@[e003o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oT6nCoi1_T00Goi1_T0ol000000oo5>/Go0000ojaC[006ojaC[003
o`000?mdRgCoM8]d00GoM8]d00?o0000oejQG_mNXEh02OmNXEh00ol0003oFJIIoeVVF@0<oeVVF@05
o`000?m</dcoC;=<odbcC?l000002_lEjQD00ol0003oBkA;od^dB`07od^dB`03o`000?lhacSo><Lh
00Ko><Lh00?o0000obCK9?l000000_l000000omVVFKo0000oc7><@07oc7><@03o`000?mMXUgoGJ9M
00SoGJ9M00?o0000ofjAK_m^TFh02Om^TFh00ol0003oGZ5No`00000=oi9]TPCo00001OoD:m@00ol0
003oj1OXonPGj00;onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oi1_Ton@Ki008on@Ki003
o`000?n/Djco[5>/00Oo[5>/00?o0000ogB;M?mdRg@01?mdRg@00ol0003oGZ5NoejQGP09oejQGP03
o`000?mIYUWoFJII00goFJII00?o0000odbcC?l000003?lEjQD:o`0000Oo><Lh0ol00005ofJIIP03
o`000?lacS7o<Lha00Ko<Lha00?o0000oefRGOmMXUd01omMXUd00ol0003oKY5^ofjAKP0:ofjAKP03
o`000?nBKI;oTVfB00_oTVfB00?o0000olPgb?o8=lP00_o8=lP3o`000003om@[e?l0003oj1OX00_o
j1OX0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000on@Ki?oT6n@02OoT6n@00ol0003o[5>/ojaC[007ojaC[003o`00
0?mdRgCoM8]d00GoM8]d00?o0000oejQG_mNXEh01omNXEh00ol0003oFJIIoeVVF@0?oeVVF@;o0000
2olEjQD00ol0003oFJIIoeVVF@07oeVVF@03o`000?lhacSo><Lh00;o><Lh0ol00008ofJIIP03o`00
0?lacS7o<Lha00Ko<Lha00?o0000oefRGOmMXUd01omMXUd00ol0003oKY5^ofjAKP0:ofjAKP03o`00
0?nBKI;oTVfB00[oTVfB00?o0000olPgb?o8=lP01_o8=lP00ol0003oj1OXonPGj008onPGj0?o0000
0_o^4Nh00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on@Ki?oT6n@02OoT6n@00ol0003o[5>/ojaC
[008ojaC[003o`000?mdRgCoM8]d00CoM8]d00?o0000oejQG_mNXEh01omNXEh00ol0003oFJIIoeVV
F@0>oeVVF@04o`000?lXebSo:=LXo`0000Wo5NXE00?o0000oeVVFOmIYUT02OmIYUT01?l0003o><Lh
o`000?l0000<ofJIIP03o`000?lacS7o<Lha00Ko<Lha00?o0000oefRGOmMXUd01_mMXUd00ol0003o
KY5^ofjAKP0;ofjAKP03o`000?nBKI;oTVfB00OoTVfB0_l00009olPgb003o`000?oX5nSoj1OX00Co
j1OX1?l00006onhAkP03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oi1_Ton@Ki009on@Ki003o`00
0?n/Djco[5>/00So[5>/00?o0000ogB;M?mdRg@00omdRg@>o`0000goFJII00?o0000obSG:?lXebP0
0_lXebP00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?mIYUWoFJII00_oFJII00?o0000ofJII_mVVFH0
3?mVVFH00ol0003o<Lhaoc7><@06oc7><@03o`000?mMXUgoGJ9M00GoGJ9M00?o0000ofjAK_m^TFh0
3?m^TFh00ol0003oTVfBoi9]TP06oi9]TP03o`000?o8=lSob3O800[ob3O800?o0000onPGj?oX5nP0
0ol0000:onhAkP?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000ojaC[?n/Dj`02?n/
Dj`01Ol0003oM8]dogB;M?mdRgCo000000_oGj1O00?o0000o`gb3Ol=lPd00ol00009oeVVF@03o`00
0?lXebSo:=LX00Co:=LX00?o0000oaGZ5OlEjQD00olEjQD00ol0003oFJIIoeVVF@0<oeVVF@03o`00
0?mVVFKoIYUV00goIYUV00?o0000oc7><OlacS401_lacS400ol0003oGJ9MoefRG@03oefRG@?o0000
3Om^TFh00ol0003oTVfBoi9]TP05oi9]TP03o`000?o8=lSob3O800cob3O80_l0000=onhAkP03o`00
0?om0_goo@;m00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oT6nCoi1_T00_oi1_T00?o0000ojaC[?n/Dj`02?n/
Dj`4o`0000coGj1O00?o0000o`gb3Ol=lPd00ol=lPd3o`0000GoFJII00?o0000obSG:?lXebP01_lX
ebP01Ol0003o5NXEoaGZ5OlEjQGo000000ooFJII00?o0000ofJII_mVVFH03OmVVFH00ol0003o<Lha
oc7><@06oc7><@03o`000?mMXUgoGJ9M00?o00000oljaCX00ol0003oKY5^ofjAKP0;ofjAKP03o`00
0?nBKI;oTVfB00?oTVfB00?o0000olPgb?o8=lP03Oo8=lP00ol0003okQ7^onhAkP0;onhAkP03o`00
0?om0_goo@;m00Coo@;m0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000on@Ki?oT6n@02_oT6n@3o`0000Ko[5>/0ol0
0003oiMXU`03o`000?mOX5ooGj1O00[oGj1O00?o0000o`gb3Ol=lPd01_l=lPd3o`000003oeVVFOl0
003o:=LX00Wo:=LX00?o0000oaGZ5Ol000004?mIYUT00ol0003oIYUVofJIIP0=ofJIIP03o`000?la
cS7o<Lha00Oo<Lha0_l00007oc[5>P03o`000?m^TFkoKY5^00[oKY5^00Co0000oi9]T_nBKI;oTVfB
0ol0000?olPgb003o`000?o^4NkokQ7^00_okQ7^00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000on@Ki?oT6n@02_oT
6n@01?l0003odbcCom</dooC;=<2o`000004ojaC[?l0003o0000o`0000KoUfRG00?o0000oenPGomO
X5l02_mOX5l00ol0003o3O8=o`gb3@09o`gb3@03o`000?lXebSo:=LX00[o:=LX00?o0000oeVVFOmI
YUT03omIYUT00ol0003oIYUVofJIIP0>ofJIIP03o`000?lacS7o<Lha00Ko<Lha00?o0000oc[5>_lj
aCX01oljaCX4o`0000SoKY5^00Co0000oi9]T_nBKI;o00000on>LHh2o`0000gob3O800?o0000onhA
k_o^4Nh02_o^4Nh00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000on@Ki?oT6n@02OoT6n@00ol0003o
dbcCom</d`04om</d`03o`000?nGJ9OoUfRG00OoUfRG00?o0000oenPGomOX5l02OmOX5l00ol0003o
3O8=o`gb3@0:o`gb3@03o`000?lXebSo:=LX00[o:=LX00?o0000oeVVFOmIYUT03omIYUT00ol0003o
IYUVofJIIP0>ofJIIP03o`000?lacS7o<Lha00Go<Lha00?o0000oc[5>_ljaCX02?ljaCX01?l0003o
G:=LoebSG?mLXe`7o`0000;oKY5^0_l00006ohiaSP;o00003?o8=lP00ol0003okQ7^onhAkP09onhA
kP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003oi1_Ton@Ki008on@Ki003o`000?oC;=?odbcC00Go
dbcC00?o0000oiMXUonGJ9L02?nGJ9L00ol0003oGj1OoenPG`08oenPG`03o`000?l=lPgo3O8=00[o
3O8=00?o0000obSG:?lXebP02olXebP00ol0003oFJIIoeVVF@0>oeVVF@03o`000?mVVFKoIYUV00ko
IYUV1Ol00002oc7><@03o`000?ljaC[o>/Dj00Wo>/Dj00?o0000oebSG?mLXe`02?mLXe`3o`0000Wo
SW6>0_l0000:olPgb003o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oT6nCoi1_T00Soi1_T00?o0000om</dooC;=<01ooC;=<00ol0003oUfRGoiMXU`07oiMXU`03o`00
0?mOX5ooGj1O00SoGj1O00?o0000o`gb3Ol=lPd02_l=lPd00ol0003o:=LXobSG:00:obSG:0;o0000
3_mIYUT3o`0000goIYUV0ol00005ofbCK0;o00002oljaCX00ol0003oG:=LoebSG00;oebSG0;o0000
2_n>LHh2o`0000Oob3O80ol00009onhAkP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:om</d`03o`00
0?nGJ9OoUfRG00OoUfRG00?o0000oenPGomOX5l02?mOX5l>o`0000Wo:=LX0ol000000ol;m0_o0000
oeVVF@0:oeVVF@?o00000_m`Sg000ol0003oIYUVofJIIP09ofJIIP;o00002Om/Tf`00ol0003o>/Dj
oc[5>P09oc[5>P03o`000?mLXecoG:=L00_oG:=L00?o0000ogZ5N_l000002on>LHh2o`0000Cob3O8
00Co0000on<LhooS7>?ohacS0_l00007onhAkP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003odbcC
om</d`09om</d`03o`000?nGJ9OoUfRG00KoUfRG00?o0000oenPGomOX5l02?mOX5l00ol0003o6^DJ
oa[U6P0:oa[U6P03o`000?lXebSo:=LX00Co:=LX0ol00005o`_d2`03o`000?mIYUWoFJII00CoFJII
1?l00006og2?L003o`000?mVVFKoIYUV00KoIYUV0_l0000;ofbCK003o`000?ljaC[o>/Dj00Wo>/Dj
00?o0000oebSG?mLXe`02_mLXe`01Ol0003oNXEjogZ5N_mjQG[o000000coSW6>0_l000000oo8=lSo
0000on<Lh`05on<Lh`03o`000?o^4NkokQ7^00?okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oC;=?odbcC00SodbcC00?o0000oiMXUonGJ9L01_nGJ9L00ol0003oGj1OoenPG`07oenPG`03o`00
0?lJiA[o6^DJ00_o6^DJ00?o0000obSG:?lXebP00_lXebP2o`0000Wo2o@;00?o0000oeVVFOmIYUT0
0ol0000;og2?L003o`000?mVVFKoIYUV00;oIYUV0ol0000>ofbCK003o`000?ljaC[o>/Dj00Oo>/Dj
00?o0000oebSG?mLXe`02omLXe`00ol0003oNXEjogZ5NP02ogZ5NP03o`000?n>LHkoSW6>00_oSW6>
00?o0000on<LhooS7><01_oS7><2o`0000?okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oC
;=?odbcC00OodbcC00?o0000oiMXUonGJ9L01onGJ9L00ol0003oGj1OoenPG`05oenPG`?o00003OlJ
iAX4o`0000_o2o@;0ol0000?og2?L004o`000?mVVFKo0000o`00017oK9=/00?o0000oc[5>_ljaCX0
1oljaCX00ol0003oG:=LoebSG00:oebSG003o`000?mjQG[oNXEj00CoNXEj00?o0000ohiaS_n>LHh0
1on>LHh3o`0000_ohacS1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om</dooC;=<02?oC;=<00ol0003oUfRGoiMX
U`06oiMXU`03o`000?mOX5ooGj1O00;oGj1O0ol00003od>l@`03o`000?lJiA[o6^DJ00[o6^DJ00?o
0000o`_d2ol;m0/02ol;m0/00ol0003o5NXEo`00000Aog2?L003o`000?m/TfcoK9=/017oK9=/00?o
0000oc[5>_ljaCX01oljaCX00ol0003oG:=LoebSG00:oebSG003o`000?mjQG[oNXEj00GoNXEj00Co
0000ohiaS_n>LHkoSW6>1Ol00002oj5NX@03o`000?oS7>?ohacS00WohacS00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000om</dooC;=<01ooC;=<00ol0003oUfRGoiMXU`05oiMXU`?o0000
00?oGj1Oo`000?l000001om3_4<00ol0003o6^DJoa[U6P08oa[U6P?o00002_l;m0/2o`0000;o5NXE
00?o0000og2?L?m`Sg003om`Sg000ol0003oK9=/ofbCK00AofbCK003o`000?ljaC[o>/Dj00Oo>/Dj
00?o0000oebSG?mLXe`02OmLXe`00ol0003oNXEjogZ5NP07ogZ5NP?o00001onQGZ400ol0003ohacS
on<Lh`09on<Lh`03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000om</dooC;=<01ooC
;=<4o`0000;oUfRG0_l00003oiIYUP03o`000?m3_4?o@ka300So@ka30_l00006oa[U6P;o00000olO
h1l00ol0003o2o@;o`_d2`06o`_d2`03o`000?lEjQGo5NXE00?o5NXE00?o0000og2?L?m`Sg003_m`
Sg000ol0003oK9=/ofbCK00BofbCK003o`000?ljaC[o>/Dj00Go>/Dj00?o0000oebSG?mLXe`02OmL
Xe`00ol0003oNXEjogZ5NP08ogZ5NP03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000on<LhooS7><02?oS
7><00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oC;=?odbcC00CodbcC0_l00004
om/Tf`;o00001OnFJIH00ol0003o@ka3od>l@`0:od>l@`03o`000?lJiA[o6^DJ00;o6^DJ00?o0000
oaoP7olOh1l01?lOh1l00ol0003o2o@;o`_d2`04o`_d2`03o`000?lEjQGo5NXE00Co5NXE00?o0000
og2?L?m`Sg003_m`Sg000ol0003oK9=/ofbCK00BofbCK0[o00002_mLXe`00ol0003oNXEjogZ5NP08
ogZ5NP03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000on<LhooS7><02?oS7><00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003odbcCom</dooC;=<2o`0000OofbCK00?o0000oiIYU_nFJIH01?nFJIH0
0ol0003o@ka3od>l@`0:od>l@`04o`000?lJiA[o0000o`0000So7n0O00Co0000o`_d2ol;m0_o2o@;
0_l00007oaGZ5@03o`000?m`Sg3oL8m`00koL8m`00?o0000ofbCK?m/Tf`04_m/Tf`00ol0003oC[5>
odjaCP07odjaCP03o`000?mLXecoG:=L00KoG:=L00?o0000ogZ5N_mjQGX02_mjQGX00ol0003oXEjQ
oj5NX@06oj5NX@03o`000?oS7>?ohacS00SohacS00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oC
;=?o0000o`0000WofbCK00?o0000oiIYU_nFJIH01?nFJIH00ol0003o@ka3od>l@`0;od>l@`03o`00
0?lOh1oo7n0O00Wo7n0O00?o0000o`_d2ol000002OlEjQD00ol0003oL8m`og2?L00>og2?L0;o0000
4_m/Tf`00ol0003oC[5>odjaCP09odjaCP;o00001_mLXe`00ol0003oNXEjogZ5NP0:ogZ5NP03o`00
0?nQGZ7oXEjQ00KoXEjQ00?o0000on<LhooS7><02?oS7><00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000om/TfooK9=/02OoK9=/00ol0003oUVVFoiIYUP05oiIYUP03o`000?m3_4?o@ka300[o@ka300?o
0000oaoP7olOh1l02_lOh1l2o`0000Wo5NXE00?o0000og2?L?m`Sg003_m`Sg000ol0003oEjQGo`00
0002o`0000ooK9=/00?o0000odjaC_m>/Dh02om>/Dh00ol0003oG:=LoebSG003o`0000goNXEj00?o
0000oj5NXOnQGZ401_nQGZ400ol0003ohacSon<Lh`07on<Lh`03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ofbCKom/Tf`09om/Tf`03o`000?nFJIKoUVVF00GoUVVF00?o0000od>l@om3_4<02Om3_4<2
o`0000_o7n0O0_l0000;oaGZ5@03o`000?m`Sg3oL8m`00coL8m`00?o0000oeNXEomGZ5L00omGZ5L3
o`0000coK9=/00?o0000odjaC_m>/Dh03?m>/Dh2o`0000;oIiQW00?o0000ogZ5N_mjQGX03?mjQGX0
0ol0003oXEjQoj5NX@05oj5NX@03o`000?oS7>?ohacS00OohacS00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oK9=_ofbCK00[ofbCK00?o0000oiIYU_nFJIH01_nFJIH00ol0003o@ka3od>l@`07od>l
@`03o`000?lgb3Oo000000[o7n0O00Co0000o`ka3_l>l@ko00002_lEjQD00ol0003oL8m`og2?L00<
og2?L003o`000?mGZ5OoEjQG00KoEjQG0_l00008ofbCK0;o00003om>/Dh00ol0003oIiQWofNHI`02
ofNHI`03o`000?mjQG[oNXEj00_oNXEj00?o0000oj5NXOnQGZ401OnQGZ400ol0003ohacSon<Lh`07
on<Lh`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ofbCKom/Tf`0:om/Tf`03o`000?nFJIKoUVVF
00KoUVVF00?o0000od>l@om3_4<01_m3_4<01Ol0003o=lPgocO8=olgb3Oo000000So7n0O00?o0000
o`ka3_l>l@h00_l>l@h00ol0003o5NXEoaGZ5@06oaGZ5@Co00003?m`Sg000ol0003oEjQGoeNXE`08
oeNXE`?o00000_m/Tf`3o`000003odNhAol0003oC[5>00goC[5>00?o0000ofNHIomWV6L01?mWV6L0
0ol0003oNXEjogZ5NP0:ogZ5NP03o`000?nQGZ7oXEjQ00GoXEjQ00?o0000on<LhooS7><01_oS7><0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000om/TfooK9=/02ooK9=/00ol0003oUVVFoiIYUP07oiIY
UP03o`000?m3_4?o@ka300?o@ka30_l00005ocO8=`03o`000?lOh1oo7n0O00Co7n0O00?o0000o`ka
3_l>l@h00ol>l@h00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?lcc3?o<l`c00;o<l`c0ol00007og2?
L0;o00003_mGZ5L2o`0000GoAkQ700?o0000odjaC_m>/Dh02_m>/Dh00ol0003oIiQWofNHI`05ofNH
I`03o`000?mjQG[oNXEj00_oNXEj00?o0000oj5NXOnQGZ401?nQGZ400ol0003ohacSon<Lh`06on<L
h`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ofbCKom/Tf`0;om/Tf`03o`000?nFJIKoUVVF00Oo
UVVF00?o0000od>l@om3_4<00_m3_4<00ol0003o=lPgocO8=`06ocO8=`03o`000?lOh1oo7n0O00;o
7n0O00?o0000o`ka3_l>l@h01Ol>l@h00ol0003o5NXEoaGZ5@02oaGZ5@;o00002?lcc3<3o`0000;o
L8m`0_l000000olm`Sgo0000oeNXE`0=oeNXE`03o`000?m7^4OoAkQ700GoAkQ700?o0000odjaC_m>
/Dh02?m>/Dh00ol0003oIiQWofNHI`07ofNHI`03o`000?mjQG[oNXEj00[oNXEj00?o0000oj5NXOnQ
GZ401?nQGZ400ol0003ohacSon<Lh`06on<Lh`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ofbCK
om/Tf`0<om/Tf`03o`000?nFJIKoUVVF00SoUVVF00Co0000od>l@om3_4?o00002Olgb3L01Ol0003o
7n0OoaoP7olOh1oo000000So3_4>00Go0000oaGZ5OlEjQGo5NXEo`00000=oc?<<`;o00001?lm`Sd0
0ol0003oEjQGoeNXE`0;oeNXE`03o`000?m7^4OoAkQ700KoAkQ700?o0000odjaC_m>/Dh01om>/Dh0
0ol0003oIiQWofNHI`08ofNHI`Co00002?mjQGX00ol0003oXEjQoj5NX@04oj5NX@03o`000?oS7>?o
hacS00KohacS00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oK9=_ofbCK00_ofbCK0ol00009oiIY
UP03o`000?m3_4?o000000_o=lPg00?o0000oaoP7ol000002_l>l@h00ol0003o5NXEo`00000?oc?<
<`03o`000?lm`Sgo?L8m00;o?L8m00?o0000oeNXEomGZ5L02omGZ5L00ol0003oAkQ7odNhA`06odNh
A`03o`000?m>/DkoC[5>00KoC[5>00?o0000ofNHIomWV6L02OmWV6L01?l0003oUFZEoiEZUOnEJYD7
o`0000;oNXEj00?o0000oj5NXOnQGZ400onQGZ400ol0003ohacSon<Lh`05on<Lh`03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oK9=_ofbCK00SofbCK0ol00003olhacP03o`000?nFJIKoUVVF00OoUVVF00?o0000ocO8
=olgb3L02olgb3L00ol0003o3_4>o`ka3P0:o`ka3P03o`000?lcc3?o<l`c00go<l`c00?o0000ocg2
?Olm`Sd01?lm`Sd00ol0003oEjQGoeNXE`09oeNXE`03o`000?m7^4OoAkQ700SoAkQ700?o0000odja
C_m>/Dh00om>/Dh2o`0000coIiQW00?o0000oiEZUOnEJYD02?nEJYD<o`0000?ohacS0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000om/TfooK9=/01_oK9=/3o`0000OocS7>00?o0000oiIYU_nFJIH01_nFJIH00ol0003o
=lPgocO8=`0;ocO8=`03o`000?l>l@ko3_4>00Wo3_4>0_l0000>oc?<<`03o`000?lm`Sgo?L8m00Go
?L8m00?o0000oeNXEomGZ5L02OmGZ5L00ol0003oAkQ7odNhA`09odNhA`03o`000?m>/Dko000000;o
00000_mMXUd00ol0003oIiQWofNHI`08ofNHI`03o`000?nEJYGoUFZE00coUFZE00?o0000on0Oh?oP
7n001_oP7n03o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ofbCKom/Tf`03om/Tf`?o00002oo><Lh00ol0003oUVVF
oiIYUP04oiIYUP03o`000?lgb3Oo=lPg00_o=lPg0ol00007o`ka3P?o000000?o:MHYo`000?lcc3<0
3Olcc3<00ol0003o?L8mocg2?@06ocg2?@03o`000?mGZ5OoEjQG00SoEjQG00?o0000odNhAom7^4L0
2_m7^4L00ol0003oGJ9MoefRG@04oefRG@03o`000?mWV6OoIiQW00OoIiQW00?o0000oiEZUOnEJYD0
2onEJYD00ol0003oh1oPon0Oh008on0Oh003o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004om/Tfol0
003o0000o`0000oocS7>00?o0000oiIYU_nFJIH00onFJIH>o`0000?o;m0_0_l00002o`ka3P?o0000
1OlYeRT00ol0003o<l`coc?<<`0:oc?<<`03o`000?lm`Sgo?L8m00Oo?L8m00?o0000oeNXEomGZ5L0
2?mGZ5L00ol0003oAkQ7odNhA`0:odNhA`03o`000?mMXUgoGJ9M00GoGJ9M00?o0000ofNHIomWV6L0
1_mWV6L00ol0003oUFZEoiEZU@0;oiEZU@03o`000?oP7n3oh1oP00Soh1oP00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;ocS7>00?o0000oiIYU_nFJIH00_nFJIH00ol0003oH9mPof2O
H00:of2OH003o`000?l_d2oo;m0_00?o;m0_0_l00009obWF:@03o`000?lcc3?o<l`c00Wo<l`c00?o
0000ocg2?Olm`Sd02?lm`Sd2o`0000SoEjQG00?o0000odNhAom7^4L02Om7^4L00ol0003oGJ9MoefR
G@07oefRG@03o`000?mWV6OoIiQW00CoIiQW00?o0000oiEZUOnEJYD02onEJYD00ol0003oh1oPon0O
h009on0Oh003o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ocS7>olhacP0?olhacP?o000000?oUVVF
o`000?mPWf002omPWf000ol0003o;m0_obo@;`04obo@;`03o`000?lYeRWo:MHY00Wo:MHY00?o0000
oc?<<olcc3<01olcc3<00ol0003o?L8mocg2?@09ocg2?@04o`000?liaSWo0000o`0000KoEjQG00?o
0000odNhAom7^4L02Om7^4L00ol0003oGJ9MoefRG@08oefRG@03o`000?mWV6OoIiQW00?oIiQW00?o
0000oiEZUOnEJYD02onEJYD00ol0003oh1oPon0Oh009on0Oh003o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ocS7>olhacP0<olhacP;o00000oo8=lP2o`0000coH9mP00?o0000obo@;ol_d2l01?l_d2l0
0ol0003o:MHYobWF:@0:obWF:@Wo00002olm`Sd00ol0003o>LHiocW6>@02ocW6>@?o00000_mGZ5L0
0ol0003oAkQ7odNhA`0:odNhA`03o`000?mMXUgoGJ9M00WoGJ9M00?o0000ofNHIomWV6L00_mWV6L0
0ol0003oUFZEoiEZU@0:oiEZU@03o`000?oP7n3oh1oP00Woh1oP00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_o><Lh2o`0000Gob3O800?o0000ohiaS_l000002_mPWf000ol0003o;m0_obo@;`06obo@
;`03o`000?lYeRWo:MHY00Wo:MHY00?o0000obOH9olWf2L01OlWf2L00ol0003o?L8mocg2?@09ocg2
?@03o`000?liaSWo>LHi00Go>LHi0ol00009odNhA`?o00003OmMXUd01Ol0003oIiQWofNHIomWV6Oo
000000coUFZE00?o0000on0Oh?oP7n002OoP7n000ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000olha
c_o><Lh01Oo><Lh2o`0000Oob3O800Co0000ohiaS_n>LHko00002OmPWf000ol0003o;m0_obo@;`06
obo@;`03o`000?lYeRWo:MHY00So:MHY00?o0000obOH9olWf2L01olWf2L00ol0003o?L8mocg2?@07
ocg2?@03o`000?liaSWo>LHi00So>LHi0ol00002odNhA`Go00000_lbcC800ol0003oGJ9MoefRG@0<
oefRG@03o`000?mWV6Oo000000coUFZE00?o0000on0Oh?oP7n002_oP7n000ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000olhac_o><Lh00_o><Lh2o`0000Sob3O800?o0000ohiaS_n>LHh00_n>LHh5o`00
00CoH9mP00?o0000obo@;ol_d2l01_l_d2l00ol0003o:MHYobWF:@08obWF:@03o`000?lWf2Oo9mPW
00Oo9mPW00?o0000ocg2?Olm`Sd01olm`Sd00ol0003o>LHiocW6>@08ocW6>@03o`000?lNhAko7^4N
00;o00002?lbcC800ol0003oGJ9MoefRG@0<oefRG@Co00002_nEJYD00ol0003oh1oPon0Oh00:on0O
h003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ocS7>o`000?l0000:olPgb003o`000?n>LHkoSW6>
00;oSW6>00?o0000oc;=<_lbcC800_lbcC84o`0000Wo;m0_00?o0000obWF:OlYeRT02?lYeRT00ol0
003o9mPWobOH9`08obOH9`03o`000?lm`Sgo?L8m00Go?L8m00?o0000ocW6>OliaST02?liaST01Ol0
003o7^4NoakQ7_lNhAko000000[o</db0ol0000;oefRG@04o`000?o:=L[obSG:olXebPCo00001OnE
JYD00ol0003oh1oPon0Oh00;on0Oh003o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ob3O8olPgb00:
olPgb003o`000?n>LHkoSW6>00?oSW6>00?o0000oc;=<_lbcC801?lbcC800ol0003o;m0_obo@;`07
obo@;`03o`000?lYeRWo:MHY00Ko:MHY0_l0000;obOH9`03o`000?lm`Sgo?L8m00Go?L8m00?o0000
ocW6>OliaST02?liaST00ol0003o7^4NoakQ7P02oakQ7P03o`000?lbcC;o</db00Oo</db00?o0000
ogn0OomoP7l01?l00006oefRG@03o`000?o:=L[obSG:00KobSG:0ol00002oiEZU@03o`000?oP7n3o
h1oP00_oh1oP00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o8=lSob3O800Wob3O800?o0000ohia
S_n>LHh01?n>LHh00ol0003o</dboc;=<P05oc;=<P03o`000?l_d2oo;m0_00Oo;m0_00?o0000obWF
:OlYeRT00_lYeRT3o`000003ocK9=_l0003o9mPW00[o9mPW00?o0000ocg2?Olm`Sd01Olm`Sd00ol0
003o>LHiocW6>@07ocW6>@03o`000?lNhAko7^4N00?o7^4N00?o0000oc;=<_lbcC801olbcC800ol0
003oOh1oogn0O`04ogn0O`?o00000_mMXUd00ol0003obSG:olXebP0:olXebP;o00003_oP7n000ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000olPgb?o8=lP02Oo8=lP00ol0003oSW6>ohiaSP04ohiaSP03
o`000?lbcC;o</db00Ko</db0_l00007obo@;`03o`000?lYeRWo000000;o00001OlfbCH00ol0003o
9mPWobOH9`08obOH9`?o00001?lm`Sd00ol0003o>LHiocW6>@08ocW6>@03o`000?lNhAko7^4N00Co
7^4N00?o0000oc;=<_lbcC801_lbcC800ol0003oOh1oogn0O`07ogn0O`;o00003_o:=LX00ol0003o
h1oPon0Oh00;on0Oh003o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ob3O8olPgb008olPgb003o`00
0?n>LHkoSW6>00GoSW6>00?o0000oc;=<_lbcC801?lbcC800ol0003oAkQ7odNhA`03o`0000Co;m0_
0_l00008ocK9=P03o`000?lWf2Oo9mPW00Oo9mPW00Co0000oe^TFomKY5_oFjAK0ol000000olm`Sgo
0000ocW6>@09ocW6>@03o`000?lNhAko7^4N00Co7^4N00?o0000oc;=<_lbcC801OlbcC800ol0003o
Oh1oogn0O`09ogn0O`03o`000?o:=L[obSG:00gobSG:00?o0000on0Oh?oP7n002_oP7n000ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000olPgb?o8=lP01oo8=lP00ol0003oSW6>ohiaSP06ohiaSP03o`00
0?lbcC;o</db00?o</db00?o0000odNhAom7^4L01?m7^4L2o`000003obo@;ol0003o=/Tf00[o=/Tf
00?o0000obOH9olWf2L01OlWf2L00ol0003oFjAKoe^TF`05oe^TF`03o`000?liaSWo>LHi00Oo>LHi
0ol00007oakQ7P03o`000?lbcC;o</db00Co</db00?o0000ogn0OomoP7l02OmoP7l00ol0003obSG:
olXebP0=olXebP03o`000?oP7n3oh1oP00[oh1oP00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o8
=lSob3O800Gob3O80ol00009ohiaSP05o`000?lbcC;o</dboc;=<_l000002Om7^4L00ol0003o=/Tf
ocK9=P0;ocK9=P03o`000?lWf2Oo9mPW00?o9mPW00?o0000oe^TFomKY5/01_mKY5/00ol0003o>LHi
ocW6>@06ocW6>@05o`000?m4^dCoA;]4odBkA?l000001olNhAh00ol0003o</dboc;=<P03oc;=<P03
o`000?moP7ooOh1o00WoOh1o00?o0000olXeb_o:=LX03_o:=LX00ol0003oh1oPon0Oh009on0Oh003
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ob3O8o`000004o`0000;ogB;M00?o0000ohiaS_n>LHh0
1on>LHh01?l0003o</dboc;=<_l00009odNhA`;o00003OlfbCH00ol0003o9mPWobOH9`02obOH9`03
o`000?mKY5_oFjAK00SoFjAK00?o0000ocW6>OliaST00oliaST2o`0000GoA;]400?o0000oakQ7_lN
hAh01?lNhAh00ol0003o</dboc;=<P03oc;=<P03o`000?moP7ooOh1o00WoOh1o00?o0000olXeb_o:
=LX03_o:=LX00ol0003oh1oPon0Oh009on0Oh003o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SogB;M
00?o0000ohiaS_n>LHh01_n>LHh00ol0003o</dbo`000009odNhA`04o`000?mFZEKoEZUFo`0000go
=/Tf00Co0000obOH9olWf2Oo00003?mKY5/01Ol0003o>LHiocW6>OliaSWo000000SoA;]40_l00005
oakQ7P03o`000?lbcC;o</db00;o</db00?o0000ogn0OomoP7l02OmoP7l00ol0003obSG:olXebP0>
olXebP03o`000?oP7n3oh1oP00Woh1oP00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oM8]gogB;M
00OogB;M00?o0000ohiaS_n>LHh01on>LHh00ol0003oAkQ7odNhA`07odNhA`03o`000?mFZEKoEZUF
00;oEZUF00?o0000ocK9=_lfbCH02_lfbCH00ol0003o9mPWo`00000>oe^TF`03o`000?liaSWo0000
00_oA;]400?o0000oakQ7_lNhAh00_lNhAh01Ol0003o</dboc;=<_lbcC;o000000coOh1o00?o0000
olXeb_o:=LX03_o:=LX3o`0000Woh1oP00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oM8]gogB;M
00WogB;M00?o0000ohiaS_n>LHh01_n>LHh00ol0003oAkQ7odNhA`06odNhA`03o`000?mFZEKoEZUF
00?oEZUF00?o0000ocK9=_lfbCH02olfbCH00ol0003oFjAKoe^TF`0>oe^TF`03o`000?m4^dCoA;]4
00_oA;]40_l00003oakQ7P04o`000?lbcC;o</dbo`0000[oOh1o0ol0000>olXebP;o00000ook1?/2
o`0000Ooh1oP00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oM8]gogB;M00[ogB;M00?o0000ohia
S_n>LHh01?n>LHh00ol0003oAkQ7odNhA`06odNhA`03o`000?mFZEKoEZUF00GoEZUF00?o0000ocK9
=_lfbCH01olfbCH3o`00017oFjAK00?o0000odBkA?m4^d@03Om4^d@01Ol0003o7^4NoakQ7_l0003o
</db00Co00000omoP7l5o`0000;od2o@00?o0000olXeb_o:=LX02_o:=LX2o`0000Oon`Ck0_l00004
on0Oh003o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ogB;MomdRg@0;omdRg@03o`000?n>LHkoSW6>
00CoSW6>00?o0000odNhAom7^4L01Om7^4L00ol0003oEZUFoeJYEP06oeJYEP03o`000?lfbCKo=/Tf
00Co=/Tf0ol00002od>l@`03o`000?mKY5_oFjAK00ooFjAK0_l0000?odBkA004o`000?lNhAko0000
o`0000CoJiA[0ol00008om0_d003o`000?o:=L[obSG:00OobSG:0_l0000;oo/4n`;o00000_oP7n00
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000omdRgOoM8]d03?oM8]d6o`0000OoAkQ700?o0000oeJY
E_mFZEH02?mFZEH00ol0003o=/TfocK9=P03o`0000Ko@ka300?o0000oe^TFomKY5/03OmKY5/01?l0
003oEjQGoeNXEol0000?odBkA003o`000?m[U6_oJiA[00GoJiA[00?o0000om0_d?o@;m002?o@;m00
0ol0003obSG:olXebP05olXebP03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oM8]d00ol0003oUVVFoiIYUP04oiIY
UP03o`000?m7^4OoAkQ700?oAkQ700?o0000oeJYE_mFZEH02_mFZEH2o`0000[o@ka300?o0000oe^T
FomKY5/02omKY5/00ol0003oEjQGoeNXE`02oeNXE`03o`000?m4^dCoA;]400_oA;]40_l00007of^D
J`03o`000?o@;m3od2o@00Wod2o@00?o0000olXeb_o:=LX00_o:=LX2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omdRgOoM8]d02ooM8]d00ol0003oUVVFoiIYUP06oiIYUP05o`000?m7^4OoAkQ7odNh
Aol000003OmFZEH00ol0003o@ka3od>l@`0:od>l@`03o`000?mKY5_oFjAK00WoFjAK00?o0000oeNX
EomGZ5L01?mGZ5L00ol0003oA;]4odBkA008odBkA0;o000000?o:]DZo`000?m[U6/01om[U6/00ol0
003od2o@om0_d009om0_d004o`000?o:=L[o0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oM8]gogB;M
00WogB;M00?o0000oiIYU_nFJIH02?nFJIH00ol0003oAkQ7o`00000=oeJYEP03o`000?m3_4?o@ka3
00_o@ka300?o0000oe^TFomKY5/02?mKY5/00ol0003oEjQGoeNXE`06oeNXE`03o`000?m4^dCoA;]4
00GoA;]40_l00003ob[E:P03o`000?m[U6_oJiA[00KoJiA[00?o0000om0_d?o@;m002_o@;m000ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003ogB;MomdRg@07omdRg@03o`000?nFJIKoUVVF00[oUVVF00?o0000oeJYE_mF
ZEH03?mFZEH00ol0003o@ka3od>l@`0<od>l@`03o`000?mKY5_oFjAK00KoFjAK00?o0000oeNXEomG
Z5L02?mGZ5L00ol0003oA;]4odBkA002odBkA0;o00001_lZeBX00ol0003oJiA[of^DJ`05of^DJ`03
o`000?o@;m3od2o@00[od2o@00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oM8]gogB;M00GogB;M
00?o0000oiIYU_nFJIH03?nFJIH2o`0000coEZUF00?o0000od>l@om3_4<03Om3_4<00ol0003oFjAK
oe^TF`04oe^TF`03o`000?mGZ5OoEjQG00[oEjQG00Co0000odBkA?l0003o00002?lZeBX00ol0003o
JiA[of^DJ`06of^DJ`03o`000?o@;m3od2o@00Wod2o@00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oM8]d00ol0003oUVVFoiIYUP0=oiIYUP03o`000?mJYE[o000000;o00002?mFZEH00ol0003o@ka3
od>l@`0?od>l@`Ko00003_mGZ5L00ol0003o:]DZob[E:P08ob[E:P03o`000?m[U6_oJiA[00KoJiA[
00?o0000om0_d?o@;m002Oo@;m000ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000omlPgooO8=oogb3O
0_l0000?oiIYUP03o`000?mJYE[oFZEJ00?oFZEJ0ol00005oeJYEP;o00004?m3_4<01_l0003o;m0_
obo@;ol0003o6NHIo`0000koEjQG00?o0000ob[E:_lZeBX02OlZeBX00ol0003oJiA[of^DJ`05of^D
J`03o`000?o@;m3od2o@00Wod2o@00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000omlPgooO8=l00ooO8=l00ol0003o
UVVFoiIYUP0=oiIYUP03o`000?mJYE[oFZEJ00KoFZEJ0ol000001?mFZEKo0000occ3??ll`c`3o`00
00co@ka300Go0000obo@;ol_d2oo;m0_o`000002oaWV6@03o`000?mGZ5OoEjQG00_oEjQG00?o0000
ob[E:_lZeBX02OlZeBX00ol0003oJiA[of^DJ`06of^DJ`03o`000?o@;m3od2o@00Sod2o@0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ogb3OomlPg`04omlPg`oo00003?mJYEX00ol0003o?<<locc3?004occ3
?0?o00002?m3_4<00ol0003o;m0_obo@;`02obo@;`05o`000?lIiQWo6NHIoaWV6Ol000003?mGZ5L0
0ol0003o:]DZob[E:P09ob[E:P03o`000?m[U6_oJiA[00GoJiA[3?l00002onXEjP;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ogb3OomlPg`05omlPg`03o`000?n9MXWoRGJ900_oRGJ900?o0000oeZU
F_mJYEX02_mJYEX00ol0003o?<<locc3?007occ3?0;o00001Om3_4<00ol0003o;m0_obo@;`03obo@
;`03o`000?lIiQWo6NHI00;o6NHI00?o0000oeNXEomGZ5L02OmGZ5L00ol0003o:]DZob[E:P0:ob[E
:P03o`000?m[U6_oJiA[00?oJiA[00?o0000ojeB[On]DZd02On]DZd00ol0003ojQGZonXEjP02onXE
jP;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ogb3OomlPg`06omlPg`03o`000?n9MXWoRGJ900[o
RGJ900?o0000oeZUF_mJYEX02omJYEX00ol0003o?<<locc3?009occ3?0?o000000?o@ka3o`000?l_
d2l01Ol_d2l00ol0003o6NHIoaWV6@03oaWV6@03o`000?mGZ5OoEjQG00SoEjQG3_l00003of^DJ`;o
00002on]DZd00ol0003ojQGZonXEjP05onXEjP03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000omlPgooO8=l01OoO8=l00ol0003oWV6No`00000;ohUfR@03o`000?mJYE[oFZEJ00[oFZEJ
0_l0000>occ3?003o`000?l_d2oo;m0_00Go;m0_00?o0000oaWV6OlIiQT00olIiQT00ol0003oEjQG
oeNXE`08oeNXE`03o`000?m[U6_oJiA[00_oJiA[00?o0000of^DJol000003On]DZd00ol0003ojQGZ
onXEjP06onXEjP;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oO8=oogb3O00Kogb3O00Co
0000oiiQW_nNHIko00002_n9MXT00ol0003oFZEJoeZUFP09oeZUFP03o`000?m2_D;o000000ko?<<l
00?o0000obo@;ol_d2l01Ol_d2l00ol0003o6NHIoaWV6@04oaWV6@03o`000?mGZ5OoEjQG00KoEjQG
00?o0000of^DJom[U6/03Om[U6/00ol0003o[E:]ojeB[@0<ojeB[@03o`000?oZ5N[ojQGZ00SojQGZ
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oO8=oogb3O00Gogb3O00?o0000oiiQW_nNHIh00_nN
HIh00ol0003oRGJ9ohUfR@06ohUfR@03o`000?mJYE[oFZEJ00SoFZEJ0_l00003od:m@P03o`000?ll
`cco?<<l00_o?<<l00?o0000obo@;ol_d2l01Ol_d2l00ol0003o6NHIoaWV6@05oaWV6@03o`000?mG
Z5OoEjQG00GoEjQG00?o0000of^DJom[U6/03Om[U6/00ol0003o[E:]ojeB[@0;ojeB[@03o`000?oZ
5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oO8=oogb3O00Kogb3O00?o0000
oiiQW_nNHIh00onNHIh00ol0003oRGJ9ohUfR@05ohUfR@03o`000?mJYE[oFZEJ00OoFZEJ00?o0000
od:m@_m2_D800om2_D800ol0003o?<<locc3?00:occ3?003o`000?l_d2oo;m0_00Ko;m0_00?o0000
oaWV6OlIiQT01_lIiQT00ol0003oEjQGoeNXE`04oeNXE`03o`000?m[U6_oJiA[00goJiA[3ol0000;
onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oO8=oogb3O00Kogb3O00?o0000oiiQW_nNHIh01OnNHIh00ol0
003oRGJ9ohUfR@04ohUfR@03o`000?mJYE[oFZEJ00GoFZEJ0_l00006od:m@P03o`000?ll`cco?<<l
00Wo?<<l0_l00008obo@;`03o`000?lIiQWo6NHI00Ko6NHI1Ol000000omGZ5Oo0000of^DJ`0?of^D
J`03o`000?n]DZgo[E:]00_o[E:]00?o0000onXEj_oZ5NX02OoZ5NX00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oO8=oogb3O00Kogb3O00?o0000oiiQW_nNHIh01_nNHIh00ol0003o
RGJ9ohUfR@04o`0000KoFZEJ00?o0000od:m@_m2_D801om2_D800ol0003o?<<locc3?005occ3?0?o
000000?o9MXUo`000?l_d2l01ol_d2l00ol0003o6NHIoaWV6@05oaWV6@03o`000?mKY5_oFjAK00?o
FjAK0_l0000?of^DJ`;o00003On]DZd00ol0003ojQGZonXEjP08onXEjP03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000Wogb3O00?o0000oiiQW_nNHIh01onNHIh2o`0000CoSG:=00Co0000oeZUF_mJYE[o
FZEJ0_l0000:od:m@P03o`000?ll`cco?<<l00;o?<<l0ol00005obGJ9@03o`000?l_d2oo;m0_00Go
;m0_00?o0000oaWV6OlIiQT01?lIiQT00ol0003oFjAKoe^TF`06oe^TF`03o`000?m[U6_oJiA[00[o
JiA[0_l00002ohacS003o`000?n]DZgo[E:]00[o[E:]00?o0000onXEj_oZ5NX02?oZ5NX00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000omlPgooO8=l01_oO8=l00ol0003oWV6NoiiQWP08oiiQWP03o`00
0?n=LXgoSG:=00CoSG:=00?o0000oeZUF_l000003?m2_D800ol0003o?<<lo`000002o`0000Wo9MXU
00?o0000obo@;ol_d2l01?l_d2l00ol0003o6NHIoaWV6@03oaWV6@03o`000?mKY5_oFjAK00SoFjAK
1_l00004of^DJ`;o00001On<Lh`00ol0003o[E:]ojeB[@09ojeB[@03o`000?oZ5N[ojQGZ00SojQGZ
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oO8=oogb3O00Gogb3O00?o0000oiiQW_nNHIh01onN
HIh00ol0003oSG:=ohebS@06ohebS@03o`000?m2_D;o@[e200co@[e200?o0000obGJ9OlUfRD02_lU
fRD00ol0003o;m0_obo@;`04obo@;`04o`000?lIiQWo6NHIoaWV6@;o00002omKY5/00ol0003oMHYe
ogF:M@03ogF:M@Co00002?n<Lh`00ol0003o[E:]ojeB[@08ojeB[@03o`000?oZ5N[ojQGZ00OojQGZ
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000omlPgooO8=l00ooO8=l00ol0003oWV6NoiiQWP07oiiQWP03o`000?n=
LXgoSG:=00OoSG:=00?o0000od:m@_m2_D803?m2_D800ol0003o9MXUobGJ9@0;obGJ9@03o`000?l_
d2oo;m0_00?o;m0_00Co0000oaWV6OlIiQWo00003OmKY5/00ol0003oMHYeogF:M@06ogF:M@03o`00
0?n<LhcoS7><00OoS7><00?o0000ojeB[On]DZd01on]DZd00ol0003ojQGZonXEjP06onXEjP04o`00
0?ol0ocoo0?loo`3o0;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oO8=oogb3O00;ogb3O00?o0000oiiQW_nNHIh0
1_nNHIh00ol0003oSG:=ohebS@09ohebS@03o`000?m2_D;o@[e200Wo@[e20_l0000>obGJ9@?o0000
0ol_d2l00ol0003o6NHIo`00000=oe^TF`03o`000?meRWGoMHYe00OoMHYe00?o0000ohacS?n<Lh`0
2?n<Lh`:o`0000KojQGZ0_l00006oo`3o003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoWV6N00?o
0000ohebSOn=LXd02_n=LXd00ol0003o@[e2od:m@P06od:m@P;o000000?o?L8mo`000?lUfRD02olU
fRD2o`0000?oEZUF1Ol0000>oe^TF`03o`000?meRWGoMHYe00OoMHYe00?o0000ohacS?n<Lh`02?n<
Lh`00ol0003o`cc3ol<l``06ol<l``03o`000?oZ5N[ojQGZ00?ojQGZ00?o0000oo`3o?ol0o`01ool
0o`2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003odbcCom</d`03om</d`Co00000_nNHIh00ol0003oSG:=ohebS@0;
ohebS@03o`000?m2_D;o@[e200?o@[e20ol00004ocg2?@03o`000?lUfRGo9MXU00Oo9MXU0_l00008
oeJYEP03o`000?mKY5_oFjAK00goFjAK00?o0000ogF:MOmeRWD02?meRWD00ol0003oS7><ohacS007
ohacS003o`000?o3?<?o`cc300Oo`cc30ol000000ooZ5N[o0000oo`3o00;oo`3o0;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oC;=?odbcC00OodbcC0_l0000?ohebS@03o`000?m2_D;o@[e200;o00002?lm`Sd00ol0
003o9MXUobGJ9@05obGJ9@03o`000?mFZEKoEZUF00SoEZUF00?o0000oe^TFomKY5/03OmKY5/00ol0
003oMHYeogF:M@08ogF:M@03o`000?n<LhcoS7><00KoS7><00?o0000ol<l`oo3?<<02?o3?<<01?l0
003ojaC[on/Djol0000?oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003odbcCom</d`09om</
d`03o`000?n=LXgoSG:=00koSG:=0_l0000;ocg2?@03o`000?lUfRGo9MXU00;o9MXU0_l0000;oeJY
EP03o`000?mKY5_oFjAK00goFjAK00?o0000ogF:MOmeRWD02?meRWD00ol0003oS7><ohacS006ohac
S003o`000?o3?<?o`cc300Oo`cc300Go0000on/Djoo[5>_ojaC[o`00000@oo`3o0;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003odbcCom</d`0:om</d`03o`000?n=LXgoSG:=00goSG:=0_l0000<ocg2?@04o`000?lUfRGo0000
o`0000goEZUF00?o0000oe^TFomKY5/03?mKY5/00ol0003oMHYeogF:M@09ogF:M@03o`000?n<Lhco
S7><00KoS7><00?o0000ol<l`oo3?<<01_o3?<<00ol0003ojaC[on/Dj`03on/Dj`03o`000?ol0oco
o0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003odbcCom</d`0:om</d`03o`000?n=LXgoSG:=00coSG:=00Co0000ocg2
?Olm`Sgo00003?lm`Sd00ol0003oEZUFoeJYEP0>oeJYEP03o`000?mKY5_oFjAK00SoFjAK1?l0000;
ogF:M@03o`000?n<LhcoS7><00KoS7><00?o0000ol<l`oo3?<<01Oo3?<<00ol0003ojaC[on/Dj`04
on/Dj`03o`000?ol0ocoo0?l00ooo0?l00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003odbcCom</d`0;om</d`03o`000?n=LXgoSG:=
00_oSG:=00?o0000ocg2?Olm`Sd00_lm`Sd00ol0003o?L8mocg2?@09ocg2?@03o`000?mFZEKoEZUF
00koEZUF00Co0000oe^TFomKY5_oFjAK1ol00003ofBKI003o`000?meRWGoMHYe00WoMHYe00?o0000
ohacS?n<Lh`01_n<Lh`00ol0003o`cc3ol<l``04ol<l``03o`000?o[5>_ojaC[00KojaC[00?o0000
oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oC;=?odbcC00codbcC00?o0000ohebSOn=LXd02_n=LXd00ol0
003o?L8mocg2?@03ocg2?@03o`000?lm`Sgo?L8m00So?L8m00?o0000oeJYE_mFZEH03_mFZEH4o`00
00_oI9]T00?o0000ogF:MOmeRWD02?meRWD00ol0003oS7><ohacS005ohacS003o`000?o3?<?o`cc3
00Go`cc300?o0000on/Djoo[5>/01_o[5>/00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om</dooC
;=<03?oC;=<7o`0000GoSG:=00?o0000ocg2?Olm`Sd01Olm`Sd00ol0003o?L8mocg2?@07ocg2?@03
o`000?mFZEKoEZUF00koEZUF00?o0000ofBKI?mTVf@03OmTVf@00ol0003oMHYeogF:M@08ogF:M@03
o`000?n<LhcoS7><00CoS7><00?o0000ol<l`oo3?<<01?o3?<<00ol0003ojaC[on/Dj`07on/Dj`03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003odbcCom</d`0=om</d`03o`000?nWF:OoYeRW00CoYeRW
1Ol00009ocg2?@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000oeJYE_mFZEH03_mFZEH00ol0003oI9]T
ofBKI00=ofBKI003o`000?meRWGoMHYe00SoMHYe00Co0000ohacS?n<LhcoS7><1Ol00004ol<l``03
o`000?o[5>_ojaC[00WojaC[1?l0000:oo`3o003o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=om</d`03o`000?nWF:OoYeRW00WoYeRW
0_l00009ocg2?@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000oeJYE_mFZEH03?mFZEH00ol0003oI9]T
ofBKI00?ofBKI0Ko00001?meRWD4o`0000GobCK90_l000000oo3?<?o0000on/Dj`0;on/Dj`04o`00
0?ol0ocoo0?loo`3o0Oo00000ool0o`00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oU6^GoiA[UonDJi@?o00002_oC;=<00ol0003o
YeRWojMHY`09ojMHY`03o`000?mC[5?o000000;o00001olm`Sd00ol0003o?L8mocg2?@05ocg2?@03
o`000?mFZEKoEZUF00SoEZUF1Ol0000AofBKI003o`000?n2OH;oPWf200?oPWf21?l0000;olTfb@03
o`000?o[5>_ojaC[00[ojaC[00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000onDJiOoU6^D01OoU6^D2o`0000OodbcC
00?o0000ojMHYonWF:L02_nWF:L00ol0003oDjaCoe>/D`02oe>/D`?o00001Olm`Sd00ol0003o?L8m
ocg2?@04ocg2?@04o`000?mFZEKoEZUFoeJYEPOo00001?m8]dP00ol0003oI9]TofBKI00>ofBKI003
o`000?n2OH;oPWf200OoPWf200?o0000olTfbOo9=/T02Oo9=/T00ol0003ojaC[on/Dj`09on/Dj`03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003oiA[UonDJi@08onDJi@;o00001?oC;=<00ol0003oYeRW
ojMHY`0;ojMHY`03o`000?mC[5?oDjaC00GoDjaC0ol00003ocg2?@04o`000?lm`Sgo?L8mocg2?@Ko
00003?m8]dP00ol0003oI9]TofBKI00=ofBKI003o`000?n2OH;oPWf200OoPWf200?o0000olTfbOo9
=/T02_o9=/T00ol0003ojaC[on/Dj`08on/Dj`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onDJi@?o000000?odbcCo`000?nWF:L0
3?nWF:L00ol0003oDjaCoe>/D`08oe>/D`?o000000Co?L8mo`000?l0003o00000_mnPGh00ol0003o
B;M8odRgB00=odRgB003o`000?mTVfCoI9]T00coI9]T00?o0000oh9mP_n2OH802?n2OH800ol0003o
bCK9olTfb@0;olTfb@03o`000?o[5>_ojaC[00KojaC[00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
iA[U00?o0000ojMHYonWF:L03?nWF:L00ol0003oDjaCoe>/D`0;oe>/D`03o`000?mnPGkoOX5n00?o
OX5n00?o0000odRgB?m8]dP03?m8]dP00ol0003o=LXeo`00000=ofBKI003o`000?n2OH;oPWf200So
PWf200?o0000olTfbOo9=/T03?o9=/T3o`0000GojaC[00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oU6^GoiA[U00coiA[U00?o0000ojMHYonWF:L03?nWF:L00ol0003oDjaCoe>/D`0:oe>/D`03o`00
0?mnPGkoOX5n00GoOX5n00?o0000odRgB?m8]dP02_m8]dP01?l0003o=LXeocG:=OlebSD2o`0000[o
I9]T00?o0000oh9mP_n2OH802On2OH800ol0003obCK9olTfb@0<olTfb@03o`000?o^4NkokQ7^00?o
000000?ojaC[o`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000ojMHYonWF:L0
3?nWF:L00ol0003oDjaCoe>/D`09oe>/D`03o`000?mnPGkoOX5n00KoOX5n00?o0000odRgB?m8]dP0
2Om8]dP00ol0003o=LXeocG:=@02ocG:=@03o`000?mlPgco000000;o00001omTVf@00ol0003oPWf2
oh9mPP09oh9mPP03o`000?o9=/WobCK900_obCK900?o0000onhAk_o^4Nh01?o^4Nh00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onDJiOoU6^D02ooU6^D00ol0003oYeRWojMHY`0;ojMHY`03o`000?mC
[5?oDjaC00SoDjaC00?o0000ogj1O_mnPGh01omnPGh00ol0003oB;M8odRgB008odRgB003o`000?le
bSGo=LXe00?o=LXe00?o0000ogb3O?mlPg`00_mlPg`2o`0000CoI9]T00?o0000oh9mP_n2OH802_n2
OH800ol0003obCK9olTfb@0:olTfb@03o`000?o^4NkokQ7^00GokQ7^00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oU6^GoiA[U00[oiA[U0ol0000;ojMHY`Ko00001?mC[5<00ol0003oOX5nogj1OP08
ogj1OP03o`000?m8]dSoB;M800OoB;M800?o0000ocG:=OlebSD00olebSD00ol0003oO8=logb3O005
ogb3O0?o000000?oI9]To`000?n2OH802on2OH800ol0003obCK9olTfb@09olTfb@03o`000?o^4Nko
kQ7^00OokQ7^00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oU6^GoiA[U00WoiA[U00?o0000oklo
_ono?kl01?l00006ojMHY`03o`000?nPGj3oX5nP00CoX5nP1?l0000<ogj1OP03o`000?m8]dSoB;M8
00GoB;M800?o0000ocG:=OlebSD01?lebSD00ol0003oO8=logb3O008ogb3O003o`000?n2OH;oPWf2
00_oPWf200?o0000olTfbOo9=/T02?o9=/T00ol0003okQ7^onhAkP08onhAkPGo00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oU6^GoiA[U00OoiA[U00?o0000oklo_ono?kl01Ono?kl3o`0000;oYeRW00?o0000oj1OX?nP
Gj002?nPGj000ol0003oOX5nogj1OP0:ogj1OP03o`000?m8]dSoB;M800CoB;M800?o0000ocG:=Ole
bSD01OlebSD00ol0003oO8=logb3O008ogb3O003o`000?n2OH;oPWf200WoPWf21?l00008olTfb@03
o`000?o^4NkokQ7^00WokQ7^00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiA[U
onDJi@05onDJi@03o`000?no?koo_cno00Wo_cno0_l0000<oj1OX003o`000?mnPGkoOX5n00WoOX5n
00?o0000odRgB?m8]dP00om8]dP00ol0003o=LXeocG:=@05ocG:=@03o`000?mlPgcoO8=l00[oO8=l
00?o0000oh9mP_n2OH801?n2OH84o`0000Co^dBk00?o0000olTfbOo9=/T01?o9=/T00ol0003okQ7^
onhAkP0:onhAkP03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oU6^GoiA[U00?oiA[U00?o0000oklo_ono?kl02ono
?kl00ol0003oX5nPoj1OX00:oj1OX003o`000?mnPGkoOX5n00WoOX5n00?o0000odRgB?m8]dP00_m8
]dP00ol0003o=LXeocG:=@06ocG:=@03o`000?mlPgcoO8=l00[oO8=l00?o0000oh9mP_n2OH801?l0
0009ok]4^`Ko00003?o^4Nh00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onDJiOoU6^GoiA[U0_l0
000=oklo_`03o`000?nPGj3oX5nP00[oX5nP00?o0000ogj1O_mnPGh02OmnPGh01Ol0003oB;M8odRg
B?m8]dSo000000Wo=LXe00?o0000ogb3O?mlPg`02omlPg`2o`0000go^dBk00?o0000onTFjOoY5^T0
0_oY5^T00ol0003okQ7^onhAkP0:onhAkP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiA[Uo`00
0002ondBk@;o00002ono?kl00ol0003oX5nPoj1OX00;oj1OX003o`000?mnPGkoOX5n00WoOX5n00?o
0000odRgB?l000002OlebSD00ol0003oO8=logb3O00<ogb3O003o`000?nkA;_o^dBk00co^dBk00?o
0000onTFjOoY5^T00ooY5^T00ol0003okQ7^onhAkP09onhAkP03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003okA;]ondBk@03ondBk@;o00002_no?kl00ol0003oX5nPoj1OX00:oj1OX003o`000?mnPGko
OX5n00SoOX5n1Ol00008ocG:=@03o`000?mlPgcoO8=l00coO8=l00?o0000ok]4^onkA;/02onkA;/0
0ol0003ojAKYonTFj@05onTFj@03o`000?o^4NkokQ7^00SokQ7^00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oo]4^d2o`0000So_cno00?o0000oj1OX?nPGj002_nPGj000ol0003oOX5nogj1OP07ogj1
OP03o`000?maSW7oLHia00?oLHia0ol00005ocG:=@03o`000?mlPgcoO8=l00_oO8=l00?o0000ok]4
^onkA;/03?nkA;/00ol0003ojAKYonTFj@06onTFj@03o`000?o^4NkokQ7^00OokQ7^00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?ol0oco000000WokA;]00?o0000oklo_ono?kl01Ono?kl2o`0000co
X5nP00?o0000ogj1O_mnPGh01OmnPGh00ol0003oLHiaog6>L@07og6>L@?o000000?o=LXeo`000?ml
Pg`03OmlPg`00ol0003o^dBkok]4^`0<ok]4^`03o`000?oY5^WojAKY00KojAKY00?o0000onhAk_o^
4Nh01_o^4Nh00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003oo`3o003o`000?o]4^gokA;]00OokA;]
0_l00004oklo_`03o`000?o<<lcoc3?<00;o00002_nPGj000ol0003oOX5nogj1OP03ogj1OP;o0000
3OmaSW42o`0000goO8=l0ol0000=ok]4^`03o`000?oY5^WojAKY00OojAKY00?o0000onhAk_o^4Nh0
1Oo^4Nh00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo0?loo`3o004oo`3o003o`000?o]4^gokA;]00SokA;]0_l0
00000ono?koo0000ol`cc004ol`cc003o`000?nPGj3oX5nP00OoX5nP00Co0000ogj1O_mnPGkoOX5n
0_l00002oiaSW003o`000?maSW7oLHia00coLHia3Ol00003ojQGZ003o`000?nkA;_o^dBk00[o^dBk
00?o0000onTFjOoY5^T02?oY5^T01?l0003okQ7^onhAk_o^4Nh4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?ol0o`00ol0003okA;]
ondBk@09ondBk@03o`000?o<<lcoc3?<00Goc3?<0_l00008oj1OX003o`000?mnPGko000000GoW6>L
00?o0000og6>LOmaSW402omaSW400ol0003oNhAkog^4N`09og^4N`03o`000?nXEjSoZ5NX00;oZ5NX
0_l00009ok]4^`03o`000?oY5^WojAKY00[ojAKY0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000oo`3
o00:oo`3o003o`000?o]4^gokA;]00SokA;]00?o0000ol`cc?o<<l`01oo<<l`4o`0000?oX5nP0ol0
0007oiaSW003o`000?maSW7oLHia00[oLHia00?o0000og^4NomkQ7/02OmkQ7/00ol0003oZ5NXojQG
Z004ojQGZ0;o00001onkA;/00ol0003ojAKYonTFj@0:onTFj@03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00OokA;]00?o0000ol`cc?o<<l`02?o<<l`0
1?l0003obcC;ol/dboo;=</3o`0000;o^DJi00?o0000oiaSW?nLHi`01_nLHi`00ol0003oLHiaog6>
L@08og6>L@03o`000?mkQ7_oNhAk00[oNhAk00?o0000ojQGZ?nXEjP01_nXEjP00ol0003o^dBkok]4
^`04ok]4^`03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000ondBkOo]4^d01Oo]4^d00ol0003oc3?<ol`cc008ol`cc003o`000?o;=<_o
bcC;00CobcC;00Go0000okU6^OniA[Wo^DJio`000008oiaSW003o`000?maSW7oLHia00OoLHia00?o
0000og^4NomkQ7/02_mkQ7/00ol0003oZ5NXojQGZ007ojQGZ0;o00001?nkA;/00ol0003ojAKYonTF
j@08onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d00oo]4^d0
0ol0003oc3?<ol`cc008ol`cc003o`000?o;=<_obcC;00CobcC;00?o0000okU6^OniA[T00_niA[T0
0ol0003oW6>LoiaSW007oiaSW003o`000?maSW7oLHia00KoLHia00?o0000og^4NomkQ7/02_mkQ7/0
0ol0003oZ5NXojQGZ009ojQGZ005o`000?nkA;_o^dBkok]4^ol000002OoY5^T00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_oc3?<00?o0000ol/dboo;=</01?o;=</00ol0003o^DJiokU6^@03
okU6^@03o`000?nLHicoW6>L00OoW6>L00?o0000og6>LOmaSW401OmaSW400ol0003oNhAkog^4N`0:
og^4N`03o`000?nXEjSoZ5NX00WoZ5NX1?l00009onTFj@03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?o`3o3ol0o`
oo0?l?l000002_o<<l`00ol0003obcC;ol/db`05ol/db`03o`000?niA[Wo^DJi00?o^DJi00?o0000
oiaSW?nLHi`02?nLHi`00ol0003oLHiaog6>L@04og6>L@03o`000?mkQ7_oNhAk00WoNhAk00?o0000
ojQGZ?nXEjP02?nXEjP2o`0000?ojAKY00?o0000onTFjOoY5^T01_oY5^T00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000oo0?l?o`3o000oo`3o000ol0003oc3?<ol`cc006ol`cc003o`000?o;=<_obcC;
00GobcC;00?o0000okU6^OniA[T01?niA[T00ol0003oW6>LoiaSW009oiaSW003o`000?maSW7oLHia
00;oLHia00?o0000og^4NomkQ7/02_mkQ7/00ol0003oZ5NXojQGZ006ojQGZ0;o00001_oY5^T8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003ol0o`oo0?l005oo0?l003o`000?o<<lcoc3?<00Goc3?<00?o0000ol/dboo;
=</01Oo;=</00ol0003o^DJiokU6^@05okU6^@03o`000?nLHicoW6>L00WoW6>L00Go0000og6>LOma
SW7oLHiao`00000<og^4N`03o`000?nXEjSoZ5NX00CoZ5NX0_l00008onTFj@03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00Ool0o`00?o0000ol`cc?o<
<l`00oo<<l`00ol0003obcC;ol/db`06ol/db`03o`000?niA[Wo^DJi00Go^DJi00?o0000oiaSW?nL
Hi`02_nLHi`00ol0003oLHiao`000004o`0000WoNhAk00?o0000ojQGZ?nXEjP00_nXEjP2o`0000[o
jAKY00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ol0o`oo0?l007oo0?l003o`00
0?o<<lcoc3?<00;oc3?<00?o0000ol/dboo;=</01_o;=</00ol0003o^DJiokU6^@07okU6^@;o0000
2onLHi`00ol0003o`cc3ol<l``03ol<l``Oo00000_mkQ7/00ol0003oZ5NXojQGZ002o`0000_ojAKY
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000oo0?l?o`3o002Oo`
3o001Ol0003oc3?<ol`cc?o<<lco000000SobcC;00?o0000okU6^OniA[T01oniA[T00ol0003ogR7N
o`000002o`0000SoW6>L00?o0000ol<l`oo3?<<02_o3?<<5o`0000gojAKY00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<oo0?l003o`000?o<<lco000000WobcC;00?o
0000okU6^OniA[T01_niA[T00ol0003ogR7NomhQgP03omhQgP?o00001?nLHi`00ol0003o`cc3ol<l
``0=ol<l``03o`000?oY5^WojAKY00gojAKY00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000oom0_d2o`0000_ol0o`00?o0000ol/dboo;=</01oo;=</00ol0003o^DJiokU6^@07
okU6^@03o`000?oN8MkogR7N00KogR7N0ol000000onLHico0000ol<l``0>ol<l``03o`000?oY5^Wo
jAKY00cojAKY00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo0?
l003o`000?o;=<_obcC;00;obcC;1_l00008okU6^@03o`000?oN8MkogR7N00[ogR7N00?o0000ol<l
`oo3?<<03oo3?<<00ol0003ojAKYonTFj@0:onTFj@;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo0?l0Go00001_o]4^d00ol0003o^DJiokU6^@05okU6^@03o`000?oN8MkogR7N00[o
gR7N00?o0000ol<l`oo3?<<03oo3?<<00ol0003ojAKYonTFj@07onTFj@?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo0?l003o`000?o]4^gokA;]00WokA;]00?o0000okU6^Oni
A[T00oniA[T00ol0003ogR7NomhQgP0;omhQgP03o`000?o3?<?o`cc300oo`cc300?o0000onTFjOoY
5^T01OoY5^T2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?ol0o`o`000?l00000
3Oo]4^d00ol0003o^DJiokU6^@02okU6^@03o`000?oN8MkogR7N00_ogR7N5?l00004onTFj@;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo0?lo`00000>ondBk@04o`000?niA[Wo^DJio`0000kogR7N
00?o0000onl@koo_4>l04?o_4>l00ol0003ojAKYo`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?ol0ocoo0?loo`3o?l000003_o]4^d00ol0003o^DJio`00000>omhQgP03o`00
0?o_4>ooka3_017oka3_00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000oo`3o?ol0o`00_ol0o`00ol0003okA;]ondBk@0=ondBk@03o`000?oN8MkogR7N00WogR7N1Ol0
000Bonl@k`;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003okA;]ondBk@0<ondBk@03o`000?oN8MkogR7N00;ogR7N1ol00004oo`3o003o`000?o_4>oo
ka3_00ooka3_00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o006oo`3
o003o`000?o]4^gokA;]00cokA;]1?l0000<oo`3o003o`000?o_4>ooka3_00coka3_0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Oo
o0?l00?o0000ondBkOo]4^d03?o]4^d00ol0003oo0?loo`3o00=oo`3o003o`000?o_4>ooka3_00_o
ka3_00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo`3o?ol
0o`02Ool0o`00ol0003okA;]ondBk@0:ondBk@03o`000?ol0ocoo0?l00koo0?l00?o0000onl@koo_
4>l02Oo_4>l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003oo0?l
oo`3o00?oo`3o003o`000?o_4>ooka3_00Koka3_0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo0?l00goo0?l3?l0
000Aoo`3o0?o00001_o_4>l00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000oo_4>l2o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000onl@kol000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01_l00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Go003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002?l00?l00oooo`3o003oo`00o`03o`00o`;oool00ol00?l2
oooo00Co003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00
o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00
o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`002Ol00?l00ooo
o`3o003oo`00o`03o`00o`04oooo0?l00?oo003oo`00o`;oool01Ol00?l00oooo`3o003oo`00o`02
o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo
0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo
00Ko003o1?ooo`000ol00?ooool0oooo0009o`00o`;oool02?l00?l00oooo`3o003oo`00o`04o`00
o`03oooo0?l00?oo003o00;o003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00
o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?oo
ool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o
003oo`00o`05o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo
003o0Oooool006[o003o0_ooo`02o`00o`04oooo0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo
003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co003o0_ooo`0;o`00o`03oooo0?l00?oo003o00Co
003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00
J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o
0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l00oooo`3o
003oo`00o`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo
003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003o
o`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co
003o0_ooo`04o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo
003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003o
o`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`00
3Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00
o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00go003o0_oo
o`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool03Ol00?l2
oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00
o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00o`;oool01_l00?l01?ooo`3o003oo`00ool00?l2
oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00
o`;oool01_l00?l2oooo01So003o0_ooo`06o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`04o`00
o`;oool01?l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko
003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`04o`00o`;o
ool00ol00?l3oooo00Co003o0_ooo`04o`00o`;oool01?l00?l2oooo00Co003o0_ooo`06o`00o`03
oc8bc?ooo`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003o
o`00o`0Fo`00o`Goool01Ol00?l6oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00;o003o
0_ooo`05o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol0
0?l5oooo027o003o1?ooo`08o`00o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1
ooooo`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(210) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.988 .012 .988 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.988 .012 .988 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.988 .012 .988 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.987 .013 .987 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.929 .071 .929 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.986 .014 .986 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.928 .072 .928 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.932 .068 .932 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.898 .102 .898 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.982 .018 .982 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.865 .135 .865 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.988 .012 .988 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.782 .218 .782 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.782 .218 .782 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.989 .011 .989 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.682 .318 .682 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.833 .167 .833 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.981 .019 .981 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.983 .017 .983 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.986 .014 .986 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.919 .081 .919 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.481 .519 .481 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.774 .226 .774 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.621 .379 .621 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.61 .39 .61 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.69 .31 .69 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.862 .138 .862 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.899 .101 .899 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.988 .012 .988 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.609 .391 .609 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.814 .186 .814 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.471 .529 .471 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.879 .121 .879 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.832 .168 .832 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.988 .012 .988 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.741 .259 .741 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.794 .206 .794 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.629 .371 .629 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.872 .128 .872 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.637 .363 .637 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.99 .01 .99 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.911 .089 .911 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.598 .402 .598 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.361 .639 .361 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.371 .629 .371 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.932 .068 .932 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.944 .056 .944 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.763 .237 .763 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.988 .012 .988 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.601 .399 .601 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.557 .443 .557 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.472 .528 .472 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.497 .503 .497 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.256 .744 .256 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.571 .429 .571 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.663 .337 .663 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.988 .012 .988 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.658 .342 .658 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.555 .445 .555 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.917 .083 .917 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.219 .781 .219 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.81 .19 .81 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.761 .239 .761 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.47 .53 .47 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.217 .783 .217 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.396 .604 .396 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.045 .955 .045 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.094 .906 .094 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.357 .643 .357 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.288 .712 .288 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.352 .648 .352 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.807 .193 .807 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.302 .698 .302 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.333 .667 .333 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.638 .362 .638 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.929 .071 .929 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.987 .013 .987 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.181 .819 .181 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.252 .748 .252 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.345 .655 .345 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.986 .014 .986 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.631 .369 .631 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.327 .673 .327 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.258 .742 .258 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.111 .889 .111 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.425 .575 .425 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.233 .767 .233 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.921 .079 .921 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.276 .724 .276 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.048 .952 .048 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.736 .264 .736 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.195 .805 .195 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.139 .861 .139 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.497 .503 .497 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.867 .133 .867 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.354 .646 .354 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.03 .97 .03 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.145 .855 .145 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.431 .569 .431 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.197 .803 .197 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.221 .779 .221 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.875 .125 .875 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.16 .84 .16 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.098 .902 .098 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.067 .933 .067 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.986 .014 .986 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.066 .934 .066 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.245 .755 .245 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.132 .868 .132 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.625 .375 .625 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.322 .678 .322 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.985 .015 .985 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.379 .621 .379 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.246 .754 .246 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.273 .727 .273 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.327 .673 .327 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.183 .817 .183 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.135 .865 .135 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.276 .724 .276 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.452 .548 .452 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.987 .013 .987 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.732 .268 .732 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.303 .697 .303 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.421 .579 .421 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.206 .794 .206 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.921 .079 .921 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.168 .832 .168 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.146 .854 .146 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.339 .661 .339 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.599 .401 .599 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.085 .915 .085 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.987 .013 .987 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.221 .779 .221 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.775 .225 .775 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.939 .061 .939 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.491 .509 .491 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.493 .507 .493 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.274 .726 .274 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.86 .14 .86 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.073 .927 .073 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.2 .8 .2 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.344 .656 .344 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.596 .404 .596 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.068 .932 .068 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.206 .794 .206 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.325 .675 .325 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.382 .618 .382 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.987 .013 .987 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.125 .875 .125 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.987 .013 .987 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.904 .096 .904 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.38 .62 .38 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.32 .68 .32 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.176 .824 .176 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.674 .326 .674 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.253 .747 .253 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.916 .084 .916 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.369 .631 .369 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.4 .6 .4 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.404 .596 .404 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.516 .484 .516 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.737 .263 .737 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.462 .538 .462 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.175 .825 .175 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.114 .886 .114 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.166 .834 .166 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.424 .576 .424 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.744 .256 .744 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.987 .013 .987 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.912 .088 .912 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.266 .734 .266 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.2 .8 .2 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.347 .653 .347 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.773 .227 .773 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.561 .439 .561 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.986 .014 .986 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.429 .571 .429 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.794 .206 .794 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.917 .083 .917 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.987 .013 .987 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.214 .786 .214 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.294 .706 .294 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.905 .095 .905 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.299 .701 .299 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.509 .491 .509 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.647 .353 .647 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.369 .631 .369 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.476 .524 .476 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.823 .177 .823 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.695 .305 .695 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.695 .305 .695 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.779 .221 .779 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.355 .645 .355 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.936 .064 .936 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.722 .278 .722 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.443 .557 .443 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.422 .578 .422 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.987 .013 .987 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.672 .328 .672 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.406 .594 .406 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.986 .014 .986 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.924 .076 .924 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.794 .206 .794 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.921 .079 .921 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.364 .636 .364 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.898 .102 .898 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.706 .294 .706 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.593 .407 .593 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.988 .012 .988 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.579 .421 .579 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.478 .522 .478 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.988 .012 .988 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.733 .267 .733 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.983 .017 .983 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.989 .011 .989 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.589 .411 .589 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.985 .015 .985 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.506 .494 .506 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.986 .014 .986 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.576 .424 .576 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.794 .206 .794 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.645 .355 .645 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.879 .121 .879 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.897 .103 .897 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.725 .275 .725 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.625 .375 .625 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.714 .286 .714 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.835 .165 .835 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.891 .109 .891 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.835 .165 .835 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.848 .152 .848 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.983 .017 .983 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.716 .284 .716 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.915 .085 .915 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.985 .015 .985 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.936 .064 .936 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.919 .081 .919 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.724 .276 .724 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.924 .076 .924 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.901 .099 .901 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.783 .217 .783 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.986 .014 .986 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.983 .017 .983 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.907 .093 .907 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.987 .013 .987 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.987 .013 .987 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.986 .014 .986 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.986 .014 .986 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.985 .015 .985 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.987 .013 .987 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003ojAKYonTFjOl0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onTFjOoY5^T00_oY5^T00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oY5^WojAKY00?ojAKY00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onTFjOoY5^T01OoY5^T00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojAKYonTFj@06onTFj@03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onTFjOoY5^T02?oY5^T00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o[5>_o0000013oo0?l00?o0000oo`3o?ol0o`02?ol
0o`9o`0000cojAKY00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003on/Dj`03o`000?ol
0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oiaSWonLHi`05onLHi`03o`000?oY
5^WojAKY00_ojAKY0ol00003onLHi`03o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
on/Djoo[5>/00oo[5>/00ol0003oo0?loo`3o00;oo`3o0;o00002ool0o`00ol0003oiaSWonLHi`06
onLHi`03o`000?oY5^WojAKY00[ojAKY00?o0000onLHiooW6>L01?oW6>L00ol0003oo0?loo`3o00:
oo`3o004o`000?oU6^GoiA[UonDJi@;o00002_ol0o`2o`000003onDJiOl0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?ol0oco
o0?l00Woo0?l00?o0000on/Djol000002ool0o`00ol0003oiaSWonLHi`06onLHi`03o`000?oY5^Wo
jAKY00WojAKY00?o0000onLHiooW6>L01_oW6>L00ol0003oo0?loo`3o008oo`3o003o`000?oU6^Go
iA[U00CoiA[U0_l00005oo`3o0?o00001?oU6^D00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008on/Dj`03o`000?ol0ocoo0?l00Ooo0?l0_l00003on/D
j`03o`000?ol0ocoo0?l00Ooo0?l00?o0000onLHiooW6>L01ooW6>L00ol0003ojAKYonTFj@09onTF
j@03o`000?oW6>OoiaSW00OoiaSW00?o0000oo`3o?ol0o`01Ool0o`2o`0000WoiA[U0_l000000ool
0oco0000o`000007onDJi@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000on/Djoo[
5>/02?o[5>/00ol0003oo0?loo`3o006oo`3o003o`000?o[5>_ojaC[00?ojaC[00?o0000oo`3o?ol
0o`01ool0o`00ol0003oiaSWonLHi`08onLHi`03o`000?oY5^WojAKY00OojAKY00?o0000onLHiooW
6>L02OoW6>L00ol0003oo0?loo`3o003oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000onDJiOoU
6^D01ooU6^D00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZo`000005oo`3o0;o00002oo[5>/2o`0000Koo0?l
00?o0000on/Djoo[5>/01Oo[5>/00ol0003oo0?loo`3o006oo`3o003o`000?oW6>OoiaSW00SoiaSW
00?o0000onTFjOoY5^T01_oY5^T00ol0003oiaSWonLHi`0;onLHi`05o`000?ol0ocoo0?loo`3o?l0
00003_oU6^D00ol0003oiA[UonDJi@08onDJi@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?oZ5N[ojQGZonXEj_l0
00000ool0o`00ol0003ojaC[on/Dj`0:on/Dj`04o`000?oM8]gogB;Mo`0000?oo0?l0_l00008on/D
j`03o`000?ol0ocoo0?l00Koo0?l00?o0000onLHiooW6>L02OoW6>L00ol0003ojAKYonTFj@05onTF
j@03o`000?oW6>OoiaSW00coiaSW00?o0000oo`3o?l000003ooU6^D00ol0003oiA[UonDJi@08onDJ
i@03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZonXEjP03onXEjP03o`000?ol0oco000000_o
jaC[0_l00004omdRg@03o`000?ol0oco000000_ojaC[00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
iaSWonLHi`09onLHi`03o`000?oY5^WojAKY00CojAKY00?o0000onLHiooW6>L03_oW6>L00ol0003o
iA[UonDJi@0>onDJi@03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000onXEj_oZ5NX0
1?oZ5NX00ol0003ojaC[on/Dj`09on/Dj`03o`000?oM8]gogB;M00GogB;M00?o0000on/Djoo[5>/0
2_o[5>/00ol0003oo0?loo`3o005oo`3o003o`000?oW6>OoiaSW00[oiaSW00?o0000onTFjOoY5^T0
0ooY5^T00ol0003oiaSWonLHi`0>onLHi`03o`000?oU6^GoiA[U00goiA[U00?o0000onDJiOoU6^D0
2_oU6^D00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZonXE
jP05onXEjP03o`000?o[5>_ojaC[00OojaC[0_l00008omdRg@03o`000?o[5>_ojaC[00_ojaC[00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oiaSWonLHi`0:onLHi`04o`000?oY5^WojAKYonTFj@?o0000
3ooW6>L00ol0003oiA[UonDJi@0>onDJi@03o`000?oU6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_ol0o`00ol0003oo0?loo`3
o009oo`3o003o`000?oZ5N[ojQGZ00OojQGZ00?o0000on/Djoo[5>/01?o[5>/2o`0000_ogB;M1?l0
0009on/Dj`03o`000?ol0ocoo0?l00?oo0?l00?o0000onLHiooW6>L02ooW6>L01?l0003ojAKYo`00
0?l00003olDja@;o00003?oW6>L2o`00013oiA[U00?o0000onDJiOoU6^D02ooU6^D00ol0003oo0?l
oo`3o00=oo`3o004o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojQGZ
onXEjP07onXEjP03o`000?o[5>_ojaC[00?ojaC[00?o0000omdRgOoM8]d02ooM8]d01?l0003o^dBk
ok]4^onkA;/5o`0000GojaC[00?o0000oo`3o?ol0o`00_ol0o`00ol0003oiaSWonLHi`0<onLHi`03
o`000?o5>/GoaC[500GoaC[50_l00008onLHi`;o00000_nhAkP00ol0003oiA[UonDJi@0=onDJi@03
o`000?oU6^GoiA[U00_oiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo0?l
00?o0000oo`3o?ol0o`01ool0o`00ol0003ojQGZonXEjP09onXEjP03o`000?o[5>_ojaC[00;o0000
3OoM8]d00ol0003o^dBkok]4^`07ok]4^`Ko00000_ol0o`4o`0000goiaSW00?o0000olDjaOo5>/D0
1oo5>/D2o`0000GoiaSW00?o0000okQ7^?nhAkP00onhAkP00ol0003oiA[UonDJi@0<onDJi@03o`00
0?oU6^GoiA[U00coiA[U00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oZ5N[ojQGZ00WojQGZ00?o
0000on/Djol000003ooM8]d00ol0003o^dBkok]4^`0<ok]4^`?o00001?oL8m`3o`0000WoiaSW00?o
0000olDjaOo5>/D02_o5>/D2o`000003onLHiol0003o000000Oo^4Nh00?o0000onDJiOoU6^D02ooU
6^D00ol0003oiA[UonDJi@0<onDJi@03o`000?ol0ocoo0?l00Koo0?l1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000
omdRgOoM8]d03_oM8]d00ol0003o^dBkok]4^`0=ok]4^`03o`000?oL8mcog2?L00Kog2?L0ol00005
onLHi`03o`000?o5>/GoaC[500goaC[500?o0000okQ7^?nhAkP02?nhAkP00ol0003oiA[UonDJi@09
onDJi@03o`000?oU6^GoiA[U00goiA[U00Co0000oo`3o?ol0ocoo0?l1Ol00003on/Dj`03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00?oo0?l00?o0000
onXEj_oZ5NX02ooZ5NX2o`0000oogB;M00?o0000ok]4^onkA;/03OnkA;/00ol0003og2?Lom`Sg00:
om`Sg0?o000000?oiaSWo`000?o5>/D03oo5>/D00ol0003o^4NhokQ7^009okQ7^003o`000?oU6^Go
iA[U00SoiA[U00?o0000onDJiOoU6^D03_oU6^D3o`0000SojaC[00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00[oo0?l0_l00003oo`3o003o`000?oZ5N[ojQGZ00SojQGZ0ol000000oo2
?L;o0000omdRg@0>omdRg@03o`000?nkA;_o^dBk00go^dBk00?o0000om`Sg?oL8m`03OoL8m`00ol0
003oaC[5olDja@0?olDja@03o`000?nhAkSo^4Nh00[o^4Nh2ol0000;onDJi@Go00003?o[5>/00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`02_ol0o`01Ol0003ojAKYo`000?ol0oco0000
00SojQGZ0ol00005ol8m`P03o`000?oM8]gogB;M00cogB;M00?o0000ok]4^onkA;/03OnkA;/00ol0
003og2?Lom`Sg00=om`Sg0;o00004?o5>/D00ol0003o^4NhokQ7^00:okQ7^003o`000?ndBkCo]4^d
00Oo]4^d00?o0000onDJiOoU6^D00_oU6^D7o`0000Co^DJi00?o0000on/Djoo[5>/02_o[5>/00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`02Ool0o`01?l0003ojAKYonTFjOoY5^T2o`00
00GojQGZ0ol00009ol8m`P;o00002ooM8]d00ol0003o^dBkok]4^`0=ok]4^`03o`000?oL8mcog2?L
00gog2?L00Co0000oka3_?nl@kco00003oo5>/D00ol0003o^4NhokQ7^009okQ7^003o`000?ndBkCo
]4^d00Wo]4^d1?l0000;okU6^@03o`000?o[5>_ojaC[00[ojaC[00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?ol0ocoo0?l00Soo0?l00?o0000onTFjOoY5^T01?oY5^T00ol0003ojQGZo`000002o`00
00co`Sg200Co0000oj5NXOl0003o00002OoM8]d00ol0003o^dBkok]4^`0=ok]4^`03o`000?oL8mco
g2?L00gog2?L00Go0000oka3_?nl@kco_4>lo`00000=olDja@03o`000?nhAkSo^4Nh00[o^4Nh00?o
0000okA;]?ndBk@02OndBk@00ol0003o^DJiokU6^@0<okU6^@03o`000?o[5>_ojaC[00[ojaC[00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00Ooo0?l00?o0000onTFjOoY5^T01_oY5^T0
0ol0003o`Sg2ol8m`P0<ol8m`P03o`000?nQGZ7oXEjQ00;oXEjQ0_l00007omdRg@03o`000?nkA;_o
^dBk00co^dBk00?o0000om`Sg?oL8m`03OoL8m`00ol0003o_4>loka3_003oka3_003o`000?o5>/Go
aC[500[oaC[500?o0000okQ7^?nhAkP02_nhAkP00ol0003o]4^dokA;]009okA;]003o`000?niA[Wo
^DJi00co^DJi00?o0000on/Djoo[5>/02oo[5>/00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000oo`3
o?ol0o`01_ol0o`00ol0003ojAKYonTFj@06onTFj@03o`000?o2?L;o`Sg200_o`Sg200?o0000oj5N
XOnQGZ401OnQGZ400ol0003ogB;MomdRg@03omdRg@03o`000?nkA;_o^dBk00go^dBk00?o0000om`S
g?oL8m`03OoL8m`00ol0003o_4>loka3_004oka3_003o`000?o5>/GoaC[500WoaC[500?o0000okQ7
^?nhAkP02OnhAkP00ol0003o]4^dokA;]00:okA;]003o`000?niA[Wo^DJi00co^DJi00?o0000on/D
joo[5>/02oo[5>/00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
jAKYonTFj@07onTFj@03o`000?o2?L;o`Sg200_o`Sg200?o0000oj5NXOnQGZ401_nQGZ42o`0000?o
gB;M00?o0000ok]4^onkA;/03OnkA;/00ol0003og2?Lom`Sg00<om`Sg003o`000?nl@kco_4>l00Ko
_4>l00?o0000olDjaOo5>/D02?o5>/D00ol0003o^4NhokQ7^009okQ7^003o`000?ndBkCo]4^d00[o
]4^d00?o0000okU6^OniA[T03?niA[T00ol0003ojaC[on/Dj`0;on/Dj`03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?ol0ocoo0?l00Coo0?l00?o0000onTFjOoY5^T02?oY5^T00ol0003o`Sg2ol8m`P0:ol8m`P03o`00
0?nQGZ7oXEjQ00WoXEjQ0_l000000ooM8]go0000ok]4^`0<ok]4^`?o00003_oL8m`00ol0003o_4>l
oka3_007oka3_003o`000?o5>/GoaC[500OoaC[500?o0000okQ7^?nhAkP02OnhAkP00ol0003o]4^d
okA;]00;okA;]003o`000?niA[Wo^DJi00co^DJi00?o0000on/Djoo[5>/02_o[5>/00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008ood2o@03o`000?ol0ocoo0?l00?oo0?l00?o0000onTFjOoY5^T02_oY5^T00ol0003o`Sg2ol8m
`P09ol8m`P03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ok]4^onkA;/02_nkA;/2o`0000?oVFJI00?o
0000om`Sg?oL8m`02_oL8m`00ol0003o_4>loka3_009oka3_003o`000?o5>/GoaC[500KoaC[500?o
0000okQ7^?nhAkP02?nhAkP00ol0003o]4^dokA;]00<okA;]003o`000?niA[Wo^DJi00co^DJi00?o
0000on/Djoo[5>/02_o[5>/00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Oom0_d0
0ol0003oo0?loo`3o002oo`3o003o`000?oY5^WojAKY00_ojAKY00?o0000ol8m`_o2?L802?o2?L80
0ol0003oXEjQoj5NX@0<oj5NX@03o`000?nkA;_o^dBk00So^dBk0_l00006oiUVV@;o00002_oL8m`0
0ol0003o_4>loka3_00:oka3_003o`000?o5>/GoaC[500GoaC[500?o0000okQ7^?nhAkP02?nhAkP0
0ol0003o]4^dokA;]00<okA;]003o`000?niA[Wo^DJi00co^DJi00?o0000on/Djoo[5>/02oo[5>/0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo@;m00Go0000oo`3o?ol0ocoo0?lo`00000=
onTFj@03o`000?o2?L;o`Sg200Oo`Sg200?o0000oj5NXOnQGZ403_nQGZ400ol0003o^dBkok]4^`04
ok]4^`?o00002_nIIYT00ol0003og2?Lom`Sg007om`Sg003o`000?nl@kco_4>l00_o_4>l00?o0000
olDjaOo5>/D00oo5>/D00ol0003o^4NhokQ7^009okQ7^003o`000?ndBkCo]4^d00co]4^d00?o0000
okU6^OniA[T03?niA[T00ol0003ojaC[on/Dj`0;on/Dj`;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_ol0o`00ol0
003ojAKYonTFj@0<onTFj@03o`000?o2?L;o`Sg200Oo`Sg200?o0000oj5NXOnQGZ403onQGZ401?l0
003o^dBkok]4^onkA;/2o`0000koVFJI0_l00006om`Sg003o`000?nl@kco_4>l00go_4>l00?o0000
olDjaOo5>/D00_o5>/D00ol0003o^4NhokQ7^008okQ7^003o`000?ndBkCo]4^d00co]4^d0ol0000=
okU6^@03o`000?o[5>_ojaC[00_ojaC[00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ol0oco0000
00oojAKY00?o0000ol8m`_o2?L801_o2?L800ol0003oXEjQoj5NX@0@oj5NX@Co00004_nIIYT00ol0
003og2?Lom`Sg003om`Sg003o`000?nl@kco_4>l00ko_4>l00Go0000olDjaOo5>/GoaC[5o`000005
okQ7^0Oo00003?ndBk@01Ol0003oPGj1oh5nPOn1OX7o000000co^DJi00?o0000on/Djoo[5>/02?o[
5>/3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000oojAKY00?o0000ol8m`_o2?L801_o2?L800ol0003oXEjQoj5NX@0=
oj5NX@?o000000CoK9=/o`000?l0003o00004onIIYT2o`0000;og2?L00?o0000oka3_?nl@k`04?nl
@k`00ol0003oaC[5o`000006o`0000Oo[5>/00?o0000okA;]?ndBk@02?ndBk@00ol0003oPGj1oh5n
P@03oh5nP@;o00002?niA[T3o`0000KojaC[1?l00002onHIiP03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003ojaC[o`000?nm@[d3o`0000gojAKY00?o0000ol8m`_o2?L801?o2?L800ol0003oXEjQoj5N
X@0;oj5NX@?o00000om/Tf`01Ol0003oKY5^o`000?mQWV7o000001CoVFJI00?o0000om`Sg?l00000
4onl@k`00ol0003o[5>/ojaC[00=ojaC[003o`000?ndBkCo]4^d00Go]4^d0_l00008oh5nP@03o`00
0?niA[Wo^DJi00Go00000onfBKH00ol0003ojaC[on/Dj`03o`0000OoiQWV00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?o[5>_ojaC[o`0000Co_D:m0ol0000:onTFj@03o`000?o2?L;o`Sg200?o`Sg2
00?o0000oj5NXOnQGZ402OnQGZ43o`0000GoK9=/00Co0000ofjAK_m^TFko00000_mQWV400ol0003o
VFJIoiUVV@0BoiUVV@03o`000?nl@kco_4>l01;o_4>l00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003o
]4^dokA;]003okA;]003o`000?n1OX7oPGj100WoPGj10_l00009okI9]P;o00002_oV6NH00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000on/Djoo[5>_ojaC[o`000007oke2_@;o00001ooY5^T5o`0000;o
`Sg200?o0000oj5NXOnQGZ401_nQGZ43o`0000SoK9=/00Co0000ofjAK_m^TFko00000omQWV400ol0
003oVFJIoiUVV@0AoiUVV@03o`000?nl@kco_4>l017o_4>l00?o0000ojaC[?n/Dj`04?n/Dj`01Ol0
003o]4^dokA;]?ndBkCo000000coPGj100?o0000okI9]_nfBKH02?nfBKH00ol0003oiQWVonHIiP0:
onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CojaC[00?o0000oke2_Onm@[d01onm@[d3o`00
0004onTFjOl0003o0000o`0000GoZ5NX0_l00006oj5NX@?o00002_m/Tf`01Ol0003oKY5^ofjAK_m^
TFko000000CoHIiQ00?o0000oiUVVOnIIYT04?nIIYT00ol0003o_4>loka3_00Aoka3_003o`000?n/
Djco[5>/017o[5>/00?o0000okA;]?l000003On1OX400ol0003o]TVfokI9]P08okI9]P03o`000?oV
6NKoiQWV00[oiQWV00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o[5>_ojaC[00CojaC[00?o0000
oke2_Onm@[d02_nm@[d00ol0003oZ5NXojQGZ008ojQGZ003o`000?nQGZ7oXEjQ00?o00003Om/Tf`0
1Ol0003oKY5^ofjAK_m^TFko000000GoHIiQ00?o0000oiUVVOnIIYT03onIIYT00ol0003o_4>loka3
_00Aoka3_003o`000?n/Djco[5>/01;o[5>/00?o0000oh5nPOn1OX403?n1OX400ol0003o]TVfokI9
]P08okI9]P03o`000?oV6NKoiQWV00_oiQWV00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000on/Djoo[5>/01Oo[5>/0
0ol0003o_D:moke2_@0:oke2_@03o`000?nXEjSoZ5NX00WoZ5NX0_l0000?ofbCK003o`000?m^TFko
KY5^00;oKY5^00?o0000of6NHOmQWV401?mQWV400ol0003oVFJIoiUVV@0=oiUVV@?o00004Onl@k`0
0ol0003o[5>/ojaC[00CojaC[003o`000?n1OX7oPGj100_oPGj100?o0000okI9]_nfBKH02OnfBKH0
0ol0003oiQWVonHIiP0;onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?o[5>/0
0ol0003o_D:moke2_@0:oke2_@03o`000?nXEjSoZ5NX00WoZ5NX00?o0000ofbCK?m/Tf`03Om/Tf`0
0ol0003oKY5^ofjAKP03ofjAKP03o`000?mQWV7oHIiQ00GoHIiQ00?o0000oiUVVOnIIYT02_nIIYT2
o`0000?oV6NH00?o0000oka3_?nl@k`03_nl@k`00ol0003o[5>/ojaC[00CojaC[003o`000?n1OX7o
PGj100_oPGj100?o0000okI9]_nfBKH02OnfBKH00ol0003oiQWVonHIiP0;onHIiP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000on/Djoo[5>/01oo[5>/2o`0000_o_D:m00?o0000ojQG
Z?nXEjP02onXEjP00ol0003oK9=/ofbCK00<ofbCK003o`000?m^TFkoKY5^00?oKY5^00?o0000of6N
HOmQWV401_mQWV400ol0003oVFJIoiUVV@07oiUVV@;o00001_nHIiP2o`0000ko_4>l00?o0000ojaC
[?n/Dj`04on/Dj`00ol0003oPGj1oh5nP@0;oh5nP@03o`000?nfBKKo]TVf00Wo]TVf00?o0000onHI
i_oV6NH03?oV6NH00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009on/D
j`03o`000?o6>LKo000000_o_D:m00?o0000ojQGZ?nXEjP02onXEjP00ol0003oK9=/ofbCK00;ofbC
K003o`000?m^TFkoKY5^00CoKY5^00?o0000of6NHOmQWV401omQWV400ol0003oVFJIoiUVV@05oiUV
V@03o`000?nHIiSoV6NH00SoV6NH00?o0000oka3_?nl@k`02_nl@k`00ol0003o[5>/ojaC[00DojaC
[003o`000?n1OX7oPGj100_oPGj100?o0000okI9]_nfBKH02OnfBKH00ol0003oiQWVonHIiP0<onHI
iP03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009on/Dj`04o`000?o6>LKoaSW6o`00
00_o_D:m00?o0000ojQGZ?nXEjP02onXEjP00ol0003oK9=/ofbCK00;ofbCK003o`000?m^TFkoKY5^
00CoKY5^00?o0000of6NHOmQWV402?mQWV400ol0003oVFJIoiUVV@02oiUVV@;o00003?nHIiP2o`00
00[o_4>l00?o0000ojaC[?n/Dj`05?n/Dj`00ol0003oPGj1oh5nP@0;oh5nP@03o`000?nfBKKo]TVf
00Wo]TVf00?o0000onHIi_oV6NH03OoV6NH00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojaC[on/Dj`07on/Dj`03
o`000?o6>LKoaSW600;oaSW600?o0000oke2_Onm@[d02?nm@[d00ol0003oZ5NXojQGZ00<ojQGZ003
o`000?m/TfcoK9=/00WoK9=/00?o0000ofjAK_m^TFh01Om^TFh00ol0003oHIiQof6NH@09of6NH@04
o`000?nIIYWo0000o`00013oV6NH0_l00008oka3_003o`000?n/Djco[5>/01Co[5>/0ol0000;oh5n
P@03o`000?nfBKKo]TVf00Wo]TVf00?o0000onHIi_oV6NH03OoV6NH01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ojaC[on/Dj`06on/Dj`03o`000?o6>LKoaSW600?oaSW600?o0000oke2
_Onm@[d02?nm@[d00ol0003oZ5NXojQGZ00;ojQGZ0;o00002_m/Tf`00ol0003oKY5^ofjAKP06ofjA
KP03o`000?mQWV7oHIiQ00[oHIiQ00?o0000oiQWV?nHIiP04_nHIiP00ol0003o_4>loka3_004oka3
_003o`000?n/Djco[5>/01Go[5>/00?o0000oiIYU_nFJIH01Ol00005oh5nP@03o`000?nfBKKo]TVf
00[o]TVf00?o0000onHIi_oV6NH03_oV6NH3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[on/Dj`04on/Dj`03
o`000?o6>LKoaSW600CoaSW600?o0000oke2_Onm@[d01onm@[d00ol0003oZ5NXojQGZ00;ojQGZ004
o`000?mhQgSoN8Mho`0000WoK9=/00?o0000ofjAK_m^TFh01_m^TFh00ol0003oHIiQof6NH@0:of6N
H@03o`000?nHIiSoV6NH01?oV6NH0_l00003oka3_0Co00005?n/Dj`00ol0003oUVVFoiIYUP06oiIY
UPCo000000?oPGj1o`000?nfBKH02onfBKH00ol0003oiQWVonHIiP0>onHIiP03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003ojaC[on/Dj`03on/Dj`03o`000?o6>LKoaSW600GoaSW600?o0000oke2_Onm
@[d01onm@[d00ol0003oZ5NXojQGZ009ojQGZ0;o00001?mhQgP00ol0003oK9=/ofbCK005ofbCK003
o`000?m^TFkoKY5^00OoKY5^00?o0000of6NHOmQWV402_mQWV400ol0003oV6NHoiQWV00EoiQWV003
o`000?nl@kco000000CoYEZU0ol0000@ojaC[003o`000?nFJIKoUVVF00_oUVVF0_l0000<okI9]P03
o`000?oV6NKoiQWV00coiQWV0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/00_o[5>/00ol0003oaSW6
olHiaP06olHiaP03o`000?nm@[go_D:m00Oo_D:m00?o0000ojQGZ?nXEjP02?nXEjP00ol0003oN8Mh
ogR7N005ogR7N003o`000?m/TfcoK9=/00CoK9=/00?o0000ofjAK_m^TFh01om^TFh00ol0003oHIiQ
of6NH@0:of6NH@03o`000?nHIiSoV6NH01KoV6NH00?o0000ojEJYOnUFZD01_nUFZD3o`0000co[5>/
00?o0000oiIYU_nFJIH03OnFJIH00ol0003o]TVfokI9]P09okI9]PGo00002OoV6NH2o`000003onPG
j?l0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003on/Djol0003oaSW600WoaSW600?o0000oke2_Onm@[d01_nm
@[d00ol0003oZ5NXojQGZ007ojQGZ003o`000?mhQgSoN8Mh00OoN8Mh00?o0000ofbCK?m/Tf`00_m/
Tf`00ol0003oKY5^ofjAKP08ofjAKP03o`000?mQWV7oHIiQ00WoHIiQ00?o0000oiQWV?nHIiP05onH
IiP00ol0003oYEZUojEJY@09ojEJY@?o00002On/Dj`00ol0003oUVVFoiIYUP0>oiIYUPKo00001?nf
BKH00ol0003o^DJiokU6^@03okU6^@Go00000_oV6NH2o`0000Coj1OX00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oM8]gogB;MomdRgOl000002oo6>LH00ol0003o_D:moke2_@06oke2_@03o`000?nX
EjSoZ5NX00GoZ5NX0_l0000;ogR7N004o`000?m/TfcoK9=/o`0000_oKY5^00?o0000of6NHOmQWV40
2OmQWV400ol0003oV6NHoiQWV00FoiQWV003o`000?nUFZGoYEZU00goYEZU0ol00005ojaC[003o`00
0?nFJIKoUVVF00ooUVVF00?o0000oimOWonOGil00onOGil4o`0000_o^DJi0_l00006onPGj003o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ogB;MomdRg@02omdRg@ko00001_nm@[d00ol0003oZ5NXojQG
Z005ojQGZ003o`000?mhQgSoN8Mh00coN8Mh00?o0000ofbCK?l000002om^TFh00ol0003oHIiQof6N
H@07of6NH@?o00006?nHIiP00ol0003oYEZUojEJY@0@ojEJY@?o000000?o[5>/o`000?nFJIH04?nF
JIH00ol0003oWenOoimOW`07oimOW`03o`000?niA[Wo^DJi00[o^DJi00?o0000onPGj?oX5nP01OoX
5nP00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005omdRg@03o`000?nNHIkoWV6N00_oWV6N0_l00004
oke2_@03o`000?nXEjSoZ5NX00?oZ5NX0_l0000@ogR7N003o`000?m^TFkoKY5^00[oKY5^00?o0000
of6NHOmQWV400omQWV44o`0000;oCK9=00?o0000oiQWV?nHIiP05OnHIiP00ol0003oYEZUojEJY@0D
ojEJY@03o`000?nFJIKoUVVF013oUVVF00?o0000oimOWonOGil01onOGil00ol0003o^DJiokU6^@0:
okU6^@03o`000?oX5nSoj1OX00Goj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oM8]gogB;M
00GogB;M00?o0000oiiQW_nNHIh03OnNHIh6o`0000?oZ5NX00?o0000ogR7N?mhQgP04?mhQgP00ol0
003oKY5^ofjAKP0:ofjAKP03o`000?mQWV7o000000?o00001om=/Td00ol0003oV6NHoiQWV00DoiQW
V003o`000?nUFZGoYEZU01CoYEZU00?o0000oiIYU_nFJIH03onFJIH00ol0003oWenOoimOW`08oimO
W`03o`000?niA[Wo^DJi00[o^DJi00?o0000onPGj?oX5nP01OoX5nP00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000omdRgOoM8]d01_oM8]d00ol0003oWV6NoiiQWP0=oiiQWP03o`000?nQGZ7oXEjQ00?o
XEjQ00?o0000ojQGZ?l000004omhQgP4o`0000WoKY5^0_l0000<odfbC@03o`000?nHIiSoV6NH01?o
V6NH00?o0000ojEJYOnUFZD05OnUFZD00ol0003oUVVFoiIYUP0>oiIYUP03o`000?nOGiooWenO00So
WenO00?o0000okU6^OniA[T02OniA[T00ol0003oj1OXonPGj007onPGj003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oM8]gogB;M00SogB;M00?o0000oiiQW_nNHIh02onNHIh00ol0003oXEjQoj5NX@05oj5NX@03o`00
0?mhQgSoN8Mh01;oN8Mh00Co0000oeZUF_mJYE[oFZEJ1Ol00003ofjAKP03o`000?m=/TgoCK9=00go
CK9=0ol0000@oiQWV0;o00006?nUFZD00ol0003oUVVFoiIYUP0=oiIYUP03o`000?nOGiooWenO00Wo
WenO00?o0000okU6^OniA[T02OniA[T00ol0003oj1OXonPGj007onPGj003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000oo`3o?ol0o`0
0_ol0o`6o`0000_ogB;M00?o0000oiiQW_nNHIh02_nNHIh00ol0003oXEjQoj5NX@06oj5NX@03o`00
0?mhQgSoN8Mh017oN8Mh00?o0000oeZUF_mJYEX01omJYEX3o`00013oCK9=00?o0000odJiA_m6^DH0
1Ol00009oiQWV0;o000000?oGZ5No`000?nUFZD05onUFZD00ol0003oUVVFoiIYUP0=oiIYUP03o`00
0?nOGiooWenO00WoWenO00?o0000okU6^OniA[T02?niA[T2o`0000[oj1OX00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo0?loo`3
o003oo`3o003o`000?o]4^gokA;]00;okA;]00?o0000omdRgOoM8]d02OoM8]d00ol0003oWV6NoiiQ
WP0:oiiQWP03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000ogR7N?mhQgP03omhQgP00ol0003oFZEJoeZU
FP0:oeZUFP03o`000?m=/TgoCK9=00goCK9=00?o0000odJiA_m6^DH01_m6^DH4o`0000CoV6NH00?o
0000oejQG_mNXEh00_mNXEh00ol0003oYEZUojEJY@0FojEJY@03o`000?nFJIKoUVVF00_oUVVF00?o
0000oimOWonOGil02onOGil00ol0003o^DJiokU6^@06okU6^@03o`000?o8=lSo000000[oj1OX00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo0?loo`3o004oo`3o003o`000?o]4^gokA;]00?okA;]00?o0000omdRgOoM8]d02?oM8]d=
o`0000[oXEjQ00?o0000ogR7N?mhQgP03omhQgP00ol0003oFZEJoeZUFP0;oeZUFP03o`000?m=/Tgo
CK9=00coCK9=00?o0000odJiA_m6^DH02_m6^DH4o`0000GoGZ5N00?o0000ojEJYOnUFZD05_nUFZD0
0ol0003oUVVFoiIYUP0:oiIYUP03o`000?nOGiooWenO00coWenO00?o0000okU6^OniA[T01?niA[T2
o`0000?ob3O800?o0000onPGj?oX5nP02?oX5nP00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ondB
kOo]4^d00oo]4^d00ol0003ogB;MomdRg@07omdRg@03o`000?nLHicoW6>L00WoW6>L00?o0000oj5N
XOnQGZ402OnQGZ400ol0003oN8MhogR7N00=ogR7N003o`000?mJYE[oFZEJ00coFZEJ00?o0000odfb
COm=/Td03?m=/Td00ol0003oA[U6odJiAP0;odJiAP03o`000?l]dRgo000000KoGZ5N00?o0000ojEJ
YOnUFZD05_nUFZD00ol0003oUVVFoiIYUP09oiIYUP03o`000?nOGiooWenO00coWenO00?o0000okU6
^OniA[T00oniA[T00ol0003ob3O8olPgb003olPgb003o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o0?loo`3o006oo`3o003o`000?o]4^gokA;]00CokA;]00?o0000omdRgOoM8]d01_oM8]d00ol0003o
W6>LoiaSW008oiaSW003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogR7N?mhQgP02?mhQgP4o`0000oo
FZEJ00?o0000odfbCOm=/Td02om=/Td00ol0003oA[U6odJiAP0;odJiAP04o`000?l]dRgo;M8]o`00
00OoGZ5N00?o0000ojEJYOnUFZD05OnUFZD00ol0003oUVVFoiIYUP08oiIYUP03o`000?nOGiooWenO
00goWenO00?o0000okU6^OniA[T00_niA[T00ol0003ob3O8olPgb005olPgb003o`000?oX5nSoj1OX
00Ooj1OX00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo0?loo`3o006oo`3o003o`000?o]4^gokA;]00GokA;]00?o0000omdRgOoM
8]d01OoM8]d00ol0003oW6>LoiaSW008oiaSW003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogR7N?mh
QgP00omhQgP5o`0000?oFjAK00?o0000oeZUF_mJYEX03_mJYEX00ol0003oCK9=odfbC@0:odfbC@03
o`000?m6^DKoA[U600[oA[U600Go0000obgB;Ol]dRgo;M8]o`000007oejQGP03o`000?nUFZGoYEZU
01GoYEZU00?o0000oiIYU_nFJIH02?nFJIH00ol0003oWenOoimOW`0=oimOW`03o`000?niA[Wo^DJi
00;o00002?o8=lP00ol0003oj1OXonPGj008onPGj0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003okA;]ondBk@05ondBk@03o`000?oM8]gogB;M00Go
gB;M00?o0000oiaSW?nLHi`02?nLHi`00ol0003oXEjQoj5NX@0<oj5NX@Go00002OmKY5/00ol0003o
FZEJoeZUFP0<oeZUFP;o00003?m=/Td00ol0003oA[U6odJiAP0:odJiAP05o`000?l]dRgo;M8]obgB
;Ol000002?mNXEh00ol0003oYEZUojEJY@0DojEJY@?o00001onFJIH00ol0003oWenOoimOW`0>oimO
W`03o`000?niA[Wo000000_ob3O800?o0000onPGj?oX5nP01_oX5nP00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00So
o0?l00?o0000ondBkOo]4^d01Oo]4^d00ol0003ogB;MomdRg@04omdRg@03o`000?nLHicoW6>L00Oo
W6>L00?o0000oj5NXOnQGZ403?nQGZ401?l0003oN8MhogR7N?l0000;oe^TF`03o`000?mJYE[oFZEJ
00_oFZEJ00Co0000obSG:?lXebSo00002_m=/Td00ol0003oA[U6odJiAP0:odJiAP03o`000?l]dRgo
;M8]00;o;M8]00?o0000oejQG_mNXEh01_mNXEh00ol0003oYEZUojEJY@0AojEJY@?o00000omaSW40
0ol0003oUVVFoiIYUP04oiIYUP03o`000?nOGiooWenO00goWenO1?l0000;olPgb003o`000?oX5nSo
j1OX00Goj1OX00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo0?loo`3o008oo`3o003o`000?o]4^gokA;]00KokA;]00Co0000omdR
gOoM8]gogB;M1?l00008oiaSW003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogR7N?mhQgP00_mhQgP0
0ol0003oFjAKoe^TF`08oe^TF`03o`000?mJYE[oFZEJ00[oFZEJ00?o0000obSG:?lXebP00_lXebP0
0ol0003oCK9=odfbC@03odfbC@Go00002om6^DH00ol0003o;M8]obgB;@03obgB;@03o`000?mNXEko
GZ5N00OoGZ5N00?o0000ojEJYOnUFZD03_nUFZD2o`0000OoLHia00?o0000oiIYU_nFJIH00_nFJIH0
0ol0003oWenOoimOW`0=oimOW`03o`000?ngB;Oo]dRg00;o]dRg00?o0000olPgb?o8=lP02Oo8=lP0
0ol0003oj1OXonPGj003onPGj003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003okA;]ondBk@07ondB
k@?o00001?o8=lP00ol0003oW6>LoiaSW005oiaSW003o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ogR7
N?mhQgP00omhQgP00ol0003oFjAKoe^TF`09oe^TF`03o`000?mJYE[oFZEJ00SoFZEJ00?o0000obSG
:?lXebP01?lXebP5o`0000Co0?l000?o0000odJiA_m6^DH02Om6^DH00ol0003o;M8]obgB;@03obgB
;@03o`000?mNXEkoGZ5N00SoGZ5N00?o0000ojEJYOnUFZD02_nUFZD3o`0000[oLHia00Go0000oiIY
U_nFJIKoUVVFo`00000>oimOW`03o`000?ngB;Oo]dRg00Co]dRg0_l00009olPgb003o`000?oX5nSo
j1OX00;oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo0?loo`3o009oo`3o003o`000?o]4^gokA;]00OokA;]00?o0000olPg
b?o8=lP01Oo8=lP00ol0003oW6>LoiaSW003oiaSW003o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ogR7
N?mhQgP01?mhQgP00ol0003oFjAKoe^TF`09oe^TF`03o`000?mJYE[oFZEJ00OoFZEJ00?o0000obSG
:?lXebP01OlXebP00ol0003o0?l0o`3o0007o`3o0003o`000?m6^DKoA[U600OoA[U600?o0000obgB
;Ol]dRd01?l]dRd00ol0003oGZ5NoejQGP08oejQGP03o`000?nUFZGoYEZU00SoYEZU0_l0000>og6>
L@Co00003?nOGil2o`0000Wo]dRg00?o0000olPgb?o8=lP01oo8=lP01?l0003oj1OXonPGj?l0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?ol0ocoo0?l
00[oo0?l00?o0000ondBkOo]4^d01Oo]4^d00ol0003ob3O8olPgb007olPgb0;o00000onLHi`00ol0
003oXEjQoj5NX@09oj5NX@03o`000?mhQgSoN8Mh00KoN8Mh00?o0000oe^TFomKY5/02OmKY5/00ol0
003oFZEJoeZUFP05oeZUFP03o`000?lXebSo:=LX00Ko:=LX00?o0000o`3o0?l0o`002?l0o`000ol0
003oA[U6odJiAP06odJiAP03o`000?l]dRgo;M8]00Co;M8]00?o0000oejQG_mNXEh02OmNXEh4o`00
00?oYEZU0ol0000@og6>L@05o`000?nkA;_o^dBkok]4^ol000002_nOGil00ol0003o]dRgokM8]`0:
okM8]`Ko00000oo8=lP00ol0003oj1OXo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?ol0ocoo0?l00Woo0?l00?o0000ondBkOo]4^d01?o]4^d00ol0
003ob3O8olPgb00:olPgb004o`000?nLHicoW6>Lo`0000[oXEjQ00?o0000ogR7N?mhQgP01omhQgP0
0ol0003oFjAKoe^TF`09oe^TF`03o`000?mJYE[oFZEJ00CoFZEJ00?o0000obSG:?lXebP01olXebP0
0ol0003o0?l0o`3o0008o`3o00;o00001_m6^DH00ol0003o;M8]obgB;@05obgB;@03o`000?mNXEko
GZ5N00WoGZ5N00Co0000odbcC?m</dcoC;=<0ol0000Bog6>L@03o`000?nkA;_o^dBk00?o^dBk0_l0
0006oimOW`;o00003OngB;L00ol0003ok1?/on`Ck003on`Ck0Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo0?l00?o0000ondBkOo]4^d00oo]4^d0
0ol0003ob3O8olPgb00<olPgb0;o00002_nQGZ400ol0003oN8MhogR7N008ogR7N003o`000?mKY5_o
FjAK00[oFjAK00?o0000oeZUF_mJYEX00_mJYEX00ol0003o:=LXobSG:008obSG:003o`000?l0o`3o
0?l000Ko0?l00_l00002obGJ9@03o`000?m6^DKoA[U600;oA[U600?o0000obgB;Ol]dRd01_l]dRd0
0ol0003oGZ5NoejQGP08oejQGP03o`000?m</dcoC;=<00CoC;=<00?o0000og6>LOmaSW403omaSW40
0ol0003o^dBkok]4^`06ok]4^`;o00000onOGil00ol0003o]dRgokM8]`0=okM8]`03o`000?o/4nco
k1?/00Ook1?/0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001ool0o`00ol0003okA;]ondBk@02ondBk@03o`000?o8=lSob3O8
00kob3O800?o0000oj5NXOnQGZ401onQGZ400ol0003oN8MhogR7N00:ogR7N003o`000?mKY5_oFjAK
00WoFjAK00Go0000oeZUF_mJYE[oFZEJo`00000;obSG:003o`000?l0o`3o0?l000Co0?l00_l00005
obGJ9@05o`000?m6^DKoA[U6odJiA_l000002?l]dRd00ol0003oGZ5NoejQGP08oejQGP03o`000?m<
/dcoC;=<00GoC;=<00?o0000og6>LOmaSW403_maSW400ol0003o^dBkok]4^`08ok]4^`03o`000?nO
Gioo000000oo]dRg00?o0000on`Ck?o/4n`02?o/4n`01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005oo`3o004o`000?o]4^gokA;]o`00017ob3O800?o0000oj5NXOnQGZ401_nQGZ400ol0003oN8Mh
ogR7N00;ogR7N003o`000?mKY5_oFjAK00WoFjAK00Co0000oeZUF_mJYE[o00003?lXebP00ol0003o
0?l0o`3o0002o`3o00;o00002?lUfRD00ol0003oA[U6o`000009obgB;@03o`000?mNXEkoGZ5N00So
GZ5N00?o0000odbcC?m</d`01Om</d`00ol0003oLHiaog6>L@0=og6>L@03o`000?nkA;_o^dBk00[o
^dBk00?o0000okM8]ongB;L03_ngB;L00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo0?lo`000?l000000ol0000BolPgb003o`00
0?nQGZ7oXEjQ00CoXEjQ00?o0000ogR7N?mhQgP03?mhQgP00ol0003oFjAKoe^TF`0:oe^TF`?o0000
3?lXebP00ol0003o0?l0o`3o0002o`0000_o9MXU00?o0000obgB;Ol]dRd02?l]dRd00ol0003oGZ5N
oejQGP07oejQGP03o`000?m</dcoC;=<00OoC;=<00?o0000og6>LOmaSW403?maSW400ol0003o^dBk
ok]4^`0;ok]4^`;o00003_ngB;L00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh00oo^4Nh00ol0003ob3O8olPgb00?olPgb0?o00000onQ
GZ400ol0003oN8MhogR7N00>ogR7N003o`000?mKY5_oFjAK00SoFjAK00Co0000oc7><OlacS7o<Lha
0_l0000:obSG:0?o00003OlUfRD00ol0003o;M8]obgB;@08obgB;@03o`000?mNXEkoGZ5N00OoGZ5N
00?o0000odbcC?m</d`01om</d`00ol0003oLHiaog6>L@0;og6>L@03o`000?nkA;_o^dBk00co^dBk
00?o0000omTVfOl000000_l0000:okM8]`03o`000?o/4ncok1?/00Sok1?/00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003okQ7^onhAkP04onhAkP03o`000?o8=lSob3O800cob3O80_l0
0003ojiA[P03o`000?nQGZ7o0000017oN8Mh00?o0000oe^TFomKY5/01omKY5/00ol0003o<Lhaoc7>
<@04oc7><@;o00002?lXebP00ol0003o9MXUobGJ9@0>obGJ9@;o00002?l]dRd00ol0003oGZ5NoejQ
GP06oejQGP03o`000?m</dcoC;=<00WoC;=<00?o0000og6>LOmaSW402OmaSW400ol0003o^dBkok]4
^`0=ok]4^`03o`000?oI9]WofBKI00;ofBKI0ol00007okM8]`03o`000?o/4ncok1?/00Ook1?/00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okQ7^onhAkP05onhAkP03o`000?o8=lSo
b3O800Wob3O80_l00006ojiA[P03o`000?mhQgSoN8Mh013oN8Mh00?o0000oe^TFomKY5/01_mKY5/0
0ol0003o<Lhaoc7><@07oc7><@03o`000?lXebSo:=LX00Co:=LX0ol0000>obGJ9@03o`000?lAkQ7o
4NhA00?o00001Ol]dRd00ol0003oGZ5NoejQGP06oejQGP03o`000?m</dcoC;=<00[oC;=<00?o0000
og6>LOmaSW402?maSW400ol0003o^dBkok]4^`0=ok]4^`03o`000?oI9]WofBKI00GofBKI0ol00004
okM8]`03o`000?o/4ncok1?/00Ook1?/00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003okQ7^onhAkP06onhAkP03o`000?o8=lSob3O800Gob3O80ol00008ojiA[P03o`000?mhQgSoN8Mh
017oN8Mh00Co0000oe^TFomKY5_oFjAK1?l0000;oc7><@;o000000Co:=LXo`000?l0003o00000oln
`Ch2o`0000_o9MXU00?o0000oa7^4OlAkQ401?lAkQ42o`0000?o;M8]00?o0000oejQG_mNXEh01_mN
XEh00ol0003oC;=<odbcC00:odbcC003o`000?maSW7oLHia00OoLHia00?o0000ok]4^onkA;/03_nk
A;/00ol0003ofBKIomTVf@08omTVf@Co00002_o/4n`00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003okQ7^onhAkP07onhAkP03o`000?o8=lSob3O800;ob3O80_l0000<ojiA[P03o`000?mhQgSo
N8Mh013oN8Mh1?l00003odfbC@03o`000?lacS7o<Lha00_o<Lha00?o0000ock1?_ln`Ch01_ln`Ch0
0ol0003o9MXUobGJ9@07obGJ9@03o`000?lAkQ7o4NhA00Oo4NhA3?l0000>odbcC003o`000?maSW7o
LHia00KoLHia00?o0000ok]4^onkA;/03_nkA;/00ol0003ofBKIomTVf@0;omTVf@03o`000?o/4nco
k1?/00Ook1?/00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o^4NkokQ7^00WokQ7^00Co0000olPg
b?l0003o00003_n^DJh00ol0003oN8MhogR7N00?ogR7N003o`000?m=/TgoCK9=00KoCK9=00?o0000
oc7><OlacS402_lacS400ol0003o?/4nock1?P07ock1?P;o00001_lUfRD00ol0003o4NhAoa7^4@08
oa7^4@03o`000?mVVFKoIYUV00SoIYUV00?o0000odbcC?m</d`03?m</d`00ol0003oLHiaog6>L@05
og6>L@03o`000?nkA;_o^dBk00oo^dBk0_l0000=omTVf@03o`000?o/4ncok1?/00Kok1?/00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o^4NkokQ7^00[okQ7^00?o0000ojiA[_n^DJh03_n^DJh00ol0
003oN8MhogR7N00>ogR7N003o`000?m=/TgoCK9=00OoCK9=00?o0000oc7><OlacS402_lacS400ol0
003o?/4nock1?P09ock1?P;o00000olUfRD00ol0003o4NhAoa7^4@09oa7^4@03o`000?mVVFKoIYUV
00WoIYUV00?o0000odbcC?m</d`02_m</d`4o`0000CoLHia00?o0000ok]4^onkA;/04?nkA;/01?l0
003oeB[Eo`000?l0000<omTVf@03o`000?o/4ncok1?/00Gok1?/00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o^4NkokQ7^00[okQ7^00?o0000ojiA[_n^DJh03on^DJh@o`0000[oCK9=00?o0000oc7>
<OlacS402OlacS400ol0003o6NHIo`00000<ock1?P05o`000?lUfRGo0000oa;]4_l000002_lAkQ40
0ol0003oIYUVofJIIP09ofJIIP03o`000?m</dcoC;=<00OoC;=<0ol00004ogV6N@?o000000?oLHia
o`000?nkA;/04OnkA;/01?l0003oeB[EomDZeOoE:]D2o`0000_ofBKI00?o0000on`Ck?o/4n`00oo/
4n`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh02_o^4Nh00ol0003o[U6^ojiA[P0?
ojiA[P03o`000?moP7ooOh1o00coOh1o00?o0000odfbCOm=/Td02Om=/Td00ol0003o<Lhaoc7><@07
oc7><@04o`000?lIiQWo6NHIo`0000go?/4n00Go0000oa;]4_lBkA;o4^dBo`000009oa7^4@03o`00
0?mVVFKoIYUV00[oIYUV00?o0000odbcC?m</d`00om</d`3o`0000[oNHIi00?o0000ok]4^onkA;/0
4?nkA;/00ol0003oeB[EomDZe@04omDZe@;o00002_oI9]T00ol0003ok1?/on`Ck004o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000cokQ7^00?o0000ojiA[_n^DJh03on^DJh00ol0003oOh1oogn0O`0<ogn0O`03o`000?m=
/TgoCK9=00WoCK9=00?o0000oc7><OlacS401_lacS400ol0003o6NHIoaWV6@02oaWV6@03o`000?ln
`Cko?/4n00[o?/4n00?o0000oa;]4_lBkA800_lBkA800ol0003o4NhAoa7^4@06oa7^4@03o`000?mV
VFKoIYUV00[oIYUV00?o0000odbcC?m</d`00ol0000=ogV6N@03o`000?nkA;_o^dBk013o^dBk00?o
0000omDZeOoE:]D01_oE:]D2o`0000WofBKI0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo0?l00?o0000onhAk_o^4Nh02_o^4Nh00ol0003o[U6^ojiA[P0=ojiA[P?o00003omoP7l0
0ol0003oCK9=odfbC@08odfbC@03o`000?lacS7o<Lha00Go<Lha00?o0000oaWV6OlIiQT00olIiQT0
0ol0003o?/4nock1?P0:ock1?P03o`000?lBkA;o4^dB00?o4^dB00?o0000oa7^4OlAkQ401OlAkQ40
0ol0003oIYUVofJIIP0;ofJIIP;o00004OmiQWT00ol0003o^dBkok]4^`0?ok]4^`03o`000?oE:]Go
eB[E00SoeB[E0_l00007omTVf@03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo0?l00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o[U6^ojiA[P09ojiA[PGo00000_mkQ7/00ol0
003oOh1oogn0O`0=ogn0O`03o`000?m=/TgoCK9=00WoCK9=00?o0000oc7><OlacS401?lacS400ol0
003o6NHIoaWV6@04oaWV6@03o`000?ln`Cko?/4n00So?/4n00?o0000oa;]4_lBkA801OlBkA800ol0
003o4NhAoa7^4@04oa7^4@03o`000?mVVFKoIYUV00_oIYUV00?o0000ogV6NOmiQWT04?miQWT00ol0
003o^dBkok]4^`0?ok]4^`03o`000?oE:]GoeB[E00[oeB[E0_l00004omTVf@03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?ol0o`00ol0003okQ7^onhAkP07onhAkP03o`000?n^DJko[U6^00Co[U6^1Ol00007og^4N`03
o`000?moP7ooOh1o00goOh1o00?o0000odfbCOm=/Td02Om=/Td00ol0003o<Lhaoc7><@03oc7><@03
o`000?lIiQWo6NHI00Go6NHI00?o0000ock1?_ln`Ch02?ln`Ch00ol0003o4^dBoa;]4P06oa;]4P03
o`000?lAkQ7o4NhA00?o4NhA00?o0000ofJII_mVVFH02omVVFH00ol0003oNHIiogV6N@0@ogV6N@03
o`000?nkA;_o^dBk00oo^dBk00?o0000omDZeOoE:]D03?oE:]D2o`000003omTVfOl0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^00OokQ7^00?o0000ojiA[_l00000
1?l0000<og^4N`03o`000?moP7ooOh1o00koOh1o00?o0000odfbCOm=/Td02?m=/Td00ol0003o<Lha
oc7><@02oc7><@03o`000?lIiQWo6NHI00Oo6NHI00?o0000ock1?_ln`Ch01oln`Ch00ol0003o4^dB
oa;]4P07oa;]4P03o`000?lAkQ7o4NhA00;o4NhA00?o0000ofJII_mVVFH02omVVFH00ol0003oNHIi
ogV6N@0AogV6N@03o`000?nkA;_o^dBk00go^dBk00?o0000omDZeOoE:]D03ooE:]D00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh01Oo^4Nh3o`00017oNhAk00?o0000ogn0OomoP7l03_mo
P7l00ol0003oCK9=odfbC@09odfbC@04o`000?lacS7o<Lhao`0000[o6NHI00?o0000ock1?_ln`Ch0
1oln`Ch00ol0003o4^dBoa;]4P08oa;]4P05o`000?lAkQ7o4NhAoa7^4Ol000003OmVVFH00ol0003o
NHIiogV6N@0AogV6N@?o00003OnkA;/00ol0003oeB[EomDZe@0?omDZe@03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o0?loo`3o00=oo`3o0?o00000_o^4Nh2o`0000;ob3O800?o0000og^4NomkQ7/03omkQ7/00ol0003o
Oh1oogn0O`0>ogn0O`03o`000?m=/TgoCK9=00SoCK9=1Ol0000;oaWV6@03o`000?ln`Cko?/4n00Ko
?/4n00?o0000oa;]4_lBkA802OlBkA801?l0003o4NhAoa7^4Ol0000=ofJIIP03o`000?miQWWoNHIi
017oNHIi00?o0000oefRGOmMXUd00ol0000:ok]4^`Co00003OoE:]D00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00co
o0?l00Co0000ondBkOo]4^gokA;]0_l00005olPgb003o`000?mkQ7_oNhAk00koNhAk00?o0000ogn0
OomoP7l03_moP7l00ol0003oCK9=odfbC@07odfbC@03o`000?m6^DKoA[U600?oA[U600?o0000oaWV
6OlIiQT02?lIiQT00ol0003o?/4nock1?P05ock1?P03o`000?lBkA;o4^dB00[o4^dB1Ol0000<ofJI
IP03o`000?miQWWoNHIi013oNHIi00?o0000oefRGOmMXUd01?mMXUd3o`0000Ko^dBk00?o0000omDZ
eOoE:]D00_oE:]D5o`0000SoeB[E00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00?o
kA;]00?o0000olPgb?o8=lP01?o8=lP00ol0003oNhAkog^4N`0=og^4N`03o`000?moP7ooOh1o00oo
Oh1o00?o0000odfbCOm=/Td01?m=/Td2o`0000OoA[U600?o0000oaWV6OlIiQT01olIiQTEo`0000Go
7mlO00?o0000ofJII_mVVFH02?mVVFH3o`00013oNHIi00?o0000oefRGOmMXUd02?mMXUd3o`0000;o
^dBk00?o0000omDZeOoE:]D02?oE:]D5o`0000?oeB[E00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo0?loo`3o00:oo`3o003o`00
0?o]4^gokA;]00CokA;]00?o0000olPgb?o8=lP01Oo8=lP00ol0003oNhAkog^4N`0;og^4N`Co0000
3omoP7l00ol0003oCK9=odfbC@03odfbC@03o`000?m6^DKoA[U600SoA[U600?o0000oaWV6OlIiQT0
1?lIiQT2o`0000SoAKY500?o0000oc?<<olcc3<02?lcc3<00ol0003o7mlOoaoO7`05oaoO7`;o0000
1_mVVFH2o`0000?oF:MH00?o0000ogV6NOmiQWT03?miQWT00ol0003oGJ9MoefRG@0<oefRG@;o0000
4?oE:]D3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02Ool0o`00ol0003okA;]ondBk@05ondBk@03o`000?o8=lSob3O800Kob3O800?o
0000og^4NomkQ7/02OmkQ7/00ol0003oN8Mho`000002oebSG0?o00003?moP7l01?l0003oCK9=odfb
COm=/Td2o`0000coA[U600?o0000oaWV6OlIiQT00_lIiQT00ol0003oAKY5odFjA@08odFjA@03o`00
0?lcc3?o<l`c00So<l`c00?o0000oaoO7olOgal01olOgal00ol0003oIYUVofJIIP02ofJIIP03o`00
0?mHYeSoF:MH00CoF:MH0_l0000;ogV6N@03o`000?mMXUgoGJ9M00coGJ9M00?o0000oiA[U?l00000
4_oE:]D00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003okA;]ondBk@06ondBk@03o`000?o8=lSob3O800Oob3O800?o
0000og^4NomkQ7/01_mkQ7/2o`0000;oN8Mh00?o0000oebSG?mLXe`00omLXe`3o`0000[oOh1o00?o
0000odfbCOl000003om6^DH01?l0003o6NHIo`000?l0000;odFjA@03o`000?lcc3?o<l`c00So<l`c
00?o0000oaoO7olOgal02?lOgal01?l0003oIYUVo`000?l00009oeRWF003o`000?miQWWoNHIi00Oo
NHIi00?o0000oefRGOmMXUd03?mMXUd01?l0003oU6^DoiA[U?l0000ComDZe@03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o0?l00?o0000ondBkOo]4^d01oo]4^d00ol0003ob3O8olPgb008olPgb003o`000?mkQ7_oNhAk00Co
NhAk00?o0000ogR7N?mhQgP00omhQgP00ol0003oG:=LoebSG005oebSG0?o00001_moP7l4o`00013o
A[U600?o0000odFjAOm5^TD03?m5^TD00ol0003o<l`coc?<<`07oc?<<`03o`000?lOgaoo7mlO00Wo
7mlO00?o0000oeRWF?mHYeP02_mHYeP2o`0000KoNHIi00?o0000oefRGOmMXUd03?mMXUd00ol0003o
U6^DoiA[U002oiA[U003o`000?oE:]GoeB[E00ooeB[E00?o0000onXEj_l000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003okA;]ondBk@08ondBk@03o`000?o8=lSob3O800Wob3O800Co0000og^4NomkQ7_o
NhAk0_l00006ogR7N003o`000?mLXecoG:=L00SoG:=L0ol000000omoP7oo0000o`000004oeFZE@03
o`000?m6^DKoA[U600goA[U600?o0000odFjAOm5^TD03?m5^TD00ol0003o<l`coc?<<`07oc?<<`03
o`000?lOgaoo7mlO00Wo7mlO00?o0000oeRWF?mHYeP03?mHYeP00ol0003oNHIiogV6N@03o`0000ko
GJ9M00?o0000oiA[U?nDJi@00onDJi@00ol0003oeB[EomDZe@0>omDZe@05o`000?oZ5N[ojQGZonXE
j_l000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000oo`3o?ol0o`00_ol0o`00ol0003okA;]ondBk@09ondBk@03o`000?o8=lSob3O800[o
b3O800?o0000og^4Nol000002?mhQgP00ol0003oG:=LoebSG00;oebSG003o`000?mEZUGoEJYE00Go
EJYE00?o0000odJiA_m6^DH03?m6^DH00ol0003oAKY5odFjA@0<odFjA@03o`000?lcc3?o<l`c00Oo
<l`c00?o0000oaoO7olOgal02?lOgal2o`0000ooF:MH0_l00002ofbCK003o`000?mMXUgoGJ9M00_o
GJ9M00?o0000oiA[U?nDJi@01?nDJi@00ol0003oeB[EomDZe@0=omDZe@03o`000?oZ5N[ojQGZ00?o
jQGZ00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ondBk@03o`000?o8=lSob3O800_ob3O800?o0000ogR7N?mhQgP0
1omhQgP00ol0003oG:=LoebSG00;oebSG003o`000?mEZUGoEJYE00KoEJYE00?o0000odJiA_m6^DH0
2om6^DH2o`0000goAKY500?o0000oc?<<olcc3<01olcc3<00ol0003o7mlOoaoO7`07oaoO7`04o`00
0?l/dbco;=</o`0000koF:MH00?o0000ofbCK?m/Tf`00_m/Tf`00ol0003oGJ9MoefRG@09oefRG@03
o`000?nDJiCoU6^D00KoU6^D00?o0000omDZeOoE:]D02ooE:]D00ol0003ojQGZonXEjP05onXEjP04
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000SokA;]00?o0000olPgb?o8=lP02_o8=lP2o`0000Wo
N8Mh00?o0000oebSG?mLXe`02omLXe`00ol0003oEJYEoeFZE@07oeFZE@03o`000?m6^DKoA[U600Wo
A[U600Co0000oa3_4?l@ka3o00003?m5^TD00ol0003o<l`coc?<<`07oc?<<`03o`000?lOgaoo7mlO
00Ko7mlO00Go0000obcC;?l/dbco;=</o`00000>oeRWF003o`000?m/TfcoK9=/00?oK9=/00?o0000
oefRGOmMXUd01omMXUd00ol0003oU6^DoiA[U007oiA[U003o`000?oE:]GoeB[E00[oeB[E00?o0000
onXEj_oZ5NX01ooZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006ondBk@03o`000?o8=lSob3O8
00Wob3O800Co0000ok1?/?n`Ck3o00002OmhQgP00ol0003oG:=LoebSG009oebSG003o`000?mEZUGo
EJYE00WoEJYE00?o0000odJiA_m6^DH01om6^DH00ol0003o4>l@oa3_4002oa3_4003o`000?m5^TGo
AKY500WoAKY500?o0000oc?<<olcc3<01olcc3<00ol0003o7mlOoaoO7`05oaoO7`03o`000?l/dbco
;=</00?o;=</00?o0000oeRWF?mHYeP02_mHYeP00ol0003oK9=/ofbCK005ofbCK003o`000?mMXUgo
GJ9M00GoGJ9M00?o0000oiA[U?nDJi@02?nDJi@00ol0003oeB[EomDZe@09omDZe@03o`000?oZ5N[o
jQGZ00SojQGZ00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_o]4^d3o`0000Wob3O800?o0000ok1?
/?n`Ck000_n`Ck000ol0003oN8MhogR7N006ogR7N003o`000?mLXecoG:=L00WoG:=L00?o0000oeFZ
EOmEZUD02_mEZUD00ol0003oA[U6odJiAP05odJiAP03o`000?l@ka3o4>l@00Co4>l@00?o0000odFj
AOm5^TD02?m5^TD00ol0003o<l`coc?<<`07oc?<<`03o`000?lOgaoo7mlO00Co7mlO00?o0000obcC
;?l/db`01?l/db`00ol0003oF:MHoeRWF00:oeRWF003o`000?m/TfcoK9=/00KoK9=/00?o0000oefR
GOmMXUd00omMXUd00ol0003oU6^DoiA[U009oiA[U003o`000?oE:]GoeB[E00SoeB[E00?o0000onXE
j_oZ5NX02OoZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003onDJi@?o00001Oo8=lP00ol0003o
/4n`ok1?/003ok1?/003o`000?mhQgSoN8Mh00KoN8Mh00?o0000oebSG?mLXe`02OmLXe`00ol0003o
EJYEoeFZE@0;oeFZE@03o`000?m6^DKoA[U600?oA[U600?o0000oa3_4?l@ka001_l@ka000ol0003o
AKY5odFjA@08odFjA@03o`000?lcc3?o<l`c00Ko<l`c00?o0000oaoO7olOgal00_lOgal2o`0000So
;=</00?o0000oeRWF?mHYeP02OmHYeP00ol0003oK9=/ofbCK007ofbCK005o`000?mMXUgoGJ9MoefR
GOl000003OnDJi@00ol0003oeB[EomDZe@06omDZe@03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oU6^GoiA[U00GoiA[U0ol000000oo8=lSo0000ok1?/006ok1?/003
o`000?mhQgSoN8Mh00GoN8Mh00?o0000oebSG?mLXe`02OmLXe`00ol0003oEJYEoeFZE@0<oeFZE@05
o`000?m6^DKoA[U6odJiA_l000002_l@ka000ol0003oAKY5odFjA@07odFjA@03o`000?lcc3?o<l`c
00Ko<l`c00?o0000oaoO7ol000000_l000000omQWV7o0000obcC;007obcC;003o`000?mHYeSoF:MH
00SoF:MH00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003oGJ9Mo`00000=oiA[U0Co00001OoE:]D00ol0
003ojQGZonXEjP0;onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiA[UonDJi@08onDJi@03
o`000?n`Ck3o/4n`00Oo/4n`00?o0000ogR7N?mhQgP01?mhQgP00ol0003oG:=LoebSG009oebSG003
o`000?mEZUGoEJYE00goEJYE00?o0000odJiA_l000003?l@ka0:o`0000Oo<l`c0ol00005of6NH@03
o`000?l/dbco;=</00Ko;=</00?o0000oeRWF?mHYeP01omHYeP00ol0003oK9=/ofbCK00:ofbCK003
o`000?nDJiCoU6^D00_oU6^D00?o0000ol/dboo;=</00_o;=</3o`000003omDZeOl0003ojQGZ00_o
jQGZ0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000onDJiOoU6^D02OoU6^D00ol0003o/4n`ok1?/007ok1?/003o`00
0?mhQgSoN8Mh00GoN8Mh00?o0000oebSG?mLXe`01omLXe`00ol0003oEJYEoeFZE@0?oeFZE@;o0000
2ol@ka000ol0003oDjaCoe>/D`07oe>/D`03o`000?lcc3?o<l`c00;o<l`c0ol00008of6NH@03o`00
0?l/dbco;=</00Ko;=</00?o0000oeRWF?mHYeP01omHYeP00ol0003oK9=/ofbCK00:ofbCK003o`00
0?nDJiCoU6^D00[oU6^D00?o0000ol/dboo;=</01_o;=</00ol0003ojQGZonXEjP08onXEjP?o0000
0_o_4>l00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onDJiOoU6^D02OoU6^D00ol0003o/4n`ok1?
/008ok1?/003o`000?mhQgSoN8Mh00CoN8Mh00?o0000oebSG?mLXe`01omLXe`00ol0003oEJYEoeFZ
E@0>oeFZE@04o`000?lSg2?o8m`So`0000Wo4>l@00?o0000oe>/DomC[5<02OmC[5<01?l0003o<l`c
o`000?l0000<of6NH@03o`000?l/dbco;=</00Ko;=</00?o0000oeRWF?mHYeP01_mHYeP00ol0003o
K9=/ofbCK00;ofbCK003o`000?nDJiCoU6^D00OoU6^D0_l00009ol/db`03o`000?oZ5N[ojQGZ00Co
jQGZ1?l00006onl@k`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oiA[UonDJi@09onDJi@03o`00
0?n`Ck3o/4n`00So/4n`00?o0000ogR7N?mhQgP00omhQgP>o`0000goEJYE00?o0000ob?L8olSg2<0
0_lSg2<00ol0003o4>l@oa3_4005oa3_4003o`000?mC[5?oDjaC00_oDjaC00?o0000of6NHOmQWV40
3?mQWV400ol0003o;=</obcC;006obcC;003o`000?mHYeSoF:MH00GoF:MH00?o0000ofbCK?m/Tf`0
3?m/Tf`00ol0003oU6^DoiA[U006oiA[U003o`000?o;=<_obcC;00[obcC;00?o0000onXEj_oZ5NX0
0ol0000:onl@k`?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000ok1?/?n`Ck002?n`
Ck001Ol0003oN8MhogR7N?mhQgSo000000_oGZ5N00?o0000o`_d2ol;m0/00ol00009oeFZE@03o`00
0?lSg2?o8m`S00Co8m`S00?o0000oa3_4?l@ka000ol@ka000ol0003oDjaCoe>/D`0<oe>/D`03o`00
0?mQWV7oHIiQ00goHIiQ00?o0000obcC;?l/db`01_l/db`00ol0003oF:MHoeRWF003oeRWF0?o0000
3Om/Tf`00ol0003oU6^DoiA[U005oiA[U003o`000?o;=<_obcC;00cobcC;0_l0000=onl@k`03o`00
0?om0_goo@;m00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oU6^GoiA[U00_oiA[U00?o0000ok1?/?n`Ck002?n`
Ck04o`0000coGZ5N00?o0000o`_d2ol;m0/00ol;m0/3o`0000GoEJYE00?o0000ob?L8olSg2<01_lS
g2<01Ol0003o4>l@oa3_4?l@ka3o000000ooDjaC00?o0000of6NHOmQWV403OmQWV400ol0003o;=</
obcC;006obcC;003o`000?mHYeSoF:MH00?o00000olfbCH00ol0003oK9=/ofbCK00;ofbCK003o`00
0?nDJiCoU6^D00?oU6^D00?o0000ol/dboo;=</03Oo;=</00ol0003oka3_onl@k`0;onl@k`03o`00
0?om0_goo@;m00Coo@;m0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000onDJiOoU6^D02_oU6^D3o`0000Ko/4n`0ol0
0003oi]TV`03o`000?mNXEkoGZ5N00[oGZ5N00?o0000o`_d2ol;m0/01_l;m0/3o`000003oeFZEOl0
003o8m`S00Wo8m`S00?o0000oa3_4?l000004?mC[5<00ol0003oHIiQof6NH@0=of6NH@03o`000?l/
dbco;=</00Oo;=</0_l00007ocK9=P03o`000?m/TfcoK9=/00[oK9=/00Co0000oiA[U?nDJiCoU6^D
0ol0000?ol/db`03o`000?o_4>ooka3_00_oka3_00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000onDJiOoU6^D02_oU
6^D01?l0003oeB[EomDZeOoE:]D2o`000004ok1?/?l0003o0000o`0000KoVfBK00?o0000oejQG_mN
XEh02_mNXEh00ol0003o2o@;o`_d2`09o`_d2`03o`000?lSg2?o8m`S00[o8m`S00?o0000oe>/DomC
[5<03omC[5<00ol0003oHIiQof6NH@0>of6NH@03o`000?l/dbco;=</00Ko;=</00?o0000ocK9=_lf
bCH01olfbCH4o`0000SoK9=/00Co0000oiA[U?nDJiCo00000onCK9<2o`0000gobcC;00?o0000onl@
koo_4>l02_o_4>l00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onDJiOoU6^D02OoU6^D00ol0003o
eB[EomDZe@04omDZe@03o`000?nKI9_oVfBK00OoVfBK00?o0000oejQG_mNXEh02OmNXEh00ol0003o
2o@;o`_d2`0:o`_d2`03o`000?lSg2?o8m`S00[o8m`S00?o0000oe>/DomC[5<03omC[5<00ol0003o
HIiQof6NH@0>of6NH@03o`000?l/dbco;=</00Go;=</00?o0000ocK9=_lfbCH02?lfbCH01?l0003o
FZEJoeZUF_mJYEX7o`0000;oK9=/0_l00006oi=/T`;o00003?o;=</00ol0003oka3_onl@k`09onl@
k`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003oiA[UonDJi@08onDJi@03o`000?oE:]GoeB[E00Go
eB[E00?o0000oi]TVonKI9/02?nKI9/00ol0003oGZ5NoejQGP08oejQGP03o`000?l;m0_o2o@;00[o
2o@;00?o0000ob?L8olSg2<02olSg2<00ol0003oDjaCoe>/D`0>oe>/D`03o`000?mQWV7oHIiQ00ko
HIiQ1Ol00002obcC;003o`000?lfbCKo=/Tf00Wo=/Tf00?o0000oeZUF_mJYEX02?mJYEX3o`0000Wo
TfbC0_l0000:ol/db`03o`000?o_4>ooka3_00Soka3_00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oU6^GoiA[U00SoiA[U00?o0000omDZeOoE:]D01ooE:]D00ol0003oVfBKoi]TV`07oi]TV`03o`00
0?mNXEkoGZ5N00SoGZ5N00?o0000o`_d2ol;m0/02_l;m0/00ol0003o8m`Sob?L8`0:ob?L8`;o0000
3_mC[5<3o`0000goHIiQ0ol00005ofNHI`;o00002olfbCH00ol0003oFZEJoeZUFP0;oeZUFP;o0000
2_nCK9<2o`0000OobcC;0ol00009onl@k`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:omDZe@03o`00
0?nKI9_oVfBK00OoVfBK00?o0000oejQG_mNXEh02?mNXEh>o`0000Wo8m`S0ol000000ol7n0Oo0000
oe>/D`0:oe>/D`?o00000_m[U6/00ol0003oHIiQof6NH@09of6NH@;o00002OmWV6L00ol0003o=/Tf
ocK9=P09ocK9=P03o`000?mJYE[oFZEJ00_oFZEJ00?o0000ogZ5N_l000002onCK9<2o`0000CobcC;
00Co0000on@Ki?oT6nCoi1_T0_l00007onl@k`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003oeB[E
omDZe@09omDZe@03o`000?nKI9_oVfBK00KoVfBK00?o0000oejQG_mNXEh02?mNXEh00ol0003o6>LH
oaSW600:oaSW6003o`000?lSg2?o8m`S00Co8m`S0ol00005o`Oh1`03o`000?mC[5?oDjaC00CoDjaC
1?l00006of^DJ`03o`000?mQWV7oHIiQ00KoHIiQ0_l0000;ofNHI`03o`000?lfbCKo=/Tf00Wo=/Tf
00?o0000oeZUF_mJYEX02_mJYEX01Ol0003oNXEjogZ5N_mjQG[o000000coTfbC0_l000000oo;=<_o
0000on@Ki005on@Ki003o`000?o_4>ooka3_00?oka3_00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oE:]GoeB[E00SoeB[E00?o0000oi]TVonKI9/01_nKI9/00ol0003oGZ5NoejQGP07oejQGP03o`00
0?lHiaSo6>LH00_o6>LH00?o0000ob?L8olSg2<00_lSg2<2o`0000Wo1oP700?o0000oe>/DomC[5<0
0ol0000;of^DJ`03o`000?mQWV7oHIiQ00;oHIiQ0ol0000>ofNHI`03o`000?lfbCKo=/Tf00Oo=/Tf
00?o0000oeZUF_mJYEX02omJYEX00ol0003oNXEjogZ5NP02ogZ5NP03o`000?nCK9?oTfbC00_oTfbC
00?o0000on@Ki?oT6n@01_oT6n@2o`0000?oka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oE
:]GoeB[E00OoeB[E00?o0000oi]TVonKI9/01onKI9/00ol0003oGZ5NoejQGP05oejQGP?o00003OlH
iaP4o`0000_o1oP70ol0000?of^DJ`04o`000?mQWV7o0000o`00017oIiQW00?o0000ocK9=_lfbCH0
1olfbCH00ol0003oFZEJoeZUFP0:oeZUFP03o`000?mjQG[oNXEj00CoNXEj00?o0000oi=/TonCK9<0
1onCK9<3o`0000_oi1_T1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omDZeOoE:]D02?oE:]D00ol0003oVfBKoi]T
V`06oi]TV`03o`000?mNXEkoGZ5N00;oGZ5N0ol00003od6n@@03o`000?lHiaSo6>LH00[o6>LH00?o
0000o`Oh1ol7n0L02ol7n0L00ol0003o4NhAo`00000Aof^DJ`03o`000?mWV6OoIiQW017oIiQW00?o
0000ocK9=_lfbCH01olfbCH00ol0003oFZEJoeZUFP0:oeZUFP03o`000?mjQG[oNXEj00GoNXEj00Co
0000oi=/TonCK9?oTfbC1Ol00002ojEJY@03o`000?oT6nCoi1_T00Woi1_T00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000omDZeOoE:]D01ooE:]D00ol0003oVfBKoi]TV`05oi]TV`?o0000
00?oGZ5No`000?l000001om1_T400ol0003o6>LHoaSW6008oaSW60?o00002_l7n0L2o`0000;o4NhA
00?o0000of^DJom[U6/03om[U6/00ol0003oIiQWofNHI`0AofNHI`03o`000?lfbCKo=/Tf00Oo=/Tf
00?o0000oeZUF_mJYEX02OmJYEX00ol0003oNXEjogZ5NP07ogZ5NP?o00001onUFZD00ol0003oi1_T
on@Ki009on@Ki003o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000omDZeOoE:]D01ooE
:]D4o`0000;oVfBK0_l00003oiUVV@03o`000?m1_T7o@Ki100So@Ki10_l00006oaSW60;o00000olL
ha`00ol0003o1oP7o`Oh1`06o`Oh1`03o`000?lAkQ7o4NhA00?o4NhA00?o0000of^DJom[U6/03_m[
U6/00ol0003oIiQWofNHI`0BofNHI`03o`000?lfbCKo=/Tf00Go=/Tf00?o0000oeZUF_mJYEX02OmJ
YEX00ol0003oNXEjogZ5NP08ogZ5NP03o`000?nUFZGoYEZU00OoYEZU00?o0000on@Ki?oT6n@02?oT
6n@00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oE:]GoeB[E00CoeB[E0_l00004
om`Sg0;o00001OnIIYT00ol0003o@Ki1od6n@@0:od6n@@03o`000?lHiaSo6>LH00;o6>LH00?o0000
oacS7?lLha`01?lLha`00ol0003o1oP7o`Oh1`04o`Oh1`03o`000?lAkQ7o4NhA00Co4NhA00?o0000
of^DJom[U6/03_m[U6/00ol0003oIiQWofNHI`0BofNHI`[o00002_mJYEX00ol0003oNXEjogZ5NP08
ogZ5NP03o`000?nUFZGoYEZU00OoYEZU00?o0000on@Ki?oT6n@02?oT6n@00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003oeB[EomDZeOoE:]D2o`0000Oog2?L00?o0000oiUVVOnIIYT01?nIIYT0
0ol0003o@Ki1od6n@@0:od6n@@04o`000?lHiaSo0000o`0000So7><L00Co0000o`Oh1ol7n0Oo1oP7
0_l00007oa7^4@03o`000?m[U6_oJiA[00koJiA[00?o0000ofNHIomWV6L04_mWV6L00ol0003oBkA;
od^dB`07od^dB`03o`000?mJYE[oFZEJ00KoFZEJ00?o0000ogZ5N_mjQGX02_mjQGX00ol0003oYEZU
ojEJY@06ojEJY@03o`000?oT6nCoi1_T00Soi1_T00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oE
:]Go0000o`0000Wog2?L00?o0000oiUVVOnIIYT01?nIIYT00ol0003o@Ki1od6n@@0;od6n@@03o`00
0?lLhaco7><L00Wo7><L00?o0000o`Oh1ol000002OlAkQ400ol0003oJiA[of^DJ`0>of^DJ`;o0000
4_mWV6L00ol0003oBkA;od^dB`09od^dB`;o00001_mJYEX00ol0003oNXEjogZ5NP0:ogZ5NP03o`00
0?nUFZGoYEZU00KoYEZU00?o0000on@Ki?oT6n@02?oT6n@00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000om`Sg?oL8m`02OoL8m`00ol0003oVFJIoiUVV@05oiUVV@03o`000?m1_T7o@Ki100[o@Ki100?o
0000oacS7?lLha`02_lLha`2o`0000Wo4NhA00?o0000of^DJom[U6/03_m[U6/00ol0003oDJiAo`00
0002o`0000ooIiQW00?o0000od^dBom;]4/02om;]4/00ol0003oFZEJoeZUFP03o`0000goNXEj00?o
0000ojEJYOnUFZD01_nUFZD00ol0003oi1_Ton@Ki007on@Ki003o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003og2?Lom`Sg009om`Sg003o`000?nIIYWoVFJI00GoVFJI00?o0000od6n@Om1_T402Om1_T42
o`0000_o7><L0_l0000;oa7^4@03o`000?m[U6_oJiA[00coJiA[00?o0000oe6^DOmA[U400omA[U43
o`0000coIiQW00?o0000od^dBom;]4/03?m;]4/2o`0000;oIiQW00?o0000ogZ5N_mjQGX03?mjQGX0
0ol0003oYEZUojEJY@05ojEJY@03o`000?oT6nCoi1_T00Ooi1_T00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oL8mcog2?L00[og2?L00?o0000oiUVVOnIIYT01_nIIYT00ol0003o@Ki1od6n@@07od6n
@@03o`000?lgb3Oo000000[o7><L00Co0000o`cc3?l<l`co00002_lAkQ400ol0003oJiA[of^DJ`0<
of^DJ`03o`000?mA[U7oDJiA00KoDJiA0_l00008ofNHI`;o00003om;]4/00ol0003oIiQWofNHI`02
ofNHI`03o`000?mjQG[oNXEj00_oNXEj00?o0000ojEJYOnUFZD01OnUFZD00ol0003oi1_Ton@Ki007
on@Ki003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003og2?Lom`Sg00:om`Sg003o`000?nIIYWoVFJI
00KoVFJI00?o0000od6n@Om1_T401_m1_T401Ol0003o=lPgocO8=olgb3Oo000000So7><L00?o0000
o`cc3?l<l``00_l<l``00ol0003o4NhAoa7^4@06oa7^4@Co00003?m[U6/00ol0003oDJiAoe6^D@08
oe6^D@?o00000_mWV6L3o`000003odBkA?l0003oBkA;00goBkA;00?o0000ofNHIomWV6L01?mWV6L0
0ol0003oNXEjogZ5NP0:ogZ5NP03o`000?nUFZGoYEZU00GoYEZU00?o0000on@Ki?oT6n@01_oT6n@0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000om`Sg?oL8m`02ooL8m`00ol0003oVFJIoiUVV@07oiUV
V@03o`000?m1_T7o@Ki100?o@Ki10_l00005ocO8=`03o`000?lLhaco7><L00Co7><L00?o0000o`cc
3?l<l``00ol<l``00ol0003o4NhAoa7^4@05oa7^4@03o`000?l^dBko;]4^00;o;]4^0ol00007of^D
J`;o00003_mA[U42o`0000GoA;]400?o0000od^dBom;]4/02_m;]4/00ol0003oIiQWofNHI`05ofNH
I`03o`000?mjQG[oNXEj00_oNXEj00?o0000ojEJYOnUFZD01?nUFZD00ol0003oi1_Ton@Ki006on@K
i003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003og2?Lom`Sg00;om`Sg003o`000?nIIYWoVFJI00Oo
VFJI00?o0000od6n@Om1_T400_m1_T400ol0003o=lPgocO8=`06ocO8=`03o`000?lLhaco7><L00;o
7><L00?o0000o`cc3?l<l``01Ol<l``00ol0003o4NhAoa7^4@02oa7^4@;o00002?l^dBh3o`0000;o
JiA[0_l000000olhacSo0000oe6^D@0=oe6^D@03o`000?m4^dCoA;]400GoA;]400?o0000od^dBom;
]4/02?m;]4/00ol0003oIiQWofNHI`07ofNHI`03o`000?mjQG[oNXEj00[oNXEj00?o0000ojEJYOnU
FZD01?nUFZD00ol0003oi1_Ton@Ki006on@Ki003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003og2?L
om`Sg00<om`Sg003o`000?nIIYWoVFJI00SoVFJI00Co0000od6n@Om1_T7o00002Olgb3L01Ol0003o
7><LoacS7?lLhaco000000So3?<<00Go0000oa7^4OlAkQ7o4NhAo`00000=obkA;P;o00001?lhacP0
0ol0003oDJiAoe6^D@0;oe6^D@03o`000?m4^dCoA;]400KoA;]400?o0000od^dBom;]4/01om;]4/0
0ol0003oIiQWofNHI`08ofNHI`Co00002?mjQGX00ol0003oYEZUojEJY@04ojEJY@03o`000?oT6nCo
i1_T00Koi1_T00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oL8mcog2?L00_og2?L0ol00009oiUV
V@03o`000?m1_T7o000000_o=lPg00?o0000oacS7?l000002_l<l``00ol0003o4NhAo`00000?obkA
;P03o`000?lhacSo><Lh00;o><Lh00?o0000oe6^DOmA[U402omA[U400ol0003oA;]4odBkA006odBk
A003o`000?m;]4_oBkA;00KoBkA;00?o0000ofNHIomWV6L02OmWV6L01?l0003oUfRGoiMXUonGJ9L7
o`0000;oNXEj00?o0000ojEJYOnUFZD00onUFZD00ol0003oi1_Ton@Ki005on@Ki003o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oL8mcog2?L00Sog2?L0ol00003om0_d003o`000?nIIYWoVFJI00OoVFJI00?o0000ocO8
=olgb3L02olgb3L00ol0003o3?<<o`cc300:o`cc3003o`000?l^dBko;]4^00go;]4^00?o0000ocS7
>?lhacP01?lhacP00ol0003oDJiAoe6^D@09oe6^D@03o`000?m4^dCoA;]400SoA;]400?o0000od^d
Bom;]4/00om;]4/2o`0000coIiQW00?o0000oiMXUonGJ9L02?nGJ9L<o`0000?oi1_T0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000om`Sg?oL8m`01_oL8m`3o`0000Ood2o@00?o0000oiUVVOnIIYT01_nIIYT00ol0003o
=lPgocO8=`0;ocO8=`03o`000?l<l`co3?<<00Wo3?<<0_l0000>obkA;P03o`000?lhacSo><Lh00Go
><Lh00?o0000oe6^DOmA[U402OmA[U400ol0003oA;]4odBkA009odBkA003o`000?m;]4_o000000;o
00000_mNXEh00ol0003oIiQWofNHI`08ofNHI`03o`000?nGJ9OoUfRG00coUfRG00?o0000on4NhOoQ
7^401_oQ7^43o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003og2?Lom`Sg003om`Sg0?o00002oo@;m000ol0003oVFJI
oiUVV@04oiUVV@03o`000?lgb3Oo=lPg00_o=lPg0ol00007o`cc30?o000000?o9MXUo`000?l^dBh0
3Ol^dBh00ol0003o><LhocS7>006ocS7>003o`000?mA[U7oDJiA00SoDJiA00?o0000odBkA?m4^d@0
2_m4^d@00ol0003oGZ5NoejQGP04oejQGP03o`000?mWV6OoIiQW00OoIiQW00?o0000oiMXUonGJ9L0
2onGJ9L00ol0003ohAkQon4Nh@08on4Nh@03o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004om`Sg?l0
003o0000o`0000ood2o@00?o0000oiUVVOnIIYT00onIIYT>o`0000?o;]4^0_l00002o`cc30?o0000
1OlUfRD00ol0003o;]4^obkA;P0:obkA;P03o`000?lhacSo><Lh00Oo><Lh00?o0000oe6^DOmA[U40
2?mA[U400ol0003oA;]4odBkA00:odBkA003o`000?mNXEkoGZ5N00GoGZ5N00?o0000ofNHIomWV6L0
1_mWV6L00ol0003oUfRGoiMXU`0;oiMXU`03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;od2o@00?o0000oiUVVOnIIYT00_nIIYT00ol0003oIIYUofFJ
I@0:ofFJI@03o`000?l^dBko;]4^00?o;]4^0_l00009obGJ9@03o`000?l^dBko;]4^00Wo;]4^00?o
0000ocS7>?lhacP02?lhacP2o`0000SoDJiA00?o0000odBkA?m4^d@02Om4^d@00ol0003oGZ5NoejQ
GP07oejQGP03o`000?mWV6OoIiQW00CoIiQW00?o0000oiMXUonGJ9L02onGJ9L00ol0003ohAkQon4N
h@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003od2o@om0_d00?om0_d0?o000000?oVFJI
o`000?mUVVD02omUVVD00ol0003o;]4^obkA;P04obkA;P03o`000?lUfRGo9MXU00Wo9MXU00?o0000
obkA;_l^dBh01ol^dBh00ol0003o><LhocS7>009ocS7>004o`000?ldbcCo0000o`0000KoDJiA00?o
0000odBkA?m4^d@02Om4^d@00ol0003oGZ5NoejQGP08oejQGP03o`000?mWV6OoIiQW00?oIiQW00?o
0000oiMXUonGJ9L02onGJ9L00ol0003ohAkQon4Nh@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003od2o@om0_d00<om0_d0;o00000oo;=</2o`0000coIIYU00?o0000obkA;_l^dBh01?l^dBh0
0ol0003o9MXUobGJ9@0:obGJ9@Wo00002olhacP00ol0003o=</docC;=002ocC;=0?o00000_mA[U40
0ol0003oA;]4odBkA00:odBkA003o`000?mNXEkoGZ5N00WoGZ5N00?o0000ofNHIomWV6L00_mWV6L0
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_o@;m02o`0000GobcC;00?o0000oi9]T_l000002_mUVVD00ol0003o;]4^obkA;P06obkA
;P03o`000?lUfRGo9MXU00Wo9MXU00?o0000ob;M8_lRgB801OlRgB800ol0003o><LhocS7>009ocS7
>003o`000?ldbcCo=</d00Go=</d0ol00009odBkA0?o00003OmNXEh01Ol0003oIiQWofNHIomWV6Oo
000000coUfRG00?o0000on4NhOoQ7^402OoQ7^400ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om0_
d?o@;m001Oo@;m02o`0000OobcC;00Co0000oi9]T_nBKI;o00002OmUVVD00ol0003o;]4^obkA;P06
obkA;P03o`000?lUfRGo9MXU00So9MXU00?o0000ob;M8_lRgB801olRgB800ol0003o><LhocS7>007
ocS7>003o`000?ldbcCo=</d00So=</d0ol00002odBkA0Go00000_lcc3<00ol0003oGZ5NoejQGP0<
oejQGP03o`000?mWV6Oo000000coUfRG00?o0000on4NhOoQ7^402_oQ7^400ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000om0_d?o@;m000_o@;m02o`0000SobcC;00?o0000oi9]T_nBKI800_nBKI85o`00
00CoIIYU00?o0000obkA;_l^dBh01_l^dBh00ol0003o9MXUobGJ9@08obGJ9@03o`000?lRgB;o8]dR
00Oo8]dR00?o0000ocS7>?lhacP01olhacP00ol0003o=</docC;=008ocC;=003o`000?lMhQgo7N8M
00;o00002?lcc3<00ol0003oGZ5NoejQGP0<oejQGPCo00002_nGJ9L00ol0003ohAkQon4Nh@0:on4N
h@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003od2o@o`000?l0000:ol/db`03o`000?nBKI;oTVfB
00;oTVfB00?o0000ocS7>?lhacP00_lhacP4o`0000Wo;]4^00?o0000obGJ9OlUfRD02?lUfRD00ol0
003o8]dRob;M8P08ob;M8P03o`000?lhacSo><Lh00Go><Lh00?o0000ocC;=?ldbc@02?ldbc@01Ol0
003o7N8MoagR7OlMhQgo000000[o<l`c0ol0000;oejQGP04o`000?o;=<_obcC;ol/db`Co00001OnG
J9L00ol0003ohAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003obcC;ol/db`0:
ol/db`03o`000?nBKI;oTVfB00?oTVfB00?o0000ocS7>?lhacP01?lhacP00ol0003o;]4^obkA;P07
obkA;P03o`000?lUfRGo9MXU00Ko9MXU0_l0000;ob;M8P03o`000?lhacSo><Lh00Go><Lh00?o0000
ocC;=?ldbc@02?ldbc@00ol0003o7N8MoagR7@02oagR7@03o`000?lcc3?o<l`c00Oo<l`c00?o0000
oh9mP_n2OH801?l00006oejQGP03o`000?o;=<_obcC;00KobcC;0ol00002oiMXU`03o`000?oQ7^7o
hAkQ00_ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o;=<_obcC;00WobcC;00?o0000oi9]
T_nBKI801?nBKI800ol0003o><LhocS7>005ocS7>003o`000?l^dBko;]4^00Oo;]4^00?o0000obGJ
9OlUfRD00_lUfRD3o`000003oc;=<_l0003o8]dR00[o8]dR00?o0000ocS7>?lhacP01OlhacP00ol0
003o=</docC;=007ocC;=003o`000?lMhQgo7N8M00?o7N8M00?o0000oc?<<olcc3<01olcc3<00ol0
003oPWf2oh9mPP04oh9mPP?o00000_mNXEh00ol0003obcC;ol/db`0:ol/db`;o00003_oQ7^400ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000ol/dboo;=</02Oo;=</00ol0003oTVfBoi9]TP04oi9]TP03
o`000?lhacSo><Lh00Ko><Lh0_l00007obkA;P03o`000?lUfRGo000000;o00001OlbcC800ol0003o
8]dRob;M8P08ob;M8P?o00001?lhacP00ol0003o=</docC;=008ocC;=003o`000?lMhQgo7N8M00Co
7N8M00?o0000oc?<<olcc3<01_lcc3<00ol0003oPWf2oh9mPP07oh9mPP;o00003_o;=</00ol0003o
hAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003obcC;ol/db`08ol/db`03o`00
0?nBKI;oTVfB00GoTVfB00?o0000ocS7>?lhacP01?lhacP00ol0003oBKI9odVfB@03o`0000Co;]4^
0_l00008oc;=<P03o`000?lRgB;o8]dR00Oo8]dR00Co0000oeJYE_mFZEKoEZUF0ol000000olhacSo
0000ocC;=009ocC;=003o`000?lMhQgo7N8M00Co7N8M00?o0000oc?<<olcc3<01Olcc3<00ol0003o
PWf2oh9mPP09oh9mPP03o`000?o;=<_obcC;00gobcC;00?o0000on4NhOoQ7^402_oQ7^400ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000ol/dboo;=</01oo;=</00ol0003oTVfBoi9]TP06oi9]TP03o`00
0?lhacSo><Lh00?o><Lh00?o0000odVfBOm9]TT01?m9]TT2o`000003obkA;_l0003o</db00[o</db
00?o0000ob;M8_lRgB801OlRgB800ol0003oEZUFoeJYEP05oeJYEP03o`000?ldbcCo=</d00Oo=</d
0ol00007oagR7@03o`000?lcc3?o<l`c00Co<l`c00?o0000oh9mP_n2OH802On2OH800ol0003obcC;
ol/db`0=ol/db`03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o;
=<_obcC;00GobcC;0ol00009oi9]TP05o`000?lhacSo><LhocS7>?l000002Om9]TT00ol0003o</db
oc;=<P0;oc;=<P03o`000?lRgB;o8]dR00?o8]dR00?o0000oeJYE_mFZEH01_mFZEH00ol0003o=</d
ocC;=006ocC;=005o`000?m0_d3o@;m0od2o@?l000001olMhQd00ol0003o<l`coc?<<`03oc?<<`03
o`000?n2OH;oPWf200WoPWf200?o0000ol/dboo;=</03_o;=</00ol0003ohAkQon4Nh@09on4Nh@03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003obcC;o`000004o`0000;ogb3O00?o0000oi9]T_nBKI80
1onBKI801?l0003o><LhocS7>?l00009odVfB@;o00003OlbcC800ol0003o8]dRob;M8P02ob;M8P03
o`000?mFZEKoEZUF00SoEZUF00?o0000ocC;=?ldbc@00oldbc@2o`0000Go@;m000?o0000oagR7OlM
hQd01?lMhQd00ol0003o<l`coc?<<`03oc?<<`03o`000?n2OH;oPWf200WoPWf200?o0000ol/dboo;
=</03_o;=</00ol0003ohAkQon4Nh@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000Sogb3O
00?o0000oi9]T_nBKI801_nBKI800ol0003o><Lho`000009odVfB@04o`000?mC[5?oDjaCo`0000go
</db00Co0000ob;M8_lRgB;o00003?mFZEH01Ol0003o=</docC;=?ldbcCo000000So@;m00_l00005
oagR7@03o`000?lcc3?o<l`c00;o<l`c00?o0000oh9mP_n2OH802On2OH800ol0003obcC;ol/db`0>
ol/db`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oO8=oogb3O
00Oogb3O00?o0000oi9]T_nBKI801onBKI800ol0003oBKI9odVfB@07odVfB@03o`000?mC[5?oDjaC
00;oDjaC00?o0000oc;=<_lbcC802_lbcC800ol0003o8]dRo`00000>oeJYEP03o`000?ldbcCo0000
00_o@;m000?o0000oagR7OlMhQd00_lMhQd01Ol0003o<l`coc?<<olcc3?o000000coPWf200?o0000
ol/dboo;=</03_o;=</3o`0000WohAkQ00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oO8=oogb3O
00Wogb3O00?o0000oi9]T_nBKI801_nBKI800ol0003oBKI9odVfB@06odVfB@03o`000?mC[5?oDjaC
00?oDjaC00?o0000oc;=<_lbcC802olbcC800ol0003oEZUFoeJYEP0>oeJYEP03o`000?m0_d3o@;m0
00_o@;m00_l00003oagR7@04o`000?lcc3?o<l`co`0000[oPWf20ol0000>ol/db`;o00000ook1?/2
o`0000OohAkQ00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oO8=oogb3O00[ogb3O00?o0000oi9]
T_nBKI801?nBKI800ol0003oBKI9odVfB@06odVfB@03o`000?mC[5?oDjaC00GoDjaC00?o0000oc;=
<_lbcC801olbcC83o`00017oEZUF00?o0000od2o@?m0_d003Om0_d001Ol0003o7N8MoagR7Ol0003o
<l`c00Co00000on2OH85o`0000;odRgB00?o0000ol/dboo;=</02_o;=</2o`0000Oon`Ck0_l00004
on4Nh@03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ogb3OomlPg`0;omlPg`03o`000?nBKI;oTVfB
00CoTVfB00?o0000odVfBOm9]TT01Om9]TT00ol0003oDjaCoe>/D`06oe>/D`03o`000?lbcC;o</db
00Co</db0ol00002ock1?P03o`000?mFZEKoEZUF00ooEZUF0_l0000?od2o@004o`000?lMhQgo0000
o`0000CoKI9]0ol00008om8]dP03o`000?o;=<_obcC;00OobcC;0_l0000;oo/4n`;o00000_oQ7^40
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000omlPgooO8=l03?oO8=l6o`0000OoBKI900?o0000oe>/
DomC[5<02?mC[5<00ol0003o</dboc;=<P03o`0000Ko?/4n00?o0000oeJYE_mFZEH03OmFZEH01?l0
003oDjaCoe>/Dol0000?od2o@003o`000?m]TVgoKI9]00GoKI9]00?o0000om8]d_oB;M802?oB;M80
0ol0003obcC;ol/db`05ol/db`03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oO8=l00ol0003oVFJIoiUVV@04oiUV
V@03o`000?m9]TWoBKI900?oBKI900?o0000oe>/DomC[5<02_mC[5<2o`0000[o?/4n00?o0000oeJY
E_mFZEH02omFZEH00ol0003oDjaCoe>/D`02oe>/D`03o`000?m0_d3o@;m000_o@;m00_l00007offB
K@03o`000?oB;M;odRgB00WodRgB00?o0000ol/dboo;=</00_o;=</2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000omlPgooO8=l02ooO8=l00ol0003oVFJIoiUVV@06oiUVV@05o`000?m9]TWoBKI9odVf
BOl000003OmC[5<00ol0003o?/4nock1?P0:ock1?P03o`000?mFZEKoEZUF00WoEZUF00?o0000oe>/
DomC[5<01?mC[5<00ol0003o@;m0od2o@008od2o@0;o000000?o:]DZo`000?m]TVd01om]TVd00ol0
003odRgBom8]dP09om8]dP04o`000?o;=<_o0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oO8=oogb3O
00Wogb3O00?o0000oiUVVOnIIYT02?nIIYT00ol0003oBKI9o`00000=oe>/D`03o`000?ln`Cko?/4n
00_o?/4n00?o0000oeJYE_mFZEH02?mFZEH00ol0003oDjaCoe>/D`06oe>/D`03o`000?m0_d3o@;m0
00Go@;m00_l00003ob[E:P03o`000?m]TVgoKI9]00KoKI9]00?o0000om8]d_oB;M802_oB;M800ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003ogb3OomlPg`07omlPg`03o`000?nIIYWoVFJI00[oVFJI00?o0000oe>/DomC
[5<03?mC[5<00ol0003o?/4nock1?P0<ock1?P03o`000?mFZEKoEZUF00KoEZUF00?o0000oe>/DomC
[5<02?mC[5<00ol0003o@;m0od2o@002od2o@0;o00001_lZeBX00ol0003oKI9]offBK@05offBK@03
o`000?oB;M;odRgB00[odRgB00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oO8=oogb3O00Gogb3O
00?o0000oiUVVOnIIYT03?nIIYT2o`0000coDjaC00?o0000ock1?_ln`Ch03Oln`Ch00ol0003oEZUF
oeJYEP04oeJYEP03o`000?mC[5?oDjaC00[oDjaC00Co0000od2o@?l0003o00002?lZeBX00ol0003o
KI9]offBK@06offBK@03o`000?oB;M;odRgB00WodRgB00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oO8=l00ol0003oVFJIoiUVV@0=oiUVV@03o`000?mJYE[o000000;o00002?mC[5<00ol0003o?/4n
ock1?P0?ock1?PKo00003_mC[5<00ol0003o:]DZob[E:P08ob[E:P03o`000?m]TVgoKI9]00KoKI9]
00?o0000om8]d_oB;M802OoB;M800ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000on4NhOoQ7^7ohAkQ
0_l0000?oiUVV@03o`000?mJYE[oFZEJ00?oFZEJ0ol00005oe>/D`;o00004?ln`Ch01_l0003o:m@[
ob_D:ol0003o5NXEo`0000koDjaC00?o0000ob[E:_lZeBX02OlZeBX00ol0003oKI9]offBK@05offB
K@03o`000?oB;M;odRgB00WodRgB00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000on4NhOoQ7^400ooQ7^400ol0003o
VFJIoiUVV@0=oiUVV@03o`000?mJYE[oFZEJ00KoFZEJ0ol000001?mC[5?o0000ocS7>?lhacP3o`00
00co?/4n00Go0000ob_D:ol[e2_o:m@[o`000002oaGZ5@03o`000?mC[5?oDjaC00_oDjaC00?o0000
ob[E:_lZeBX02OlZeBX00ol0003oKI9]offBK@06offBK@03o`000?oB;M;odRgB00SodRgB0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ohAkQon4Nh@04on4Nh@oo00003?mJYEX00ol0003o><LhocS7>004ocS7
>0?o00002?ln`Ch00ol0003o:m@[ob_D:`02ob_D:`05o`000?lEjQGo5NXEoaGZ5Ol000003?mC[5<0
0ol0003o:]DZob[E:P09ob[E:P03o`000?m]TVgoKI9]00GoKI9]3?l00002on/Dj`;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ohAkQon4Nh@05on4Nh@03o`000?n>LHkoSW6>00_oSW6>00?o0000oeZU
F_mJYEX02_mJYEX00ol0003o><LhocS7>007ocS7>0;o00001Oln`Ch00ol0003o:m@[ob_D:`03ob_D
:`03o`000?lEjQGo5NXE00;o5NXE00?o0000oe>/DomC[5<02OmC[5<00ol0003o:]DZob[E:P0:ob[E
:P03o`000?m]TVgoKI9]00?oKI9]00?o0000ok5>/OnaC[402OnaC[400ol0003ojaC[on/Dj`02on/D
j`;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ohAkQon4Nh@06on4Nh@03o`000?n>LHkoSW6>00[o
SW6>00?o0000oeZUF_mJYEX02omJYEX00ol0003o><LhocS7>009ocS7>0?o000000?o?/4no`000?l[
e2/01Ol[e2/00ol0003o5NXEoaGZ5@03oaGZ5@03o`000?mC[5?oDjaC00SoDjaC3_l00003offBK@;o
00002onaC[400ol0003ojaC[on/Dj`05on/Dj`03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000on4NhOoQ7^401OoQ7^400ol0003oXebSo`00000;ohiaSP03o`000?mJYE[oFZEJ00[oFZEJ
0_l0000>ocS7>003o`000?l[e2_o:m@[00Go:m@[00?o0000oaGZ5OlEjQD00olEjQD00ol0003oDjaC
oe>/D`08oe>/D`03o`000?m/TfcoK9=/00_oK9=/00?o0000offBKOl000003OnaC[400ol0003ojaC[
on/Dj`06on/Dj`;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oQ7^7ohAkQ00KohAkQ00Co
0000oj=LXonSG:?o00002_n>LHh00ol0003oFZEJoeZUFP09oeZUFP03o`000?m0_d3o000000ko><Lh
00?o0000ob_D:ol[e2/01Ol[e2/00ol0003o5NXEoaGZ5@04oaGZ5@03o`000?mC[5?oDjaC00KoDjaC
00?o0000ofbCK?m/Tf`03Om/Tf`00ol0003o/Djaok5>/@0<ok5>/@03o`000?o[5>_ojaC[00SojaC[
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oQ7^7ohAkQ00GohAkQ00?o0000oj=LXonSG:<00_nS
G:<00ol0003oSW6>ohiaSP06ohiaSP03o`000?mJYE[oFZEJ00SoFZEJ0_l00003od2o@003o`000?lh
acSo><Lh00_o><Lh00?o0000ob_D:ol[e2/01Ol[e2/00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?mC
[5?oDjaC00GoDjaC00?o0000ofbCK?m/Tf`03Om/Tf`00ol0003o/Djaok5>/@0;ok5>/@03o`000?o[
5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oQ7^7ohAkQ00KohAkQ00?o0000
oj=LXonSG:<00onSG:<00ol0003oSW6>ohiaSP05ohiaSP03o`000?mJYE[oFZEJ00OoFZEJ00?o0000
od2o@?m0_d000om0_d000ol0003o><LhocS7>00:ocS7>003o`000?l[e2_o:m@[00Ko:m@[00?o0000
oaGZ5OlEjQD01_lEjQD00ol0003oDjaCoe>/D`04oe>/D`03o`000?m/TfcoK9=/00goK9=/3ol0000;
on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oQ7^7ohAkQ00KohAkQ00?o0000oj=LXonSG:<01OnSG:<00ol0
003oSW6>ohiaSP04ohiaSP03o`000?mJYE[oFZEJ00GoFZEJ0_l00006od2o@003o`000?lhacSo><Lh
00Wo><Lh0_l00008ob_D:`03o`000?lEjQGo5NXE00Ko5NXE1Ol000000omC[5?o0000ofbCK00?ofbC
K003o`000?naC[7o/Dja00_o/Dja00?o0000on/Djoo[5>/02Oo[5>/00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oQ7^7ohAkQ00KohAkQ00?o0000oj=LXonSG:<01_nSG:<00ol0003o
SW6>ohiaSP04o`0000KoFZEJ00?o0000od2o@?m0_d001om0_d000ol0003o><LhocS7>005ocS7>0?o
000000?o8MhQo`000?l[e2/01ol[e2/00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?mHYeSoF:MH00?o
F:MH0_l0000?ofbCK0;o00003OnaC[400ol0003ojaC[on/Dj`08on/Dj`03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WohAkQ00?o0000oj=LXonSG:<01onSG:<2o`0000CoSW6>00Co0000oeZUF_mJYE[o
FZEJ0_l0000:od2o@003o`000?lhacSo><Lh00;o><Lh0ol00005ob7N8@03o`000?l[e2_o:m@[00Go
:m@[00?o0000oaGZ5OlEjQD01?lEjQD00ol0003oF:MHoeRWF006oeRWF003o`000?m/TfcoK9=/00[o
K9=/0_l00002ohm`S`03o`000?naC[7o/Dja00[o/Dja00?o0000on/Djoo[5>/02?o[5>/00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000on4NhOoQ7^401_oQ7^400ol0003oXebSoj=LX`08oj=LX`03o`00
0?n>LHkoSW6>00CoSW6>00?o0000oeZUF_l000003?m0_d000ol0003o><Lho`000002o`0000Wo8MhQ
00?o0000ob_D:ol[e2/01?l[e2/00ol0003o5NXEoaGZ5@03oaGZ5@03o`000?mHYeSoF:MH00SoF:MH
1_l00004ofbCK0;o00001On?L8l00ol0003o/Djaok5>/@09ok5>/@03o`000?o[5>_ojaC[00SojaC[
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oQ7^7ohAkQ00GohAkQ00?o0000oj=LXonSG:<01onS
G:<00ol0003oSW6>ohiaSP06ohiaSP03o`000?m0_d3o@;m000co@;m000?o0000ob7N8OlQgR402_lQ
gR400ol0003o:m@[ob_D:`04ob_D:`04o`000?lEjQGo5NXEoaGZ5@;o00002omHYeP00ol0003oMXUf
ogJ9MP03ogJ9MPCo00002?n?L8l00ol0003o/Djaok5>/@08ok5>/@03o`000?o[5>_ojaC[00OojaC[
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000on4NhOoQ7^400ooQ7^400ol0003oXebSoj=LX`07oj=LX`03o`000?n>
LHkoSW6>00OoSW6>00?o0000od2o@?m0_d003?m0_d000ol0003o8MhQob7N8@0;ob7N8@03o`000?l[
e2_o:m@[00?o:m@[00Co0000oaGZ5OlEjQGo00003OmHYeP00ol0003oMXUfogJ9MP06ogJ9MP03o`00
0?n?L8ooSg2?00OoSg2?00?o0000ok5>/OnaC[401onaC[400ol0003ojaC[on/Dj`06on/Dj`04o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oQ7^7ohAkQ00;ohAkQ00?o0000oj=LXonSG:<0
1_nSG:<00ol0003oSW6>ohiaSP09ohiaSP03o`000?m0_d3o@;m000Wo@;m00_l0000>ob7N8@?o0000
0ol[e2/00ol0003o5NXEo`00000=oeRWF003o`000?mfRGKoMXUf00OoMXUf00?o0000ohm`Son?L8l0
2?n?L8l:o`0000KojaC[0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoXebS00?o
0000ohiaS_n>LHh02_n>LHh00ol0003o@;m0od2o@006od2o@0;o000000?o>l@ko`000?lQgR402olQ
gR42o`0000?oDZeB1Ol0000>oeRWF003o`000?mfRGKoMXUf00OoMXUf00?o0000ohm`Son?L8l02?n?
L8l00ol0003oacS7olLha`06olLha`03o`000?o[5>_ojaC[00?ojaC[00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003oe2_Dom@[e003om@[e0Co00000_nSG:<00ol0003oSW6>ohiaSP0;
ohiaSP03o`000?m0_d3o@;m000?o@;m00ol00004oc_4>`03o`000?lQgR7o8MhQ00Oo8MhQ0_l00008
oe:]DP03o`000?mHYeSoF:MH00goF:MH00?o0000ogJ9M_mfRGH02?mfRGH00ol0003oSg2?ohm`S`07
ohm`S`03o`000?o7><OoacS700OoacS70ol000000oo[5>_o0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oD:mCoe2_D00Ooe2_D0_l0000?ohiaSP03o`000?m0_d3o@;m000;o00002?lka3/00ol0
003o8MhQob7N8@05ob7N8@03o`000?mB[E;oDZeB00SoDZeB00?o0000oeRWF?mHYeP03OmHYeP00ol0
003oMXUfogJ9MP08ogJ9MP03o`000?n?L8ooSg2?00KoSg2?00?o0000olLhaoo7><L02?o7><L01?l0
003ok1?/on`Ck?l0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003oe2_Dom@[e009om@[
e003o`000?n>LHkoSW6>00koSW6>0_l0000;oc_4>`03o`000?lQgR7o8MhQ00;o8MhQ0_l0000;oe:]
DP03o`000?mHYeSoF:MH00goF:MH00?o0000ogJ9M_mfRGH02?mfRGH00ol0003oSg2?ohm`S`06ohm`
S`03o`000?o7><OoacS700OoacS700Go0000on`Ck?o/4ncok1?/o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oe2_Dom@[e00:om@[e003o`000?n>LHkoSW6>00goSW6>0_l0000<oc_4>`04o`000?lQgR7o0000
o`0000goDZeB00?o0000oeRWF?mHYeP03?mHYeP00ol0003oMXUfogJ9MP09ogJ9MP03o`000?n?L8oo
Sg2?00KoSg2?00?o0000olLhaoo7><L01_o7><L00ol0003ok1?/on`Ck003on`Ck003o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003oe2_Dom@[e00:om@[e003o`000?n>LHkoSW6>00coSW6>00Co0000od:m
@_m2_D;o00003?lka3/00ol0003oDZeBoe:]DP0>oe:]DP03o`000?mHYeSoF:MH00SoF:MH1?l0000;
ogJ9MP03o`000?n?L8ooSg2?00KoSg2?00?o0000olLhaoo7><L01Oo7><L00ol0003ok1?/on`Ck004
on`Ck003o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003oe2_Dom@[e00;om@[e003o`000?n>LHkoSW6>
00_oSW6>00?o0000od:m@_m2_D800_m2_D800ol0003o>l@koc_4>`09oc_4>`03o`000?mB[E;oDZeB
00koDZeB00Co0000oeRWF?mHYeSoF:MH1ol00003of6NH@03o`000?mfRGKoMXUf00WoMXUf00?o0000
ohm`Son?L8l01_n?L8l00ol0003oacS7olLha`04olLha`03o`000?o/4ncok1?/00Kok1?/00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oD:mCoe2_D00coe2_D00?o0000ohiaS_n>LHh02_n>LHh00ol0
003o@[e2od:m@P03od:m@P03o`000?lka3_o>l@k00So>l@k00?o0000oe:]D_mB[E803_mB[E84o`00
00_oHIiQ00?o0000ogJ9M_mfRGH02?mfRGH00ol0003oSg2?ohm`S`05ohm`S`03o`000?o7><OoacS7
00GoacS700?o0000on`Ck?o/4n`01_o/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om@[e?oD
:m@03?oD:m@7o`0000GoSW6>00?o0000od:m@_m2_D801Om2_D800ol0003o>l@koc_4>`07oc_4>`03
o`000?mB[E;oDZeB00koDZeB00?o0000of6NHOmQWV403OmQWV400ol0003oMXUfogJ9MP08ogJ9MP03
o`000?n?L8ooSg2?00CoSg2?00?o0000olLhaoo7><L01?o7><L00ol0003ok1?/on`Ck007on`Ck003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003oe2_Dom@[e00=om@[e003o`000?nYEZWoZEJY00CoZEJY
1Ol00009od:m@P03o`000?lka3_o>l@k00Ko>l@k00?o0000oe:]D_mB[E803_mB[E800ol0003oHIiQ
of6NH@0=of6NH@03o`000?mfRGKoMXUf00SoMXUf00Co0000ohm`Son?L8ooSg2?1Ol00004olLha`03
o`000?o/4ncok1?/00Wok1?/1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=om@[e003o`000?nYEZWoZEJY00WoZEJY
0_l00009od:m@P03o`000?lka3_o>l@k00Ko>l@k00?o0000oe:]D_mB[E803?mB[E800ol0003oHIiQ
of6NH@0?of6NH@Ko00001?mfRGH4o`0000GobcC;0_l000000oo7><Oo0000on`Ck00;on`Ck004o`00
0?ol0ocoo0?loo`3o0Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oV6NKoiQWVonHIiP?o00002_oD:m@00ol0003o
ZEJYojUFZ@09ojUFZ@03o`000?mHYeSo000000;o00001om2_D800ol0003o>l@koc_4>`05oc_4>`03
o`000?mB[E;oDZeB00SoDZeB1Ol0000Aof6NH@03o`000?n4NhCoQ7^400?oQ7^41?l0000;ol/db`03
o`000?o/4ncok1?/00[ok1?/00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000onHIi_oV6NH01OoV6NH2o`0000Ooe2_D
00?o0000ojUFZOnYEZT02_nYEZT00ol0003oF:MHoeRWF002oeRWF0?o00001Om2_D800ol0003o>l@k
oc_4>`04oc_4>`04o`000?mB[E;oDZeBoe:]DPOo00001?m6^DH00ol0003oHIiQof6NH@0>of6NH@03
o`000?n4NhCoQ7^400OoQ7^400?o0000ol/dboo;=</02Oo;=</00ol0003ok1?/on`Ck009on`Ck003
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003oiQWVonHIiP08onHIiP;o00001?oD:m@00ol0003oZEJY
ojUFZ@0;ojUFZ@03o`000?mHYeSoF:MH00GoF:MH0ol00003od:m@P04o`000?lka3_o>l@koc_4>`Ko
00003?m6^DH00ol0003oHIiQof6NH@0=of6NH@03o`000?n4NhCoQ7^400OoQ7^400?o0000ol/dboo;
=</02_o;=</00ol0003ok1?/on`Ck008on`Ck003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onHIiP?o000000?oe2_Do`000?nYEZT0
3?nYEZT00ol0003oF:MHoeRWF008oeRWF0?o000000Co@[e2o`000?l0003o00000_moP7l00ol0003o
A[U6odJiAP0=odJiAP03o`000?mQWV7oHIiQ00coHIiQ00?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003o
bcC;ol/db`0;ol/db`03o`000?o/4ncok1?/00Kok1?/00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
iQWV00?o0000ojUFZOnYEZT03?nYEZT00ol0003oF:MHoeRWF00;oeRWF003o`000?moP7ooOh1o00?o
Oh1o00?o0000odJiA_m6^DH03?m6^DH00ol0003o=</do`00000=of6NH@03o`000?n4NhCoQ7^400So
Q7^400?o0000ol/dboo;=</03?o;=</3o`0000Gok1?/00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oV6NKoiQWV00coiQWV00?o0000ojUFZOnYEZT03?nYEZT00ol0003oF:MHoeRWF00:oeRWF003o`00
0?moP7ooOh1o00GoOh1o00?o0000odJiA_m6^DH02_m6^DH01?l0003o=</docC;=?ldbc@2o`0000[o
HIiQ00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003obcC;ol/db`0<ol/db`03o`000?o_4>ooka3_00?o
000000?ok1?/o`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000ojUFZOnYEZT0
3?nYEZT00ol0003oF:MHoeRWF009oeRWF003o`000?moP7ooOh1o00KoOh1o00?o0000odJiA_m6^DH0
2Om6^DH00ol0003o=</docC;=002ocC;=003o`000?mmPWgo000000;o00001omQWV400ol0003oQ7^4
ohAkQ009ohAkQ003o`000?o;=<_obcC;00_obcC;00?o0000onl@koo_4>l01?o_4>l00ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onHIi_oV6NH02ooV6NH00ol0003oZEJYojUFZ@0;ojUFZ@03o`000?mH
YeSoF:MH00SoF:MH00?o0000ogn0OomoP7l01omoP7l00ol0003oA[U6odJiAP08odJiAP03o`000?ld
bcCo=</d00?o=</d00?o0000ogf2OOmmPWd00_mmPWd2o`0000CoHIiQ00?o0000ohAkQ?n4Nh@02_n4
Nh@00ol0003obcC;ol/db`0:ol/db`03o`000?o_4>ooka3_00Goka3_00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oV6NKoiQWV00[oiQWV0ol0000;ojUFZ@Ko00001?mHYeP00ol0003oOh1oogn0O`08
ogn0O`03o`000?m6^DKoA[U600OoA[U600?o0000ocC;=?ldbc@00oldbc@00ol0003oOH9mogf2O@05
ogf2O@?o000000?oHIiQo`000?n4Nh@02on4Nh@00ol0003obcC;ol/db`09ol/db`03o`000?o_4>oo
ka3_00Ooka3_00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oV6NKoiQWV00WoiQWV00?o0000ol<l
`oo3?<<01?l00006ojUFZ@03o`000?nSG:?oXebS00CoXebS1?l0000<ogn0O`03o`000?m6^DKoA[U6
00GoA[U600?o0000ocC;=?ldbc@01?ldbc@00ol0003oOH9mogf2O@08ogf2O@03o`000?n4NhCoQ7^4
00_oQ7^400?o0000ol/dboo;=</02?o;=</00ol0003oka3_onl@k`08onl@k`Go00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oV6NKoiQWV00OoiQWV00?o0000ol<l`oo3?<<01Oo3?<<3o`0000;oZEJY00?o0000oj=LXonS
G:<02?nSG:<00ol0003oOh1oogn0O`0:ogn0O`03o`000?m6^DKoA[U600CoA[U600?o0000ocC;=?ld
bc@01Oldbc@00ol0003oOH9mogf2O@08ogf2O@03o`000?n4NhCoQ7^400WoQ7^41?l00008ol/db`03
o`000?o_4>ooka3_00Woka3_00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWV
onHIiP05onHIiP03o`000?o3?<?o`cc300Wo`cc30_l0000<oj=LX`03o`000?moP7ooOh1o00WoOh1o
00?o0000odJiA_m6^DH00om6^DH00ol0003o=</docC;=005ocC;=003o`000?mmPWgoOH9m00[oOH9m
00?o0000ohAkQ?n4Nh@01?n4Nh@4o`0000Co_T6n00?o0000ol/dboo;=</01?o;=</00ol0003oka3_
onl@k`0:onl@k`03o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oV6NKoiQWV00?oiQWV00?o0000ol<l`oo3?<<02oo3
?<<00ol0003oXebSoj=LX`0:oj=LX`03o`000?moP7ooOh1o00WoOh1o00?o0000odJiA_m6^DH00_m6
^DH00ol0003o=</docC;=006ocC;=003o`000?mmPWgoOH9m00[oOH9m00?o0000ohAkQ?n4Nh@01?l0
0009oki1_PKo00003?o_4>l00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onHIi_oV6NKoiQWV0_l0
000=ol<l``03o`000?nSG:?oXebS00[oXebS00?o0000ogn0OomoP7l02OmoP7l01Ol0003oA[U6odJi
A_m6^DKo000000Wo=</d00?o0000ogf2OOmmPWd02ommPWd2o`0000go_T6n00?o0000onXEj_oZ5NX0
0_oZ5NX00ol0003oka3_onl@k`0:onl@k`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiQWVo`00
0002onhAkP;o00002oo3?<<00ol0003oXebSoj=LX`0;oj=LX`03o`000?moP7ooOh1o00WoOh1o00?o
0000odJiA_l000002Oldbc@00ol0003oOH9mogf2O@0<ogf2O@03o`000?nn@Kko_T6n00co_T6n00?o
0000onXEj_oZ5NX00ooZ5NX00ol0003oka3_onl@k`09onl@k`03o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003okQ7^onhAkP03onhAkP;o00002_o3?<<00ol0003oXebSoj=LX`0:oj=LX`03o`000?moP7oo
Oh1o00SoOh1o1Ol00008ocC;=003o`000?mmPWgoOH9m00coOH9m00?o0000oki1__nn@Kh02onn@Kh0
0ol0003ojQGZonXEjP05onXEjP03o`000?o_4>ooka3_00Soka3_00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oo^4Nh2o`0000So`cc300?o0000oj=LXonSG:<02_nSG:<00ol0003oOh1oogn0O`07ogn0
O`03o`000?mcS7?oLhac00?oLhac0ol00005ocC;=003o`000?mmPWgoOH9m00_oOH9m00?o0000oki1
__nn@Kh03?nn@Kh00ol0003ojQGZonXEjP06onXEjP03o`000?o_4>ooka3_00Ooka3_00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?ol0oco000000WokQ7^00?o0000ol<l`oo3?<<01Oo3?<<2o`0000co
XebS00?o0000ogn0OomoP7l01OmoP7l00ol0003oLhacog><L`07og><L`?o000000?o=</do`000?mm
PWd03OmmPWd00ol0003o_T6noki1_P0<oki1_P03o`000?oZ5N[ojQGZ00KojQGZ00?o0000onl@koo_
4>l01_o_4>l00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003oo`3o003o`000?o^4NkokQ7^00OokQ7^
0_l00004ol<l``03o`000?o?<<oocc3?00;o00002_nSG:<00ol0003oOh1oogn0O`03ogn0O`;o0000
3OmcS7<2o`0000goOH9m0ol0000=oki1_P03o`000?oZ5N[ojQGZ00OojQGZ00?o0000onl@koo_4>l0
1Oo_4>l00ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo0?loo`3o004oo`3o003o`000?o^4NkokQ7^00SokQ7^0_l0
00000oo3?<?o0000oll`c`04oll`c`03o`000?nSG:?oXebS00OoXebS00Co0000ogn0OomoP7ooOh1o
0_l00002oimOW`03o`000?mcS7?oLhac00coLhac3Ol00003ojaC[003o`000?nn@Kko_T6n00[o_T6n
00?o0000onXEj_oZ5NX02?oZ5NX01?l0003oka3_onl@koo_4>l4o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?ol0o`00ol0003okQ7^
onhAkP09onhAkP03o`000?o?<<oocc3?00Gocc3?0_l00008oj=LX`03o`000?moP7oo000000GoWenO
00?o0000og><LomcS7<02omcS7<00ol0003oOX5nogj1OP09ogj1OP03o`000?n/Djco[5>/00;o[5>/
0_l00009oki1_P03o`000?oZ5N[ojQGZ00[ojQGZ0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000oo`3
o00:oo`3o003o`000?o^4NkokQ7^00SokQ7^00?o0000oll`coo?<<l01oo?<<l4o`0000?oXebS0ol0
0007oimOW`03o`000?mcS7?oLhac00[oLhac00?o0000ogj1O_mnPGh02OmnPGh00ol0003o[5>/ojaC
[004ojaC[0;o00001onn@Kh00ol0003ojQGZonXEjP0:onXEjP03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?o^4NkokQ7^00OokQ7^00?o0000oll`coo?<<l02?o?<<l0
1?l0003ocS7>olhac_o><Lh3o`0000;o_4>l00?o0000oimOWonOGil01_nOGil00ol0003oLhacog><
L`08og><L`03o`000?mnPGkoOX5n00[oOX5n00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003o_T6noki1
_P04oki1_P03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003occ3?oll`c`08oll`c`03o`000?o><Lko
cS7>00CocS7>00Go0000oka3_?nl@kco_4>lo`000008oimOW`03o`000?mcS7?oLhac00OoLhac00?o
0000ogj1O_mnPGh02_mnPGh00ol0003o[5>/ojaC[007ojaC[0;o00001?nn@Kh00ol0003ojQGZonXE
jP08onXEjP03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh00oo^4Nh0
0ol0003occ3?oll`c`08oll`c`03o`000?o><LkocS7>00CocS7>00?o0000oka3_?nl@k`00_nl@k`0
0ol0003oWenOoimOW`07oimOW`03o`000?mcS7?oLhac00KoLhac00?o0000ogj1O_mnPGh02_mnPGh0
0ol0003o[5>/ojaC[009ojaC[005o`000?nn@Kko_T6noki1__l000002OoZ5NX00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_occ3?00?o0000olhac_o><Lh01?o><Lh00ol0003o_4>loka3_003
oka3_003o`000?nOGiooWenO00OoWenO00?o0000og><LomcS7<01OmcS7<00ol0003oOX5nogj1OP0:
ogj1OP03o`000?n/Djco[5>/00Wo[5>/1?l00009onXEjP03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?oa3_7ol@ka
oo4>lOl000002_o?<<l00ol0003ocS7>olhacP05olhacP03o`000?nl@kco_4>l00?o_4>l00?o0000
oimOWonOGil02?nOGil00ol0003oLhacog><L`04og><L`03o`000?mnPGkoOX5n00WoOX5n00?o0000
ojaC[?n/Dj`02?n/Dj`2o`0000?ojQGZ00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000oo4>lOoa3_400ooa3_400ol0003occ3?oll`c`06oll`c`03o`000?o><LkocS7>
00GocS7>00?o0000oka3_?nl@k`01?nl@k`00ol0003oWenOoimOW`09oimOW`03o`000?mcS7?oLhac
00;oLhac00?o0000ogj1O_mnPGh02_mnPGh00ol0003o[5>/ojaC[006ojaC[0;o00001_oZ5NX8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003ol@kaoo4>l@05oo4>l@03o`000?o?<<oocc3?00Gocc3?00?o0000olhac_o>
<Lh01Oo><Lh00ol0003o_4>loka3_005oka3_003o`000?nOGiooWenO00WoWenO00Go0000og><Lomc
S7?oLhaco`00000<ogj1OP03o`000?n/Djco[5>/00Co[5>/0_l00008onXEjP03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?oa3_7ol@ka00Ool@ka00?o0000oll`coo?
<<l00oo?<<l00ol0003ocS7>olhacP06olhacP03o`000?nl@kco_4>l00Go_4>l00?o0000oimOWonO
Gil02_nOGil00ol0003oLhaco`000004o`0000WoOX5n00?o0000ojaC[?n/Dj`00_n/Dj`2o`0000[o
jQGZ00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ol@kaoo4>l@07oo4>l@03o`00
0?o?<<oocc3?00;occ3?00?o0000olhac_o><Lh01_o><Lh00ol0003o_4>loka3_007oka3_0;o0000
2onOGil00ol0003oaSW6olHiaP03olHiaPOo00000_mnPGh00ol0003o[5>/ojaC[002o`0000_ojQGZ
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000oo4>lOoa3_402Ooa
3_401Ol0003occ3?oll`coo?<<oo000000SocS7>00?o0000oka3_?nl@k`01onl@k`00ol0003ogaoO
o`000002o`0000SoWenO00?o0000olHia_o6>LH02_o6>LH5o`0000gojQGZ00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<oo4>l@03o`000?o?<<oo000000WocS7>00?o
0000oka3_?nl@k`01_nl@k`00ol0003ogaoOomlOg`03omlOg`?o00001?nOGil00ol0003oaSW6olHi
aP0=olHiaP03o`000?oZ5N[ojQGZ00gojQGZ00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000oom0_d2o`0000_ol@ka00?o0000olhac_o><Lh01oo><Lh00ol0003o_4>loka3_007
oka3_003o`000?oO7moogaoO00KogaoO0ol000000onOGioo0000olHiaP0>olHiaP03o`000?oZ5N[o
jQGZ00cojQGZ00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo4>
l@03o`000?o><LkocS7>00;ocS7>1_l00008oka3_003o`000?oO7moogaoO00[ogaoO00?o0000olHi
a_o6>LH03oo6>LH00ol0003ojQGZonXEjP0:onXEjP;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo4>l@Go00001_o]4^d00ol0003o_4>loka3_005oka3_003o`000?oO7moogaoO00[o
gaoO00?o0000olHia_o6>LH03oo6>LH00ol0003ojQGZonXEjP07onXEjP?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo4>l@03o`000?o]4^gokA;]00WokA;]00?o0000oka3_?nl
@k`00onl@k`00ol0003ogaoOomlOg`0;omlOg`03o`000?o6>LKoaSW600ooaSW600?o0000onXEj_oZ
5NX01OoZ5NX2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?ol@kao`000?l00000
3Oo]4^d00ol0003o_4>loka3_002oka3_003o`000?oO7moogaoO00_ogaoO5?l00004onXEjP;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo0?lo`00000>ondBk@04o`000?nl@kco_4>lo`0000kogaoO
00?o0000oo0?l?o`3o004?o`3o000ol0003ojQGZo`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?ol0ocoo0?loo`3o?l000003_o]4^d00ol0003o_4>lo`00000>omlOg`03o`00
0?o`3o3ol0o`017ol0o`00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000oo`3o?ol0o`00_ol0o`00ol0003okA;]ondBk@0=ondBk@03o`000?oO7moogaoO00WogaoO1Ol0
000Boo0?l0;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003okA;]ondBk@0<ondBk@03o`000?oO7moogaoO00;ogaoO1ol00004oo`3o003o`000?o`3o3o
l0o`00ool0o`00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o006oo`3
o003o`000?o]4^gokA;]00cokA;]1?l0000<oo`3o003o`000?o`3o3ol0o`00col0o`0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Oo
o0?l00?o0000ondBkOo]4^d03?o]4^d00ol0003oo0?loo`3o00=oo`3o003o`000?o`3o3ol0o`00_o
l0o`00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo`3o?ol
0o`02Ool0o`00ol0003okA;]ondBk@0:ondBk@03o`000?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`
3o002Oo`3o02o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000ondBkOo]4^d02_o]4^d00ol0003oo0?l
oo`3o00?oo`3o003o`000?o`3o3ol0o`00Kol0o`0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo0?l00goo0?l3?l0
000Aoo`3o0?o00001_o`3o000ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000oo`3o02o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?ol0oco
o0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000oo0?l?l000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000oo`3o?ol0o`00ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002oo`3
o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01Ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Oo003o0_ooo`08o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000So003o00?oool0o`00ool00?l00ol00?l2oooo00Ko003o0_ooo`07o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002Ol00?l00oooo`3o003oo`00o`03o`00o`03oooo0?l00?oo003o
00Co003o0_ooo`07o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0009o`00o`;oool02ol00?l2oooo00Oo
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o003oo`00o`09o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00_o003o00?oool0o`00ool00?l02?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00co003o00?oool0o`00ool00?l01ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00co003o0_ooo`08o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
000=o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3
oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`0=o`00o`;oool01ol00?l2
oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00
o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool03Ol00?l2oooo00Oo003o0_ooo`06o`00
o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go
003o00?oool0o`00ool00?l05ol00?l2oooo00Ko003o00?oool0o`00ool00?l01?l00?l2oooo00Oo
003o0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`05o`00o`;oool0
1ol00?l2oooo00Oo003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_oo
o`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l01?l0
0?l2oooo00?o003o0oooo`07o`00o`;oool01ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool01Ol00?l6oooo00Ko003o1?ooo`08o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1W
o`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08Ol00?l4oooo
00Wo003o0_ooo`09o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(220) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.988 .012 .988 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.989 .011 .989 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.989 .011 .989 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.988 .012 .988 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.933 .067 .933 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.986 .014 .986 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.932 .068 .932 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.934 .066 .934 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.902 .098 .902 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.983 .017 .983 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.872 .128 .872 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.988 .012 .988 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.789 .211 .789 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.791 .209 .791 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.99 .01 .99 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.69 .31 .69 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.841 .159 .841 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.981 .019 .981 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.984 .016 .984 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.924 .076 .924 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.487 .513 .487 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.792 .208 .792 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.64 .36 .64 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.628 .372 .628 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.705 .295 .705 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.867 .133 .867 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.904 .096 .904 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.989 .011 .989 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.624 .376 .624 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.822 .178 .822 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.486 .514 .486 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.885 .115 .885 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.838 .162 .838 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.988 .012 .988 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.748 .252 .748 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.804 .196 .804 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.632 .368 .632 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.877 .123 .877 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.653 .347 .653 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.991 .009 .991 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.914 .086 .914 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.607 .393 .607 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.354 .646 .354 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.371 .629 .371 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.937 .063 .937 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.947 .053 .947 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.775 .225 .775 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.988 .012 .988 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.614 .386 .614 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.576 .424 .576 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.464 .536 .464 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.488 .512 .488 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.252 .748 .252 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.584 .416 .584 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.672 .328 .672 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.989 .011 .989 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.664 .336 .664 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.56 .44 .56 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.921 .079 .921 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.241 .759 .241 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.821 .179 .821 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.769 .231 .769 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.462 .538 .462 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.219 .781 .219 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.415 .585 .415 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.038 .962 .038 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.085 .915 .085 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.34 .66 .34 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.297 .703 .297 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.354 .646 .354 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.817 .183 .817 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.285 .715 .285 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.316 .684 .316 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.649 .351 .649 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.932 .068 .932 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.987 .013 .987 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.179 .821 .179 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.247 .753 .247 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.364 .636 .364 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.987 .013 .987 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.636 .364 .636 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.319 .681 .319 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.276 .724 .276 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.101 .899 .101 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.422 .578 .422 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.226 .774 .226 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.925 .075 .925 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.256 .744 .256 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.04 .96 .04 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.749 .251 .749 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.176 .824 .176 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.123 .877 .123 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.501 .499 .501 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.872 .128 .872 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.337 .663 .337 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.017 .983 .017 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.13 .87 .13 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.426 .574 .426 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.182 .818 .182 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.209 .791 .209 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.881 .119 .881 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.142 .858 .142 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.08 .92 .08 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.052 .948 .052 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.986 .014 .986 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.049 .951 .049 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.228 .772 .228 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.12 .88 .12 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.639 .361 .639 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.307 .693 .307 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.986 .014 .986 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.365 .635 .365 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.226 .774 .226 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.252 .748 .252 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.307 .693 .307 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.164 .836 .164 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.117 .883 .117 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.27 .73 .27 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.46 .54 .46 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.987 .013 .987 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.737 .263 .737 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.286 .714 .286 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.402 .598 .402 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.208 .792 .208 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.926 .074 .926 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.153 .847 .153 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.127 .873 .127 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.32 .68 .32 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.598 .402 .598 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.073 .927 .073 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.988 .012 .988 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.201 .799 .201 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.786 .214 .786 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.942 .058 .942 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.496 .504 .496 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.504 .496 .504 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.255 .745 .255 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.864 .136 .864 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.055 .945 .055 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.18 .82 .18 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.333 .667 .333 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.584 .416 .584 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.051 .949 .051 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.189 .811 .189 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.311 .689 .311 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.375 .625 .375 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.987 .013 .987 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.106 .894 .106 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.987 .013 .987 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.907 .093 .907 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.36 .64 .36 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.301 .699 .301 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.158 .842 .158 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.691 .309 .691 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.241 .759 .241 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.92 .08 .92 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.35 .65 .35 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.381 .619 .381 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.385 .615 .385 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.524 .476 .524 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.737 .263 .737 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.468 .532 .468 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.157 .843 .157 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.109 .891 .109 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.167 .833 .167 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.431 .569 .431 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.753 .247 .753 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.988 .012 .988 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.916 .084 .916 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.253 .747 .253 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.206 .794 .206 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.329 .671 .329 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.778 .222 .778 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.576 .424 .576 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.987 .013 .987 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.438 .562 .438 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.802 .198 .802 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.921 .079 .921 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.2 .8 .2 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.283 .717 .283 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.908 .092 .908 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.281 .719 .281 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.52 .48 .52 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.635 .365 .635 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.372 .628 .372 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.462 .538 .462 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.831 .169 .831 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.713 .287 .713 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.714 .286 .714 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.792 .208 .792 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.351 .649 .351 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.939 .061 .939 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.729 .271 .729 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.43 .57 .43 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.414 .586 .414 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.669 .331 .669 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.41 .59 .41 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.987 .013 .987 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.928 .072 .928 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.799 .201 .799 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.925 .075 .925 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.359 .641 .359 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.901 .099 .901 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.713 .287 .713 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.601 .399 .601 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.988 .012 .988 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.586 .414 .586 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.48 .52 .48 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.988 .012 .988 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.732 .268 .732 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.983 .017 .983 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.989 .011 .989 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.583 .417 .583 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.985 .015 .985 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.512 .488 .512 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.987 .013 .987 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.595 .405 .595 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.803 .197 .803 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.66 .34 .66 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.882 .118 .882 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.9 .1 .9 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.733 .267 .733 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.625 .375 .625 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.721 .279 .721 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.84 .16 .84 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.895 .105 .895 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.842 .158 .842 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.856 .144 .856 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.984 .016 .984 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.727 .273 .727 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.919 .081 .919 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.986 .014 .986 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.939 .061 .939 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.922 .078 .922 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.735 .265 .735 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.928 .072 .928 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.904 .096 .904 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.797 .203 .797 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.986 .014 .986 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.984 .016 .984 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.911 .089 .911 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.987 .013 .987 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.987 .013 .987 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.986 .014 .986 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.987 .013 .987 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.986 .014 .986 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.987 .013 .987 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003ojQGZonXEj_l0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000onXEj_oZ5NX00_oZ5NX00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oZ5N[ojQGZ00?ojQGZ00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000onXEj_oZ5NX01OoZ5NX00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojQGZonXEjP06onXEjP03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o/4nco0000013oo0?l00?o0000oo`3o?ol0o`02?ol
0o`9o`0000cojQGZ00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003on`Ck003o`000?ol
0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj005onPGj003o`000?oZ
5N[ojQGZ00_ojQGZ0ol00003onPGj003o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
on`Ck?o/4n`00oo/4n`00ol0003oo0?loo`3o00;oo`3o0;o00002ool0o`00ol0003oj1OXonPGj006
onPGj003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000onPGj?oX5nP01?oX5nP00ol0003oo0?loo`3o00:
oo`3o004o`000?oV6NKoiQWVonHIiP;o00002_ol0o`2o`000003onHIi_l0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?ol0oco
o0?l00Ooo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003ok1?/on`Ck005on`Ck003o`000?ol0oco
o0?l00Woo0?l00?o0000ondBkOl000002ool0o`00ol0003oj1OXonPGj006onPGj003o`000?oZ5N[o
jQGZ00WojQGZ00?o0000onPGj?oX5nP01_oX5nP00ol0003oo0?loo`3o008oo`3o003o`000?oV6NKo
iQWV00CoiQWV0_l00005oo`3o0?o00001?oV6NH00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo0?loo`3o009oo`3
o003o`000?ol0ocoo0?l00Soo0?l0_l00008on`Ck003o`000?ol0ocoo0?l00Ooo0?l0_l00003ondB
k@03o`000?ol0ocoo0?l00Ooo0?l00?o0000onPGj?oX5nP01ooX5nP00ol0003ojQGZonXEjP09onXE
jP03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo`3o?ol0o`01Ool0o`2o`0000WoiQWV0_l000000ool
0oco0000o`000007onHIiP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000oo`3o?ol0o`02_ol0o`2o`0000Soo0?l00?o0000on`Ck?o/
4n`02?o/4n`00ol0003oo0?loo`3o006oo`3o003o`000?o]4^gokA;]00?okA;]00?o0000oo`3o?ol
0o`01ool0o`00ol0003oj1OXonPGj008onPGj003o`000?oZ5N[ojQGZ00OojQGZ00?o0000onPGj?oX
5nP02OoX5nP00ol0003oo0?loo`3o003oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000onHIi_oV
6NH01ooV6NH00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[o`000005oo`3o0;o00002oo/4n`2o`0000Koo0?l
00?o0000ondBkOo]4^d01Oo]4^d00ol0003oo0?loo`3o006oo`3o003o`000?oX5nSoj1OX00Soj1OX
00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oj1OXonPGj00;onPGj005o`000?ol0ocoo0?loo`3o?l0
00003_oV6NH00ol0003oiQWVonHIiP08onHIiP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo0?loo`3o00;oo`3o005o`000?o[5>_ojaC[on/Djol0
00000ool0o`00ol0003ok1?/on`Ck00:on`Ck004o`000?oO8=oogb3Oo`0000?oo0?l0_l00008ondB
k@03o`000?ol0ocoo0?l00Koo0?l00?o0000onPGj?oX5nP02OoX5nP00ol0003ojQGZonXEjP05onXE
jP03o`000?oX5nSoj1OX00coj1OX00?o0000oo`3o?l000003ooV6NH00ol0003oiQWVonHIiP08onHI
iP03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[on/Dj`03on/Dj`03o`000?ol0oco000000_o
k1?/0_l00004omlPg`03o`000?ol0oco000000_okA;]00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
j1OXonPGj009onPGj003o`000?oZ5N[ojQGZ00CojQGZ00?o0000onPGj?oX5nP03_oX5nP00ol0003o
iQWVonHIiP0>onHIiP03o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo0?l00?o0000on/Djoo[5>/0
1?o[5>/00ol0003ok1?/on`Ck009on`Ck003o`000?oO8=oogb3O00Gogb3O00?o0000ondBkOo]4^d0
2_o]4^d00ol0003oo0?loo`3o005oo`3o003o`000?oX5nSoj1OX00[oj1OX00?o0000onXEj_oZ5NX0
0ooZ5NX00ol0003oj1OXonPGj00>onPGj003o`000?oV6NKoiQWV00goiQWV00?o0000onHIi_oV6NH0
2_oV6NH00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[on/D
j`05on/Dj`03o`000?o/4ncok1?/00Ook1?/0_l00008omlPg`03o`000?o]4^gokA;]00_okA;]00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oj1OXonPGj00:onPGj004o`000?oZ5N[ojQGZonXEjP?o0000
3ooX5nP00ol0003oiQWVonHIiP0>onHIiP03o`000?oV6NKoiQWV00[oiQWV00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo0?loo`3
o009oo`3o003o`000?o[5>_ojaC[00OojaC[00?o0000on`Ck?o/4n`01?o/4n`2o`0000_ogb3O1?l0
0009ondBk@03o`000?ol0ocoo0?l00?oo0?l00?o0000onPGj?oX5nP02ooX5nP01?l0003ojQGZo`00
0?l00003olLha`;o00003?oX5nP2o`00013oiQWV00?o0000onHIi_oV6NH02ooV6NH00ol0003oo0?l
oo`3o00=oo`3o004o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojaC[
on/Dj`07on/Dj`03o`000?o/4ncok1?/00?ok1?/00?o0000omlPgooO8=l02ooO8=l01?l0003o_4>l
oka3_?nl@k`5o`0000GokA;]00?o0000oo`3o?ol0o`00_ol0o`00ol0003oj1OXonPGj00<onPGj003
o`000?o7><OoacS700GoacS70_l00008onPGj0;o00000_njAKX00ol0003oiQWVonHIiP0=onHIiP03
o`000?oV6NKoiQWV00_oiQWV00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000oo`3o?ol0o`01ool0o`00ol0003ojaC[on/Dj`09on/Dj`03o`000?o/4ncok1?/00;o0000
3OoO8=l00ol0003o_4>loka3_007oka3_0Ko00000_ol0o`4o`0000goj1OX00?o0000olLhaoo7><L0
1oo7><L2o`0000Goj1OX00?o0000okY5^_njAKX00onjAKX00ol0003oiQWVonHIiP0<onHIiP03o`00
0?oV6NKoiQWV00coiQWV00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o006oo`3o003o`000?o[5>_ojaC[00WojaC[00?o
0000on`Ck?l000003ooO8=l00ol0003o_4>loka3_00<oka3_0?o00001?oM8]d3o`0000Woj1OX00?o
0000olLhaoo7><L02_o7><L2o`000003onPGj?l0003o000000Oo^TFj00?o0000onHIi_oV6NH02ooV
6NH00ol0003oiQWVonHIiP0<onHIiP03o`000?ol0ocoo0?l00Koo0?l1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o005oo`3o003o`000?o[5>_ojaC[00_ojaC[00?o0000
omlPgooO8=l03_oO8=l00ol0003o_4>loka3_00=oka3_003o`000?oM8]gogB;M00KogB;M0ol00005
onPGj003o`000?o7><OoacS700goacS700?o0000okY5^_njAKX02?njAKX00ol0003oiQWVonHIiP09
onHIiP03o`000?oV6NKoiQWV00goiQWV00Co0000oo`3o?ol0ocoo0?l1Ol00003on`Ck003o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00?oo0?l00?o0000
on/Djoo[5>/02oo[5>/2o`0000oogb3O00?o0000oka3_?nl@k`03Onl@k`00ol0003ogB;MomdRg@0:
omdRg@?o000000?oj1OXo`000?o7><L03oo7><L00ol0003o^TFjokY5^P09okY5^P03o`000?oV6NKo
iQWV00SoiQWV00?o0000onHIi_oV6NH03_oV6NH3o`0000Sok1?/00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003oo`3o003o`000?o[5>_ojaC[00SojaC[0ol000000oo4
>lCo0000omlPg`0>omlPg`03o`000?nl@kco_4>l00go_4>l00?o0000omdRgOoM8]d03OoM8]d00ol0
003oacS7olLha`0?olLha`03o`000?njAK[o^TFj00[o^TFj2ol0000;onHIiPGo00003?o/4n`00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003ojAKYo`000?ol0oco0000
00SojaC[0ol00005ol@ka003o`000?oO8=oogb3O00cogb3O00?o0000oka3_?nl@k`03Onl@k`00ol0
003ogB;MomdRg@0=omdRg@;o00004?o7><L00ol0003o^TFjokY5^P0:okY5^P03o`000?nfBKKo]TVf
00Oo]TVf00?o0000onHIi_oV6NH00_oV6NH7o`0000Co^dBk00?o0000on`Ck?o/4n`02_o/4n`00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003ojAKYonTFjOoY5^T2o`00
00GojaC[0ol00009ol@ka0;o00002ooO8=l00ol0003o_4>loka3_00=oka3_003o`000?oM8]gogB;M
00gogB;M00Co0000oka3_?nl@kco00003oo7><L00ol0003o^TFjokY5^P09okY5^P03o`000?nfBKKo
]TVf00Wo]TVf1?l0000;ok]4^`03o`000?o/4ncok1?/00[ok1?/00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000onTFjOoY5^T01?oY5^T00ol0003ojaC[o`000002o`00
00coa3_400Co0000oj9MX_l0003o00002OoO8=l00ol0003o_4>loka3_00=oka3_003o`000?oM8]go
gB;M00gogB;M00Go0000oka3_?nl@kco_4>lo`00000=olLha`03o`000?njAK[o^TFj00[o^TFj00?o
0000okI9]_nfBKH02OnfBKH00ol0003o^dBkok]4^`0<ok]4^`03o`000?o/4ncok1?/00[ok1?/00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000onTFjOoY5^T01_oY5^T0
0ol0003oa3_4ol@ka00<ol@ka003o`000?nRGJ;oXUfR00;oXUfR0_l00007omlPg`03o`000?nl@kco
_4>l00co_4>l00?o0000omdRgOoM8]d03OoM8]d00ol0003o_4>loka3_003oka3_003o`000?o7><Oo
acS700[oacS700?o0000okY5^_njAKX02_njAKX00ol0003o]TVfokI9]P09okI9]P03o`000?nkA;_o
^dBk00co^dBk00?o0000on`Ck?o/4n`02oo/4n`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003ojAKYonTFj@06onTFj@03o`000?o4>lCoa3_400_oa3_400?o0000oj9M
X_nRGJ801OnRGJ800ol0003ogb3OomlPg`03omlPg`03o`000?nl@kco_4>l00go_4>l00?o0000omdR
gOoM8]d03OoM8]d00ol0003o_4>loka3_004oka3_003o`000?o7><OoacS700WoacS700?o0000okY5
^_njAKX02OnjAKX00ol0003o]TVfokI9]P0:okI9]P03o`000?nkA;_o^dBk00co^dBk00?o0000on`C
k?o/4n`02oo/4n`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
jAKYonTFj@07onTFj@03o`000?o4>lCoa3_400_oa3_400?o0000oj9MX_nRGJ801_nRGJ82o`0000?o
gb3O00?o0000oka3_?nl@k`03Onl@k`00ol0003ogB;MomdRg@0<omdRg@03o`000?nl@kco_4>l00Ko
_4>l00?o0000olLhaoo7><L02?o7><L00ol0003o^TFjokY5^P09okY5^P03o`000?nfBKKo]TVf00[o
]TVf00?o0000ok]4^onkA;/03?nkA;/00ol0003ok1?/on`Ck00;on`Ck003o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000onTFjOoY5^T02?oY5^T00ol0003oa3_4ol@ka00:ol@ka003o`00
0?nRGJ;oXUfR00WoXUfR0_l000000ooO8=oo0000oka3_00<oka3_0?o00003_oM8]d00ol0003o_4>l
oka3_007oka3_003o`000?o7><OoacS700OoacS700?o0000okY5^_njAKX02OnjAKX00ol0003o]TVf
okI9]P0;okI9]P03o`000?nkA;_o^dBk00co^dBk00?o0000on`Ck?o/4n`02_o/4n`00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000onTFjOoY5^T02_oY5^T00ol0003oa3_4ol@k
a009ol@ka003o`000?nRGJ;oXUfR00_oXUfR00?o0000oka3_?nl@k`02_nl@k`2o`0000?oVFJI00?o
0000omdRgOoM8]d02_oM8]d00ol0003o_4>loka3_009oka3_003o`000?o7><OoacS700KoacS700?o
0000okY5^_njAKX02?njAKX00ol0003o]TVfokI9]P0<okI9]P03o`000?nkA;_o^dBk00co^dBk00?o
0000on`Ck?o/4n`02_o/4n`00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?oY5^WojAKY00_ojAKY00?o0000ol@ka?o4>l@02?o4>l@0
0ol0003oXUfRoj9MXP0<oj9MXP03o`000?nl@kco_4>l00So_4>l0_l00006oiUVV@;o00002_oM8]d0
0ol0003o_4>loka3_00:oka3_003o`000?o7><OoacS700GoacS700?o0000okY5^_njAKX02?njAKX0
0ol0003o]TVfokI9]P0<okI9]P03o`000?nkA;_o^dBk00co^dBk00?o0000on`Ck?o/4n`02oo/4n`0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
onTFj@03o`000?o4>lCoa3_400Ooa3_400?o0000oj9MX_nRGJ803_nRGJ800ol0003o_4>loka3_004
oka3_0?o00002_nIIYT00ol0003ogB;MomdRg@07omdRg@03o`000?nl@kco_4>l00_o_4>l00?o0000
olLhaoo7><L00oo7><L00ol0003o^TFjokY5^P09okY5^P03o`000?nfBKKo]TVf00co]TVf00?o0000
ok]4^onkA;/03?nkA;/00ol0003ok1?/on`Ck00;on`Ck0;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_om0_d00ol0
003ojAKYonTFj@0<onTFj@03o`000?o4>lCoa3_400Ooa3_400?o0000oj9MX_nRGJ803onRGJ801?l0
003o_4>loka3_?nl@k`2o`0000koVFJI0_l00006omdRg@03o`000?nl@kco_4>l00go_4>l00?o0000
olLhaoo7><L00_o7><L00ol0003o^TFjokY5^P08okY5^P03o`000?nfBKKo]TVf00co]TVf0ol0000=
ok]4^`03o`000?o/4ncok1?/00_ok1?/00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?om0_go0000
00oojAKY00?o0000ol@ka?o4>l@01_o4>l@00ol0003oXUfRoj9MXP0@oj9MXPCo00004_nIIYT00ol0
003ogB;MomdRg@03omdRg@03o`000?nl@kco_4>l00ko_4>l00Go0000olLhaoo7><OoacS7o`000005
okY5^POo00003?nfBKH01Ol0003oPgb3oh=lPon3O8?o000000co^dBk00?o0000on`Ck?o/4n`02?o/
4n`3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000oojAKY00?o0000ol@ka?o4>l@01_o4>l@00ol0003oXUfRoj9MXP0=
oj9MXP?o000000CoK9=/o`000?l0003o00004onIIYT2o`0000;ogB;M00?o0000oka3_?nl@k`04?nl
@k`00ol0003oacS7o`000006o`0000OoZeB[00?o0000okI9]_nfBKH02?nfBKH00ol0003oPgb3oh=l
P`03oh=lP`;o00002?nkA;/3o`0000Kok1?/1?l00002onLHi`03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003ok1?/o`000?no@;l3o`0000gojAKY00?o0000ol@ka?o4>l@01?o4>l@00ol0003oXUfRoj9M
XP0;oj9MXP?o00000om/Tf`01Ol0003oKI9]o`000?mMXUgo000001CoVFJI00?o0000omdRgOl00000
4onl@k`00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?nfBKKo]TVf00Go]TVf0_l00008oh=lP`03o`00
0?nkA;_o^dBk00Go00000onhAkP00ol0003ok1?/on`Ck003o`0000OoiaSW00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?o/4ncok1?/o`0000Co_d2o0ol0000:onTFj@03o`000?o4>lCoa3_400?oa3_4
00?o0000oj9MX_nRGJ802OnRGJ83o`0000GoK9=/00Co0000offBKOm]TVgo00000_mMXUd00ol0003o
VFJIoiUVV@0BoiUVV@03o`000?nl@kco_4>l01;o_4>l00?o0000oj]DZon[E:/03_n[E:/00ol0003o
]TVfokI9]P03okI9]P03o`000?n3O8?oPgb300WoPgb30_l00009okQ7^0;o00002_oW6>L00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000on`Ck?o/4ncok1?/o`000007okm0_`;o00001ooY5^T5o`0000;o
a3_400?o0000oj9MX_nRGJ801_nRGJ83o`0000SoK9=/00Co0000offBKOm]TVgo00000omMXUd00ol0
003oVFJIoiUVV@0AoiUVV@03o`000?nl@kco_4>l017o_4>l00?o0000oj]DZon[E:/04?n[E:/01Ol0
003o]TVfokI9]_nfBKKo000000coPgb300?o0000okQ7^?nhAkP02?nhAkP00ol0003oiaSWonLHi`0:
onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000Cok1?/00?o0000okm0_ono@;l01ono@;l3o`00
0004onTFjOl0003o0000o`0000GoZEJY0_l00006oj9MXP?o00002_m/Tf`01Ol0003oKI9]offBKOm]
TVgo000000CoGJ9M00?o0000oiUVVOnIIYT04?nIIYT00ol0003o_4>loka3_00Aoka3_003o`000?n[
E:_oZeB[017oZeB[00?o0000okI9]_l000003On3O8<00ol0003o^4NhokQ7^008okQ7^003o`000?oW
6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o/4ncok1?/00Cok1?/00?o0000
okm0_ono@;l02_no@;l00ol0003oZEJYojUFZ@08ojUFZ@03o`000?nRGJ;oXUfR00?o00003Om/Tf`0
1Ol0003oKI9]offBKOm]TVgo000000GoGJ9M00?o0000oiUVVOnIIYT03onIIYT00ol0003o_4>loka3
_00Aoka3_003o`000?n[E:_oZeB[01;oZeB[00?o0000oh=lPon3O8<03?n3O8<00ol0003o^4NhokQ7
^008okQ7^003o`000?oW6>OoiaSW00_oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000on`Ck?o/4n`01Oo/4n`0
0ol0003o_d2ookm0_`0:okm0_`03o`000?nYEZWoZEJY00WoZEJY0_l0000?ofbCK003o`000?m]TVgo
KI9]00;oKI9]00?o0000oefRGOmMXUd01?mMXUd00ol0003oVFJIoiUVV@0=oiUVV@?o00004Onl@k`0
0ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n3O8?oPgb300_oPgb300?o0000okQ7^?nhAkP02OnhAkP0
0ol0003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?o/4n`0
0ol0003o_d2ookm0_`0:okm0_`03o`000?nYEZWoZEJY00WoZEJY00?o0000ofbCK?m/Tf`03Om/Tf`0
0ol0003oKI9]offBK@03offBK@03o`000?mMXUgoGJ9M00GoGJ9M00?o0000oiUVVOnIIYT02_nIIYT2
o`0000?oUFZE00?o0000oka3_?nl@k`03_nl@k`00ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n3O8?o
Pgb300_oPgb300?o0000okQ7^?nhAkP02OnhAkP00ol0003oiaSWonLHi`0;onLHi`03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000on`Ck?o/4n`01oo/4n`2o`0000_o_d2o00?o0000ojUF
ZOnYEZT02onYEZT00ol0003oK9=/ofbCK00<ofbCK003o`000?m]TVgoKI9]00?oKI9]00?o0000oefR
GOmMXUd01_mMXUd00ol0003oVFJIoiUVV@07oiUVV@;o00001_nEJYD2o`0000ko_4>l00?o0000oj]D
Zon[E:/04on[E:/00ol0003oPgb3oh=lP`0;oh=lP`03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000onLH
iooW6>L03?oW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009on`C
k003o`000?o:=L[o000000_o_d2o00?o0000ojUFZOnYEZT02onYEZT00ol0003oK9=/ofbCK00;ofbC
K003o`000?m]TVgoKI9]00CoKI9]00?o0000oefRGOmMXUd01omMXUd00ol0003oVFJIoiUVV@05oiUV
V@03o`000?nEJYGoUFZE00SoUFZE00?o0000oka3_?nl@k`02_nl@k`00ol0003oZeB[oj]DZ`0Doj]D
Z`03o`000?n3O8?oPgb300_oPgb300?o0000okQ7^?nhAkP02OnhAkP00ol0003oiaSWonLHi`0<onLH
i`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009on`Ck004o`000?o:=L[obSG:o`00
00_o_d2o00?o0000ojUFZOnYEZT02onYEZT00ol0003oK9=/ofbCK00;ofbCK003o`000?m]TVgoKI9]
00CoKI9]00?o0000oefRGOmMXUd02?mMXUd00ol0003oVFJIoiUVV@02oiUVV@;o00003?nEJYD2o`00
00[o_4>l00?o0000oj]DZon[E:/05?n[E:/00ol0003oPgb3oh=lP`0;oh=lP`03o`000?nhAkSo^4Nh
00Wo^4Nh00?o0000onLHiooW6>L03OoW6>L00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ok1?/on`Ck007on`Ck003
o`000?o:=L[obSG:00;obSG:00?o0000okm0_ono@;l02?no@;l00ol0003oZEJYojUFZ@0<ojUFZ@03
o`000?m/TfcoK9=/00WoK9=/00?o0000offBKOm]TVd01Om]TVd00ol0003oGJ9MoefRG@09oefRG@04
o`000?nIIYWo0000o`00013oUFZE0_l00008oka3_003o`000?n[E:_oZeB[01CoZeB[0ol0000;oh=l
P`03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000onLHiooW6>L03OoW6>L01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ok1?/on`Ck006on`Ck003o`000?o:=L[obSG:00?obSG:00?o0000okm0
_ono@;l02?no@;l00ol0003oZEJYojUFZ@0;ojUFZ@;o00002_m/Tf`00ol0003oKI9]offBK@06offB
K@03o`000?mMXUgoGJ9M00[oGJ9M00?o0000oiEZUOnEJYD04_nEJYD00ol0003o_4>loka3_004oka3
_003o`000?n[E:_oZeB[01GoZeB[00?o0000oiEZUOnEJYD01Ol00005oh=lP`03o`000?nhAkSo^4Nh
00[o^4Nh00?o0000onLHiooW6>L03_oW6>L3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ok1?/on`Ck004on`Ck003
o`000?o:=L[obSG:00CobSG:00?o0000okm0_ono@;l01ono@;l00ol0003oZEJYojUFZ@0;ojUFZ@04
o`000?mfRGKoMXUfo`0000WoK9=/00?o0000offBKOm]TVd01_m]TVd00ol0003oGJ9MoefRG@0:oefR
G@03o`000?nEJYGoUFZE01?oUFZE0_l00003oka3_0Co00005?n[E:/00ol0003oUFZEoiEZU@06oiEZ
U@Co000000?oPgb3o`000?nhAkP02onhAkP00ol0003oiaSWonLHi`0>onLHi`03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003ok1?/on`Ck003on`Ck003o`000?o:=L[obSG:00GobSG:00?o0000okm0_ono
@;l01ono@;l00ol0003oZEJYojUFZ@09ojUFZ@;o00001?mfRGH00ol0003oK9=/ofbCK005ofbCK003
o`000?m]TVgoKI9]00OoKI9]00?o0000oefRGOmMXUd02_mMXUd00ol0003oUFZEoiEZU@0EoiEZU@03
o`000?nl@kco000000CoXUfR0ol0000@oj]DZ`03o`000?nEJYGoUFZE00_oUFZE0_l0000<okQ7^003
o`000?oW6>OoiaSW00coiaSW0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`00_o/4n`00ol0003obSG:
olXebP06olXebP03o`000?no@;oo_d2o00Oo_d2o00?o0000ojUFZOnYEZT02?nYEZT00ol0003oMXUf
ogJ9MP05ogJ9MP03o`000?m/TfcoK9=/00CoK9=/00?o0000offBKOm]TVd01om]TVd00ol0003oGJ9M
oefRG@0:oefRG@03o`000?nEJYGoUFZE01KoUFZE00?o0000oj9MX_nRGJ801_nRGJ83o`0000coZeB[
00?o0000oiEZUOnEJYD03OnEJYD00ol0003o^4NhokQ7^009okQ7^0Go00002OoW6>L2o`000003onTF
jOl0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003on`Ck?l0003obSG:00WobSG:00?o0000okm0_ono@;l01_no
@;l00ol0003oZEJYojUFZ@07ojUFZ@03o`000?mfRGKoMXUf00OoMXUf00?o0000ofbCK?m/Tf`00_m/
Tf`00ol0003oKI9]offBK@08offBK@03o`000?mMXUgoGJ9M00WoGJ9M00?o0000oiEZUOnEJYD05onE
JYD00ol0003oXUfRoj9MXP09oj9MXP?o00002On[E:/00ol0003oUFZEoiEZU@0>oiEZU@Ko00001?nh
AkP00ol0003o_4>loka3_003oka3_0Go00000_oW6>L2o`0000CojAKY00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oO8=oogb3OomlPgol000002oo:=LX00ol0003o_d2ookm0_`06okm0_`03o`000?nY
EZWoZEJY00GoZEJY0_l0000;ogJ9MP04o`000?m/TfcoK9=/o`0000_oKI9]00?o0000oefRGOmMXUd0
2OmMXUd00ol0003oUFZEoiEZU@0FoiEZU@03o`000?nRGJ;oXUfR00goXUfR0ol00005oj]DZ`03o`00
0?nEJYGoUFZE00ooUFZE00?o0000oimOWonOGil00onOGil4o`0000_o_4>l0_l00006onTFj@03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ogb3OomlPg`02omlPg`ko00001_no@;l00ol0003oZEJYojUF
Z@05ojUFZ@03o`000?mfRGKoMXUf00coMXUf00?o0000ofbCK?l000002om]TVd00ol0003oGJ9MoefR
G@07oefRG@?o00006?nEJYD00ol0003oXUfRoj9MXP0@oj9MXP?o000000?oZeB[o`000?nEJYD04?nE
JYD00ol0003oWenOoimOW`07oimOW`03o`000?nl@kco_4>l00[o_4>l00?o0000onTFjOoY5^T01OoY
5^T00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005omlPg`03o`000?nSG:?oXebS00_oXebS0_l00004
okm0_`03o`000?nYEZWoZEJY00?oZEJY0_l0000@ogJ9MP03o`000?m]TVgoKI9]00[oKI9]00?o0000
oefRGOmMXUd00omMXUd4o`0000;oBKI900?o0000oiEZUOnEJYD05OnEJYD00ol0003oXUfRoj9MXP0D
oj9MXP03o`000?nEJYGoUFZE013oUFZE00?o0000oimOWonOGil01onOGil00ol0003o_4>loka3_00:
oka3_003o`000?oY5^WojAKY00GojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oO8=oogb3O
00Gogb3O00?o0000oj=LXonSG:<03OnSG:<6o`0000?oZEJY00?o0000ogJ9M_mfRGH04?mfRGH00ol0
003oKI9]offBK@0:offBK@03o`000?mMXUgo000000?o00001om9]TT00ol0003oUFZEoiEZU@0DoiEZ
U@03o`000?nRGJ;oXUfR01CoXUfR00?o0000oiEZUOnEJYD03onEJYD00ol0003oWenOoimOW`08oimO
W`03o`000?nl@kco_4>l00[o_4>l00?o0000onTFjOoY5^T01OoY5^T00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000omlPgooO8=l01_oO8=l00ol0003oXebSoj=LX`0=oj=LX`03o`000?nQGZ7oXEjQ00?o
XEjQ00?o0000ojUFZOl000004omfRGH4o`0000WoKI9]0_l0000<odVfB@03o`000?nEJYGoUFZE01?o
UFZE00?o0000oj9MX_nRGJ805OnRGJ800ol0003oUFZEoiEZU@0>oiEZU@03o`000?nOGiooWenO00So
WenO00?o0000oka3_?nl@k`02Onl@k`00ol0003ojAKYonTFj@07onTFj@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oO8=oogb3O00Sogb3O00?o0000oj=LXonSG:<02onSG:<00ol0003oXEjQoj5NX@05oj5NX@03o`00
0?mfRGKoMXUf01;oMXUf00Co0000oeJYE_mFZEKoEZUF1Ol00003offBK@03o`000?m9]TWoBKI900go
BKI90ol0000@oiEZU@;o00006?nRGJ800ol0003oUFZEoiEZU@0=oiEZU@03o`000?nOGiooWenO00Wo
WenO00?o0000oka3_?nl@k`02Onl@k`00ol0003ojAKYonTFj@07onTFj@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ogb3O00?o0000oj=LXonSG:<02_nSG:<00ol0003oXEjQoj5NX@06oj5NX@03o`00
0?mfRGKoMXUf017oMXUf00?o0000oeJYE_mFZEH01omFZEH3o`00013oBKI900?o0000od6n@Om1_T40
1Ol00009oiEZU@;o000000?oFJIIo`000?nRGJ805onRGJ800ol0003oUFZEoiEZU@0=oiEZU@03o`00
0?nOGiooWenO00WoWenO00?o0000oka3_?nl@k`02?nl@k`2o`0000[ojAKY00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?o^4NkokQ7^00;okQ7^00?o0000omlPgooO8=l02OoO8=l00ol0003oXebSoj=L
X`0:oj=LX`03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000ogJ9M_mfRGH03omfRGH00ol0003oEZUFoeJY
EP0:oeJYEP03o`000?m9]TWoBKI900goBKI900?o0000od6n@Om1_T401_m1_T44o`0000CoUFZE00?o
0000oeVVFOmIYUT00_mIYUT00ol0003oXUfRoj9MXP0Foj9MXP03o`000?nEJYGoUFZE00_oUFZE00?o
0000oimOWonOGil02onOGil00ol0003o_4>loka3_006oka3_003o`000?o<<lco000000[ojAKY00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?o^4NkokQ7^00?okQ7^00?o0000omlPgooO8=l02?oO8=l=
o`0000[oXEjQ00?o0000ogJ9M_mfRGH03omfRGH00ol0003oEZUFoeJYEP0;oeJYEP03o`000?m9]TWo
BKI900coBKI900?o0000od6n@Om1_T402_m1_T44o`0000GoFJII00?o0000oj9MX_nRGJ805_nRGJ80
0ol0003oUFZEoiEZU@0:oiEZU@03o`000?nOGiooWenO00coWenO00?o0000oka3_?nl@k`01?nl@k`2
o`0000?oc3?<00?o0000onTFjOoY5^T02?oY5^T00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onhA
k_o^4Nh00oo^4Nh00ol0003ogb3OomlPg`07omlPg`03o`000?nPGj3oX5nP00WoX5nP00?o0000oj5N
XOnQGZ402OnQGZ400ol0003oMXUfogJ9MP0=ogJ9MP03o`000?mFZEKoEZUF00coEZUF00?o0000odVf
BOm9]TT03?m9]TT00ol0003o@Ki1od6n@@0;od6n@@03o`000?lXebSo000000KoFJII00?o0000oj9M
X_nRGJ805_nRGJ800ol0003oUFZEoiEZU@09oiEZU@03o`000?nOGiooWenO00coWenO00?o0000oka3
_?nl@k`00onl@k`00ol0003oc3?<ol`cc003ol`cc003o`000?oY5^WojAKY00SojAKY00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?o^4NkokQ7^00CokQ7^00?o0000omlPgooO8=l01_oO8=l00ol0003o
X5nPoj1OX008oj1OX003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogJ9M_mfRGH02?mfRGH4o`0000oo
EZUF00?o0000odVfBOm9]TT02om9]TT00ol0003o@Ki1od6n@@0;od6n@@04o`000?lXebSo:=LXo`00
00OoFJII00?o0000oj9MX_nRGJ805OnRGJ800ol0003oUFZEoiEZU@08oiEZU@03o`000?nOGiooWenO
00goWenO00?o0000oka3_?nl@k`00_nl@k`00ol0003oc3?<ol`cc005ol`cc003o`000?oY5^WojAKY
00OojAKY00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?o^4NkokQ7^00GokQ7^00?o0000omlPgooO
8=l01OoO8=l00ol0003oX5nPoj1OX008oj1OX003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogJ9M_mf
RGH00omfRGH5o`0000?oEjQG00?o0000oeJYE_mFZEH03_mFZEH00ol0003oBKI9odVfB@0:odVfB@03
o`000?m1_T7o@Ki100[o@Ki100Go0000obSG:?lXebSo:=LXo`000007oeVVF@03o`000?nRGJ;oXUfR
01GoXUfR00?o0000oiEZUOnEJYD02?nEJYD00ol0003oWenOoimOW`0=oimOW`03o`000?nl@kco_4>l
00;o00002?o<<l`00ol0003ojAKYonTFj@08onTFj@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003okQ7^onhAkP05onhAkP03o`000?oO8=oogb3O00Go
gb3O00?o0000oj1OX?nPGj002?nPGj000ol0003oXEjQoj5NX@0<oj5NX@Go00002OmGZ5L00ol0003o
EZUFoeJYEP0<oeJYEP;o00003?m9]TT00ol0003o@Ki1od6n@@0:od6n@@05o`000?lXebSo:=LXobSG
:?l000002?mIYUT00ol0003oXUfRoj9MXP0Doj9MXP?o00001onEJYD00ol0003oWenOoimOW`0>oimO
W`03o`000?nl@kco000000_oc3?<00?o0000onTFjOoY5^T01_oY5^T00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003ogb3OomlPg`04omlPg`03o`000?nPGj3oX5nP00Oo
X5nP00?o0000oj5NXOnQGZ403?nQGZ401?l0003oMXUfogJ9M_l0000;oeNXE`03o`000?mFZEKoEZUF
00_oEZUF00Co0000obCK9?lTfbCo00002_m9]TT00ol0003o@Ki1od6n@@0:od6n@@03o`000?lXebSo
:=LX00;o:=LX00?o0000oeVVFOmIYUT01_mIYUT00ol0003oXUfRoj9MXP0Aoj9MXP?o00000om^TFh0
0ol0003oUFZEoiEZU@04oiEZU@03o`000?nOGiooWenO00goWenO1?l0000;ol`cc003o`000?oY5^Wo
jAKY00GojAKY00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o^4NkokQ7^00KokQ7^00Co0000omlP
gooO8=oogb3O1?l00008oj1OX003o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ogJ9M_mfRGH00_mfRGH0
0ol0003oEjQGoeNXE`08oeNXE`03o`000?mFZEKoEZUF00[oEZUF00?o0000obCK9?lTfb@00_lTfb@0
0ol0003oBKI9odVfB@03odVfB@Go00002om1_T400ol0003o:=LXobSG:003obSG:003o`000?mIYUWo
FJII00OoFJII00?o0000oj9MX_nRGJ803_nRGJ82o`0000OoKY5^00?o0000oiEZUOnEJYD00_nEJYD0
0ol0003oWenOoimOW`0=oimOW`03o`000?njAK[o^TFj00;o^TFj00?o0000ol`cc?o<<l`02Oo<<l`0
0ol0003ojAKYonTFj@03onTFj@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP07onhA
kP?o00001?o9=/T00ol0003oX5nPoj1OX005oj1OX003o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ogJ9
M_mfRGH00omfRGH00ol0003oEjQGoeNXE`09oeNXE`03o`000?mFZEKoEZUF00SoEZUF00?o0000obCK
9?lTfb@01?lTfb@5o`0000Co0?l000?o0000od6n@Om1_T402Om1_T400ol0003o:=LXobSG:003obSG
:003o`000?mIYUWoFJII00SoFJII00?o0000oj9MX_nRGJ802_nRGJ83o`0000[oKY5^00Go0000oiEZ
UOnEJYGoUFZEo`00000>oimOW`03o`000?njAK[o^TFj00Co^TFj0_l00009ol`cc003o`000?oY5^Wo
jAKY00;ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?o^4NkokQ7^00OokQ7^00?o0000olTf
bOo9=/T01Oo9=/T00ol0003oX5nPoj1OX003oj1OX003o`000?nQGZ7oXEjQ00[oXEjQ00?o0000ogJ9
M_mfRGH01?mfRGH00ol0003oEjQGoeNXE`09oeNXE`03o`000?mFZEKoEZUF00OoEZUF00?o0000obCK
9?lTfb@01OlTfb@00ol0003o0?l0o`3o0007o`3o0003o`000?m1_T7o@Ki100Oo@Ki100?o0000obSG
:?lXebP01?lXebP00ol0003oFJIIoeVVF@08oeVVF@03o`000?nRGJ;oXUfR00SoXUfR0_l0000>ofjA
KPCo00003?nOGil2o`0000Wo^TFj00?o0000ol`cc?o<<l`01oo<<l`01?l0003ojAKYonTFjOl0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003obCK9olTfb@07olTfb@;o00000onPGj000ol0
003oXEjQoj5NX@09oj5NX@03o`000?mfRGKoMXUf00KoMXUf00?o0000oeNXEomGZ5L02OmGZ5L00ol0
003oEZUFoeJYEP05oeJYEP03o`000?lTfbCo9=/T00Ko9=/T00?o0000o`3o0?l0o`002?l0o`000ol0
003o@Ki1od6n@@06od6n@@03o`000?lXebSo:=LX00Co:=LX00?o0000oeVVFOmIYUT02OmIYUT4o`00
00?oXUfR0ol0000@ofjAKP05o`000?nkA;_o^dBkok]4^ol000002_nOGil00ol0003o^TFjokY5^P0:
okY5^PKo00000oo<<l`00ol0003ojAKYo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000onhAk_o^4Nh01?o^4Nh00ol0
003obCK9olTfb@0:olTfb@04o`000?nPGj3oX5nPo`0000[oXEjQ00?o0000ogJ9M_mfRGH01omfRGH0
0ol0003oEjQGoeNXE`09oeNXE`03o`000?mFZEKoEZUF00CoEZUF00?o0000obCK9?lTfb@01olTfb@0
0ol0003o0?l0o`3o0008o`3o00;o00001_m1_T400ol0003o:=LXobSG:005obSG:003o`000?mIYUWo
FJII00WoFJII00Co0000odNhAom7^4OoAkQ70ol0000BofjAKP03o`000?nkA;_o^dBk00?o^dBk0_l0
0006oimOW`;o00003OnjAKX00ol0003okA;]ondBk@03ondBk@Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000onhAk_o^4Nh00oo^4Nh0
0ol0003obCK9olTfb@0<olTfb@;o00002_nQGZ400ol0003oMXUfogJ9MP08ogJ9MP03o`000?mGZ5Oo
EjQG00[oEjQG00?o0000oeJYE_mFZEH00_mFZEH00ol0003o9=/TobCK9008obCK9003o`000?l0o`3o
0?l000Ko0?l00_l00002ob3O8003o`000?m1_T7o@Ki100;o@Ki100?o0000obSG:?lXebP01_lXebP0
0ol0003oFJIIoeVVF@08oeVVF@03o`000?m7^4OoAkQ700CoAkQ700?o0000ofjAK_m^TFh03om^TFh0
0ol0003o^dBkok]4^`06ok]4^`;o00000onOGil00ol0003o^TFjokY5^P0=okY5^P03o`000?o]4^go
kA;]00OokA;]0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?ol0ocoo0?l00?o00001oom0_d00ol0003okQ7^onhAkP02onhAkP03o`000?o9=/WobCK9
00kobCK900?o0000oj5NXOnQGZ401onQGZ400ol0003oMXUfogJ9MP0:ogJ9MP03o`000?mGZ5OoEjQG
00WoEjQG00Go0000oeJYE_mFZEKoEZUFo`00000;obCK9003o`000?l0o`3o0?l000Co0?l00_l00005
ob3O8005o`000?m1_T7o@Ki1od6n@Ol000002?lXebP00ol0003oFJIIoeVVF@08oeVVF@03o`000?m7
^4OoAkQ700GoAkQ700?o0000ofjAK_m^TFh03_m^TFh00ol0003o^dBkok]4^`08ok]4^`03o`000?nO
Gioo000000oo^TFj00?o0000ondBkOo]4^d02?o]4^d01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?ol0ocoo0?l00Coo0?l0ol0
0005ood2o@04o`000?o^4NkokQ7^o`00017obCK900?o0000oj5NXOnQGZ401_nQGZ400ol0003oMXUf
ogJ9MP0;ogJ9MP03o`000?mGZ5OoEjQG00WoEjQG00Co0000oeJYE_mFZEKo00003?lTfb@00ol0003o
0?l0o`3o0002o`3o00;o00002?lPgb000ol0003o@Ki1o`000009obSG:003o`000?mIYUWoFJII00So
FJII00?o0000odNhAom7^4L01Om7^4L00ol0003oKY5^ofjAKP0=ofjAKP03o`000?nkA;_o^dBk00[o
^dBk00?o0000okY5^_njAKX03_njAKX00ol0003okA;]ondBk@07ondBk@03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo0?loo`3o008oo`3o0?o000000?oo@;mo`000?l000000ol0000BolTfb@03o`00
0?nQGZ7oXEjQ00CoXEjQ00?o0000ogJ9M_mfRGH03?mfRGH00ol0003oEjQGoeNXE`0:oeNXE`?o0000
3?lTfb@00ol0003o0?l0o`3o0002o`0000_o8=lP00?o0000obSG:?lXebP02?lXebP00ol0003oFJII
oeVVF@07oeVVF@03o`000?m7^4OoAkQ700OoAkQ700?o0000ofjAK_m^TFh03?m^TFh00ol0003o^dBk
ok]4^`0;ok]4^`;o00003_njAKX00ol0003okA;]ondBk@07ondBk@03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?ol
0ocoo0?l00coo0?l00?o0000onl@koo_4>l00oo_4>l00ol0003obCK9olTfb@0?olTfb@?o00000onQ
GZ400ol0003oMXUfogJ9MP0>ogJ9MP03o`000?mGZ5OoEjQG00SoEjQG00Co0000obgB;Ol]dRgo;M8]
0_l0000:obCK90?o00003OlPgb000ol0003o:=LXobSG:008obSG:003o`000?mIYUWoFJII00OoFJII
00?o0000odNhAom7^4L01om7^4L00ol0003oKY5^ofjAKP0;ofjAKP03o`000?nkA;_o^dBk00co^dBk
00?o0000om/Tfol000000_l0000:okY5^P03o`000?o]4^gokA;]00SokA;]00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000oo`3o?ol0o`03Ool0o`00ol0003oka3_onl@k`04onl@k`03o`000?o9=/WobCK900cobCK90_l0
0003ok1?/003o`000?nQGZ7o0000017oMXUf00?o0000oeNXEomGZ5L01omGZ5L00ol0003o;M8]obgB
;@04obgB;@;o00002?lTfb@00ol0003o8=lPob3O800>ob3O80;o00002?lXebP00ol0003oFJIIoeVV
F@06oeVVF@03o`000?m7^4OoAkQ700WoAkQ700?o0000ofjAK_m^TFh02Om^TFh00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oK9=_ofbCK00;ofbCK0ol00007okY5^P03o`000?o]4^gokA;]00OokA;]00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oka3_onl@k`05onl@k`03o`000?o9=/Wo
bCK900WobCK90_l00006ok1?/003o`000?mfRGKoMXUf013oMXUf00?o0000oeNXEomGZ5L01_mGZ5L0
0ol0003o;M8]obgB;@07obgB;@03o`000?lTfbCo9=/T00Co9=/T0ol0000>ob3O8003o`000?l=lPgo
3O8=00?o00001OlXebP00ol0003oFJIIoeVVF@06oeVVF@03o`000?m7^4OoAkQ700[oAkQ700?o0000
ofjAK_m^TFh02?m^TFh00ol0003o^dBkok]4^`0=ok]4^`03o`000?oK9=_ofbCK00GofbCK0ol00004
okY5^P03o`000?o]4^gokA;]00OokA;]00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003oka3_onl@k`06onl@k`03o`000?o9=/WobCK900GobCK90ol00008ok1?/003o`000?mfRGKoMXUf
017oMXUf00Co0000oeNXEomGZ5OoEjQG1?l0000;obgB;@;o000000Co9=/To`000?l0003o00000oli
aST2o`0000_o8=lP00?o0000o`gb3Ol=lPd01?l=lPd2o`0000?o:=LX00?o0000oeVVFOmIYUT01_mI
YUT00ol0003oAkQ7odNhA`0:odNhA`03o`000?m^TFkoKY5^00OoKY5^00?o0000ok]4^onkA;/03_nk
A;/00ol0003ofbCKom/Tf`08om/Tf`Co00002_o]4^d00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003oka3_onl@k`07onl@k`03o`000?o9=/WobCK900;obCK90_l0000<ok1?/003o`000?mfRGKo
MXUf013oMXUf1?l00003odRgB003o`000?l]dRgo;M8]00_o;M8]00?o0000ocW6>OliaST01_liaST0
0ol0003o8=lPob3O8007ob3O8003o`000?l=lPgo3O8=00Oo3O8=3?l0000>odNhA`03o`000?m^TFko
KY5^00KoKY5^00?o0000ok]4^onkA;/03_nkA;/00ol0003ofbCKom/Tf`0;om/Tf`03o`000?o]4^go
kA;]00OokA;]00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o_4>ooka3_00Woka3_00Co0000olTf
bOl0003o00003_n`Ck000ol0003oMXUfogJ9MP0?ogJ9MP03o`000?m8]dSoB;M800KoB;M800?o0000
obgB;Ol]dRd02_l]dRd00ol0003o>LHiocW6>@07ocW6>@;o00001_lPgb000ol0003o3O8=o`gb3@08
o`gb3@03o`000?mQWV7oHIiQ00SoHIiQ00?o0000odNhAom7^4L03?m7^4L00ol0003oKY5^ofjAKP05
ofjAKP03o`000?nkA;_o^dBk00oo^dBk0_l0000=om/Tf`03o`000?o]4^gokA;]00KokA;]00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?o_4>ooka3_00[oka3_00?o0000ok1?/?n`Ck003_n`Ck000ol0
003oMXUfogJ9MP0>ogJ9MP03o`000?m8]dSoB;M800OoB;M800?o0000obgB;Ol]dRd02_l]dRd00ol0
003o>LHiocW6>@09ocW6>@;o00000olPgb000ol0003o3O8=o`gb3@09o`gb3@03o`000?mQWV7oHIiQ
00WoHIiQ00?o0000odNhAom7^4L02_m7^4L4o`0000CoKY5^00?o0000ok]4^onkA;/04?nkA;/01?l0
003oebSGo`000?l0000<om/Tf`03o`000?o]4^gokA;]00GokA;]00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo0?loo`3o00<oo`3
o003o`000?o_4>ooka3_00[oka3_00?o0000ok1?/?n`Ck003on`Ck0@o`0000[oB;M800?o0000obgB
;Ol]dRd02Ol]dRd00ol0003o5>/Do`00000<ocW6>@05o`000?lPgb3o0000o`ka3_l000002_l=lPd0
0ol0003oHIiQof6NH@09of6NH@03o`000?m7^4OoAkQ700OoAkQ70ol00004ogJ9MP?o000000?oKY5^
o`000?nkA;/04OnkA;/01?l0003oebSGomLXeooG:=L2o`0000_ofbCK00?o0000ondBkOo]4^d00oo]
4^d00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@koo_4>l02_o_4>l00ol0003o/4n`ok1?/00?
ok1?/003o`000?mlPgcoO8=l00coO8=l00?o0000odRgB?m8]dP02Om8]dP00ol0003o;M8]obgB;@07
obgB;@04o`000?lDjaCo5>/Do`0000go>LHi00Go0000o`ka3_l>l@ko3_4>o`000009o`gb3@03o`00
0?mQWV7oHIiQ00[oHIiQ00?o0000odNhAom7^4L00om7^4L3o`0000[oMXUf00?o0000ok]4^onkA;/0
4?nkA;/00ol0003oebSGomLXe`04omLXe`;o00002_oK9=/00ol0003okA;]ondBk@04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000oo`3o?ol0o`02_ol
0o`3o`0000coka3_00?o0000ok1?/?n`Ck003on`Ck000ol0003oO8=logb3O00<ogb3O003o`000?m8
]dSoB;M800WoB;M800?o0000obgB;Ol]dRd01_l]dRd00ol0003o5>/DoaC[5002oaC[5003o`000?li
aSWo>LHi00[o>LHi00?o0000o`ka3_l>l@h00_l>l@h00ol0003o3O8=o`gb3@06o`gb3@03o`000?mQ
WV7oHIiQ00[oHIiQ00?o0000odNhAom7^4L00ol0000=ogJ9MP03o`000?nkA;_o^dBk013o^dBk00?o
0000omLXeooG:=L01_oG:=L2o`0000WofbCK0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000oo`3o?ol0o`01Ool0o`4
o`0000;oo@;m00?o0000onl@koo_4>l02_o_4>l00ol0003o/4n`ok1?/00=ok1?/0?o00003omlPg`0
0ol0003oB;M8odRgB008odRgB003o`000?l]dRgo;M8]00Go;M8]00?o0000oaC[5?lDja@00olDja@0
0ol0003o>LHiocW6>@0:ocW6>@03o`000?l>l@ko3_4>00?o3_4>00?o0000o`gb3Ol=lPd01Ol=lPd0
0ol0003oHIiQof6NH@0;of6NH@;o00004OmfRGH00ol0003o^dBkok]4^`0?ok]4^`03o`000?oG:=Oo
ebSG00SoebSG0_l00007om/Tf`03o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo0?loo`3o004o`00
00Ooo@;m00?o0000onl@koo_4>l02?o_4>l00ol0003o/4n`ok1?/009ok1?/0Go00000_mlPg`00ol0
003oO8=logb3O00=ogb3O003o`000?m8]dSoB;M800WoB;M800?o0000obgB;Ol]dRd01?l]dRd00ol0
003o5>/DoaC[5004oaC[5003o`000?liaSWo>LHi00So>LHi00?o0000o`ka3_l>l@h01Ol>l@h00ol0
003o3O8=o`gb3@04o`gb3@03o`000?mQWV7oHIiQ00_oHIiQ00?o0000ogJ9M_mfRGH04?mfRGH00ol0
003o^dBkok]4^`0?ok]4^`03o`000?oG:=OoebSG00[oebSG0_l00004om/Tf`03o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003oka3_onl@k`07onl@k`03o`000?n`Ck3o/4n`00Co/4n`1Ol00007ogb3O003
o`000?mlPgcoO8=l00goO8=l00?o0000odRgB?m8]dP02Om8]dP00ol0003o;M8]obgB;@03obgB;@03
o`000?lDjaCo5>/D00Go5>/D00?o0000ocW6>OliaST02?liaST00ol0003o3_4>o`ka3P06o`ka3P03
o`000?l=lPgo3O8=00?o3O8=00?o0000of6NHOmQWV402omQWV400ol0003oMXUfogJ9MP0@ogJ9MP03
o`000?nkA;_o^dBk00oo^dBk00?o0000omLXeooG:=L03?oG:=L2o`000003om/Tfol0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o_4>ooka3_00Ooka3_00?o0000ok1?/?l00000
1?l0000<ogb3O003o`000?mlPgcoO8=l00koO8=l00?o0000odRgB?m8]dP02?m8]dP00ol0003o;M8]
obgB;@02obgB;@03o`000?lDjaCo5>/D00Oo5>/D00?o0000ocW6>OliaST01oliaST00ol0003o3_4>
o`ka3P07o`ka3P03o`000?l=lPgo3O8=00;o3O8=00?o0000of6NHOmQWV402omQWV400ol0003oMXUf
ogJ9MP0AogJ9MP03o`000?nkA;_o^dBk00go^dBk00?o0000omLXeooG:=L03ooG:=L00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000onl@koo_4>l01Oo_4>l3o`00017oO8=l00?o0000ogb3O?mlPg`03_ml
Pg`00ol0003oB;M8odRgB009odRgB004o`000?l]dRgo;M8]o`0000[o5>/D00?o0000ocW6>OliaST0
1oliaST00ol0003o3_4>o`ka3P08o`ka3P05o`000?l=lPgo3O8=o`gb3Ol000003OmQWV400ol0003o
MXUfogJ9MP0AogJ9MP?o00003OnkA;/00ol0003oebSGomLXe`0?omLXe`03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_o_4>l2o`0000;obSG:00?o0000ogb3O?mlPg`03omlPg`00ol0003o
O8=logb3O00>ogb3O003o`000?m8]dSoB;M800SoB;M81Ol0000;oaC[5003o`000?liaSWo>LHi00Ko
>LHi00?o0000o`ka3_l>l@h02Ol>l@h01?l0003o3O8=o`gb3Ol0000=of6NH@03o`000?mfRGKoMXUf
017oMXUf00?o0000oe^TFomKY5/00ol0000:ok]4^`Co00003OoG:=L00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000onhAk_o^4NkokQ7^0_l00005olXebP03o`000?mlPgcoO8=l00koO8=l00?o0000ogb3
O?mlPg`03_mlPg`00ol0003oB;M8odRgB007odRgB003o`000?m1_T7o@Ki100?o@Ki100?o0000oaC[
5?lDja@02?lDja@00ol0003o>LHiocW6>@05ocW6>@03o`000?l>l@ko3_4>00[o3_4>1Ol0000<of6N
H@03o`000?mfRGKoMXUf013oMXUf00?o0000oe^TFomKY5/01?mKY5/3o`0000Ko^dBk00?o0000omLX
eooG:=L00_oG:=L5o`0000SoebSG00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o^4NkokQ7^00?o
kQ7^00?o0000olXeb_o:=LX01?o:=LX00ol0003oO8=logb3O00=ogb3O003o`000?mlPgcoO8=l00oo
O8=l00?o0000odRgB?m8]dP01?m8]dP2o`0000Oo@Ki100?o0000oaC[5?lDja@01olDja@Eo`0000Go
6n@K00?o0000of6NHOmQWV402?mQWV43o`00013oMXUf00?o0000oe^TFomKY5/02?mKY5/3o`0000;o
^dBk00?o0000omLXeooG:=L02?oG:=L5o`0000?oebSG00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?o^4NkokQ7^00CokQ7^00?o0000olXeb_o:=LX01Oo:=LX00ol0003oO8=logb3O00;ogb3O0Co0000
3omlPg`00ol0003oB;M8odRgB003odRgB003o`000?m1_T7o@Ki100So@Ki100?o0000oaC[5?lDja@0
1?lDja@2o`0000So@;m000?o0000obkA;_l^dBh02?l^dBh00ol0003o6n@Koa_T6`05oa_T6`;o0000
1_mQWV42o`0000?oE:]D00?o0000ogJ9M_mfRGH03?mfRGH00ol0003oFjAKoe^TF`0<oe^TF`;o0000
4?oG:=L3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP05onhAkP03o`000?o:=L[obSG:00KobSG:00?o
0000ogb3O?mlPg`02OmlPg`00ol0003oO8=lo`000002oeZUFP?o00003?mlPg`01?l0003oB;M8odRg
B?m8]dP2o`0000co@Ki100?o0000oaC[5?lDja@00_lDja@00ol0003o@;m0od2o@008od2o@003o`00
0?l^dBko;]4^00So;]4^00?o0000oa_T6olKi1/01olKi1/00ol0003oHIiQof6NH@02of6NH@03o`00
0?mDZeCoE:]D00CoE:]D0_l0000;ogJ9MP03o`000?mKY5_oFjAK00coFjAK00?o0000oiIYU_l00000
4_oG:=L00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003okQ7^onhAkP06onhAkP03o`000?o:=L[obSG:00OobSG:00?o
0000ogb3O?mlPg`01_mlPg`2o`0000;oO8=l00?o0000oeZUF_mJYEX00omJYEX3o`0000[oO8=l00?o
0000odRgB?l000003om1_T401?l0003o5>/Do`000?l0000;od2o@003o`000?l^dBko;]4^00So;]4^
00?o0000oa_T6olKi1/02?lKi1/01?l0003oHIiQo`000?l00009oeB[E003o`000?mfRGKoMXUf00Oo
MXUf00?o0000oe^TFomKY5/03?mKY5/01?l0003oUVVFoiIYU_l0000ComLXe`03o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000onhAk_o^4Nh01oo^4Nh00ol0003obSG:olXebP08olXebP03o`000?mlPgcoO8=l00Co
O8=l00?o0000ogb3O?mlPg`00omlPg`00ol0003oFZEJoeZUFP05oeZUFP?o00001_mlPg`4o`00013o
@Ki100?o0000od2o@?m0_d003?m0_d000ol0003o;]4^obkA;P07obkA;P03o`000?lKi1_o6n@K00Wo
6n@K00?o0000oeB[E?mDZe@02_mDZe@2o`0000KoMXUf00?o0000oe^TFomKY5/03?mKY5/00ol0003o
UVVFoiIYUP02oiIYUP03o`000?oG:=OoebSG00ooebSG00?o0000on/Djol000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003okQ7^onhAkP08onhAkP03o`000?o:=L[obSG:00WobSG:00Co0000ogb3O?mlPgco
O8=l0_l00006ogb3O003o`000?mJYE[oFZEJ00SoFZEJ0ol000000omlPgco0000o`000004oe2_D003
o`000?m1_T7o@Ki100go@Ki100?o0000od2o@?m0_d003?m0_d000ol0003o;]4^obkA;P07obkA;P03
o`000?lKi1_o6n@K00Wo6n@K00?o0000oeB[E?mDZe@03?mDZe@00ol0003oMXUfogJ9MP03o`0000ko
FjAK00?o0000oiIYU_nFJIH00onFJIH00ol0003oebSGomLXe`0>omLXe`05o`000?o[5>_ojaC[on/D
jol000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003okQ7^onhAkP09onhAkP03o`000?o:=L[obSG:00[o
bSG:00?o0000ogb3O?l000002?mlPg`00ol0003oFZEJoeZUFP0;oeZUFP03o`000?m@[e3oD:m@00Go
D:m@00?o0000od6n@Om1_T403?m1_T400ol0003o@;m0od2o@00<od2o@003o`000?l^dBko;]4^00Oo
;]4^00?o0000oa_T6olKi1/02?lKi1/2o`0000ooE:]D0_l00002ofVFJ@03o`000?mKY5_oFjAK00_o
FjAK00?o0000oiIYU_nFJIH01?nFJIH00ol0003oebSGomLXe`0=omLXe`03o`000?o[5>_ojaC[00?o
jaC[00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onhAkP03o`000?o:=L[obSG:00_obSG:00?o0000ogb3O?mlPg`0
1omlPg`00ol0003oFZEJoeZUFP0;oeZUFP03o`000?m@[e3oD:m@00KoD:m@00?o0000od6n@Om1_T40
2om1_T42o`0000go@;m000?o0000obkA;_l^dBh01ol^dBh00ol0003o6n@Koa_T6`07oa_T6`04o`00
0?lXebSo:=LXo`0000koE:]D00?o0000ofVFJOmYUVT00_mYUVT00ol0003oFjAKoe^TF`09oe^TF`03
o`000?nFJIKoUVVF00KoUVVF00?o0000omLXeooG:=L02ooG:=L00ol0003ojaC[on/Dj`05on/Dj`04
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000SokQ7^00?o0000olXeb_o:=LX02_o:=LX2o`0000Wo
O8=l00?o0000oeZUF_mJYEX02omJYEX00ol0003oD:m@oe2_D007oe2_D003o`000?m1_T7o@Ki100Wo
@Ki100Co0000o`cc3?l<l`co00003?m0_d000ol0003o;]4^obkA;P07obkA;P03o`000?lKi1_o6n@K
00Ko6n@K00Go0000obSG:?lXebSo:=LXo`00000>oeB[E003o`000?mYUVWoJIIY00?oJIIY00?o0000
oe^TFomKY5/01omKY5/00ol0003oUVVFoiIYUP07oiIYUP03o`000?oG:=OoebSG00[oebSG00?o0000
on/Djoo[5>/01oo[5>/00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006onhAkP03o`000?o:=L[obSG:
00WobSG:00Co0000okA;]?ndBkCo00002OmlPg`00ol0003oFZEJoeZUFP09oeZUFP03o`000?m@[e3o
D:m@00WoD:m@00?o0000od6n@Om1_T401om1_T400ol0003o3?<<o`cc3002o`cc3003o`000?m0_d3o
@;m000Wo@;m000?o0000obkA;_l^dBh01ol^dBh00ol0003o6n@Koa_T6`05oa_T6`03o`000?lXebSo
:=LX00?o:=LX00?o0000oeB[E?mDZe@02_mDZe@00ol0003oJIIYofVFJ@05ofVFJ@03o`000?mKY5_o
FjAK00GoFjAK00?o0000oiIYU_nFJIH02?nFJIH00ol0003oebSGomLXe`09omLXe`03o`000?o[5>_o
jaC[00SojaC[00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_o^4Nh3o`0000WobSG:00?o0000okA;
]?ndBk@00_ndBk@00ol0003oO8=logb3O006ogb3O003o`000?mJYE[oFZEJ00WoFZEJ00?o0000oe2_
D?m@[e002_m@[e000ol0003o@Ki1od6n@@05od6n@@03o`000?l<l`co3?<<00Co3?<<00?o0000od2o
@?m0_d002?m0_d000ol0003o;]4^obkA;P07obkA;P03o`000?lKi1_o6n@K00Co6n@K00?o0000obSG
:?lXebP01?lXebP00ol0003oE:]DoeB[E00:oeB[E003o`000?mYUVWoJIIY00KoJIIY00?o0000oe^T
FomKY5/00omKY5/00ol0003oUVVFoiIYUP09oiIYUP03o`000?oG:=OoebSG00SoebSG00?o0000on/D
joo[5>/02Oo[5>/00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003onHIiP?o00001Oo:=LX00ol0003o
]4^dokA;]003okA;]003o`000?mlPgcoO8=l00KoO8=l00?o0000oeZUF_mJYEX02OmJYEX00ol0003o
D:m@oe2_D00;oe2_D003o`000?m1_T7o@Ki100?o@Ki100?o0000o`cc3?l<l``01_l<l``00ol0003o
@;m0od2o@008od2o@003o`000?l^dBko;]4^00Ko;]4^00?o0000oa_T6olKi1/00_lKi1/2o`0000So
:=LX00?o0000oeB[E?mDZe@02OmDZe@00ol0003oJIIYofVFJ@07ofVFJ@05o`000?mKY5_oFjAKoe^T
Fol000003OnFJIH00ol0003oebSGomLXe`06omLXe`03o`000?o[5>_ojaC[00[ojaC[00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oV6NKoiQWV00GoiQWV0ol000000oo:=L[o0000okA;]006okA;]003
o`000?mlPgcoO8=l00GoO8=l00?o0000oeZUF_mJYEX02OmJYEX00ol0003oD:m@oe2_D00<oe2_D005
o`000?m1_T7o@Ki1od6n@Ol000002_l<l``00ol0003o@;m0od2o@007od2o@003o`000?l^dBko;]4^
00Ko;]4^00?o0000oa_T6ol000000_l000000omLXeco0000obSG:007obSG:003o`000?mDZeCoE:]D
00SoE:]D00?o0000ofVFJOmYUVT02OmYUVT00ol0003oFjAKo`00000=oiIYUPCo00001OoG:=L00ol0
003ojaC[on/Dj`0;on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWVonHIiP08onHIiP03
o`000?ndBkCo]4^d00Oo]4^d00?o0000ogb3O?mlPg`01?mlPg`00ol0003oFZEJoeZUFP09oeZUFP03
o`000?m@[e3oD:m@00goD:m@00?o0000od6n@Ol000003?l<l``:o`0000Oo;]4^0ol00005oebSG003
o`000?lXebSo:=LX00Ko:=LX00?o0000oeB[E?mDZe@01omDZe@00ol0003oJIIYofVFJ@0:ofVFJ@03
o`000?nFJIKoUVVF00_oUVVF00?o0000oldbcOo=</d00_o=</d3o`000003omLXeol0003ojaC[00_o
jaC[0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000onHIi_oV6NH02OoV6NH00ol0003o]4^dokA;]007okA;]003o`00
0?mlPgcoO8=l00GoO8=l00?o0000oeZUF_mJYEX01omJYEX00ol0003oD:m@oe2_D00?oe2_D0;o0000
2ol<l``00ol0003oC[5>odjaCP07odjaCP03o`000?l^dBko;]4^00;o;]4^0ol00008oebSG003o`00
0?lXebSo:=LX00Ko:=LX00?o0000oeB[E?mDZe@01omDZe@00ol0003oJIIYofVFJ@0:ofVFJ@03o`00
0?nFJIKoUVVF00[oUVVF00?o0000oldbcOo=</d01_o=</d00ol0003ojaC[on/Dj`08on/Dj`?o0000
0_o`3o000ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onHIi_oV6NH02OoV6NH00ol0003o]4^dokA;
]008okA;]003o`000?mlPgcoO8=l00CoO8=l00?o0000oeZUF_mJYEX01omJYEX00ol0003oD:m@oe2_
D00>oe2_D004o`000?lOh1oo7n0Oo`0000Wo3?<<00?o0000odjaC_m>/Dh02Om>/Dh01?l0003o;]4^
o`000?l0000<oebSG003o`000?lXebSo:=LX00Ko:=LX00?o0000oeB[E?mDZe@01_mDZe@00ol0003o
JIIYofVFJ@0;ofVFJ@03o`000?nFJIKoUVVF00OoUVVF0_l00009oldbc@03o`000?o[5>_ojaC[00Co
jaC[1?l00006oo0?l003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oiQWVonHIiP09onHIiP03o`00
0?ndBkCo]4^d00So]4^d00?o0000ogb3O?mlPg`00omlPg`>o`0000goD:m@00?o0000oaoP7olOh1l0
0_lOh1l00ol0003o3?<<o`cc3005o`cc3003o`000?m>/DkoC[5>00_oC[5>00?o0000oebSG?mLXe`0
3?mLXe`00ol0003o:=LXobSG:006obSG:003o`000?mDZeCoE:]D00GoE:]D00?o0000ofVFJOmYUVT0
3?mYUVT00ol0003oUVVFoiIYUP06oiIYUP03o`000?o=</gocC;=00[ocC;=00?o0000on/Djoo[5>/0
0ol0000:oo0?l0?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000okA;]?ndBk@02?nd
Bk@01Ol0003oO8=logb3O?mlPgco000000_oGZ5N00?o0000o`Wf2Ol9mPT00ol00009oe2_D003o`00
0?lOh1oo7n0O00Co7n0O00?o0000o`cc3?l<l``00ol<l``00ol0003oC[5>odjaCP0<odjaCP03o`00
0?mLXecoG:=L00goG:=L00?o0000obSG:?lXebP01_lXebP00ol0003oE:]DoeB[E003oeB[E0?o0000
3OmYUVT00ol0003oUVVFoiIYUP05oiIYUP03o`000?o=</gocC;=00cocC;=0_l0000=oo0?l003o`00
0?om0_goo@;m00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oV6NKoiQWV00_oiQWV00?o0000okA;]?ndBk@02?nd
Bk@4o`0000coGZ5N00?o0000o`Wf2Ol9mPT00ol9mPT3o`0000GoD:m@00?o0000oaoP7olOh1l01_lO
h1l01Ol0003o3?<<o`cc3?l<l`co000000ooC[5>00?o0000oebSG?mLXe`03OmLXe`00ol0003o:=LX
obSG:006obSG:003o`000?mDZeCoE:]D00?o00000olcc3<00ol0003oJIIYofVFJ@0;ofVFJ@03o`00
0?nFJIKoUVVF00?oUVVF00?o0000oldbcOo=</d03Oo=</d00ol0003ol0o`oo0?l00;oo0?l003o`00
0?om0_goo@;m00Coo@;m0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000onHIi_oV6NH02_oV6NH3o`0000Ko]4^d0ol0
0003oimPW`03o`000?mNXEkoGZ5N00[oGZ5N00?o0000o`Wf2Ol9mPT01_l9mPT3o`000003oe2_D?l0
003o7n0O00Wo7n0O00?o0000o`cc3?l000004?m>/Dh00ol0003oG:=LoebSG00=oebSG003o`000?lX
ebSo:=LX00Oo:=LX0_l00007oc?<<`03o`000?mYUVWoJIIY00[oJIIY00Co0000oiIYU_nFJIKoUVVF
0ol0000?oldbc@03o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000onHIi_oV6NH02_oV
6NH01?l0003oebSGomLXeooG:=L2o`000004okA;]?l0003o0000o`0000KoWf2O00?o0000oejQG_mN
XEh02_mNXEh00ol0003o2OH9o`Wf2@09o`Wf2@03o`000?lOh1oo7n0O00[o7n0O00?o0000odjaC_m>
/Dh03om>/Dh00ol0003oG:=LoebSG00>oebSG003o`000?lXebSo:=LX00Ko:=LX00?o0000oc?<<olc
c3<01olcc3<4o`0000SoJIIY00Co0000oiIYU_nFJIKo00000onHIiP2o`0000gocC;=00?o0000oo0?
l?o`3o002_o`3o000ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onHIi_oV6NH02OoV6NH00ol0003o
ebSGomLXe`04omLXe`03o`000?nOH9ooWf2O00OoWf2O00?o0000oejQG_mNXEh02OmNXEh00ol0003o
2OH9o`Wf2@0:o`Wf2@03o`000?lOh1oo7n0O00[o7n0O00?o0000odjaC_m>/Dh03om>/Dh00ol0003o
G:=LoebSG00>oebSG003o`000?lXebSo:=LX00Go:=LX00?o0000oc?<<olcc3<02?lcc3<01?l0003o
FJIIoeVVFOmIYUT7o`0000;oJIIY0_l00006oiQWV0;o00003?o=</d00ol0003ol0o`oo0?l009oo0?
l003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003oiQWVonHIiP08onHIiP03o`000?oG:=OoebSG00Go
ebSG00?o0000oimPWonOH9l02?nOH9l00ol0003oGZ5NoejQGP08oejQGP03o`000?l9mPWo2OH900[o
2OH900?o0000oaoP7olOh1l02olOh1l00ol0003oC[5>odjaCP0>odjaCP03o`000?mLXecoG:=L00ko
G:=L1Ol00002obSG:003o`000?lcc3?o<l`c00Wo<l`c00?o0000oeVVFOmIYUT02?mIYUT3o`0000Wo
V6NH0_l0000:oldbc@03o`000?o`3o3ol0o`00Sol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oV6NKoiQWV00SoiQWV00?o0000omLXeooG:=L01ooG:=L00ol0003oWf2OoimPW`07oimPW`03o`00
0?mNXEkoGZ5N00SoGZ5N00?o0000o`Wf2Ol9mPT02_l9mPT00ol0003o7n0OoaoP7`0:oaoP7`;o0000
3_m>/Dh3o`0000goG:=L0ol00005of:MHP;o00002olcc3<00ol0003oFJIIoeVVF@0;oeVVF@;o0000
2_nHIiP2o`0000OocC;=0ol00009oo0?l003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:omLXe`03o`00
0?nOH9ooWf2O00OoWf2O00?o0000oejQG_mNXEh02?mNXEh>o`0000Wo7n0O0ol000000ol4n`Co0000
odjaCP0:odjaCP?o00000_mVVFH00ol0003oG:=LoebSG009oebSG0;o00002OmRWF800ol0003o<l`c
oc?<<`09oc?<<`03o`000?mIYUWoFJII00_oFJII00?o0000ogZ5N_l000002onHIiP2o`0000CocC;=
00Co0000onDJiOoU6^GoiA[U0_l00007oo0?l003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003oebSG
omLXe`09omLXe`03o`000?nOH9ooWf2O00KoWf2O00?o0000oejQG_mNXEh02?mNXEh00ol0003o5NXE
oaGZ5@0:oaGZ5@03o`000?lOh1oo7n0O00Co7n0O0ol00005o`Ck1003o`000?m>/DkoC[5>00CoC[5>
1?l00006ofJIIP03o`000?mLXecoG:=L00KoG:=L0_l0000;of:MHP03o`000?lcc3?o<l`c00Wo<l`c
00?o0000oeVVFOmIYUT02_mIYUT01Ol0003oNXEjogZ5N_mjQG[o000000coV6NH0_l000000oo=</go
0000onDJi@05onDJi@03o`000?o`3o3ol0o`00?ol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oG:=OoebSG00SoebSG00?o0000oimPWonOH9l01_nOH9l00ol0003oGZ5NoejQGP07oejQGP03o`00
0?lEjQGo5NXE00_o5NXE00?o0000oaoP7olOh1l00_lOh1l2o`0000Wo1?/400?o0000odjaC_m>/Dh0
0ol0000;ofJIIP03o`000?mLXecoG:=L00;oG:=L0ol0000>of:MHP03o`000?lcc3?o<l`c00Oo<l`c
00?o0000oeVVFOmIYUT02omIYUT00ol0003oNXEjogZ5NP02ogZ5NP03o`000?nHIiSoV6NH00_oV6NH
00?o0000onDJiOoU6^D01_oU6^D2o`0000?ol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oG
:=OoebSG00OoebSG00?o0000oimPWonOH9l01onOH9l00ol0003oGZ5NoejQGP05oejQGP?o00003OlE
jQD4o`0000_o1?/40ol0000?ofJIIP04o`000?mLXeco0000o`00017oHYeR00?o0000oc?<<olcc3<0
1olcc3<00ol0003oFJIIoeVVF@0:oeVVF@03o`000?mjQG[oNXEj00CoNXEj00?o0000oiQWV?nHIiP0
1onHIiP3o`0000_oiA[U1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omLXeooG:=L02?oG:=L00ol0003oWf2OoimP
W`06oimPW`03o`000?mNXEkoGZ5N00;oGZ5N0ol00003od2o@003o`000?lEjQGo5NXE00[o5NXE00?o
0000o`Ck1?l4n`@02ol4n`@00ol0003o3O8=o`00000AofJIIP03o`000?mRWF;oHYeR017oHYeR00?o
0000oc?<<olcc3<01olcc3<00ol0003oFJIIoeVVF@0:oeVVF@03o`000?mjQG[oNXEj00GoNXEj00Co
0000oiQWV?nHIiSoV6NH1Ol00002ojQGZ003o`000?oU6^GoiA[U00WoiA[U00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000omLXeooG:=L01ooG:=L00ol0003oWf2OoimPW`05oimPW`?o0000
00?oGZ5No`000?l000001om0_d000ol0003o5NXEoaGZ5@08oaGZ5@?o00002_l4n`@2o`0000;o3O8=
00?o0000ofJII_mVVFH03omVVFH00ol0003oHYeRof:MHP0Aof:MHP03o`000?lcc3?o<l`c00Oo<l`c
00?o0000oeVVFOmIYUT02OmIYUT00ol0003oNXEjogZ5NP07ogZ5NP?o00001onXEjP00ol0003oiA[U
onDJi@09onDJi@03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000omLXeooG:=L01ooG
:=L4o`0000;oWf2O0_l00003oi]TV`03o`000?m0_d3o@;m000So@;m00_l00006oaGZ5@;o00000olI
iQT00ol0003o1?/4o`Ck1006o`Ck1003o`000?l=lPgo3O8=00?o3O8=00?o0000ofJII_mVVFH03_mV
VFH00ol0003oHYeRof:MHP0Bof:MHP03o`000?lcc3?o<l`c00Go<l`c00?o0000oeVVFOmIYUT02OmI
YUT00ol0003oNXEjogZ5NP08ogZ5NP03o`000?nXEjSoZ5NX00OoZ5NX00?o0000onDJiOoU6^D02?oU
6^D00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oG:=OoebSG00CoebSG0_l00004
omdRg@;o00001OnKI9/00ol0003o@;m0od2o@00:od2o@003o`000?lEjQGo5NXE00;o5NXE00?o0000
oaWV6OlIiQT01?lIiQT00ol0003o1?/4o`Ck1004o`Ck1003o`000?l=lPgo3O8=00Co3O8=00?o0000
ofJII_mVVFH03_mVVFH00ol0003oHYeRof:MHP0Bof:MHP[o00002_mIYUT00ol0003oNXEjogZ5NP08
ogZ5NP03o`000?nXEjSoZ5NX00OoZ5NX00?o0000onDJiOoU6^D02?oU6^D00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003oebSGomLXeooG:=L2o`0000OogB;M00?o0000oi]TVonKI9/01?nKI9/0
0ol0003o@;m0od2o@00:od2o@004o`000?lEjQGo0000o`0000So6NHI00Co0000o`Ck1?l4n`Co1?/4
0_l00007o`gb3@03o`000?mVVFKoIYUV00koIYUV00?o0000of:MH_mRWF804_mRWF800ol0003oB;M8
odRgB007odRgB003o`000?mIYUWoFJII00KoFJII00?o0000ogZ5N_mjQGX02_mjQGX00ol0003oZ5NX
ojQGZ006ojQGZ003o`000?oU6^GoiA[U00SoiA[U00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oG
:=Oo0000o`0000WogB;M00?o0000oi]TVonKI9/01?nKI9/00ol0003o@;m0od2o@00;od2o@003o`00
0?lIiQWo6NHI00Wo6NHI00?o0000o`Ck1?l000002Ol=lPd00ol0003oIYUVofJIIP0>ofJIIP;o0000
4_mRWF800ol0003oB;M8odRgB009odRgB0;o00001_mIYUT00ol0003oNXEjogZ5NP0:ogZ5NP03o`00
0?nXEjSoZ5NX00KoZ5NX00?o0000onDJiOoU6^D02?oU6^D00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omdRgOoM8]d02OoM8]d00ol0003oVfBKoi]TV`05oi]TV`03o`000?m0_d3o@;m000[o@;m000?o
0000oaWV6OlIiQT02_lIiQT2o`0000Wo3O8=00?o0000ofJII_mVVFH03_mVVFH00ol0003oCK9=o`00
0002o`0000ooHYeR00?o0000odRgB?m8]dP02om8]dP00ol0003oFJIIoeVVF@03o`0000goNXEj00?o
0000ojQGZ?nXEjP01_nXEjP00ol0003oiA[UonDJi@07onDJi@03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ogB;MomdRg@09omdRg@03o`000?nKI9_oVfBK00GoVfBK00?o0000od2o@?m0_d002Om0_d02
o`0000_o6NHI0_l0000;o`gb3@03o`000?mVVFKoIYUV00coIYUV00?o0000odfbCOm=/Td00om=/Td3
o`0000coHYeR00?o0000odRgB?m8]dP03?m8]dP2o`0000;oJ9MX00?o0000ogZ5N_mjQGX03?mjQGX0
0ol0003oZ5NXojQGZ005ojQGZ003o`000?oU6^GoiA[U00OoiA[U00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oM8]gogB;M00[ogB;M00?o0000oi]TVonKI9/01_nKI9/00ol0003o@;m0od2o@007od2o
@003o`000?lhacSo000000[o6NHI00Co0000o`[e2_l:m@[o00002_l=lPd00ol0003oIYUVofJIIP0<
ofJIIP03o`000?m=/TgoCK9=00KoCK9=0_l00008of:MHP;o00003om8]dP00ol0003oJ9MXofRGJ002
ofRGJ003o`000?mjQG[oNXEj00_oNXEj00?o0000ojQGZ?nXEjP01OnXEjP00ol0003oiA[UonDJi@07
onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ogB;MomdRg@0:omdRg@03o`000?nKI9_oVfBK
00KoVfBK00?o0000od2o@?m0_d001_m0_d001Ol0003o><LhocS7>?lhacSo000000So6NHI00?o0000
o`[e2_l:m@X00_l:m@X00ol0003o3O8=o`gb3@06o`gb3@Co00003?mVVFH00ol0003oCK9=odfbC@08
odfbC@?o00000_mRWF83o`000003od2o@?l0003oB;M800goB;M800?o0000ofRGJ?mXUfP01?mXUfP0
0ol0003oNXEjogZ5NP0:ogZ5NP03o`000?nXEjSoZ5NX00GoZ5NX00?o0000onDJiOoU6^D01_oU6^D0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omdRgOoM8]d02ooM8]d00ol0003oVfBKoi]TV`07oi]T
V`03o`000?m0_d3o@;m000?o@;m00_l00005ocS7>003o`000?lIiQWo6NHI00Co6NHI00?o0000o`[e
2_l:m@X00ol:m@X00ol0003o3O8=o`gb3@05o`gb3@03o`000?lYeRWo:MHY00;o:MHY0ol00007ofJI
IP;o00003_m=/Td2o`0000Go@;m000?o0000odRgB?m8]dP02_m8]dP00ol0003oJ9MXofRGJ005ofRG
J003o`000?mjQG[oNXEj00_oNXEj00?o0000ojQGZ?nXEjP01?nXEjP00ol0003oiA[UonDJi@06onDJ
i@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ogB;MomdRg@0;omdRg@03o`000?nKI9_oVfBK00Oo
VfBK00?o0000od2o@?m0_d000_m0_d000ol0003o><LhocS7>006ocS7>003o`000?lIiQWo6NHI00;o
6NHI00?o0000o`[e2_l:m@X01Ol:m@X00ol0003o3O8=o`gb3@02o`gb3@;o00002?lYeRT3o`0000;o
IYUV0_l000000olcc3?o0000odfbC@0=odfbC@03o`000?m0_d3o@;m000Go@;m000?o0000odRgB?m8
]dP02?m8]dP00ol0003oJ9MXofRGJ007ofRGJ003o`000?mjQG[oNXEj00[oNXEj00?o0000ojQGZ?nX
EjP01?nXEjP00ol0003oiA[UonDJi@06onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ogB;M
omdRg@0<omdRg@03o`000?nKI9_oVfBK00SoVfBK00Co0000od2o@?m0_d3o00002OlhacP01Ol0003o
6NHIoaWV6OlIiQWo000000So2_D:00Go0000o`gb3Ol=lPgo3O8=o`00000=obWF:@;o00001?lcc3<0
0ol0003oCK9=odfbC@0;odfbC@03o`000?m0_d3o@;m000Ko@;m000?o0000odRgB?m8]dP01om8]dP0
0ol0003oJ9MXofRGJ008ofRGJ0Co00002?mjQGX00ol0003oZ5NXojQGZ004ojQGZ003o`000?oU6^Go
iA[U00KoiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oM8]gogB;M00_ogB;M0ol00009oi]T
V`03o`000?m0_d3o000000_o><Lh00?o0000oaWV6Ol000002_l:m@X00ol0003o3O8=o`00000?obWF
:@03o`000?lcc3?o<l`c00;o<l`c00?o0000odfbCOm=/Td02om=/Td00ol0003o@;m0od2o@006od2o
@003o`000?m8]dSoB;M800KoB;M800?o0000ofRGJ?mXUfP02OmXUfP01?l0003oVFJIoiUVVOnIIYT7
o`0000;oNXEj00?o0000ojQGZ?nXEjP00onXEjP00ol0003oiA[UonDJi@05onDJi@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oM8]gogB;M00SogB;M0ol00003om8]dP03o`000?nKI9_oVfBK00OoVfBK00?o0000ocS7
>?lhacP02olhacP00ol0003o2_D:o`[e2P0:o`[e2P03o`000?lYeRWo:MHY00go:MHY00?o0000oc?<
<olcc3<01?lcc3<00ol0003oCK9=odfbC@09odfbC@03o`000?m0_d3o@;m000So@;m000?o0000odRg
B?m8]dP00om8]dP2o`0000coJ9MX00?o0000oiUVVOnIIYT02?nIIYT<o`0000?oiA[U0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omdRgOoM8]d01_oM8]d3o`0000OodRgB00?o0000oi]TVonKI9/01_nKI9/00ol0003o
><LhocS7>00;ocS7>003o`000?l:m@[o2_D:00Wo2_D:0_l0000>obWF:@03o`000?lcc3?o<l`c00Go
<l`c00?o0000odfbCOm=/Td02Om=/Td00ol0003o@;m0od2o@009od2o@003o`000?m8]dSo000000;o
00000_mOX5l00ol0003oJ9MXofRGJ008ofRGJ003o`000?nIIYWoVFJI00coVFJI00?o0000on4NhOoQ
7^401_oQ7^43o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ogB;MomdRg@03omdRg@?o00002ooB;M800ol0003oVfBK
oi]TV`04oi]TV`03o`000?lhacSo><Lh00_o><Lh0ol00007o`[e2P?o000000?o8MhQo`000?lYeRT0
3OlYeRT00ol0003o<l`coc?<<`06oc?<<`03o`000?m=/TgoCK9=00SoCK9=00?o0000od2o@?m0_d00
2_m0_d000ol0003oGj1OoenPG`04oenPG`03o`000?mXUfSoJ9MX00OoJ9MX00?o0000oiUVVOnIIYT0
2onIIYT00ol0003ohAkQon4Nh@08on4Nh@03o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omdRgOl0
003o0000o`0000oodRgB00?o0000oi]TVonKI9/00onKI9/>o`0000?o;M8]0_l00002o`[e2P?o0000
1OlQgR400ol0003o:MHYobWF:@0:obWF:@03o`000?lcc3?o<l`c00Oo<l`c00?o0000odfbCOm=/Td0
2?m=/Td00ol0003o@;m0od2o@00:od2o@003o`000?mOX5ooGj1O00GoGj1O00?o0000ofRGJ?mXUfP0
1_mXUfP00ol0003oVFJIoiUVV@0;oiUVV@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;odRgB00?o0000oi]TVonKI9/00_nKI9/00ol0003oJYEZofZE
JP0:ofZEJP03o`000?l]dRgo;M8]00?o;M8]0_l00009ob7N8@03o`000?lYeRWo:MHY00Wo:MHY00?o
0000oc?<<olcc3<02?lcc3<2o`0000SoCK9=00?o0000od2o@?m0_d002Om0_d000ol0003oGj1OoenP
G`07oenPG`03o`000?mXUfSoJ9MX00CoJ9MX00?o0000oiUVVOnIIYT02onIIYT00ol0003ohAkQon4N
h@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003odRgBom8]dP0?om8]dP?o000000?oVfBK
o`000?mZUFX02omZUFX00ol0003o;M8]obgB;@04obgB;@03o`000?lQgR7o8MhQ00Wo8MhQ00?o0000
obWF:OlYeRT01olYeRT00ol0003o<l`coc?<<`09oc?<<`04o`000?l`cc3o0000o`0000KoCK9=00?o
0000od2o@?m0_d002Om0_d000ol0003oGj1OoenPG`08oenPG`03o`000?mXUfSoJ9MX00?oJ9MX00?o
0000oiUVVOnIIYT02onIIYT00ol0003ohAkQon4Nh@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003odRgBom8]dP0<om8]dP;o00000oo=</d2o`0000coJYEZ00?o0000obgB;Ol]dRd01?l]dRd0
0ol0003o8MhQob7N8@0:ob7N8@Wo00002olcc3<00ol0003o<<l`oc3?<002oc3?<0?o00000_m=/Td0
0ol0003o@;m0od2o@00:od2o@003o`000?mOX5ooGj1O00WoGj1O00?o0000ofRGJ?mXUfP00_mXUfP0
0ol0003oVFJIoiUVV@0:oiUVV@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oB;M82o`0000GocC;=00?o0000oiEZUOl000002_mZUFX00ol0003o;M8]obgB;@06obgB
;@03o`000?lQgR7o8MhQ00Wo8MhQ00?o0000oagR7OlMhQd01OlMhQd00ol0003o<l`coc?<<`09oc?<
<`03o`000?l`cc3o<<l`00Go<<l`0ol00009od2o@0?o00003OmOX5l01Ol0003oJ9MXofRGJ?mXUfSo
000000coVFJI00?o0000on4NhOoQ7^402OoQ7^400ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om8]
d_oB;M801OoB;M82o`0000OocC;=00Co0000oiEZUOnEJYGo00002OmZUFX00ol0003o;M8]obgB;@06
obgB;@03o`000?lQgR7o8MhQ00So8MhQ00?o0000oagR7OlMhQd01olMhQd00ol0003o<l`coc?<<`07
oc?<<`03o`000?l`cc3o<<l`00So<<l`0ol00002od2o@0Go00000_ldbc@00ol0003oGj1OoenPG`0<
oenPG`03o`000?mXUfSo000000coVFJI00?o0000on4NhOoQ7^402_oQ7^400ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000om8]d_oB;M800_oB;M82o`0000SocC;=00?o0000oiEZUOnEJYD00_nEJYD5o`00
00CoJYEZ00?o0000obgB;Ol]dRd01_l]dRd00ol0003o8MhQob7N8@08ob7N8@03o`000?lMhQgo7N8M
00Oo7N8M00?o0000oc?<<olcc3<01olcc3<00ol0003o<<l`oc3?<008oc3?<003o`000?lKi1_o6n@K
00;o00002?ldbc@00ol0003oGj1OoenPG`0<oenPG`Co00002_nIIYT00ol0003ohAkQon4Nh@0:on4N
h@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003odRgBo`000?l0000:oldbc@03o`000?nEJYGoUFZE
00;oUFZE00?o0000ocg2?Olm`Sd00_lm`Sd4o`0000Wo;M8]00?o0000ob7N8OlQgR402?lQgR400ol0
003o7N8MoagR7@08oagR7@03o`000?lcc3?o<l`c00Go<l`c00?o0000oc3?<?l`cc002?l`cc001Ol0
003o6n@Koa_T6olKi1_o000000[o=</d0ol0000;oenPG`04o`000?o<<lcoc3?<ol`cc0Co00001OnI
IYT00ol0003ohAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ocC;=oldbc@0:
oldbc@03o`000?nEJYGoUFZE00?oUFZE00?o0000ocg2?Olm`Sd01?lm`Sd00ol0003o;M8]obgB;@07
obgB;@03o`000?lQgR7o8MhQ00Ko8MhQ0_l0000;oagR7@03o`000?lcc3?o<l`c00Go<l`c00?o0000
oc3?<?l`cc002?l`cc000ol0003o6n@Koa_T6`02oa_T6`03o`000?ldbcCo=</d00Oo=</d00?o0000
ohEjQOn5NXD01?l00006oenPG`03o`000?o<<lcoc3?<00Koc3?<0ol00002oiUVV@03o`000?oQ7^7o
hAkQ00_ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o=</gocC;=00WocC;=00?o0000oiEZ
UOnEJYD01?nEJYD00ol0003o?L8mocg2?@05ocg2?@03o`000?l]dRgo;M8]00Oo;M8]00?o0000ob7N
8OlQgR400_lQgR43o`000003obkA;_l0003o7N8M00[o7N8M00?o0000oc?<<olcc3<01Olcc3<00ol0
003o<<l`oc3?<007oc3?<003o`000?lKi1_o6n@K00?o6n@K00?o0000ocC;=?ldbc@01oldbc@00ol0
003oQGZ5ohEjQ@04ohEjQ@?o00000_mOX5l00ol0003oc3?<ol`cc00:ol`cc0;o00003_oQ7^400ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000oldbcOo=</d02Oo=</d00ol0003oUFZEoiEZU@04oiEZU@03
o`000?lm`Sgo?L8m00Ko?L8m0_l00007obgB;@03o`000?lQgR7o000000;o00001Ol^dBh00ol0003o
7N8MoagR7@08oagR7@?o00001?lcc3<00ol0003o<<l`oc3?<008oc3?<003o`000?lKi1_o6n@K00Co
6n@K00?o0000ocC;=?ldbc@01_ldbc@00ol0003oQGZ5ohEjQ@07ohEjQ@;o00003_o<<l`00ol0003o
hAkQon4Nh@0;on4Nh@03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ocC;=oldbc@08oldbc@03o`00
0?nEJYGoUFZE00GoUFZE00?o0000ocg2?Olm`Sd01?lm`Sd00ol0003oC;=<odbcC003o`0000Co;M8]
0_l00008obkA;P03o`000?lMhQgo7N8M00Oo7N8M00Co0000oe6^DOmA[U7oDJiA0ol000000olcc3?o
0000oc3?<009oc3?<003o`000?lKi1_o6n@K00Co6n@K00?o0000ocC;=?ldbc@01Oldbc@00ol0003o
QGZ5ohEjQ@09ohEjQ@03o`000?o<<lcoc3?<00goc3?<00?o0000on4NhOoQ7^402_oQ7^400ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000oldbcOo=</d01oo=</d00ol0003oUFZEoiEZU@06oiEZU@03o`00
0?lm`Sgo?L8m00?o?L8m00?o0000odbcC?m</d`01?m</d`2o`000003obgB;Ol0003o;]4^00[o;]4^
00?o0000oagR7OlMhQd01OlMhQd00ol0003oDJiAoe6^D@05oe6^D@03o`000?l`cc3o<<l`00Oo<<l`
0ol00007oa_T6`03o`000?ldbcCo=</d00Co=</d00?o0000ohEjQOn5NXD02On5NXD00ol0003oc3?<
ol`cc00=ol`cc003o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o=
</gocC;=00GocC;=0ol00009oiEZU@05o`000?lm`Sgo?L8mocg2?Ol000002Om</d`00ol0003o;]4^
obkA;P0;obkA;P03o`000?lMhQgo7N8M00?o7N8M00?o0000oe6^DOmA[U401_mA[U400ol0003o<<l`
oc3?<006oc3?<005o`000?lm`Sgo?L8mocg2?Ol000001olKi1/00ol0003o=</docC;=003ocC;=003
o`000?n5NXGoQGZ500WoQGZ500?o0000ol`cc?o<<l`03_o<<l`00ol0003ohAkQon4Nh@09on4Nh@03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ocC;=o`000004o`0000;oh1oP00?o0000oiEZUOnEJYD0
1onEJYD01?l0003o?L8mocg2?Ol00009odbcC0;o00003Ol^dBh00ol0003o7N8MoagR7@02oagR7@03
o`000?mA[U7oDJiA00SoDJiA00?o0000oc3?<?l`cc000ol`cc02o`0000Go?L8m00?o0000oa_T6olK
i1/01?lKi1/00ol0003o=</docC;=003ocC;=003o`000?n5NXGoQGZ500WoQGZ500?o0000ol`cc?o<
<l`03_o<<l`00ol0003ohAkQon4Nh@09on4Nh@03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000Soh1oP
00?o0000oiEZUOnEJYD01_nEJYD00ol0003o?L8mo`000009odbcC004o`000?mA[U7oDJiAo`0000go
;]4^00Co0000oagR7OlMhQgo00003?mA[U401Ol0003o<<l`oc3?<?l`cc3o000000So?L8m0_l00005
oa_T6`03o`000?ldbcCo=</d00;o=</d00?o0000ohEjQOn5NXD02On5NXD00ol0003oc3?<ol`cc00>
ol`cc003o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oP7n3oh1oP
00Ooh1oP00?o0000oiEZUOnEJYD01onEJYD00ol0003oC;=<odbcC007odbcC003o`000?mA[U7oDJiA
00;oDJiA00?o0000obkA;_l^dBh02_l^dBh00ol0003o7N8Mo`00000>oe6^D@03o`000?l`cc3o0000
00_o?L8m00?o0000oa_T6olKi1/00_lKi1/01Ol0003o=</docC;=?ldbcCo000000coQGZ500?o0000
ol`cc?o<<l`03_o<<l`3o`0000WohAkQ00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oP7n3oh1oP
00Woh1oP00?o0000oiEZUOnEJYD01_nEJYD00ol0003oC;=<odbcC006odbcC003o`000?mA[U7oDJiA
00?oDJiA00?o0000obkA;_l^dBh02ol^dBh00ol0003oDJiAoe6^D@0>oe6^D@03o`000?lm`Sgo?L8m
00_o?L8m0_l00003oa_T6`04o`000?ldbcCo=</do`0000[oQGZ50ol0000>ol`cc0;o00000ook1?/2
o`0000OohAkQ00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oP7n3oh1oP00[oh1oP00?o0000oiEZ
UOnEJYD01?nEJYD00ol0003oC;=<odbcC006odbcC003o`000?mA[U7oDJiA00GoDJiA00?o0000obkA
;_l^dBh01ol^dBh3o`00017oDJiA00?o0000ocg2?Olm`Sd03Olm`Sd01Ol0003o6n@Koa_T6ol0003o
=</d00Co00000on5NXD5o`0000;oe2_D00?o0000ol`cc?o<<l`02_o<<l`2o`0000Oon`Ck0_l00004
on4Nh@03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oh1oPon0Oh00;on0Oh003o`000?nEJYGoUFZE
00CoUFZE00?o0000odbcC?m</d`01Om</d`00ol0003oDJiAoe6^D@06oe6^D@03o`000?l^dBko;]4^
00Co;]4^0ol00002oc[5>P03o`000?mA[U7oDJiA00ooDJiA0_l0000?ocg2?@04o`000?lKi1_o0000
o`0000CoL8m`0ol00008om@[e003o`000?o<<lcoc3?<00Ooc3?<0_l0000;oo/4n`;o00000_oQ7^40
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000on0Oh?oP7n003?oP7n06o`0000OoC;=<00?o0000oe6^
DOmA[U402?mA[U400ol0003o;]4^obkA;P03o`0000Ko>/Dj00?o0000oe6^DOmA[U403OmA[U401?l0
003oCk1?odn`Col0000?ocg2?@03o`000?m`Sg3oL8m`00GoL8m`00?o0000om@[e?oD:m@02?oD:m@0
0ol0003oc3?<ol`cc005ol`cc003o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oP7n000ol0003oWF:MoieRW@04oieR
W@03o`000?m</dcoC;=<00?oC;=<00?o0000oe6^DOmA[U402_mA[U42o`0000[o>/Dj00?o0000oe6^
DOmA[U402omA[U400ol0003oCk1?odn`C`02odn`C`03o`000?lm`Sgo?L8m00_o?L8m0_l00007og2?
L003o`000?oD:mCoe2_D00Woe2_D00?o0000ol`cc?o<<l`00_o<<l`2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000on0Oh?oP7n002ooP7n000ol0003oWF:MoieRW@06oieRW@05o`000?m</dcoC;=<odbc
C?l000003OmA[U400ol0003o>/Djoc[5>P0:oc[5>P03o`000?mA[U7oDJiA00WoDJiA00?o0000odn`
Com?/4l01?m?/4l00ol0003o?L8mocg2?@08ocg2?@;o000000?o:]DZo`000?m`Sg001om`Sg000ol0
003oe2_Dom@[e009om@[e004o`000?o<<lco0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oP7n3oh1oP
00Woh1oP00?o0000oieRWOnMHYd02?nMHYd00ol0003oC;=<o`00000=oe6^D@03o`000?ljaC[o>/Dj
00_o>/Dj00?o0000oe6^DOmA[U402?mA[U400ol0003oCk1?odn`C`06odn`C`03o`000?lm`Sgo?L8m
00Go?L8m0_l00003ob[E:P03o`000?m`Sg3oL8m`00KoL8m`00?o0000om@[e?oD:m@02_oD:m@00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003oh1oPon0Oh007on0Oh003o`000?nMHYgoWF:M00[oWF:M00?o0000oe6^DOmA
[U403?mA[U400ol0003o>/Djoc[5>P0<oc[5>P03o`000?mA[U7oDJiA00KoDJiA00?o0000odn`Com?
/4l02?m?/4l00ol0003o?L8mocg2?@02ocg2?@;o00001_lZeBX00ol0003oL8m`og2?L005og2?L003
o`000?oD:mCoe2_D00[oe2_D00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oP7n3oh1oP00Goh1oP
00?o0000oieRWOnMHYd03?nMHYd2o`0000coDJiA00?o0000oc[5>_ljaCX03OljaCX00ol0003oDJiA
oe6^D@04oe6^D@03o`000?m?/4ooCk1?00[oCk1?00Co0000ocg2?Ol0003o00002?lZeBX00ol0003o
L8m`og2?L006og2?L003o`000?oD:mCoe2_D00Woe2_D00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oP7n000ol0003oWF:MoieRW@0=oieRW@03o`000?mJYE[o000000;o00002?mA[U400ol0003o>/Dj
oc[5>P0?oc[5>PKo00003_m?/4l00ol0003o:]DZob[E:P08ob[E:P03o`000?m`Sg3oL8m`00KoL8m`
00?o0000om@[e?oD:m@02OoD:m@00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000on8Mh_oR7N;ohQgR
0_l0000?oieRW@03o`000?mJYE[oFZEJ00?oFZEJ0ol00005oe6^D@;o00004?ljaCX01_l0003o9mPW
obOH9ol0003o4^dBo`0000koCk1?00?o0000ob[E:_lZeBX02OlZeBX00ol0003oL8m`og2?L005og2?
L003o`000?oD:mCoe2_D00Woe2_D00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000on8Mh_oR7N800ooR7N800ol0003o
WF:MoieRW@0=oieRW@03o`000?mJYE[oFZEJ00KoFZEJ0ol000001?mA[U7o0000ocG:=OlebSD3o`00
00co>/Dj00Go0000obOH9olWf2Oo9mPWo`000002oa;]4P03o`000?m?/4ooCk1?00_oCk1?00?o0000
ob[E:_lZeBX02OlZeBX00ol0003oL8m`og2?L006og2?L003o`000?oD:mCoe2_D00Soe2_D0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ohQgRon8MhP04on8MhPoo00003?mJYEX00ol0003o=LXeocG:=@04ocG:
=@?o00002?ljaCX00ol0003o9mPWobOH9`02obOH9`05o`000?lBkA;o4^dBoa;]4_l000003?m?/4l0
0ol0003o:]DZob[E:P09ob[E:P03o`000?m`Sg3oL8m`00GoL8m`3?l00002on`Ck0;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ohQgRon8MhP05on8MhP03o`000?nCK9?oTfbC00_oTfbC00?o0000oeZU
F_mJYEX02_mJYEX00ol0003o=LXeocG:=@07ocG:=@;o00001OljaCX00ol0003o9mPWobOH9`03obOH
9`03o`000?lBkA;o4^dB00;o4^dB00?o0000odn`Com?/4l02Om?/4l00ol0003o:]DZob[E:P0:ob[E
:P03o`000?m`Sg3oL8m`00?oL8m`00?o0000okI9]_nfBKH02OnfBKH00ol0003ok1?/on`Ck002on`C
k0;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ohQgRon8MhP06on8MhP03o`000?nCK9?oTfbC00[o
TfbC00?o0000oeZUF_mJYEX02omJYEX00ol0003o=LXeocG:=@09ocG:=@?o000000?o>/Djo`000?lW
f2L01OlWf2L00ol0003o4^dBoa;]4P03oa;]4P03o`000?m?/4ooCk1?00SoCk1?3_l00003og2?L0;o
00002onfBKH00ol0003ok1?/on`Ck005on`Ck003o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000on8Mh_oR7N801OoR7N800ol0003oYeRWo`00000;oi=/T`03o`000?mJYE[oFZEJ00[oFZEJ
0_l0000>ocG:=@03o`000?lWf2Oo9mPW00Go9mPW00?o0000oa;]4_lBkA800olBkA800ol0003oCk1?
odn`C`08odn`C`03o`000?m^TFkoKY5^00_oKY5^00?o0000og2?L?l000003OnfBKH00ol0003ok1?/
on`Ck006on`Ck0;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oR7N;ohQgR00KohQgR00Co
0000ojMHYonWF:Oo00002_nCK9<00ol0003oFZEJoeZUFP09oeZUFP03o`000?lo`3oo000000ko=LXe
00?o0000obOH9olWf2L01OlWf2L00ol0003o4^dBoa;]4P04oa;]4P03o`000?m?/4ooCk1?00KoCk1?
00?o0000ofjAK_m^TFh03Om^TFh00ol0003o]TVfokI9]P0<okI9]P03o`000?o/4ncok1?/00Sok1?/
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oR7N;ohQgR00GohQgR00?o0000ojMHYonWF:L00_nW
F:L00ol0003oTfbCoi=/T`06oi=/T`03o`000?mJYE[oFZEJ00SoFZEJ0_l00003oco0?`03o`000?le
bSGo=LXe00_o=LXe00?o0000obOH9olWf2L01OlWf2L00ol0003o4^dBoa;]4P05oa;]4P03o`000?m?
/4ooCk1?00GoCk1?00?o0000ofjAK_m^TFh03Om^TFh00ol0003o]TVfokI9]P0;okI9]P03o`000?o/
4ncok1?/00Wok1?/00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oR7N;ohQgR00KohQgR00?o0000
ojMHYonWF:L00onWF:L00ol0003oTfbCoi=/T`05oi=/T`03o`000?mJYE[oFZEJ00OoFZEJ00?o0000
oco0?olo`3l00olo`3l00ol0003o=LXeocG:=@0:ocG:=@03o`000?lWf2Oo9mPW00Ko9mPW00?o0000
oa;]4_lBkA801_lBkA800ol0003oCk1?odn`C`04odn`C`03o`000?m^TFkoKY5^00goKY5^3ol0000;
on`Ck003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oR7N;ohQgR00KohQgR00?o0000ojMHYonWF:L01OnWF:L00ol0
003oTfbCoi=/T`04oi=/T`03o`000?mJYE[oFZEJ00GoFZEJ0_l00006oco0?`03o`000?lebSGo=LXe
00Wo=LXe0_l00008obOH9`03o`000?lBkA;o4^dB00Ko4^dB1Ol000000om?/4oo0000ofjAKP0?ofjA
KP03o`000?nfBKKo]TVf00_o]TVf00?o0000on`Ck?o/4n`02Oo/4n`00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oR7N;ohQgR00KohQgR00?o0000ojMHYonWF:L01_nWF:L00ol0003o
TfbCoi=/T`04o`0000KoFZEJ00?o0000oco0?olo`3l01olo`3l00ol0003o=LXeocG:=@05ocG:=@?o
000000?o7^4No`000?lWf2L01olWf2L00ol0003o4^dBoa;]4P05oa;]4P03o`000?mEZUGoEJYE00?o
EJYE0_l0000?ofjAKP;o00003OnfBKH00ol0003ok1?/on`Ck008on`Ck003o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WohQgR00?o0000ojMHYonWF:L01onWF:L2o`0000CoSg2?00Co0000oeZUF_mJYE[o
FZEJ0_l0000:oco0?`03o`000?lebSGo=LXe00;o=LXe0ol00005oakQ7P03o`000?lWf2Oo9mPW00Go
9mPW00?o0000oa;]4_lBkA801?lBkA800ol0003oEJYEoeFZE@06oeFZE@03o`000?m^TFkoKY5^00[o
KY5^0_l00002oi=/T`03o`000?nfBKKo]TVf00[o]TVf00?o0000on`Ck?o/4n`02?o/4n`00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000on8Mh_oR7N801_oR7N800ol0003oYeRWojMHY`08ojMHY`03o`00
0?n?L8ooSg2?00CoSg2?00?o0000oeZUF_l000003?lo`3l00ol0003o=LXeo`000002o`0000Wo7^4N
00?o0000obOH9olWf2L01?lWf2L00ol0003o4^dBoa;]4P03oa;]4P03o`000?mEZUGoEJYE00SoEJYE
1_l00004ofjAKP;o00001OnCK9<00ol0003o]TVfokI9]P09okI9]P03o`000?o/4ncok1?/00Sok1?/
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oR7N;ohQgR00GohQgR00?o0000ojMHYonWF:L01onW
F:L00ol0003oSg2?ohm`S`06ohm`S`03o`000?lo`3oo?l0o00co?l0o00?o0000oakQ7_lNhAh02_lN
hAh00ol0003o9mPWobOH9`04obOH9`04o`000?lBkA;o4^dBoa;]4P;o00002omEZUD00ol0003oMhQg
ogN8M`03ogN8M`Co00002?nCK9<00ol0003o]TVfokI9]P08okI9]P03o`000?o/4ncok1?/00Ook1?/
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000on8Mh_oR7N800ooR7N800ol0003oYeRWojMHY`07ojMHY`03o`000?n?
L8ooSg2?00OoSg2?00?o0000oco0?olo`3l03?lo`3l00ol0003o7^4NoakQ7P0;oakQ7P03o`000?lW
f2Oo9mPW00?o9mPW00Co0000oa;]4_lBkA;o00003OmEZUD00ol0003oMhQgogN8M`06ogN8M`03o`00
0?nCK9?oTfbC00OoTfbC00?o0000okI9]_nfBKH01onfBKH00ol0003ok1?/on`Ck006on`Ck004o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oR7N;ohQgR00;ohQgR00?o0000ojMHYonWF:L0
1_nWF:L00ol0003oSg2?ohm`S`09ohm`S`03o`000?lo`3oo?l0o00Wo?l0o0_l0000>oakQ7P?o0000
0olWf2L00ol0003o4^dBo`00000=oeFZE@03o`000?mgR7OoMhQg00OoMhQg00?o0000oi=/TonCK9<0
2?nCK9<:o`0000Kok1?/0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoYeRW00?o
0000ohm`Son?L8l02_n?L8l00ol0003o?l0ooco0?`06oco0?`;o000000?o>LHio`000?lNhAh02olN
hAh2o`0000?oC[5>1Ol0000>oeFZE@03o`000?mgR7OoMhQg00OoMhQg00?o0000oi=/TonCK9<02?nC
K9<00ol0003obSG:olXebP06olXebP03o`000?o/4ncok1?/00?ok1?/00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003oeRWFomHYeP03omHYePCo00000_nWF:L00ol0003oSg2?ohm`S`0;
ohm`S`03o`000?lo`3oo?l0o00?o?l0o0ol00004ocW6>@03o`000?lNhAko7^4N00Oo7^4N0_l00008
odjaCP03o`000?mEZUGoEJYE00goEJYE00?o0000ogN8MomgR7L02?mgR7L00ol0003oTfbCoi=/T`07
oi=/T`03o`000?o:=L[obSG:00OobSG:0ol000000oo/4nco0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oF:MKoeRWF00OoeRWF0_l0000?ohm`S`03o`000?lo`3oo?l0o00;o00002?liaST00ol0
003o7^4NoakQ7P05oakQ7P03o`000?m>/DkoC[5>00SoC[5>00?o0000oeFZEOmEZUD03OmEZUD00ol0
003oMhQgogN8M`08ogN8M`03o`000?nCK9?oTfbC00KoTfbC00?o0000olXeb_o:=LX02?o:=LX01?l0
003okA;]ondBkOl0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003oeRWFomHYeP09omHY
eP03o`000?n?L8ooSg2?00koSg2?0_l0000;ocW6>@03o`000?lNhAko7^4N00;o7^4N0_l0000;odja
CP03o`000?mEZUGoEJYE00goEJYE00?o0000ogN8MomgR7L02?mgR7L00ol0003oTfbCoi=/T`06oi=/
T`03o`000?o:=L[obSG:00OobSG:00Go0000ondBkOo]4^gokA;]o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003oeRWFomHYeP0:omHYeP03o`000?n?L8ooSg2?00goSg2?0_l0000<ocW6>@04o`000?lNhAko0000
o`0000goC[5>00?o0000oeFZEOmEZUD03?mEZUD00ol0003oMhQgogN8M`09ogN8M`03o`000?nCK9?o
TfbC00KoTfbC00?o0000olXeb_o:=LX01_o:=LX00ol0003okA;]ondBk@03ondBk@03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003oeRWFomHYeP0:omHYeP03o`000?n?L8ooSg2?00coSg2?00Co0000odJi
A_m6^DKo00003?liaST00ol0003oC[5>odjaCP0>odjaCP03o`000?mEZUGoEJYE00SoEJYE1?l0000;
ogN8M`03o`000?nCK9?oTfbC00KoTfbC00?o0000olXeb_o:=LX01Oo:=LX00ol0003okA;]ondBk@04
ondBk@03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003oeRWFomHYeP0;omHYeP03o`000?n?L8ooSg2?
00_oSg2?00?o0000odJiA_m6^DH00_m6^DH00ol0003o>LHiocW6>@09ocW6>@03o`000?m>/DkoC[5>
00koC[5>00Co0000oeFZEOmEZUGoEJYE1ol00003oenOG`03o`000?mgR7OoMhQg00WoMhQg00?o0000
oi=/TonCK9<01_nCK9<00ol0003obSG:olXebP04olXebP03o`000?o]4^gokA;]00KokA;]00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oF:MKoeRWF00coeRWF00?o0000ohm`Son?L8l02_n?L8l00ol0
003oA[U6odJiAP03odJiAP03o`000?liaSWo>LHi00So>LHi00?o0000odjaC_m>/Dh03_m>/Dh4o`00
00_oGimO00?o0000ogN8MomgR7L02?mgR7L00ol0003oTfbCoi=/T`05oi=/T`03o`000?o:=L[obSG:
00GobSG:00?o0000ondBkOo]4^d01_o]4^d00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omHYe_oF
:MH03?oF:MH7o`0000GoSg2?00?o0000odJiA_m6^DH01Om6^DH00ol0003o>LHiocW6>@07ocW6>@03
o`000?m>/DkoC[5>00koC[5>00?o0000oenOGomOWel03OmOWel00ol0003oMhQgogN8M`08ogN8M`03
o`000?nCK9?oTfbC00CoTfbC00?o0000olXeb_o:=LX01?o:=LX00ol0003okA;]ondBk@07ondBk@03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003oeRWFomHYeP0=omHYeP03o`000?n/Djco[5>/00Co[5>/
1Ol00009odJiAP03o`000?liaSWo>LHi00Ko>LHi00?o0000odjaC_m>/Dh03_m>/Dh00ol0003oGimO
oenOG`0=oenOG`03o`000?mgR7OoMhQg00SoMhQg00Co0000oi=/TonCK9?oTfbC1Ol00004olXebP03
o`000?o]4^gokA;]00WokA;]1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=omHYeP03o`000?n/Djco[5>/00Wo[5>/
0_l00009odJiAP03o`000?liaSWo>LHi00Ko>LHi00?o0000odjaC_m>/Dh03?m>/Dh00ol0003oGimO
oenOG`0?oenOG`Ko00001?mgR7L4o`0000GocC;=0_l000000oo:=L[o0000ondBk@0;ondBk@04o`00
0?ol0ocoo0?loo`3o0Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oW6>OoiaSWonLHi`?o00002_oF:MH00ol0003o
[5>/ojaC[009ojaC[003o`000?mMXUgo000000;o00001om6^DH00ol0003o>LHiocW6>@05ocW6>@03
o`000?m>/DkoC[5>00SoC[5>1Ol0000AoenOG`03o`000?n6NHKoQWV600?oQWV61?l0000;oldbc@03
o`000?o]4^gokA;]00[okA;]00?o0000oo`3o?ol0o`02Ool0o`3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000onLHiooW6>L01OoW6>L2o`0000OoeRWF
00?o0000ojaC[?n/Dj`02_n/Dj`00ol0003oGJ9MoefRG@02oefRG@?o00001Om6^DH00ol0003o>LHi
ocW6>@04ocW6>@04o`000?m>/DkoC[5>odjaCPOo00001?m5^TD00ol0003oGimOoenOG`0>oenOG`03
o`000?n6NHKoQWV600OoQWV600?o0000oldbcOo=</d02Oo=</d00ol0003okA;]ondBk@09ondBk@03
o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003oiaSWonLHi`08onLHi`;o00001?oF:MH00ol0003o[5>/
ojaC[00;ojaC[003o`000?mMXUgoGJ9M00GoGJ9M0ol00003odJiAP04o`000?liaSWo>LHiocW6>@Ko
00003?m5^TD00ol0003oGimOoenOG`0=oenOG`03o`000?n6NHKoQWV600OoQWV600?o0000oldbcOo=
</d02_o=</d00ol0003okA;]ondBk@08ondBk@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onLHi`?o000000?oeRWFo`000?n/Dj`0
3?n/Dj`00ol0003oGJ9MoefRG@08oefRG@?o000000CoA[U6o`000?l0003o00000_n0Oh000ol0003o
AKY5odFjA@0=odFjA@03o`000?mOWeooGimO00coGimO00?o0000ohIiQ_n6NHH02?n6NHH00ol0003o
cC;=oldbc@0;oldbc@03o`000?o]4^gokA;]00KokA;]00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
iaSW00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oGJ9MoefRG@0;oefRG@03o`000?n0Oh3oP7n000?o
P7n000?o0000odFjAOm5^TD03?m5^TD00ol0003o=LXeo`00000=oenOG`03o`000?n6NHKoQWV600So
QWV600?o0000oldbcOo=</d03?o=</d3o`0000GokA;]00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oW6>OoiaSW00coiaSW00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oGJ9MoefRG@0:oefRG@03o`00
0?n0Oh3oP7n000GoP7n000?o0000odFjAOm5^TD02_m5^TD01?l0003o=LXeocG:=OlebSD2o`0000[o
GimO00?o0000ohIiQ_n6NHH02On6NHH00ol0003ocC;=oldbc@0<oldbc@03o`000?o`3o3ol0o`00?o
000000?okA;]o`000?ol0o`03ool0o`00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000ojaC[?n/Dj`0
3?n/Dj`00ol0003oGJ9MoefRG@09oefRG@03o`000?n0Oh3oP7n000KoP7n000?o0000odFjAOm5^TD0
2Om5^TD00ol0003o=LXeocG:=@02ocG:=@03o`000?mnPGko000000;o00001omOWel00ol0003oQWV6
ohIiQP09ohIiQP03o`000?o=</gocC;=00_ocC;=00?o0000oo0?l?o`3o001?o`3o000ol0003oo0?l
oo`3o00?oo`3o003o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onLHiooW6>L02ooW6>L00ol0003o[5>/ojaC[00;ojaC[003o`000?mM
XUgoGJ9M00SoGJ9M00?o0000oh1oP?n0Oh001on0Oh000ol0003oAKY5odFjA@08odFjA@03o`000?le
bSGo=LXe00?o=LXe00?o0000ogj1O_mnPGh00_mnPGh2o`0000CoGimO00?o0000ohIiQ_n6NHH02_n6
NHH00ol0003ocC;=oldbc@0:oldbc@03o`000?o`3o3ol0o`00Gol0o`00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oW6>OoiaSW00[oiaSW0ol0000;ojaC[0Ko00001?mMXUd00ol0003oP7n0oh1oP008
oh1oP003o`000?m5^TGoAKY500OoAKY500?o0000ocG:=OlebSD00olebSD00ol0003oOX5nogj1OP05
ogj1OP?o000000?oGimOo`000?n6NHH02on6NHH00ol0003ocC;=oldbc@09oldbc@03o`000?o`3o3o
l0o`00Ool0o`00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oW6>OoiaSW00WoiaSW00?o0000olHi
a_o6>LH01?l00006ojaC[003o`000?nVFJKoYUVV00CoYUVV1?l0000<oh1oP003o`000?m5^TGoAKY5
00GoAKY500?o0000ocG:=OlebSD01?lebSD00ol0003oOX5nogj1OP08ogj1OP03o`000?n6NHKoQWV6
00_oQWV600?o0000oldbcOo=</d02?o=</d00ol0003ol0o`oo0?l008oo0?l0Go00002_ol0o`00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oW6>OoiaSW00OoiaSW00?o0000olHia_o6>LH01Oo6>LH3o`0000;o[5>/00?o0000ojIIY_nV
FJH02?nVFJH00ol0003oP7n0oh1oP00:oh1oP003o`000?m5^TGoAKY500CoAKY500?o0000ocG:=Ole
bSD01OlebSD00ol0003oOX5nogj1OP08ogj1OP03o`000?n6NHKoQWV600WoQWV61?l00008oldbc@03
o`000?o`3o3ol0o`00Wol0o`00?o0000oo`3o?ol0o`00_ol0o`7o`0000?oo0?l00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSW
onLHi`05onLHi`03o`000?o6>LKoaSW600WoaSW60_l0000<ojIIYP03o`000?n0Oh3oP7n000WoP7n0
00?o0000odFjAOm5^TD00om5^TD00ol0003o=LXeocG:=@05ocG:=@03o`000?mnPGkoOX5n00[oOX5n
00?o0000ohIiQ_n6NHH01?n6NHH4o`0000Co`3o000?o0000oldbcOo=</d01?o=</d00ol0003ol0o`
oo0?l00:oo0?l003o`000?ol0ocoo0?l00Woo0?l0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oW6>OoiaSW00?oiaSW00?o0000olHia_o6>LH02oo6
>LH00ol0003oYUVVojIIYP0:ojIIYP03o`000?n0Oh3oP7n000WoP7n000?o0000odFjAOm5^TD00_m5
^TD00ol0003o=LXeocG:=@06ocG:=@03o`000?mnPGkoOX5n00[oOX5n00?o0000ohIiQ_n6NHH01?l0
0009ol0o`0Ko00003?o`3o000ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onLHiooW6>OoiaSW0_l0
000=olHiaP03o`000?nVFJKoYUVV00[oYUVV00?o0000oh1oP?n0Oh002On0Oh001Ol0003oAKY5odFj
AOm5^TGo000000Wo=LXe00?o0000ogj1O_mnPGh02omnPGh2o`0000go`3o000?o0000on/Djoo[5>/0
0_o[5>/00ol0003ol0o`oo0?l00:oo0?l003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiaSWo`00
0002onl@k`;o00002oo6>LH00ol0003oYUVVojIIYP0;ojIIYP03o`000?n0Oh3oP7n000WoP7n000?o
0000odFjAOl000002OlebSD00ol0003oOX5nogj1OP0<ogj1OP03o`000?o0?l3o`3o000co`3o000?o
0000on/Djoo[5>/00oo[5>/00ol0003ol0o`oo0?l009oo0?l003o`000?ol0ocoo0?l00goo0?l00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003oka3_onl@k`03onl@k`;o00002_o6>LH00ol0003oYUVVojIIYP0:ojIIYP03o`000?n0Oh3o
P7n000SoP7n01Ol00008ocG:=@03o`000?mnPGkoOX5n00coOX5n00?o0000ol0o`?o0?l002oo0?l00
0ol0003ojaC[on/Dj`05on/Dj`03o`000?o`3o3ol0o`00Sol0o`00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oo_4>l2o`0000SoaSW600?o0000ojIIY_nVFJH02_nVFJH00ol0003oP7n0oh1oP007oh1o
P003o`000?meRWGoMHYe00?oMHYe0ol00005ocG:=@03o`000?mnPGkoOX5n00_oOX5n00?o0000ol0o
`?o0?l003?o0?l000ol0003ojaC[on/Dj`06on/Dj`03o`000?o`3o3ol0o`00Ool0o`00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?ol0oco000000Woka3_00?o0000olHia_o6>LH01Oo6>LH2o`0000co
YUVV00?o0000oh1oP?n0Oh001On0Oh000ol0003oMHYeogF:M@07ogF:M@?o000000?o=LXeo`000?mn
PGh03OmnPGh00ol0003o`3o0ol0o`00<ol0o`003o`000?o[5>_ojaC[00KojaC[00?o0000oo0?l?o`
3o001_o`3o000ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003oo`3o003o`000?o_4>ooka3_00Ooka3_
0_l00004olHiaP03o`000?oB;M;odRgB00;o00002_nVFJH00ol0003oP7n0oh1oP003oh1oP0;o0000
3OmeRWD2o`0000goOX5n0ol0000=ol0o`003o`000?o[5>_ojaC[00OojaC[00?o0000oo0?l?o`3o00
1Oo`3o000ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo0?loo`3o004oo`3o003o`000?o_4>ooka3_00Soka3_0_l0
00000oo6>LKo0000om8]dP04om8]dP03o`000?nVFJKoYUVV00OoYUVV00Co0000oh1oP?n0Oh3oP7n0
0_l00002oj=LX`03o`000?meRWGoMHYe00coMHYe3Ol00003ok1?/003o`000?o0?l3o`3o000[o`3o0
00?o0000on/Djoo[5>/02?o[5>/01?l0003ol0o`oo0?l?o`3o04o`0000koo0?l00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?ol0o`00ol0003oka3_
onl@k`09onl@k`03o`000?oB;M;odRgB00GodRgB0_l00008ojIIYP03o`000?n0Oh3o000000GoXebS
00?o0000ogF:MOmeRWD02omeRWD00ol0003oPGj1oh5nP@09oh5nP@03o`000?n`Ck3o/4n`00;o/4n`
0_l00009ol0o`003o`000?o[5>_ojaC[00[ojaC[0ol00004oo`3o003o`000?ol0ocoo0?l00[oo0?l
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000oo`3
o00:oo`3o003o`000?o_4>ooka3_00Soka3_00?o0000om8]d_oB;M801ooB;M84o`0000?oYUVV0ol0
0007oj=LX`03o`000?meRWGoMHYe00[oMHYe00?o0000oh5nPOn1OX402On1OX400ol0003o/4n`ok1?
/004ok1?/0;o00001oo0?l000ol0003ojaC[on/Dj`0:on/Dj`03o`000?ol0ocoo0?l00Goo0?l00?o
0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo0?loo`3o00:oo`3o003o`000?o_4>ooka3_00Ooka3_00?o0000om8]d_oB;M802?oB;M80
1?l0003odBkAom4^dOoA;]43o`0000;o_d2o00?o0000oj=LXonSG:<01_nSG:<00ol0003oMHYeogF:
M@08ogF:M@03o`000?n1OX7oPGj100[oPGj100?o0000ok1?/?n`Ck001_n`Ck000ol0003o`3o0ol0o
`004ol0o`003o`000?o[5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3
o007oo`3o003o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?ol0oco
o0?l00_oo0?l00?o0000onl@koo_4>l01Oo_4>l00ol0003odRgBom8]dP08om8]dP03o`000?oA;]7o
dBkA00CodBkA00Go0000okm0_ono@;oo_d2oo`000008oj=LX`03o`000?meRWGoMHYe00OoMHYe00?o
0000oh5nPOn1OX402_n1OX400ol0003o/4n`ok1?/007ok1?/0;o00001?o0?l000ol0003ojaC[on/D
j`08on/Dj`03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`01?ol0o`2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@koo_4>l00oo_4>l0
0ol0003odRgBom8]dP08om8]dP03o`000?oA;]7odBkA00CodBkA00?o0000okm0_ono@;l00_no@;l0
0ol0003oXebSoj=LX`07oj=LX`03o`000?meRWGoMHYe00KoMHYe00?o0000oh5nPOn1OX402_n1OX40
0ol0003o/4n`ok1?/009ok1?/005o`000?o0?l3o`3o0ol0o`?l000002Oo[5>/00ol0003oo0?loo`3
o00;oo`3o003o`000?ol0ocoo0?l00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
oo`3o?ol0o`03Ool0o`5o`0000_odRgB00?o0000om4^dOoA;]401?oA;]400ol0003o_d2ookm0_`03
okm0_`03o`000?nSG:?oXebS00OoXebS00?o0000ogF:MOmeRWD01OmeRWD00ol0003oPGj1oh5nP@0:
oh5nP@03o`000?n`Ck3o/4n`00Wo/4n`1?l00009on/Dj`03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo0?loo`3o00<oo`3o005o`000?ob3O;olPgb
oo8=l_l000002_oB;M800ol0003odBkAom4^d@05om4^d@03o`000?no@;oo_d2o00?o_d2o00?o0000
oj=LXonSG:<02?nSG:<00ol0003oMHYeogF:M@04ogF:M@03o`000?n1OX7oPGj100WoPGj100?o0000
ok1?/?n`Ck002?n`Ck02o`0000?ojaC[00?o0000on/Djoo[5>/01_o[5>/00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000oo8=l_ob3O800oob3O800ol0003odRgBom8]dP06om8]dP03o`000?oA;]7odBkA
00GodBkA00?o0000okm0_ono@;l01?no@;l00ol0003oXebSoj=LX`09oj=LX`03o`000?meRWGoMHYe
00;oMHYe00?o0000oh5nPOn1OX402_n1OX400ol0003o/4n`ok1?/006ok1?/0;o00001_o[5>/8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000oo`3o?ol
0o`02_ol0o`00ol0003olPgboo8=lP05oo8=lP03o`000?oB;M;odRgB00GodRgB00?o0000om4^dOoA
;]401OoA;]400ol0003o_d2ookm0_`05okm0_`03o`000?nSG:?oXebS00WoXebS00Go0000ogF:MOme
RWGoMHYeo`00000<oh5nP@03o`000?n`Ck3o/4n`00Co/4n`0_l00008on/Dj`03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo0?loo`3o009oo`3o003o`000?ob3O;olPgb00OolPgb00?o0000om8]d_oB
;M800ooB;M800ol0003odBkAom4^d@06om4^d@03o`000?no@;oo_d2o00Go_d2o00?o0000oj=LXonS
G:<02_nSG:<00ol0003oMHYeo`000004o`0000WoPGj100?o0000ok1?/?n`Ck000_n`Ck02o`0000[o
jaC[00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000oo`3o?ol0o`02?ol0o`00ol0003olPgboo8=lP07oo8=lP03o`00
0?oB;M;odRgB00;odRgB00?o0000om4^dOoA;]401_oA;]400ol0003o_d2ookm0_`07okm0_`;o0000
2onSG:<00ol0003obCK9olTfb@03olTfb@Oo00000_n1OX400ol0003o/4n`ok1?/002o`0000_ojaC[
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000oo8=l_ob3O802Oob
3O801Ol0003odRgBom8]d_oB;M;o000000SodBkA00?o0000okm0_ono@;l01ono@;l00ol0003ohAkQ
o`000002o`0000SoXebS00?o0000olTfbOo9=/T02_o9=/T5o`0000gojaC[00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?ol0ocoo0?l00?oo0?l0ol0000<oo8=lP03o`000?oB;M;o000000WodBkA00?o
0000okm0_ono@;l01_no@;l00ol0003ohAkQon4Nh@03on4Nh@?o00001?nSG:<00ol0003obCK9olTf
b@0=olTfb@03o`000?o[5>_ojaC[00gojaC[00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?ol0oco
000000;o00000oom0_d2o`0000_olPgb00?o0000om4^dOoA;]401ooA;]400ol0003o_d2ookm0_`07
okm0_`03o`000?oQ7^7ohAkQ00KohAkQ0ol000000onSG:?o0000olTfb@0>olTfb@03o`000?o[5>_o
jaC[00cojaC[00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo8=
lP03o`000?oA;]7odBkA00;odBkA1_l00008okm0_`03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000olTf
bOo9=/T03oo9=/T00ol0003ojaC[on/Dj`0:on/Dj`;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo8=lPGo00001_o^4Nh00ol0003o_d2ookm0_`05okm0_`03o`000?oQ7^7ohAkQ00[o
hAkQ00?o0000olTfbOo9=/T03oo9=/T00ol0003ojaC[on/Dj`07on/Dj`?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo8=lP03o`000?o^4NkokQ7^00WokQ7^00?o0000okm0_ono
@;l00ono@;l00ol0003ohAkQon4Nh@0;on4Nh@03o`000?o9=/WobCK900oobCK900?o0000on/Djoo[
5>/01Oo[5>/2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?olPgbo`000?l00000
3Oo^4Nh00ol0003o_d2ookm0_`02okm0_`03o`000?oQ7^7ohAkQ00_ohAkQ5?l00004on/Dj`;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo@;mo`00000>onhAkP04o`000?no@;oo_d2oo`0000kohAkQ
00?o0000oo4>lOoa3_404?oa3_400ol0003ojaC[o`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?om0_goo@;mood2oOl000003_o^4Nh00ol0003o_d2oo`00000>on4Nh@03o`00
0?oa3_7ol@ka017ol@ka00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000ood2oOom0_d00_om0_d00ol0003okQ7^onhAkP0=onhAkP03o`000?oQ7^7ohAkQ00WohAkQ1Ol0
000Boo4>l@;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d0
0ol0003okQ7^onhAkP0<onhAkP03o`000?oQ7^7ohAkQ00;ohAkQ1ol00004oo`3o003o`000?oa3_7o
l@ka00ool@ka00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo@;mood2o@06ood2
o@03o`000?o^4NkokQ7^00cokQ7^1?l0000<oo`3o003o`000?oa3_7ol@ka00col@ka0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Oo
o@;m00?o0000onhAk_o^4Nh03?o^4Nh00ol0003oo0?loo`3o00=oo`3o003o`000?oa3_7ol@ka00_o
l@ka00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003okQ7^onhAkP0:onhAkP03o`000?ol0ocoo0?l00koo0?l00?o0000oo4>lOoa
3_402Ooa3_42o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000onhAk_o^4Nh02_o^4Nh00ol0003oo0?l
oo`3o00?oo`3o003o`000?oa3_7ol@ka00Kol@ka0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_oa3_400ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000ooa3_42o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000oo4>lOl000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool00ol00?l9oooo00Ko003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Co003o2?ooo`05o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000So003o00?oool0o`00ool00?l00ol00?l2oooo00Co003o00?oool0o`00ool00?l00ol00?l2
oooo00?o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo0009o`00o`03oooo0?l00?oo003o
00?o003o00?oool0o`00ool00?l00ol00?l00oooo`3o003oo`00o`03o`00o`04oooo0?l00?oo003o
o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo
0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo
00Ko003o1?ooo`000ol00?ooool0oooo0009o`00o`;oool02_l00?l2oooo00So003o00?oool0o`00
ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003
o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go
003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o003oo`00o`09o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo
0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co
003o0_ooo`0;o`00o`03oooo0?l00?oo003o00Wo003o00?oool0o`00ool00?l01?l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l0
0_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o
00Coool0o`00ooooo`3oool03?l00?l00oooo`3o003oo`00o`09o`00o`03oooo0?l00?oo003o00?o
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo
0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o0_ooo`0:o`00o`;oool01?l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`00
0_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o
0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o00Wo003o00?oool0o`00ool00?l0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0ooo
o`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00oooo
o`3o003o00;oool03Ol00?l2oooo00[o003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2
oooo00go003o0_ooo`0:o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00
o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00
o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`05o`00o`;oool00ol00?l2oooo00Go
003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool0
1_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Co003o
0_ooo`03o`00o`?oool01?l00?l2oooo00?o003o0oooo`04o`00o`;oool01?l00?l2oooo00Ko003o
00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o1Oooo`05o`00o`Koool01_l00?l6oooo00Ko003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Q
o`00o`Coool02?l00?l4oooo00So003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(230) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.989 .011 .989 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.989 .011 .989 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.989 .011 .989 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.988 .012 .988 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.937 .063 .937 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.987 .013 .987 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.936 .064 .936 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.937 .063 .937 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.906 .094 .906 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.983 .017 .983 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.878 .122 .878 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.988 .012 .988 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.796 .204 .796 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.8 .2 .8 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.984 .016 .984 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.99 .01 .99 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.698 .302 .698 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.849 .151 .849 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.982 .018 .982 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.984 .016 .984 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.929 .071 .929 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.494 .506 .494 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.809 .191 .809 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.658 .342 .658 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.646 .354 .646 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.721 .279 .721 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.871 .129 .871 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.908 .092 .908 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.989 .011 .989 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.639 .361 .639 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.83 .17 .83 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.503 .497 .503 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.89 .11 .89 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.844 .156 .844 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.989 .011 .989 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.756 .244 .756 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.813 .187 .813 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.635 .365 .635 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.882 .118 .882 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.668 .332 .668 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.991 .009 .991 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.917 .083 .917 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.617 .383 .617 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.35 .65 .35 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.372 .628 .372 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.941 .059 .941 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.95 .05 .95 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.787 .213 .787 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.989 .011 .989 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.628 .372 .628 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.595 .405 .595 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.458 .542 .458 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.48 .52 .48 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.25 .75 .25 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.598 .402 .598 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.681 .319 .681 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.989 .011 .989 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.671 .329 .671 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.565 .435 .565 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.925 .075 .925 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.264 .736 .264 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.832 .168 .832 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.777 .223 .777 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.455 .545 .455 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.222 .778 .222 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.435 .565 .435 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.034 .966 .034 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.079 .921 .079 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.325 .675 .325 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.308 .692 .308 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.358 .642 .358 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.828 .172 .828 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.27 .73 .27 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.3 .7 .3 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.66 .34 .66 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.935 .065 .935 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.988 .012 .988 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.178 .822 .178 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.244 .756 .244 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.385 .615 .385 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.987 .013 .987 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.641 .359 .641 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.314 .686 .314 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.297 .703 .297 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.092 .908 .092 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.42 .58 .42 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.221 .779 .221 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.929 .071 .929 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.238 .762 .238 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.034 .966 .034 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.761 .239 .761 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.159 .841 .159 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.107 .893 .107 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.506 .494 .506 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.876 .124 .876 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.322 .678 .322 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.006 .994 .006 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.116 .884 .116 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.422 .578 .422 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.168 .832 .168 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.198 .802 .198 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.886 .114 .886 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.125 .875 .125 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.063 .937 .063 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.039 .961 .039 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.986 .014 .986 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.034 .966 .034 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.213 .787 .213 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.11 .89 .11 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.653 .347 .653 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.293 .707 .293 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.986 .014 .986 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.353 .647 .353 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.206 .794 .206 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.233 .767 .233 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.288 .712 .288 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.147 .853 .147 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.102 .898 .102 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.266 .734 .266 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.469 .531 .469 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.987 .013 .987 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.742 .258 .742 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.271 .729 .271 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.383 .617 .383 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.212 .788 .212 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.93 .07 .93 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.14 .86 .14 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.11 .89 .11 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.303 .697 .303 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.597 .403 .597 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.062 .938 .062 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.988 .012 .988 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.183 .817 .183 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.796 .204 .796 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.944 .056 .944 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.502 .498 .502 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.517 .483 .517 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.237 .763 .237 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.867 .133 .867 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.039 .961 .039 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.16 .84 .16 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.322 .678 .322 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.572 .428 .572 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.036 .964 .036 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.173 .827 .173 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.299 .701 .299 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.37 .63 .37 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.988 .012 .988 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.089 .911 .089 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.987 .013 .987 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.91 .09 .91 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.341 .659 .341 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.284 .716 .284 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.141 .859 .141 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.707 .293 .707 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.231 .769 .231 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.925 .075 .925 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.333 .667 .333 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.363 .637 .363 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.368 .632 .368 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.533 .467 .533 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.738 .262 .738 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.475 .525 .475 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.14 .86 .14 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.107 .893 .107 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.17 .83 .17 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.44 .56 .44 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.762 .238 .762 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.988 .012 .988 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.92 .08 .92 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.242 .758 .242 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.214 .786 .214 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.313 .687 .313 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.784 .216 .784 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.591 .409 .591 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.987 .013 .987 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.448 .552 .448 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.81 .19 .81 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.925 .075 .925 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.188 .812 .188 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.273 .727 .273 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.912 .088 .912 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.265 .735 .265 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.532 .468 .532 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.625 .375 .625 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.378 .622 .378 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.45 .55 .45 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.838 .162 .838 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.729 .271 .729 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.732 .268 .732 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.804 .196 .804 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.348 .652 .348 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.942 .058 .942 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.737 .263 .737 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.419 .581 .419 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.408 .592 .408 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.668 .332 .668 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.416 .584 .416 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.987 .013 .987 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.931 .069 .931 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.804 .196 .804 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.928 .072 .928 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.357 .643 .357 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.904 .096 .904 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.72 .28 .72 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.61 .39 .61 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.989 .011 .989 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.593 .407 .593 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.483 .517 .483 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.989 .011 .989 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.732 .268 .732 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.983 .017 .983 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.99 .01 .99 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.579 .421 .579 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.986 .014 .986 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.521 .479 .521 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.987 .013 .987 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.613 .387 .613 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.811 .189 .811 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.675 .325 .675 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.885 .115 .885 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.903 .097 .903 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.741 .259 .741 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.627 .373 .627 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.729 .271 .729 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.845 .155 .845 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.899 .101 .899 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.849 .151 .849 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.862 .138 .862 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.984 .016 .984 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.737 .263 .737 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.924 .076 .924 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.986 .014 .986 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.942 .058 .942 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.925 .075 .925 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.746 .254 .746 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.931 .069 .931 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.906 .094 .906 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.811 .189 .811 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.986 .014 .986 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.984 .016 .984 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.915 .085 .915 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.988 .012 .988 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.988 .012 .988 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.986 .014 .986 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.987 .013 .987 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.986 .014 .986 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.988 .012 .988 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?ol0ocoo0?loo`3o?l000004Ool
0o`01?l0003ojaC[on/Djol0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo0?loo`3o002oo`3o003o`000?ol
0ocoo0?l00goo0?l00?o0000on/Djoo[5>/00_o[5>/00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00<oo`3o003o`000?o[5>_ojaC[00?ojaC[00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l
00[oo0?l00?o0000on/Djoo[5>/01Oo[5>/00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003ojaC[on/Dj`06on/Dj`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ol0ocoo0?l00Ooo0?l
00?o0000on/Djoo[5>/02?o[5>/00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o]4^go0000013oo0?l00?o0000oo`3o?ol0o`02?ol
0o`9o`0000cojaC[00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003ondBk@03o`000?ol
0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oj1OXonPGj005onPGj003o`000?o[
5>_ojaC[00_ojaC[0ol00003onTFj@03o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
ondBkOo]4^d00oo]4^d00ol0003oo0?loo`3o00;oo`3o0;o00002ool0o`00ol0003oj1OXonPGj006
onPGj003o`000?o[5>_ojaC[00[ojaC[00?o0000onTFjOoY5^T01?oY5^T00ol0003oo0?loo`3o00:
oo`3o004o`000?oW6>OoiaSWonLHi`;o00002_ol0o`2o`000003onLHiol0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003okA;]ondBk@05ondBk@03o`000?ol0oco
o0?l00Woo0?l00?o0000onhAk_l000002ool0o`00ol0003oj1OXonPGj006onPGj003o`000?o[5>_o
jaC[00WojaC[00?o0000onTFjOoY5^T01_oY5^T00ol0003oo0?loo`3o008oo`3o003o`000?oW6>Oo
iaSW00CoiaSW0_l00005oo`3o0?o00001?oW6>L00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00Soo0?l0_l00008ondBk@03o`000?ol0ocoo0?l00Ooo0?l0_l00003onhA
kP03o`000?ol0ocoo0?l00Ooo0?l00?o0000onPGj?oX5nP01ooX5nP00ol0003ojaC[on/Dj`09on/D
j`03o`000?oY5^WojAKY00OojAKY00?o0000oo`3o?ol0o`01Ool0o`2o`0000WoiaSW0_l000000ool
0oco0000o`000007onLHi`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo0?l00?o0000ondBkOo]
4^d02?o]4^d00ol0003oo0?loo`3o006oo`3o003o`000?o^4NkokQ7^00?okQ7^00?o0000oo`3o?ol
0o`01ool0o`00ol0003oj1OXonPGj008onPGj003o`000?o[5>_ojaC[00OojaC[00?o0000onTFjOoY
5^T02OoY5^T00ol0003oo0?loo`3o003oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000onLHiooW
6>L01ooW6>L00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ok1?/o`000005oo`3o0;o00002oo]4^d2o`0000Koo0?l
00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oo0?loo`3o006oo`3o003o`000?oX5nSoj1OX00Soj1OX
00?o0000on/Djoo[5>/01_o[5>/00ol0003ojAKYonTFj@0;onTFj@05o`000?ol0ocoo0?loo`3o?l0
00003_oW6>L00ol0003oiaSWonLHi`08onLHi`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o/4ncok1?/on`Ck?l0
00000ool0o`00ol0003okA;]ondBk@0:ondBk@04o`000?oP7n3oh1oPo`0000?oo0?l0_l00008onhA
kP03o`000?ol0ocoo0?l00Koo0?l00?o0000onPGj?oX5nP02OoX5nP00ol0003ojaC[on/Dj`05on/D
j`03o`000?oY5^WojAKY00cojAKY00?o0000oo`3o?l000003ooW6>L00ol0003oiaSWonLHi`08onLH
i`03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ok1?/on`Ck003on`Ck003o`000?ol0oco000000_o
kA;]0_l00004on0Oh003o`000?ol0oco000000_okQ7^00?o0000oo`3o?ol0o`01Ool0o`00ol0003o
j1OXonPGj009onPGj003o`000?o[5>_ojaC[00CojaC[00?o0000onTFjOoY5^T03_oY5^T00ol0003o
iaSWonLHi`0>onLHi`03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000on`Ck?o/4n`0
1?o/4n`00ol0003okA;]ondBk@09ondBk@03o`000?oP7n3oh1oP00Goh1oP00?o0000onhAk_o^4Nh0
2_o^4Nh00ol0003oo0?loo`3o005oo`3o003o`000?oX5nSoj1OX00[oj1OX00?o0000on/Djoo[5>/0
0oo[5>/00ol0003ojAKYonTFj@0>onTFj@03o`000?oW6>OoiaSW00goiaSW00?o0000onLHiooW6>L0
2_oW6>L00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ok1?/on`C
k005on`Ck003o`000?o]4^gokA;]00OokA;]0_l00008on0Oh003o`000?o^4NkokQ7^00_okQ7^00?o
0000oo`3o?ol0o`01?ol0o`00ol0003oj1OXonPGj00:onPGj004o`000?o[5>_ojaC[on/Dj`?o0000
3ooY5^T00ol0003oiaSWonLHi`0>onLHi`03o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o/4ncok1?/00Ook1?/00?o0000ondBkOo]4^d01?o]4^d2o`0000_oh1oP1?l0
0009onhAkP03o`000?ol0ocoo0?l00?oo0?l00?o0000onPGj?oX5nP02ooX5nP01?l0003ojaC[o`00
0?l00003olPgb0;o00003?oY5^T2o`00013oiaSW00?o0000onLHiooW6>L02ooW6>L00ol0003oo0?l
oo`3o00=oo`3o004o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ok1?/
on`Ck007on`Ck003o`000?o]4^gokA;]00?okA;]00?o0000on0Oh?oP7n002ooP7n001?l0003o_D:m
oke2_Onm@[d5o`0000GokQ7^00?o0000oo`3o?ol0o`00_ol0o`00ol0003oj1OXonPGj00<onPGj003
o`000?o8=lSob3O800Gob3O80_l00008onTFj@;o00000_nl@k`00ol0003oiaSWonLHi`0=onLHi`03
o`000?oW6>OoiaSW00_oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ok1?/on`Ck009on`Ck003o`000?o]4^gokA;]00;o0000
3OoP7n000ol0003o_D:moke2_@07oke2_@Ko00000_ol0o`4o`0000goj1OX00?o0000olPgb?o8=lP0
1oo8=lP2o`0000GojAKY00?o0000oka3_?nl@k`00onl@k`00ol0003oiaSWonLHi`0<onLHi`03o`00
0?oW6>OoiaSW00coiaSW00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o/4ncok1?/00Wok1?/00?o
0000ondBkOl000003ooP7n000ol0003o_D:moke2_@0<oke2_@?o00001?oM8]d3o`0000Woj1OX00?o
0000olPgb?o8=lP02_o8=lP2o`000003onTFjOl0003o000000Oo_4>l00?o0000onLHiooW6>L02ooW
6>L00ol0003oiaSWonLHi`0<onLHi`03o`000?ol0ocoo0?l00Koo0?l1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000
on0Oh?oP7n003_oP7n000ol0003o_D:moke2_@0=oke2_@03o`000?oM8]gogB;M00KogB;M0ol00005
onPGj003o`000?o8=lSob3O800gob3O800?o0000oka3_?nl@k`02?nl@k`00ol0003oiaSWonLHi`09
onLHi`03o`000?oW6>OoiaSW00goiaSW00Co0000oo`3o?ol0ocoo0?l1Ol00003on`Ck003o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
on`Ck?o/4n`02oo/4n`2o`0000ooh1oP00?o0000oke2_Onm@[d03Onm@[d00ol0003ogB;MomdRg@0:
omdRg@?o000000?oj1OXo`000?o8=lP03oo8=lP00ol0003o_4>loka3_009oka3_003o`000?oW6>Oo
iaSW00SoiaSW00?o0000onLHiooW6>L03_oW6>L3o`0000Sok1?/00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o/4ncok1?/00Sok1?/0ol000000oo6
>LKo0000on0Oh00>on0Oh003o`000?nm@[go_D:m00go_D:m00?o0000omdRgOoM8]d03OoM8]d00ol0
003ob3O8olPgb00?olPgb003o`000?nl@kco_4>l00[o_4>l2ol0000;onLHi`Go00003?o/4n`00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003ojQGZo`000?om0_go0000
00Sok1?/0ol00005olHiaP03o`000?oP7n3oh1oP00coh1oP00?o0000oke2_Onm@[d03Onm@[d00ol0
003ogB;MomdRg@0=omdRg@;o00004?o8=lP00ol0003o_4>loka3_00:oka3_003o`000?nhAkSo^4Nh
00Oo^4Nh00?o0000onLHiooW6>L00_oW6>L7o`0000Co_D:m00?o0000on`Ck?o/4n`02_o/4n`00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003ojQGZonXEj_oZ5NX2o`00
00Gok1?/0ol00009olHiaP;o00002ooP7n000ol0003o_D:moke2_@0=oke2_@03o`000?oM8]gogB;M
00gogB;M00Co0000oka3_?nl@kco00003oo8=lP00ol0003o_4>loka3_009oka3_003o`000?nhAkSo
^4Nh00Wo^4Nh1?l0000;oke2_@03o`000?o/4ncok1?/00[ok1?/00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000onXEj_oZ5NX01?oZ5NX00ol0003ok1?/o`000002o`00
00coaSW600Co0000ojAKY?l0003o00002OoP7n000ol0003o_D:moke2_@0=oke2_@03o`000?oM8]go
gB;M00gogB;M00Go0000oka3_?nl@kco_4>lo`00000=olPgb003o`000?nl@kco_4>l00[o_4>l00?o
0000okQ7^?nhAkP02OnhAkP00ol0003o_D:moke2_@0<oke2_@03o`000?o/4ncok1?/00[ok1?/00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000onXEj_oZ5NX01_oZ5NX0
0ol0003oaSW6olHiaP0<olHiaP03o`000?nTFjCoY5^T00;oY5^T0_l00007on0Oh003o`000?nm@[go
_D:m00co_D:m00?o0000omdRgOoM8]d03OoM8]d00ol0003o_4>loka3_003oka3_003o`000?o8=lSo
b3O800[ob3O800?o0000oka3_?nl@k`02_nl@k`00ol0003o^4NhokQ7^009okQ7^003o`000?nm@[go
_D:m00co_D:m00?o0000on`Ck?o/4n`02oo/4n`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003ojQGZonXEjP06onXEjP03o`000?o6>LKoaSW600_oaSW600?o0000ojAK
Y?nTFj@01OnTFj@00ol0003oh1oPon0Oh003on0Oh003o`000?nm@[go_D:m00go_D:m00?o0000omdR
gOoM8]d03OoM8]d00ol0003o_4>loka3_004oka3_003o`000?o8=lSob3O800Wob3O800?o0000oka3
_?nl@k`02Onl@k`00ol0003o^4NhokQ7^00:okQ7^003o`000?nm@[go_D:m00co_D:m00?o0000on`C
k?o/4n`02oo/4n`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
jQGZonXEjP07onXEjP03o`000?o6>LKoaSW600_oaSW600?o0000ojAKY?nTFj@01_nTFj@2o`0000?o
h1oP00?o0000oke2_Onm@[d03Onm@[d00ol0003ogB;MomdRg@0<omdRg@03o`000?nl@kco_4>l00Ko
_4>l00?o0000olPgb?o8=lP02?o8=lP00ol0003o_4>loka3_009oka3_003o`000?nhAkSo^4Nh00[o
^4Nh00?o0000oke2_Onm@[d03?nm@[d00ol0003ok1?/on`Ck00;on`Ck003o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oaSW6olHiaP0:olHiaP03o`00
0?nTFjCoY5^T00WoY5^T0_l000000ooP7n3o0000oke2_@0<oke2_@?o00003_oM8]d00ol0003o_4>l
oka3_007oka3_003o`000?o8=lSob3O800Oob3O800?o0000oka3_?nl@k`02Onl@k`00ol0003o^4Nh
okQ7^00;okQ7^003o`000?nm@[go_D:m00co_D:m00?o0000on`Ck?o/4n`02_o/4n`00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000oo`3o?ol0o`00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oaSW6olHi
aP09olHiaP03o`000?nTFjCoY5^T00_oY5^T00?o0000oke2_Onm@[d02_nm@[d2o`0000?oV6NH00?o
0000omdRgOoM8]d02_oM8]d00ol0003o_4>loka3_009oka3_003o`000?o8=lSob3O800Kob3O800?o
0000oka3_?nl@k`02?nl@k`00ol0003o^4NhokQ7^00<okQ7^003o`000?nm@[go_D:m00co_D:m00?o
0000on`Ck?o/4n`02_o/4n`00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o004oo`3o0?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000olHia_o6>LH02?o6>LH0
0ol0003oY5^TojAKY00<ojAKY003o`000?nm@[go_D:m00So_D:m0_l00006oiQWV0;o00002_oM8]d0
0ol0003o_4>loka3_00:oka3_003o`000?o8=lSob3O800Gob3O800?o0000oka3_?nl@k`02?nl@k`0
0ol0003o^4NhokQ7^00<okQ7^003o`000?nm@[go_D:m00co_D:m00?o0000on`Ck?o/4n`02oo/4n`0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`02?ol0o`3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
onXEjP03o`000?o6>LKoaSW600OoaSW600?o0000ojAKY?nTFj@03_nTFj@00ol0003o_D:moke2_@04
oke2_@?o00002_nHIiP00ol0003ogB;MomdRg@07omdRg@03o`000?nl@kco_4>l00_o_4>l00?o0000
olPgb?o8=lP00oo8=lP00ol0003o_4>loka3_009oka3_003o`000?nhAkSo^4Nh00co^4Nh00?o0000
oke2_Onm@[d03?nm@[d00ol0003ok1?/on`Ck00;on`Ck0;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00<oo`3o0Co00000_om0_d00ol0
003ojQGZonXEjP0<onXEjP03o`000?o6>LKoaSW600OoaSW600?o0000ojAKY?nTFj@03onTFj@01?l0
003o_D:moke2_Onm@[d2o`0000koV6NH0_l00006omdRg@03o`000?nl@kco_4>l00go_4>l00?o0000
olPgb?o8=lP00_o8=lP00ol0003o_4>loka3_008oka3_003o`000?nhAkSo^4Nh00co^4Nh0ol0000=
oke2_@03o`000?o/4ncok1?/00_ok1?/00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?om0_go0000
00oojQGZ00?o0000olHia_o6>LH01_o6>LH00ol0003oY5^TojAKY00@ojAKY0Co00004_nHIiP00ol0
003ogB;MomdRg@03omdRg@03o`000?nl@kco_4>l00ko_4>l00Go0000olPgb?o8=lSob3O8o`000005
oka3_0Oo00003?nhAkP01Ol0003oQGZ5ohEjQOn5NXGo000000co_D:m00?o0000on`Ck?o/4n`02?o/
4n`3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
oo`3o?ol0o`04?ol0o`3o`0000oojQGZ00?o0000olHia_o6>LH01_o6>LH00ol0003oY5^TojAKY00=
ojAKY0?o000000CoJiA[o`000?l0003o00004onHIiP2o`0000;ogB;M00?o0000oka3_?nl@k`04?nl
@k`00ol0003ob3O8o`000006o`0000OoZeB[00?o0000okQ7^?nhAkP02?nhAkP00ol0003oQGZ5ohEj
Q@03ohEjQ@;o00002?nm@[d3o`0000Kok1?/1?l00002onLHi`03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`03ool0o`0
1?l0003okA;]o`000?o1?/43o`0000gojQGZ00?o0000olHia_o6>LH01?o6>LH00ol0003oY5^TojAK
Y00;ojAKY0?o00000om[U6/01Ol0003oK9=/o`000?mJYE[o000001CoV6NH00?o0000omdRgOl00000
4onl@k`00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?nhAkSo^4Nh00Go^4Nh0_l00008ohEjQ@03o`00
0?nm@[go_D:m00Go00000onjAKX00ol0003ok1?/on`Ck003o`0000OoiaSW00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo0?loo`3
o00>oo`3o004o`000?o]4^gokA;]o`0000Co`Ck10ol0000:onXEjP03o`000?o6>LKoaSW600?oaSW6
00?o0000ojAKY?nTFj@02OnTFj@3o`0000GoJiA[00Co0000ofbCK?m/Tfco00000_mJYEX00ol0003o
V6NHoiQWV00BoiQWV003o`000?nl@kco_4>l01;o_4>l00?o0000oj]DZon[E:/03_n[E:/00ol0003o
^4NhokQ7^003okQ7^003o`000?n5NXGoQGZ500WoQGZ50_l00009okY5^P;o00002_oW6>L00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?ol0ocoo0?l00koo0?l00Go0000ondBkOo]4^gokA;]o`000007ol4n`@;o00001ooZ5NX5o`0000;o
aSW600?o0000ojAKY?nTFj@01_nTFj@3o`0000SoJiA[00Co0000ofbCK?m/Tfco00000omJYEX00ol0
003oV6NHoiQWV00AoiQWV003o`000?nl@kco_4>l017o_4>l00?o0000oj]DZon[E:/04?n[E:/01Ol0
003o^4NhokQ7^?nhAkSo000000coQGZ500?o0000okY5^_njAKX02?njAKX00ol0003oiaSWonLHi`0:
onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000oo`3o?ol0o`03?ol0o`2o`0000CokA;]00?o0000ol4n`Oo1?/401oo1?/43o`00
0004onXEj_l0003o0000o`0000GoZeB[0_l00006ojAKY0?o00002_m[U6/01Ol0003oK9=/ofbCK?m/
Tfco000000CoFZEJ00?o0000oiQWV?nHIiP04?nHIiP00ol0003o_4>loka3_00Aoka3_003o`000?n[
E:_oZeB[017oZeB[00?o0000okQ7^?l000003On5NXD00ol0003o^TFjokY5^P08okY5^P03o`000?oW
6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00CokA;]00?o0000
ol4n`Oo1?/402_o1?/400ol0003oZeB[oj]DZ`08oj]DZ`03o`000?nTFjCoY5^T00?o00003Om[U6/0
1Ol0003oK9=/ofbCK?m/Tfco000000GoFZEJ00?o0000oiQWV?nHIiP03onHIiP00ol0003o_4>loka3
_00Aoka3_003o`000?n[E:_oZeB[01;oZeB[00?o0000ohEjQOn5NXD03?n5NXD00ol0003o^TFjokY5
^P08okY5^P03o`000?oW6>OoiaSW00_oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo0?l00?o0000ondBkOo]4^d01Oo]4^d0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?n[E:_oZeB[00WoZeB[0_l0000?of^DJ`03o`000?m/Tfco
K9=/00;oK9=/00?o0000oeZUF_mJYEX01?mJYEX00ol0003oV6NHoiQWV00=oiQWV0?o00004Onl@k`0
0ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n5NXGoQGZ500_oQGZ500?o0000okY5^_njAKX02OnjAKX0
0ol0003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008oo`3o0;o00002?o]4^d0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?n[E:_oZeB[00WoZeB[00?o0000of^DJom[U6/03Om[U6/0
0ol0003oK9=/ofbCK003ofbCK003o`000?mJYE[oFZEJ00GoFZEJ00?o0000oiQWV?nHIiP02_nHIiP2
o`0000?oTVfB00?o0000oka3_?nl@k`03_nl@k`00ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n5NXGo
QGZ500_oQGZ500?o0000okY5^_njAKX02OnjAKX00ol0003oiaSWonLHi`0;onLHi`03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo0?l00?o0000ondBkOo]4^d01oo]4^d2o`0000_o`Ck100?o0000oj]D
Zon[E:/02on[E:/00ol0003oJiA[of^DJ`0<of^DJ`03o`000?m/TfcoK9=/00?oK9=/00?o0000oeZU
F_mJYEX01_mJYEX00ol0003oV6NHoiQWV007oiQWV0;o00001_nBKI82o`0000ko_4>l00?o0000oj]D
Zon[E:/04on[E:/00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?njAK[o^TFj00Wo^TFj00?o0000onLH
iooW6>L03?oW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000oo`3o?ol0ocoo0?lo`000009ondB
k@03o`000?o?<<oo000000_o`Ck100?o0000oj]DZon[E:/02on[E:/00ol0003oJiA[of^DJ`0;of^D
J`03o`000?m/TfcoK9=/00CoK9=/00?o0000oeZUF_mJYEX01omJYEX00ol0003oV6NHoiQWV005oiQW
V003o`000?nBKI;oTVfB00SoTVfB00?o0000oka3_?nl@k`02_nl@k`00ol0003oZeB[oj]DZ`0Doj]D
Z`03o`000?n5NXGoQGZ500_oQGZ500?o0000okY5^_njAKX02OnjAKX00ol0003oiaSWonLHi`0<onLH
i`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?lo`000009ondBk@04o`000?o?<<oocc3?o`00
00_o`Ck100?o0000oj]DZon[E:/02on[E:/00ol0003oJiA[of^DJ`0;of^DJ`03o`000?m/TfcoK9=/
00CoK9=/00?o0000oeZUF_mJYEX02?mJYEX00ol0003oV6NHoiQWV002oiQWV0;o00003?nBKI82o`00
00[o_4>l00?o0000oj]DZon[E:/05?n[E:/00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?njAK[o^TFj
00Wo^TFj00?o0000onLHiooW6>L03OoW6>L00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003okA;]ondBk@07ondBk@03
o`000?o?<<oocc3?00;occ3?00?o0000ol4n`Oo1?/402?o1?/400ol0003oZeB[oj]DZ`0<oj]DZ`03
o`000?m[U6_oJiA[00WoJiA[00?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oFZEJoeZUFP09oeZUFP04
o`000?nHIiSo0000o`00013oTVfB0_l00008oka3_003o`000?n[E:_oZeB[01CoZeB[0ol0000;ohEj
Q@03o`000?njAK[o^TFj00Wo^TFj00?o0000onLHiooW6>L03OoW6>L01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003okA;]ondBk@06ondBk@03o`000?o?<<oocc3?00?occ3?00?o0000ol4n
`Oo1?/402?o1?/400ol0003oZeB[oj]DZ`0;oj]DZ`;o00002_m[U6/00ol0003oK9=/ofbCK006ofbC
K003o`000?mJYE[oFZEJ00[oFZEJ00?o0000oi9]T_nBKI804_nBKI800ol0003o_4>loka3_004oka3
_003o`000?n[E:_oZeB[01GoZeB[00?o0000oiA[U?nDJi@01Ol00005ohEjQ@03o`000?njAK[o^TFj
00[o^TFj00?o0000onLHiooW6>L03_oW6>L3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okA;]ondBk@04ondBk@03
o`000?o?<<oocc3?00Cocc3?00?o0000ol4n`Oo1?/401oo1?/400ol0003oZeB[oj]DZ`0;oj]DZ`04
o`000?mdRgCoM8]do`0000WoJiA[00?o0000ofbCK?m/Tf`01_m/Tf`00ol0003oFZEJoeZUFP0:oeZU
FP03o`000?nBKI;oTVfB01?oTVfB0_l00003oka3_0Co00005?n[E:/00ol0003oU6^DoiA[U006oiA[
U0Co000000?oQGZ5o`000?njAKX02onjAKX00ol0003oiaSWonLHi`0>onLHi`03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003okA;]ondBk@03ondBk@03o`000?o?<<oocc3?00Gocc3?00?o0000ol4n`Oo1
?/401oo1?/400ol0003oZeB[oj]DZ`09oj]DZ`;o00001?mdRg@00ol0003oJiA[of^DJ`05of^DJ`03
o`000?m/TfcoK9=/00OoK9=/00?o0000oeZUF_mJYEX02_mJYEX00ol0003oTVfBoi9]TP0Eoi9]TP03
o`000?nl@kco000000CoWenO0ol0000@oj]DZ`03o`000?nDJiCoU6^D00_oU6^D0_l0000<okY5^P03
o`000?oW6>OoiaSW00coiaSW0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d00_o]4^d00ol0003occ3?
oll`c`06oll`c`03o`000?o1?/7o`Ck100Oo`Ck100?o0000oj]DZon[E:/02?n[E:/00ol0003oM8]d
ogB;M005ogB;M003o`000?m[U6_oJiA[00CoJiA[00?o0000ofbCK?m/Tf`01om/Tf`00ol0003oFZEJ
oeZUFP0:oeZUFP03o`000?nBKI;oTVfB01KoTVfB00?o0000oimOWonOGil01_nOGil3o`0000coZeB[
00?o0000oiA[U?nDJi@03OnDJi@00ol0003o^TFjokY5^P09okY5^PGo00002OoW6>L2o`000003onXE
j_l0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003ondBkOl0003occ3?00Wocc3?00?o0000ol4n`Oo1?/401_o1
?/400ol0003oZeB[oj]DZ`07oj]DZ`03o`000?mdRgCoM8]d00OoM8]d00?o0000of^DJom[U6/00_m[
U6/00ol0003oK9=/ofbCK008ofbCK003o`000?mJYE[oFZEJ00WoFZEJ00?o0000oi9]T_nBKI805onB
KI800ol0003oWenOoimOW`09oimOW`?o00002On[E:/00ol0003oU6^DoiA[U00>oiA[U0Ko00001?nj
AKX00ol0003o_T6noki1_P03oki1_PGo00000_oW6>L2o`0000CojQGZ00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oP7n3oh1oPon0Oh?l000002oo?<<l00ol0003o`Ck1ol4n`@06ol4n`@03o`000?n[
E:_oZeB[00GoZeB[0_l0000;ogB;M004o`000?m[U6_oJiA[o`0000_oK9=/00?o0000oeZUF_mJYEX0
2OmJYEX00ol0003oTVfBoi9]TP0Foi9]TP03o`000?nOGiooWenO00goWenO0ol00005oj]DZ`03o`00
0?nDJiCoU6^D00ooU6^D00?o0000oj1OX?nPGj000onPGj04o`0000_o_T6n0_l00006onXEjP03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003oh1oPon0Oh002on0Oh0ko00001_o1?/400ol0003oZeB[oj]D
Z`05oj]DZ`03o`000?mdRgCoM8]d00coM8]d00?o0000of^DJol000002om/Tf`00ol0003oFZEJoeZU
FP07oeZUFP?o00006?nBKI800ol0003oWenOoimOW`0@oimOW`?o000000?oZeB[o`000?nDJi@04?nD
Ji@00ol0003oX5nPoj1OX007oj1OX003o`000?nn@Kko_T6n00[o_T6n00?o0000onXEj_oZ5NX01OoZ
5NX00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005on0Oh003o`000?nXEjSoZ5NX00_oZ5NX0_l00004
ol4n`@03o`000?n[E:_oZeB[00?oZeB[0_l0000@ogB;M003o`000?m/TfcoK9=/00[oK9=/00?o0000
oeZUF_mJYEX00omJYEX4o`0000;oAKY500?o0000oi9]T_nBKI805OnBKI800ol0003oWenOoimOW`0D
oimOW`03o`000?nDJiCoU6^D013oU6^D00?o0000oj1OX?nPGj001onPGj000ol0003o_T6noki1_P0:
oki1_P03o`000?oZ5N[ojQGZ00GojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oP7n3oh1oP
00Goh1oP00?o0000ojQGZ?nXEjP03OnXEjP6o`0000?oZeB[00?o0000ogB;M?mdRg@04?mdRg@00ol0
003oK9=/ofbCK00:ofbCK003o`000?mJYE[o000000?o00001om5^TD00ol0003oTVfBoi9]TP0Doi9]
TP03o`000?nOGiooWenO01CoWenO00?o0000oiA[U?nDJi@03onDJi@00ol0003oX5nPoj1OX008oj1O
X003o`000?nn@Kko_T6n00[o_T6n00?o0000onXEj_oZ5NX01OoZ5NX00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on0Oh?oP7n001_oP7n000ol0003oZ5NXojQGZ00=ojQGZ003o`000?nRGJ;oXUfR00?o
XUfR00?o0000oj]DZol000004omdRg@4o`0000WoK9=/0_l0000<odFjA@03o`000?nBKI;oTVfB01?o
TVfB00?o0000oimOWonOGil05OnOGil00ol0003oU6^DoiA[U00>oiA[U003o`000?nPGj3oX5nP00So
X5nP00?o0000oki1__nn@Kh02Onn@Kh00ol0003ojQGZonXEjP07onXEjP03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oP7n3oh1oP00Soh1oP00?o0000ojQGZ?nXEjP02onXEjP00ol0003oXUfRoj9MXP05oj9MXP03o`00
0?mdRgCoM8]d01;oM8]d00Co0000oe:]D_mB[E;oDZeB1Ol00003ofbCK003o`000?m5^TGoAKY500go
AKY50ol0000@oi9]TP;o00006?nOGil00ol0003oU6^DoiA[U00=oiA[U003o`000?nPGj3oX5nP00Wo
X5nP00?o0000oki1__nn@Kh02Onn@Kh00ol0003ojQGZonXEjP07onXEjP03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_oh1oP00?o0000ojQGZ?nXEjP02_nXEjP00ol0003oXUfRoj9MXP06oj9MXP03o`00
0?mdRgCoM8]d017oM8]d00?o0000oe:]D_mB[E801omB[E83o`00013oAKY500?o0000occ3??ll`c`0
1Ol00009oi9]TP;o000000?oEJYEo`000?nOGil05onOGil00ol0003oU6^DoiA[U00=oiA[U003o`00
0?nPGj3oX5nP00WoX5nP00?o0000oki1__nn@Kh02?nn@Kh2o`0000[ojQGZ00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?o_4>ooka3_00;oka3_00?o0000on0Oh?oP7n002OoP7n000ol0003oZ5NXojQG
Z00:ojQGZ003o`000?nRGJ;oXUfR00OoXUfR00?o0000ogB;M?mdRg@03omdRg@00ol0003oDZeBoe:]
DP0:oe:]DP03o`000?m5^TGoAKY500goAKY500?o0000occ3??ll`c`01_ll`c`4o`0000CoTVfB00?o
0000oeFZEOmEZUD00_mEZUD00ol0003oWenOoimOW`0FoimOW`03o`000?nDJiCoU6^D00_oU6^D00?o
0000oj1OX?nPGj002onPGj000ol0003o_T6noki1_P06oki1_P03o`000?o?<<oo000000[ojQGZ00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?o_4>ooka3_00?oka3_00?o0000on0Oh?oP7n002?oP7n0=
o`0000[oXUfR00?o0000ogB;M?mdRg@03omdRg@00ol0003oDZeBoe:]DP0;oe:]DP03o`000?m5^TGo
AKY500coAKY500?o0000occ3??ll`c`02_ll`c`4o`0000GoEJYE00?o0000oimOWonOGil05_nOGil0
0ol0003oU6^DoiA[U00:oiA[U003o`000?nPGj3oX5nP00coX5nP00?o0000oki1__nn@Kh01?nn@Kh2
o`0000?occ3?00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onl@
koo_4>l00oo_4>l00ol0003oh1oPon0Oh007on0Oh003o`000?nUFZGoYEZU00WoYEZU00?o0000oj9M
X_nRGJ802OnRGJ800ol0003oM8]dogB;M00=ogB;M003o`000?mB[E;oDZeB00coDZeB00?o0000odFj
AOm5^TD03?m5^TD00ol0003o?<<locc3?00;occ3?003o`000?lTfbCo000000KoEJYE00?o0000oimO
WonOGil05_nOGil00ol0003oU6^DoiA[U009oiA[U003o`000?nPGj3oX5nP00coX5nP00?o0000oki1
__nn@Kh00onn@Kh00ol0003occ3?oll`c`03oll`c`03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?o_4>ooka3_00Coka3_00?o0000on0Oh?oP7n001_oP7n000ol0003o
YEZUojEJY@08ojEJY@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ogB;M?mdRg@02?mdRg@4o`0000oo
DZeB00?o0000odFjAOm5^TD02om5^TD00ol0003o?<<locc3?00;occ3?004o`000?lTfbCo9=/To`00
00OoEJYE00?o0000oimOWonOGil05OnOGil00ol0003oU6^DoiA[U008oiA[U003o`000?nPGj3oX5nP
00goX5nP00?o0000oki1__nn@Kh00_nn@Kh00ol0003occ3?oll`c`05oll`c`03o`000?oZ5N[ojQGZ
00OojQGZ00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?o_4>ooka3_00Goka3_00?o0000on0Oh?oP
7n001OoP7n000ol0003oYEZUojEJY@08ojEJY@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ogB;M?md
Rg@00omdRg@5o`0000?oDjaC00?o0000oe:]D_mB[E803_mB[E800ol0003oAKY5odFjA@0:odFjA@03
o`000?ll`cco?<<l00[o?<<l00Go0000obCK9?lTfbCo9=/To`000007oeFZE@03o`000?nOGiooWenO
01GoWenO00?o0000oiA[U?nDJi@02?nDJi@00ol0003oX5nPoj1OX00=oj1OX003o`000?nn@Kko_T6n
00;o00002?o?<<l00ol0003ojQGZonXEjP08onXEjPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003oka3_onl@k`05onl@k`03o`000?oP7n3oh1oP00Go
h1oP00?o0000ojEJYOnUFZD02?nUFZD00ol0003oXUfRoj9MXP0<oj9MXPGo00002OmC[5<00ol0003o
DZeBoe:]DP0<oe:]DP;o00003?m5^TD00ol0003o?<<locc3?00:occ3?005o`000?lTfbCo9=/TobCK
9?l000002?mEZUD00ol0003oWenOoimOW`0DoimOW`?o00001onDJi@00ol0003oX5nPoj1OX00>oj1O
X003o`000?nn@Kko000000_occ3?00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000onl@koo_4>l01Oo_4>l00ol0003oh1oPon0Oh004on0Oh003o`000?nUFZGoYEZU00Oo
YEZU00?o0000oj9MX_nRGJ803?nRGJ801?l0003oMHYeogF:MOl0000;oe>/D`03o`000?mB[E;oDZeB
00_oDZeB00Co0000oaoO7olOgaoo00002_m5^TD00ol0003o?<<locc3?00:occ3?003o`000?lTfbCo
9=/T00;o9=/T00?o0000oeFZEOmEZUD01_mEZUD00ol0003oWenOoimOW`0AoimOW`?o00000om[U6/0
0ol0003oU6^DoiA[U004oiA[U003o`000?nPGj3oX5nP00goX5nP1?l0000;oll`c`03o`000?oZ5N[o
jQGZ00GojQGZ00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o_4>ooka3_00Koka3_00Co0000on0O
h?oP7n3oh1oP1?l00008ojEJY@03o`000?nRGJ;oXUfR00_oXUfR00?o0000ogF:MOmeRWD00_meRWD0
0ol0003oDjaCoe>/D`08oe>/D`03o`000?mB[E;oDZeB00[oDZeB00?o0000oaoO7olOgal00_lOgal0
0ol0003oAKY5odFjA@03odFjA@Go00002oll`c`00ol0003o9=/TobCK9003obCK9003o`000?mEZUGo
EJYE00OoEJYE00?o0000oimOWonOGil03_nOGil2o`0000OoJiA[00?o0000oiA[U?nDJi@00_nDJi@0
0ol0003oX5nPoj1OX00=oj1OX003o`000?nl@kco_4>l00;o_4>l00?o0000oll`coo?<<l02Oo?<<l0
0ol0003ojQGZonXEjP03onXEjP03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003oka3_onl@k`07onl@
k`?o00001?o;=</00ol0003oYEZUojEJY@05ojEJY@03o`000?nRGJ;oXUfR00[oXUfR00?o0000ogF:
MOmeRWD00omeRWD00ol0003oDjaCoe>/D`09oe>/D`03o`000?mB[E;oDZeB00SoDZeB00?o0000oaoO
7olOgal01?lOgal5o`0000Co0?l000?o0000occ3??ll`c`02Oll`c`00ol0003o9=/TobCK9003obCK
9003o`000?mEZUGoEJYE00SoEJYE00?o0000oimOWonOGil02_nOGil3o`0000[oJiA[00Go0000oiA[
U?nDJiCoU6^Do`00000>oj1OX003o`000?nl@kco_4>l00Co_4>l0_l00009oll`c`03o`000?oZ5N[o
jQGZ00;ojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?o_4>ooka3_00Ooka3_00?o0000ol/d
boo;=</01Oo;=</00ol0003oYEZUojEJY@03ojEJY@03o`000?nRGJ;oXUfR00[oXUfR00?o0000ogF:
MOmeRWD01?meRWD00ol0003oDjaCoe>/D`09oe>/D`03o`000?mB[E;oDZeB00OoDZeB00?o0000oaoO
7olOgal01OlOgal00ol0003o0?l0o`3o0007o`3o0003o`000?ll`cco?<<l00Oo?<<l00?o0000obCK
9?lTfb@01?lTfb@00ol0003oEJYEoeFZE@08oeFZE@03o`000?nOGiooWenO00SoWenO0_l0000>of^D
J`Co00003?nPGj02o`0000Wo_4>l00?o0000oll`coo?<<l01oo?<<l01?l0003ojQGZonXEj_l0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000onl@koo_4>l01Oo_4>l00ol0003obcC;ol/db`07ol/db`;o00000onUFZD00ol0
003oXUfRoj9MXP09oj9MXP03o`000?meRWGoMHYe00KoMHYe00?o0000oe>/DomC[5<02OmC[5<00ol0
003oDZeBoe:]DP05oe:]DP03o`000?lOgaoo7mlO00Ko7mlO00?o0000o`3o0?l0o`002?l0o`000ol0
003o?<<locc3?006occ3?003o`000?lTfbCo9=/T00Co9=/T00?o0000oeFZEOmEZUD02OmEZUD4o`00
00?oWenO0ol0000@of^DJ`05o`000?nkA;_o^dBkok]4^ol000002_nPGj000ol0003o_4>loka3_00:
oka3_0Ko00000oo?<<l00ol0003ojQGZo`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000onl@koo_4>l01?o_4>l00ol0
003obcC;ol/db`0:ol/db`04o`000?nUFZGoYEZUo`0000[oXUfR00?o0000ogF:MOmeRWD01omeRWD0
0ol0003oDjaCoe>/D`09oe>/D`03o`000?mB[E;oDZeB00CoDZeB00?o0000oaoO7olOgal01olOgal0
0ol0003o0?l0o`3o0008o`3o00;o00001_ll`c`00ol0003o9=/TobCK9005obCK9003o`000?mEZUGo
EJYE00WoEJYE00Co0000od>l@om3_4?o@ka30ol0000Bof^DJ`03o`000?nkA;_o^dBk00?o^dBk0_l0
0006oj1OX0;o00003Onl@k`00ol0003okQ7^onhAkP03onhAkPGo00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000onl@koo_4>l00oo_4>l0
0ol0003obcC;ol/db`0<ol/db`;o00002_nRGJ800ol0003oMHYeogF:M@08ogF:M@03o`000?mC[5?o
DjaC00[oDjaC00?o0000oe:]D_mB[E800_mB[E800ol0003o7mlOoaoO7`08oaoO7`03o`000?l0o`3o
0?l000Ko0?l00_l00002oacS7003o`000?ll`cco?<<l00;o?<<l00?o0000obCK9?lTfb@01_lTfb@0
0ol0003oEJYEoeFZE@08oeFZE@03o`000?m3_4?o@ka300Co@ka300?o0000of^DJom[U6/03om[U6/0
0ol0003o^dBkok]4^`06ok]4^`;o00000onPGj000ol0003o_4>loka3_00=oka3_003o`000?o^4Nko
kQ7^00OokQ7^0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003oka3_onl@k`02onl@k`03o`000?o;=<_obcC;
00kobcC;00?o0000oj9MX_nRGJ801onRGJ800ol0003oMHYeogF:M@0:ogF:M@03o`000?mC[5?oDjaC
00WoDjaC00Go0000oe:]D_mB[E;oDZeBo`00000;oaoO7`03o`000?l0o`3o0?l000Co0?l00_l00005
oacS7005o`000?ll`cco?<<locc3??l000002?lTfb@00ol0003oEJYEoeFZE@08oeFZE@03o`000?m3
_4?o@ka300Go@ka300?o0000of^DJom[U6/03_m[U6/00ol0003o^dBkok]4^`08ok]4^`03o`000?nP
Gj3o000000oo_4>l00?o0000onhAk_o^4Nh02?o^4Nh01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?o_4>ooka3_o`00017obcC;00?o0000oj9MX_nRGJ801_nRGJ800ol0003oMHYe
ogF:M@0;ogF:M@03o`000?mC[5?oDjaC00WoDjaC00Co0000oe:]D_mB[E;o00003?lOgal00ol0003o
0?l0o`3o0002o`3o00;o00002?lLha`00ol0003o?<<lo`000009obCK9003o`000?mEZUGoEJYE00So
EJYE00?o0000od>l@om3_4<01Om3_4<00ol0003oJiA[of^DJ`0=of^DJ`03o`000?nkA;_o^dBk00[o
^dBk00?o0000oka3_?nl@k`03_nl@k`00ol0003okQ7^onhAkP07onhAkP03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Bol/db`03o`00
0?nRGJ;oXUfR00CoXUfR00?o0000ogF:MOmeRWD03?meRWD00ol0003oDjaCoe>/D`0:oe>/D`?o0000
3?lOgal00ol0003o0?l0o`3o0002o`0000_o7><L00?o0000obCK9?lTfb@02?lTfb@00ol0003oEJYE
oeFZE@07oeFZE@03o`000?m3_4?o@ka300Oo@ka300?o0000of^DJom[U6/03?m[U6/00ol0003o^dBk
ok]4^`0;ok]4^`;o00003_nl@k`00ol0003okQ7^onhAkP07onhAkP03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000onl@koo_4>l00oo_4>l00ol0003obcC;ol/db`0?ol/db`?o00000onR
GJ800ol0003oMHYeogF:M@0>ogF:M@03o`000?mC[5?oDjaC00SoDjaC00Co0000obSG:?lXebSo:=LX
0_l0000:oaoO7`?o00003OlLha`00ol0003o9=/TobCK9008obCK9003o`000?mEZUGoEJYE00OoEJYE
00?o0000od>l@om3_4<01om3_4<00ol0003oJiA[of^DJ`0;of^DJ`03o`000?nkA;_o^dBk00co^dBk
00?o0000om`Sg?l000000_l0000:oka3_003o`000?o^4NkokQ7^00SokQ7^00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003oka3_onl@k`04onl@k`03o`000?o;=<_obcC;00cobcC;0_l0
0003ok9=/P03o`000?nRGJ;o0000017oMHYe00?o0000oe>/DomC[5<01omC[5<00ol0003o:=LXobSG
:004obSG:0;o00002?lOgal00ol0003o7><LoacS700>oacS70;o00002?lTfb@00ol0003oEJYEoeFZ
E@06oeFZE@03o`000?m3_4?o@ka300Wo@ka300?o0000of^DJom[U6/02Om[U6/00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oL8mcog2?L00;og2?L0ol00007oka3_003o`000?o^4NkokQ7^00OokQ7^00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003oka3_onl@k`05onl@k`03o`000?o;=<_o
bcC;00WobcC;0_l00006ok9=/P03o`000?meRWGoMHYe013oMHYe00?o0000oe>/DomC[5<01_mC[5<0
0ol0003o:=LXobSG:007obSG:003o`000?lOgaoo7mlO00Co7mlO0ol0000>oacS7003o`000?l9mPWo
2OH900?o00001OlTfb@00ol0003oEJYEoeFZE@06oeFZE@03o`000?m3_4?o@ka300[o@ka300?o0000
of^DJom[U6/02?m[U6/00ol0003o^dBkok]4^`0=ok]4^`03o`000?oL8mcog2?L00Gog2?L0ol00004
oka3_003o`000?o^4NkokQ7^00OokQ7^00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003oka3_onl@k`06onl@k`03o`000?o;=<_obcC;00GobcC;0ol00008ok9=/P03o`000?meRWGoMHYe
017oMHYe00Co0000oe>/DomC[5?oDjaC1?l0000;obSG:0;o000000Co7mlOo`000?l0003o00000old
bc@2o`0000_o7><L00?o0000o`Wf2Ol9mPT01?l9mPT2o`0000?o9=/T00?o0000oeFZEOmEZUD01_mE
ZUD00ol0003o@ka3od>l@`0:od>l@`03o`000?m[U6_oJiA[00OoJiA[00?o0000ok]4^onkA;/03_nk
A;/00ol0003og2?Lom`Sg008om`Sg0Co00002_o^4Nh00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003oka3_onl@k`07onl@k`03o`000?o;=<_obcC;00;obcC;0_l0000<ok9=/P03o`000?meRWGo
MHYe013oMHYe1?l00003odFjA@03o`000?lXebSo:=LX00_o:=LX00?o0000ocC;=?ldbc@01_ldbc@0
0ol0003o7><LoacS7007oacS7003o`000?l9mPWo2OH900Oo2OH93?l0000>od>l@`03o`000?m[U6_o
JiA[00KoJiA[00?o0000ok]4^onkA;/03_nkA;/00ol0003og2?Lom`Sg00;om`Sg003o`000?o^4Nko
kQ7^00OokQ7^00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?o_4>ooka3_00Woka3_00Co0000ol/d
bol0003o00003_nbCK800ol0003oMHYeogF:M@0?ogF:M@03o`000?m5^TGoAKY500KoAKY500?o0000
obSG:?lXebP02_lXebP00ol0003o=</docC;=007ocC;=0;o00001_lLha`00ol0003o2OH9o`Wf2@08
o`Wf2@03o`000?mLXecoG:=L00SoG:=L00?o0000od>l@om3_4<03?m3_4<00ol0003oJiA[of^DJ`05
of^DJ`03o`000?nkA;_o^dBk00oo^dBk0_l0000=om`Sg003o`000?o^4NkokQ7^00KokQ7^00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o_4>ooka3_00[oka3_00?o0000ok9=/_nbCK803_nbCK800ol0
003oMHYeogF:M@0>ogF:M@03o`000?m5^TGoAKY500OoAKY500?o0000obSG:?lXebP02_lXebP00ol0
003o=</docC;=009ocC;=0;o00000olLha`00ol0003o2OH9o`Wf2@09o`Wf2@03o`000?mLXecoG:=L
00WoG:=L00?o0000od>l@om3_4<02_m3_4<4o`0000CoJiA[00?o0000ok]4^onkA;/04?nkA;/01?l0
003ofBKIo`000?l0000<om`Sg003o`000?o^4NkokQ7^00GokQ7^00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?o_4>ooka3_00[oka3_00?o0000ok9=/_nbCK803onbCK8@o`0000[oAKY500?o0000obSG
:?lXebP02OlXebP00ol0003o4>l@o`00000<ocC;=005o`000?lLhaco0000o`Wf2Ol000002_l9mPT0
0ol0003oG:=LoebSG009oebSG003o`000?m3_4?o@ka300Oo@ka30ol00004og><L`?o000000?oJiA[
o`000?nkA;/04OnkA;/01?l0003ofBKIomTVfOoI9]T2o`0000_og2?L00?o0000onhAk_o^4Nh00oo^
4Nh00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onl@koo_4>l02_o_4>l00ol0003o/Tfbok9=/P0?
ok9=/P03o`000?mjQG[oNXEj00coNXEj00?o0000odFjAOm5^TD02Om5^TD00ol0003o:=LXobSG:007
obSG:004o`000?l@ka3o4>l@o`0000go=</d00Go0000o`Wf2Ol9mPWo2OH9o`000009o`Wf2@03o`00
0?mLXecoG:=L00[oG:=L00?o0000od>l@om3_4<00om3_4<3o`0000[oLhac00?o0000ok]4^onkA;/0
4?nkA;/00ol0003ofBKIomTVf@04omTVf@;o00002_oL8m`00ol0003okQ7^onhAkP04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000coka3_00?o0000ok9=/_nbCK803onbCK800ol0003oNXEjogZ5NP0<ogZ5NP03o`000?m5
^TGoAKY500WoAKY500?o0000obSG:?lXebP01_lXebP00ol0003o4>l@oa3_4002oa3_4003o`000?ld
bcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT00_l9mPT00ol0003o2OH9o`Wf2@06o`Wf2@03o`000?mL
XecoG:=L00[oG:=L00?o0000od>l@om3_4<00ol0000=og><L`03o`000?nkA;_o^dBk013o^dBk00?o
0000omTVfOoI9]T01_oI9]T2o`0000Wog2?L0_l00004oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000onl@koo_4>l02_o_4>l00ol0003o/Tfbok9=/P0=ok9=/P?o00003omjQGX0
0ol0003oAKY5odFjA@08odFjA@03o`000?lXebSo:=LX00Go:=LX00?o0000oa3_4?l@ka000ol@ka00
0ol0003o=</docC;=00:ocC;=003o`000?l9mPWo2OH900?o2OH900?o0000o`Wf2Ol9mPT01Ol9mPT0
0ol0003oG:=LoebSG00;oebSG0;o00004OmcS7<00ol0003o^dBkok]4^`0?ok]4^`03o`000?oI9]Wo
fBKI00SofBKI0_l00007om`Sg003o`000?ok1?_on`Ck00Con`Ck00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000onl@koo_4>l02?o_4>l00ol0003o/Tfbok9=/P09ok9=/PGo00000_mnPGh00ol0
003oNXEjogZ5NP0=ogZ5NP03o`000?m5^TGoAKY500WoAKY500?o0000obSG:?lXebP01?lXebP00ol0
003o4>l@oa3_4004oa3_4003o`000?ldbcCo=</d00So=</d00?o0000o`Wf2Ol9mPT01Ol9mPT00ol0
003o2OH9o`Wf2@04o`Wf2@03o`000?mLXecoG:=L00_oG:=L00?o0000og><LomcS7<04?mcS7<00ol0
003o^dBkok]4^`0?ok]4^`03o`000?oI9]WofBKI00[ofBKI0_l00004om`Sg003o`000?ok1?_on`Ck
00Kon`Ck0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003oka3_onl@k`07onl@k`03o`000?nbCK;o/Tfb00Co/Tfb1Ol00007ogj1OP03
o`000?mjQG[oNXEj00goNXEj00?o0000odFjAOm5^TD02Om5^TD00ol0003o:=LXobSG:003obSG:003
o`000?l@ka3o4>l@00Go4>l@00?o0000ocC;=?ldbc@02?ldbc@00ol0003o2OH9o`Wf2@06o`Wf2@03
o`000?l9mPWo2OH900?o2OH900?o0000oebSG?mLXe`02omLXe`00ol0003oLhacog><L`0@og><L`03
o`000?nkA;_o^dBk00oo^dBk00?o0000omTVfOoI9]T03?oI9]T2o`000003om`Sg?l0003on`Ck00[o
n`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o_4>ooka3_00Ooka3_00?o0000ok9=/_l00000
1?l0000<ogj1OP03o`000?mjQG[oNXEj00koNXEj00?o0000odFjAOm5^TD02?m5^TD00ol0003o:=LX
obSG:002obSG:003o`000?l@ka3o4>l@00Oo4>l@00?o0000ocC;=?ldbc@01oldbc@00ol0003o2OH9
o`Wf2@07o`Wf2@03o`000?l9mPWo2OH900;o2OH900?o0000oebSG?mLXe`02omLXe`00ol0003oLhac
og><L`0Aog><L`03o`000?nkA;_o^dBk00go^dBk00?o0000omTVfOoI9]T03ooI9]T00ol0003on`Ck
oo/4n`0;oo/4n`;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000onl@koo_4>l01Oo_4>l3o`00017oOX5n00?o0000ogZ5N_mjQGX03_mj
QGX00ol0003oAKY5odFjA@09odFjA@04o`000?lXebSo:=LXo`0000[o4>l@00?o0000ocC;=?ldbc@0
1oldbc@00ol0003o2OH9o`Wf2@08o`Wf2@05o`000?l9mPWo2OH9o`Wf2Ol000003OmLXe`00ol0003o
Lhacog><L`0Aog><L`?o00003OnkA;/00ol0003ofBKIomTVf@0?omTVf@03o`000?ok1?_on`Ck00go
n`Ck00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_o_4>l2o`0000;oc3?<00?o0000ogj1O_mnPGh03omnPGh00ol0003o
NXEjogZ5NP0>ogZ5NP03o`000?m5^TGoAKY500SoAKY51Ol0000;oa3_4003o`000?ldbcCo=</d00Ko
=</d00?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o2OH9o`Wf2Ol0000=oebSG003o`000?mcS7?oLhac
017oLhac00?o0000oe^TFomKY5/00ol0000:ok]4^`Co00003OoI9]T00ol0003on`Ckoo/4n`0?oo/4
n`03o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000onl@koo_4>ooka3_0_l00005ol`cc003o`000?mnPGkoOX5n00koOX5n00?o0000ogZ5
N_mjQGX03_mjQGX00ol0003oAKY5odFjA@07odFjA@03o`000?ll`cco?<<l00?o?<<l00?o0000oa3_
4?l@ka002?l@ka000ol0003o=</docC;=005ocC;=003o`000?l9mPWo2OH900[o2OH91Ol0000<oebS
G003o`000?mcS7?oLhac013oLhac00?o0000oe^TFomKY5/01?mKY5/3o`0000Ko^dBk00?o0000omPW
f?oH9mP00_oH9mP5o`0000SofBKI00?o0000oo/4nook1?/04?ok1?/00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o_4>ooka3_00?o
ka3_00?o0000ol`cc?o<<l`01?o<<l`00ol0003oOX5nogj1OP0=ogj1OP03o`000?mjQG[oNXEj00oo
NXEj00?o0000odFjAOm5^TD01?m5^TD2o`0000Oo?<<l00?o0000oa3_4?l@ka001ol@ka0Eo`0000Go
5^TF00?o0000oebSG?mLXe`02?mLXe`3o`00013oLhac00?o0000oe^TFomKY5/02?mKY5/3o`0000;o
^dBk00?o0000omPWf?oH9mP02?oH9mP5o`0000?ofBKI00?o0000oo/4nook1?/04?ok1?/00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?o_4>ooka3_00Coka3_00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oOX5nogj1OP0;ogj1OPCo0000
3omjQGX00ol0003oAKY5odFjA@03odFjA@03o`000?ll`cco?<<l00So?<<l00?o0000oa3_4?l@ka00
1?l@ka02o`0000So>l@k00?o0000obSG:?lXebP02?lXebP00ol0003o5^TFoaKY5P05oaKY5P;o0000
1_mLXe`2o`0000?oD:m@00?o0000og><LomcS7<03?mcS7<00ol0003oFjAKoe^TF`0<oe^TF`;o0000
4?oH9mP3o`0001?on`Ck00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003oka3_onl@k`05onl@k`03o`000?o<<lcoc3?<00Koc3?<00?o
0000ogj1O_mnPGh02OmnPGh00ol0003oP7n0o`000002oeVVF@?o00003?mjQGX01?l0003oAKY5odFj
AOm5^TD2o`0000co?<<l00?o0000oa3_4?l@ka000_l@ka000ol0003o>l@koc_4>`08oc_4>`03o`00
0?lXebSo:=LX00So:=LX00?o0000oaKY5_lFjAH01olFjAH00ol0003oG:=LoebSG002oebSG003o`00
0?m@[e3oD:m@00CoD:m@0_l0000;og><L`03o`000?mKY5_oFjAK00coFjAK00?o0000oiMXUol00000
4_oH9mP00ol0003on`Ckoo/4n`0@oo/4n`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003oka3_onl@k`06onl@k`03o`000?o<<lcoc3?<00Ooc3?<00?o
0000ogj1O_mnPGh01_mnPGh2o`0000;oP7n000?o0000oeVVFOmIYUT00omIYUT3o`0000[oNXEj00?o
0000odFjAOl000003oll`c`01?l0003o4>l@o`000?l0000;oc_4>`03o`000?lXebSo:=LX00So:=LX
00?o0000oaKY5_lFjAH02?lFjAH01?l0003oG:=Lo`000?l00009oe2_D003o`000?mcS7?oLhac00Oo
Lhac00?o0000oe^TFomKY5/03?mKY5/01?l0003oUfRGoiMXUol0000ComPWf003o`000?ok1?_on`Ck
00con`Ck0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000onl@koo_4>l01oo_4>l00ol0003oc3?<ol`cc008ol`cc003o`000?mnPGkoOX5n00Co
OX5n00?o0000oh1oP?n0Oh000on0Oh000ol0003oFJIIoeVVF@05oeVVF@?o00001_mjQGX4o`00013o
?<<l00?o0000oc_4>olka3/03?lka3/00ol0003o:=LXobSG:007obSG:003o`000?lFjAKo5^TF00Wo
5^TF00?o0000oe2_D?m@[e002_m@[e02o`0000KoLhac00?o0000oe^TFomKY5/03?mKY5/00ol0003o
UfRGoiMXU`02oiMXU`03o`000?oH9mSof2OH00oof2OH00?o0000on`Ck?l000002ook1?/2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003oka3_onl@k`08onl@k`03o`000?o<<lcoc3?<00Woc3?<00Co0000ogj1O_mnPGko
OX5n0_l00006oh1oP003o`000?mIYUWoFJII00SoFJII0ol000000omjQG[o0000o`000004odbcC003
o`000?ll`cco?<<l00go?<<l00?o0000oc_4>olka3/03?lka3/00ol0003o:=LXobSG:007obSG:003
o`000?lFjAKo5^TF00Wo5^TF00?o0000oe2_D?m@[e003?m@[e000ol0003oLhacog><L`03o`0000ko
FjAK00?o0000oiMXUonGJ9L00onGJ9L00ol0003of2OHomPWf00>omPWf005o`000?o/4ncok1?/on`C
k?l000002?ok1?/2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003oka3_onl@k`09onl@k`03o`000?o<<lcoc3?<00[o
c3?<00?o0000ogj1O_l000002?n0Oh000ol0003oFJIIoeVVF@0;oeVVF@03o`000?m</dcoC;=<00Go
C;=<00?o0000occ3??ll`c`03?ll`c`00ol0003o>l@koc_4>`0<oc_4>`03o`000?lXebSo:=LX00Oo
:=LX00?o0000oaKY5_lFjAH02?lFjAH2o`0000ooD:m@0_l00002ofRGJ003o`000?mKY5_oFjAK00_o
FjAK00?o0000oiMXUonGJ9L01?nGJ9L00ol0003of2OHomPWf00=omPWf003o`000?o/4ncok1?/00?o
k1?/00?o0000oo/4nook1?/00_ok1?/3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;onl@k`03o`000?o<<lcoc3?<00_oc3?<00?o0000oh1oP?n0Oh00
1on0Oh000ol0003oFJIIoeVVF@0;oeVVF@03o`000?m</dcoC;=<00KoC;=<00?o0000occ3??ll`c`0
2oll`c`2o`0000go>l@k00?o0000obSG:?lXebP01olXebP00ol0003o5^TFoaKY5P07oaKY5P04o`00
0?lSg2?o8m`So`0000koD:m@00?o0000ofRGJ?mXUfP00_mXUfP00ol0003oFjAKoe^TF`09oe^TF`03
o`000?nGJ9OoUfRG00KoUfRG00?o0000omPWf?oH9mP02ooH9mP00ol0003ok1?/on`Ck005on`Ck004
o`000?ok1?_o0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000oo`3o?ol0o`00_ol0o`3o`0000Soka3_00?o0000ol`cc?o<<l`02_o<<l`2o`0000Wo
P7n000?o0000oeVVFOmIYUT02omIYUT00ol0003oC;=<odbcC007odbcC003o`000?ll`cco?<<l00Wo
?<<l00Co0000o`Sg2?l8m`So00003?lka3/00ol0003o:=LXobSG:007obSG:003o`000?lFjAKo5^TF
00Ko5^TF00Go0000ob?L8olSg2?o8m`So`00000>oe2_D003o`000?mXUfSoJ9MX00?oJ9MX00?o0000
oe^TFomKY5/01omKY5/00ol0003oUfRGoiMXU`07oiMXU`03o`000?oH9mSof2OH00[of2OH00?o0000
on`Ck?o/4n`01oo/4n`00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00Goo0?l0_l00006onl@k`03o`000?o<<lcoc3?<
00Woc3?<00Co0000okQ7^?nhAkSo00002On0Oh000ol0003oFJIIoeVVF@09oeVVF@03o`000?m</dco
C;=<00WoC;=<00?o0000occ3??ll`c`01oll`c`00ol0003o2?L8o`Sg2002o`Sg2003o`000?lka3_o
>l@k00Wo>l@k00?o0000obSG:?lXebP01olXebP00ol0003o5^TFoaKY5P05oaKY5P03o`000?lSg2?o
8m`S00?o8m`S00?o0000oe2_D?m@[e002_m@[e000ol0003oJ9MXofRGJ005ofRGJ003o`000?mKY5_o
FjAK00GoFjAK00?o0000oiMXUonGJ9L02?nGJ9L00ol0003of2OHomPWf009omPWf003o`000?o/4nco
k1?/00Sok1?/00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo0?loo`3o007oo`3o0?o00000_o_4>l3o`0000Woc3?<00?o0000okQ7
^?nhAkP00_nhAkP00ol0003oP7n0oh1oP006oh1oP003o`000?mIYUWoFJII00WoFJII00?o0000odbc
C?m</d`02_m</d`00ol0003o?<<locc3?005occ3?003o`000?l8m`So2?L800Co2?L800?o0000oc_4
>olka3/02?lka3/00ol0003o:=LXobSG:007obSG:003o`000?lFjAKo5^TF00Co5^TF00?o0000ob?L
8olSg2<01?lSg2<00ol0003oD:m@oe2_D00:oe2_D003o`000?mXUfSoJ9MX00KoJ9MX00?o0000oe^T
FomKY5/00omKY5/00ol0003oUfRGoiMXU`09oiMXU`03o`000?oH9mSof2OH00Sof2OH00?o0000on`C
k?o/4n`02Oo/4n`00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?ol0ocoo0?l00[oo0?l0_l00003onLHi`?o00001Oo<<l`00ol0003o
^4NhokQ7^003okQ7^003o`000?n0Oh3oP7n000KoP7n000?o0000oeVVFOmIYUT02OmIYUT00ol0003o
C;=<odbcC00;odbcC003o`000?ll`cco?<<l00?o?<<l00?o0000o`Sg2?l8m`P01_l8m`P00ol0003o
>l@koc_4>`08oc_4>`03o`000?lXebSo:=LX00Ko:=LX00?o0000oaKY5_lFjAH00_lFjAH2o`0000So
8m`S00?o0000oe2_D?m@[e002Om@[e000ol0003oJ9MXofRGJ007ofRGJ005o`000?mKY5_oFjAKoe^T
Fol000003OnGJ9L00ol0003of2OHomPWf006omPWf003o`000?o/4ncok1?/00[ok1?/00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o0?loo`3o00:oo`3o003o`000?oW6>OoiaSW00GoiaSW0ol000000oo<<lco0000okQ7^006okQ7^003
o`000?n0Oh3oP7n000GoP7n000?o0000oeVVFOmIYUT02OmIYUT00ol0003oC;=<odbcC00<odbcC005
o`000?ll`cco?<<locc3??l000002_l8m`P00ol0003o>l@koc_4>`07oc_4>`03o`000?lXebSo:=LX
00Ko:=LX00?o0000oaKY5_l000000_l000000omGZ5Oo0000ob?L8`07ob?L8`03o`000?m@[e3oD:m@
00SoD:m@00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oFjAKo`00000=oiMXU`Co00001OoH9mP00ol0
003ok1?/on`Ck00;on`Ck003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSWonLHi`08onLHi`03
o`000?nhAkSo^4Nh00Oo^4Nh00?o0000oh1oP?n0Oh001?n0Oh000ol0003oFJIIoeVVF@09oeVVF@03
o`000?m</dcoC;=<00goC;=<00?o0000occ3??l000003?l8m`P:o`0000Oo:=LX0ol00005oeNXE`03
o`000?lSg2?o8m`S00Ko8m`S00?o0000oe2_D?m@[e001om@[e000ol0003oJ9MXofRGJ00:ofRGJ003
o`000?nGJ9OoUfRG00_oUfRG00?o0000oll`coo?<<l00_o?<<l3o`000003omPWf?l0003ok1?/00_o
k1?/0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?ol0ocoo0?l00[oo0?l00?o0000onLHiooW6>L02OoW6>L00ol0003o^4NhokQ7^007okQ7^003o`00
0?n0Oh3oP7n000GoP7n000?o0000oeVVFOmIYUT01omIYUT00ol0003oC;=<odbcC00?odbcC0;o0000
2ol8m`P00ol0003oBKI9odVfB@07odVfB@03o`000?lXebSo:=LX00;o:=LX0ol00008oeNXE`03o`00
0?lSg2?o8m`S00Ko8m`S00?o0000oe2_D?m@[e001om@[e000ol0003oJ9MXofRGJ00:ofRGJ003o`00
0?nGJ9OoUfRG00[oUfRG00?o0000oll`coo?<<l01_o?<<l00ol0003ok1?/on`Ck008on`Ck0?o0000
0_oa3_400ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onLHiooW6>L02OoW6>L00ol0003o^4NhokQ7
^008okQ7^003o`000?n0Oh3oP7n000CoP7n000?o0000oeVVFOmIYUT01omIYUT00ol0003oC;=<odbc
C00>odbcC004o`000?lKi1_o6n@Ko`0000Wo2?L800?o0000odVfBOm9]TT02Om9]TT01?l0003o:=LX
o`000?l0000<oeNXE`03o`000?lSg2?o8m`S00Ko8m`S00?o0000oe2_D?m@[e001_m@[e000ol0003o
J9MXofRGJ00;ofRGJ003o`000?nGJ9OoUfRG00OoUfRG0_l00009oll`c`03o`000?o/4ncok1?/00Co
k1?/1?l00006oo4>l@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oiaSWonLHi`09onLHi`03o`00
0?nhAkSo^4Nh00So^4Nh00?o0000oh1oP?n0Oh000on0Oh0>o`0000goC;=<00?o0000oa_T6olKi1/0
0_lKi1/00ol0003o2?L8o`Sg2005o`Sg2003o`000?m9]TWoBKI900_oBKI900?o0000oeNXEomGZ5L0
3?mGZ5L00ol0003o8m`Sob?L8`06ob?L8`03o`000?m@[e3oD:m@00GoD:m@00?o0000ofRGJ?mXUfP0
3?mXUfP00ol0003oUfRGoiMXU`06oiMXU`03o`000?o?<<oocc3?00[occ3?00?o0000on`Ck?o/4n`0
0ol0000:oo4>l@?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000okQ7^?nhAkP02?nh
AkP01Ol0003oP7n0oh1oP?n0Oh3o000000_oGj1O00?o0000o`Sg2?l8m`P00ol00009odbcC003o`00
0?lKi1_o6n@K00Co6n@K00?o0000o`Sg2?l8m`P00ol8m`P00ol0003oBKI9odVfB@0<odVfB@03o`00
0?mGZ5OoEjQG00goEjQG00?o0000ob?L8olSg2<01_lSg2<00ol0003oD:m@oe2_D003oe2_D0?o0000
3OmXUfP00ol0003oUfRGoiMXU`05oiMXU`03o`000?o?<<oocc3?00cocc3?0_l0000=oo4>l@03o`00
0?om0_goo@;m00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo0?loo`3o009oo`3o003o`000?oW6>OoiaSW00_oiaSW00?o0000okQ7^?nhAkP02?nh
AkP4o`0000coGj1O00?o0000o`Sg2?l8m`P00ol8m`P3o`0000GoC;=<00?o0000oa_T6olKi1/01_lK
i1/01Ol0003o2?L8o`Sg2?l8m`So000000ooBKI900?o0000oeNXEomGZ5L03OmGZ5L00ol0003o8m`S
ob?L8`06ob?L8`03o`000?m@[e3oD:m@00?o00000ol`cc000ol0003oJ9MXofRGJ00;ofRGJ003o`00
0?nGJ9OoUfRG00?oUfRG00?o0000oll`coo?<<l03Oo?<<l00ol0003ol@kaoo4>l@0;oo4>l@03o`00
0?om0_goo@;m00Coo@;m0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?ol0ocoo0?l00Soo0?l00?o0000onLHiooW6>L02_oW6>L3o`0000Ko^4Nh0ol0
0003oj=LX`03o`000?mOX5ooGj1O00[oGj1O00?o0000o`Sg2?l8m`P01_l8m`P3o`000003odbcC?l0
003o6n@K00Wo6n@K00?o0000o`Sg2?l000004?m9]TT00ol0003oEjQGoeNXE`0=oeNXE`03o`000?lS
g2?o8m`S00Oo8m`S0_l00007oc3?<003o`000?mXUfSoJ9MX00[oJ9MX00Co0000oiMXUonGJ9OoUfRG
0ol0000?oll`c`03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?ol0ocoo0?l00Koo0?l00?o0000onLHiooW6>L02_oW
6>L01?l0003ofBKIomTVfOoI9]T2o`000004okQ7^?l0003o0000o`0000KoXebS00?o0000oenPGomO
X5l02_mOX5l00ol0003o2?L8o`Sg2009o`Sg2003o`000?lKi1_o6n@K00[o6n@K00?o0000odVfBOm9
]TT03om9]TT00ol0003oEjQGoeNXE`0>oeNXE`03o`000?lSg2?o8m`S00Ko8m`S00?o0000oc3?<?l`
cc001ol`cc04o`0000SoJ9MX00Co0000oiMXUonGJ9Oo00000onLHi`2o`0000gocc3?00?o0000oo4>
lOoa3_402_oa3_400ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?ol0ocoo0?l00Goo0?l00?o0000onLHiooW6>L02OoW6>L00ol0003o
fBKIomTVf@04omTVf@03o`000?nSG:?oXebS00OoXebS00?o0000oenPGomOX5l02OmOX5l00ol0003o
2?L8o`Sg200:o`Sg2003o`000?lKi1_o6n@K00[o6n@K00?o0000odVfBOm9]TT03om9]TT00ol0003o
EjQGoeNXE`0>oeNXE`03o`000?lSg2?o8m`S00Go8m`S00?o0000oc3?<?l`cc002?l`cc001?l0003o
FJIIoeVVFOmIYUT7o`0000;oJ9MX0_l00006oiaSW0;o00003?o?<<l00ol0003ol@kaoo4>l@09oo4>
l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000oo`3o?ol0o`01?ol0o`00ol0003oiaSWonLHi`08onLHi`03o`000?oI9]WofBKI00Go
fBKI00?o0000oj=LXonSG:<02?nSG:<00ol0003oGj1OoenPG`08oenPG`03o`000?l8m`So2?L800[o
2?L800?o0000oa_T6olKi1/02olKi1/00ol0003oBKI9odVfB@0>odVfB@03o`000?mGZ5OoEjQG00ko
EjQG1Ol00002ob?L8`03o`000?l`cc3o<<l`00Wo<<l`00?o0000oeVVFOmIYUT02?mIYUT3o`0000Wo
W6>L0_l0000:oll`c`03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oW6>OoiaSW00SoiaSW00?o0000omTVfOoI9]T01ooI9]T00ol0003oXebSoj=LX`07oj=LX`03o`00
0?mOX5ooGj1O00SoGj1O00?o0000o`Sg2?l8m`P02_l8m`P00ol0003o6n@Koa_T6`0:oa_T6`;o0000
3_m9]TT3o`0000goEjQG0ol00005oejQGP;o00002ol`cc000ol0003oFJIIoeVVF@0;oeVVF@;o0000
2_nLHi`2o`0000Oocc3?0ol00009oo4>l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000oo`3o?ol0ocoo0?l3?l0000:omTVf@03o`00
0?nSG:?oXebS00OoXebS00?o0000oenPGomOX5l02?mOX5l>o`0000Wo6n@K0ol000000ol1oP7o0000
odVfB@0:odVfB@?o00000_mRWF800ol0003oEjQGoeNXE`09oeNXE`;o00002OmNXEh00ol0003o<<l`
oc3?<009oc3?<003o`000?mIYUWoFJII00_oFJII00?o0000og^4Nol000002onLHi`2o`0000Cocc3?
00Co0000onHIi_oV6NKoiQWV0_l00007oo4>l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000oo`3o?l000002ook1?/00ol0003ofBKI
omTVf@09omTVf@03o`000?nSG:?oXebS00KoXebS00?o0000oenPGomOX5l02?mOX5l00ol0003o5>/D
oaC[500:oaC[5003o`000?lKi1_o6n@K00Co6n@K0ol00005o`7n0@03o`000?m9]TWoBKI900CoBKI9
1?l00006of:MHP03o`000?mGZ5OoEjQG00KoEjQG0_l0000;oejQGP03o`000?l`cc3o<<l`00Wo<<l`
00?o0000oeVVFOmIYUT02_mIYUT01Ol0003oNhAkog^4NomkQ7_o000000coW6>L0_l000000oo?<<oo
0000onHIiP05onHIiP03o`000?oa3_7ol@ka00?ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oI9]WofBKI00SofBKI00?o0000oj=LXonSG:<01_nSG:<00ol0003oGj1OoenPG`07oenPG`03o`00
0?lDjaCo5>/D00_o5>/D00?o0000oa_T6olKi1/00_lKi1/2o`0000Wo0Oh100?o0000odVfBOm9]TT0
0ol0000;of:MHP03o`000?mGZ5OoEjQG00;oEjQG0ol0000>oejQGP03o`000?l`cc3o<<l`00Oo<<l`
00?o0000oeVVFOmIYUT02omIYUT00ol0003oNhAkog^4N`02og^4N`03o`000?nLHicoW6>L00_oW6>L
00?o0000onHIi_oV6NH01_oV6NH2o`0000?ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oI
9]WofBKI00OofBKI00?o0000oj=LXonSG:<01onSG:<00ol0003oGj1OoenPG`05oenPG`?o00003OlD
ja@4o`0000_o0Oh10ol0000?of:MHP04o`000?mGZ5Oo0000o`00017oGZ5N00?o0000oc3?<?l`cc00
1ol`cc000ol0003oFJIIoeVVF@0:oeVVF@03o`000?mkQ7_oNhAk00CoNhAk00?o0000oiaSW?nLHi`0
1onLHi`3o`0000_oiQWV1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omTVfOoI9]T02?oI9]T00ol0003oXebSoj=L
X`06oj=LX`03o`000?mOX5ooGj1O00;oGj1O0ol00003ocno?`03o`000?lDjaCo5>/D00[o5>/D00?o
0000o`7n0Ol1oP402ol1oP400ol0003o2OH9o`00000Aof:MHP03o`000?mNXEkoGZ5N017oGZ5N00?o
0000oc3?<?l`cc001ol`cc000ol0003oFJIIoeVVF@0:oeVVF@03o`000?mkQ7_oNhAk00GoNhAk00Co
0000oiaSW?nLHicoW6>L1Ol00002ojaC[003o`000?oV6NKoiQWV00WoiQWV00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000omTVfOoI9]T01ooI9]T00ol0003oXebSoj=LX`05oj=LX`?o0000
00?oGj1Oo`000?l000001olo_cl00ol0003o5>/DoaC[5008oaC[50?o00002_l1oP42o`0000;o2OH9
00?o0000of:MH_mRWF803omRWF800ol0003oGZ5NoejQGP0AoejQGP03o`000?l`cc3o<<l`00Oo<<l`
00?o0000oeVVFOmIYUT02OmIYUT00ol0003oNhAkog^4N`07og^4N`?o00001on/Dj`00ol0003oiQWV
onHIiP09onHIiP03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000omTVfOoI9]T01ooI
9]T4o`0000;oXebS0_l00003oieRW@03o`000?lo_coo?klo00So?klo0_l00006oaC[50;o00000olG
j1L00ol0003o0Oh1o`7n0@06o`7n0@03o`000?l9mPWo2OH900?o2OH900?o0000of:MH_mRWF803_mR
WF800ol0003oGZ5NoejQGP0BoejQGP03o`000?l`cc3o<<l`00Go<<l`00?o0000oeVVFOmIYUT02OmI
YUT00ol0003oNhAkog^4N`08og^4N`03o`000?n/Djco[5>/00Oo[5>/00?o0000onHIi_oV6NH02?oV
6NH00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oI9]WofBKI00CofBKI0_l00004
omhQgP;o00001OnMHYd00ol0003o?kloocno?`0:ocno?`03o`000?lDjaCo5>/D00;o5>/D00?o0000
oaOX5olGj1L01?lGj1L00ol0003o0Oh1o`7n0@04o`7n0@03o`000?l9mPWo2OH900Co2OH900?o0000
of:MH_mRWF803_mRWF800ol0003oGZ5NoejQGP0BoejQGP[o00002_mIYUT00ol0003oNhAkog^4N`08
og^4N`03o`000?n/Djco[5>/00Oo[5>/00?o0000onHIi_oV6NH02?oV6NH00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003ofBKIomTVfOoI9]T2o`0000OogR7N00?o0000oieRWOnMHYd01?nMHYd0
0ol0003o?kloocno?`0:ocno?`04o`000?lDjaCo0000o`0000So5nPG00Co0000o`7n0Ol1oP7o0Oh1
0_l00007o`Wf2@03o`000?mRWF;oHYeR00koHYeR00?o0000oejQG_mNXEh04_mNXEh00ol0003oAKY5
odFjA@07odFjA@03o`000?mIYUWoFJII00KoFJII00?o0000og^4NomkQ7/02_mkQ7/00ol0003o[5>/
ojaC[006ojaC[003o`000?oV6NKoiQWV00SoiQWV00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oI
9]Wo0000o`0000WogR7N00?o0000oieRWOnMHYd01?nMHYd00ol0003o?kloocno?`0;ocno?`03o`00
0?lGj1Oo5nPG00Wo5nPG00?o0000o`7n0Ol000002Ol9mPT00ol0003oHYeRof:MHP0>of:MHP;o0000
4_mNXEh00ol0003oAKY5odFjA@09odFjA@;o00001_mIYUT00ol0003oNhAkog^4N`0:og^4N`03o`00
0?n/Djco[5>/00Ko[5>/00?o0000onHIi_oV6NH02?oV6NH00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omhQg_oN8Mh02OoN8Mh00ol0003oWF:MoieRW@05oieRW@03o`000?lo_coo?klo00[o?klo00?o
0000oaOX5olGj1L02_lGj1L2o`0000Wo2OH900?o0000of:MH_mRWF803_mRWF800ol0003oB;M8o`00
0002o`0000ooGZ5N00?o0000odFjAOm5^TD02om5^TD00ol0003oFJIIoeVVF@03o`0000goNhAk00?o
0000ojaC[?n/Dj`01_n/Dj`00ol0003oiQWVonHIiP07onHIiP03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ogR7NomhQgP09omhQgP03o`000?nMHYgoWF:M00GoWF:M00?o0000ocno?olo_cl02Olo_cl2
o`0000_o5nPG0_l0000;o`Wf2@03o`000?mRWF;oHYeR00coHYeR00?o0000odRgB?m8]dP00om8]dP3
o`0000coGZ5N00?o0000odFjAOm5^TD03?m5^TD2o`0000;oJYEZ00?o0000og^4NomkQ7/03?mkQ7/0
0ol0003o[5>/ojaC[005ojaC[003o`000?oV6NKoiQWV00OoiQWV00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oN8MkogR7N00[ogR7N00?o0000oieRWOnMHYd01_nMHYd00ol0003o?kloocno?`07ocno
?`03o`000?lhacSo000000[o5nPG00Co0000o`Sg2?l8m`So00002_l9mPT00ol0003oHYeRof:MHP0<
of:MHP03o`000?m8]dSoB;M800KoB;M80_l00008oejQGP;o00003om5^TD00ol0003oJYEZofZEJP02
ofZEJP03o`000?mkQ7_oNhAk00_oNhAk00?o0000ojaC[?n/Dj`01On/Dj`00ol0003oiQWVonHIiP07
onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ogR7NomhQgP0:omhQgP03o`000?nMHYgoWF:M
00KoWF:M00?o0000ocno?olo_cl01_lo_cl01Ol0003o><LhocS7>?lhacSo000000So5nPG00?o0000
o`Sg2?l8m`P00_l8m`P00ol0003o2OH9o`Wf2@06o`Wf2@Co00003?mRWF800ol0003oB;M8odRgB008
odRgB0?o00000_mNXEh3o`000003ocg2?Ol0003oAKY500goAKY500?o0000ofZEJ_mZUFX01?mZUFX0
0ol0003oNhAkog^4N`0:og^4N`03o`000?n/Djco[5>/00Go[5>/00?o0000onHIi_oV6NH01_oV6NH0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omhQg_oN8Mh02ooN8Mh00ol0003oWF:MoieRW@07oieR
W@03o`000?lo_coo?klo00?o?klo0_l00005ocS7>003o`000?lGj1Oo5nPG00Co5nPG00?o0000o`Sg
2?l8m`P00ol8m`P00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?lUfRGo9MXU00;o9MXU0ol00007of:M
HP;o00003_m8]dP2o`0000Go?L8m00?o0000odFjAOm5^TD02_m5^TD00ol0003oJYEZofZEJP05ofZE
JP03o`000?mkQ7_oNhAk00_oNhAk00?o0000ojaC[?n/Dj`01?n/Dj`00ol0003oiQWVonHIiP06onHI
iP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ogR7NomhQgP0;omhQgP03o`000?nMHYgoWF:M00Oo
WF:M00?o0000ocno?olo_cl00_lo_cl00ol0003o><LhocS7>006ocS7>003o`000?lGj1Oo5nPG00;o
5nPG00?o0000o`Sg2?l8m`P01Ol8m`P00ol0003o2OH9o`Wf2@02o`Wf2@;o00002?lUfRD3o`0000;o
HYeR0_l000000ol^dBko0000odRgB00=odRgB003o`000?lm`Sgo?L8m00Go?L8m00?o0000odFjAOm5
^TD02?m5^TD00ol0003oJYEZofZEJP07ofZEJP03o`000?mkQ7_oNhAk00[oNhAk00?o0000ojaC[?n/
Dj`01?n/Dj`00ol0003oiQWVonHIiP06onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ogR7N
omhQgP0<omhQgP03o`000?nMHYgoWF:M00SoWF:M00Co0000ocno?olo_coo00002OlhacP01Ol0003o
5nPGoaOX5olGj1Oo000000So2?L800Go0000o`Wf2Ol9mPWo2OH9o`00000=obGJ9@;o00001?l^dBh0
0ol0003oB;M8odRgB00;odRgB003o`000?lm`Sgo?L8m00Ko?L8m00?o0000odFjAOm5^TD01om5^TD0
0ol0003oJYEZofZEJP08ofZEJPCo00002?mkQ7/00ol0003o[5>/ojaC[004ojaC[003o`000?oV6NKo
iQWV00KoiQWV00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oN8MkogR7N00_ogR7N0ol00009oieR
W@03o`000?lo_coo000000_o><Lh00?o0000oaOX5ol000002_l8m`P00ol0003o2OH9o`00000?obGJ
9@03o`000?l^dBko;]4^00;o;]4^00?o0000odRgB?m8]dP02om8]dP00ol0003o?L8mocg2?@06ocg2
?@03o`000?m5^TGoAKY500KoAKY500?o0000ofZEJ_mZUFX02OmZUFX01?l0003oW6>LoiaSW?nLHi`7
o`0000;oNhAk00?o0000ojaC[?n/Dj`00on/Dj`00ol0003oiQWVonHIiP05onHIiP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oN8MkogR7N00SogR7N0ol00003om@[e003o`000?nMHYgoWF:M00OoWF:M00?o0000ocS7
>?lhacP02olhacP00ol0003o2?L8o`Sg200:o`Sg2003o`000?lUfRGo9MXU00go9MXU00?o0000obkA
;_l^dBh01?l^dBh00ol0003oB;M8odRgB009odRgB003o`000?lm`Sgo?L8m00So?L8m00?o0000odFj
AOm5^TD00om5^TD2o`0000coJYEZ00?o0000oiaSW?nLHi`02?nLHi`<o`0000?oiQWV0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omhQg_oN8Mh01_oN8Mh3o`0000Ooe2_D00?o0000oieRWOnMHYd01_nMHYd00ol0003o
><LhocS7>00;ocS7>003o`000?l8m`So2?L800Wo2?L80_l0000>obGJ9@03o`000?l^dBko;]4^00Go
;]4^00?o0000odRgB?m8]dP02Om8]dP00ol0003o?L8mocg2?@09ocg2?@03o`000?m5^TGo000000;o
00000_mPWf000ol0003oJYEZofZEJP08ofZEJP03o`000?nLHicoW6>L00coW6>L00?o0000on8Mh_oR
7N801_oR7N83o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ogR7NomhQgP03omhQgP?o00002ooD:m@00ol0003oWF:M
oieRW@04oieRW@03o`000?lhacSo><Lh00_o><Lh0ol00007o`Sg20?o000000?o7N8Mo`000?lUfRD0
3OlUfRD00ol0003o;]4^obkA;P06obkA;P03o`000?m8]dSoB;M800SoB;M800?o0000ocg2?Olm`Sd0
2_lm`Sd00ol0003oH9mPof2OH004of2OH003o`000?mZUF[oJYEZ00OoJYEZ00?o0000oiaSW?nLHi`0
2onLHi`00ol0003ohQgRon8MhP08on8MhP03o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omhQg_l0
003o0000o`0000ooe2_D00?o0000oieRWOnMHYd00onMHYd>o`0000?o;M8]0_l00002o`Sg20?o0000
1OlMhQd00ol0003o9MXUobGJ9@0:obGJ9@03o`000?l^dBko;]4^00Oo;]4^00?o0000odRgB?m8]dP0
2?m8]dP00ol0003o?L8mocg2?@0:ocg2?@03o`000?mPWf3oH9mP00GoH9mP00?o0000ofZEJ_mZUFX0
1_mZUFX00ol0003oW6>LoiaSW00;oiaSW003o`000?oR7N;ohQgR00SohQgR00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;oe2_D00?o0000oieRWOnMHYd00_nMHYd00ol0003oKi1_ofn@
K`0:ofn@K`03o`000?l]dRgo;M8]00?o;M8]0_l00009oagR7@03o`000?lUfRGo9MXU00Wo9MXU00?o
0000obkA;_l^dBh02?l^dBh2o`0000SoB;M800?o0000ocg2?Olm`Sd02Olm`Sd00ol0003oH9mPof2O
H007of2OH003o`000?mZUF[oJYEZ00CoJYEZ00?o0000oiaSW?nLHi`02onLHi`00ol0003ohQgRon8M
hP09on8MhP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003oe2_Dom@[e00?om@[e0?o000000?oWF:M
o`000?m_T6l02om_T6l00ol0003o;M8]obgB;@04obgB;@03o`000?lMhQgo7N8M00Wo7N8M00?o0000
obGJ9OlUfRD01olUfRD00ol0003o;]4^obkA;P09obkA;P04o`000?l/dbco0000o`0000KoB;M800?o
0000ocg2?Olm`Sd02Olm`Sd00ol0003oH9mPof2OH008of2OH003o`000?mZUF[oJYEZ00?oJYEZ00?o
0000oiaSW?nLHi`02onLHi`00ol0003ohQgRon8MhP09on8MhP03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003oe2_Dom@[e00<om@[e0;o00000oo@;m02o`0000coKi1_00?o0000obgB;Ol]dRd01?l]dRd0
0ol0003o7N8MoagR7@0:oagR7@Wo00002ol^dBh00ol0003o;=</obcC;002obcC;0?o00000_m8]dP0
0ol0003o?L8mocg2?@0:ocg2?@03o`000?mPWf3oH9mP00WoH9mP00?o0000ofZEJ_mZUFX00_mZUFX0
0ol0003oW6>LoiaSW00:oiaSW003o`000?oR7N;ohQgR00WohQgR00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oD:m@2o`0000God2o@00?o0000oiUVVOl000002_m_T6l00ol0003o;M8]obgB;@06obgB
;@03o`000?lMhQgo7N8M00Wo7N8M00?o0000oa[U6_lJiAX01OlJiAX00ol0003o;]4^obkA;P09obkA
;P03o`000?l/dbco;=</00Go;=</0ol00009ocg2?@?o00003OmPWf001Ol0003oJYEZofZEJ_mZUF[o
000000coW6>L00?o0000on8Mh_oR7N802OoR7N800ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om@[
e?oD:m@01OoD:m@2o`0000Ood2o@00Co0000oiUVVOnIIYWo00002Om_T6l00ol0003o;M8]obgB;@06
obgB;@03o`000?lMhQgo7N8M00So7N8M00?o0000oa[U6_lJiAX01olJiAX00ol0003o;]4^obkA;P07
obkA;P03o`000?l/dbco;=</00So;=</0ol00002ocg2?@Go00000_lfbCH00ol0003oH9mPof2OH00<
of2OH003o`000?mZUF[o000000coW6>L00?o0000on8Mh_oR7N802_oR7N800ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000om@[e?oD:m@00_oD:m@2o`0000Sod2o@00?o0000oiUVVOnIIYT00_nIIYT5o`00
00CoKi1_00?o0000obgB;Ol]dRd01_l]dRd00ol0003o7N8MoagR7@08oagR7@03o`000?lJiA[o6^DJ
00Oo6^DJ00?o0000obkA;_l^dBh01ol^dBh00ol0003o;=</obcC;008obcC;003o`000?lKi1_o6n@K
00;o00002?lfbCH00ol0003oH9mPof2OH00<of2OH0Co00002_nLHi`00ol0003ohQgRon8MhP0:on8M
hP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003oe2_Do`000?l0000:om0_d003o`000?nIIYWoVFJI
00;oVFJI00?o0000od>l@om3_4<00_m3_4<4o`0000Wo;M8]00?o0000oagR7OlMhQd02?lMhQd00ol0
003o6^DJoa[U6P08oa[U6P03o`000?l^dBko;]4^00Go;]4^00?o0000obcC;?l/db`02?l/db`01Ol0
003o6n@Koa_T6olKi1_o000000[o=/Tf0ol0000;of2OH004o`000?o=</gocC;=oldbc@Co00001OnL
Hi`00ol0003ohQgRon8MhP0;on8MhP03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003od2o@om0_d00:
om0_d003o`000?nIIYWoVFJI00?oVFJI00?o0000od>l@om3_4<01?m3_4<00ol0003o;M8]obgB;@07
obgB;@03o`000?lMhQgo7N8M00Ko7N8M0_l0000;oa[U6P03o`000?l^dBko;]4^00Go;]4^00?o0000
obcC;?l/db`02?l/db`00ol0003o6n@Koa_T6`02oa_T6`03o`000?lfbCKo=/Tf00Oo=/Tf00?o0000
ohQgR?n8MhP01?l00006of2OH003o`000?o=</gocC;=00KocC;=0ol00002oiaSW003o`000?oR7N;o
hQgR00_ohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o@;m3od2o@00Wod2o@00?o0000oiUV
VOnIIYT01?nIIYT00ol0003o@ka3od>l@`05od>l@`03o`000?l]dRgo;M8]00Oo;M8]00?o0000oagR
7OlMhQd00_lMhQd3o`000003ob_D:ol0003o6^DJ00[o6^DJ00?o0000obkA;_l^dBh01Ol^dBh00ol0
003o;=</obcC;007obcC;003o`000?lKi1_o6n@K00?o6n@K00?o0000ocK9=_lfbCH01olfbCH00ol0
003oR7N8ohQgR004ohQgR0?o00000_mPWf000ol0003ocC;=oldbc@0:oldbc@;o00003_oR7N800ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000om0_d?o@;m002Oo@;m000ol0003oVFJIoiUVV@04oiUVV@03
o`000?m3_4?o@ka300Ko@ka30_l00007obgB;@03o`000?lMhQgo000000;o00001Ol[e2/00ol0003o
6^DJoa[U6P08oa[U6P?o00001?l^dBh00ol0003o;=</obcC;008obcC;003o`000?lKi1_o6n@K00Co
6n@K00?o0000ocK9=_lfbCH01_lfbCH00ol0003oR7N8ohQgR007ohQgR0;o00003_o=</d00ol0003o
hQgRon8MhP0;on8MhP03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003od2o@om0_d008om0_d003o`00
0?nIIYWoVFJI00GoVFJI00?o0000od>l@om3_4<01?m3_4<00ol0003oC[5>odjaCP03o`0000Co;M8]
0_l00008ob_D:`03o`000?lJiA[o6^DJ00Oo6^DJ00Co0000odfbCOm=/TgoCK9=0ol000000ol^dBko
0000obcC;009obcC;003o`000?lKi1_o6n@K00Co6n@K00?o0000ocK9=_lfbCH01OlfbCH00ol0003o
R7N8ohQgR009ohQgR003o`000?o=</gocC;=00gocC;=00?o0000on8Mh_oR7N802_oR7N800ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000om0_d?o@;m001oo@;m000ol0003oVFJIoiUVV@06oiUVV@03o`00
0?m3_4?o@ka300?o@ka300?o0000odjaC_m>/Dh01?m>/Dh2o`000003obgB;Ol0003o:m@[00[o:m@[
00?o0000oa[U6_lJiAX01OlJiAX00ol0003oCK9=odfbC@05odfbC@03o`000?l/dbco;=</00Oo;=</
0ol00007oa_T6`03o`000?lfbCKo=/Tf00Co=/Tf00?o0000ohQgR?n8MhP02On8MhP00ol0003ocC;=
oldbc@0=oldbc@03o`000?oR7N;ohQgR00[ohQgR00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o@
;m3od2o@00God2o@0ol00009oiUVV@05o`000?m3_4?o@ka3od>l@ol000002Om>/Dh00ol0003o:m@[
ob_D:`0;ob_D:`03o`000?lJiA[o6^DJ00?o6^DJ00?o0000odfbCOm=/Td01_m=/Td00ol0003o;=</
obcC;006obcC;005o`000?lka3_o>l@koc_4>ol000001olKi1/00ol0003o=/TfocK9=P03ocK9=P03
o`000?n8MhSoR7N800WoR7N800?o0000oldbcOo=</d03_o=</d00ol0003ohQgRon8MhP09on8MhP03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003od2o@o`000004o`0000;ohAkQ00?o0000oiUVVOnIIYT0
1onIIYT01?l0003o@ka3od>l@ol00009odjaCP;o00003Ol[e2/00ol0003o6^DJoa[U6P02oa[U6P03
o`000?m=/TgoCK9=00SoCK9=00?o0000obcC;?l/db`00ol/db`2o`0000Go>l@k00?o0000oa_T6olK
i1/01?lKi1/00ol0003o=/TfocK9=P03ocK9=P03o`000?n8MhSoR7N800WoR7N800?o0000oldbcOo=
</d03_o=</d00ol0003ohQgRon8MhP09on8MhP03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SohAkQ
00?o0000oiUVVOnIIYT01_nIIYT00ol0003o@ka3o`000009odjaCP04o`000?m@[e3oD:m@o`0000go
:m@[00Co0000oa[U6_lJiA[o00003?m=/Td01Ol0003o;=</obcC;?l/dbco000000So>l@k0_l00005
oa_T6`03o`000?lfbCKo=/Tf00;o=/Tf00?o0000ohQgR?n8MhP02On8MhP00ol0003ocC;=oldbc@0>
oldbc@03o`000?oR7N;ohQgR00WohQgR00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oQ7^7ohAkQ
00OohAkQ00?o0000oiUVVOnIIYT01onIIYT00ol0003oC[5>odjaCP07odjaCP03o`000?m@[e3oD:m@
00;oD:m@00?o0000ob_D:ol[e2/02_l[e2/00ol0003o6^DJo`00000>odfbC@03o`000?l/dbco0000
00_o>l@k00?o0000oa_T6olKi1/00_lKi1/01Ol0003o=/TfocK9=_lfbCKo000000coR7N800?o0000
oldbcOo=</d03_o=</d3o`0000WohQgR00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oQ7^7ohAkQ
00WohAkQ00?o0000oiUVVOnIIYT01_nIIYT00ol0003oC[5>odjaCP06odjaCP03o`000?m@[e3oD:m@
00?oD:m@00?o0000ob_D:ol[e2/02ol[e2/00ol0003oCK9=odfbC@0>odfbC@03o`000?lka3_o>l@k
00_o>l@k0_l00003oa_T6`04o`000?lfbCKo=/Tfo`0000[oR7N80ol0000>oldbc@;o00000ook1?/2
o`0000OohQgR00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oiUV
VOnIIYT01?nIIYT00ol0003oC[5>odjaCP06odjaCP03o`000?m@[e3oD:m@00GoD:m@00?o0000ob_D
:ol[e2/01ol[e2/3o`00017oCK9=00?o0000oc_4>olka3/03Olka3/01Ol0003o6n@Koa_T6ol0003o
=/Tf00Co00000on8MhP5o`0000;oeRWF00?o0000oldbcOo=</d02_o=</d2o`0000Oon`Ck0_l00004
on8MhP03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ohAkQon4Nh@0;on4Nh@03o`000?nIIYWoVFJI
00CoVFJI00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oD:m@oe2_D006oe2_D003o`000?l[e2_o:m@[
00Co:m@[0ol00002ocK9=P03o`000?m=/TgoCK9=00ooCK9=0_l0000?oc_4>`04o`000?lKi1_o0000
o`0000CoLXeb0ol00008omHYeP03o`000?o=</gocC;=00OocC;=0_l0000;oo/4n`;o00000_oR7N80
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000on4NhOoQ7^403?oQ7^46o`0000OoC[5>00?o0000oe2_
D?m@[e002?m@[e000ol0003o:m@[ob_D:`03o`0000Ko=/Tf00?o0000odfbCOm=/Td03Om=/Td01?l0
003oC;=<odbcC?l0000?oc_4>`03o`000?mbSG;oLXeb00GoLXeb00?o0000omHYe_oF:MH02?oF:MH0
0ol0003ocC;=oldbc@05oldbc@03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oQ7^400ol0003oX5nPoj1OX004oj1O
X003o`000?m>/DkoC[5>00?oC[5>00?o0000oe2_D?m@[e002_m@[e02o`0000[o=/Tf00?o0000odfb
COm=/Td02om=/Td00ol0003oC;=<odbcC002odbcC003o`000?lka3_o>l@k00_o>l@k0_l00007og:=
LP03o`000?oF:MKoeRWF00WoeRWF00?o0000oldbcOo=</d00_o=</d2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00co
n`Ck00?o0000on4NhOoQ7^402ooQ7^400ol0003oX5nPoj1OX006oj1OX005o`000?m>/DkoC[5>odja
C_l000003Om@[e000ol0003o=/TfocK9=P0:ocK9=P03o`000?m=/TgoCK9=00WoCK9=00?o0000odbc
C?m</d`01?m</d`00ol0003o>l@koc_4>`08oc_4>`;o000000?o:m@[o`000?mbSG801ombSG800ol0
003oeRWFomHYeP09omHYeP04o`000?o=</go0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oQ7^7ohAkQ
00WohAkQ00?o0000oj1OX?nPGj002?nPGj000ol0003oC[5>o`00000=oe2_D003o`000?lfbCKo=/Tf
00_o=/Tf00?o0000odfbCOm=/Td02?m=/Td00ol0003oC;=<odbcC006odbcC003o`000?lka3_o>l@k
00Go>l@k0_l00003ob_D:`03o`000?mbSG;oLXeb00KoLXeb00?o0000omHYe_oF:MH02_oF:MH00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo/4nook
1?/03ook1?/00ol0003ohAkQon4Nh@07on4Nh@03o`000?nPGj3oX5nP00[oX5nP00?o0000oe2_D?m@
[e003?m@[e000ol0003o=/TfocK9=P0<ocK9=P03o`000?m=/TgoCK9=00KoCK9=00?o0000odbcC?m<
/d`02?m</d`00ol0003o>l@koc_4>`02oc_4>`;o00001_l[e2/00ol0003oLXebog:=LP05og:=LP03
o`000?oF:MKoeRWF00[oeRWF00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oQ7^7ohAkQ00GohAkQ
00?o0000oj1OX?nPGj003?nPGj02o`0000coD:m@00?o0000ocK9=_lfbCH03OlfbCH00ol0003oCK9=
odfbC@04odfbC@03o`000?m</dcoC;=<00[oC;=<00Co0000oc_4>ol0003o00002?l[e2/00ol0003o
LXebog:=LP06og:=LP03o`000?oF:MKoeRWF00WoeRWF00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0Aoo/4n`Co0000
0_oQ7^400ol0003oX5nPoj1OX00=oj1OX003o`000?mKY5_o000000;o00002?m@[e000ol0003o=/Tf
ocK9=P0?ocK9=PKo00003_m</d`00ol0003o:m@[ob_D:`08ob_D:`03o`000?mbSG;oLXeb00KoLXeb
00?o0000omHYe_oF:MH02OoF:MH00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck017on`Ck00Co0000on<LhooS7>?ohacS
0_l0000?oj1OX003o`000?mKY5_oFjAK00?oFjAK0ol00005oe2_D0;o00004?lfbCH01_l0003o8m`S
ob?L8ol0003o3o0?o`0000koC;=<00?o0000ob_D:ol[e2/02Ol[e2/00ol0003oLXebog:=LP05og:=
LP03o`000?oF:MKoeRWF00WoeRWF00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00oon`Ck00?o0000on<LhooS7><00ooS7><00ol0003o
X5nPoj1OX00=oj1OX003o`000?mKY5_oFjAK00KoFjAK0ol000001?m@[e3o0000oc;=<_lbcC83o`00
00co=/Tf00Go0000ob?L8olSg2?o8m`So`000002o`o`3`03o`000?m</dcoC;=<00_oC;=<00?o0000
ob_D:ol[e2/02Ol[e2/00ol0003oLXebog:=LP06og:=LP03o`000?oF:MKoeRWF00SoeRWF0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03ook1?/00ol0003ohacSon<Lh`04on<Lh`oo00003?mKY5/00ol0003o</dboc;=<P04oc;=
<P?o00002?lfbCH00ol0003o8m`Sob?L8`02ob?L8`05o`000?l?l0oo3o0?o`o`3ol000003?m</d`0
0ol0003o:m@[ob_D:`09ob_D:`03o`000?mbSG;oLXeb00GoLXeb3?l00002ondBk@;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo/4
nook1?/03_ok1?/00ol0003ohacSon<Lh`05on<Lh`03o`000?nHIiSoV6NH00_oV6NH00?o0000oe^T
FomKY5/02_mKY5/00ol0003o</dboc;=<P07oc;=<P;o00001OlfbCH00ol0003o8m`Sob?L8`03ob?L
8`03o`000?l?l0oo3o0?00;o3o0?00?o0000odbcC?m</d`02Om</d`00ol0003o:m@[ob_D:`0:ob_D
:`03o`000?mbSG;oLXeb00?oLXeb00?o0000okY5^_njAKX02OnjAKX00ol0003okA;]ondBk@02ondB
k@;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo/4nook1?/03Ook1?/00ol0003ohacSon<Lh`06on<Lh`03o`000?nHIiSoV6NH00[o
V6NH00?o0000oe^TFomKY5/02omKY5/00ol0003o</dboc;=<P09oc;=<P?o000000?o=/Tfo`000?lS
g2<01OlSg2<00ol0003o3o0?o`o`3`03o`o`3`03o`000?m</dcoC;=<00SoC;=<3_l00003og:=LP;o
00002onjAKX00ol0003okA;]ondBk@05ondBk@03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00gon`Ck
00?o0000on<LhooS7><01OoS7><00ol0003oZeB[o`00000;oiQWV003o`000?mKY5_oFjAK00[oFjAK
0_l0000>oc;=<P03o`000?lSg2?o8m`S00Go8m`S00?o0000o`o`3ol?l0l00ol?l0l00ol0003oC;=<
odbcC008odbcC003o`000?m`Sg3oL8m`00_oL8m`00?o0000og:=L_l000003OnjAKX00ol0003okA;]
ondBk@06ondBk@;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oS7>?ohacS00KohacS00Co
0000oj]DZon[E:_o00002_nHIiP00ol0003oFjAKoe^TF`09oe^TF`03o`000?ln`Cko000000ko</db
00?o0000ob?L8olSg2<01OlSg2<00ol0003o3o0?o`o`3`04o`o`3`03o`000?m</dcoC;=<00KoC;=<
00?o0000og2?L?m`Sg003Om`Sg000ol0003o^TFjokY5^P0<okY5^P03o`000?o]4^gokA;]00SokA;]
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oS7>?ohacS00GohacS00?o0000oj]DZon[E:/00_n[
E:/00ol0003oV6NHoiQWV006oiQWV003o`000?mKY5_oFjAK00SoFjAK0_l00003ock1?P03o`000?lb
cC;o</db00_o</db00?o0000ob?L8olSg2<01OlSg2<00ol0003o3o0?o`o`3`05o`o`3`03o`000?m<
/dcoC;=<00GoC;=<00?o0000og2?L?m`Sg003Om`Sg000ol0003o^TFjokY5^P0;okY5^P03o`000?o]
4^gokA;]00WokA;]00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oS7>?ohacS00KohacS00?o0000
oj]DZon[E:/00on[E:/00ol0003oV6NHoiQWV005oiQWV003o`000?mKY5_oFjAK00OoFjAK00?o0000
ock1?_ln`Ch00oln`Ch00ol0003o</dboc;=<P0:oc;=<P03o`000?lSg2?o8m`S00Ko8m`S00?o0000
o`o`3ol?l0l01_l?l0l00ol0003oC;=<odbcC004odbcC003o`000?m`Sg3oL8m`00goL8m`3ol0000;
ondBk@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo/4n`03o`000?oS7>?ohacS00KohacS00?o0000oj]DZon[E:/01On[E:/00ol0
003oV6NHoiQWV004oiQWV003o`000?mKY5_oFjAK00GoFjAK0_l00006ock1?P03o`000?lbcC;o</db
00Wo</db0_l00008ob?L8`03o`000?l?l0oo3o0?00Ko3o0?1Ol000000om</dco0000og2?L00?og2?
L003o`000?nkA;_o^dBk00_o^dBk00?o0000ondBkOo]4^d02Oo]4^d00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ok1?_on`Ck00;o
n`Ck1Ol00003oo/4n`03o`000?oS7>?ohacS00KohacS00?o0000oj]DZon[E:/01_n[E:/00ol0003o
V6NHoiQWV004o`0000KoFjAK00?o0000ock1?_ln`Ch01oln`Ch00ol0003o</dboc;=<P05oc;=<P?o
000000?o7><Lo`000?lSg2<01olSg2<00ol0003o3o0?o`o`3`05o`o`3`03o`000?mB[E;oDZeB00?o
DZeB0_l0000?og2?L0;o00003OnkA;/00ol0003okA;]ondBk@08ondBk@03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo/4nook1?/0
1ook1?/3o`0000WohacS00?o0000oj]DZon[E:/01on[E:/2o`0000CoT6n@00Co0000oe^TFomKY5_o
FjAK0_l0000:ock1?P03o`000?lbcC;o</db00;o</db0ol00005oacS7003o`000?lSg2?o8m`S00Go
8m`S00?o0000o`o`3ol?l0l01?l?l0l00ol0003oDZeBoe:]DP06oe:]DP03o`000?m`Sg3oL8m`00[o
L8m`0_l00002oiMXU`03o`000?nkA;_o^dBk00[o^dBk00?o0000ondBkOo]4^d02?o]4^d00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ok1?_on`Ck00Won`Ck00?o0000on<LhooS7><01_oS7><00ol0003oZeB[oj]DZ`08oj]DZ`03o`00
0?n@Ki3oT6n@00CoT6n@00?o0000oe^TFol000003?ln`Ch00ol0003o</dbo`000002o`0000Wo7><L
00?o0000ob?L8olSg2<01?lSg2<00ol0003o3o0?o`o`3`03o`o`3`03o`000?mB[E;oDZeB00SoDZeB
1_l00004og2?L0;o00001OnGJ9L00ol0003o^dBkok]4^`09ok]4^`03o`000?o]4^gokA;]00SokA;]
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oS7>?ohacS00GohacS00?o0000oj]DZon[E:/01on[
E:/00ol0003oT6n@oi1_T006oi1_T003o`000?ln`Cko?/4n00co?/4n00?o0000oacS7?lLha`02_lL
ha`00ol0003o8m`Sob?L8`04ob?L8`04o`000?l?l0oo3o0?o`o`3`;o00002omB[E800ol0003oNHIi
ogV6N@03ogV6N@Co00002?nGJ9L00ol0003o^dBkok]4^`08ok]4^`03o`000?o]4^gokA;]00OokA;]
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ok
1?_on`Ck00_on`Ck00?o0000on<LhooS7><00ooS7><00ol0003oZeB[oj]DZ`07oj]DZ`03o`000?n@
Ki3oT6n@00OoT6n@00?o0000ock1?_ln`Ch03?ln`Ch00ol0003o7><LoacS700;oacS7003o`000?lS
g2?o8m`S00?o8m`S00Co0000o`o`3ol?l0oo00003OmB[E800ol0003oNHIiogV6N@06ogV6N@03o`00
0?nGJ9OoUfRG00OoUfRG00?o0000ok]4^onkA;/01onkA;/00ol0003okA;]ondBk@06ondBk@04o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oS7>?ohacS00;ohacS00?o0000oj]DZon[E:/0
1_n[E:/00ol0003oT6n@oi1_T009oi1_T003o`000?ln`Cko?/4n00Wo?/4n0_l0000>oacS70?o0000
0olSg2<00ol0003o3o0?o`00000=oe:]DP03o`000?miQWWoNHIi00OoNHIi00?o0000oiMXUonGJ9L0
2?nGJ9L:o`0000KokA;]0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo/4nook1?/03Ook1?/6o`0000OoZeB[00?o
0000oi1_T?n@Ki002_n@Ki000ol0003o?/4nock1?P06ock1?P;o000000?o><Lho`000?lLha`02olL
ha`2o`0000?oBkA;1Ol0000>oe:]DP03o`000?miQWWoNHIi00OoNHIi00?o0000oiMXUonGJ9L02?nG
J9L00ol0003ocC;=oldbc@06oldbc@03o`000?o]4^gokA;]00?okA;]00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo/4nook1?/03Ook1?/00ol0003of2OHomPWf003omPWf0Co00000_n[E:/00ol0003oT6n@oi1_T00;
oi1_T003o`000?ln`Cko?/4n00?o?/4n0ol00004ocS7>003o`000?lLhaco7><L00Oo7><L0_l00008
od^dB`03o`000?mB[E;oDZeB00goDZeB00?o0000ogV6NOmiQWT02?miQWT00ol0003oUfRGoiMXU`07
oiMXU`03o`000?o=</gocC;=00OocC;=0ol000000oo]4^go0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oH9mSof2OH00Oof2OH0_l0000?oi1_T003o`000?ln`Cko?/4n00;o00002?lhacP00ol0
003o7><LoacS7005oacS7003o`000?m;]4_oBkA;00SoBkA;00?o0000oe:]D_mB[E803OmB[E800ol0
003oNHIiogV6N@08ogV6N@03o`000?nGJ9OoUfRG00KoUfRG00?o0000oldbcOo=</d02?o=</d01?l0
003okQ7^onhAk_l0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0003of2OHomPWf009omPW
f003o`000?n@Ki3oT6n@00koT6n@0_l0000;ocS7>003o`000?lLhaco7><L00;o7><L0_l0000;od^d
B`03o`000?mB[E;oDZeB00goDZeB00?o0000ogV6NOmiQWT02?miQWT00ol0003oUfRGoiMXU`06oiMX
U`03o`000?o=</gocC;=00OocC;=00Go0000onhAk_o^4NkokQ7^o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4nook1?/03Ook1?/00ol0
003of2OHomPWf00:omPWf003o`000?n@Ki3oT6n@00goT6n@0_l0000<ocS7>004o`000?lLhaco0000
o`0000goBkA;00?o0000oe:]D_mB[E803?mB[E800ol0003oNHIiogV6N@09ogV6N@03o`000?nGJ9Oo
UfRG00KoUfRG00?o0000oldbcOo=</d01_o=</d00ol0003okQ7^onhAkP03onhAkP03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo/4
nook1?/03Ook1?/00ol0003of2OHomPWf00:omPWf003o`000?n@Ki3oT6n@00coT6n@00Co0000odbc
C?m</dco00003?lhacP00ol0003oBkA;od^dB`0>od^dB`03o`000?mB[E;oDZeB00SoDZeB1?l0000;
ogV6N@03o`000?nGJ9OoUfRG00KoUfRG00?o0000oldbcOo=</d01Oo=</d00ol0003okQ7^onhAkP04
onhAkP03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03?ok1?/00ol0003of2OHomPWf00;omPWf003o`000?n@Ki3oT6n@
00_oT6n@00?o0000odbcC?m</d`00_m</d`00ol0003o><LhocS7>009ocS7>003o`000?m;]4_oBkA;
00koBkA;00Co0000oe:]D_mB[E;oDZeB1ol00003oejQGP03o`000?miQWWoNHIi00WoNHIi00?o0000
oiMXUonGJ9L01_nGJ9L00ol0003ocC;=oldbc@04oldbc@03o`000?o^4NkokQ7^00KokQ7^00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?oH9mSof2OH00cof2OH00?o0000oi1_T?n@Ki002_n@Ki000ol0
003oC;=<odbcC003odbcC003o`000?lhacSo><Lh00So><Lh00?o0000od^dBom;]4/03_m;]4/4o`00
00_oGZ5N00?o0000ogV6NOmiQWT02?miQWT00ol0003oUfRGoiMXU`05oiMXU`03o`000?o=</gocC;=
00GocC;=00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omPWf?oH
9mP03?oH9mP7o`0000GoT6n@00?o0000odbcC?m</d`01Om</d`00ol0003o><LhocS7>007ocS7>003
o`000?m;]4_oBkA;00koBkA;00?o0000oejQG_mNXEh03OmNXEh00ol0003oNHIiogV6N@08ogV6N@03
o`000?nGJ9OoUfRG00CoUfRG00?o0000oldbcOo=</d01?o=</d00ol0003okQ7^onhAkP07onhAkP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo/4nook1?/02_ok1?/00ol0003of2OHomPWf00=omPWf003o`000?n^DJko[U6^00Co[U6^
1Ol00009odbcC003o`000?lhacSo><Lh00Ko><Lh00?o0000od^dBom;]4/03_m;]4/00ol0003oGZ5N
oejQGP0=oejQGP03o`000?miQWWoNHIi00SoNHIi00Co0000oiMXUonGJ9OoUfRG1Ol00004oldbc@03
o`000?o^4NkokQ7^00WokQ7^1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ok1?_on`Ck00Son`Ck0ol0000=omPWf003o`000?n^DJko[U6^00Wo[U6^
0_l00009odbcC003o`000?lhacSo><Lh00Ko><Lh00?o0000od^dBom;]4/03?m;]4/00ol0003oGZ5N
oejQGP0?oejQGPKo00001?miQWT4o`0000Gocc3?0_l000000oo=</go0000onhAkP0;onhAkP04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003on`Ckoo/4n`06oo/4n`04o`000?oX5nSoj1OXonPGj0?o00002_oH9mP00ol0003o
[U6^ojiA[P09ojiA[P03o`000?mRWF;o000000;o00001om</d`00ol0003o><LhocS7>005ocS7>003
o`000?m;]4_oBkA;00SoBkA;1Ol0000AoejQGP03o`000?n8MhSoR7N800?oR7N81?l0000;oll`c`03
o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ok1?_on`Ck00Con`Ck00?o0000onPGj?oX5nP01OoX5nP2o`0000Oof2OH
00?o0000ojiA[_n^DJh02_n^DJh00ol0003oHYeRof:MHP02of:MHP?o00001Om</d`00ol0003o><Lh
ocS7>004ocS7>004o`000?m;]4_oBkA;od^dB`Oo00001?m4^d@00ol0003oGZ5NoejQGP0>oejQGP03
o`000?n8MhSoR7N800OoR7N800?o0000oll`coo?<<l02Oo?<<l00ol0003okQ7^onhAkP09onhAkP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo/4nook1?/00_ok1?/00ol0003oj1OXonPGj008onPGj0;o00001?oH9mP00ol0003o[U6^
ojiA[P0;ojiA[P03o`000?mRWF;oHYeR00GoHYeR0ol00003odbcC004o`000?lhacSo><LhocS7>0Ko
00003?m4^d@00ol0003oGZ5NoejQGP0=oejQGP03o`000?n8MhSoR7N800OoR7N800?o0000oll`coo?
<<l02_o?<<l00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onPGj0?o000000?of2OHo`000?n^DJh0
3?n^DJh00ol0003oHYeRof:MHP08of:MHP?o000000CoC;=<o`000?l0003o00000_n1OX400ol0003o
A;]4odBkA00=odBkA003o`000?mNXEkoGZ5N00coGZ5N00?o0000ohQgR?n8MhP02?n8MhP00ol0003o
cc3?oll`c`0;oll`c`03o`000?o^4NkokQ7^00KokQ7^00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
j1OX00?o0000ojiA[_n^DJh03?n^DJh00ol0003oHYeRof:MHP0;of:MHP03o`000?n1OX7oPGj100?o
PGj100?o0000odBkA?m4^d@03?m4^d@00ol0003o=/Tfo`00000=oejQGP03o`000?n8MhSoR7N800So
R7N800?o0000oll`coo?<<l03?o?<<l3o`0000GokQ7^00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oX5nSoj1OX00coj1OX00?o0000ojiA[_n^DJh03?n^DJh00ol0003oHYeRof:MHP0:of:MHP03o`00
0?n1OX7oPGj100GoPGj100?o0000odBkA?m4^d@02_m4^d@01?l0003o=/TfocK9=_lfbCH2o`0000[o
GZ5N00?o0000ohQgR?n8MhP02On8MhP00ol0003occ3?oll`c`0<oll`c`03o`000?oa3_7ol@ka00?o
000000?okQ7^o`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oX5nSoj1OX00_oj1OX00?o0000ojiA[_n^DJh0
3?n^DJh00ol0003oHYeRof:MHP09of:MHP03o`000?n1OX7oPGj100KoPGj100?o0000odBkA?m4^d@0
2Om4^d@00ol0003o=/TfocK9=P02ocK9=P03o`000?n0Oh3o000000;o00001omNXEh00ol0003oR7N8
ohQgR009ohQgR003o`000?o?<<oocc3?00_occ3?00?o0000oo4>lOoa3_401?oa3_400ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onPGj?oX5nP02ooX5nP00ol0003o[U6^ojiA[P0;ojiA[P03o`000?mR
WF;oHYeR00SoHYeR00?o0000oh5nPOn1OX401on1OX400ol0003oA;]4odBkA008odBkA003o`000?lf
bCKo=/Tf00?o=/Tf00?o0000oh1oP?n0Oh000_n0Oh02o`0000CoGZ5N00?o0000ohQgR?n8MhP02_n8
MhP00ol0003occ3?oll`c`0:oll`c`03o`000?oa3_7ol@ka00Gol@ka00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oX5nSoj1OX00[oj1OX0ol0000;ojiA[PKo00001?mRWF800ol0003oPGj1oh5nP@08
oh5nP@03o`000?m4^dCoA;]400OoA;]400?o0000ocK9=_lfbCH00olfbCH00ol0003oP7n0oh1oP005
oh1oP0?o000000?oGZ5No`000?n8MhP02on8MhP00ol0003occ3?oll`c`09oll`c`03o`000?oa3_7o
l@ka00Ool@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oX5nSoj1OX00Woj1OX00?o0000olTf
bOo9=/T01?l00006ojiA[P03o`000?nXEjSoZ5NX00CoZ5NX1?l0000<oh5nP@03o`000?m4^dCoA;]4
00GoA;]400?o0000ocK9=_lfbCH01?lfbCH00ol0003oP7n0oh1oP008oh1oP003o`000?n8MhSoR7N8
00_oR7N800?o0000oll`coo?<<l02?o?<<l00ol0003ol@kaoo4>l@08oo4>l@Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oX5nSoj1OX00Ooj1OX00?o0000olTfbOo9=/T01Oo9=/T3o`0000;o[U6^00?o0000ojQGZ?nX
EjP02?nXEjP00ol0003oPGj1oh5nP@0:oh5nP@03o`000?m4^dCoA;]400CoA;]400?o0000ocK9=_lf
bCH01OlfbCH00ol0003oP7n0oh1oP008oh1oP003o`000?n8MhSoR7N800WoR7N81?l00008oll`c`03
o`000?oa3_7ol@ka00Wol@ka00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OX
onPGj005onPGj003o`000?o9=/WobCK900WobCK90_l0000<ojQGZ003o`000?n1OX7oPGj100WoPGj1
00?o0000odBkA?m4^d@00om4^d@00ol0003o=/TfocK9=P05ocK9=P03o`000?n0Oh3oP7n000[oP7n0
00?o0000ohQgR?n8MhP01?n8MhP4o`0000Co`cc300?o0000oll`coo?<<l01?o?<<l00ol0003ol@ka
oo4>l@0:oo4>l@03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oX5nSoj1OX00?oj1OX00?o0000olTfbOo9=/T02oo9
=/T00ol0003oZ5NXojQGZ00:ojQGZ003o`000?n1OX7oPGj100WoPGj100?o0000odBkA?m4^d@00_m4
^d@00ol0003o=/TfocK9=P06ocK9=P03o`000?n0Oh3oP7n000[oP7n000?o0000ohQgR?n8MhP01?l0
0009ol<l``Ko00003?oa3_400ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onPGj?oX5nSoj1OX0_l0
000=olTfb@03o`000?nXEjSoZ5NX00[oZ5NX00?o0000oh5nPOn1OX402On1OX401Ol0003oA;]4odBk
A?m4^dCo000000Wo=/Tf00?o0000oh1oP?n0Oh002on0Oh02o`0000go`cc300?o0000on`Ck?o/4n`0
0_o/4n`00ol0003ol@kaoo4>l@0:oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oj1OXo`00
0002oo0?l0;o00002oo9=/T00ol0003oZ5NXojQGZ00;ojQGZ003o`000?n1OX7oPGj100WoPGj100?o
0000odBkA?l000002OlfbCH00ol0003oP7n0oh1oP00<oh1oP003o`000?o3?<?o`cc300co`cc300?o
0000on`Ck?o/4n`00oo/4n`00ol0003ol@kaoo4>l@09oo4>l@03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ol0o`oo0?l003oo0?l0;o00002_o9=/T00ol0003oZ5NXojQGZ00:ojQGZ003o`000?n1OX7o
PGj100SoPGj11Ol00008ocK9=P03o`000?n0Oh3oP7n000coP7n000?o0000ol<l`oo3?<<02oo3?<<0
0ol0003ok1?/on`Ck005on`Ck003o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oo`3o02o`0000SobCK900?o0000ojQGZ?nXEjP02_nXEjP00ol0003oPGj1oh5nP@07oh5n
P@03o`000?mhQgSoN8Mh00?oN8Mh0ol00005ocK9=P03o`000?n0Oh3oP7n000_oP7n000?o0000ol<l
`oo3?<<03?o3?<<00ol0003ok1?/on`Ck006on`Ck003o`000?oa3_7ol@ka00Ool@ka00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?om0_go000000Wol0o`00?o0000olTfbOo9=/T01Oo9=/T2o`0000co
Z5NX00?o0000oh5nPOn1OX401On1OX400ol0003oN8MhogR7N007ogR7N0?o000000?o=/Tfo`000?n0
Oh003On0Oh000ol0003o`cc3ol<l``0<ol<l``03o`000?o/4ncok1?/00Kok1?/00?o0000oo4>lOoa
3_401_oa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003ood2o@03o`000?o`3o3ol0o`00Ool0o`
0_l00004olTfb@03o`000?oD:mCoe2_D00;o00002_nXEjP00ol0003oPGj1oh5nP@03oh5nP@;o0000
3OmhQgP2o`0000goP7n00ol0000=ol<l``03o`000?o/4ncok1?/00Ook1?/00?o0000oo4>lOoa3_40
1Ooa3_400ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo@;mood2o@04ood2o@03o`000?o`3o3ol0o`00Sol0o`0_l0
00000oo9=/Wo0000om@[e004om@[e003o`000?nXEjSoZ5NX00OoZ5NX00Co0000oh5nPOn1OX7oPGj1
0_l00002ojMHY`03o`000?mhQgSoN8Mh00coN8Mh3Ol00003okA;]003o`000?o3?<?o`cc300[o`cc3
00?o0000on`Ck?o/4n`02?o/4n`01?l0003ol@kaoo4>lOoa3_44o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?om0_d00ol0003ol0o`
oo0?l009oo0?l003o`000?oD:mCoe2_D00Goe2_D0_l00008ojQGZ003o`000?n1OX7o000000GoYeRW
00?o0000ogR7N?mhQgP02omhQgP00ol0003oQ7^4ohAkQ009ohAkQ003o`000?ndBkCo]4^d00;o]4^d
0_l00009ol<l``03o`000?o/4ncok1?/00[ok1?/0ol00004oo`3o003o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000ood2
o@0:ood2o@03o`000?o`3o3ol0o`00Sol0o`00?o0000om@[e?oD:m@01ooD:m@4o`0000?oZ5NX0ol0
0007ojMHY`03o`000?mhQgSoN8Mh00[oN8Mh00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o]4^dokA;
]004okA;]0;o00001oo3?<<00ol0003ok1?/on`Ck00:on`Ck003o`000?ol0ocoo0?l00Goo0?l00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?o`3o3ol0o`00Ool0o`00?o0000om@[e?oD:m@02?oD:m@0
1?l0003odbcCom</dooC;=<3o`0000;o`Sg200?o0000ojMHYonWF:L01_nWF:L00ol0003oN8MhogR7
N008ogR7N003o`000?n4NhCoQ7^400[oQ7^400?o0000okA;]?ndBk@01_ndBk@00ol0003o`cc3ol<l
``04ol<l``03o`000?o/4ncok1?/00Wok1?/00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000oo0?l?o`3o001Oo`3o000ol0003oe2_Dom@[e008om@[e003o`000?oC;=?o
dbcC00CodbcC00Go0000ol8m`_o2?L;o`Sg2o`000008ojMHY`03o`000?mhQgSoN8Mh00OoN8Mh00?o
0000ohAkQ?n4Nh@02_n4Nh@00ol0003o]4^dokA;]007okA;]0;o00001?o3?<<00ol0003ok1?/on`C
k008on`Ck003o`000?ol0ocoo0?l00Woo0?l00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o000oo`3o00
0ol0003oe2_Dom@[e008om@[e003o`000?oC;=?odbcC00CodbcC00?o0000ol8m`_o2?L800_o2?L80
0ol0003oYeRWojMHY`07ojMHY`03o`000?mhQgSoN8Mh00KoN8Mh00?o0000ohAkQ?n4Nh@02_n4Nh@0
0ol0003o]4^dokA;]009okA;]005o`000?o3?<?o`cc3ol<l`ol000002Oo/4n`00ol0003oo0?loo`3
o00;oo`3o003o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oe2_D00?o0000om</dooC;=<01?oC;=<00ol0003o`Sg2ol8m`P03
ol8m`P03o`000?nWF:OoYeRW00OoYeRW00?o0000ogR7N?mhQgP01OmhQgP00ol0003oQ7^4ohAkQ00:
ohAkQ003o`000?ndBkCo]4^d00Wo]4^d1?l00009on`Ck003o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oc3??ol`cc
oo<<lol000002_oD:m@00ol0003odbcCom</d`05om</d`03o`000?o2?L;o`Sg200?o`Sg200?o0000
ojMHYonWF:L02?nWF:L00ol0003oN8MhogR7N004ogR7N003o`000?n4NhCoQ7^400WoQ7^400?o0000
okA;]?ndBk@02?ndBk@2o`0000?ok1?/00?o0000on`Ck?o/4n`01_o/4n`00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003oe2_Dom@[e006om@[e003o`000?oC;=?odbcC
00GodbcC00?o0000ol8m`_o2?L801?o2?L800ol0003oYeRWojMHY`09ojMHY`03o`000?mhQgSoN8Mh
00;oN8Mh00?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003o]4^dokA;]006okA;]0;o00001_o/4n`8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oD:mCoe2_D00Goe2_D00?o0000om</dooC
;=<01OoC;=<00ol0003o`Sg2ol8m`P05ol8m`P03o`000?nWF:OoYeRW00WoYeRW00Go0000ogR7N?mh
QgSoN8Mho`00000<ohAkQ003o`000?ndBkCo]4^d00Co]4^d0_l00008on`Ck003o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000om@[e?oD
:m@00ooD:m@00ol0003odbcCom</d`06om</d`03o`000?o2?L;o`Sg200Go`Sg200?o0000ojMHYonW
F:L02_nWF:L00ol0003oN8Mho`000004o`0000WoQ7^400?o0000okA;]?ndBk@00_ndBk@2o`0000[o
k1?/00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?oD:mCoe2_D00;oe2_D00?o0000om</dooC;=<01_oC;=<00ol0003o`Sg2ol8m`P07ol8m`P;o0000
2onWF:L00ol0003obcC;ol/db`03ol/db`Oo00000_n4Nh@00ol0003o]4^dokA;]002o`0000_ok1?/
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo<<looc3?<02Ooc
3?<01Ol0003oe2_Dom@[e?oD:mCo000000SodbcC00?o0000ol8m`_o2?L801oo2?L800ol0003ohQgR
o`000002o`0000SoYeRW00?o0000ol/dboo;=</02_o;=</5o`0000gok1?/00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<oo<<l`03o`000?oD:mCo000000WodbcC00?o
0000ol8m`_o2?L801_o2?L800ol0003ohQgRon8MhP03on8MhP?o00001?nWF:L00ol0003obcC;ol/d
b`0=ol/db`03o`000?o/4ncok1?/00gok1?/00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oom0_d2o`0000_ol`cc00?o0000om</dooC;=<01ooC;=<00ol0003o`Sg2ol8m`P07
ol8m`P03o`000?oR7N;ohQgR00KohQgR0ol000000onWF:Oo0000ol/db`0>ol/db`03o`000?o/4nco
k1?/00cok1?/00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo<<
l`03o`000?oC;=?odbcC00;odbcC1_l00008ol8m`P03o`000?oR7N;ohQgR00[ohQgR00?o0000ol/d
boo;=</03oo;=</00ol0003ok1?/on`Ck00:on`Ck0;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo<<l`Go00001_o_4>l00ol0003o`Sg2ol8m`P05ol8m`P03o`000?oR7N;ohQgR00[o
hQgR00?o0000ol/dboo;=</03oo;=</00ol0003ok1?/on`Ck007on`Ck0?o000000?oo0?lo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo<<l`03o`000?o_4>ooka3_00Woka3_00?o0000ol8m`_o2
?L800oo2?L800ol0003ohQgRon8MhP0;on8MhP03o`000?o;=<_obcC;00oobcC;00?o0000on`Ck?o/
4n`01Oo/4n`2o`0000Goo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?ol`cco`000?l00000
3Oo_4>l00ol0003o`Sg2ol8m`P02ol8m`P03o`000?oR7N;ohQgR00_ohQgR5?l00004on`Ck0;o0000
2?ol0o`00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo@;mo`00000>onl@k`04o`000?o2?L;o`Sg2o`0000kohQgR
00?o0000oo4>lOoa3_404?oa3_400ol0003ok1?/o`000002o`0000[oo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?om0_goo@;mood2oOl000003_o_4>l00ol0003o`Sg2o`00000>on8MhP03o`00
0?oa3_7ol@ka017ol@ka00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000ood2oOom0_d00_om0_d00ol0003oka3_onl@k`0=onl@k`03o`000?oR7N;ohQgR00WohQgR1Ol0
000Boo4>l@;o00003ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d0
0ol0003oka3_onl@k`0<onl@k`03o`000?oR7N;ohQgR00;ohQgR1ol00004oo`3o003o`000?oa3_7o
l@ka00ool@ka00?o0000oo`3o?l000004?ol0o`00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo@;mood2o@06ood2
o@03o`000?o_4>ooka3_00coka3_1?l0000<oo`3o003o`000?oa3_7ol@ka00col@ka0_l00003oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Oo
o@;m00?o0000onl@koo_4>l03?o_4>l00ol0003oo0?loo`3o00=oo`3o003o`000?oa3_7ol@ka00_o
l@ka00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3o004o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oka3_onl@k`0:onl@k`03o`000?ol0ocoo0?l00koo0?l00?o0000oo4>lOoa
3_402Ooa3_42o`0000Ooo0?l00?o0000oo`3o?ol0o`03Ool0o`3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000onl@koo_4>l02_o_4>l00ol0003oo0?l
oo`3o00?oo`3o003o`000?oa3_7ol@ka00Kol@ka0_l0000:oo`3o003o`000?ol0ocoo0?l00_oo0?l
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_oa3_400ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Woo0?l0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000ooa3_42o`0000koo0?l00?o
0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000oo4>lOl000004Ool0o`00ol0003oo0?loo`3o004oo`3o0;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000oo`3
o?ol0o`00ool0o`00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool00_l00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00;o003o0oooo`03o`00o`;oool01ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0008o`00o`03oooo0?l00?oo003o00?o003o0_ooo`08o`00o`;oool01Ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Wo003o00?oool0o`00ool00?l00ol00?l00ooo
o`3o003oo`00o`07o`00o`03oooo0?l00?oo003o00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003
o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01_l00?l4oooo0003o`00ooooo`3oool000Wo
003o0_ooo`0>o`00o`;oool01?l00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0:o`00o`03oooo
0?l00?oo003o00co003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool02ol00?l00oooo`3o003oo`00o`0;o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l00oooo`3o003oo`00o`09o`00o`?oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l2oooo00Wo003o0oooo`04o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000go003o00?oool0o`00ool00?l01?l00?l5oooo00Go003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00go003o0_ooo`07o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00
o`;oool02?l00?l2oooo00Go003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So
003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l00oooo`3o
003oo`00o`04o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool0
1_l00?l2oooo00Go003o0_ooo`02o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Co003o0_ooo`03o`00o`?oool00_l0
0?l00oooo`3o003oo`00o`04o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool01Ol00?l6oooo00Co003o0_ooo`03o`00o`;oool01ol00?l2oooo00;o003o0_ooo`05
o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
027o003o1?ooo`07o`00o`Coool02Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(240) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.989 .011 .989 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.99 .01 .99 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.99 .01 .99 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.989 .011 .989 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.941 .059 .941 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.987 .013 .987 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.94 .06 .94 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.94 .06 .94 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.91 .09 .91 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.983 .017 .983 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.884 .116 .884 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.989 .011 .989 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.803 .197 .803 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.808 .192 .808 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.985 .015 .985 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.991 .009 .991 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.706 .294 .706 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.856 .144 .856 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.982 .018 .982 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.985 .015 .985 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.933 .067 .933 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.503 .497 .503 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.824 .176 .824 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.675 .325 .675 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.664 .336 .664 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.735 .265 .735 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.875 .125 .875 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.912 .088 .912 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.99 .01 .99 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.655 .345 .655 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.837 .163 .837 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.519 .481 .519 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.896 .104 .896 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.849 .151 .849 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.989 .011 .989 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.763 .237 .763 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.822 .178 .822 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.64 .36 .64 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.887 .113 .887 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.684 .316 .684 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.991 .009 .991 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.92 .08 .92 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.628 .372 .628 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.346 .654 .346 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.375 .625 .375 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.945 .055 .945 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.953 .047 .953 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.798 .202 .798 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.989 .011 .989 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.641 .359 .641 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.613 .387 .613 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.453 .547 .453 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.473 .527 .473 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.25 .75 .25 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.611 .389 .611 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.69 .31 .69 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.99 .01 .99 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.678 .322 .678 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.572 .428 .572 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.928 .072 .928 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.287 .713 .287 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.841 .159 .841 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.786 .214 .786 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.45 .55 .45 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.227 .773 .227 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.455 .545 .455 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.031 .969 .031 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.074 .926 .074 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.311 .689 .311 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.32 .68 .32 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.363 .637 .363 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.837 .163 .837 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.256 .744 .256 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.286 .714 .286 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.671 .329 .671 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.938 .062 .938 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.988 .012 .988 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.179 .821 .179 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.243 .757 .243 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.407 .593 .407 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.988 .012 .988 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.647 .353 .647 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.309 .691 .309 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.319 .681 .319 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.085 .915 .085 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.42 .58 .42 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.219 .781 .219 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.933 .067 .933 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.22 .78 .22 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.029 .971 .029 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.772 .228 .772 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.143 .857 .143 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.094 .906 .094 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.512 .488 .512 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.88 .12 .88 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.308 .692 .308 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.103 .897 .103 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.421 .579 .421 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.156 .844 .156 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.19 .81 .19 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.892 .108 .892 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.11 .89 .11 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.048 .952 .048 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.027 .973 .027 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.987 .013 .987 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.019 .981 .019 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.199 .801 .199 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.103 .897 .103 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.667 .333 .667 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.281 .719 .281 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.987 .013 .987 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.343 .657 .343 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.188 .812 .188 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.214 .786 .214 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.269 .731 .269 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.131 .869 .131 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.087 .913 .087 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.265 .735 .265 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.48 .52 .48 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.988 .012 .988 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.747 .253 .747 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.257 .743 .257 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.366 .634 .366 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.218 .782 .218 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.934 .066 .934 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.128 .872 .128 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.093 .907 .093 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.287 .713 .287 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.598 .402 .598 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.053 .947 .053 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.989 .011 .989 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.166 .834 .166 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.805 .195 .805 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.947 .053 .947 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.509 .491 .509 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.53 .47 .53 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.22 .78 .22 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.871 .129 .871 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.024 .976 .024 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.142 .858 .142 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.314 .686 .314 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.561 .439 .561 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.022 .978 .022 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.159 .841 .159 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.288 .712 .288 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.366 .634 .366 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.988 .012 .988 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.074 .926 .074 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.988 .012 .988 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.913 .087 .913 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.322 .678 .322 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.267 .733 .267 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.126 .874 .126 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.722 .278 .722 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.222 .778 .222 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.928 .072 .928 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.317 .683 .317 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.346 .654 .346 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.351 .649 .351 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.543 .457 .543 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.739 .261 .739 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.484 .516 .484 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.124 .876 .124 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.106 .894 .106 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.175 .825 .175 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.449 .551 .449 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.771 .229 .771 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.989 .011 .989 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.923 .077 .923 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.232 .768 .232 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.223 .777 .223 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.297 .703 .297 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.789 .211 .789 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.606 .394 .606 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.988 .012 .988 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.46 .54 .46 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.817 .183 .817 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.929 .071 .929 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.177 .823 .177 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.266 .734 .266 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.915 .085 .915 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.251 .749 .251 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.544 .456 .544 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.615 .385 .615 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.384 .616 .384 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.439 .561 .439 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.845 .155 .845 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.745 .255 .745 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.749 .251 .749 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.815 .185 .815 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.347 .653 .347 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.945 .055 .945 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.745 .255 .745 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.41 .59 .41 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.403 .597 .403 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.667 .333 .667 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.424 .576 .424 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.988 .012 .988 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.935 .065 .935 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.809 .191 .809 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.931 .069 .931 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.356 .644 .356 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.907 .093 .907 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.727 .273 .727 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.619 .381 .619 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.989 .011 .989 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.601 .399 .601 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.487 .513 .487 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.989 .011 .989 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.733 .267 .733 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.984 .016 .984 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.99 .01 .99 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.576 .424 .576 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.986 .014 .986 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.53 .47 .53 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.987 .013 .987 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.631 .369 .631 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.819 .181 .819 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.689 .311 .689 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.887 .113 .887 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.906 .094 .906 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.749 .251 .749 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.629 .371 .629 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.736 .264 .736 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.849 .151 .849 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.902 .098 .902 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.855 .145 .855 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.869 .131 .869 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.984 .016 .984 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.748 .252 .748 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.928 .072 .928 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.986 .014 .986 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.945 .055 .945 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.927 .073 .927 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.757 .243 .757 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.934 .066 .934 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.909 .091 .909 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.823 .177 .823 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.987 .013 .987 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.985 .015 .985 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.918 .082 .918 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.988 .012 .988 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.988 .012 .988 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.987 .013 .987 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.988 .012 .988 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.987 .013 .987 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.988 .012 .988 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Ool
0o`01?l0003ok1?/on`Ck?l0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?ol
0ocoo0?l00goo0?l00?o0000on`Ck?o/4n`00_o/4n`00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo0?loo`3o00<oo`3o003o`000?o/4ncok1?/00?ok1?/00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ol0ocoo0?l
00[oo0?l00?o0000on`Ck?o/4n`01Oo/4n`00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003ok1?/on`Ck006on`Ck003
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Ooo0?l
00?o0000on`Ck?o/4n`02?o/4n`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o^4Nko0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000cok1?/00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onhAkP03o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003ojAKYonTFj@05onTFj@03o`000?o/
4ncok1?/00_ok1?/0ol00003onXEjP03o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onhAk_o^4Nh00oo^4Nh00ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003ojAKYonTFj@06
onTFj@03o`000?o/4ncok1?/00[ok1?/00?o0000onXEj_oZ5NX01?oZ5NX00ol0003oo0?loo`3o00:
oo`3o004o`000?oX5nSoj1OXonPGj0;o00002_ol0o`2o`000003onLHiol0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003okQ7^onhAkP05onhAkP03o`000?ol0oco
o0?l00Woo0?l00?o0000onl@kol000002oom0_d00ol0003ojAKYonTFj@06onTFj@03o`000?o/4nco
k1?/00Wok1?/00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oo0?loo`3o008oo`3o003o`000?oX5nSo
j1OX00Coj1OX0_l00005oo`3o0?o00001?oW6>L00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00Soo0?l0_l00008onhAkP03o`000?ol0ocoo0?l00Ooo0?l0_l00003onl@
k`03o`000?om0_goo@;m00Ooo@;m00?o0000onTFjOoY5^T01ooY5^T00ol0003ok1?/on`Ck009on`C
k003o`000?oZ5N[ojQGZ00OojQGZ00?o0000oo`3o?ol0o`01Ool0o`2o`0000Woj1OX0_l000000ool
0oco0000o`000007onLHi`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo0?l00?o0000onhAk_o^
4Nh02?o^4Nh00ol0003oo0?loo`3o006oo`3o003o`000?o_4>ooka3_00?oka3_00?o0000ood2oOom
0_d01oom0_d00ol0003ojAKYonTFj@08onTFj@03o`000?o/4ncok1?/00Ook1?/00?o0000onXEj_oZ
5NX02OoZ5NX00ol0003oo0?loo`3o003oo`3o003o`000?oX5nSoj1OX00_oj1OX00?o0000onLHiooW
6>L01ooW6>L00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003okA;]o`000005oo`3o0;o00002oo^4Nh2o`0000Koo0?l
00?o0000onl@koo_4>l01Oo_4>l00ol0003oo@;mood2o@06ood2o@03o`000?oY5^WojAKY00SojAKY
00?o0000on`Ck?o/4n`01_o/4n`00ol0003ojQGZonXEjP0;onXEjP05o`000?ol0ocoo0?loo`3o?l0
00003_oX5nP00ol0003oiaSWonLHi`08onLHi`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o]4^gokA;]ondBkOl0
00000ool0o`00ol0003okQ7^onhAkP0:onhAkP04o`000?oQ7^7ohAkQo`0000?oo0?l0_l00008onl@
k`03o`000?om0_goo@;m00Koo@;m00?o0000onTFjOoY5^T02OoY5^T00ol0003ok1?/on`Ck005on`C
k003o`000?oZ5N[ojQGZ00cojQGZ00?o0000oo`3o?l000003ooX5nP00ol0003oiaSWonLHi`08onLH
i`03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003okA;]ondBk@03ondBk@03o`000?ol0oco000000_o
kQ7^0_l00004on4Nh@03o`000?ol0oco000000_oka3_00?o0000ood2oOom0_d01Oom0_d00ol0003o
jAKYonTFj@09onTFj@03o`000?o/4ncok1?/00Cok1?/00?o0000onXEj_oZ5NX03_oZ5NX00ol0003o
j1OXonPGj00>onPGj003o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000ondBkOo]4^d0
1?o]4^d00ol0003okQ7^onhAkP09onhAkP03o`000?oQ7^7ohAkQ00GohAkQ00?o0000onl@koo_4>l0
2_o_4>l00ol0003oo@;mood2o@05ood2o@03o`000?oY5^WojAKY00[ojAKY00?o0000on`Ck?o/4n`0
0oo/4n`00ol0003ojQGZonXEjP0>onXEjP03o`000?oX5nSoj1OX00goj1OX00?o0000onLHiooW6>L0
2_oW6>L00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003okA;]ondB
k@05ondBk@03o`000?o^4NkokQ7^00OokQ7^0_l00008on4Nh@03o`000?o_4>ooka3_00_oka3_00?o
0000ood2oOom0_d01?om0_d00ol0003ojAKYonTFj@0:onTFj@04o`000?o/4ncok1?/on`Ck0?o0000
3ooZ5NX00ol0003oj1OXonPGj00>onPGj003o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o]4^gokA;]00OokA;]00?o0000onhAk_o^4Nh01?o^4Nh2o`0000_ohAkQ1?l0
0009onl@k`03o`000?om0_goo@;m00?oo@;m00?o0000onTFjOoY5^T02ooY5^T01?l0003ok1?/o`00
0?l00003olTfb@;o00003?oZ5NX2o`00013oj1OX00?o0000onLHiooW6>L02ooW6>L00ol0003oo0?l
oo`3o00=oo`3o004o`000?ol0ocoo0?loo`3o0?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003okA;]
ondBk@07ondBk@03o`000?o^4NkokQ7^00?okQ7^00?o0000on4NhOoQ7^402ooQ7^401?l0003o_d2o
okm0_ono@;l5o`0000Goka3_00?o0000ood2oOom0_d00_om0_d00ol0003ojAKYonTFj@0<onTFj@03
o`000?o9=/WobCK900GobCK90_l00008onXEjP;o00000_nn@Kh00ol0003oj1OXonPGj00=onPGj003
o`000?oW6>OoiaSW00_oiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o005oo`3o0?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003okA;]ondBk@09ondBk@03o`000?o^4NkokQ7^00;o0000
3OoQ7^400ol0003o_d2ookm0_`07okm0_`Ko00000_om0_d4o`0000gojAKY00?o0000olTfbOo9=/T0
1oo9=/T2o`0000GojQGZ00?o0000oki1__nn@Kh00onn@Kh00ol0003oj1OXonPGj00<onPGj003o`00
0?oW6>OoiaSW00coiaSW00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o009oo`3o003o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o]4^gokA;]00WokA;]00?o
0000onhAk_l000003ooQ7^400ol0003o_d2ookm0_`0<okm0_`?o00001?oN8Mh3o`0000WojAKY00?o
0000olTfbOo9=/T02_o9=/T2o`000003onXEj_l0003o000000Oo_T6n00?o0000onPGj?oX5nP02ooX
5nP00ol0003oiaSWonLHi`0<onLHi`03o`000?ol0ocoo0?l00Koo0?l1?l0000<oo`3o003o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000
on4NhOoQ7^403_oQ7^400ol0003o_d2ookm0_`0=okm0_`03o`000?oN8MkogR7N00KogR7N0ol00005
onTFj@03o`000?o9=/WobCK900gobCK900?o0000oki1__nn@Kh02?nn@Kh00ol0003oj1OXonPGj009
onPGj003o`000?oW6>OoiaSW00goiaSW00Co0000oo`3o?ol0ocoo0?l1Ol00003ondBk@03o`000?ol
0ocoo0?l00_oo0?l00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
ondBkOo]4^d02oo]4^d2o`0000oohAkQ00?o0000okm0_ono@;l03Ono@;l00ol0003ogR7NomhQgP0:
omhQgP?o000000?ojAKYo`000?o9=/T03oo9=/T00ol0003o_T6noki1_P09oki1_P03o`000?oX5nSo
j1OX00Soj1OX00?o0000onLHiooW6>L03_oW6>L3o`0000SokA;]00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o]4^gokA;]00SokA;]0ol000000oo9
=/Wo0000on4Nh@0>on4Nh@03o`000?no@;oo_d2o00go_d2o00?o0000omhQg_oN8Mh03OoN8Mh00ol0
003obCK9olTfb@0?olTfb@03o`000?nn@Kko_T6n00[o_T6n2ol0000;onLHi`Go00003?o]4^d00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003ojaC[o`000?om0_go0000
00SokA;]0ol00005olTfb@03o`000?oQ7^7ohAkQ00cohAkQ00?o0000okm0_ono@;l03Ono@;l00ol0
003ogR7NomhQgP0=omhQgP;o00004?o9=/T00ol0003o_T6noki1_P0:oki1_P03o`000?njAK[o^TFj
00Oo^TFj00?o0000onLHiooW6>L00_oW6>L7o`0000Co_d2o00?o0000ondBkOo]4^d02_o]4^d00ol0
003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003ojaC[on/Djoo[5>/2o`00
00GokA;]0ol00009olTfb@;o00002ooQ7^400ol0003o_d2ookm0_`0=okm0_`03o`000?oN8MkogR7N
00gogR7N00Co0000oke2_Onm@[go00003oo9=/T00ol0003o_T6noki1_P09oki1_P03o`000?njAK[o
^TFj00Wo^TFj1?l0000;okm0_`03o`000?o]4^gokA;]00[okA;]00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000on/Djoo[5>/01?o[5>/00ol0003okA;]o`000002o`00
00cobCK900Co0000ojEJYOl0003o00002OoQ7^400ol0003o_d2ookm0_`0=okm0_`03o`000?oN8Mko
gR7N00gogR7N00Go0000oke2_Onm@[go_D:mo`00000=olTfb@03o`000?nn@Kko_T6n00[o_T6n00?o
0000okY5^_njAKX02OnjAKX00ol0003o_d2ookm0_`0<okm0_`03o`000?o]4^gokA;]00[okA;]00?o
0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000on/Djoo[5>/01_o[5>/0
0ol0003obCK9olTfb@0<olTfb@03o`000?nUFZGoYEZU00;oYEZU0_l00007on4Nh@03o`000?no@;oo
_d2o00co_d2o00?o0000omhQg_oN8Mh03OoN8Mh00ol0003o_D:moke2_@03oke2_@03o`000?o9=/Wo
bCK900[obCK900?o0000oki1__nn@Kh02_nn@Kh00ol0003o^TFjokY5^P09okY5^P03o`000?no@;oo
_d2o00co_d2o00?o0000ondBkOo]4^d02oo]4^d00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003ojaC[on/Dj`06on/Dj`03o`000?o9=/WobCK900_obCK900?o0000ojEJ
YOnUFZD01OnUFZD00ol0003ohAkQon4Nh@03on4Nh@03o`000?no@;oo_d2o00go_d2o00?o0000omhQ
g_oN8Mh03OoN8Mh00ol0003o_D:moke2_@04oke2_@03o`000?o9=/WobCK900WobCK900?o0000oki1
__nn@Kh02Onn@Kh00ol0003o^TFjokY5^P0:okY5^P03o`000?no@;oo_d2o00co_d2o00?o0000ondB
kOo]4^d02oo]4^d00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
jaC[on/Dj`07on/Dj`03o`000?o9=/WobCK900_obCK900?o0000ojEJYOnUFZD01_nUFZD2o`0000?o
hAkQ00?o0000okm0_ono@;l03Ono@;l00ol0003ogR7NomhQgP0<omhQgP03o`000?nm@[go_D:m00Ko
_D:m00?o0000olTfbOo9=/T02?o9=/T00ol0003o_T6noki1_P09oki1_P03o`000?njAK[o^TFj00[o
^TFj00?o0000okm0_ono@;l03?no@;l00ol0003okA;]ondBk@0;ondBk@03o`000?ol0ocoo0?l00[o
o0?l00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000on/Djoo[5>/02?o[5>/00ol0003obCK9olTfb@0:olTfb@03o`00
0?nUFZGoYEZU00WoYEZU0_l000000ooQ7^7o0000okm0_`0<okm0_`?o00003_oN8Mh00ol0003o_D:m
oke2_@07oke2_@03o`000?o9=/WobCK900OobCK900?o0000oki1__nn@Kh02Onn@Kh00ol0003o^TFj
okY5^P0;okY5^P03o`000?no@;oo_d2o00co_d2o00?o0000ondBkOo]4^d02_o]4^d00ol0003oo0?l
oo`3o008oo`3o0?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000on/Djoo[5>/02_o[5>/00ol0003obCK9olTf
b@09olTfb@03o`000?nUFZGoYEZU00_oYEZU00?o0000okm0_ono@;l02_no@;l2o`0000?oVFJI00?o
0000omhQg_oN8Mh02_oN8Mh00ol0003o_D:moke2_@09oke2_@03o`000?o9=/WobCK900KobCK900?o
0000oki1__nn@Kh02?nn@Kh00ol0003o^TFjokY5^P0<okY5^P03o`000?no@;oo_d2o00co_d2o00?o
0000ondBkOo]4^d02_o]4^d00ol0003oo0?loo`3o004oo`3o0Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o[5>_ojaC[00_ojaC[00?o0000olTfbOo9=/T02?o9=/T0
0ol0003oYEZUojEJY@0<ojEJY@03o`000?no@;oo_d2o00So_d2o0_l00006oiUVV@;o00002_oN8Mh0
0ol0003o_D:moke2_@0:oke2_@03o`000?o9=/WobCK900GobCK900?o0000oki1__nn@Kh02?nn@Kh0
0ol0003o^TFjokY5^P0<okY5^P03o`000?no@;oo_d2o00co_d2o00?o0000ondBkOo]4^d02oo]4^d0
0ol0003oo0?lo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
on/Dj`03o`000?o9=/WobCK900OobCK900?o0000ojEJYOnUFZD03_nUFZD00ol0003o_d2ookm0_`04
okm0_`?o00002_nIIYT00ol0003ogR7NomhQgP07omhQgP03o`000?nm@[go_D:m00_o_D:m00?o0000
olTfbOo9=/T00oo9=/T00ol0003o_T6noki1_P09oki1_P03o`000?njAK[o^TFj00co^TFj00?o0000
okm0_ono@;l03?no@;l00ol0003okA;]ondBk@0;ondBk@;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003ojaC[on/Dj`0<on/Dj`03o`000?o9=/WobCK900OobCK900?o0000ojEJYOnUFZD03onUFZD01?l0
003o_d2ookm0_ono@;l2o`0000koVFJI0_l00006omhQgP03o`000?nm@[go_D:m00go_D:m00?o0000
olTfbOo9=/T00_o9=/T00ol0003o_T6noki1_P08oki1_P03o`000?njAK[o^TFj00co^TFj0ol0000=
okm0_`03o`000?o]4^gokA;]00_okA;]00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00oojaC[00?o0000olTfbOo9=/T01_o9=/T00ol0003oYEZUojEJY@0@ojEJY@Co00004_nIIYT00ol0
003ogR7NomhQgP03omhQgP03o`000?nm@[go_D:m00ko_D:m00Go0000olTfbOo9=/WobCK9o`000005
oki1_POo00003?njAKX01Ol0003oQgR7ohMhQon7N8Oo000000co_d2o00?o0000ondBkOo]4^d02?o]
4^d3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000oojaC[00?o0000olTfbOo9=/T01_o9=/T00ol0003oYEZUojEJY@0=
ojEJY@?o000000CoJiA[o`000?l0003o00004onIIYT2o`0000;ogR7N00?o0000oke2_Onm@[d04?nm
@[d00ol0003obCK9o`000006o`0000OoZUFZ00?o0000okY5^_njAKX02?njAKX00ol0003oQgR7ohMh
Q`03ohMhQ`;o00002?no@;l3o`0000KokA;]1?l00002onPGj003o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003okQ7^o`000?o3?<<3o`0000gojaC[00?o0000olTfbOo9=/T01?o9=/T00ol0003oYEZUojEJ
Y@0;ojEJY@?o00000om[U6/01Ol0003oJiA[o`000?mGZ5Oo000001CoVFJI00?o0000omhQg_l00000
4onm@[d00ol0003oZUFZojYEZP0=ojYEZP03o`000?njAK[o^TFj00Go^TFj0_l00008ohMhQ`03o`00
0?no@;oo_d2o00Go00000onl@k`00ol0003okA;]ondBk@03o`0000Ooj1OX00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?o^4NkokQ7^o`0000Co`cc30ol0000:on/Dj`03o`000?o9=/WobCK900?obCK9
00?o0000ojEJYOnUFZD02OnUFZD3o`0000GoJiA[00Co0000of^DJom[U6_o00000_mGZ5L00ol0003o
VFJIoiUVV@0BoiUVV@03o`000?nm@[go_D:m01;o_D:m00?o0000ojYEZ_nZEJX03_nZEJX00ol0003o
^TFjokY5^P03okY5^P03o`000?n7N8OoQgR700WoQgR70_l00009oka3_0;o00002_oX5nP00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000onhAk_o^4NkokQ7^o`000007ol<l``;o00001oo[5>/5o`0000;o
bCK900?o0000ojEJYOnUFZD01_nUFZD3o`0000SoJiA[00Co0000of^DJom[U6_o00000omGZ5L00ol0
003oVFJIoiUVV@0AoiUVV@03o`000?nm@[go_D:m017o_D:m00?o0000ojYEZ_nZEJX04?nZEJX01Ol0
003o^TFjokY5^_njAK[o000000coQgR700?o0000oka3_?nl@k`02?nl@k`00ol0003oj1OXonPGj00:
onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000CokQ7^00?o0000ol<l`oo3?<<01oo3?<<3o`00
0004on/Djol0003o0000o`0000Go[E:]0_l00006ojEJY@?o00002_m[U6/01Ol0003oJiA[of^DJom[
U6_o000000CoEjQG00?o0000oiUVVOnIIYT04?nIIYT00ol0003o_D:moke2_@0Aoke2_@03o`000?nZ
EJ[oZUFZ017oZUFZ00?o0000okY5^_l000003On7N8L00ol0003o_4>loka3_008oka3_003o`000?oX
5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o^4NkokQ7^00CokQ7^00?o0000
ol<l`oo3?<<02_o3?<<00ol0003o[E:]ojeB[@08ojeB[@03o`000?nUFZGoYEZU00?o00003Om[U6/0
1Ol0003oJiA[of^DJom[U6_o000000GoEjQG00?o0000oiUVVOnIIYT03onIIYT00ol0003o_D:moke2
_@0Aoke2_@03o`000?nZEJ[oZUFZ01;oZUFZ00?o0000ohMhQon7N8L03?n7N8L00ol0003o_4>loka3
_008oka3_003o`000?oX5nSoj1OX00_oj1OX00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000onhAk_o^4Nh01Oo^4Nh0
0ol0003o`cc3ol<l``0:ol<l``03o`000?n]DZgo[E:]00Wo[E:]0_l0000?of^DJ`03o`000?m[U6_o
JiA[00;oJiA[00?o0000oeNXEomGZ5L01?mGZ5L00ol0003oVFJIoiUVV@0=oiUVV@?o00004Onm@[d0
0ol0003oZUFZojYEZP0CojYEZP03o`000?n7N8OoQgR700_oQgR700?o0000oka3_?nl@k`02Onl@k`0
0ol0003oj1OXonPGj00;onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008ood2o@;o00002?o^4Nh0
0ol0003o`cc3ol<l``0:ol<l``03o`000?n]DZgo[E:]00Wo[E:]00?o0000of^DJom[U6/03Om[U6/0
0ol0003oJiA[of^DJ`03of^DJ`03o`000?mGZ5OoEjQG00GoEjQG00?o0000oiUVVOnIIYT02_nIIYT2
o`0000?oSg2?00?o0000oke2_Onm@[d03_nm@[d00ol0003oZUFZojYEZP0CojYEZP03o`000?n7N8Oo
QgR700_oQgR700?o0000oka3_?nl@k`02Onl@k`00ol0003oj1OXonPGj00;onPGj003o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo@;m00?o0000onhAk_o^4Nh01oo^4Nh2o`0000_o`cc300?o0000ojeB
[On]DZd02on]DZd00ol0003oJiA[of^DJ`0<of^DJ`03o`000?m[U6_oJiA[00?oJiA[00?o0000oeNX
EomGZ5L01_mGZ5L00ol0003oVFJIoiUVV@07oiUVV@;o00001_n?L8l2o`0000ko_D:m00?o0000ojYE
Z_nZEJX04onZEJX00ol0003oQgR7ohMhQ`0;ohMhQ`03o`000?nl@kco_4>l00Wo_4>l00?o0000onPG
j?oX5nP03?oX5nP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000ood2oOom0_goo@;mo`000009onhA
kP03o`000?oB;M;o000000_o`cc300?o0000ojeB[On]DZd02on]DZd00ol0003oJiA[of^DJ`0;of^D
J`03o`000?m[U6_oJiA[00CoJiA[00?o0000oeNXEomGZ5L01omGZ5L00ol0003oVFJIoiUVV@05oiUV
V@03o`000?n?L8ooSg2?00SoSg2?00?o0000oke2_Onm@[d02_nm@[d00ol0003oZUFZojYEZP0DojYE
ZP03o`000?n7N8OoQgR700_oQgR700?o0000oka3_?nl@k`02Onl@k`00ol0003oj1OXonPGj00<onPG
j003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mo`000009onhAkP04o`000?oB;M;odRgBo`00
00_o`cc300?o0000ojeB[On]DZd02on]DZd00ol0003oJiA[of^DJ`0;of^DJ`03o`000?m[U6_oJiA[
00CoJiA[00?o0000oeNXEomGZ5L02?mGZ5L00ol0003oVFJIoiUVV@02oiUVV@;o00003?n?L8l2o`00
00[o_D:m00?o0000ojYEZ_nZEJX05?nZEJX00ol0003oQgR7ohMhQ`0;ohMhQ`03o`000?nl@kco_4>l
00Wo_4>l00?o0000onPGj?oX5nP03OoX5nP00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003okQ7^onhAkP07onhAkP03
o`000?oB;M;odRgB00;odRgB00?o0000ol<l`oo3?<<02?o3?<<00ol0003o[E:]ojeB[@0<ojeB[@03
o`000?m[U6_oJiA[00WoJiA[00?o0000of^DJom[U6/01Om[U6/00ol0003oEjQGoeNXE`09oeNXE`04
o`000?nIIYWo0000o`00013oSg2?0_l00008oke2_@03o`000?nZEJ[oZUFZ01CoZUFZ0ol0000;ohMh
Q`03o`000?nl@kco_4>l00Wo_4>l00?o0000onPGj?oX5nP03OoX5nP01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003okQ7^onhAkP06onhAkP03o`000?oB;M;odRgB00?odRgB00?o0000ol<l
`oo3?<<02?o3?<<00ol0003o[E:]ojeB[@0;ojeB[@;o00002_m[U6/00ol0003oJiA[of^DJ`06of^D
J`03o`000?mGZ5OoEjQG00[oEjQG00?o0000ohm`Son?L8l04_n?L8l00ol0003o_D:moke2_@04oke2
_@03o`000?nZEJ[oZUFZ01GoZUFZ00?o0000oi=/TonCK9<01Ol00005ohMhQ`03o`000?nl@kco_4>l
00[o_4>l00?o0000onPGj?oX5nP03_oX5nP3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okQ7^onhAkP04onhAkP03
o`000?oB;M;odRgB00CodRgB00?o0000ol<l`oo3?<<01oo3?<<00ol0003o[E:]ojeB[@0;ojeB[@04
o`000?mcS7?oLhaco`0000WoJiA[00?o0000of^DJom[U6/01_m[U6/00ol0003oEjQGoeNXE`0:oeNX
E`03o`000?n?L8ooSg2?01?oSg2?0_l00003oke2_@Co00005?nZEJX00ol0003oTfbCoi=/T`06oi=/
T`Co000000?oQgR7o`000?nl@k`02onl@k`00ol0003oj1OXonPGj00>onPGj003o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003okQ7^onhAkP03onhAkP03o`000?oB;M;odRgB00GodRgB00?o0000ol<l`oo3
?<<01oo3?<<00ol0003o[E:]ojeB[@09ojeB[@;o00001?mcS7<00ol0003oJiA[of^DJ`05of^DJ`03
o`000?m[U6_oJiA[00OoJiA[00?o0000oeNXEomGZ5L02_mGZ5L00ol0003oSg2?ohm`S`0Eohm`S`03
o`000?nm@[go000000CoWF:M0ol0000@ojYEZP03o`000?nCK9?oTfbC00_oTfbC0_l0000<oka3_003
o`000?oX5nSoj1OX00coj1OX0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh00_o^4Nh00ol0003odRgB
om8]dP06om8]dP03o`000?o3?<?o`cc300Oo`cc300?o0000ojeB[On]DZd02?n]DZd00ol0003oLhac
og><L`05og><L`03o`000?m[U6_oJiA[00CoJiA[00?o0000of^DJom[U6/01om[U6/00ol0003oEjQG
oeNXE`0:oeNXE`03o`000?n?L8ooSg2?01KoSg2?00?o0000oieRWOnMHYd01_nMHYd3o`0000coZUFZ
00?o0000oi=/TonCK9<03OnCK9<00ol0003o_4>loka3_009oka3_0Go00002OoX5nP2o`000003on/D
jol0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003onhAk_l0003odRgB00WodRgB00?o0000ol<l`oo3?<<01_o3
?<<00ol0003o[E:]ojeB[@07ojeB[@03o`000?mcS7?oLhac00OoLhac00?o0000of^DJom[U6/00_m[
U6/00ol0003oJiA[of^DJ`08of^DJ`03o`000?mGZ5OoEjQG00WoEjQG00?o0000ohm`Son?L8l05on?
L8l00ol0003oWF:MoieRW@09oieRW@?o00002OnZEJX00ol0003oTfbCoi=/T`0>oi=/T`Ko00001?nl
@k`00ol0003o`Ck1ol4n`@03ol4n`@Go00000_oX5nP2o`0000CojaC[00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oR7N;ohQgRon8Mh_l000002ooB;M800ol0003o`cc3ol<l``06ol<l``03o`000?n]
DZgo[E:]00Go[E:]0_l0000;og><L`04o`000?m[U6_oJiA[o`0000_oJiA[00?o0000oeNXEomGZ5L0
2OmGZ5L00ol0003oSg2?ohm`S`0Fohm`S`03o`000?nMHYgoWF:M00goWF:M0ol00005ojYEZP03o`00
0?nCK9?oTfbC00ooTfbC00?o0000oj5NXOnQGZ400onQGZ44o`0000_o`Ck10_l00006on/Dj`03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ohQgRon8MhP02on8MhPko00001_o3?<<00ol0003o[E:]ojeB
[@05ojeB[@03o`000?mcS7?oLhac00coLhac00?o0000of^DJol000002om[U6/00ol0003oEjQGoeNX
E`07oeNXE`?o00006?n?L8l00ol0003oWF:MoieRW@0@oieRW@?o000000?oZUFZo`000?nCK9<04?nC
K9<00ol0003oXEjQoj5NX@07oj5NX@03o`000?o1?/7o`Ck100[o`Ck100?o0000on/Djoo[5>/01Oo[
5>/00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005on8MhP03o`000?n/Djco[5>/00_o[5>/0_l00004
ol<l``03o`000?n]DZgo[E:]00?o[E:]0_l0000@og><L`03o`000?m[U6_oJiA[00[oJiA[00?o0000
oeNXEomGZ5L00omGZ5L4o`0000;o@Ki100?o0000ohm`Son?L8l05On?L8l00ol0003oWF:MoieRW@0D
oieRW@03o`000?nCK9?oTfbC013oTfbC00?o0000oj5NXOnQGZ401onQGZ400ol0003o`Ck1ol4n`@0:
ol4n`@03o`000?o[5>_ojaC[00GojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oR7N;ohQgR
00GohQgR00?o0000ojaC[?n/Dj`03On/Dj`6o`0000?o[E:]00?o0000og><LomcS7<04?mcS7<00ol0
003oJiA[of^DJ`0:of^DJ`03o`000?mGZ5Oo000000?o00001om1_T400ol0003oSg2?ohm`S`0Dohm`
S`03o`000?nMHYgoWF:M01CoWF:M00?o0000oi=/TonCK9<03onCK9<00ol0003oXEjQoj5NX@08oj5N
X@03o`000?o1?/7o`Ck100[o`Ck100?o0000on/Djoo[5>/01Oo[5>/00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on8Mh_oR7N801_oR7N800ol0003o[5>/ojaC[00=ojaC[003o`000?nSG:?oXebS00?o
XebS00?o0000ojeB[Ol000004omcS7<4o`0000WoJiA[0_l0000<od6n@@03o`000?n?L8ooSg2?01?o
Sg2?00?o0000oieRWOnMHYd05OnMHYd00ol0003oTfbCoi=/T`0>oi=/T`03o`000?nQGZ7oXEjQ00So
XEjQ00?o0000ol4n`Oo1?/402Oo1?/400ol0003ojaC[on/Dj`07on/Dj`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oR7N;ohQgR00SohQgR00?o0000ojaC[?n/Dj`02on/Dj`00ol0003oXebSoj=LX`05oj=LX`03o`00
0?mcS7?oLhac01;oLhac00Co0000odjaC_m>/DkoC[5>1Ol00003of^DJ`03o`000?m1_T7o@Ki100go
@Ki10ol0000@ohm`S`;o00006?nMHYd00ol0003oTfbCoi=/T`0=oi=/T`03o`000?nQGZ7oXEjQ00Wo
XEjQ00?o0000ol4n`Oo1?/402Oo1?/400ol0003ojaC[on/Dj`07on/Dj`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ohQgR00?o0000ojaC[?n/Dj`02_n/Dj`00ol0003oXebSoj=LX`06oj=LX`03o`00
0?mcS7?oLhac017oLhac00?o0000odjaC_m>/Dh01om>/Dh3o`00013o@Ki100?o0000ocS7>?lhacP0
1Ol00009ohm`S`;o000000?oDJiAo`000?nMHYd05onMHYd00ol0003oTfbCoi=/T`0=oi=/T`03o`00
0?nQGZ7oXEjQ00WoXEjQ00?o0000ol4n`Oo1?/402?o1?/42o`0000[ojaC[00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?o`3o3ol0o`00;ol0o`00?o0000on8Mh_oR7N802OoR7N800ol0003o[5>/ojaC
[00:ojaC[003o`000?nSG:?oXebS00OoXebS00?o0000og><LomcS7<03omcS7<00ol0003oC[5>odja
CP0:odjaCP03o`000?m1_T7o@Ki100go@Ki100?o0000ocS7>?lhacP01_lhacP4o`0000CoSg2?00?o
0000oe6^DOmA[U400_mA[U400ol0003oWF:MoieRW@0FoieRW@03o`000?nCK9?oTfbC00_oTfbC00?o
0000oj5NXOnQGZ402onQGZ400ol0003o`Ck1ol4n`@06ol4n`@03o`000?oB;M;o000000[ojaC[00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?o`3o3ol0o`00?ol0o`00?o0000on8Mh_oR7N802?oR7N8=
o`0000[oXebS00?o0000og><LomcS7<03omcS7<00ol0003oC[5>odjaCP0;odjaCP03o`000?m1_T7o
@Ki100co@Ki100?o0000ocS7>?lhacP02_lhacP4o`0000GoDJiA00?o0000oieRWOnMHYd05_nMHYd0
0ol0003oTfbCoi=/T`0:oi=/T`03o`000?nQGZ7oXEjQ00coXEjQ00?o0000ol4n`Oo1?/401?o1?/42
o`0000?odRgB00?o0000on/Djoo[5>/02?o[5>/00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo0?
l?o`3o000oo`3o000ol0003ohQgRon8MhP07on8MhP03o`000?nYEZWoZEJY00WoZEJY00?o0000oj=L
XonSG:<02OnSG:<00ol0003oLhacog><L`0=og><L`03o`000?m>/DkoC[5>00coC[5>00?o0000od6n
@Om1_T403?m1_T400ol0003o><LhocS7>00;ocS7>003o`000?lPgb3o000000KoDJiA00?o0000oieR
WOnMHYd05_nMHYd00ol0003oTfbCoi=/T`09oi=/T`03o`000?nQGZ7oXEjQ00coXEjQ00?o0000ol4n
`Oo1?/400oo1?/400ol0003odRgBom8]dP03om8]dP03o`000?o[5>_ojaC[00SojaC[00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Col0o`00?o0000on8Mh_oR7N801_oR7N800ol0003o
ZEJYojUFZ@08ojUFZ@03o`000?nSG:?oXebS00_oXebS00?o0000og><LomcS7<02?mcS7<4o`0000oo
C[5>00?o0000od6n@Om1_T402om1_T400ol0003o><LhocS7>00;ocS7>004o`000?lPgb3o8=lPo`00
00OoDJiA00?o0000oieRWOnMHYd05OnMHYd00ol0003oTfbCoi=/T`08oi=/T`03o`000?nQGZ7oXEjQ
00goXEjQ00?o0000ol4n`Oo1?/400_o1?/400ol0003odRgBom8]dP05om8]dP03o`000?o[5>_ojaC[
00OojaC[00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Gol0o`00?o0000on8Mh_oR
7N801OoR7N800ol0003oZEJYojUFZ@08ojUFZ@03o`000?nSG:?oXebS00_oXebS00?o0000og><Lomc
S7<00omcS7<5o`0000?oCk1?00?o0000odjaC_m>/Dh03_m>/Dh00ol0003o@Ki1od6n@@0:od6n@@03
o`000?lhacSo><Lh00[o><Lh00Go0000ob3O8?lPgb3o8=lPo`000007oe6^D@03o`000?nMHYgoWF:M
01GoWF:M00?o0000oi=/TonCK9<02?nCK9<00ol0003oXEjQoj5NX@0=oj5NX@03o`000?o1?/7o`Ck1
00;o00002?oB;M800ol0003ojaC[on/Dj`08on/Dj`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003ol0o`oo0?l005oo0?l003o`000?oR7N;ohQgR00Go
hQgR00?o0000ojUFZOnYEZT02?nYEZT00ol0003oXebSoj=LX`0<oj=LX`Go00002Om?/4l00ol0003o
C[5>odjaCP0<odjaCP;o00003?m1_T400ol0003o><LhocS7>00:ocS7>005o`000?lPgb3o8=lPob3O
8?l000002?mA[U400ol0003oWF:MoieRW@0DoieRW@?o00001onCK9<00ol0003oXEjQoj5NX@0>oj5N
X@03o`000?o1?/7o000000_odRgB00?o0000on/Djoo[5>/01_o[5>/00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo0?l?o`3o001Oo`3o000ol0003ohQgRon8MhP04on8MhP03o`000?nYEZWoZEJY00Oo
ZEJY00?o0000oj=LXonSG:<03?nSG:<01?l0003oLhacog><Lol0000;odn`C`03o`000?m>/DkoC[5>
00_oC[5>00Co0000oacS7?lLhaco00002_m1_T400ol0003o><LhocS7>00:ocS7>003o`000?lPgb3o
8=lP00;o8=lP00?o0000oe6^DOmA[U401_mA[U400ol0003oWF:MoieRW@0AoieRW@?o00000omXUfP0
0ol0003oTfbCoi=/T`04oi=/T`03o`000?nQGZ7oXEjQ00goXEjQ1?l0000;om8]dP03o`000?o[5>_o
jaC[00GojaC[00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o`3o3ol0o`00Kol0o`00Co0000on8M
h_oR7N;ohQgR1?l00008ojUFZ@03o`000?nSG:?oXebS00_oXebS00?o0000og><LomcS7<00_mcS7<0
0ol0003oCk1?odn`C`08odn`C`03o`000?m>/DkoC[5>00[oC[5>00?o0000oacS7?lLha`00_lLha`0
0ol0003o@Ki1od6n@@03od6n@@Go00002olhacP00ol0003o8=lPob3O8003ob3O8003o`000?mA[U7o
DJiA00OoDJiA00?o0000oieRWOnMHYd03_nMHYd2o`0000OoJ9MX00?o0000oi=/TonCK9<00_nCK9<0
0ol0003oXEjQoj5NX@0=oj5NX@03o`000?no@;oo_d2o00;o_d2o00?o0000om8]d_oB;M802OoB;M80
0ol0003ojaC[on/Dj`03on/Dj`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l007oo0?
l0?o00001?o=</d00ol0003oZEJYojUFZ@05ojUFZ@03o`000?nSG:?oXebS00[oXebS00?o0000og><
LomcS7<00omcS7<00ol0003oCk1?odn`C`09odn`C`03o`000?m>/DkoC[5>00SoC[5>00?o0000oacS
7?lLha`01?lLha`5o`0000Co0?l000?o0000ocS7>?lhacP02OlhacP00ol0003o8=lPob3O8003ob3O
8003o`000?mA[U7oDJiA00SoDJiA00?o0000oieRWOnMHYd02_nMHYd3o`0000[oJ9MX00Go0000oi=/
TonCK9?oTfbCo`00000>oj5NX@03o`000?no@;oo_d2o00Co_d2o0_l00009om8]dP03o`000?o[5>_o
jaC[00;ojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?o`3o3ol0o`00Ool0o`00?o0000oldb
cOo=</d01Oo=</d00ol0003oZEJYojUFZ@03ojUFZ@03o`000?nSG:?oXebS00[oXebS00?o0000og><
LomcS7<01?mcS7<00ol0003oCk1?odn`C`09odn`C`03o`000?m>/DkoC[5>00OoC[5>00?o0000oacS
7?lLha`01OlLha`00ol0003o0?l0o`3o0007o`3o0003o`000?lhacSo><Lh00Oo><Lh00?o0000ob3O
8?lPgb001?lPgb000ol0003oDJiAoe6^D@08oe6^D@03o`000?nMHYgoWF:M00SoWF:M0_l0000>ofRG
J0Co00003?nQGZ42o`0000Wo_d2o00?o0000om8]d_oB;M801ooB;M801?l0003ojaC[on/Djol0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo0?l?o`3o001Oo`3o000ol0003ocC;=oldbc@07oldbc@;o00000onYEZT00ol0
003oXebSoj=LX`09oj=LX`03o`000?mcS7?oLhac00KoLhac00?o0000odn`Com?/4l02Om?/4l00ol0
003oC[5>odjaCP05odjaCP03o`000?lLhaco7><L00Ko7><L00?o0000o`3o0?l0o`002?l0o`000ol0
003o><LhocS7>006ocS7>003o`000?lPgb3o8=lP00Co8=lP00?o0000oe6^DOmA[U402OmA[U44o`00
00?oWF:M0ol0000@ofRGJ005o`000?nkA;_o^dBkok]4^ol000002_nQGZ400ol0003o_d2ookm0_`0:
okm0_`Ko00000ooB;M800ol0003ojaC[o`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo0?l?o`3o001?o`3o000ol0
003ocC;=oldbc@0:oldbc@04o`000?nYEZWoZEJYo`0000[oXebS00?o0000og><LomcS7<01omcS7<0
0ol0003oCk1?odn`C`09odn`C`03o`000?m>/DkoC[5>00CoC[5>00?o0000oacS7?lLha`01olLha`0
0ol0003o0?l0o`3o0008o`3o00;o00001_lhacP00ol0003o8=lPob3O8005ob3O8003o`000?mA[U7o
DJiA00WoDJiA00Co0000od2o@?m0_d3o@;m00ol0000BofRGJ003o`000?nkA;_o^dBk00?o^dBk0_l0
0006oj5NX@;o00003Ono@;l00ol0003oka3_onl@k`03onl@k`Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo0?l?o`3o000oo`3o00
0ol0003ocC;=oldbc@0<oldbc@;o00002_nSG:<00ol0003oLhacog><L`08og><L`03o`000?m?/4oo
Ck1?00[oCk1?00?o0000odjaC_m>/Dh00_m>/Dh00ol0003o7><LoacS7008oacS7003o`000?l0o`3o
0?l000Ko0?l00_l00002oaOX5`03o`000?lhacSo><Lh00;o><Lh00?o0000ob3O8?lPgb001_lPgb00
0ol0003oDJiAoe6^D@08oe6^D@03o`000?m0_d3o@;m000Co@;m000?o0000ofRGJ?mXUfP03omXUfP0
0ol0003o^dBkok]4^`06ok]4^`;o00000onQGZ400ol0003o_d2ookm0_`0=okm0_`03o`000?o_4>oo
ka3_00Ooka3_0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003ol0o`oo0?l002oo0?l003o`000?o=</gocC;=
00kocC;=00?o0000oj=LXonSG:<01onSG:<00ol0003oLhacog><L`0:og><L`03o`000?m?/4ooCk1?
00WoCk1?00Go0000odjaC_m>/DkoC[5>o`00000;oacS7003o`000?l0o`3o0?l000Co0?l00_l00005
oaOX5`05o`000?lhacSo><LhocS7>?l000002?lPgb000ol0003oDJiAoe6^D@08oe6^D@03o`000?m0
_d3o@;m000Go@;m000?o0000ofRGJ?mXUfP03_mXUfP00ol0003o^dBkok]4^`08ok]4^`03o`000?nQ
GZ7o000000oo_d2o00?o0000onl@koo_4>l02?o_4>l01?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?o`3o3ol0o`o`00017ocC;=00?o0000oj=LXonSG:<01_nSG:<00ol0003oLhac
og><L`0;og><L`03o`000?m?/4ooCk1?00WoCk1?00Co0000odjaC_m>/Dko00003?lLha`00ol0003o
0?l0o`3o0002o`3o00;o00002?lGj1L00ol0003o><Lho`000009ob3O8003o`000?mA[U7oDJiA00So
DJiA00?o0000od2o@?m0_d001Om0_d000ol0003oJ9MXofRGJ00=ofRGJ003o`000?nkA;_o^dBk00[o
^dBk00?o0000okm0_ono@;l03_no@;l00ol0003oka3_onl@k`07onl@k`03o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Boldbc@03o`00
0?nSG:?oXebS00CoXebS00?o0000og><LomcS7<03?mcS7<00ol0003oCk1?odn`C`0:odn`C`?o0000
3?lLha`00ol0003o0?l0o`3o0002o`0000_o5nPG00?o0000ob3O8?lPgb002?lPgb000ol0003oDJiA
oe6^D@07oe6^D@03o`000?m0_d3o@;m000Oo@;m000?o0000ofRGJ?mXUfP03?mXUfP00ol0003o^dBk
ok]4^`0;ok]4^`;o00003_no@;l00ol0003oka3_onl@k`07onl@k`03o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo0?l?o`3o000oo`3o000ol0003ocC;=oldbc@0?oldbc@?o00000onS
G:<00ol0003oLhacog><L`0>og><L`03o`000?m?/4ooCk1?00SoCk1?00Co0000obCK9?lTfbCo9=/T
0_l0000:oacS70?o00003OlGj1L00ol0003o8=lPob3O8008ob3O8003o`000?mA[U7oDJiA00OoDJiA
00?o0000od2o@?m0_d001om0_d000ol0003oJ9MXofRGJ00;ofRGJ003o`000?nkA;_o^dBk00co^dBk
00?o0000omhQg_l000000_l0000:okm0_`03o`000?o_4>ooka3_00Soka3_00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003ol0o`oo0?l004oo0?l003o`000?o=</gocC;=00cocC;=0_l0
0003okA;]003o`000?nSG:?o0000017oLhac00?o0000odn`Com?/4l01om?/4l00ol0003o9=/TobCK
9004obCK90;o00002?lLha`00ol0003o5nPGoaOX5`0>oaOX5`;o00002?lPgb000ol0003oDJiAoe6^
D@06oe6^D@03o`000?m0_d3o@;m000Wo@;m000?o0000ofRGJ?mXUfP02OmXUfP00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oN8MkogR7N00;ogR7N0ol00007okm0_`03o`000?o_4>ooka3_00Ooka3_00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol0o`oo0?l005oo0?l003o`000?o=</go
cC;=00WocC;=0_l00006okA;]003o`000?mcS7?oLhac013oLhac00?o0000odn`Com?/4l01_m?/4l0
0ol0003o9=/TobCK9007obCK9003o`000?lLhaco7><L00Co7><L0ol0000>oaOX5`03o`000?l5nPGo
1OX500?o00001OlPgb000ol0003oDJiAoe6^D@06oe6^D@03o`000?m0_d3o@;m000[o@;m000?o0000
ofRGJ?mXUfP02?mXUfP00ol0003o^dBkok]4^`0=ok]4^`03o`000?oN8MkogR7N00GogR7N0ol00004
okm0_`03o`000?o_4>ooka3_00Ooka3_00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ol0o`oo0?l006oo0?l003o`000?o=</gocC;=00GocC;=0ol00008okA;]003o`000?mcS7?oLhac
017oLhac00Co0000odn`Com?/4ooCk1?1?l0000;obCK90;o000000Co7><Lo`000?l0003o00000ol`
cc02o`0000_o5nPG00?o0000o`Gj1Ol5nPD01?l5nPD2o`0000?o8=lP00?o0000oe6^DOmA[U401_mA
[U400ol0003o@;m0od2o@00:od2o@003o`000?mXUfSoJ9MX00OoJ9MX00?o0000ok]4^onkA;/03_nk
A;/00ol0003ogR7NomhQgP08omhQgPCo00002_o_4>l00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003ol0o`oo0?l007oo0?l003o`000?o=</gocC;=00;ocC;=0_l0000<okA;]003o`000?mcS7?o
Lhac013oLhac1?l00003od6n@@03o`000?lTfbCo9=/T00_o9=/T00?o0000oc3?<?l`cc001_l`cc00
0ol0003o5nPGoaOX5`07oaOX5`03o`000?l5nPGo1OX500Oo1OX53?l0000>od2o@003o`000?mXUfSo
J9MX00KoJ9MX00?o0000ok]4^onkA;/03_nkA;/00ol0003ogR7NomhQgP0;omhQgP03o`000?o_4>oo
ka3_00Ooka3_00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?o`3o3ol0o`00Wol0o`00Co0000oldb
cOl0003o00003_ndBk@00ol0003oLhacog><L`0?og><L`03o`000?m1_T7o@Ki100Ko@Ki100?o0000
obCK9?lTfb@02_lTfb@00ol0003o<<l`oc3?<007oc3?<0;o00001_lGj1L00ol0003o1OX5o`Gj1@08
o`Gj1@03o`000?mHYeSoF:MH00SoF:MH00?o0000od2o@?m0_d003?m0_d000ol0003oJ9MXofRGJ005
ofRGJ003o`000?nkA;_o^dBk00oo^dBk0_l0000=omhQgP03o`000?o_4>ooka3_00Koka3_00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o`3o3ol0o`00[ol0o`00?o0000okA;]?ndBk@03_ndBk@00ol0
003oLhacog><L`0>og><L`03o`000?m1_T7o@Ki100Oo@Ki100?o0000obCK9?lTfb@02_lTfb@00ol0
003o<<l`oc3?<009oc3?<0;o00000olGj1L00ol0003o1OX5o`Gj1@09o`Gj1@03o`000?mHYeSoF:MH
00WoF:MH00?o0000od2o@?m0_d002_m0_d04o`0000CoJ9MX00?o0000ok]4^onkA;/04?nkA;/01?l0
003ofRGJo`000?l0000<omhQgP03o`000?o_4>ooka3_00Goka3_00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?o`3o3ol0o`00[ol0o`00?o0000okA;]?ndBk@03ondBk@@o`0000[o@Ki100?o0000obCK
9?lTfb@02OlTfb@00ol0003o3?<<o`00000<oc3?<005o`000?lGj1Oo0000o`Ki1_l000002_l5nPD0
0ol0003oF:MHoeRWF009oeRWF003o`000?m0_d3o@;m000Oo@;m00ol00004og2?L0?o000000?oJ9MX
o`000?nkA;/04OnkA;/01?l0003ofRGJomXUf_oJ9MX2o`0000_ogR7N00?o0000onl@koo_4>l00oo_
4>l00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003o]4^dokA;]00?
okA;]003o`000?miQWWoNHIi00coNHIi00?o0000od6n@Om1_T402Om1_T400ol0003o9=/TobCK9007
obCK9004o`000?l<l`co3?<<o`0000go<<l`00Go0000o`Ki1_l6n@Ko1_T6o`000009o`Gj1@03o`00
0?mHYeSoF:MH00[oF:MH00?o0000od2o@?m0_d000om0_d03o`0000[oL8m`00?o0000ok]4^onkA;/0
4?nkA;/00ol0003ofRGJomXUfP04omXUfP;o00002_oN8Mh00ol0003oka3_onl@k`04o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000col0o`00?o0000okA;]?ndBk@03ondBk@00ol0003oNHIiogV6N@0<ogV6N@03o`000?m1
_T7o@Ki100Wo@Ki100?o0000obCK9?lTfb@01_lTfb@00ol0003o3?<<o`cc3002o`cc3003o`000?l`
cc3o<<l`00[o<<l`00?o0000o`Ki1_l6n@H00_l6n@H00ol0003o1OX5o`Gj1@06o`Gj1@03o`000?mH
YeSoF:MH00[oF:MH00?o0000od2o@?m0_d000ol0000=og2?L003o`000?nkA;_o^dBk013o^dBk00?o
0000omXUf_oJ9MX01_oJ9MX2o`0000WogR7N0_l00004oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003o]4^dokA;]00=okA;]0?o00003omiQWT0
0ol0003o@Ki1od6n@@08od6n@@03o`000?lTfbCo9=/T00Go9=/T00?o0000o`cc3?l<l``00ol<l``0
0ol0003o<<l`oc3?<00:oc3?<003o`000?l6n@Ko1_T600?o1_T600?o0000o`Gj1Ol5nPD01Ol5nPD0
0ol0003oF:MHoeRWF00;oeRWF0;o00004Om`Sg000ol0003o^dBkok]4^`0?ok]4^`03o`000?oJ9M[o
fRGJ00SofRGJ0_l00007omhQgP03o`000?ol0ocoo0?l00Coo0?l00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo0?l?o`3o002?o`3o000ol0003o]4^dokA;]009okA;]0Go00000_n0Oh000ol0
003oNHIiogV6N@0=ogV6N@03o`000?m1_T7o@Ki100Wo@Ki100?o0000obCK9?lTfb@01?lTfb@00ol0
003o3?<<o`cc3004o`cc3003o`000?l`cc3o<<l`00So<<l`00?o0000o`Ki1_l6n@H01Ol6n@H00ol0
003o1OX5o`Gj1@04o`Gj1@03o`000?mHYeSoF:MH00_oF:MH00?o0000og2?L?m`Sg004?m`Sg000ol0
003o^dBkok]4^`0?ok]4^`03o`000?oJ9M[ofRGJ00[ofRGJ0_l00004omhQgP03o`000?ol0ocoo0?l
00Koo0?l0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003ol0o`oo0?l007oo0?l003o`000?ndBkCo]4^d00Co]4^d1Ol00007oh1oP003
o`000?miQWWoNHIi00goNHIi00?o0000od6n@Om1_T402Om1_T400ol0003o9=/TobCK9003obCK9003
o`000?l<l`co3?<<00Go3?<<00?o0000oc3?<?l`cc002?l`cc000ol0003o1_T6o`Ki1P06o`Ki1P03
o`000?l5nPGo1OX500?o1OX500?o0000oeRWF?mHYeP02omHYeP00ol0003oL8m`og2?L00@og2?L003
o`000?nkA;_o^dBk00oo^dBk00?o0000omXUf_oJ9MX03?oJ9MX2o`000003omhQg_l0003oo0?l00[o
o0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o`3o3ol0o`00Ool0o`00?o0000okA;]?l00000
1?l0000<oh1oP003o`000?miQWWoNHIi00koNHIi00?o0000od6n@Om1_T402?m1_T400ol0003o9=/T
obCK9002obCK9003o`000?l<l`co3?<<00Oo3?<<00?o0000oc3?<?l`cc001ol`cc000ol0003o1_T6
o`Ki1P07o`Ki1P03o`000?l5nPGo1OX500;o1OX500?o0000oeRWF?mHYeP02omHYeP00ol0003oL8m`
og2?L00Aog2?L003o`000?nkA;_o^dBk00go^dBk00?o0000omXUf_oJ9MX03ooJ9MX00ol0003oo0?l
oo`3o00;oo`3o0;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo0?l?o`3o001Oo`3o03o`00017oP7n000?o0000ogV6NOmiQWT03_mi
QWT00ol0003o@Ki1od6n@@09od6n@@04o`000?lTfbCo9=/To`0000[o3?<<00?o0000oc3?<?l`cc00
1ol`cc000ol0003o1_T6o`Ki1P08o`Ki1P05o`000?l5nPGo1OX5o`Gj1Ol000003OmHYeP00ol0003o
L8m`og2?L00Aog2?L0?o00003OnkA;/00ol0003ofRGJomXUfP0?omXUfP03o`000?ol0ocoo0?l00go
o0?l00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_o`3o02o`0000;ocS7>00?o0000oh1oP?n0Oh003on0Oh000ol0003o
NHIiogV6N@0>ogV6N@03o`000?m1_T7o@Ki100So@Ki11Ol0000;o`cc3003o`000?l`cc3o<<l`00Ko
<<l`00?o0000o`Ki1_l6n@H02Ol6n@H01?l0003o1OX5o`Gj1Ol0000=oeRWF003o`000?m`Sg3oL8m`
017oL8m`00?o0000oe^TFomKY5/00ol0000:ok]4^`Co00003OoJ9MX00ol0003oo0?loo`3o00?oo`3
o003o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo0?l?o`3o3ol0o`0_l00005olhacP03o`000?n0Oh3oP7n000koP7n000?o0000ogV6
NOmiQWT03_miQWT00ol0003o@Ki1od6n@@07od6n@@03o`000?lhacSo><Lh00?o><Lh00?o0000o`cc
3?l<l``02?l<l``00ol0003o<<l`oc3?<005oc3?<003o`000?l6n@Ko1_T600[o1_T61Ol0000<oeRW
F003o`000?m`Sg3oL8m`013oL8m`00?o0000oe^TFomKY5/01?mKY5/3o`0000Ko^dBk00?o0000omTV
fOoI9]T00_oI9]T5o`0000SofRGJ00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o`3o3ol0o`00?o
l0o`00?o0000olhac_o><Lh01?o><Lh00ol0003oP7n0oh1oP00=oh1oP003o`000?miQWWoNHIi00oo
NHIi00?o0000od6n@Om1_T401?m1_T42o`0000Oo><Lh00?o0000o`cc3?l<l``01ol<l``Eo`0000Go
4^dB00?o0000oeRWF?mHYeP02?mHYeP3o`00013oL8m`00?o0000oe^TFomKY5/02?mKY5/3o`0000;o
^dBk00?o0000omTVfOoI9]T02?oI9]T5o`0000?ofRGJ00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?o`3o3ol0o`00Col0o`00?o0000olhac_o><Lh01Oo><Lh00ol0003oP7n0oh1oP00;oh1oP0Co0000
3omiQWT00ol0003o@Ki1od6n@@03od6n@@03o`000?lhacSo><Lh00So><Lh00?o0000o`cc3?l<l``0
1?l<l``2o`0000So=/Tf00?o0000obCK9?lTfb@02?lTfb@00ol0003o4^dBoa;]4P05oa;]4P;o0000
1_mHYeP2o`0000?oC;=<00?o0000og2?L?m`Sg003?m`Sg000ol0003oFjAKoe^TF`0<oe^TF`;o0000
4?oI9]T3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l005oo0?l003o`000?o><LkocS7>00KocS7>00?o
0000oh1oP?n0Oh002On0Oh000ol0003oQ7^4o`000002oeRWF0?o00003?miQWT01?l0003o@Ki1od6n
@Om1_T42o`0000co><Lh00?o0000o`cc3?l<l``00_l<l``00ol0003o=/TfocK9=P08ocK9=P03o`00
0?lTfbCo9=/T00So9=/T00?o0000oa;]4_lBkA801olBkA800ol0003oF:MHoeRWF002oeRWF003o`00
0?m</dcoC;=<00CoC;=<0_l0000;og2?L003o`000?mKY5_oFjAK00coFjAK00?o0000oiUVVOl00000
4_oI9]T00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003ol0o`oo0?l006oo0?l003o`000?o><LkocS7>00OocS7>00?o
0000oh1oP?n0Oh001_n0Oh02o`0000;oQ7^400?o0000oeRWF?mHYeP00omHYeP3o`0000[oNHIi00?o
0000od6n@Ol000003olhacP01?l0003o3?<<o`000?l0000;ocK9=P03o`000?lTfbCo9=/T00So9=/T
00?o0000oa;]4_lBkA802?lBkA801?l0003oF:MHo`000?l00009odbcC003o`000?m`Sg3oL8m`00Oo
L8m`00?o0000oe^TFomKY5/03?mKY5/01?l0003oVFJIoiUVVOl0000ComTVf@03o`000?ol0ocoo0?l
00coo0?l0ol000000ool0oco0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo0?l?o`3o001oo`3o000ol0003ocS7>olhacP08olhacP03o`000?n0Oh3oP7n000Co
P7n000?o0000ohAkQ?n4Nh@00on4Nh@00ol0003oF:MHoeRWF005oeRWF0?o00001_miQWT4o`00013o
><Lh00?o0000ocK9=_lfbCH03?lfbCH00ol0003o9=/TobCK9007obCK9003o`000?lBkA;o4^dB00Wo
4^dB00?o0000odbcC?m</d`02_m</d`2o`0000KoL8m`00?o0000oe^TFomKY5/03?mKY5/00ol0003o
VFJIoiUVV@02oiUVV@03o`000?oI9]WofBKI00oofBKI00?o0000ondBkOl000002ool0o`2o`0000Co
o0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003ol0o`oo0?l008oo0?l003o`000?o><LkocS7>00WocS7>00Co0000oh1oP?n0Oh3o
P7n00_l00006ohAkQ003o`000?mHYeSoF:MH00SoF:MH0ol000000omiQWWo0000o`000004odVfB@03
o`000?lhacSo><Lh00go><Lh00?o0000ocK9=_lfbCH03?lfbCH00ol0003o9=/TobCK9007obCK9003
o`000?lBkA;o4^dB00Wo4^dB00?o0000odbcC?m</d`03?m</d`00ol0003oL8m`og2?L003o`0000ko
FjAK00?o0000oiUVVOnIIYT00onIIYT00ol0003ofBKIomTVf@0>omTVf@05o`000?o]4^gokA;]ondB
kOl000002?ol0o`2o`0000Ooo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003ol0o`oo0?l009oo0?l003o`000?o><LkocS7>00[o
cS7>00?o0000oh1oP?l000002?n4Nh@00ol0003oF:MHoeRWF00;oeRWF003o`000?m9]TWoBKI900Go
BKI900?o0000ocS7>?lhacP03?lhacP00ol0003o=/TfocK9=P0<ocK9=P03o`000?lTfbCo9=/T00Oo
9=/T00?o0000oa;]4_lBkA802?lBkA82o`0000ooC;=<0_l00002ofNHI`03o`000?mKY5_oFjAK00_o
FjAK00?o0000oiUVVOnIIYT01?nIIYT00ol0003ofBKIomTVf@0=omTVf@03o`000?o]4^gokA;]00?o
kA;]00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo0?l003o`000?o><LkocS7>00_ocS7>00?o0000ohAkQ?n4Nh@0
1on4Nh@00ol0003oF:MHoeRWF00;oeRWF003o`000?m9]TWoBKI900KoBKI900?o0000ocS7>?lhacP0
2olhacP2o`0000go=/Tf00?o0000obCK9?lTfb@01olTfb@00ol0003o4^dBoa;]4P07oa;]4P04o`00
0?lOh1oo7n0Oo`0000koC;=<00?o0000ofNHIomWV6L00_mWV6L00ol0003oFjAKoe^TF`09oe^TF`03
o`000?nIIYWoVFJI00KoVFJI00?o0000omTVfOoI9]T02ooI9]T00ol0003okA;]ondBk@05ondBk@04
o`000?ol0oco0000o`0000coo0?l00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Sol0o`00?o0000olhac_o><Lh02_o><Lh2o`0000Wo
Q7^400?o0000oeRWF?mHYeP02omHYeP00ol0003oBKI9odVfB@07odVfB@03o`000?lhacSo><Lh00Wo
><Lh00Co0000o`Ck1?l4n`Co00003?lfbCH00ol0003o9=/TobCK9007obCK9003o`000?lBkA;o4^dB
00Ko4^dB00Go0000oaoP7olOh1oo7n0Oo`00000>odbcC003o`000?mWV6OoIiQW00?oIiQW00?o0000
oe^TFomKY5/01omKY5/00ol0003oVFJIoiUVV@07oiUVV@03o`000?oI9]WofBKI00[ofBKI00?o0000
ondBkOo]4^d01oo]4^d00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo0?l003o`000?o><LkocS7>
00WocS7>00Co0000oka3_?nl@kco00002On4Nh@00ol0003oF:MHoeRWF009oeRWF003o`000?m9]TWo
BKI900WoBKI900?o0000ocS7>?lhacP01olhacP00ol0003o1?/4o`Ck1002o`Ck1003o`000?lfbCKo
=/Tf00Wo=/Tf00?o0000obCK9?lTfb@01olTfb@00ol0003o4^dBoa;]4P05oa;]4P03o`000?lOh1oo
7n0O00?o7n0O00?o0000odbcC?m</d`02_m</d`00ol0003oIiQWofNHI`05ofNHI`03o`000?mKY5_o
FjAK00GoFjAK00?o0000oiUVVOnIIYT02?nIIYT00ol0003ofBKIomTVf@09omTVf@03o`000?o]4^go
kA;]00SokA;]00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_o`3o03o`0000WocS7>00?o0000oka3
_?nl@k`00_nl@k`00ol0003oQ7^4ohAkQ006ohAkQ003o`000?mHYeSoF:MH00WoF:MH00?o0000odVf
BOm9]TT02_m9]TT00ol0003o><LhocS7>005ocS7>003o`000?l4n`Co1?/400Co1?/400?o0000ocK9
=_lfbCH02?lfbCH00ol0003o9=/TobCK9007obCK9003o`000?lBkA;o4^dB00Co4^dB00?o0000oaoP
7olOh1l01?lOh1l00ol0003oC;=<odbcC00:odbcC003o`000?mWV6OoIiQW00KoIiQW00?o0000oe^T
FomKY5/00omKY5/00ol0003oVFJIoiUVV@09oiUVV@03o`000?oI9]WofBKI00SofBKI00?o0000ondB
kOo]4^d02Oo]4^d00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onPGj0?o00001Oo><Lh00ol0003o
_4>loka3_003oka3_003o`000?n4NhCoQ7^400KoQ7^400?o0000oeRWF?mHYeP02OmHYeP00ol0003o
BKI9odVfB@0;odVfB@03o`000?lhacSo><Lh00?o><Lh00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o
=/TfocK9=P08ocK9=P03o`000?lTfbCo9=/T00Ko9=/T00?o0000oa;]4_lBkA800_lBkA82o`0000So
7n0O00?o0000odbcC?m</d`02Om</d`00ol0003oIiQWofNHI`07ofNHI`05o`000?mKY5_oFjAKoe^T
Fol000003OnIIYT00ol0003ofBKIomTVf@06omTVf@03o`000?o]4^gokA;]00[okA;]00?o0000oo`3
o?ol0o`03Ool0o`00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?oX5nSoj1OX00Goj1OX0ol000000oo><Lko0000oka3_006oka3_003
o`000?n4NhCoQ7^400GoQ7^400?o0000oeRWF?mHYeP02OmHYeP00ol0003oBKI9odVfB@0<odVfB@05
o`000?lhacSo><LhocS7>?l000002_l4n`@00ol0003o=/TfocK9=P07ocK9=P03o`000?lTfbCo9=/T
00Ko9=/T00?o0000oa;]4_l000000_l000000omB[E;o0000oaoP7`07oaoP7`03o`000?m</dcoC;=<
00SoC;=<00?o0000ofNHIomWV6L02OmWV6L00ol0003oFjAKo`00000=oiUVV@Co00001OoI9]T00ol0
003okA;]ondBk@0;ondBk@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003oj1OXonPGj008onPGj003
o`000?nl@kco_4>l00Oo_4>l00?o0000ohAkQ?n4Nh@01?n4Nh@00ol0003oF:MHoeRWF009oeRWF003
o`000?m9]TWoBKI900goBKI900?o0000ocS7>?l000003?l4n`@:o`0000Oo9=/T0ol00005oe:]DP03
o`000?lOh1oo7n0O00Ko7n0O00?o0000odbcC?m</d`01om</d`00ol0003oIiQWofNHI`0:ofNHI`03
o`000?nIIYWoVFJI00_oVFJI00?o0000om4^dOoA;]400_oA;]43o`000003omTVfOl0003okA;]00_o
kA;]0ol0000>oo`3o003o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onPGj?oX5nP02OoX5nP00ol0003o_4>loka3_007oka3_003o`00
0?n4NhCoQ7^400GoQ7^400?o0000oeRWF?mHYeP01omHYeP00ol0003oBKI9odVfB@0?odVfB@;o0000
2ol4n`@00ol0003oA;]4odBkA007odBkA003o`000?lTfbCo9=/T00;o9=/T0ol00008oe:]DP03o`00
0?lOh1oo7n0O00Ko7n0O00?o0000odbcC?m</d`01om</d`00ol0003oIiQWofNHI`0:ofNHI`03o`00
0?nIIYWoVFJI00[oVFJI00?o0000om4^dOoA;]401_oA;]400ol0003okA;]ondBk@08ondBk@?o0000
0_oa3_400ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onPGj?oX5nP02OoX5nP00ol0003o_4>loka3
_008oka3_003o`000?n4NhCoQ7^400CoQ7^400?o0000oeRWF?mHYeP01omHYeP00ol0003oBKI9odVf
B@0>odVfB@04o`000?lHiaSo6>LHo`0000Wo1?/400?o0000odBkA?m4^d@02Om4^d@01?l0003o9=/T
o`000?l0000<oe:]DP03o`000?lOh1oo7n0O00Ko7n0O00?o0000odbcC?m</d`01_m</d`00ol0003o
IiQWofNHI`0;ofNHI`03o`000?nIIYWoVFJI00OoVFJI0_l00009om4^d@03o`000?o]4^gokA;]00Co
kA;]1?l00006oo4>l@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003oj1OXonPGj009onPGj003o`00
0?nl@kco_4>l00So_4>l00?o0000ohAkQ?n4Nh@00on4Nh@>o`0000goBKI900?o0000oaSW6?lHiaP0
0_lHiaP00ol0003o1?/4o`Ck1005o`Ck1003o`000?m4^dCoA;]400_oA;]400?o0000oe:]D_mB[E80
3?mB[E800ol0003o7n0OoaoP7`06oaoP7`03o`000?m</dcoC;=<00GoC;=<00?o0000ofNHIomWV6L0
3?mWV6L00ol0003oVFJIoiUVV@06oiUVV@03o`000?oA;]7odBkA00[odBkA00?o0000ondBkOo]4^d0
0ol0000:oo4>l@?o00002_ol0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oX5nSoj1OX00_oj1OX00?o0000oka3_?nl@k`02?nl
@k`01Ol0003oQ7^4ohAkQ?n4NhCo000000_oGimO00?o0000o`Oh1ol7n0L00ol00009odVfB@03o`00
0?lHiaSo6>LH00Co6>LH00?o0000o`Ck1?l4n`@00ol4n`@00ol0003oA;]4odBkA00<odBkA003o`00
0?mB[E;oDZeB00goDZeB00?o0000oaoP7olOh1l01_lOh1l00ol0003oC;=<odbcC003odbcC0?o0000
3OmWV6L00ol0003oVFJIoiUVV@05oiUVV@03o`000?oA;]7odBkA00codBkA0_l0000=oo4>l@03o`00
0?om0_goo@;m00?o00001ool0o`00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oX5nSoj1OX00_oj1OX00?o0000oka3_?nl@k`02?nl
@k`4o`0000coGimO00?o0000o`Oh1ol7n0L00ol7n0L3o`0000GoBKI900?o0000oaSW6?lHiaP01_lH
iaP01Ol0003o1?/4o`Ck1?l4n`Co000000ooA;]400?o0000oe:]D_mB[E803OmB[E800ol0003o7n0O
oaoP7`06oaoP7`03o`000?m</dcoC;=<00?o00000ol]dRd00ol0003oIiQWofNHI`0;ofNHI`03o`00
0?nIIYWoVFJI00?oVFJI00?o0000om4^dOoA;]403OoA;]400ol0003ol@kaoo4>l@0;oo4>l@03o`00
0?om0_goo@;m00Coo@;m0ol00004oo`3o003o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onPGj?oX5nP02_oX5nP3o`0000Ko_4>l0ol0
0003ojMHY`03o`000?mOWeooGimO00[oGimO00?o0000o`Oh1ol7n0L01_l7n0L3o`000003odVfBOl0
003o6>LH00Wo6>LH00?o0000o`Ck1?l000004?m4^d@00ol0003oDZeBoe:]DP0=oe:]DP03o`000?lO
h1oo7n0O00Oo7n0O0_l00007obgB;@03o`000?mWV6OoIiQW00[oIiQW00Co0000oiUVVOnIIYWoVFJI
0ol0000?om4^d@03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onPGj?oX5nP02_oX
5nP01?l0003ofbCKom/TfooK9=/2o`000004oka3_?l0003o0000o`0000KoYeRW00?o0000oenOGomO
Wel02_mOWel00ol0003o1oP7o`Oh1`09o`Oh1`03o`000?lHiaSo6>LH00[o6>LH00?o0000odBkA?m4
^d@03om4^d@00ol0003oDZeBoe:]DP0>oe:]DP03o`000?lOh1oo7n0O00Ko7n0O00?o0000obgB;Ol]
dRd01ol]dRd4o`0000SoIiQW00Co0000oiUVVOnIIYWo00000onQGZ42o`0000godBkA00?o0000oo4>
lOoa3_402_oa3_400ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onPGj?oX5nP02OoX5nP00ol0003o
fbCKom/Tf`04om/Tf`03o`000?nWF:OoYeRW00OoYeRW00?o0000oenOGomOWel02OmOWel00ol0003o
1oP7o`Oh1`0:o`Oh1`03o`000?lHiaSo6>LH00[o6>LH00?o0000odBkA?m4^d@03om4^d@00ol0003o
DZeBoe:]DP0>oe:]DP03o`000?lOh1oo7n0O00Go7n0O00?o0000obgB;Ol]dRd02?l]dRd01?l0003o
F:MHoeRWF?mHYeP7o`0000;oIiQW0_l00006oj5NX@;o00003?oA;]400ol0003ol@kaoo4>l@09oo4>
l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003oj1OXonPGj008onPGj003o`000?oK9=_ofbCK00Go
fbCK00?o0000ojMHYonWF:L02?nWF:L00ol0003oGimOoenOG`08oenOG`03o`000?l7n0Oo1oP700[o
1oP700?o0000oaSW6?lHiaP02olHiaP00ol0003oA;]4odBkA00>odBkA003o`000?mB[E;oDZeB00ko
DZeB1Ol00002oaoP7`03o`000?l]dRgo;M8]00Wo;M8]00?o0000oeRWF?mHYeP02?mHYeP3o`0000Wo
XEjQ0_l0000:om4^d@03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oX5nSoj1OX00Soj1OX00?o0000om/TfooK9=/01ooK9=/00ol0003oYeRWojMHY`07ojMHY`03o`00
0?mOWeooGimO00SoGimO00?o0000o`Oh1ol7n0L02_l7n0L00ol0003o6>LHoaSW600:oaSW60;o0000
3_m4^d@3o`0000goDZeB0ol00005oeVVF@;o00002ol]dRd00ol0003oF:MHoeRWF00;oeRWF0;o0000
2_nQGZ42o`0000OodBkA0ol00009oo4>l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:om/Tf`03o`00
0?nWF:OoYeRW00OoYeRW00?o0000oenOGomOWel02?mOWel>o`0000Wo6>LH0ol000000ol0o`3o0000
odBkA00:odBkA0?o00000_mMXUd00ol0003oDZeBoe:]DP09oe:]DP;o00002OmIYUT00ol0003o;M8]
obgB;@09obgB;@03o`000?mHYeSoF:MH00_oF:MH00?o0000ogb3O?l000002onQGZ42o`0000CodBkA
00Co0000onHIi_oV6NKoiQWV0_l00007oo4>l@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ook1?/00ol0003ofbCK
om/Tf`09om/Tf`03o`000?nWF:OoYeRW00KoYeRW00?o0000oenOGomOWel02?mOWel00ol0003o4^dB
oa;]4P0:oa;]4P03o`000?lHiaSo6>LH00Co6>LH0ol00005o`3o0003o`000?m4^dCoA;]400CoA;]4
1?l00006oefRG@03o`000?mB[E;oDZeB00KoDZeB0_l0000;oeVVF@03o`000?l]dRgo;M8]00Wo;M8]
00?o0000oeRWF?mHYeP02_mHYeP01Ol0003oO8=logb3O?mlPgco000000coXEjQ0_l000000ooA;]7o
0000onHIiP05onHIiP03o`000?oa3_7ol@ka00?ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oK9=_ofbCK00SofbCK00?o0000ojMHYonWF:L01_nWF:L00ol0003oGimOoenOG`07oenOG`03o`00
0?lBkA;o4^dB00_o4^dB00?o0000oaSW6?lHiaP00_lHiaP2o`0000Wo0?l000?o0000odBkA?m4^d@0
0ol0000;oefRG@03o`000?mB[E;oDZeB00;oDZeB0ol0000>oeVVF@03o`000?l]dRgo;M8]00Oo;M8]
00?o0000oeRWF?mHYeP02omHYeP00ol0003oO8=logb3O002ogb3O003o`000?nQGZ7oXEjQ00_oXEjQ
00?o0000onHIi_oV6NH01_oV6NH2o`0000?ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oK
9=_ofbCK00OofbCK00?o0000ojMHYonWF:L01onWF:L00ol0003oGimOoenOG`05oenOG`?o00003OlB
kA84o`0000_o0?l00ol0000?oefRG@04o`000?mB[E;o0000o`00017oFJII00?o0000obgB;Ol]dRd0
1ol]dRd00ol0003oF:MHoeRWF00:oeRWF003o`000?mlPgcoO8=l00CoO8=l00?o0000oj5NXOnQGZ40
1onQGZ43o`0000_oiQWV1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om/TfooK9=/02?oK9=/00ol0003oYeRWojMH
Y`06ojMHY`03o`000?mOWeooGimO00;oGimO0ol00003ocno?`03o`000?lBkA;o4^dB00[o4^dB00?o
0000o`3o0?l0o`002ol0o`000ol0003o1_T6o`00000AoefRG@03o`000?mIYUWoFJII017oFJII00?o
0000obgB;Ol]dRd01ol]dRd00ol0003oF:MHoeRWF00:oeRWF003o`000?mlPgcoO8=l00GoO8=l00Co
0000oj5NXOnQGZ7oXEjQ1Ol00002ok1?/003o`000?oV6NKoiQWV00WoiQWV00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000om/TfooK9=/01ooK9=/00ol0003oYeRWojMHY`05ojMHY`?o0000
00?oGimOo`000?l000001olo_cl00ol0003o4^dBoa;]4P08oa;]4P?o00002_l0o`02o`0000;o1_T6
00?o0000oefRGOmMXUd03omMXUd00ol0003oFJIIoeVVF@0AoeVVF@03o`000?l]dRgo;M8]00Oo;M8]
00?o0000oeRWF?mHYeP02OmHYeP00ol0003oO8=logb3O007ogb3O0?o00001on`Ck000ol0003oiQWV
onHIiP09onHIiP03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000om/TfooK9=/01ooK
9=/4o`0000;oYeRW0_l00003oj1OX003o`000?lo_coo?klo00So?klo0_l00006oa;]4P;o00000olE
jQD00ol0003o0?l0o`3o0006o`3o0003o`000?l6n@Ko1_T600?o1_T600?o0000oefRGOmMXUd03_mM
XUd00ol0003oFJIIoeVVF@0BoeVVF@03o`000?l]dRgo;M8]00Go;M8]00?o0000oeRWF?mHYeP02OmH
YeP00ol0003oO8=logb3O008ogb3O003o`000?n`Ck3o/4n`00Oo/4n`00?o0000onHIi_oV6NH02?oV
6NH00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oK9=_ofbCK00CofbCK0_l00004
omlOg`;o00001OnPGj000ol0003o?kloocno?`0:ocno?`03o`000?lBkA;o4^dB00;o4^dB00?o0000
oaGZ5OlEjQD01?lEjQD00ol0003o0?l0o`3o0004o`3o0003o`000?l6n@Ko1_T600Co1_T600?o0000
oefRGOmMXUd03_mMXUd00ol0003oFJIIoeVVF@0BoeVVF@[o00002_mHYeP00ol0003oO8=logb3O008
ogb3O003o`000?n`Ck3o/4n`00Oo/4n`00?o0000onHIi_oV6NH02?oV6NH00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003ofbCKom/TfooK9=/2o`0000OogaoO00?o0000oj1OX?nPGj001?nPGj00
0ol0003o?kloocno?`0:ocno?`04o`000?lBkA;o0000o`0000So5NXE00Co0000o`3o0?l0o`3o0?l0
0_l00007o`Ki1P03o`000?mMXUgoGJ9M00koGJ9M00?o0000oeVVFOmIYUT04_mIYUT00ol0003oA;]4
odBkA007odBkA003o`000?mHYeSoF:MH00KoF:MH00?o0000ogb3O?mlPg`02_mlPg`00ol0003o/4n`
ok1?/006ok1?/003o`000?oV6NKoiQWV00SoiQWV00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oK
9=_o0000o`0000WogaoO00?o0000oj1OX?nPGj001?nPGj000ol0003o?kloocno?`0;ocno?`03o`00
0?lEjQGo5NXE00Wo5NXE00?o0000o`3o0?l000002Ol6n@H00ol0003oGJ9MoefRG@0>oefRG@;o0000
4_mIYUT00ol0003oA;]4odBkA009odBkA0;o00001_mHYeP00ol0003oO8=logb3O00:ogb3O003o`00
0?n`Ck3o/4n`00Ko/4n`00?o0000onHIi_oV6NH02?oV6NH00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000omlOgooO7ml02OoO7ml00ol0003oX5nPoj1OX005oj1OX003o`000?lo_coo?klo00[o?klo00?o
0000oaGZ5OlEjQD02_lEjQD2o`0000Wo1_T600?o0000oefRGOmMXUd03_mMXUd00ol0003oA;]4o`00
0002o`0000ooFJII00?o0000odBkA?m4^d@02om4^d@00ol0003oF:MHoeRWF003o`0000goO8=l00?o
0000ok1?/?n`Ck001_n`Ck000ol0003oiQWVonHIiP07onHIiP03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ogaoOomlOg`09omlOg`03o`000?nPGj3oX5nP00GoX5nP00?o0000ocno?olo_cl02Olo_cl2
o`0000_o5NXE0_l0000;o`Ki1P03o`000?mMXUgoGJ9M00coGJ9M00?o0000odBkA?m4^d@00om4^d@3
o`0000coFJII00?o0000odBkA?m4^d@03?m4^d@2o`0000;oK9=/00?o0000ogb3O?mlPg`03?mlPg`0
0ol0003o/4n`ok1?/005ok1?/003o`000?oV6NKoiQWV00OoiQWV00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oO7moogaoO00[ogaoO00?o0000oj1OX?nPGj001_nPGj000ol0003o?kloocno?`07ocno
?`03o`000?ljaC[o000000[o5NXE00Co0000o`Oh1ol7n0Oo00002_l6n@H00ol0003oGJ9MoefRG@0<
oefRG@03o`000?m4^dCoA;]400KoA;]40_l00008oeVVF@;o00003om4^d@00ol0003oK9=/ofbCK002
ofbCK003o`000?mlPgcoO8=l00_oO8=l00?o0000ok1?/?n`Ck001On`Ck000ol0003oiQWVonHIiP07
onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ogaoOomlOg`0:omlOg`03o`000?nPGj3oX5nP
00KoX5nP00?o0000ocno?olo_cl01_lo_cl01Ol0003o>/Djoc[5>_ljaC[o000000So5NXE00?o0000
o`Oh1ol7n0L00_l7n0L00ol0003o1_T6o`Ki1P06o`Ki1PCo00003?mMXUd00ol0003oA;]4odBkA008
odBkA0?o00000_mIYUT3o`000003oc_4>ol0003oA;]400goA;]400?o0000ofbCK?m/Tf`01?m/Tf`0
0ol0003oO8=logb3O00:ogb3O003o`000?n`Ck3o/4n`00Go/4n`00?o0000onHIi_oV6NH01_oV6NH0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000omlOgooO7ml02ooO7ml00ol0003oX5nPoj1OX007oj1O
X003o`000?lo_coo?klo00?o?klo0_l00005oc[5>P03o`000?lEjQGo5NXE00Co5NXE00?o0000o`Oh
1ol7n0L00ol7n0L00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?lQgR7o8MhQ00;o8MhQ0ol00007oefR
G@;o00003_m4^d@2o`0000Go>l@k00?o0000odBkA?m4^d@02_m4^d@00ol0003oK9=/ofbCK005ofbC
K003o`000?mlPgcoO8=l00_oO8=l00?o0000ok1?/?n`Ck001?n`Ck000ol0003oiQWVonHIiP06onHI
iP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ogaoOomlOg`0;omlOg`03o`000?nPGj3oX5nP00Oo
X5nP00?o0000ocno?olo_cl00_lo_cl00ol0003o>/Djoc[5>P06oc[5>P03o`000?lEjQGo5NXE00;o
5NXE00?o0000o`Oh1ol7n0L01Ol7n0L00ol0003o1_T6o`Ki1P02o`Ki1P;o00002?lQgR43o`0000;o
GJ9M0_l000000olZeB[o0000odBkA00=odBkA003o`000?lka3_o>l@k00Go>l@k00?o0000odBkA?m4
^d@02?m4^d@00ol0003oK9=/ofbCK007ofbCK003o`000?mlPgcoO8=l00[oO8=l00?o0000ok1?/?n`
Ck001?n`Ck000ol0003oiQWVonHIiP06onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ogaoO
omlOg`0<omlOg`03o`000?nPGj3oX5nP00SoX5nP00Co0000ocno?olo_coo00002OljaCX01Ol0003o
5NXEoaGZ5OlEjQGo000000So1oP700Go0000o`Ki1_l6n@Ko1_T6o`00000=ob7N8@;o00001?lZeBX0
0ol0003oA;]4odBkA00;odBkA003o`000?lka3_o>l@k00Ko>l@k00?o0000odBkA?m4^d@01om4^d@0
0ol0003oK9=/ofbCK008ofbCK0Co00002?mlPg`00ol0003o/4n`ok1?/004ok1?/003o`000?oV6NKo
iQWV00KoiQWV00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oO7moogaoO00_ogaoO0ol00009oj1O
X003o`000?lo_coo000000_o>/Dj00?o0000oaGZ5Ol000002_l7n0L00ol0003o1_T6o`00000?ob7N
8@03o`000?lZeB[o:]DZ00;o:]DZ00?o0000odBkA?m4^d@02om4^d@00ol0003o>l@koc_4>`06oc_4
>`03o`000?m4^dCoA;]400KoA;]400?o0000ofbCK?m/Tf`02Om/Tf`01?l0003oWV6NoiiQW_nNHIh7
o`0000;oO8=l00?o0000ok1?/?n`Ck000on`Ck000ol0003oiQWVonHIiP05onHIiP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oO7moogaoO00SogaoO0ol00003omHYeP03o`000?nPGj3oX5nP00OoX5nP00?o0000oc[5
>_ljaCX02oljaCX00ol0003o1oP7o`Oh1`0:o`Oh1`03o`000?lQgR7o8MhQ00go8MhQ00?o0000ob[E
:_lZeBX01?lZeBX00ol0003oA;]4odBkA009odBkA003o`000?lka3_o>l@k00So>l@k00?o0000odBk
A?m4^d@00om4^d@2o`0000coK9=/00?o0000oiiQW_nNHIh02?nNHIh<o`0000?oiQWV0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000omlOgooO7ml01_oO7ml3o`0000OoeRWF00?o0000oj1OX?nPGj001_nPGj000ol0003o
>/Djoc[5>P0;oc[5>P03o`000?l7n0Oo1oP700Wo1oP70_l0000>ob7N8@03o`000?lZeB[o:]DZ00Go
:]DZ00?o0000odBkA?m4^d@02Om4^d@00ol0003o>l@koc_4>`09oc_4>`03o`000?m4^dCo000000;o
00000_mRWF800ol0003oK9=/ofbCK008ofbCK003o`000?nNHIkoWV6N00coWV6N00?o0000on<LhooS
7><01_oS7><3o`0000?on`Ck0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ogaoOomlOg`03omlOg`?o00002ooF:MH00ol0003oX5nP
oj1OX004oj1OX003o`000?ljaC[o>/Dj00_o>/Dj0ol00007o`Oh1`?o000000?o6^DJo`000?lQgR40
3OlQgR400ol0003o:]DZob[E:P06ob[E:P03o`000?m4^dCoA;]400SoA;]400?o0000oc_4>olka3/0
2_lka3/00ol0003oHYeRof:MHP04of:MHP03o`000?m/TfcoK9=/00OoK9=/00?o0000oiiQW_nNHIh0
2onNHIh00ol0003ohacSon<Lh`08on<Lh`03o`000?ok1?_on`Ck00Con`Ck0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004omlOgol0
003o0000o`0000ooeRWF00?o0000oj1OX?nPGj000onPGj0>o`0000?o;M8]0_l00002o`Oh1`?o0000
1OlJiAX00ol0003o8MhQob7N8@0:ob7N8@03o`000?lZeB[o:]DZ00Oo:]DZ00?o0000odBkA?m4^d@0
2?m4^d@00ol0003o>l@koc_4>`0:oc_4>`03o`000?mRWF;oHYeR00GoHYeR00?o0000ofbCK?m/Tf`0
1_m/Tf`00ol0003oWV6NoiiQWP0;oiiQWP03o`000?oS7>?ohacS00SohacS00?o0000oo/4nook1?/0
1ook1?/2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;oeRWF00?o0000oj1OX?nPGj000_nPGj000ol0003oM8]dogB;
M00:ogB;M003o`000?l]dRgo;M8]00?o;M8]0_l00009oa[U6P03o`000?lQgR7o8MhQ00Wo8MhQ00?o
0000ob[E:_lZeBX02?lZeBX2o`0000SoA;]400?o0000oc_4>olka3/02Olka3/00ol0003oHYeRof:M
HP07of:MHP03o`000?m/TfcoK9=/00CoK9=/00?o0000oiiQW_nNHIh02onNHIh00ol0003ohacSon<L
h`09on<Lh`03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003oeRWFomHYeP0?omHYeP?o000000?oX5nP
o`000?mdRg@02omdRg@00ol0003o;M8]obgB;@04obgB;@03o`000?lJiA[o6^DJ00Wo6^DJ00?o0000
ob7N8OlQgR401olQgR400ol0003o:]DZob[E:P09ob[E:P04o`000?lXebSo0000o`0000KoA;]400?o
0000oc_4>olka3/02Olka3/00ol0003oHYeRof:MHP08of:MHP03o`000?m/TfcoK9=/00?oK9=/00?o
0000oiiQW_nNHIh02onNHIh00ol0003ohacSon<Lh`09on<Lh`03o`000?ok1?_on`Ck00Won`Ck00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003oeRWFomHYeP0<omHYeP;o00000ooB;M82o`0000coM8]d00?o0000obgB;Ol]dRd01?l]dRd0
0ol0003o6^DJoa[U6P0:oa[U6PWo00002olZeBX00ol0003o:=LXobSG:002obSG:0?o00000_m4^d@0
0ol0003o>l@koc_4>`0:oc_4>`03o`000?mRWF;oHYeR00WoHYeR00?o0000ofbCK?m/Tf`00_m/Tf`0
0ol0003oWV6NoiiQWP0:oiiQWP03o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/02_ok1?/0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oF:MH2o`0000GodRgB00?o0000oiaSW?l000002_mdRg@00ol0003o;M8]obgB;@06obgB
;@03o`000?lJiA[o6^DJ00Wo6^DJ00?o0000oaKY5_lFjAH01OlFjAH00ol0003o:]DZob[E:P09ob[E
:P03o`000?lXebSo:=LX00Go:=LX0ol00009oc_4>`?o00003OmRWF801Ol0003oK9=/ofbCK?m/Tfco
000000coWV6N00?o0000on<LhooS7><02OoS7><00ol0003on`Ckoo/4n`0:oo/4n`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omHY
e_oF:MH01OoF:MH2o`0000OodRgB00Co0000oiaSW?nLHico00002OmdRg@00ol0003o;M8]obgB;@06
obgB;@03o`000?lJiA[o6^DJ00So6^DJ00?o0000oaKY5_lFjAH01olFjAH00ol0003o:]DZob[E:P07
ob[E:P03o`000?lXebSo:=LX00So:=LX0ol00002oc_4>`Go00000_liaST00ol0003oHYeRof:MHP0<
of:MHP03o`000?m/Tfco000000coWV6N00?o0000on<LhooS7><02_oS7><00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000omHYe_oF:MH00_oF:MH2o`0000SodRgB00?o0000oiaSW?nLHi`00_nLHi`5o`00
00CoM8]d00?o0000obgB;Ol]dRd01_l]dRd00ol0003o6^DJoa[U6P08oa[U6P03o`000?lFjAKo5^TF
00Oo5^TF00?o0000ob[E:_lZeBX01olZeBX00ol0003o:=LXobSG:008obSG:003o`000?lKi1_o6n@K
00;o00002?liaST00ol0003oHYeRof:MHP0<of:MHPCo00002_nNHIh00ol0003ohacSon<Lh`0:on<L
h`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003oeRWFo`000?l0000:om8]dP03o`000?nLHicoW6>L
00;oW6>L00?o0000odVfBOm9]TT00_m9]TT4o`0000Wo;M8]00?o0000oa[U6_lJiAX02?lJiAX00ol0
003o5^TFoaKY5P08oaKY5P03o`000?lZeB[o:]DZ00Go:]DZ00?o0000obSG:?lXebP02?lXebP01Ol0
003o6n@Koa_T6olKi1_o000000[o>LHi0ol0000;of:MHP04o`000?o?<<oocc3?oll`c`Co00001OnN
HIh00ol0003ohacSon<Lh`0;on<Lh`03o`000?ok1?_on`Ck00_on`Ck00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003odRgBom8]dP0:
om8]dP03o`000?nLHicoW6>L00?oW6>L00?o0000odVfBOm9]TT01?m9]TT00ol0003o;M8]obgB;@07
obgB;@03o`000?lJiA[o6^DJ00Ko6^DJ0_l0000;oaKY5P03o`000?lZeB[o:]DZ00Go:]DZ00?o0000
obSG:?lXebP02?lXebP00ol0003o6n@Koa_T6`02oa_T6`03o`000?liaSWo>LHi00Oo>LHi00?o0000
oh]dRon;M8/01?l00006of:MHP03o`000?o?<<oocc3?00Kocc3?0ol00002oiiQWP03o`000?oS7>?o
hacS00_ohacS00?o0000oo/4nook1?/02ook1?/00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oB;M;odRgB00WodRgB00?o0000oiaS
W?nLHi`01?nLHi`00ol0003oBKI9odVfB@05odVfB@03o`000?l]dRgo;M8]00Oo;M8]00?o0000oa[U
6_lJiAX00_lJiAX3o`000003obOH9ol0003o5^TF00[o5^TF00?o0000ob[E:_lZeBX01OlZeBX00ol0
003o:=LXobSG:007obSG:003o`000?lKi1_o6n@K00?o6n@K00?o0000ocW6>OliaST01oliaST00ol0
003oRgB;oh]dR`04oh]dR`?o00000_mRWF800ol0003occ3?oll`c`0:oll`c`;o00003_oS7><00ol0
003on`Ckoo/4n`0;oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000om8]d_oB;M802OoB;M800ol0003oW6>LoiaSW004oiaSW003
o`000?m9]TWoBKI900KoBKI90_l00007obgB;@03o`000?lJiA[o000000;o00001OlWf2L00ol0003o
5^TFoaKY5P08oaKY5P?o00001?lZeBX00ol0003o:=LXobSG:008obSG:003o`000?lKi1_o6n@K00Co
6n@K00?o0000ocW6>OliaST01_liaST00ol0003oRgB;oh]dR`07oh]dR`;o00003_o?<<l00ol0003o
hacSon<Lh`0;on<Lh`03o`000?ok1?_on`Ck00con`Ck00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003odRgBom8]dP08om8]dP03o`00
0?nLHicoW6>L00GoW6>L00?o0000odVfBOm9]TT01?m9]TT00ol0003oDJiAoe6^D@03o`0000Co;M8]
0_l00008obOH9`03o`000?lFjAKo5^TF00Oo5^TF00Co0000odVfBOm9]TWoBKI90ol000000olZeB[o
0000obSG:009obSG:003o`000?lKi1_o6n@K00Co6n@K00?o0000ocW6>OliaST01OliaST00ol0003o
RgB;oh]dR`09oh]dR`03o`000?o?<<oocc3?00gocc3?00?o0000on<LhooS7><02_oS7><00ol0003o
n`Ckoo/4n`0<oo/4n`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000om8]d_oB;M801ooB;M800ol0003oW6>LoiaSW006oiaSW003o`00
0?m9]TWoBKI900?oBKI900?o0000oe6^DOmA[U401?mA[U42o`000003obgB;Ol0003o9mPW00[o9mPW
00?o0000oaKY5_lFjAH01OlFjAH00ol0003oBKI9odVfB@05odVfB@03o`000?lXebSo:=LX00Oo:=LX
0ol00007oa_T6`03o`000?liaSWo>LHi00Co>LHi00?o0000oh]dRon;M8/02On;M8/00ol0003occ3?
oll`c`0=oll`c`03o`000?oS7>?ohacS00[ohacS00?o0000oo/4nook1?/02ook1?/00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oB
;M;odRgB00GodRgB0ol00009oiaSW005o`000?m9]TWoBKI9odVfBOl000002OmA[U400ol0003o9mPW
obOH9`0;obOH9`03o`000?lFjAKo5^TF00?o5^TF00?o0000odVfBOm9]TT01_m9]TT00ol0003o:=LX
obSG:006obSG:005o`000?lhacSo><LhocS7>?l000001olKi1/00ol0003o>LHiocW6>@03ocW6>@03
o`000?n;M8_oRgB;00WoRgB;00?o0000oll`coo?<<l03_o?<<l00ol0003ohacSon<Lh`09on<Lh`03
o`000?ok1?_on`Ck00[on`Ck00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003odRgBo`000004o`0000;ohacS00?o0000oiaSW?nLHi`0
1onLHi`01?l0003oBKI9odVfBOl00009oe6^D@;o00003OlWf2L00ol0003o5^TFoaKY5P02oaKY5P03
o`000?m9]TWoBKI900SoBKI900?o0000obSG:?lXebP00olXebP2o`0000Go><Lh00?o0000oa_T6olK
i1/01?lKi1/00ol0003o>LHiocW6>@03ocW6>@03o`000?n;M8_oRgB;00WoRgB;00?o0000oll`coo?
<<l03_o?<<l00ol0003ohacSon<Lh`09on<Lh`03o`000?ok1?_on`Ck00Won`Ck00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SohacS
00?o0000oiaSW?nLHi`01_nLHi`00ol0003oBKI9o`000009oe6^D@04o`000?m?/4ooCk1?o`0000go
9mPW00Co0000oaKY5_lFjAKo00003?m9]TT01Ol0003o:=LXobSG:?lXebSo000000So><Lh0_l00005
oa_T6`03o`000?liaSWo>LHi00;o>LHi00?o0000oh]dRon;M8/02On;M8/00ol0003occ3?oll`c`0>
oll`c`03o`000?oS7>?ohacS00WohacS00?o0000oo/4nook1?/02Ook1?/00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oS7>?ohacS
00OohacS00?o0000oiaSW?nLHi`01onLHi`00ol0003oDJiAoe6^D@07oe6^D@03o`000?m?/4ooCk1?
00;oCk1?00?o0000obOH9olWf2L02_lWf2L00ol0003o5^TFo`00000>odVfB@03o`000?lXebSo0000
00_o><Lh00?o0000oa_T6olKi1/00_lKi1/01Ol0003o>LHiocW6>OliaSWo000000coRgB;00?o0000
oll`coo?<<l03_o?<<l3o`0000WohacS00?o0000oo/4nook1?/02?ok1?/00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oS7>?ohacS
00WohacS00?o0000oiaSW?nLHi`01_nLHi`00ol0003oDJiAoe6^D@06oe6^D@03o`000?m?/4ooCk1?
00?oCk1?00?o0000obOH9olWf2L02olWf2L00ol0003oBKI9odVfB@0>odVfB@03o`000?lhacSo><Lh
00_o><Lh0_l00003oa_T6`04o`000?liaSWo>LHio`0000[oRgB;0ol0000>oll`c`;o00000ook1?/2
o`0000OohacS00?o0000oo/4nook1?/01ook1?/00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oS7>?ohacS00[ohacS00?o0000oiaS
W?nLHi`01?nLHi`00ol0003oDJiAoe6^D@06oe6^D@03o`000?m?/4ooCk1?00GoCk1?00?o0000obOH
9olWf2L01olWf2L3o`00017oBKI900?o0000ocS7>?lhacP03OlhacP01Ol0003o6n@Koa_T6ol0003o
>LHi00Co00000on;M8/5o`0000;of2OH00?o0000oll`coo?<<l02_o?<<l2o`0000Oon`Ck0_l00004
on<Lh`03o`000?ok1?_on`Ck00Son`Ck00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ohacSon<Lh`0;on<Lh`03o`000?nLHicoW6>L
00CoW6>L00?o0000oe6^DOmA[U401OmA[U400ol0003oCk1?odn`C`06odn`C`03o`000?lWf2Oo9mPW
00Co9mPW0ol00002oc;=<P03o`000?m9]TWoBKI900ooBKI90_l0000?ocS7>004o`000?lKi1_o0000
o`0000CoMHYe0ol00008omPWf003o`000?o?<<oocc3?00Oocc3?0_l0000;oo/4n`;o00000_oS7><0
0ol0003on`Ckoo/4n`07oo/4n`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000on<LhooS7><03?oS7><6o`0000OoDJiA00?o0000odn`
Com?/4l02?m?/4l00ol0003o9mPWobOH9`03o`0000Ko</db00?o0000odVfBOm9]TT03Om9]TT01?l0
003oBKI9odVfBOl0000?ocS7>003o`000?meRWGoMHYe00GoMHYe00?o0000omPWf?oH9mP02?oH9mP0
0ol0003occ3?oll`c`05oll`c`03o`000?ok1?_on`Ck00gon`Ck0ol00008oo/4n`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oS7><00ol0003oY5^TojAKY004ojAK
Y003o`000?mA[U7oDJiA00?oDJiA00?o0000odn`Com?/4l02_m?/4l2o`0000[o</db00?o0000odVf
BOm9]TT02om9]TT00ol0003oBKI9odVfB@02odVfB@03o`000?lhacSo><Lh00_o><Lh0_l00007ogF:
M@03o`000?oH9mSof2OH00Wof2OH00?o0000oll`coo?<<l00_o?<<l2o`0001;on`Ck00?o0000oo/4
nook1?/00ook1?/3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000on<LhooS7><02ooS7><00ol0003oY5^TojAKY006ojAKY005o`000?mA[U7oDJiAoe6^
DOl000003Om?/4l00ol0003o</dboc;=<P0:oc;=<P03o`000?m9]TWoBKI900WoBKI900?o0000odVf
BOm9]TT01?m9]TT00ol0003o><LhocS7>008ocS7>0;o000000?o;=</o`000?meRWD01omeRWD00ol0
003of2OHomPWf009omPWf004o`000?o?<<oo0000o`0001Con`Ck00?o0000oo/4nook1?/00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oS7>?ohacS
00WohacS00?o0000ojAKY?nTFj@02?nTFj@00ol0003oDJiAo`00000=odn`C`03o`000?lbcC;o</db
00_o</db00?o0000odVfBOm9]TT02?m9]TT00ol0003oBKI9odVfB@06odVfB@03o`000?lhacSo><Lh
00Go><Lh0_l00003obcC;003o`000?meRWGoMHYe00KoMHYe00?o0000omPWf?oH9mP02_oH9mP00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ohacSon<Lh`07on<Lh`03o`000?nTFjCoY5^T00[oY5^T00?o0000odn`Com?
/4l03?m?/4l00ol0003o</dboc;=<P0<oc;=<P03o`000?m9]TWoBKI900KoBKI900?o0000odVfBOm9
]TT02?m9]TT00ol0003o><LhocS7>002ocS7>0;o00001_l/db`00ol0003oMHYeogF:M@05ogF:M@03
o`000?oH9mSof2OH00[of2OH00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oS7>?ohacS00GohacS
00?o0000ojAKY?nTFj@03?nTFj@2o`0000coCk1?00?o0000oc;=<_lbcC803OlbcC800ol0003oBKI9
odVfB@04odVfB@03o`000?m9]TWoBKI900[oBKI900Co0000ocS7>?l0003o00002?l/db`00ol0003o
MHYeogF:M@06ogF:M@03o`000?oH9mSof2OH00Wof2OH00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oS7><00ol0003oY5^TojAKY00=ojAKY003o`000?mLXeco000000;o00002?m?/4l00ol0003o</db
oc;=<P0?oc;=<PKo00003_m9]TT00ol0003o;=</obcC;008obcC;003o`000?meRWGoMHYe00KoMHYe
00?o0000omPWf?oH9mP02OoH9mP00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onDJiOoU6^GoiA[U
0_l0000?ojAKY003o`000?mLXecoG:=L00?oG:=L0ol00005odn`C`;o00004?lbcC801_l0003o8=lP
ob3O8?l0003o3O8=o`0000koBKI900?o0000obcC;?l/db`02Ol/db`00ol0003oMHYeogF:M@05ogF:
M@03o`000?oH9mSof2OH00Wof2OH00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onDJiOoU6^D00ooU6^D00ol0003o
Y5^TojAKY00=ojAKY003o`000?mLXecoG:=L00KoG:=L0ol000001?m?/4oo0000oc3?<?l`cc03o`00
00co</db00Go0000ob3O8?lPgb3o8=lPo`000002o`gb3@03o`000?m9]TWoBKI900_oBKI900?o0000
obcC;?l/db`02Ol/db`00ol0003oMHYeogF:M@06ogF:M@03o`000?oH9mSof2OH00Sof2OH0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003oiA[UonDJi@04onDJi@oo00003?mLXe`00ol0003o<<l`oc3?<004oc3?
<0?o00002?lbcC800ol0003o8=lPob3O8002ob3O8005o`000?l=lPgo3O8=o`gb3Ol000003?m9]TT0
0ol0003o;=</obcC;009obcC;003o`000?meRWGoMHYe00GoMHYe3?l00002onhAkP;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oiA[UonDJi@05onDJi@03o`000?nLHicoW6>L00_oW6>L00?o0000oebS
G?mLXe`02_mLXe`00ol0003o<<l`oc3?<007oc3?<0;o00001OlbcC800ol0003o8=lPob3O8003ob3O
8003o`000?l=lPgo3O8=00;o3O8=00?o0000odVfBOm9]TT02Om9]TT00ol0003o;=</obcC;00:obcC
;003o`000?meRWGoMHYe00?oMHYe00?o0000oki1__nn@Kh02Onn@Kh00ol0003okQ7^onhAkP02onhA
kP;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiA[UonDJi@06onDJi@03o`000?nLHicoW6>L00[o
W6>L00?o0000oebSG?mLXe`02omLXe`00ol0003o<<l`oc3?<009oc3?<0?o000000?o</dbo`000?lP
gb001OlPgb000ol0003o3O8=o`gb3@03o`gb3@03o`000?m9]TWoBKI900SoBKI93_l00003ogF:M@;o
00002onn@Kh00ol0003okQ7^onhAkP05onhAkP03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onDJiOoU6^D01OoU6^D00ol0003o[e2_o`00000;oiaSW003o`000?mLXecoG:=L00[oG:=L
0_l0000>oc3?<003o`000?lPgb3o8=lP00Go8=lP00?o0000o`gb3Ol=lPd00ol=lPd00ol0003oBKI9
odVfB@08odVfB@03o`000?mbSG;oLXeb00_oLXeb00?o0000ogF:MOl000003Onn@Kh00ol0003okQ7^
onhAkP06onhAkP;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oU6^GoiA[U00KoiA[U00Co
0000ojm@[on_D:oo00002_nLHi`00ol0003oG:=LoebSG009oebSG003o`000?ln`Cko000000ko<<l`
00?o0000ob3O8?lPgb001OlPgb000ol0003o3O8=o`gb3@04o`gb3@03o`000?m9]TWoBKI900KoBKI9
00?o0000og:=L_mbSG803OmbSG800ol0003o_T6noki1_P0<oki1_P03o`000?o^4NkokQ7^00SokQ7^
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oU6^GoiA[U00GoiA[U00?o0000ojm@[on_D:l00_n_
D:l00ol0003oW6>LoiaSW006oiaSW003o`000?mLXecoG:=L00SoG:=L0_l00003ock1?P03o`000?l`
cc3o<<l`00_o<<l`00?o0000ob3O8?lPgb001OlPgb000ol0003o3O8=o`gb3@05o`gb3@03o`000?m9
]TWoBKI900GoBKI900?o0000og:=L_mbSG803OmbSG800ol0003o_T6noki1_P0;oki1_P03o`000?o^
4NkokQ7^00WokQ7^00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oU6^GoiA[U00KoiA[U00?o0000
ojm@[on_D:l00on_D:l00ol0003oW6>LoiaSW005oiaSW003o`000?mLXecoG:=L00OoG:=L00?o0000
ock1?_ln`Ch00oln`Ch00ol0003o<<l`oc3?<00:oc3?<003o`000?lPgb3o8=lP00Ko8=lP00?o0000
o`gb3Ol=lPd01_l=lPd00ol0003oBKI9odVfB@04odVfB@03o`000?mbSG;oLXeb00goLXeb3ol0000;
onhAkP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oU6^GoiA[U00KoiA[U00?o0000ojm@[on_D:l01On_D:l00ol0
003oW6>LoiaSW004oiaSW003o`000?mLXecoG:=L00GoG:=L0_l00006ock1?P03o`000?l`cc3o<<l`
00Wo<<l`0_l00008ob3O8003o`000?l=lPgo3O8=00Ko3O8=1Ol000000om9]TWo0000og:=LP0?og:=
LP03o`000?no@;oo_d2o00_o_d2o00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?oU6^GoiA[U00KoiA[U00?o0000ojm@[on_D:l01_n_D:l00ol0003o
W6>LoiaSW004o`0000KoG:=L00?o0000ock1?_ln`Ch01oln`Ch00ol0003o<<l`oc3?<005oc3?<0?o
000000?o6^DJo`000?lPgb001olPgb000ol0003o3O8=o`gb3@05o`gb3@03o`000?m@[e3oD:m@00?o
D:m@0_l0000?og:=LP;o00003Ono@;l00ol0003okQ7^onhAkP08onhAkP03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WoiA[U00?o0000ojm@[on_D:l01on_D:l2o`0000CoTVfB00Co0000oebSG?mLXeco
G:=L0_l0000:ock1?P03o`000?l`cc3o<<l`00;o<<l`0ol00005oa[U6P03o`000?lPgb3o8=lP00Go
8=lP00?o0000o`gb3Ol=lPd01?l=lPd00ol0003oD:m@oe2_D006oe2_D003o`000?mbSG;oLXeb00[o
LXeb0_l00002oi]TV`03o`000?no@;oo_d2o00[o_d2o00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onDJiOoU6^D01_oU6^D00ol0003o[e2_ojm@[`08ojm@[`03o`00
0?nBKI;oTVfB00CoTVfB00?o0000oebSG?l000003?ln`Ch00ol0003o<<l`o`000002o`0000Wo6^DJ
00?o0000ob3O8?lPgb001?lPgb000ol0003o3O8=o`gb3@03o`gb3@03o`000?m@[e3oD:m@00SoD:m@
1_l00004og:=LP;o00001OnKI9/00ol0003o_d2ookm0_`09okm0_`03o`000?o^4NkokQ7^00SokQ7^
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?oU6^GoiA[U00GoiA[U00?o0000ojm@[on_D:l01on_
D:l00ol0003oTVfBoi9]TP06oi9]TP03o`000?ln`Cko?/4n00co?/4n00?o0000oa[U6_lJiAX02_lJ
iAX00ol0003o8=lPob3O8004ob3O8004o`000?l=lPgo3O8=o`gb3@;o00002om@[e000ol0003oNhAk
og^4N`03og^4N`Co00002?nKI9/00ol0003o_d2ookm0_`08okm0_`03o`000?o^4NkokQ7^00OokQ7^
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onDJiOoU6^D00ooU6^D00ol0003o[e2_ojm@[`07ojm@[`03o`000?nB
KI;oTVfB00OoTVfB00?o0000ock1?_ln`Ch03?ln`Ch00ol0003o6^DJoa[U6P0;oa[U6P03o`000?lP
gb3o8=lP00?o8=lP00Co0000o`gb3Ol=lPgo00003Om@[e000ol0003oNhAkog^4N`06og^4N`03o`00
0?nKI9_oVfBK00OoVfBK00?o0000okm0_ono@;l01ono@;l00ol0003okQ7^onhAkP06onhAkP04o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oU6^GoiA[U00;oiA[U00?o0000ojm@[on_D:l0
1_n_D:l00ol0003oTVfBoi9]TP09oi9]TP03o`000?ln`Cko?/4n00Wo?/4n0_l0000>oa[U6P?o0000
0olPgb000ol0003o3O8=o`00000=oe2_D003o`000?mkQ7_oNhAk00OoNhAk00?o0000oi]TVonKI9/0
2?nKI9/:o`0000KokQ7^0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo[e2_00?o
0000oi9]T_nBKI802_nBKI800ol0003o?/4nock1?P06ock1?P;o000000?o><Lho`000?lJiAX02olJ
iAX2o`0000?oAkQ71Ol0000>oe2_D003o`000?mkQ7_oNhAk00OoNhAk00?o0000oi]TVonKI9/02?nK
I9/00ol0003od2o@om0_d006om0_d003o`000?o^4NkokQ7^00?okQ7^00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ofBKIomTVf@03omTVf@Co00000_n_D:l00ol0003oTVfBoi9]TP0;
oi9]TP03o`000?ln`Cko?/4n00?o?/4n0ol00004ocS7>003o`000?lJiA[o6^DJ00Oo6^DJ0_l00008
odNhA`03o`000?m@[e3oD:m@00goD:m@00?o0000og^4NomkQ7/02?mkQ7/00ol0003oVfBKoi]TV`07
oi]TV`03o`000?o@;m3od2o@00Ood2o@0ol000000oo^4Nko0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oI9]WofBKI00OofBKI0_l0000?oi9]TP03o`000?ln`Cko?/4n00;o00002?lhacP00ol0
003o6^DJoa[U6P05oa[U6P03o`000?m7^4OoAkQ700SoAkQ700?o0000oe2_D?m@[e003Om@[e000ol0
003oNhAkog^4N`08og^4N`03o`000?nKI9_oVfBK00KoVfBK00?o0000om0_d?o@;m002?o@;m001?l0
003oka3_onl@kol0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ofBKIomTVf@09omTV
f@03o`000?nBKI;oTVfB00koTVfB0_l0000;ocS7>003o`000?lJiA[o6^DJ00;o6^DJ0_l0000;odNh
A`03o`000?m@[e3oD:m@00goD:m@00?o0000og^4NomkQ7/02?mkQ7/00ol0003oVfBKoi]TV`06oi]T
V`03o`000?o@;m3od2o@00Ood2o@00Go0000onl@koo_4>ooka3_o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ofBKIomTVf@0:omTVf@03o`000?nBKI;oTVfB00goTVfB0_l0000<ocS7>004o`000?lJiA[o0000
o`0000goAkQ700?o0000oe2_D?m@[e003?m@[e000ol0003oNhAkog^4N`09og^4N`03o`000?nKI9_o
VfBK00KoVfBK00?o0000om0_d?o@;m001_o@;m000ol0003oka3_onl@k`03onl@k`03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ofBKIomTVf@0:omTVf@03o`000?nBKI;oTVfB00coTVfB00Co0000oe6^
DOmA[U7o00003?lhacP00ol0003oAkQ7odNhA`0>odNhA`03o`000?m@[e3oD:m@00SoD:m@1?l0000;
og^4N`03o`000?nKI9_oVfBK00KoVfBK00?o0000om0_d?o@;m001Oo@;m000ol0003oka3_onl@k`04
onl@k`03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ofBKIomTVf@0;omTVf@03o`000?nBKI;oTVfB
00_oTVfB00?o0000oe6^DOmA[U400_mA[U400ol0003o><LhocS7>009ocS7>003o`000?m7^4OoAkQ7
00koAkQ700Co0000oe2_D?m@[e3oD:m@1ol00003oefRG@03o`000?mkQ7_oNhAk00WoNhAk00?o0000
oi]TVonKI9/01_nKI9/00ol0003od2o@om0_d004om0_d003o`000?o_4>ooka3_00Koka3_00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oI9]WofBKI00cofBKI00?o0000oi9]T_nBKI802_nBKI800ol0
003oDJiAoe6^D@03oe6^D@03o`000?lhacSo><Lh00So><Lh00?o0000odNhAom7^4L03_m7^4L4o`00
00_oGJ9M00?o0000og^4NomkQ7/02?mkQ7/00ol0003oVfBKoi]TV`05oi]TV`03o`000?o@;m3od2o@
00God2o@00?o0000onl@koo_4>l01_o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000omTVfOoI
9]T03?oI9]T7o`0000GoTVfB00?o0000oe6^DOmA[U401OmA[U400ol0003o><LhocS7>007ocS7>003
o`000?m7^4OoAkQ700koAkQ700?o0000oefRGOmMXUd03OmMXUd00ol0003oNhAkog^4N`08og^4N`03
o`000?nKI9_oVfBK00CoVfBK00?o0000om0_d?o@;m001?o@;m000ol0003oka3_onl@k`07onl@k`03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ofBKIomTVf@0=omTVf@03o`000?n`Ck3o/4n`00Co/4n`
1Ol00009oe6^D@03o`000?lhacSo><Lh00Ko><Lh00?o0000odNhAom7^4L03_m7^4L00ol0003oGJ9M
oefRG@0=oefRG@03o`000?mkQ7_oNhAk00SoNhAk00Co0000oi]TVonKI9_oVfBK1Ol00004om0_d003
o`000?o_4>ooka3_00Woka3_1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=omTVf@03o`000?n`Ck3o/4n`00Wo/4n`
0_l00009oe6^D@03o`000?lhacSo><Lh00Ko><Lh00?o0000odNhAom7^4L03?m7^4L00ol0003oGJ9M
oefRG@0?oefRG@Ko00001?mkQ7/4o`0000GodBkA0_l000000oo@;m3o0000onl@k`0;onl@k`04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?oY5^WojAKYonTFj@?o00002_oI9]T00ol0003o
/4n`ok1?/009ok1?/003o`000?mXUfSo000000;o00001omA[U400ol0003o><LhocS7>005ocS7>003
o`000?m7^4OoAkQ700SoAkQ71Ol0000AoefRG@03o`000?n;M8_oRgB;00?oRgB;1?l0000;om4^d@03
o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000onTFjOoY5^T01OoY5^T2o`0000OofBKI
00?o0000ok1?/?n`Ck002_n`Ck000ol0003oJ9MXofRGJ002ofRGJ0?o00001OmA[U400ol0003o><Lh
ocS7>004ocS7>004o`000?m7^4OoAkQ7odNhA`Oo00001?m3_4<00ol0003oGJ9MoefRG@0>oefRG@03
o`000?n;M8_oRgB;00OoRgB;00?o0000om4^dOoA;]402OoA;]400ol0003oka3_onl@k`09onl@k`03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ojAKYonTFj@08onTFj@;o00001?oI9]T00ol0003o/4n`
ok1?/00;ok1?/003o`000?mXUfSoJ9MX00GoJ9MX0ol00003oe6^D@04o`000?lhacSo><LhocS7>0Ko
00003?m3_4<00ol0003oGJ9MoefRG@0=oefRG@03o`000?n;M8_oRgB;00OoRgB;00?o0000om4^dOoA
;]402_oA;]400ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onTFj@?o000000?ofBKIo`000?n`Ck00
3?n`Ck000ol0003oJ9MXofRGJ008ofRGJ0?o000000CoDJiAo`000?l0003o00000_n3O8<00ol0003o
@ka3od>l@`0=od>l@`03o`000?mMXUgoGJ9M00coGJ9M00?o0000oh]dRon;M8/02?n;M8/00ol0003o
dBkAom4^d@0;om4^d@03o`000?o_4>ooka3_00Koka3_00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
jAKY00?o0000ok1?/?n`Ck003?n`Ck000ol0003oJ9MXofRGJ00;ofRGJ003o`000?n3O8?oPgb300?o
Pgb300?o0000od>l@om3_4<03?m3_4<00ol0003o=lPgo`00000=oefRG@03o`000?n;M8_oRgB;00So
RgB;00?o0000om4^dOoA;]403?oA;]43o`0000Goka3_00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oY5^WojAKY00cojAKY00?o0000ok1?/?n`Ck003?n`Ck000ol0003oJ9MXofRGJ00:ofRGJ003o`00
0?n3O8?oPgb300GoPgb300?o0000od>l@om3_4<02_m3_4<01?l0003o=lPgocO8=olgb3L2o`0000[o
GJ9M00?o0000oh]dRon;M8/02On;M8/00ol0003odBkAom4^d@0<om4^d@03o`000?oa3_7ol@ka00?o
000000?oka3_o`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oY5^WojAKY00_ojAKY00?o0000ok1?/?n`Ck00
3?n`Ck000ol0003oJ9MXofRGJ009ofRGJ003o`000?n3O8?oPgb300KoPgb300?o0000od>l@om3_4<0
2Om3_4<00ol0003o=lPgocO8=`02ocO8=`03o`000?n2OH;o000000;o00001omMXUd00ol0003oRgB;
oh]dR`09oh]dR`03o`000?oA;]7odBkA00_odBkA00?o0000oo4>lOoa3_401?oa3_400ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onTFjOoY5^T02ooY5^T00ol0003o/4n`ok1?/00;ok1?/003o`000?mX
UfSoJ9MX00SoJ9MX00?o0000oh=lPon3O8<01on3O8<00ol0003o@ka3od>l@`08od>l@`03o`000?lg
b3Oo=lPg00?o=lPg00?o0000oh9mP_n2OH800_n2OH82o`0000CoGJ9M00?o0000oh]dRon;M8/02_n;
M8/00ol0003odBkAom4^d@0:om4^d@03o`000?oa3_7ol@ka00Gol@ka00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oY5^WojAKY00[ojAKY0ol0000;ok1?/0Ko00001?mXUfP00ol0003oPgb3oh=lP`08
oh=lP`03o`000?m3_4?o@ka300Oo@ka300?o0000ocO8=olgb3L00olgb3L00ol0003oPWf2oh9mPP05
oh9mPP?o000000?oGJ9Mo`000?n;M8/02on;M8/00ol0003odBkAom4^d@09om4^d@03o`000?oa3_7o
l@ka00Ool@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oY5^WojAKY00WojAKY00?o0000ol`c
c?o<<l`01?l00006ok1?/003o`000?n[E:_oZeB[00CoZeB[1?l0000<oh=lP`03o`000?m3_4?o@ka3
00Go@ka300?o0000ocO8=olgb3L01?lgb3L00ol0003oPWf2oh9mPP08oh9mPP03o`000?n;M8_oRgB;
00_oRgB;00?o0000om4^dOoA;]402?oA;]400ol0003ol@kaoo4>l@08oo4>l@Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oY5^WojAKY00OojAKY00?o0000ol`cc?o<<l`01Oo<<l`3o`0000;o/4n`00?o0000oj]DZon[
E:/02?n[E:/00ol0003oPgb3oh=lP`0:oh=lP`03o`000?m3_4?o@ka300Co@ka300?o0000ocO8=olg
b3L01Olgb3L00ol0003oPWf2oh9mPP08oh9mPP03o`000?n;M8_oRgB;00WoRgB;1?l00008om4^d@03
o`000?oa3_7ol@ka00Wol@ka00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKY
onTFj@05onTFj@03o`000?o<<lcoc3?<00Woc3?<0_l0000<oj]DZ`03o`000?n3O8?oPgb300WoPgb3
00?o0000od>l@om3_4<00om3_4<00ol0003o=lPgocO8=`05ocO8=`03o`000?n2OH;oPWf200[oPWf2
00?o0000oh]dRon;M8/01?n;M8/4o`0000CoaC[500?o0000om4^dOoA;]401?oA;]400ol0003ol@ka
oo4>l@0:oo4>l@03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oY5^WojAKY00?ojAKY00?o0000ol`cc?o<<l`02oo<
<l`00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?n3O8?oPgb300WoPgb300?o0000od>l@om3_4<00_m3
_4<00ol0003o=lPgocO8=`06ocO8=`03o`000?n2OH;oPWf200[oPWf200?o0000oh]dRon;M8/01?l0
0009olDja@Ko00003?oa3_400ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onTFjOoY5^WojAKY0_l0
000=ol`cc003o`000?n[E:_oZeB[00[oZeB[00?o0000oh=lPon3O8<02On3O8<01Ol0003o@ka3od>l
@om3_4?o000000Wo=lPg00?o0000oh9mP_n2OH802on2OH82o`0000goaC[500?o0000ondBkOo]4^d0
0_o]4^d00ol0003ol@kaoo4>l@0:oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojAKYo`00
0002oo4>l@;o00002oo<<l`00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?n3O8?oPgb300WoPgb300?o
0000od>l@ol000002Olgb3L00ol0003oPWf2oh9mPP0<oh9mPP03o`000?o5>/GoaC[500coaC[500?o
0000ondBkOo]4^d00oo]4^d00ol0003ol@kaoo4>l@09oo4>l@03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ol@kaoo4>l@03oo4>l@;o00002_o<<l`00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?n3O8?o
Pgb300SoPgb31Ol00008ocO8=`03o`000?n2OH;oPWf200coPWf200?o0000olDjaOo5>/D02oo5>/D0
0ol0003okA;]ondBk@05ondBk@03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001ooa3_42o`0000Soc3?<00?o0000oj]DZon[E:/02_n[E:/00ol0003oPgb3oh=lP`07oh=l
P`03o`000?mjQG[oNXEj00?oNXEj0ol00005ocO8=`03o`000?n2OH;oPWf200_oPWf200?o0000olDj
aOo5>/D03?o5>/D00ol0003okA;]ondBk@06ondBk@03o`000?oa3_7ol@ka00Ool@ka00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?om0_go000000Wol@ka00?o0000ol`cc?o<<l`01Oo<<l`2o`0000co
ZeB[00?o0000oh=lPon3O8<01On3O8<00ol0003oNXEjogZ5NP07ogZ5NP?o000000?o=lPgo`000?n2
OH803On2OH800ol0003oaC[5olDja@0<olDja@03o`000?o]4^gokA;]00KokA;]00?o0000oo4>lOoa
3_401_oa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003ood2o@03o`000?oa3_7ol@ka00Ool@ka
0_l00004ol`cc003o`000?oG:=OoebSG00;o00002_n[E:/00ol0003oPgb3oh=lP`03oh=lP`;o0000
3OmjQGX2o`0000goPWf20ol0000=olDja@03o`000?o]4^gokA;]00OokA;]00?o0000oo4>lOoa3_40
1Ooa3_400ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo@;mood2o@04ood2o@03o`000?oa3_7ol@ka00Sol@ka0_l0
00000oo<<lco0000omLXe`04omLXe`03o`000?n[E:_oZeB[00OoZeB[00Co0000oh=lPon3O8?oPgb3
0_l00002ojYEZP03o`000?mjQG[oNXEj00coNXEj3Ol00003okQ7^003o`000?o5>/GoaC[500[oaC[5
00?o0000ondBkOo]4^d02?o]4^d01?l0003ol@kaoo4>lOoa3_44o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?om0_d00ol0003ol@ka
oo4>l@09oo4>l@03o`000?oG:=OoebSG00GoebSG0_l00008oj]DZ`03o`000?n3O8?o000000GoZUFZ
00?o0000ogZ5N_mjQGX02omjQGX00ol0003oQgR7ohMhQ`09ohMhQ`03o`000?nhAkSo^4Nh00;o^4Nh
0_l00009olDja@03o`000?o]4^gokA;]00[okA;]0ol00004oo`3o003o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000ood2
o@0:ood2o@03o`000?oa3_7ol@ka00Sol@ka00?o0000omLXeooG:=L01ooG:=L4o`0000?oZeB[0ol0
0007ojYEZP03o`000?mjQG[oNXEj00[oNXEj00?o0000ohMhQon7N8L02On7N8L00ol0003o^4NhokQ7
^004okQ7^0;o00001oo5>/D00ol0003okA;]ondBk@0:ondBk@03o`000?ol0ocoo0?l00Goo0?l00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oa3_7ol@ka00Ool@ka00?o0000omLXeooG:=L02?oG:=L0
1?l0003oeRWFomHYe_oF:MH3o`0000;oaC[500?o0000ojYEZ_nZEJX01_nZEJX00ol0003oNXEjogZ5
NP08ogZ5NP03o`000?n7N8OoQgR700[oQgR700?o0000okQ7^?nhAkP01_nhAkP00ol0003oaC[5olDj
a@04olDja@03o`000?o]4^gokA;]00WokA;]00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000oo4>lOoa3_401Ooa3_400ol0003oebSGomLXe`08omLXe`03o`000?oF:MKo
eRWF00CoeRWF00Go0000olDjaOo5>/GoaC[5o`000008ojYEZP03o`000?mjQG[oNXEj00OoNXEj00?o
0000ohMhQon7N8L02_n7N8L00ol0003o^4NhokQ7^007okQ7^0;o00001?o5>/D00ol0003okA;]ondB
k@08ondBk@03o`000?ol0ocoo0?l00Woo0?l00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_400ooa3_40
0ol0003oebSGomLXe`08omLXe`03o`000?oF:MKoeRWF00CoeRWF00?o0000olDjaOo5>/D00_o5>/D0
0ol0003oZUFZojYEZP07ojYEZP03o`000?mjQG[oNXEj00KoNXEj00?o0000ohMhQon7N8L02_n7N8L0
0ol0003o^4NhokQ7^009okQ7^005o`000?o5>/GoaC[5olDjaOl000002Oo]4^d00ol0003oo0?loo`3
o00;oo`3o003o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oebSG00?o0000omHYe_oF:MH01?oF:MH00ol0003oaC[5olDja@03
olDja@03o`000?nZEJ[oZUFZ00OoZUFZ00?o0000ogZ5N_mjQGX01OmjQGX00ol0003oQgR7ohMhQ`0:
ohMhQ`03o`000?nhAkSo^4Nh00Wo^4Nh1?l00009ondBk@03o`000?ol0ocoo0?l00goo0?l0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oc3??ol`cc
oo<<lol000002_oG:=L00ol0003oeRWFomHYeP05omHYeP03o`000?o5>/GoaC[500?oaC[500?o0000
ojYEZ_nZEJX02?nZEJX00ol0003oNXEjogZ5NP04ogZ5NP03o`000?n7N8OoQgR700WoQgR700?o0000
okQ7^?nhAkP02?nhAkP2o`0000?okA;]00?o0000ondBkOo]4^d01_o]4^d00ol0003oo0?loo`3o00>
oo`3o003o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003oebSGomLXe`06omLXe`03o`000?oF:MKoeRWF
00GoeRWF00?o0000olDjaOo5>/D01?o5>/D00ol0003oZUFZojYEZP09ojYEZP03o`000?mjQG[oNXEj
00;oNXEj00?o0000ohMhQon7N8L02_n7N8L00ol0003o^4NhokQ7^006okQ7^0;o00001_o]4^d8o`00
017oo0?l00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oG:=OoebSG00GoebSG00?o0000omHYe_oF
:MH01OoF:MH00ol0003oaC[5olDja@05olDja@03o`000?nZEJ[oZUFZ00WoZUFZ00Go0000ogZ5N_mj
QG[oNXEjo`00000<ohMhQ`03o`000?nhAkSo^4Nh00Co^4Nh0_l00008ondBk@03o`000?ol0ocoo0?l
00Coo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000omLXeooG
:=L00ooG:=L00ol0003oeRWFomHYeP06omHYeP03o`000?o5>/GoaC[500GoaC[500?o0000ojYEZ_nZ
EJX02_nZEJX00ol0003oNXEjo`000004o`0000WoQgR700?o0000okQ7^?nhAkP00_nhAkP2o`0000[o
kA;]00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo0?loo`3o00<oo`3o0;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?oG:=OoebSG00;oebSG00?o0000omHYe_oF:MH01_oF:MH00ol0003oaC[5olDja@07olDja@;o0000
2onZEJX00ol0003ocS7>olhacP03olhacPOo00000_n7N8L00ol0003o^4NhokQ7^002o`0000_okA;]
00?o0000oo`3o?ol0o`01ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo<<looc3?<02Ooc
3?<01Ol0003oebSGomLXeooG:=Oo000000SoeRWF00?o0000olDjaOo5>/D01oo5>/D00ol0003oi1_T
o`000002o`0000SoZUFZ00?o0000olhac_o><Lh02_o><Lh5o`0000gokA;]00?o0000oo`3o?ol0o`0
2?ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<oo<<l`03o`000?oG:=Oo000000WoeRWF00?o
0000olDjaOo5>/D01_o5>/D00ol0003oi1_Ton@Ki003on@Ki0?o00001?nZEJX00ol0003ocS7>olha
cP0=olhacP03o`000?o]4^gokA;]00gokA;]00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3
o006oo`3o003o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oom0_d2o`0000_ol`cc00?o0000omHYe_oF:MH01ooF:MH00ol0003oaC[5olDja@07
olDja@03o`000?oT6nCoi1_T00Koi1_T0ol000000onZEJ[o0000olhacP0>olhacP03o`000?o]4^go
kA;]00cokA;]00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo<<
l`03o`000?oF:MKoeRWF00;oeRWF1_l00008olDja@03o`000?oT6nCoi1_T00[oi1_T00?o0000olha
c_o><Lh03oo><Lh00ol0003okA;]ondBk@0:ondBk@;o00003Ool0o`00ol0003oo0?loo`3o003oo`3
o003o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo<<l`Go00001_o`3o000ol0003oaC[5olDja@05olDja@03o`000?oT6nCoi1_T00[o
i1_T00?o0000olhac_o><Lh03oo><Lh00ol0003okA;]ondBk@07ondBk@?o000000?oo@;mo`000?ol
0o`03Ool0o`01Ol0003oo0?loo`3o?ol0oco000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo<<l`03o`000?o`3o3ol0o`00Wol0o`00?o0000olDjaOo5
>/D00oo5>/D00ol0003oi1_Ton@Ki00;on@Ki003o`000?o><LkocS7>00oocS7>00?o0000ondBkOo]
4^d01Oo]4^d2o`0000Goo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?lo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?ol`cco`000?l00000
3Oo`3o000ol0003oaC[5olDja@02olDja@03o`000?oT6nCoi1_T00_oi1_T5?l00004ondBk@;o0000
2?om0_d00ol0003oo0?loo`3o00;oo`3o0;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo@;mo`00000>oo0?l004o`000?o5>/GoaC[5o`0000koi1_T
00?o0000oo8=l_ob3O804?ob3O800ol0003okA;]o`000002o`0000[oo@;m00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?om0_goo@;mood2oOl000003_o`3o000ol0003oaC[5o`00000>on@Ki003o`00
0?ob3O;olPgb017olPgb00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3o008oo`3o003o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000ood2oOom0_d00_om0_d00ol0003ol0o`oo0?l00=oo0?l003o`000?oT6nCoi1_T00Woi1_T1Ol0
000Boo8=lP;o00003oom0_d00ol0003oo0?loo`3o006oo`3o003o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d0
0ol0003ol0o`oo0?l00<oo0?l003o`000?oT6nCoi1_T00;oi1_T1ol00004oo`3o003o`000?ob3O;o
lPgb00oolPgb00?o0000oo`3o?l000004?om0_d00ol0003oo0?loo`3o003oo`3o0;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo@;mood2o@06ood2
o@03o`000?o`3o3ol0o`00col0o`1?l0000<oo`3o003o`000?ob3O;olPgb00colPgb0_l00003oo`3
o003o`000?om0_goo@;m00goo@;m00?o0000oo`3o?ol0o`00_ol0o`00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o003?o`3o000ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_o
lPgb00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mood2o@0=ood2o@04o`000?ol0ocoo0?lo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003ol0o`oo0?l00:oo0?l003o`000?ol0ocoo0?l00koo0?l00?o0000oo8=l_ob
3O802Oob3O82o`0000Ooo0?l00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003oo0?l
oo`3o00?oo`3o003o`000?ob3O;olPgb00KolPgb0_l0000:oo`3o003o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_ob3O800ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000oob3O82o`0000koo0?l00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000oo8=l_l000004Ool0o`00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?ol0ocoo0?l00coo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ool0o`00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo0?loo`3o00>oo`3o004o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00<oo`3o0Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?ol0o`3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002oo`3o0?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool02Ol00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Wo003o0_ooo`06o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000So003o00?oool0o`00ool00?l00ol00?l2oooo00So003o0_ooo`05o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002Ol00?l00oooo`3o003oo`00o`03o`00o`03oooo0?l00?oo003o
00Ko003o0_ooo`05o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0009o`00o`;oool01_l00?l<oooo00;o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o003oo`00o`04o`00o`coool0
00?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l0
0?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o
0oooo`04o`00o`;oool02ol00?l00oooo`3o003oo`00o`03o`00o`03oooo0?l00?oo003o00Co003o
0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol0
0?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0<o`00o`03oooo0?l00?oo003o00?o003o
00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o
0_ooo`05o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo0002oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol00?l2oooo0003o`00oooo
o`3oool000go003o00?oool0o`00ool00?l00ol00?l2oooo00?o003o0_ooo`04o`00o`;oool01_l0
0?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0
o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`0=
o`00o`;oool01Ol00?l01?ooo`3o003oo`00ool00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0G
o`00o`;oool03Ol00?l2oooo00Ko003o00?oool0o`00ool00?l00_ooo`04o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00Ko003o00?oool0o`00ool00?l01?l00?l2oooo00Oo003o00Coool0o`00
ooooo`3oool01?l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool0
06So003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`06o`00o`;oool01Ol00?l2oooo
00Oo003o00Coool0o`00ooooo`3oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb
</co003oo`00o`04o`00o`;oool00ol00?l3oooo00So003o0oooo`05o`00o`;oool01?l00?l2oooo
00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03
oooo0?l00?oo003o01Ko003o1Oooo`05o`00o`Koool02_l00?l2oooo00Ko003o0_ooo`02o`00o`;o
ool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o
1Oooo`0Qo`00o`Coool02ol00?l2oooo00Oo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Ooo
ool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(250) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.99 .01 .99 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.99 .01 .99 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.99 .01 .99 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.989 .011 .989 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.944 .056 .944 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.988 .012 .988 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.944 .056 .944 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.942 .058 .942 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.914 .086 .914 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.984 .016 .984 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.89 .11 .89 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.989 .011 .989 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.81 .19 .81 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.817 .183 .817 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.985 .015 .985 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.991 .009 .991 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.714 .286 .714 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.863 .137 .863 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.982 .018 .982 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.985 .015 .985 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.937 .063 .937 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.512 .488 .512 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.838 .162 .838 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.692 .308 .692 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.681 .319 .681 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.749 .251 .749 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.88 .12 .88 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.916 .084 .916 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.99 .01 .99 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.669 .331 .669 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.845 .155 .845 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.536 .464 .536 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.901 .099 .901 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.855 .145 .855 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.989 .011 .989 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.771 .229 .771 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.83 .17 .83 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.645 .355 .645 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.892 .108 .892 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.699 .301 .699 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.992 .008 .992 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.923 .077 .923 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.638 .362 .638 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.345 .655 .345 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.379 .621 .379 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.949 .051 .949 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.955 .045 .955 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.809 .191 .809 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.99 .01 .99 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.655 .345 .655 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.631 .369 .631 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.449 .551 .449 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.468 .532 .468 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.251 .749 .251 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.625 .375 .625 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.699 .301 .699 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.99 .01 .99 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.685 .315 .685 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.579 .421 .579 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.932 .068 .932 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.31 .69 .31 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.851 .149 .851 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.794 .206 .794 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.446 .554 .446 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.233 .767 .233 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.475 .525 .475 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.031 .969 .031 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.071 .929 .071 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.298 .702 .298 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.333 .667 .333 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.37 .63 .37 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.846 .154 .846 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.244 .756 .244 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.273 .727 .273 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.683 .317 .683 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.94 .06 .94 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.989 .011 .989 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.182 .818 .182 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.244 .756 .244 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.429 .571 .429 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.988 .012 .988 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.653 .347 .653 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.307 .693 .307 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.341 .659 .341 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.079 .921 .079 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.422 .578 .422 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.218 .782 .218 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.937 .063 .937 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.204 .796 .204 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.026 .974 .026 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.784 .216 .784 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.129 .871 .129 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.081 .919 .081 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.52 .48 .52 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.884 .116 .884 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.295 .705 .295 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.092 .908 .092 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.42 .58 .42 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.145 .855 .145 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.183 .817 .183 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.897 .103 .897 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.095 .905 .095 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.033 .967 .033 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.017 .983 .017 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.987 .013 .987 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.006 .994 .006 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.187 .813 .187 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.097 .903 .097 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.68 .32 .68 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.27 .73 .27 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.987 .013 .987 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.333 .667 .333 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.171 .829 .171 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.196 .804 .196 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.252 .748 .252 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.117 .883 .117 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.074 .926 .074 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.265 .735 .265 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.492 .508 .492 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.988 .012 .988 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.752 .248 .752 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.244 .756 .244 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.349 .651 .349 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.227 .773 .227 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.938 .062 .938 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.118 .882 .118 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.078 .922 .078 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.272 .728 .272 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.599 .401 .599 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.046 .954 .046 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.989 .011 .989 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.151 .849 .151 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.815 .185 .815 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.949 .051 .949 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.517 .483 .517 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.544 .456 .544 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.205 .795 .205 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.874 .126 .874 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.01 .99 .01 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.125 .875 .125 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.307 .693 .307 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.55 .45 .55 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.009 .991 .009 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.146 .854 .146 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.278 .722 .278 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.364 .636 .364 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.988 .012 .988 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.059 .941 .059 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.988 .012 .988 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.916 .084 .916 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.305 .695 .305 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.252 .748 .252 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.112 .888 .112 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.737 .263 .737 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.215 .785 .215 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.932 .068 .932 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.301 .699 .301 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.33 .67 .33 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.336 .664 .336 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.554 .446 .554 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.74 .26 .74 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.493 .507 .493 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.11 .89 .11 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.107 .893 .107 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.182 .818 .182 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.46 .54 .46 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.78 .22 .78 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.989 .011 .989 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.926 .074 .926 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.224 .776 .224 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.234 .766 .234 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.283 .717 .283 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.795 .205 .795 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.62 .38 .62 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.988 .012 .988 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.471 .529 .471 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.824 .176 .824 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.932 .068 .932 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.989 .011 .989 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.168 .832 .168 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.26 .74 .26 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.918 .082 .918 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.238 .762 .238 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.557 .443 .557 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.607 .393 .607 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.392 .608 .392 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.429 .571 .429 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.852 .148 .852 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.76 .24 .76 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.765 .235 .765 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.826 .174 .826 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.348 .652 .348 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.947 .053 .947 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.752 .248 .752 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.401 .599 .401 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.4 .6 .4 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.667 .333 .667 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.432 .568 .432 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.988 .012 .988 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.938 .062 .938 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.814 .186 .814 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.934 .066 .934 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.357 .643 .357 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.911 .089 .911 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.734 .266 .734 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.629 .371 .629 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.989 .011 .989 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.609 .391 .609 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.493 .507 .493 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.99 .01 .99 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.734 .266 .734 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.984 .016 .984 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.991 .009 .991 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.574 .426 .574 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.986 .014 .986 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.54 .46 .54 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.988 .012 .988 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.649 .351 .649 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.827 .173 .827 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.703 .297 .703 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.89 .11 .89 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.909 .091 .909 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.757 .243 .757 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.633 .367 .633 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.744 .256 .744 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.854 .146 .854 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.906 .094 .906 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.862 .138 .862 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.875 .125 .875 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.985 .015 .985 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.758 .242 .758 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.932 .068 .932 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.987 .013 .987 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.948 .052 .948 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.929 .071 .929 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.767 .233 .767 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.938 .062 .938 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.912 .088 .912 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.835 .165 .835 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.987 .013 .987 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.985 .015 .985 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.922 .078 .922 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.989 .011 .989 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.987 .013 .987 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.988 .012 .988 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.987 .013 .987 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.988 .012 .988 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo0?loo`3o005oo`3o0Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ool0o`3o`000003o`00ool0003oo0?l00koo0?l00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3
o?ol0o`03ool0o`01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?ol0ocoo0?l013oo0?l0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo0?loo`3o00?oo`3o003
o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?ol0ocoo0?l013oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo0?l0_l0000@oo`3o003o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Ool
0o`01?l0003okA;]ondBkOl0000>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?ol
0ocoo0?l00goo0?l00?o0000ondBkOo]4^d00_o]4^d00ol0003oo0?loo`3o00;oo`3o003o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00?okA;]00?o0000
oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ol0ocoo0?l
00[oo0?l00?o0000ondBkOo]4^d01Oo]4^d00ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003okA;]ondBk@06ondBk@03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00Ooo0?l
00?o0000ondBkOo]4^d02?o]4^d00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o_4>oo0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000cokA;]00Co0000oo`3o?ol0ocoo0?l0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003onl@k`03o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003ojQGZonXEjP05onXEjP03o`000?o]
4^gokA;]00_okA;]0ol00003on/Dj`03o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
onl@koo_4>l00oo_4>l00ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003ojQGZonXEjP06
onXEjP03o`000?o]4^gokA;]00[okA;]00?o0000on/Djoo[5>/01?o[5>/00ol0003oo0?loo`3o00:
oo`3o004o`000?oY5^WojAKYonTFj@;o00002_ol0o`2o`000003onPGj?l0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003oka3_onl@k`05onl@k`03o`000?ol0oco
o0?l00Woo0?l00?o0000oo0?l?l000002oom0_d00ol0003ojQGZonXEjP06onXEjP03o`000?o]4^go
kA;]00WokA;]00?o0000on/Djoo[5>/01_o[5>/00ol0003oo0?loo`3o008oo`3o003o`000?oY5^Wo
jAKY00CojAKY0_l00005oo`3o0?o00001?oX5nP00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00Soo0?l0_l00008onl@k`03o`000?ol0ocoo0?l00Ooo0?l0_l00003oo0?
l003o`000?om0_goo@;m00Ooo@;m00?o0000onXEj_oZ5NX01ooZ5NX00ol0003okA;]ondBk@09ondB
k@03o`000?o[5>_ojaC[00OojaC[00?o0000oo`3o?ol0o`01Ool0o`2o`0000WojAKY0_l000000ool
0oco0000o`000007onPGj003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo0?l00?o0000onl@koo_
4>l02?o_4>l00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00?ol0o`00?o0000ood2oOom
0_d01oom0_d00ol0003ojQGZonXEjP08onXEjP03o`000?o]4^gokA;]00OokA;]00?o0000on/Djoo[
5>/02Oo[5>/00ol0003oo0?loo`3o003oo`3o003o`000?oY5^WojAKY00_ojAKY00?o0000onPGj?oX
5nP01ooX5nP00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^o`000005oo`3o0;o00002oo_4>l2o`0000Koo0?l
00?o0000oo0?l?o`3o001Oo`3o000ol0003oo@;mood2o@06ood2o@03o`000?oZ5N[ojQGZ00SojQGZ
00?o0000ondBkOo]4^d01_o]4^d00ol0003ojaC[on/Dj`0;on/Dj`05o`000?ol0ocoo0?loo`3o?l0
00003_oY5^T00ol0003oj1OXonPGj008onPGj003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o^4NkokQ7^onhAk_l0
00000ool0o`00ol0003oka3_onl@k`0:onl@k`04o`000?oR7N;ohQgRo`0000?oo0?l0_l00008oo0?
l003o`000?om0_goo@;m00Koo@;m00?o0000onXEj_oZ5NX02OoZ5NX00ol0003okA;]ondBk@05ondB
k@03o`000?o[5>_ojaC[00cojaC[00?o0000oo`3o?l000003ooY5^T00ol0003oj1OXonPGj008onPG
j003o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^onhAkP03onhAkP03o`000?ol0oco000000_o
ka3_0_l00004on8MhP03o`000?ol0oco000000_ol0o`00?o0000ood2oOom0_d01Oom0_d00ol0003o
jQGZonXEjP09onXEjP03o`000?o]4^gokA;]00CokA;]00?o0000on/Djoo[5>/03_o[5>/00ol0003o
jAKYonTFj@0>onTFj@03o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000onhAk_o^4Nh0
1?o^4Nh00ol0003oka3_onl@k`09onl@k`03o`000?oR7N;ohQgR00GohQgR00?o0000oo0?l?o`3o00
2_o`3o000ol0003oo@;mood2o@05ood2o@03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ondBkOo]4^d0
0oo]4^d00ol0003ojaC[on/Dj`0>on/Dj`03o`000?oY5^WojAKY00gojAKY00?o0000onPGj?oX5nP0
2_oX5nP00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^onhA
kP05onhAkP03o`000?o_4>ooka3_00Ooka3_0_l00008on8MhP03o`000?o`3o3ol0o`00_ol0o`00?o
0000ood2oOom0_d01?om0_d00ol0003ojQGZonXEjP0:onXEjP04o`000?o]4^gokA;]ondBk@?o0000
3oo[5>/00ol0003ojAKYonTFj@0>onTFj@03o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o^4NkokQ7^00OokQ7^00?o0000onl@koo_4>l01?o_4>l2o`0000_ohQgR1?l0
0009oo0?l003o`000?om0_goo@;m00?oo@;m00?o0000onXEj_oZ5NX02ooZ5NX01?l0003okA;]o`00
0?l00003ol/db`;o00003?o[5>/2o`00013ojAKY00?o0000onPGj?oX5nP02ooX5nP00ol0003oo0?l
oo`3o00=oo`3o004o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003okQ7^
onhAkP07onhAkP03o`000?o_4>ooka3_00?oka3_00?o0000on8Mh_oR7N802ooR7N801?l0003o`3o0
ol0o`?o0?l05o`0000Gol0o`00?o0000ood2oOom0_d00_om0_d00ol0003ojQGZonXEjP0<onXEjP03
o`000?o;=<_obcC;00GobcC;0_l00008on/Dj`;o00000_o0?l000ol0003ojAKYonTFj@0=onTFj@03
o`000?oX5nSoj1OX00_oj1OX00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003okQ7^onhAkP09onhAkP03o`000?o_4>ooka3_00;o0000
3OoR7N800ol0003o`3o0ol0o`007ol0o`0Ko00000_om0_d4o`0000gojQGZ00?o0000ol/dboo;=</0
1oo;=</2o`0000GojaC[00?o0000ol0o`?o0?l000oo0?l000ol0003ojAKYonTFj@0<onTFj@03o`00
0?oX5nSoj1OX00coj1OX00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o^4NkokQ7^00WokQ7^00?o
0000onl@kol000003ooR7N800ol0003o`3o0ol0o`00<ol0o`0?o00001?oO8=l3o`0000WojQGZ00?o
0000ol/dboo;=</02_o;=</2o`000003on/Djol0003o000000Oo`3o000?o0000onTFjOoY5^T02ooY
5^T00ol0003oj1OXonPGj00<onPGj003o`000?ol0ocoo0?l00Koo0?l1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000
on8Mh_oR7N803_oR7N800ol0003o`3o0ol0o`00=ol0o`003o`000?oO8=oogb3O00Kogb3O0ol00005
onXEjP03o`000?o;=<_obcC;00gobcC;00?o0000ol0o`?o0?l002?o0?l000ol0003ojAKYonTFj@09
onTFj@03o`000?oX5nSoj1OX00goj1OX00Co0000oo`3o?ol0ocoo0?l1Ol00003ondBk@03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
onhAk_o^4Nh02oo^4Nh2o`0000oohQgR00?o0000ol0o`?o0?l003Oo0?l000ol0003ogb3OomlPg`0:
omlPg`?o000000?ojQGZo`000?o;=</03oo;=</00ol0003o`3o0ol0o`009ol0o`003o`000?oY5^Wo
jAKY00SojAKY00?o0000onPGj?oX5nP03_oX5nP3o`0000SokA;]00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o^4NkokQ7^00SokQ7^0ol000000oo;
=<_o0000on8MhP0>on8MhP03o`000?o0?l3o`3o000go`3o000?o0000omlPgooO8=l03OoO8=l00ol0
003obcC;ol/db`0?ol/db`03o`000?o0?l3o`3o000[o`3o02ol0000;onPGj0Go00003?o]4^d00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003ok1?/o`000?om0_go0000
00SokQ7^0ol00005ol/db`03o`000?oR7N;ohQgR00cohQgR00?o0000ol0o`?o0?l003Oo0?l000ol0
003ogb3OomlPg`0=omlPg`;o00004?o;=</00ol0003o`3o0ol0o`00:ol0o`003o`000?nkA;_o^dBk
00Oo^dBk00?o0000onPGj?oX5nP00_oX5nP7o`0000Co`Ck100?o0000ondBkOo]4^d02_o]4^d00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003ok1?/on`Ck?o/4n`2o`00
00GokQ7^0ol00009ol/db`;o00002ooR7N800ol0003o`3o0ol0o`00=ol0o`003o`000?oO8=oogb3O
00gogb3O00Co0000oke2_Onm@[go00003oo;=</00ol0003o`3o0ol0o`009ol0o`003o`000?nkA;_o
^dBk00Wo^dBk1?l0000;ol4n`@03o`000?o]4^gokA;]00[okA;]00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000on`Ck?o/4n`01?o/4n`00ol0003okQ7^o`000002o`00
00cobcC;00Co0000ojMHYol0003o00002OoR7N800ol0003o`3o0ol0o`00=ol0o`003o`000?oO8=oo
gb3O00gogb3O00Go0000oke2_Onm@[go_D:mo`00000=ol/db`03o`000?o0?l3o`3o000[o`3o000?o
0000ok]4^onkA;/02OnkA;/00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?o]4^gokA;]00[okA;]00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000on`Ck?o/4n`01_o/4n`0
0ol0003obcC;ol/db`0<ol/db`03o`000?nWF:OoYeRW00;oYeRW0_l00007on8MhP03o`000?o0?l3o
`3o000co`3o000?o0000omlPgooO8=l03OoO8=l00ol0003o_D:moke2_@03oke2_@03o`000?o;=<_o
bcC;00[obcC;00?o0000ol0o`?o0?l002_o0?l000ol0003o^dBkok]4^`09ok]4^`03o`000?o1?/7o
`Ck100co`Ck100?o0000ondBkOo]4^d02oo]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003ok1?/on`Ck006on`Ck003o`000?o;=<_obcC;00_obcC;00?o0000ojMH
YonWF:L01OnWF:L00ol0003ohQgRon8MhP03on8MhP03o`000?o0?l3o`3o000go`3o000?o0000omlP
gooO8=l03OoO8=l00ol0003o_D:moke2_@04oke2_@03o`000?o;=<_obcC;00WobcC;00?o0000ol0o
`?o0?l002Oo0?l000ol0003o^dBkok]4^`0:ok]4^`03o`000?o1?/7o`Ck100co`Ck100?o0000ondB
kOo]4^d02oo]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
k1?/on`Ck007on`Ck003o`000?o;=<_obcC;00_obcC;00?o0000ojMHYonWF:L01_nWF:L2o`0000?o
hQgR00?o0000ol0o`?o0?l003Oo0?l000ol0003ogb3OomlPg`0<omlPg`03o`000?nm@[go_D:m00Ko
_D:m00?o0000ol/dboo;=</02?o;=</00ol0003o`3o0ol0o`009ol0o`003o`000?nkA;_o^dBk00[o
^dBk00?o0000ol4n`Oo1?/403?o1?/400ol0003okA;]ondBk@0;ondBk@03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000on`Ck?o/4n`02?o/4n`00ol0003obcC;ol/db`0:ol/db`03o`00
0?nWF:OoYeRW00WoYeRW0_l000000ooR7N;o0000ol0o`00<ol0o`0?o00003_oO8=l00ol0003o_D:m
oke2_@07oke2_@03o`000?o;=<_obcC;00OobcC;00?o0000ol0o`?o0?l002Oo0?l000ol0003o^dBk
ok]4^`0;ok]4^`03o`000?o1?/7o`Ck100co`Ck100?o0000ondBkOo]4^d02_o]4^d00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000on`Ck?o/4n`02_o/4n`00ol0003obcC;ol/d
b`09ol/db`03o`000?nWF:OoYeRW00_oYeRW00?o0000ol0o`?o0?l002_o0?l02o`0000?oVFJI00?o
0000omlPgooO8=l02_oO8=l00ol0003o_D:moke2_@09oke2_@03o`000?o;=<_obcC;00KobcC;00?o
0000ol0o`?o0?l002?o0?l000ol0003o^dBkok]4^`0<ok]4^`03o`000?o1?/7o`Ck100co`Ck100?o
0000ondBkOo]4^d02_o]4^d00ol0003oo@;mood2o@04ood2o@Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000ol/dboo;=</02?o;=</0
0ol0003oYeRWojMHY`0<ojMHY`03o`000?o0?l3o`3o000So`3o00_l00006oiUVV@;o00002_oO8=l0
0ol0003o_D:moke2_@0:oke2_@03o`000?o;=<_obcC;00GobcC;00?o0000ol0o`?o0?l002?o0?l00
0ol0003o^dBkok]4^`0<ok]4^`03o`000?o1?/7o`Ck100co`Ck100?o0000ondBkOo]4^d02oo]4^d0
0ol0003oo@;mo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
on`Ck003o`000?o;=<_obcC;00OobcC;00?o0000ojMHYonWF:L03_nWF:L00ol0003o`3o0ol0o`004
ol0o`0?o00002_nIIYT00ol0003ogb3OomlPg`07omlPg`03o`000?nm@[go_D:m00_o_D:m00?o0000
ol/dboo;=</00oo;=</00ol0003o`3o0ol0o`009ol0o`003o`000?nkA;_o^dBk00co^dBk00?o0000
ol4n`Oo1?/403?o1?/400ol0003okA;]ondBk@0;ondBk@;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003ok1?/on`Ck00<on`Ck003o`000?o;=<_obcC;00OobcC;00?o0000ojMHYonWF:L03onWF:L01?l0
003o`3o0ol0o`?o0?l02o`0000koVFJI0_l00006omlPg`03o`000?nm@[go_D:m00go_D:m00?o0000
ol/dboo;=</00_o;=</00ol0003o`3o0ol0o`008ol0o`003o`000?nkA;_o^dBk00co^dBk0ol0000=
ol4n`@03o`000?o]4^gokA;]00_okA;]00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ook1?/00?o0000ol/dboo;=</01_o;=</00ol0003oYeRWojMHY`0@ojMHY`Co00004_nIIYT00ol0
003ogb3OomlPg`03omlPg`03o`000?nm@[go_D:m00ko_D:m00Go0000ol/dboo;=<_obcC;o`000005
ol0o`0Oo00003?nkA;/01Ol0003oRWF:ohYeR_n:MH[o000000co`Ck100?o0000ondBkOo]4^d02?o]
4^d3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ook1?/00?o0000ol/dboo;=</01_o;=</00ol0003oYeRWojMHY`0=
ojMHY`?o000000CoK9=/o`000?l0003o00004onIIYT2o`0000;ogb3O00?o0000oke2_Onm@[d04?nm
@[d00ol0003obcC;o`000006o`0000OoZUFZ00?o0000ok]4^onkA;/02?nkA;/00ol0003oRWF:ohYe
RP03ohYeRP;o00002?o1?/43o`0000KokA;]1?l00002onTFj@03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003oka3_o`000?o5>/D3o`0000gok1?/00?o0000ol/dboo;=</01?o;=</00ol0003oYeRWojMH
Y`0;ojMHY`?o00000om/Tf`01Ol0003oJiA[o`000?mEZUGo000001CoVFJI00?o0000omlPgol00000
4onm@[d00ol0003oZUFZojYEZP0=ojYEZP03o`000?nkA;_o^dBk00Go^dBk0_l00008ohYeRP03o`00
0?o1?/7o`Ck100Go00000onn@Kh00ol0003okA;]ondBk@03o`0000OojAKY00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?o_4>ooka3_o`0000CoaC[50ol0000:on`Ck003o`000?o;=<_obcC;00?obcC;
00?o0000ojMHYonWF:L02OnWF:L3o`0000GoK9=/00Co0000of^DJom[U6_o00000_mEZUD00ol0003o
VFJIoiUVV@0BoiUVV@03o`000?nm@[go_D:m01;o_D:m00?o0000ojYEZ_nZEJX03_nZEJX00ol0003o
^dBkok]4^`03ok]4^`03o`000?n:MH[oRWF:00WoRWF:0_l00009oki1_P;o00002_oY5^T00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000onl@koo_4>ooka3_o`000007olDja@;o00001oo/4n`5o`0000;o
bcC;00?o0000ojMHYonWF:L01_nWF:L3o`0000SoK9=/00Co0000of^DJom[U6_o00000omEZUD00ol0
003oVFJIoiUVV@0AoiUVV@03o`000?nm@[go_D:m017o_D:m00?o0000ojYEZ_nZEJX04?nZEJX01Ol0
003o^dBkok]4^onkA;_o000000coRWF:00?o0000oki1__nn@Kh02?nn@Kh00ol0003ojAKYonTFj@0:
onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Coka3_00?o0000olDjaOo5>/D01oo5>/D3o`00
0004on`Ck?l0003o0000o`0000Go[e2_0_l00006ojMHY`?o00002_m/Tf`01Ol0003oJiA[of^DJom[
U6_o000000CoEJYE00?o0000oiUVVOnIIYT04?nIIYT00ol0003o_D:moke2_@0Aoke2_@03o`000?nZ
EJ[oZUFZ017oZUFZ00?o0000ok]4^ol000003On:MHX00ol0003o_T6noki1_P08oki1_P03o`000?oY
5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o_4>ooka3_00Coka3_00?o0000
olDjaOo5>/D02_o5>/D00ol0003o[e2_ojm@[`08ojm@[`03o`000?nWF:OoYeRW00?o00003Om/Tf`0
1Ol0003oJiA[of^DJom[U6_o000000GoEJYE00?o0000oiUVVOnIIYT03onIIYT00ol0003o_D:moke2
_@0Aoke2_@03o`000?nZEJ[oZUFZ01;oZUFZ00?o0000ohYeR_n:MHX03?n:MHX00ol0003o_T6noki1
_P08oki1_P03o`000?oY5^WojAKY00_ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000onl@koo_4>l01Oo_4>l0
0ol0003oaC[5olDja@0:olDja@03o`000?n_D:oo[e2_00Wo[e2_0_l0000?ofbCK003o`000?m[U6_o
JiA[00;oJiA[00?o0000oeFZEOmEZUD01?mEZUD00ol0003oVFJIoiUVV@0=oiUVV@?o00004Onm@[d0
0ol0003oZUFZojYEZP0CojYEZP03o`000?n:MH[oRWF:00_oRWF:00?o0000oki1__nn@Kh02Onn@Kh0
0ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008ood2o@;o00002?o_4>l0
0ol0003oaC[5olDja@0:olDja@03o`000?n_D:oo[e2_00Wo[e2_00?o0000ofbCK?m/Tf`03Om/Tf`0
0ol0003oJiA[of^DJ`03of^DJ`03o`000?mEZUGoEJYE00GoEJYE00?o0000oiUVVOnIIYT02_nIIYT2
o`0000?oS7><00?o0000oke2_Onm@[d03_nm@[d00ol0003oZUFZojYEZP0CojYEZP03o`000?n:MH[o
RWF:00_oRWF:00?o0000oki1__nn@Kh02Onn@Kh00ol0003ojAKYonTFj@0;onTFj@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo@;m00?o0000onl@koo_4>l01oo_4>l2o`0000_oaC[500?o0000ojm@
[on_D:l02on_D:l00ol0003oK9=/ofbCK00<ofbCK003o`000?m[U6_oJiA[00?oJiA[00?o0000oeFZ
EOmEZUD01_mEZUD00ol0003oVFJIoiUVV@07oiUVV@;o00001_n<Lh`2o`0000ko_D:m00?o0000ojYE
Z_nZEJX04onZEJX00ol0003oRWF:ohYeRP0;ohYeRP03o`000?nn@Kko_T6n00Wo_T6n00?o0000onTF
jOoY5^T03?oY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000ood2oOom0_goo@;mo`000009onl@
k`03o`000?oF:MKo000000_oaC[500?o0000ojm@[on_D:l02on_D:l00ol0003oK9=/ofbCK00;ofbC
K003o`000?m[U6_oJiA[00CoJiA[00?o0000oeFZEOmEZUD01omEZUD00ol0003oVFJIoiUVV@05oiUV
V@03o`000?n<LhcoS7><00SoS7><00?o0000oke2_Onm@[d02_nm@[d00ol0003oZUFZojYEZP0DojYE
ZP03o`000?n:MH[oRWF:00_oRWF:00?o0000oki1__nn@Kh02Onn@Kh00ol0003ojAKYonTFj@0<onTF
j@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mo`000009onl@k`04o`000?oF:MKoeRWFo`00
00_oaC[500?o0000ojm@[on_D:l02on_D:l00ol0003oK9=/ofbCK00;ofbCK003o`000?m[U6_oJiA[
00CoJiA[00?o0000oeFZEOmEZUD02?mEZUD00ol0003oVFJIoiUVV@02oiUVV@;o00003?n<Lh`2o`00
00[o_D:m00?o0000ojYEZ_nZEJX05?nZEJX00ol0003oRWF:ohYeRP0;ohYeRP03o`000?nn@Kko_T6n
00Wo_T6n00?o0000onTFjOoY5^T03OoY5^T00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oka3_onl@k`07onl@k`03
o`000?oF:MKoeRWF00;oeRWF00?o0000olDjaOo5>/D02?o5>/D00ol0003o[e2_ojm@[`0<ojm@[`03
o`000?m/TfcoK9=/00WoK9=/00?o0000of^DJom[U6/01Om[U6/00ol0003oEJYEoeFZE@09oeFZE@04
o`000?nIIYWo0000o`00013oS7><0_l00008oke2_@03o`000?nZEJ[oZUFZ01CoZUFZ0ol0000;ohYe
RP03o`000?nn@Kko_T6n00Wo_T6n00?o0000onTFjOoY5^T03OoY5^T01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oka3_onl@k`06onl@k`03o`000?oF:MKoeRWF00?oeRWF00?o0000olDj
aOo5>/D02?o5>/D00ol0003o[e2_ojm@[`0;ojm@[`;o00002_m/Tf`00ol0003oJiA[of^DJ`06of^D
J`03o`000?mEZUGoEJYE00[oEJYE00?o0000ohacS?n<Lh`04_n<Lh`00ol0003o_D:moke2_@04oke2
_@03o`000?nZEJ[oZUFZ01GoZUFZ00?o0000oi9]T_nBKI801Ol00005ohYeRP03o`000?nn@Kko_T6n
00[o_T6n00?o0000onTFjOoY5^T03_oY5^T3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oka3_onl@k`04onl@k`03
o`000?oF:MKoeRWF00CoeRWF00?o0000olDjaOo5>/D01oo5>/D00ol0003o[e2_ojm@[`0;ojm@[`04
o`000?mbSG;oLXebo`0000WoK9=/00?o0000of^DJom[U6/01_m[U6/00ol0003oEJYEoeFZE@0:oeFZ
E@03o`000?n<LhcoS7><01?oS7><0_l00003oke2_@Co00005?nZEJX00ol0003oTVfBoi9]TP06oi9]
TPCo000000?oRWF:o`000?nn@Kh02onn@Kh00ol0003ojAKYonTFj@0>onTFj@03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003oka3_onl@k`03onl@k`03o`000?oF:MKoeRWF00GoeRWF00?o0000olDjaOo5
>/D01oo5>/D00ol0003o[e2_ojm@[`09ojm@[`;o00001?mbSG800ol0003oK9=/ofbCK005ofbCK003
o`000?m[U6_oJiA[00OoJiA[00?o0000oeFZEOmEZUD02_mEZUD00ol0003oS7><ohacS00EohacS003
o`000?nm@[go000000CoVfBK0ol0000@ojYEZP03o`000?nBKI;oTVfB00_oTVfB0_l0000<oki1_P03
o`000?oY5^WojAKY00cojAKY0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@koo_4>l00_o_4>l00ol0003oeRWF
omHYeP06omHYeP03o`000?o5>/GoaC[500OoaC[500?o0000ojm@[on_D:l02?n_D:l00ol0003oLXeb
og:=LP05og:=LP03o`000?m/TfcoK9=/00CoK9=/00?o0000of^DJom[U6/01om[U6/00ol0003oEJYE
oeFZE@0:oeFZE@03o`000?n<LhcoS7><01KoS7><00?o0000oi]TVonKI9/01_nKI9/3o`0000coZUFZ
00?o0000oi9]T_nBKI803OnBKI800ol0003o_T6noki1_P09oki1_PGo00002OoY5^T2o`000003on`C
k?l0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003onl@kol0003oeRWF00WoeRWF00?o0000olDjaOo5>/D01_o5
>/D00ol0003o[e2_ojm@[`07ojm@[`03o`000?mbSG;oLXeb00OoLXeb00?o0000ofbCK?m/Tf`00_m/
Tf`00ol0003oJiA[of^DJ`08of^DJ`03o`000?mEZUGoEJYE00WoEJYE00?o0000ohacS?n<Lh`05on<
Lh`00ol0003oVfBKoi]TV`09oi]TV`?o00002OnZEJX00ol0003oTVfBoi9]TP0>oi9]TPKo00001?nn
@Kh00ol0003oa3_4ol@ka003ol@ka0Go00000_oY5^T2o`0000Cok1?/00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oS7>?ohacSon<Lhol000002ooF:MH00ol0003oaC[5olDja@06olDja@03o`000?n_
D:oo[e2_00Go[e2_0_l0000;og:=LP04o`000?m/TfcoK9=/o`0000_oJiA[00?o0000oeFZEOmEZUD0
2OmEZUD00ol0003oS7><ohacS00FohacS003o`000?nKI9_oVfBK00goVfBK0ol00005ojYEZP03o`00
0?nBKI;oTVfB00ooTVfB00?o0000oj9MX_nRGJ800onRGJ84o`0000_oa3_40_l00006on`Ck003o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003ohacSon<Lh`02on<Lh`ko00001_o5>/D00ol0003o[e2_ojm@
[`05ojm@[`03o`000?mbSG;oLXeb00coLXeb00?o0000ofbCK?l000002om[U6/00ol0003oEJYEoeFZ
E@07oeFZE@?o00006?n<Lh`00ol0003oVfBKoi]TV`0@oi]TV`?o000000?oZUFZo`000?nBKI804?nB
KI800ol0003oXUfRoj9MXP07oj9MXP03o`000?o4>lCoa3_400[oa3_400?o0000on`Ck?o/4n`01Oo/
4n`00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005on<Lh`03o`000?naC[7o/Dja00_o/Dja0_l00004
olDja@03o`000?n_D:oo[e2_00?o[e2_0_l0000@og:=LP03o`000?m[U6_oJiA[00[oJiA[00?o0000
oeFZEOmEZUD00omEZUD4o`0000;o?/4n00?o0000ohacS?n<Lh`05On<Lh`00ol0003oVfBKoi]TV`0D
oi]TV`03o`000?nBKI;oTVfB013oTVfB00?o0000oj9MX_nRGJ801onRGJ800ol0003oa3_4ol@ka00:
ol@ka003o`000?o/4ncok1?/00Gok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oS7>?ohacS
00GohacS00?o0000ok5>/OnaC[403OnaC[46o`0000?o[e2_00?o0000og:=L_mbSG804?mbSG800ol0
003oJiA[of^DJ`0:of^DJ`03o`000?mEZUGo000000?o00001oln`Ch00ol0003oS7><ohacS00Dohac
S003o`000?nKI9_oVfBK01CoVfBK00?o0000oi9]T_nBKI803onBKI800ol0003oXUfRoj9MXP08oj9M
XP03o`000?o4>lCoa3_400[oa3_400?o0000on`Ck?o/4n`01Oo/4n`00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on<LhooS7><01_oS7><00ol0003o/Djaok5>/@0=ok5>/@03o`000?nUFZGoYEZU00?o
YEZU00?o0000ojm@[ol000004ombSG84o`0000WoJiA[0_l0000<ock1?P03o`000?n<LhcoS7><01?o
S7><00?o0000oi]TVonKI9/05OnKI9/00ol0003oTVfBoi9]TP0>oi9]TP03o`000?nRGJ;oXUfR00So
XUfR00?o0000ol@ka?o4>l@02Oo4>l@00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oS7>?ohacS00SohacS00?o0000ok5>/OnaC[402onaC[400ol0003oYEZUojEJY@05ojEJY@03o`00
0?mbSG;oLXeb01;oLXeb00Co0000od^dBom;]4_oBkA;1Ol00003of^DJ`03o`000?ln`Cko?/4n00go
?/4n0ol0000@ohacS0;o00006?nKI9/00ol0003oTVfBoi9]TP0=oi9]TP03o`000?nRGJ;oXUfR00Wo
XUfR00?o0000ol@ka?o4>l@02Oo4>l@00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ohacS00?o0000ok5>/OnaC[402_naC[400ol0003oYEZUojEJY@06ojEJY@03o`00
0?mbSG;oLXeb017oLXeb00?o0000od^dBom;]4/01om;]4/3o`00013o?/4n00?o0000ocC;=?ldbc@0
1Ol00009ohacS0;o000000?oCK9=o`000?nKI9/05onKI9/00ol0003oTVfBoi9]TP0=oi9]TP03o`00
0?nRGJ;oXUfR00WoXUfR00?o0000ol@ka?o4>l@02?o4>l@2o`0000[ok1?/00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?oa3_7ol@ka00;ol@ka00?o0000on<LhooS7><02OoS7><00ol0003o/Djaok5>
/@0:ok5>/@03o`000?nUFZGoYEZU00OoYEZU00?o0000og:=L_mbSG803ombSG800ol0003oBkA;od^d
B`0:od^dB`03o`000?ln`Cko?/4n00go?/4n00?o0000ocC;=?ldbc@01_ldbc@4o`0000CoS7><00?o
0000odfbCOm=/Td00_m=/Td00ol0003oVfBKoi]TV`0Foi]TV`03o`000?nBKI;oTVfB00_oTVfB00?o
0000oj9MX_nRGJ802onRGJ800ol0003oa3_4ol@ka006ol@ka003o`000?oE:]Go000000[ok1?/00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?oa3_7ol@ka00?ol@ka00?o0000on<LhooS7><02?oS7><=
o`0000[oYEZU00?o0000og:=L_mbSG803ombSG800ol0003oBkA;od^dB`0;od^dB`03o`000?ln`Cko
?/4n00co?/4n00?o0000ocC;=?ldbc@02_ldbc@4o`0000GoCK9=00?o0000oi]TVonKI9/05_nKI9/0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?nRGJ;oXUfR00coXUfR00?o0000ol@ka?o4>l@01?o4>l@2
o`0000?oeB[E00?o0000on`Ck?o/4n`02?o/4n`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo4>
lOoa3_400ooa3_400ol0003ohacSon<Lh`07on<Lh`03o`000?n^DJko[U6^00Wo[U6^00?o0000ojEJ
YOnUFZD02OnUFZD00ol0003oLXebog:=LP0=og:=LP03o`000?m;]4_oBkA;00coBkA;00?o0000ock1
?_ln`Ch03?ln`Ch00ol0003o=</docC;=00;ocC;=003o`000?lLhaco000000KoCK9=00?o0000oi]T
VonKI9/05_nKI9/00ol0003oTVfBoi9]TP09oi9]TP03o`000?nRGJ;oXUfR00coXUfR00?o0000ol@k
a?o4>l@00oo4>l@00ol0003oeB[EomDZe@03omDZe@03o`000?o/4ncok1?/00Sok1?/00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?oa3_7ol@ka00Col@ka00?o0000on<LhooS7><01_oS7><00ol0003o
[U6^ojiA[P08ojiA[P03o`000?nUFZGoYEZU00_oYEZU00?o0000og:=L_mbSG802?mbSG84o`0000oo
BkA;00?o0000ock1?_ln`Ch02oln`Ch00ol0003o=</docC;=00;ocC;=004o`000?lLhaco7><Lo`00
00OoCK9=00?o0000oi]TVonKI9/05OnKI9/00ol0003oTVfBoi9]TP08oi9]TP03o`000?nRGJ;oXUfR
00goXUfR00?o0000ol@ka?o4>l@00_o4>l@00ol0003oeB[EomDZe@05omDZe@03o`000?o/4ncok1?/
00Ook1?/00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?oa3_7ol@ka00Gol@ka00?o0000on<LhooS
7><01OoS7><00ol0003o[U6^ojiA[P08ojiA[P03o`000?nUFZGoYEZU00_oYEZU00?o0000og:=L_mb
SG800ombSG85o`0000?oC;=<00?o0000od^dBom;]4/03_m;]4/00ol0003o?/4nock1?P0:ock1?P03
o`000?ldbcCo=</d00[o=</d00Go0000oacS7?lLhaco7><Lo`000007odfbC@03o`000?nKI9_oVfBK
01GoVfBK00?o0000oi9]T_nBKI802?nBKI800ol0003oXUfRoj9MXP0=oj9MXP03o`000?o4>lCoa3_4
00;o00002?oE:]D00ol0003ok1?/on`Ck008on`Ck0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?oS7>?ohacS00Go
hacS00?o0000ojiA[_n^DJh02?n^DJh00ol0003oYEZUojEJY@0<ojEJY@Go00002Om</d`00ol0003o
BkA;od^dB`0<od^dB`;o00003?ln`Ch00ol0003o=</docC;=00:ocC;=005o`000?lLhaco7><LoacS
7?l000002?m=/Td00ol0003oVfBKoi]TV`0Doi]TV`?o00001onBKI800ol0003oXUfRoj9MXP0>oj9M
XP03o`000?o4>lCo000000_oeB[E00?o0000on`Ck?o/4n`01_o/4n`00ol0003oo0?loo`3o006oo`3
o003o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo4>lOoa3_401Ooa3_400ol0003ohacSon<Lh`04on<Lh`03o`000?n^DJko[U6^00Oo
[U6^00?o0000ojEJYOnUFZD03?nUFZD01?l0003oLXebog:=L_l0000;odbcC003o`000?m;]4_oBkA;
00_oBkA;00Co0000oaSW6?lHiaSo00002_ln`Ch00ol0003o=</docC;=00:ocC;=003o`000?lLhaco
7><L00;o7><L00?o0000odfbCOm=/Td01_m=/Td00ol0003oVfBKoi]TV`0Aoi]TV`?o00000omVVFH0
0ol0003oTVfBoi9]TP04oi9]TP03o`000?nRGJ;oXUfR00goXUfR1?l0000;omDZe@03o`000?o/4nco
k1?/00Gok1?/00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oa3_7ol@ka00Kol@ka00Co0000on<L
hooS7>?ohacS1?l00008ojiA[P03o`000?nUFZGoYEZU00_oYEZU00?o0000og:=L_mbSG800_mbSG80
0ol0003oC;=<odbcC008odbcC003o`000?m;]4_oBkA;00[oBkA;00?o0000oaSW6?lHiaP00_lHiaP0
0ol0003o?/4nock1?P03ock1?PGo00002oldbc@00ol0003o7><LoacS7003oacS7003o`000?m=/Tgo
CK9=00OoCK9=00?o0000oi]TVonKI9/03_nKI9/2o`0000OoIYUV00?o0000oi9]T_nBKI800_nBKI80
0ol0003oXUfRoj9MXP0=oj9MXP03o`000?o2?L;o`Sg200;o`Sg200?o0000omDZeOoE:]D02OoE:]D0
0ol0003ok1?/on`Ck003on`Ck003o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003ol@kaoo4>l@07oo4>
l@?o00001?o?<<l00ol0003o[U6^ojiA[P05ojiA[P03o`000?nUFZGoYEZU00[oYEZU00?o0000og:=
L_mbSG800ombSG800ol0003oC;=<odbcC009odbcC003o`000?m;]4_oBkA;00SoBkA;00?o0000oaSW
6?lHiaP01?lHiaP5o`0000Co0?l000?o0000ocC;=?ldbc@02Oldbc@00ol0003o7><LoacS7003oacS
7003o`000?m=/TgoCK9=00SoCK9=00?o0000oi]TVonKI9/02_nKI9/3o`0000[oIYUV00Go0000oi9]
T_nBKI;oTVfBo`00000>oj9MXP03o`000?o2?L;o`Sg200Co`Sg20_l00009omDZe@03o`000?o/4nco
k1?/00;ok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?oa3_7ol@ka00Ool@ka00?o0000oll`
coo?<<l01Oo?<<l00ol0003o[U6^ojiA[P03ojiA[P03o`000?nUFZGoYEZU00[oYEZU00?o0000og:=
L_mbSG801?mbSG800ol0003oC;=<odbcC009odbcC003o`000?m;]4_oBkA;00OoBkA;00?o0000oaSW
6?lHiaP01OlHiaP00ol0003o0?l0o`3o0007o`3o0003o`000?ldbcCo=</d00Oo=</d00?o0000oacS
7?lLha`01?lLha`00ol0003oCK9=odfbC@08odfbC@03o`000?nKI9_oVfBK00SoVfBK0_l0000>ofJI
IPCo00003?nRGJ82o`0000Wo`Sg200?o0000omDZeOoE:]D01ooE:]D01?l0003ok1?/on`Ck?l0000?
oo`3o003o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo4>lOoa3_401Ooa3_400ol0003occ3?oll`c`07oll`c`;o00000on^DJh00ol0
003oYEZUojEJY@09ojEJY@03o`000?mbSG;oLXeb00KoLXeb00?o0000odbcC?m</d`02Om</d`00ol0
003oBkA;od^dB`05od^dB`03o`000?lHiaSo6>LH00Ko6>LH00?o0000o`3o0?l0o`002?l0o`000ol0
003o=</docC;=006ocC;=003o`000?lLhaco7><L00Co7><L00?o0000odfbCOm=/Td02Om=/Td4o`00
00?oVfBK0ol0000@ofJIIP05o`000?nkA;_o^dBkok]4^ol000002_nRGJ800ol0003o`Sg2ol8m`P0:
ol8m`PKo00000ooE:]D00ol0003ok1?/o`00000@oo`3o003o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo4>lOoa3_401?oa3_400ol0
003occ3?oll`c`0:oll`c`04o`000?n^DJko[U6^o`0000[oYEZU00?o0000og:=L_mbSG801ombSG80
0ol0003oC;=<odbcC009odbcC003o`000?m;]4_oBkA;00CoBkA;00?o0000oaSW6?lHiaP01olHiaP0
0ol0003o0?l0o`3o0008o`3o00;o00001_ldbc@00ol0003o7><LoacS7005oacS7003o`000?m=/Tgo
CK9=00WoCK9=00Co0000occ3??ll`cco?<<l0ol0000BofJIIP03o`000?nkA;_o^dBk00?o^dBk0_l0
0006oj9MXP;o00003Oo2?L800ol0003ol0o`oo0?l003oo0?l0Go00004Ool0o`00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo4>lOoa3_400ooa3_40
0ol0003occ3?oll`c`0<oll`c`;o00002_nUFZD00ol0003oLXebog:=LP08og:=LP03o`000?m</dco
C;=<00[oC;=<00?o0000od^dBom;]4/00_m;]4/00ol0003o6>LHoaSW6008oaSW6003o`000?l0o`3o
0?l000Ko0?l00_l00002oa?/4`03o`000?ldbcCo=</d00;o=</d00?o0000oacS7?lLha`01_lLha`0
0ol0003oCK9=odfbC@08odfbC@03o`000?ll`cco?<<l00Co?<<l00?o0000ofJII_mVVFH03omVVFH0
0ol0003o^dBkok]4^`06ok]4^`;o00000onRGJ800ol0003o`Sg2ol8m`P0=ol8m`P03o`000?o`3o3o
l0o`00Ool0o`0_l0000@oo`3o003o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003ol@kaoo4>l@02oo4>l@03o`000?o?<<oocc3?
00kocc3?00?o0000ojEJYOnUFZD01onUFZD00ol0003oLXebog:=LP0:og:=LP03o`000?m</dcoC;=<
00WoC;=<00Go0000od^dBom;]4_oBkA;o`00000;oaSW6003o`000?l0o`3o0?l000Co0?l00_l00005
oa?/4`05o`000?ldbcCo=</docC;=?l000002?lLha`00ol0003oCK9=odfbC@08odfbC@03o`000?ll
`cco?<<l00Go?<<l00?o0000ofJII_mVVFH03_mVVFH00ol0003o^dBkok]4^`08ok]4^`03o`000?nR
GJ;o000000oo`Sg200?o0000oo0?l?o`3o002?o`3o001?l0003oo0?lo`000?l0000>oo`3o003o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?oa3_7ol@kao`00017occ3?00?o0000ojEJYOnUFZD01_nUFZD00ol0003oLXeb
og:=LP0;og:=LP03o`000?m</dcoC;=<00WoC;=<00Co0000od^dBom;]4_o00003?lHiaP00ol0003o
0?l0o`3o0002o`3o00;o00002?lCk1<00ol0003o=</do`000009oacS7003o`000?m=/TgoCK9=00So
CK9=00?o0000occ3??ll`c`01Oll`c`00ol0003oIYUVofJIIP0=ofJIIP03o`000?nkA;_o^dBk00[o
^dBk00?o0000ol8m`_o2?L803_o2?L800ol0003ol0o`oo0?l007oo0?l003o`000?ol0ocoo0?l00;o
o0?l00?o0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Boll`c`03o`00
0?nUFZGoYEZU00CoYEZU00?o0000og:=L_mbSG803?mbSG800ol0003oC;=<odbcC00:odbcC0?o0000
3?lHiaP00ol0003o0?l0o`3o0002o`0000_o4n`C00?o0000oacS7?lLha`02?lLha`00ol0003oCK9=
odfbC@07odfbC@03o`000?ll`cco?<<l00Oo?<<l00?o0000ofJII_mVVFH03?mVVFH00ol0003o^dBk
ok]4^`0;ok]4^`;o00003_o2?L800ol0003ol0o`oo0?l007oo0?l003o`000?ol0ocoo0?l00?oo0?l
0_l0000:oo`3o003o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo4>lOoa3_400ooa3_400ol0003occ3?oll`c`0?oll`c`?o00000onU
FZD00ol0003oLXebog:=LP0>og:=LP03o`000?m</dcoC;=<00SoC;=<00Co0000ob7N8OlQgR7o8MhQ
0_l0000:oaSW60?o00003OlCk1<00ol0003o7><LoacS7008oacS7003o`000?m=/TgoCK9=00OoCK9=
00?o0000occ3??ll`c`01oll`c`00ol0003oIYUVofJIIP0;ofJIIP03o`000?nkA;_o^dBk00co^dBk
00?o0000omlOgol000000_l0000:ol8m`P03o`000?o`3o3ol0o`00Sol0o`00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003ol@kaoo4>l@04oo4>l@03o`000?o?<<oocc3?00cocc3?0_l0
0003okI9]P03o`000?nUFZGo0000017oLXeb00?o0000odbcC?m</d`01om</d`00ol0003o8MhQob7N
8@04ob7N8@;o00002?lHiaP00ol0003o4n`Coa?/4`0>oa?/4`;o00002?lLha`00ol0003oCK9=odfb
C@06odfbC@03o`000?ll`cco?<<l00Wo?<<l00?o0000ofJII_mVVFH02OmVVFH00ol0003o^dBkok]4
^`0=ok]4^`03o`000?oO7moogaoO00;ogaoO0ol00007ol8m`P03o`000?o`3o3ol0o`00Ool0o`00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo0?l00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?o?<<oo
cc3?00Wocc3?0_l00006okI9]P03o`000?mbSG;oLXeb013oLXeb00?o0000odbcC?m</d`01_m</d`0
0ol0003o8MhQob7N8@07ob7N8@03o`000?lHiaSo6>LH00Co6>LH0ol0000>oa?/4`03o`000?l2o@;o
0_d200?o00001OlLha`00ol0003oCK9=odfbC@06odfbC@03o`000?ll`cco?<<l00[o?<<l00?o0000
ofJII_mVVFH02?mVVFH00ol0003o^dBkok]4^`0=ok]4^`03o`000?oO7moogaoO00GogaoO0ol00004
ol8m`P03o`000?o`3o3ol0o`00Ool0o`00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo0?loo`3o002
oo`3o0;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ol@kaoo4>l@06oo4>l@03o`000?o?<<oocc3?00Gocc3?0ol00008okI9]P03o`000?mbSG;oLXeb
017oLXeb00Co0000odbcC?m</dcoC;=<1?l0000;ob7N8@;o000000Co6>LHo`000?l0003o00000ol[
e2/2o`0000_o4n`C00?o0000o`;m0_l2o@801?l2o@82o`0000?o7><L00?o0000odfbCOm=/Td01_m=
/Td00ol0003o?<<locc3?00:occ3?003o`000?mVVFKoIYUV00OoIYUV00?o0000ok]4^onkA;/03_nk
A;/00ol0003ogaoOomlOg`08omlOg`Co00002_o`3o000ol0003oo0?loo`3o00;oo`3o0;o000000?o
o0?lo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003ol@kaoo4>l@07oo4>l@03o`000?o?<<oocc3?00;occ3?0_l0000<okI9]P03o`000?mbSG;o
LXeb013oLXeb1?l00003ock1?P03o`000?lQgR7o8MhQ00_o8MhQ00?o0000ob_D:ol[e2/01_l[e2/0
0ol0003o4n`Coa?/4`07oa?/4`03o`000?l2o@;o0_d200Oo0_d23?l0000>occ3?003o`000?mVVFKo
IYUV00KoIYUV00?o0000ok]4^onkA;/03_nkA;/00ol0003ogaoOomlOg`0;omlOg`03o`000?o`3o3o
l0o`00Ool0o`00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00Wol@ka00Co0000oll`
col0003o00003_nfBKH00ol0003oLXebog:=LP0?og:=LP03o`000?ln`Cko?/4n00Ko?/4n00?o0000
ob7N8OlQgR402_lQgR400ol0003o:m@[ob_D:`07ob_D:`;o00001_lCk1<00ol0003o0_d2o`;m0P08
o`;m0P03o`000?mDZeCoE:]D00SoE:]D00?o0000occ3??ll`c`03?ll`c`00ol0003oIYUVofJIIP05
ofJIIP03o`000?nkA;_o^dBk00oo^dBk0_l0000=omlOg`03o`000?o`3o3ol0o`00Kol0o`00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00[ol@ka00?o0000okI9]_nfBKH03_nfBKH00ol0
003oLXebog:=LP0>og:=LP03o`000?ln`Cko?/4n00Oo?/4n00?o0000ob7N8OlQgR402_lQgR400ol0
003o:m@[ob_D:`09ob_D:`;o00000olCk1<00ol0003o0_d2o`;m0P09o`;m0P03o`000?mDZeCoE:]D
00WoE:]D00?o0000occ3??ll`c`02_ll`c`4o`0000CoIYUV00?o0000ok]4^onkA;/04?nkA;/01?l0
003og2?Lo`000?l0000<omlOg`03o`000?o`3o3ol0o`00Gol0o`00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oa3_7ol@ka00[ol@ka00?o0000okI9]_nfBKH03onfBKH@o`0000[o?/4n00?o0000ob7N
8OlQgR402OlQgR400ol0003o2?L8o`00000<ob_D:`05o`000?lCk1?o0000o`;m0_l000002_l2o@80
0ol0003oE:]DoeB[E009oeB[E003o`000?ll`cco?<<l00Oo?<<l0ol00004offBK@?o000000?oIYUV
o`000?nkA;/04OnkA;/01?l0003og2?Lom`Sg?oL8m`2o`0000_ogaoO00?o0000oo0?l?o`3o000oo`
3o000ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003o]TVfokI9]P0?
okI9]P03o`000?mgR7OoMhQg00coMhQg00?o0000ock1?_ln`Ch02Oln`Ch00ol0003o8MhQob7N8@07
ob7N8@04o`000?l8m`So2?L8o`0000go:m@[00Go0000o`;m0_l2o@;o0_d2o`000009o`;m0P03o`00
0?mDZeCoE:]D00[oE:]D00?o0000occ3??ll`c`00oll`c`3o`0000[oKI9]00?o0000ok]4^onkA;/0
4?nkA;/00ol0003og2?Lom`Sg004om`Sg0;o00002_oO7ml00ol0003ol0o`oo0?l004o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000col@ka00?o0000okI9]_nfBKH03onfBKH00ol0003oMhQgogN8M`0<ogN8M`03o`000?ln
`Cko?/4n00Wo?/4n00?o0000ob7N8OlQgR401_lQgR400ol0003o2?L8o`Sg2002o`Sg2003o`000?l[
e2_o:m@[00[o:m@[00?o0000o`;m0_l2o@800_l2o@800ol0003o0_d2o`;m0P06o`;m0P03o`000?mD
ZeCoE:]D00[oE:]D00?o0000occ3??ll`c`00ol0000=offBK@03o`000?nkA;_o^dBk013o^dBk00?o
0000om`Sg?oL8m`01_oL8m`2o`0000WogaoO0_l00004oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003o]TVfokI9]P0=okI9]P?o00003omgR7L0
0ol0003o?/4nock1?P08ock1?P03o`000?lQgR7o8MhQ00Go8MhQ00?o0000o`Sg2?l8m`P00ol8m`P0
0ol0003o:m@[ob_D:`0:ob_D:`03o`000?l2o@;o0_d200?o0_d200?o0000o`;m0_l2o@801Ol2o@80
0ol0003oE:]DoeB[E00;oeB[E0;o00004Om]TVd00ol0003o^dBkok]4^`0?ok]4^`03o`000?oL8mco
g2?L00Sog2?L0_l00007omlOg`03o`000?ol0ocoo0?l00Coo0?l00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo4>lOoa3_402?oa3_400ol0003o]TVfokI9]P09okI9]PGo00000_n3O8<00ol0
003oMhQgogN8M`0=ogN8M`03o`000?ln`Cko?/4n00Wo?/4n00?o0000ob7N8OlQgR401?lQgR400ol0
003o2?L8o`Sg2004o`Sg2003o`000?l[e2_o:m@[00So:m@[00?o0000o`;m0_l2o@801Ol2o@800ol0
003o0_d2o`;m0P04o`;m0P03o`000?mDZeCoE:]D00_oE:]D00?o0000offBKOm]TVd04?m]TVd00ol0
003o^dBkok]4^`0?ok]4^`03o`000?oL8mcog2?L00[og2?L0_l00004omlOg`03o`000?ol0ocoo0?l
00Koo0?l0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003ol@kaoo4>l@07oo4>l@03o`000?nfBKKo]TVf00Co]TVf1Ol00007oh=lP`03
o`000?mgR7OoMhQg00goMhQg00?o0000ock1?_ln`Ch02Oln`Ch00ol0003o8MhQob7N8@03ob7N8@03
o`000?l8m`So2?L800Go2?L800?o0000ob_D:ol[e2/02?l[e2/00ol0003o0_d2o`;m0P06o`;m0P03
o`000?l2o@;o0_d200?o0_d200?o0000oeB[E?mDZe@02omDZe@00ol0003oKI9]offBK@0@offBK@03
o`000?nkA;_o^dBk00oo^dBk00?o0000om`Sg?oL8m`03?oL8m`2o`000003omlOgol0003oo0?l00[o
o0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00Ool@ka00?o0000okI9]_l00000
1?l0000<oh=lP`03o`000?mgR7OoMhQg00koMhQg00?o0000ock1?_ln`Ch02?ln`Ch00ol0003o8MhQ
ob7N8@02ob7N8@03o`000?l8m`So2?L800Oo2?L800?o0000ob_D:ol[e2/01ol[e2/00ol0003o0_d2
o`;m0P07o`;m0P03o`000?l2o@;o0_d200;o0_d200?o0000oeB[E?mDZe@02omDZe@00ol0003oKI9]
offBK@0AoffBK@03o`000?nkA;_o^dBk00go^dBk00?o0000om`Sg?oL8m`03ooL8m`00ol0003oo0?l
oo`3o00;oo`3o0;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo4>lOoa3_401Ooa3_43o`00017oPgb300?o0000ogN8MomgR7L03_mg
R7L00ol0003o?/4nock1?P09ock1?P04o`000?lQgR7o8MhQo`0000[o2?L800?o0000ob_D:ol[e2/0
1ol[e2/00ol0003o0_d2o`;m0P08o`;m0P05o`000?l2o@;o0_d2o`;m0_l000003OmDZe@00ol0003o
KI9]offBK@0AoffBK@?o00003OnkA;/00ol0003og2?Lom`Sg00?om`Sg003o`000?ol0ocoo0?l00go
o0?l00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_oa3_42o`0000;odBkA00?o0000oh=lPon3O8<03on3O8<00ol0003o
MhQgogN8M`0>ogN8M`03o`000?ln`Cko?/4n00So?/4n1Ol0000;o`Sg2003o`000?l[e2_o:m@[00Ko
:m@[00?o0000o`;m0_l2o@802Ol2o@801?l0003o0_d2o`;m0_l0000=oeB[E003o`000?m]TVgoKI9]
017oKI9]00?o0000oe^TFomKY5/00ol0000:ok]4^`Co00003OoL8m`00ol0003oo0?loo`3o00?oo`3
o003o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo4>lOoa3_7ol@ka0_l00005om4^d@03o`000?n3O8?oPgb300koPgb300?o0000ogN8
MomgR7L03_mgR7L00ol0003o?/4nock1?P07ock1?P03o`000?ldbcCo=</d00?o=</d00?o0000o`Sg
2?l8m`P02?l8m`P00ol0003o:m@[ob_D:`05ob_D:`03o`000?l2o@;o0_d200[o0_d21Ol0000<oeB[
E003o`000?m]TVgoKI9]013oKI9]00?o0000oe^TFomKY5/01?mKY5/3o`0000Ko^dBk00?o0000omXU
f_oJ9MX00_oJ9MX5o`0000Sog2?L00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00?o
l@ka00?o0000om4^dOoA;]401?oA;]400ol0003oPgb3oh=lP`0=oh=lP`03o`000?mgR7OoMhQg00oo
MhQg00?o0000ock1?_ln`Ch01?ln`Ch2o`0000Oo=</d00?o0000o`Sg2?l8m`P01ol8m`PEo`0000Go
3o0?00?o0000oeB[E?mDZe@02?mDZe@3o`00013oKI9]00?o0000oe^TFomKY5/02?mKY5/3o`0000;o
^dBk00?o0000omXUf_oJ9MX02?oJ9MX5o`0000?og2?L00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?oa3_7ol@ka00Col@ka00?o0000om4^dOoA;]401OoA;]400ol0003oPgb3oh=lP`0;oh=lP`Co0000
3omgR7L00ol0003o?/4nock1?P03ock1?P03o`000?ldbcCo=</d00So=</d00?o0000o`Sg2?l8m`P0
1?l8m`P2o`0000So</db00?o0000oaoO7olOgal02?lOgal00ol0003o3o0?o`o`3`05o`o`3`;o0000
1_mDZe@2o`0000?oB;M800?o0000offBKOm]TVd03?m]TVd00ol0003oFjAKoe^TF`0<oe^TF`;o0000
4?oJ9MX3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?oA;]7odBkA00KodBkA00?o
0000oh=lPon3O8<02On3O8<00ol0003oRGJ9o`000002oeRWF0?o00003?mgR7L01?l0003o?/4nock1
?_ln`Ch2o`0000co=</d00?o0000o`Sg2?l8m`P00_l8m`P00ol0003o</dboc;=<P08oc;=<P03o`00
0?lOgaoo7mlO00So7mlO00?o0000o`o`3ol?l0l01ol?l0l00ol0003oE:]DoeB[E002oeB[E003o`00
0?m8]dSoB;M800CoB;M80_l0000;offBK@03o`000?mKY5_oFjAK00coFjAK00?o0000oi]TVol00000
4_oJ9MX00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003ol@kaoo4>l@06oo4>l@03o`000?oA;]7odBkA00OodBkA00?o
0000oh=lPon3O8<01_n3O8<2o`0000;oRGJ900?o0000oeRWF?mHYeP00omHYeP3o`0000[oMhQg00?o
0000ock1?_l000003oldbc@01?l0003o2?L8o`000?l0000;oc;=<P03o`000?lOgaoo7mlO00So7mlO
00?o0000o`o`3ol?l0l02?l?l0l01?l0003oE:]Do`000?l00009odRgB003o`000?m]TVgoKI9]00Oo
KI9]00?o0000oe^TFomKY5/03?mKY5/01?l0003oVfBKoi]TVol0000ComXUfP03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo4>lOoa3_401ooa3_400ol0003odBkAom4^d@08om4^d@03o`000?n3O8?oPgb300Co
Pgb300?o0000ohUfROn9MXT00on9MXT00ol0003oF:MHoeRWF005oeRWF0?o00001_mgR7L4o`00013o
=</d00?o0000oc;=<_lbcC803?lbcC800ol0003o7mlOoaoO7`07oaoO7`03o`000?l?l0oo3o0?00Wo
3o0?00?o0000odRgB?m8]dP02_m8]dP2o`0000KoKI9]00?o0000oe^TFomKY5/03?mKY5/00ol0003o
VfBKoi]TV`02oi]TV`03o`000?oJ9M[ofRGJ00oofRGJ00?o0000onhAk_l000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003ol@kaoo4>l@08oo4>l@03o`000?oA;]7odBkA00WodBkA00Co0000oh=lPon3O8?o
Pgb30_l00006ohUfR@03o`000?mHYeSoF:MH00SoF:MH0ol000000omgR7Oo0000o`000004odFjA@03
o`000?ldbcCo=</d00go=</d00?o0000oc;=<_lbcC803?lbcC800ol0003o7mlOoaoO7`07oaoO7`03
o`000?l?l0oo3o0?00Wo3o0?00?o0000odRgB?m8]dP03?m8]dP00ol0003oKI9]offBK@03o`0000ko
FjAK00?o0000oi]TVonKI9/00onKI9/00ol0003ofRGJomXUfP0>omXUfP05o`000?o^4NkokQ7^onhA
k_l000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003ol@kaoo4>l@09oo4>l@03o`000?oA;]7odBkA00[o
dBkA00?o0000oh=lPol000002?n9MXT00ol0003oF:MHoeRWF00;oeRWF003o`000?m5^TGoAKY500Go
AKY500?o0000ocC;=?ldbc@03?ldbc@00ol0003o</dboc;=<P0<oc;=<P03o`000?lOgaoo7mlO00Oo
7mlO00?o0000o`o`3ol?l0l02?l?l0l2o`0000ooB;M80_l00002ofJIIP03o`000?mKY5_oFjAK00_o
FjAK00?o0000oi]TVonKI9/01?nKI9/00ol0003ofRGJomXUfP0=omXUfP03o`000?o^4NkokQ7^00?o
kQ7^00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo4>l@03o`000?oA;]7odBkA00_odBkA00?o0000ohUfROn9MXT0
1on9MXT00ol0003oF:MHoeRWF00;oeRWF003o`000?m5^TGoAKY500KoAKY500?o0000ocC;=?ldbc@0
2oldbc@2o`0000go</db00?o0000oaoO7olOgal01olOgal00ol0003o3o0?o`o`3`07o`o`3`04o`00
0?lLhaco7><Lo`0000koB;M800?o0000ofJII_mVVFH00_mVVFH00ol0003oFjAKoe^TF`09oe^TF`03
o`000?nKI9_oVfBK00KoVfBK00?o0000omXUf_oJ9MX02ooJ9MX00ol0003okQ7^onhAkP05onhAkP04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Sol@ka00?o0000om4^dOoA;]402_oA;]42o`0000Wo
RGJ900?o0000oeRWF?mHYeP02omHYeP00ol0003oAKY5odFjA@07odFjA@03o`000?ldbcCo=</d00Wo
=</d00Co0000o`7n0Ol1oP7o00003?lbcC800ol0003o7mlOoaoO7`07oaoO7`03o`000?l?l0oo3o0?
00Ko3o0?00Go0000oacS7?lLhaco7><Lo`00000>odRgB003o`000?mVVFKoIYUV00?oIYUV00?o0000
oe^TFomKY5/01omKY5/00ol0003oVfBKoi]TV`07oi]TV`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000
onhAk_o^4Nh01oo^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo4>l@03o`000?oA;]7odBkA
00WodBkA00Co0000okm0_ono@;oo00002On9MXT00ol0003oF:MHoeRWF009oeRWF003o`000?m5^TGo
AKY500WoAKY500?o0000ocC;=?ldbc@01oldbc@00ol0003o0Oh1o`7n0@02o`7n0@03o`000?lbcC;o
</db00Wo</db00?o0000oaoO7olOgal01olOgal00ol0003o3o0?o`o`3`05o`o`3`03o`000?lLhaco
7><L00?o7><L00?o0000odRgB?m8]dP02_m8]dP00ol0003oIYUVofJIIP05ofJIIP03o`000?mKY5_o
FjAK00GoFjAK00?o0000oi]TVonKI9/02?nKI9/00ol0003ofRGJomXUfP09omXUfP03o`000?o^4Nko
kQ7^00SokQ7^00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oa3_43o`0000WodBkA00?o0000okm0
_ono@;l00_no@;l00ol0003oRGJ9ohUfR@06ohUfR@03o`000?mHYeSoF:MH00WoF:MH00?o0000odFj
AOm5^TD02_m5^TD00ol0003o=</docC;=005ocC;=003o`000?l1oP7o0Oh100Co0Oh100?o0000oc;=
<_lbcC802?lbcC800ol0003o7mlOoaoO7`07oaoO7`03o`000?l?l0oo3o0?00Co3o0?00?o0000oacS
7?lLha`01?lLha`00ol0003oB;M8odRgB00:odRgB003o`000?mVVFKoIYUV00KoIYUV00?o0000oe^T
FomKY5/00omKY5/00ol0003oVfBKoi]TV`09oi]TV`03o`000?oJ9M[ofRGJ00SofRGJ00?o0000onhA
k_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onTFj@?o00001OoA;]400ol0003o
_d2ookm0_`03okm0_`03o`000?n9MXWoRGJ900KoRGJ900?o0000oeRWF?mHYeP02OmHYeP00ol0003o
AKY5odFjA@0;odFjA@03o`000?ldbcCo=</d00?o=</d00?o0000o`7n0Ol1oP401_l1oP400ol0003o
</dboc;=<P08oc;=<P03o`000?lOgaoo7mlO00Ko7mlO00?o0000o`o`3ol?l0l00_l?l0l2o`0000So
7><L00?o0000odRgB?m8]dP02Om8]dP00ol0003oIYUVofJIIP07ofJIIP05o`000?mKY5_oFjAKoe^T
Fol000003OnKI9/00ol0003ofRGJomXUfP06omXUfP03o`000?o^4NkokQ7^00[okQ7^00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?oY5^WojAKY00GojAKY0ol000000ooA;]7o0000okm0_`06okm0_`03
o`000?n9MXWoRGJ900GoRGJ900?o0000oeRWF?mHYeP02OmHYeP00ol0003oAKY5odFjA@0<odFjA@05
o`000?ldbcCo=</docC;=?l000002_l1oP400ol0003o</dboc;=<P07oc;=<P03o`000?lOgaoo7mlO
00Ko7mlO00?o0000o`o`3ol000000_l000000om>/Dko0000oacS7007oacS7003o`000?m8]dSoB;M8
00SoB;M800?o0000ofJII_mVVFH02OmVVFH00ol0003oFjAKo`00000=oi]TV`Co00001OoJ9MX00ol0
003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ojAKYonTFj@08onTFj@03
o`000?no@;oo_d2o00Oo_d2o00?o0000ohUfROn9MXT01?n9MXT00ol0003oF:MHoeRWF009oeRWF003
o`000?m5^TGoAKY500goAKY500?o0000ocC;=?l000003?l1oP4:o`0000Oo7mlO0ol00005odjaCP03
o`000?lLhaco7><L00Ko7><L00?o0000odRgB?m8]dP01om8]dP00ol0003oIYUVofJIIP0:ofJIIP03
o`000?nKI9_oVfBK00_oVfBK00?o0000om</dooC;=<00_oC;=<3o`000003omXUf_l0003okQ7^00_o
kQ7^0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onTFjOoY5^T02OoY5^T00ol0003o_d2ookm0_`07okm0_`03o`00
0?n9MXWoRGJ900GoRGJ900?o0000oeRWF?mHYeP01omHYeP00ol0003oAKY5odFjA@0?odFjA@;o0000
2ol1oP400ol0003o@;m0od2o@007od2o@003o`000?lOgaoo7mlO00;o7mlO0ol00008odjaCP03o`00
0?lLhaco7><L00Ko7><L00?o0000odRgB?m8]dP01om8]dP00ol0003oIYUVofJIIP0:ofJIIP03o`00
0?nKI9_oVfBK00[oVfBK00?o0000om</dooC;=<01_oC;=<00ol0003okQ7^onhAkP08onhAkP?o0000
0_ob3O800ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onTFjOoY5^T02OoY5^T00ol0003o_d2ookm0
_`08okm0_`03o`000?n9MXWoRGJ900CoRGJ900?o0000oeRWF?mHYeP01omHYeP00ol0003oAKY5odFj
A@0>odFjA@04o`000?lDjaCo5>/Do`0000Wo0Oh100?o0000od2o@?m0_d002Om0_d001?l0003o7mlO
o`000?l0000<odjaCP03o`000?lLhaco7><L00Ko7><L00?o0000odRgB?m8]dP01_m8]dP00ol0003o
IYUVofJIIP0;ofJIIP03o`000?nKI9_oVfBK00OoVfBK0_l00009om</d`03o`000?o^4NkokQ7^00Co
kQ7^1?l00006oo8=lP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ojAKYonTFj@09onTFj@03o`00
0?no@;oo_d2o00So_d2o00?o0000ohUfROn9MXT00on9MXT>o`0000goAKY500?o0000oaC[5?lDja@0
0_lDja@00ol0003o0Oh1o`7n0@05o`7n0@03o`000?m0_d3o@;m000_o@;m000?o0000odjaC_m>/Dh0
3?m>/Dh00ol0003o7><LoacS7006oacS7003o`000?m8]dSoB;M800GoB;M800?o0000ofJII_mVVFH0
3?mVVFH00ol0003oVfBKoi]TV`06oi]TV`03o`000?oC;=?odbcC00[odbcC00?o0000onhAk_o^4Nh0
0ol0000:oo8=lP?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oY5^WojAKY00_ojAKY00?o0000okm0_ono@;l02?no
@;l01Ol0003oRGJ9ohUfROn9MXWo000000_oHIiQ00?o0000o`Oh1ol7n0L00ol00009odFjA@03o`00
0?lDjaCo5>/D00Co5>/D00?o0000o`7n0Ol1oP400ol1oP400ol0003o@;m0od2o@00<od2o@003o`00
0?m>/DkoC[5>00goC[5>00?o0000oacS7?lLha`01_lLha`00ol0003oB;M8odRgB003odRgB0?o0000
3OmVVFH00ol0003oVfBKoi]TV`05oi]TV`03o`000?oC;=?odbcC00codbcC0_l0000=oo8=lP03o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oY5^WojAKY00_ojAKY00?o0000okm0_ono@;l02?no
@;l4o`0000coHIiQ00?o0000o`Oh1ol7n0L00ol7n0L3o`0000GoAKY500?o0000oaC[5?lDja@01_lD
ja@01Ol0003o0Oh1o`7n0Ol1oP7o000000oo@;m000?o0000odjaC_m>/Dh03Om>/Dh00ol0003o7><L
oacS7006oacS7003o`000?m8]dSoB;M800?o00000ol[e2/00ol0003oIYUVofJIIP0;ofJIIP03o`00
0?nKI9_oVfBK00?oVfBK00?o0000om</dooC;=<03OoC;=<00ol0003olPgboo8=lP0;oo8=lP03o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onTFjOoY5^T02_oY5^T3o`0000Ko_d2o0ol0
0003oj]DZ`03o`000?mQWV7oHIiQ00[oHIiQ00?o0000o`Oh1ol7n0L01_l7n0L3o`000003odFjAOl0
003o5>/D00Wo5>/D00?o0000o`7n0Ol000004?m0_d000ol0003oC[5>odjaCP0=odjaCP03o`000?lL
haco7><L00Oo7><L0_l00007ob_D:`03o`000?mVVFKoIYUV00[oIYUV00Co0000oi]TVonKI9_oVfBK
0ol0000?om</d`03o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onTFjOoY5^T02_oY
5^T01?l0003og2?Lom`Sg?oL8m`2o`000004okm0_ol0003o0000o`0000KoZeB[00?o0000of6NHOmQ
WV402_mQWV400ol0003o1oP7o`Oh1`09o`Oh1`03o`000?lDjaCo5>/D00[o5>/D00?o0000od2o@?m0
_d003om0_d000ol0003oC[5>odjaCP0>odjaCP03o`000?lLhaco7><L00Ko7><L00?o0000ob_D:ol[
e2/01ol[e2/4o`0000SoIYUV00Co0000oi]TVonKI9_o00000onVFJH2o`0000godbcC00?o0000oo8=
l_ob3O802_ob3O800ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onTFjOoY5^T02OoY5^T00ol0003o
g2?Lom`Sg004om`Sg003o`000?n[E:_oZeB[00OoZeB[00?o0000of6NHOmQWV402OmQWV400ol0003o
1oP7o`Oh1`0:o`Oh1`03o`000?lDjaCo5>/D00[o5>/D00?o0000od2o@?m0_d003om0_d000ol0003o
C[5>odjaCP0>odjaCP03o`000?lLhaco7><L00Go7><L00?o0000ob_D:ol[e2/02?l[e2/01?l0003o
FJIIoeVVFOmIYUT7o`0000;oIYUV0_l00006ojIIYP;o00003?oC;=<00ol0003olPgboo8=lP09oo8=
lP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ojAKYonTFj@08onTFj@03o`000?oL8mcog2?L00Go
g2?L00?o0000oj]DZon[E:/02?n[E:/00ol0003oHIiQof6NH@08of6NH@03o`000?l7n0Oo1oP700[o
1oP700?o0000oaC[5?lDja@02olDja@00ol0003o@;m0od2o@00>od2o@003o`000?m>/DkoC[5>00ko
C[5>1Ol00002oacS7003o`000?l[e2_o:m@[00Wo:m@[00?o0000oeVVFOmIYUT02?mIYUT3o`0000Wo
YUVV0_l0000:om</d`03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oY5^WojAKY00SojAKY00?o0000om`Sg?oL8m`01ooL8m`00ol0003oZeB[oj]DZ`07oj]DZ`03o`00
0?mQWV7oHIiQ00SoHIiQ00?o0000o`Oh1ol7n0L02_l7n0L00ol0003o5>/DoaC[500:oaC[50;o0000
3_m0_d03o`0000goC[5>0ol00005oeJYEP;o00002ol[e2/00ol0003oFJIIoeVVF@0;oeVVF@;o0000
2_nVFJH2o`0000OodbcC0ol00009oo8=lP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:om`Sg003o`00
0?n[E:_oZeB[00OoZeB[00?o0000of6NHOmQWV402?mQWV4>o`0000Wo5>/D0ol000000ol0o`3o0000
od2o@00:od2o@0?o00000_mIYUT00ol0003oC[5>odjaCP09odjaCP;o00002OmFZEH00ol0003o:m@[
ob_D:`09ob_D:`03o`000?mIYUWoFJII00_oFJII00?o0000ogj1O_l000002onVFJH2o`0000CodbcC
00Co0000onLHiooW6>OoiaSW0_l00007oo8=lP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ook1?/00ol0003og2?L
om`Sg009om`Sg003o`000?n[E:_oZeB[00KoZeB[00?o0000of6NHOmQWV402?mQWV400ol0003o4^dB
oa;]4P0:oa;]4P03o`000?lDjaCo5>/D00Co5>/D0ol00005o`3o0003o`000?m0_d3o@;m000Co@;m0
1?l00006oeVVF@03o`000?m>/DkoC[5>00KoC[5>0_l0000;oeJYEP03o`000?l[e2_o:m@[00Wo:m@[
00?o0000oeVVFOmIYUT02_mIYUT01Ol0003oOX5nogj1O_mnPGko000000coYUVV0_l000000ooC;=?o
0000onLHi`05onLHi`03o`000?ob3O;olPgb00?olPgb00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oL8mcog2?L00Sog2?L00?o0000oj]DZon[E:/01_n[E:/00ol0003oHIiQof6NH@07of6NH@03o`00
0?lBkA;o4^dB00_o4^dB00?o0000oaC[5?lDja@00_lDja@2o`0000Wo0?l000?o0000od2o@?m0_d00
0ol0000;oeVVF@03o`000?m>/DkoC[5>00;oC[5>0ol0000>oeJYEP03o`000?l[e2_o:m@[00Oo:m@[
00?o0000oeVVFOmIYUT02omIYUT00ol0003oOX5nogj1OP02ogj1OP03o`000?nVFJKoYUVV00_oYUVV
00?o0000onLHiooW6>L01_oW6>L2o`0000?olPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oL
8mcog2?L00Oog2?L00?o0000oj]DZon[E:/01on[E:/00ol0003oHIiQof6NH@05of6NH@?o00003OlB
kA84o`0000_o0?l00ol0000?oeVVF@04o`000?m>/Dko0000o`00017oEZUF00?o0000ob_D:ol[e2/0
1ol[e2/00ol0003oFJIIoeVVF@0:oeVVF@03o`000?mnPGkoOX5n00CoOX5n00?o0000ojIIY_nVFJH0
1onVFJH3o`0000_oiaSW1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om`Sg?oL8m`02?oL8m`00ol0003oZeB[oj]D
Z`06oj]DZ`03o`000?mQWV7oHIiQ00;oHIiQ0ol00003od2o@003o`000?lBkA;o4^dB00[o4^dB00?o
0000o`3o0?l0o`002ol0o`000ol0003o1?/4o`00000AoeVVF@03o`000?mFZEKoEZUF017oEZUF00?o
0000ob_D:ol[e2/01ol[e2/00ol0003oFJIIoeVVF@0:oeVVF@03o`000?mnPGkoOX5n00GoOX5n00Co
0000ojIIY_nVFJKoYUVV1Ol00002ok=</`03o`000?oW6>OoiaSW00WoiaSW00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000om`Sg?oL8m`01ooL8m`00ol0003oZeB[oj]DZ`05oj]DZ`?o0000
00?oHIiQo`000?l000001om0_d000ol0003o4^dBoa;]4P08oa;]4P?o00002_l0o`02o`0000;o1?/4
00?o0000oeVVFOmIYUT03omIYUT00ol0003oEZUFoeJYEP0AoeJYEP03o`000?l[e2_o:m@[00Oo:m@[
00?o0000oeVVFOmIYUT02OmIYUT00ol0003oOX5nogj1OP07ogj1OP?o00001oncC;<00ol0003oiaSW
onLHi`09onLHi`03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000om`Sg?oL8m`01ooL
8m`4o`0000;oZeB[0_l00003oj=LX`03o`000?m0_d3o@;m000So@;m00_l00006oa;]4P;o00000olD
ja@00ol0003o0?l0o`3o0006o`3o0003o`000?l4n`Co1?/400?o1?/400?o0000oeVVFOmIYUT03_mI
YUT00ol0003oEZUFoeJYEP0BoeJYEP03o`000?l[e2_o:m@[00Go:m@[00?o0000oeVVFOmIYUT02OmI
YUT00ol0003oOX5nogj1OP08ogj1OP03o`000?ncC;?o/dbc00Oo/dbc00?o0000onLHiooW6>L02?oW
6>L00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oL8mcog2?L00Cog2?L0_l00004
on4Nh@;o00001OnSG:<00ol0003o@;m0od2o@00:od2o@003o`000?lBkA;o4^dB00;o4^dB00?o0000
oaC[5?lDja@01?lDja@00ol0003o0?l0o`3o0004o`3o0003o`000?l4n`Co1?/400Co1?/400?o0000
oeVVFOmIYUT03_mIYUT00ol0003oEZUFoeJYEP0BoeJYEP[o00002_mIYUT00ol0003oOX5nogj1OP08
ogj1OP03o`000?ncC;?o/dbc00Oo/dbc00?o0000onLHiooW6>L02?oW6>L00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003og2?Lom`Sg?oL8m`2o`0000OohAkQ00?o0000oj=LXonSG:<01?nSG:<0
0ol0003o@;m0od2o@00:od2o@004o`000?lBkA;o0000o`0000So5>/D00Co0000o`3o0?l0o`3o0?l0
0_l00007o`Ck1003o`000?mIYUWoFJII00koFJII00?o0000oeJYE_mFZEH04_mFZEH00ol0003o@[e2
od:m@P07od:m@P03o`000?mIYUWoFJII00KoFJII00?o0000ogj1O_mnPGh02_mnPGh00ol0003o/dbc
ok=</`06ok=</`03o`000?oW6>OoiaSW00SoiaSW00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oL
8mco0000o`0000WohAkQ00?o0000oj=LXonSG:<01?nSG:<00ol0003o@;m0od2o@00;od2o@003o`00
0?lDjaCo5>/D00Wo5>/D00?o0000o`3o0?l000002Ol4n`@00ol0003oFJIIoeVVF@0>oeVVF@;o0000
4_mFZEH00ol0003o@[e2od:m@P09od:m@P;o00001_mIYUT00ol0003oOX5nogj1OP0:ogj1OP03o`00
0?ncC;?o/dbc00Ko/dbc00?o0000onLHiooW6>L02?oW6>L00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000on4NhOoQ7^402OoQ7^400ol0003oXebSoj=LX`05oj=LX`03o`000?m0_d3o@;m000[o@;m000?o
0000oaC[5?lDja@02_lDja@2o`0000Wo1?/400?o0000oeVVFOmIYUT03_mIYUT00ol0003o@;m0o`00
0002o`0000ooEZUF00?o0000od:m@_m2_D802om2_D800ol0003oFJIIoeVVF@03o`0000goOX5n00?o
0000ok=</oncC;<01_ncC;<00ol0003oiaSWonLHi`07onLHi`03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ohAkQon4Nh@09on4Nh@03o`000?nSG:?oXebS00GoXebS00?o0000od2o@?m0_d002Om0_d02
o`0000_o5>/D0_l0000;o`Ck1003o`000?mIYUWoFJII00coFJII00?o0000od2o@?m0_d000om0_d03
o`0000coEZUF00?o0000od:m@_m2_D803?m2_D82o`0000;oKY5^00?o0000ogj1O_mnPGh03?mnPGh0
0ol0003o/dbcok=</`05ok=</`03o`000?oW6>OoiaSW00OoiaSW00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oj=LXonSG:<01_nSG:<00ol0003o@;m0od2o@007od2o
@003o`000?lka3_o000000[o5>/D00Co0000o`Ki1_l6n@Ko00002_l4n`@00ol0003oFJIIoeVVF@0<
oeVVF@03o`000?m0_d3o@;m000Ko@;m00_l00008oeJYEP;o00003om2_D800ol0003oKY5^ofjAKP02
ofjAKP03o`000?mnPGkoOX5n00_oOX5n00?o0000ok=</oncC;<01OncC;<00ol0003oiaSWonLHi`07
onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ohAkQon4Nh@0:on4Nh@03o`000?nSG:?oXebS
00KoXebS00?o0000od2o@?m0_d001_m0_d001Ol0003o>l@koc_4>olka3_o000000So5>/D00?o0000
o`Ki1_l6n@H00_l6n@H00ol0003o1?/4o`Ck1006o`Ck10Co00003?mIYUT00ol0003o@;m0od2o@008
od2o@0?o00000_mFZEH3o`000003ocW6>Ol0003o@[e200go@[e200?o0000ofjAK_m^TFh01?m^TFh0
0ol0003oOX5nogj1OP0:ogj1OP03o`000?ncC;?o/dbc00Go/dbc00?o0000onLHiooW6>L01_oW6>L0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000on4NhOoQ7^402ooQ7^400ol0003oXebSoj=LX`07oj=L
X`03o`000?m0_d3o@;m000?o@;m00_l00005oc_4>`03o`000?lDjaCo5>/D00Co5>/D00?o0000o`Ki
1_l6n@H00ol6n@H00ol0003o1?/4o`Ck1005o`Ck1003o`000?lMhQgo7N8M00;o7N8M0ol00007oeVV
F@;o00003_m0_d02o`0000Go>LHi00?o0000od:m@_m2_D802_m2_D800ol0003oKY5^ofjAKP05ofjA
KP03o`000?mnPGkoOX5n00_oOX5n00?o0000ok=</oncC;<01?ncC;<00ol0003oiaSWonLHi`06onLH
i`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ohAkQon4Nh@0;on4Nh@03o`000?nSG:?oXebS00Oo
XebS00?o0000od2o@?m0_d000_m0_d000ol0003o>l@koc_4>`06oc_4>`03o`000?lDjaCo5>/D00;o
5>/D00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o1?/4o`Ck1002o`Ck10;o00002?lMhQd3o`0000;o
FJII0_l000000olVfBKo0000od2o@00=od2o@003o`000?liaSWo>LHi00Go>LHi00?o0000od:m@_m2
_D802?m2_D800ol0003oKY5^ofjAKP07ofjAKP03o`000?mnPGkoOX5n00[oOX5n00?o0000ok=</onc
C;<01?ncC;<00ol0003oiaSWonLHi`06onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ohAkQ
on4Nh@0<on4Nh@03o`000?nSG:?oXebS00SoXebS00Co0000od2o@?m0_d3o00002Olka3/01Ol0003o
5>/DoaC[5?lDjaCo000000So1_T600Go0000o`Ck1?l4n`Co1?/4o`00000=oagR7@;o00001?lVfBH0
0ol0003o@;m0od2o@00;od2o@003o`000?liaSWo>LHi00Ko>LHi00?o0000od:m@_m2_D801om2_D80
0ol0003oKY5^ofjAKP08ofjAKPCo00002?mnPGh00ol0003o/dbcok=</`04ok=</`03o`000?oW6>Oo
iaSW00KoiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oQ7^7ohAkQ00_ohAkQ0ol00009oj=L
X`03o`000?m0_d3o000000_o>l@k00?o0000oaC[5?l000002_l6n@H00ol0003o1?/4o`00000?oagR
7@03o`000?lVfBKo9]TV00;o9]TV00?o0000od2o@?m0_d002om0_d000ol0003o>LHiocW6>@06ocW6
>@03o`000?m2_D;o@[e200Ko@[e200?o0000ofjAK_m^TFh02Om^TFh01?l0003oXEjQoj5NXOnQGZ47
o`0000;oOX5n00?o0000ok=</oncC;<00oncC;<00ol0003oiaSWonLHi`05onLHi`03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oQ7^7ohAkQ00SohAkQ0ol00003omPWf003o`000?nSG:?oXebS00OoXebS00?o0000oc_4
>olka3/02olka3/00ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?lMhQgo7N8M00go7N8M00?o0000obKI
9_lVfBH01?lVfBH00ol0003o@;m0od2o@009od2o@003o`000?liaSWo>LHi00So>LHi00?o0000od:m
@_m2_D800om2_D82o`0000coKY5^00?o0000oj5NXOnQGZ402?nQGZ4<o`0000?oiaSW0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on4NhOoQ7^401_oQ7^43o`0000Oof2OH00?o0000oj=LXonSG:<01_nSG:<00ol0003o
>l@koc_4>`0;oc_4>`03o`000?l6n@Ko1_T600Wo1_T60_l0000>oagR7@03o`000?lVfBKo9]TV00Go
9]TV00?o0000od2o@?m0_d002Om0_d000ol0003o>LHiocW6>@09ocW6>@03o`000?m2_D;o000000;o
00000_mTVf@00ol0003oKY5^ofjAKP08ofjAKP03o`000?nQGZ7oXEjQ00coXEjQ00?o0000on<LhooS
7><01_oS7><3o`0000?oo0?l0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ohAkQon4Nh@03on4Nh@?o00002ooH9mP00ol0003oXebS
oj=LX`04oj=LX`03o`000?lka3_o>l@k00_o>l@k0ol00007o`Ki1P?o000000?o5nPGo`000?lMhQd0
3OlMhQd00ol0003o9]TVobKI9P06obKI9P03o`000?m0_d3o@;m000So@;m000?o0000ocW6>OliaST0
2_liaST00ol0003oI9]TofBKI004ofBKI003o`000?m^TFkoKY5^00OoKY5^00?o0000oj5NXOnQGZ40
2onQGZ400ol0003ohacSon<Lh`08on<Lh`03o`000?ol0ocoo0?l00Coo0?l0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004on4NhOl0
003o0000o`0000oof2OH00?o0000oj=LXonSG:<00onSG:<>o`0000?o;]4^0_l00002o`Ki1P?o0000
1OlGj1L00ol0003o7N8MoagR7@0:oagR7@03o`000?lVfBKo9]TV00Oo9]TV00?o0000od2o@?m0_d00
2?m0_d000ol0003o>LHiocW6>@0:ocW6>@03o`000?mTVfCoI9]T00GoI9]T00?o0000ofjAK_m^TFh0
1_m^TFh00ol0003oXEjQoj5NX@0;oj5NX@03o`000?oS7>?ohacS00SohacS00?o0000oo`3o?ol0o`0
1ool0o`2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;of2OH00?o0000oj=LXonSG:<00_nSG:<00ol0003oNHIiogV6
N@0:ogV6N@03o`000?l^dBko;]4^00?o;]4^0_l00009oaOX5`03o`000?lMhQgo7N8M00Wo7N8M00?o
0000obKI9_lVfBH02?lVfBH2o`0000So@;m000?o0000ocW6>OliaST02OliaST00ol0003oI9]TofBK
I007ofBKI003o`000?m^TFkoKY5^00CoKY5^00?o0000oj5NXOnQGZ402onQGZ400ol0003ohacSon<L
h`09on<Lh`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003of2OHomPWf00?omPWf0?o000000?oXebS
o`000?miQWT02omiQWT00ol0003o;]4^obkA;P04obkA;P03o`000?lGj1Oo5nPG00Wo5nPG00?o0000
oagR7OlMhQd01olMhQd00ol0003o9]TVobKI9P09obKI9P04o`000?lUfRGo0000o`0000Ko@;m000?o
0000ocW6>OliaST02OliaST00ol0003oI9]TofBKI008ofBKI003o`000?m^TFkoKY5^00?oKY5^00?o
0000oj5NXOnQGZ402onQGZ400ol0003ohacSon<Lh`09on<Lh`03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003of2OHomPWf00<omPWf0;o00000ooD:m@2o`0000coNHIi00?o0000obkA;_l^dBh01?l^dBh0
0ol0003o5nPGoaOX5`0:oaOX5`Wo00002olVfBH00ol0003o9MXUobGJ9@02obGJ9@?o00000_m0_d00
0ol0003o>LHiocW6>@0:ocW6>@03o`000?mTVfCoI9]T00WoI9]T00?o0000ofjAK_m^TFh00_m^TFh0
0ol0003oXEjQoj5NX@0:oj5NX@03o`000?oS7>?ohacS00WohacS00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oH9mP2o`0000Goe2_D00?o0000oimOWol000002_miQWT00ol0003o;]4^obkA;P06obkA
;P03o`000?lGj1Oo5nPG00Wo5nPG00?o0000oa;]4_lBkA801OlBkA800ol0003o9]TVobKI9P09obKI
9P03o`000?lUfRGo9MXU00Go9MXU0ol00009ocW6>@?o00003OmTVf@01Ol0003oKY5^ofjAK_m^TFko
000000coXEjQ00?o0000on<LhooS7><02OoS7><00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omPW
f?oH9mP01OoH9mP2o`0000Ooe2_D00Co0000oimOWonOGioo00002OmiQWT00ol0003o;]4^obkA;P06
obkA;P03o`000?lGj1Oo5nPG00So5nPG00?o0000oa;]4_lBkA801olBkA800ol0003o9]TVobKI9P07
obKI9P03o`000?lUfRGo9MXU00So9MXU0ol00002ocW6>@Go00000_lka3/00ol0003oI9]TofBKI00<
ofBKI003o`000?m^TFko000000coXEjQ00?o0000on<LhooS7><02_oS7><00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000omPWf?oH9mP00_oH9mP2o`0000Soe2_D00?o0000oimOWonOGil00_nOGil5o`00
00CoNHIi00?o0000obkA;_l^dBh01_l^dBh00ol0003o5nPGoaOX5`08oaOX5`03o`000?lBkA;o4^dB
00Oo4^dB00?o0000obKI9_lVfBH01olVfBH00ol0003o9MXUobGJ9@08obGJ9@03o`000?lKi1_o6n@K
00;o00002?lka3/00ol0003oI9]TofBKI00<ofBKI0Co00002_nQGZ400ol0003ohacSon<Lh`0:on<L
h`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003of2OHo`000?l0000:om@[e003o`000?nOGiooWenO
00;oWenO00?o0000odn`Com?/4l00_m?/4l4o`0000Wo;]4^00?o0000oaOX5olGj1L02?lGj1L00ol0
003o4^dBoa;]4P08oa;]4P03o`000?lVfBKo9]TV00Go9]TV00?o0000obGJ9OlUfRD02?lUfRD01Ol0
003o6n@Koa_T6olKi1_o000000[o>l@k0ol0000;ofBKI004o`000?o@;m3od2o@om0_d0Co00001OnQ
GZ400ol0003ohacSon<Lh`0;on<Lh`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003oe2_Dom@[e00:
om@[e003o`000?nOGiooWenO00?oWenO00?o0000odn`Com?/4l01?m?/4l00ol0003o;]4^obkA;P07
obkA;P03o`000?lGj1Oo5nPG00Ko5nPG0_l0000;oa;]4P03o`000?lVfBKo9]TV00Go9]TV00?o0000
obGJ9OlUfRD02?lUfRD00ol0003o6n@Koa_T6`02oa_T6`03o`000?lka3_o>l@k00Oo>l@k00?o0000
ohiaS_n>LHh01?l00006ofBKI003o`000?o@;m3od2o@00Kod2o@0ol00002oj5NX@03o`000?oS7>?o
hacS00_ohacS00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oD:mCoe2_D00Woe2_D00?o0000oimO
WonOGil01?nOGil00ol0003oCk1?odn`C`05odn`C`03o`000?l^dBko;]4^00Oo;]4^00?o0000oaOX
5olGj1L00_lGj1L3o`000003obGJ9Ol0003o4^dB00[o4^dB00?o0000obKI9_lVfBH01OlVfBH00ol0
003o9MXUobGJ9@07obGJ9@03o`000?lKi1_o6n@K00?o6n@K00?o0000oc_4>olka3/01olka3/00ol0
003oSW6>ohiaSP04ohiaSP?o00000_mTVf@00ol0003od2o@om0_d00:om0_d0;o00003_oS7><00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000om@[e?oD:m@02OoD:m@00ol0003oWenOoimOW`04oimOW`03
o`000?m?/4ooCk1?00KoCk1?0_l00007obkA;P03o`000?lGj1Oo000000;o00001OlUfRD00ol0003o
4^dBoa;]4P08oa;]4P?o00001?lVfBH00ol0003o9MXUobGJ9@08obGJ9@03o`000?lKi1_o6n@K00Co
6n@K00?o0000oc_4>olka3/01_lka3/00ol0003oSW6>ohiaSP07ohiaSP;o00003_o@;m000ol0003o
hacSon<Lh`0;on<Lh`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003oe2_Dom@[e008om@[e003o`00
0?nOGiooWenO00GoWenO00?o0000odn`Com?/4l01?m?/4l00ol0003oEJYEoeFZE@03o`0000Co;]4^
0_l00008obGJ9@03o`000?lBkA;o4^dB00Oo4^dB00Co0000odFjAOm5^TGoAKY50ol000000olVfBKo
0000obGJ9@09obGJ9@03o`000?lKi1_o6n@K00Co6n@K00?o0000oc_4>olka3/01Olka3/00ol0003o
SW6>ohiaSP09ohiaSP03o`000?o@;m3od2o@00god2o@00?o0000on<LhooS7><02_oS7><00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000om@[e?oD:m@01ooD:m@00ol0003oWenOoimOW`06oimOW`03o`00
0?m?/4ooCk1?00?oCk1?00?o0000oeFZEOmEZUD01?mEZUD2o`000003obkA;_l0003o9MXU00[o9MXU
00?o0000oa;]4_lBkA801OlBkA800ol0003oAKY5odFjA@05odFjA@03o`000?lUfRGo9MXU00Oo9MXU
0ol00007oa_T6`03o`000?lka3_o>l@k00Co>l@k00?o0000ohiaS_n>LHh02On>LHh00ol0003od2o@
om0_d00=om0_d003o`000?oS7>?ohacS00[ohacS00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oD
:mCoe2_D00Goe2_D0ol00009oimOW`05o`000?m?/4ooCk1?odn`Col000002OmEZUD00ol0003o9MXU
obGJ9@0;obGJ9@03o`000?lBkA;o4^dB00?o4^dB00?o0000odFjAOm5^TD01_m5^TD00ol0003o9MXU
obGJ9@06obGJ9@05o`000?lgb3Oo=lPgocO8=ol000001olKi1/00ol0003o>l@koc_4>`03oc_4>`03
o`000?n>LHkoSW6>00WoSW6>00?o0000om0_d?o@;m003_o@;m000ol0003ohacSon<Lh`09on<Lh`03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003oe2_Do`000004o`0000;oi1_T00?o0000oimOWonOGil0
1onOGil01?l0003oCk1?odn`Col00009oeFZE@;o00003OlUfRD00ol0003o4^dBoa;]4P02oa;]4P03
o`000?m5^TGoAKY500SoAKY500?o0000obGJ9OlUfRD00olUfRD2o`0000Go=lPg00?o0000oa_T6olK
i1/01?lKi1/00ol0003o>l@koc_4>`03oc_4>`03o`000?n>LHkoSW6>00WoSW6>00?o0000om0_d?o@
;m003_o@;m000ol0003ohacSon<Lh`09on<Lh`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000Soi1_T
00?o0000oimOWonOGil01_nOGil00ol0003oCk1?o`000009oeFZE@04o`000?m>/DkoC[5>o`0000go
9MXU00Co0000oa;]4_lBkA;o00003?m5^TD01Ol0003o9MXUobGJ9OlUfRGo000000So=lPg0_l00005
oa_T6`03o`000?lka3_o>l@k00;o>l@k00?o0000ohiaS_n>LHh02On>LHh00ol0003od2o@om0_d00>
om0_d003o`000?oS7>?ohacS00WohacS00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oT6nCoi1_T
00Ooi1_T00?o0000oimOWonOGil01onOGil00ol0003oEJYEoeFZE@07oeFZE@03o`000?m>/DkoC[5>
00;oC[5>00?o0000obGJ9OlUfRD02_lUfRD00ol0003o4^dBo`00000>odFjA@03o`000?lUfRGo0000
00_o=lPg00?o0000oa_T6olKi1/00_lKi1/01Ol0003o>l@koc_4>olka3_o000000coSW6>00?o0000
om0_d?o@;m003_o@;m03o`0000WohacS00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oT6nCoi1_T
00Woi1_T00?o0000oimOWonOGil01_nOGil00ol0003oEJYEoeFZE@06oeFZE@03o`000?m>/DkoC[5>
00?oC[5>00?o0000obGJ9OlUfRD02olUfRD00ol0003oAKY5odFjA@0>odFjA@03o`000?lgb3Oo=lPg
00_o=lPg0_l00003oa_T6`04o`000?lka3_o>l@ko`0000[oSW6>0ol0000>om0_d0;o00000ook1?/2
o`0000OohacS00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oT6nCoi1_T00[oi1_T00?o0000oimO
WonOGil01?nOGil00ol0003oEJYEoeFZE@06oeFZE@03o`000?m>/DkoC[5>00GoC[5>00?o0000obGJ
9OlUfRD01olUfRD3o`00017oAKY500?o0000ocO8=olgb3L03Olgb3L01Ol0003o6n@Koa_T6ol0003o
>l@k00Co00000on>LHh5o`0000;ofRGJ00?o0000om0_d?o@;m002_o@;m02o`0000Oon`Ck0_l00004
on<Lh`03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oi1_Ton@Ki00;on@Ki003o`000?nOGiooWenO
00CoWenO00?o0000oeFZEOmEZUD01OmEZUD00ol0003oC[5>odjaCP06odjaCP03o`000?lUfRGo9MXU
00Co9MXU0ol00002obo@;`03o`000?m5^TGoAKY500ooAKY50_l0000?ocO8=`04o`000?lKi1_o0000
o`0000CoN8Mh0ol00008omXUfP03o`000?o@;m3od2o@00Ood2o@0_l0000;oo/4n`;o00000_oS7><0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000on@Ki?oT6n@03?oT6n@6o`0000OoEJYE00?o0000odja
C_m>/Dh02?m>/Dh00ol0003o9MXUobGJ9@03o`0000Ko;m0_00?o0000odFjAOm5^TD03Om5^TD01?l0
003oAkQ7odNhAol0000?ocO8=`03o`000?mhQgSoN8Mh00GoN8Mh00?o0000omXUf_oJ9MX02?oJ9MX0
0ol0003od2o@om0_d005om0_d003o`000?ok1?_on`Ck00gon`Ck0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oT6n@00ol0003oYeRWojMHY`04ojMH
Y`03o`000?mEZUGoEJYE00?oEJYE00?o0000odjaC_m>/Dh02_m>/Dh2o`0000[o;m0_00?o0000odFj
AOm5^TD02om5^TD00ol0003oAkQ7odNhA`02odNhA`03o`000?lgb3Oo=lPg00_o=lPg0_l00007ogR7
N003o`000?oJ9M[ofRGJ00WofRGJ00?o0000om0_d?o@;m000_o@;m02o`0001;on`Ck00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000on@Ki?oT6n@02ooT6n@00ol0003oYeRWojMHY`06ojMHY`05o`000?mEZUGoEJYEoeFZ
EOl000003Om>/Dh00ol0003o;m0_obo@;`0:obo@;`03o`000?m5^TGoAKY500WoAKY500?o0000odNh
Aom7^4L01?m7^4L00ol0003o=lPgocO8=`08ocO8=`;o000000?o;]4^o`000?mhQgP01omhQgP00ol0
003ofRGJomXUfP09omXUfP04o`000?o@;m3o0000o`0001Con`Ck00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oT6nCoi1_T
00Woi1_T00?o0000ojMHYonWF:L02?nWF:L00ol0003oEJYEo`00000=odjaCP03o`000?l_d2oo;m0_
00_o;m0_00?o0000odFjAOm5^TD02?m5^TD00ol0003oAkQ7odNhA`06odNhA`03o`000?lgb3Oo=lPg
00Go=lPg0_l00003obkA;P03o`000?mhQgSoN8Mh00KoN8Mh00?o0000omXUf_oJ9MX02_oJ9MX00ol0
003on`Ckoo/4n`0Eoo/4n`;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003oi1_Ton@Ki007on@Ki003o`000?nWF:OoYeRW00[oYeRW00?o0000odjaC_m>
/Dh03?m>/Dh00ol0003o;m0_obo@;`0<obo@;`03o`000?m5^TGoAKY500KoAKY500?o0000odNhAom7
^4L02?m7^4L00ol0003o=lPgocO8=`02ocO8=`;o00001_l^dBh00ol0003oN8MhogR7N005ogR7N003
o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oo/4nook1?/05Ook1?/00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oT6nCoi1_T00Goi1_T
00?o0000ojMHYonWF:L03?nWF:L2o`0000coC[5>00?o0000obo@;ol_d2l03Ol_d2l00ol0003oAKY5
odFjA@04odFjA@03o`000?m7^4OoAkQ700[oAkQ700Co0000ocO8=ol0003o00002?l^dBh00ol0003o
N8MhogR7N006ogR7N003o`000?oJ9M[ofRGJ00WofRGJ00?o0000oo/4nook1?/05Ook1?/00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oT6n@00ol0003oYeRWojMHY`0=ojMHY`03o`000?mNXEko000000;o00002?m>/Dh00ol0003o;m0_
obo@;`0?obo@;`Ko00003_m7^4L00ol0003o;]4^obkA;P08obkA;P03o`000?mhQgSoN8Mh00KoN8Mh
00?o0000omXUf_oJ9MX02OoJ9MX00ol0003on`Ckoo/4n`0Doo/4n`03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onHIi_oV6NKoiQWV
0_l0000?ojMHY`03o`000?mNXEkoGZ5N00?oGZ5N0ol00005odjaCP;o00004?l_d2l01_l0003o7^4N
oakQ7_l0003o2o@;o`0000koAkQ700?o0000obkA;_l^dBh02Ol^dBh00ol0003oN8MhogR7N005ogR7
N003o`000?oJ9M[ofRGJ00WofRGJ00?o0000oo/4nook1?/04ook1?/2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onHIi_oV6NH00ooV6NH00ol0003o
YeRWojMHY`0=ojMHY`03o`000?mNXEkoGZ5N00KoGZ5N0ol000001?m>/Dko0000obkA;_l^dBh3o`00
00co;m0_00Go0000oakQ7_lNhAko7^4No`000002o`_d2`03o`000?m7^4OoAkQ700_oAkQ700?o0000
obkA;_l^dBh02Ol^dBh00ol0003oN8MhogR7N006ogR7N003o`000?oJ9M[ofRGJ00SofRGJ0_l0000A
oo/4n`?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003oiQWVonHIiP04onHIiPoo00003?mNXEh00ol0003o;]4^obkA;P04obkA
;P?o00002?l_d2l00ol0003o7^4NoakQ7P02oakQ7P05o`000?l;m0_o2o@;o`_d2ol000003?m7^4L0
0ol0003o;]4^obkA;P09obkA;P03o`000?mhQgSoN8Mh00GoN8Mh3?l00002onl@k`;o00003Ook1?/2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oiQWVonHIiP05onHIiP03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000oejQ
G_mNXEh02_mNXEh00ol0003o;]4^obkA;P07obkA;P;o00001Ol_d2l00ol0003o7^4NoakQ7P03oakQ
7P03o`000?l;m0_o2o@;00;o2o@;00?o0000odNhAom7^4L02Om7^4L00ol0003o;]4^obkA;P0:obkA
;P03o`000?mhQgSoN8Mh00?oN8Mh00?o0000ol8m`_o2?L802Oo2?L800ol0003oka3_onl@k`02onl@
k`;o00002Ook1?/2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiQWVonHIiP06onHIiP03o`000?nQGZ7oXEjQ00[o
XEjQ00?o0000oejQG_mNXEh02omNXEh00ol0003o;]4^obkA;P09obkA;P?o000000?o;m0_o`000?lN
hAh01OlNhAh00ol0003o2o@;o`_d2`03o`_d2`03o`000?m7^4OoAkQ700SoAkQ73_l00003ogR7N0;o
00002oo2?L800ol0003oka3_onl@k`05onl@k`03o`000?ok1?_on`Ck00?on`Ck0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onHIi_oV6NH01OoV6NH00ol0003o/Tfbo`00000;oj5NX@03o`000?mNXEkoGZ5N00[oGZ5N
0_l0000>obkA;P03o`000?lNhAko7^4N00Go7^4N00?o0000o`_d2ol;m0/00ol;m0/00ol0003oAkQ7
odNhA`08odNhA`03o`000?meRWGoMHYe00_oMHYe00?o0000ogR7N?l000003Oo2?L800ol0003oka3_
onl@k`06onl@k`;o000000?on`Cko`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oV6NKoiQWV00KoiQWV00Co
0000ok9=/_nbCK;o00002_nQGZ400ol0003oGZ5NoejQGP09oejQGP03o`000?ln`Cko000000ko;]4^
00?o0000oakQ7_lNhAh01OlNhAh00ol0003o2o@;o`_d2`04o`_d2`03o`000?m7^4OoAkQ700KoAkQ7
00?o0000ogF:MOmeRWD03OmeRWD00ol0003o`Sg2ol8m`P0<ol8m`P03o`000?o_4>ooka3_00Soka3_
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oV6NKoiQWV00GoiQWV00?o0000ok9=/_nbCK800_nb
CK800ol0003oXEjQoj5NX@06oj5NX@03o`000?mNXEkoGZ5N00SoGZ5N0_l00003ock1?P03o`000?l^
dBko;]4^00_o;]4^00?o0000oakQ7_lNhAh01OlNhAh00ol0003o2o@;o`_d2`05o`_d2`03o`000?m7
^4OoAkQ700GoAkQ700?o0000ogF:MOmeRWD03OmeRWD00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?o_
4>ooka3_00Woka3_00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oV6NKoiQWV00KoiQWV00?o0000
ok9=/_nbCK800onbCK800ol0003oXEjQoj5NX@05oj5NX@03o`000?mNXEkoGZ5N00OoGZ5N00?o0000
ock1?_ln`Ch00oln`Ch00ol0003o;]4^obkA;P0:obkA;P03o`000?lNhAko7^4N00Ko7^4N00?o0000
o`_d2ol;m0/01_l;m0/00ol0003oAkQ7odNhA`04odNhA`03o`000?meRWGoMHYe00goMHYe3ol0000;
onl@k`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oV6NKoiQWV00KoiQWV00?o0000ok9=/_nbCK801OnbCK800ol0
003oXEjQoj5NX@04oj5NX@03o`000?mNXEkoGZ5N00GoGZ5N0_l00006ock1?P03o`000?l^dBko;]4^
00Wo;]4^0_l00008oakQ7P03o`000?l;m0_o2o@;00Ko2o@;1Ol000000om7^4Oo0000ogF:M@0?ogF:
M@03o`000?o3?<?o`cc300_o`cc300?o0000onl@koo_4>l02Oo_4>l00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?oV6NKoiQWV00KoiQWV00?o0000ok9=/_nbCK801_nbCK800ol0003o
XEjQoj5NX@04o`0000KoGZ5N00?o0000ock1?_ln`Ch01oln`Ch00ol0003o;]4^obkA;P05obkA;P?o
000000?o6>LHo`000?lNhAh01olNhAh00ol0003o2o@;o`_d2`05o`_d2`03o`000?m>/DkoC[5>00?o
C[5>0_l0000?ogF:M@;o00003Oo3?<<00ol0003oka3_onl@k`08onl@k`03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WoiQWV00?o0000ok9=/_nbCK801onbCK82o`0000CoU6^D00Co0000oejQG_mNXEko
GZ5N0_l0000:ock1?P03o`000?l^dBko;]4^00;o;]4^0ol00005oaSW6003o`000?lNhAko7^4N00Go
7^4N00?o0000o`_d2ol;m0/01?l;m0/00ol0003oC[5>odjaCP06odjaCP03o`000?meRWGoMHYe00[o
MHYe0_l00002oiiQWP03o`000?o3?<?o`cc300[o`cc300?o0000onl@koo_4>l02?o_4>l00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onHIi_oV6NH01_oV6NH00ol0003o/Tfbok9=/P08ok9=/P03o`00
0?nDJiCoU6^D00CoU6^D00?o0000oejQG_l000003?ln`Ch00ol0003o;]4^o`000002o`0000Wo6>LH
00?o0000oakQ7_lNhAh01?lNhAh00ol0003o2o@;o`_d2`03o`_d2`03o`000?m>/DkoC[5>00SoC[5>
1_l00004ogF:M@;o00001OnNHIh00ol0003o`cc3ol<l``09ol<l``03o`000?o_4>ooka3_00Soka3_
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?oV6NKoiQWV00GoiQWV00?o0000ok9=/_nbCK801onb
CK800ol0003oU6^DoiA[U006oiA[U003o`000?ln`Cko?/4n00co?/4n00?o0000oaSW6?lHiaP02_lH
iaP00ol0003o7^4NoakQ7P04oakQ7P04o`000?l;m0_o2o@;o`_d2`;o00002om>/Dh00ol0003oOX5n
ogj1OP03ogj1OPCo00002?nNHIh00ol0003o`cc3ol<l``08ol<l``03o`000?o_4>ooka3_00Ooka3_
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onHIi_oV6NH00ooV6NH00ol0003o/Tfbok9=/P07ok9=/P03o`000?nD
JiCoU6^D00OoU6^D00?o0000ock1?_ln`Ch03?ln`Ch00ol0003o6>LHoaSW600;oaSW6003o`000?lN
hAko7^4N00?o7^4N00Co0000o`_d2ol;m0_o00003Om>/Dh00ol0003oOX5nogj1OP06ogj1OP03o`00
0?nNHIkoWV6N00OoWV6N00?o0000ol<l`oo3?<<01oo3?<<00ol0003oka3_onl@k`06onl@k`04o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oV6NKoiQWV00;oiQWV00?o0000ok9=/_nbCK80
1_nbCK800ol0003oU6^DoiA[U009oiA[U003o`000?ln`Cko?/4n00Wo?/4n0_l0000>oaSW60?o0000
0olNhAh00ol0003o2o@;o`00000=odjaCP03o`000?mnPGkoOX5n00OoOX5n00?o0000oiiQW_nNHIh0
2?nNHIh:o`0000Koka3_0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo/Tfb00?o
0000oiA[U?nDJi@02_nDJi@00ol0003o?/4nock1?P06ock1?P;o000000?o=lPgo`000?lHiaP02olH
iaP2o`0000?oAKY51Ol0000>odjaCP03o`000?mnPGkoOX5n00OoOX5n00?o0000oiiQW_nNHIh02?nN
HIh00ol0003odbcCom</d`06om</d`03o`000?o_4>ooka3_00?oka3_00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ofRGJomXUfP03omXUfPCo00000_nbCK800ol0003oU6^DoiA[U00;
oiA[U003o`000?ln`Cko?/4n00?o?/4n0ol00004ocO8=`03o`000?lHiaSo6>LH00Oo6>LH0_l00008
odFjA@03o`000?m>/DkoC[5>00goC[5>00?o0000ogj1O_mnPGh02?mnPGh00ol0003oWV6NoiiQWP07
oiiQWP03o`000?oC;=?odbcC00OodbcC0ol000000oo_4>oo0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oJ9M[ofRGJ00OofRGJ0_l0000?oiA[U003o`000?ln`Cko?/4n00;o00002?lgb3L00ol0
003o6>LHoaSW6005oaSW6003o`000?m5^TGoAKY500SoAKY500?o0000odjaC_m>/Dh03Om>/Dh00ol0
003oOX5nogj1OP08ogj1OP03o`000?nNHIkoWV6N00KoWV6N00?o0000om</dooC;=<02?oC;=<01?l0
003ol0o`oo0?l?l0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ofRGJomXUfP09omXU
fP03o`000?nDJiCoU6^D00koU6^D0_l0000;ocO8=`03o`000?lHiaSo6>LH00;o6>LH0_l0000;odFj
A@03o`000?m>/DkoC[5>00goC[5>00?o0000ogj1O_mnPGh02?mnPGh00ol0003oWV6NoiiQWP06oiiQ
WP03o`000?oC;=?odbcC00OodbcC00Go0000oo0?l?o`3o3ol0o`o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ofRGJomXUfP0:omXUfP03o`000?nDJiCoU6^D00goU6^D0_l0000<ocO8=`04o`000?lHiaSo0000
o`0000goAKY500?o0000odjaC_m>/Dh03?m>/Dh00ol0003oOX5nogj1OP09ogj1OP03o`000?nNHIko
WV6N00KoWV6N00?o0000om</dooC;=<01_oC;=<00ol0003ol0o`oo0?l003oo0?l003o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ofRGJomXUfP0:omXUfP03o`000?nDJiCoU6^D00coU6^D00Co0000oeNX
EomGZ5Oo00003?lgb3L00ol0003oAKY5odFjA@0>odFjA@03o`000?m>/DkoC[5>00SoC[5>1?l0000;
ogj1OP03o`000?nNHIkoWV6N00KoWV6N00?o0000om</dooC;=<01OoC;=<00ol0003ol0o`oo0?l004
oo0?l003o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ofRGJomXUfP0;omXUfP03o`000?nDJiCoU6^D
00_oU6^D00?o0000oeNXEomGZ5L00_mGZ5L00ol0003o=lPgocO8=`09ocO8=`03o`000?m5^TGoAKY5
00koAKY500Co0000odjaC_m>/DkoC[5>1ol00003oefRG@03o`000?mnPGkoOX5n00WoOX5n00?o0000
oiiQW_nNHIh01_nNHIh00ol0003odbcCom</d`04om</d`03o`000?o`3o3ol0o`00Kol0o`00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oJ9M[ofRGJ00cofRGJ00?o0000oiA[U?nDJi@02_nDJi@00ol0
003oEjQGoeNXE`03oeNXE`03o`000?lgb3Oo=lPg00So=lPg00?o0000odFjAOm5^TD03_m5^TD4o`00
00_oGJ9M00?o0000ogj1O_mnPGh02?mnPGh00ol0003oWV6NoiiQWP05oiiQWP03o`000?oC;=?odbcC
00GodbcC00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000omXUf_oJ
9MX03?oJ9MX7o`0000GoU6^D00?o0000oeNXEomGZ5L01OmGZ5L00ol0003o=lPgocO8=`07ocO8=`03
o`000?m5^TGoAKY500koAKY500?o0000oefRGOmMXUd03OmMXUd00ol0003oOX5nogj1OP08ogj1OP03
o`000?nNHIkoWV6N00CoWV6N00?o0000om</dooC;=<01?oC;=<00ol0003ol0o`oo0?l007oo0?l003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ofRGJomXUfP0=omXUfP03o`000?nbCK;o/Tfb00Co/Tfb
1Ol00009oeNXE`03o`000?lgb3Oo=lPg00Ko=lPg00?o0000odFjAOm5^TD03_m5^TD00ol0003oGJ9M
oefRG@0=oefRG@03o`000?mnPGkoOX5n00SoOX5n00Co0000oiiQW_nNHIkoWV6N1Ol00004om</d`03
o`000?o`3o3ol0o`00Wol0o`1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=omXUfP03o`000?nbCK;o/Tfb00Wo/Tfb
0_l00009oeNXE`03o`000?lgb3Oo=lPg00Ko=lPg00?o0000odFjAOm5^TD03?m5^TD00ol0003oGJ9M
oefRG@0?oefRG@Ko00001?mnPGh4o`0000GodRgB0_l000000ooC;=?o0000oo0?l00;oo0?l004o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?oZ5N[ojQGZonXEjP?o00002_oJ9MX00ol0003o
/Tfbok9=/P09ok9=/P03o`000?m]TVgo000000;o00001omGZ5L00ol0003o=lPgocO8=`05ocO8=`03
o`000?m5^TGoAKY500SoAKY51Ol0000AoefRG@03o`000?n=LXgoSG:=00?oSG:=1?l0000;om8]dP03
o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000onXEj_oZ5NX01OoZ5NX2o`0000OofRGJ
00?o0000ok9=/_nbCK802_nbCK800ol0003oKI9]offBK@02offBK@?o00001OmGZ5L00ol0003o=lPg
ocO8=`04ocO8=`04o`000?m5^TGoAKY5odFjA@Oo00001?m3_4<00ol0003oGJ9MoefRG@0>oefRG@03
o`000?n=LXgoSG:=00OoSG:=00?o0000om8]d_oB;M802OoB;M800ol0003ol0o`oo0?l009oo0?l003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ojQGZonXEjP08onXEjP;o00001?oJ9MX00ol0003o/Tfb
ok9=/P0;ok9=/P03o`000?m]TVgoKI9]00GoKI9]0ol00003oeNXE`04o`000?lgb3Oo=lPgocO8=`Ko
00003?m3_4<00ol0003oGJ9MoefRG@0=oefRG@03o`000?n=LXgoSG:=00OoSG:=00?o0000om8]d_oB
;M802_oB;M800ol0003ol0o`oo0?l008oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onXEjP?o000000?ofRGJo`000?nbCK80
3?nbCK800ol0003oKI9]offBK@08offBK@?o000000CoEjQGo`000?l0003o00000_n5NXD00ol0003o
@ka3od>l@`0=od>l@`03o`000?mMXUgoGJ9M00coGJ9M00?o0000ohebSOn=LXd02?n=LXd00ol0003o
dRgBom8]dP0;om8]dP03o`000?o`3o3ol0o`00Kol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
jQGZ00?o0000ok9=/_nbCK803?nbCK800ol0003oKI9]offBK@0;offBK@03o`000?n5NXGoQGZ500?o
QGZ500?o0000od>l@om3_4<03?m3_4<00ol0003o>/Djo`00000=oefRG@03o`000?n=LXgoSG:=00So
SG:=00?o0000om8]d_oB;M803?oB;M83o`0000Gol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?oZ5N[ojQGZ00cojQGZ00?o0000ok9=/_nbCK803?nbCK800ol0003oKI9]offBK@0:offBK@03o`00
0?n5NXGoQGZ500GoQGZ500?o0000od>l@om3_4<02_m3_4<01?l0003o>/Djoc[5>_ljaCX2o`0000[o
GJ9M00?o0000ohebSOn=LXd02On=LXd00ol0003odRgBom8]dP0<om8]dP03o`000?ob3O;olPgb00?o
000000?ol0o`o`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ok9=/_nbCK80
3?nbCK800ol0003oKI9]offBK@09offBK@03o`000?n5NXGoQGZ500KoQGZ500?o0000od>l@om3_4<0
2Om3_4<00ol0003o>/Djoc[5>P02oc[5>P03o`000?n4NhCo000000;o00001omMXUd00ol0003oSG:=
ohebS@09ohebS@03o`000?oB;M;odRgB00_odRgB00?o0000oo8=l_ob3O801?ob3O800ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000onXEj_oZ5NX02ooZ5NX00ol0003o/Tfbok9=/P0;ok9=/P03o`000?m]
TVgoKI9]00SoKI9]00?o0000ohEjQOn5NXD01on5NXD00ol0003o@ka3od>l@`08od>l@`03o`000?lj
aC[o>/Dj00?o>/Dj00?o0000ohAkQ?n4Nh@00_n4Nh@2o`0000CoGJ9M00?o0000ohebSOn=LXd02_n=
LXd00ol0003odRgBom8]dP0:om8]dP03o`000?ob3O;olPgb00GolPgb00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?oZ5N[ojQGZ00[ojQGZ0ol0000;ok9=/PKo00001?m]TVd00ol0003oQGZ5ohEjQ@08
ohEjQ@03o`000?m3_4?o@ka300Oo@ka300?o0000oc[5>_ljaCX00oljaCX00ol0003oQ7^4ohAkQ005
ohAkQ0?o000000?oGJ9Mo`000?n=LXd02on=LXd00ol0003odRgBom8]dP09om8]dP03o`000?ob3O;o
lPgb00OolPgb00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?oZ5N[ojQGZ00WojQGZ00?o0000oll`
coo?<<l01?l00006ok9=/P03o`000?n^DJko[U6^00Co[U6^1?l0000<ohEjQ@03o`000?m3_4?o@ka3
00Go@ka300?o0000oc[5>_ljaCX01?ljaCX00ol0003oQ7^4ohAkQ008ohAkQ003o`000?n=LXgoSG:=
00_oSG:=00?o0000om8]d_oB;M802?oB;M800ol0003olPgboo8=lP08oo8=lPGo00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?oZ5N[ojQGZ00OojQGZ00?o0000oll`coo?<<l01Oo?<<l3o`0000;o/Tfb00?o0000ojiA[_n^
DJh02?n^DJh00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?m3_4?o@ka300Co@ka300?o0000oc[5>_lj
aCX01OljaCX00ol0003oQ7^4ohAkQ008ohAkQ003o`000?n=LXgoSG:=00WoSG:=1?l00008om8]dP03
o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZ
onXEjP05onXEjP03o`000?o?<<oocc3?00Wocc3?0_l0000<ojiA[P03o`000?n5NXGoQGZ500WoQGZ5
00?o0000od>l@om3_4<00om3_4<00ol0003o>/Djoc[5>P05oc[5>P03o`000?n4NhCoQ7^400[oQ7^4
00?o0000ohebSOn=LXd01?n=LXd4o`0000CoacS700?o0000om8]d_oB;M801?oB;M800ol0003olPgb
oo8=lP0:oo8=lP03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oZ5N[ojQGZ00?ojQGZ00?o0000oll`coo?<<l02oo?
<<l00ol0003o[U6^ojiA[P0:ojiA[P03o`000?n5NXGoQGZ500WoQGZ500?o0000od>l@om3_4<00_m3
_4<00ol0003o>/Djoc[5>P06oc[5>P03o`000?n4NhCoQ7^400[oQ7^400?o0000ohebSOn=LXd01?l0
0009olLha`Ko00003?ob3O800ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000onXEj_oZ5N[ojQGZ0_l0
000=oll`c`03o`000?n^DJko[U6^00[o[U6^00?o0000ohEjQOn5NXD02On5NXD01Ol0003o@ka3od>l
@om3_4?o000000Wo>/Dj00?o0000ohAkQ?n4Nh@02on4Nh@2o`0000goacS700?o0000onhAk_o^4Nh0
0_o^4Nh00ol0003olPgboo8=lP0:oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojQGZo`00
0002oo8=lP;o00002oo?<<l00ol0003o[U6^ojiA[P0;ojiA[P03o`000?n5NXGoQGZ500WoQGZ500?o
0000od>l@ol000002OljaCX00ol0003oQ7^4ohAkQ00<ohAkQ003o`000?o7><OoacS700coacS700?o
0000onhAk_o^4Nh00oo^4Nh00ol0003olPgboo8=lP09oo8=lP03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003olPgboo8=lP03oo8=lP;o00002_o?<<l00ol0003o[U6^ojiA[P0:ojiA[P03o`000?n5NXGo
QGZ500SoQGZ51Ol00008oc[5>P03o`000?n4NhCoQ7^400coQ7^400?o0000olLhaoo7><L02oo7><L0
0ol0003okQ7^onhAkP05onhAkP03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001oob3O82o`0000Socc3?00?o0000ojiA[_n^DJh02_n^DJh00ol0003oQGZ5ohEjQ@07ohEj
Q@03o`000?mmPWgoOH9m00?oOH9m0ol00005oc[5>P03o`000?n4NhCoQ7^400_oQ7^400?o0000olLh
aoo7><L03?o7><L00ol0003okQ7^onhAkP06onhAkP03o`000?ob3O;olPgb00OolPgb00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?om0_go000000WolPgb00?o0000oll`coo?<<l01Oo?<<l2o`0000co
[U6^00?o0000ohEjQOn5NXD01On5NXD00ol0003oOH9mogf2O@07ogf2O@?o000000?o>/Djo`000?n4
Nh@03On4Nh@00ol0003oacS7olLha`0<olLha`03o`000?o^4NkokQ7^00KokQ7^00?o0000oo8=l_ob
3O801_ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003ood2o@03o`000?ob3O;olPgb00OolPgb
0_l00004oll`c`03o`000?oI9]WofBKI00;o00002_n^DJh00ol0003oQGZ5ohEjQ@03ohEjQ@;o0000
3OmmPWd2o`0000goQ7^40ol0000=olLha`03o`000?o^4NkokQ7^00OokQ7^00?o0000oo8=l_ob3O80
1Oob3O800ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo@;mood2o@04ood2o@03o`000?ob3O;olPgb00SolPgb0_l0
00000oo?<<oo0000omTVf@04omTVf@03o`000?n^DJko[U6^00Oo[U6^00Co0000ohEjQOn5NXGoQGZ5
0_l00002ojiA[P03o`000?mmPWgoOH9m00coOH9m3Ol00003oka3_003o`000?o7><OoacS700[oacS7
00?o0000onhAk_o^4Nh02?o^4Nh01?l0003olPgboo8=l_ob3O84o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?om0_d00ol0003olPgb
oo8=lP09oo8=lP03o`000?oI9]WofBKI00GofBKI0_l00008ojiA[P03o`000?n5NXGo000000Go[U6^
00?o0000ogf2OOmmPWd02ommPWd00ol0003oRgB;oh]dR`09oh]dR`03o`000?nl@kco_4>l00;o_4>l
0_l00009olLha`03o`000?o^4NkokQ7^00[okQ7^0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000ood2
o@0:ood2o@03o`000?ob3O;olPgb00SolPgb00?o0000omTVfOoI9]T01ooI9]T4o`0000?o[U6^0ol0
0007ojiA[P03o`000?mmPWgoOH9m00[oOH9m00?o0000oh]dRon;M8/02On;M8/00ol0003o_4>loka3
_004oka3_0;o00001oo7><L00ol0003okQ7^onhAkP0:onhAkP03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?ob3O;olPgb00OolPgb00?o0000omTVfOoI9]T02?oI9]T0
1?l0003of2OHomPWf?oH9mP3o`0000;ob3O800?o0000ojiA[_n^DJh01_n^DJh00ol0003oOH9mogf2
O@08ogf2O@03o`000?n;M8_oRgB;00[oRgB;00?o0000oka3_?nl@k`01_nl@k`00ol0003oacS7olLh
a`04olLha`03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000oo8=l_ob3O801Oob3O800ol0003ofBKIomTVf@08omTVf@03o`000?oH9mSo
f2OH00Cof2OH00Go0000olPgb?o8=lSob3O8o`000008ojiA[P03o`000?mmPWgoOH9m00OoOH9m00?o
0000oh]dRon;M8/02_n;M8/00ol0003o_4>loka3_007oka3_0;o00001?o7><L00ol0003okQ7^onhA
kP08onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O800oob3O80
0ol0003ofBKIomTVf@08omTVf@03o`000?oH9mSof2OH00Cof2OH00?o0000olPgb?o8=lP00_o8=lP0
0ol0003o[U6^ojiA[P07ojiA[P03o`000?mmPWgoOH9m00KoOH9m00?o0000oh]dRon;M8/02_n;M8/0
0ol0003o_4>loka3_009oka3_005o`000?o7><OoacS7olLhaol000002Oo^4Nh00ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_ofBKI00?o0000omPWf?oH9mP01?oH9mP00ol0003ob3O8olPgb003
olPgb003o`000?n^DJko[U6^00Oo[U6^00?o0000ogf2OOmmPWd01OmmPWd00ol0003oRgB;oh]dR`0:
oh]dR`03o`000?nl@kco_4>l00Wo_4>l1?l00009onhAkP03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?od2oCom0_d
oo@;m?l000002_oI9]T00ol0003of2OHomPWf005omPWf003o`000?o8=lSob3O800?ob3O800?o0000
ojiA[_n^DJh02?n^DJh00ol0003oOH9mogf2O@04ogf2O@03o`000?n;M8_oRgB;00WoRgB;00?o0000
oka3_?nl@k`02?nl@k`2o`0000?okQ7^00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003ofBKIomTVf@06omTVf@03o`000?oH9mSof2OH
00Gof2OH00?o0000olPgb?o8=lP01?o8=lP00ol0003o[U6^ojiA[P09ojiA[P03o`000?mmPWgoOH9m
00;oOH9m00?o0000oh]dRon;M8/02_n;M8/00ol0003o_4>loka3_006oka3_0;o00001_o^4Nh8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om0_doo@;m005oo@;m003o`000?oI9]WofBKI00GofBKI00?o0000omPWf?oH
9mP01OoH9mP00ol0003ob3O8olPgb005olPgb003o`000?n^DJko[U6^00Wo[U6^00Go0000ogf2OOmm
PWgoOH9mo`00000<oh]dR`03o`000?nl@kco_4>l00Co_4>l0_l00008onhAkP03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?od2oCom0_d00Oom0_d00?o0000omTVfOoI
9]T00ooI9]T00ol0003of2OHomPWf006omPWf003o`000?o8=lSob3O800Gob3O800?o0000ojiA[_n^
DJh02_n^DJh00ol0003oOH9mo`000004o`0000WoRgB;00?o0000oka3_?nl@k`00_nl@k`2o`0000[o
kQ7^00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om0_doo@;m007oo@;m003o`00
0?oI9]WofBKI00;ofBKI00?o0000omPWf?oH9mP01_oH9mP00ol0003ob3O8olPgb007olPgb0;o0000
2on^DJh00ol0003od2o@om0_d003om0_d0Oo00000_n;M8/00ol0003o_4>loka3_002o`0000_okQ7^
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo@;m?od2o@02Ood
2o@01Ol0003ofBKIomTVfOoI9]Wo000000Sof2OH00?o0000olPgb?o8=lP01oo8=lP00ol0003oiA[U
o`000002o`0000So[U6^00?o0000om0_d?o@;m002_o@;m05o`0000gokQ7^00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<oo@;m003o`000?oI9]Wo000000Wof2OH00?o
0000olPgb?o8=lP01_o8=lP00ol0003oiA[UonDJi@03onDJi@?o00001?n^DJh00ol0003od2o@om0_
d00=om0_d003o`000?o^4NkokQ7^00gokQ7^00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oom0_d2o`0000_om0_d00?o0000omPWf?oH9mP01ooH9mP00ol0003ob3O8olPgb007
olPgb003o`000?oU6^GoiA[U00KoiA[U0ol000000on^DJko0000om0_d00>om0_d003o`000?o^4Nko
kQ7^00cokQ7^00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009oo@;
m003o`000?oH9mSof2OH00;of2OH1_l00008olPgb003o`000?oU6^GoiA[U00[oiA[U00?o0000om0_
d?o@;m003oo@;m000ol0003okQ7^onhAkP0:onhAkP;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007oo@;m0Go00001_o`3o000ol0003ob3O8olPgb005olPgb003o`000?oU6^GoiA[U00[o
iA[U00?o0000om0_d?o@;m003oo@;m000ol0003okQ7^onhAkP07onhAkP?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005oo@;m003o`000?o`3o3ol0o`00Wol0o`00?o0000olPgb?o8
=lP00oo8=lP00ol0003oiA[UonDJi@0;onDJi@03o`000?o@;m3od2o@00ood2o@00?o0000onhAk_o^
4Nh01Oo^4Nh2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?om0_do`000?l00000
3Oo`3o000ol0003ob3O8olPgb002olPgb003o`000?oU6^GoiA[U00_oiA[U5?l00004onhAkP;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo@;mo`00000>oo0?l004o`000?o8=lSob3O8o`0000koiA[U
00?o0000oo8=l_ob3O804?ob3O800ol0003okQ7^o`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?om0_goo@;mood2oOl000003_o`3o000ol0003ob3O8o`00000>onDJi@03o`00
0?ob3O;olPgb017olPgb00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000ood2oOom0_d00_om0_d00ol0003ol0o`oo0?l00=oo0?l003o`000?oU6^GoiA[U00WoiA[U1Ol0
000Boo8=lP;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d0
0ol0003ol0o`oo0?l00<oo0?l003o`000?oU6^GoiA[U00;oiA[U1ol00004oo`3o003o`000?ob3O;o
lPgb00oolPgb00?o0000oo`3o?l000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo@;mood2o@06ood2
o@03o`000?o`3o3ol0o`00col0o`1?l0000<oo`3o003o`000?ob3O;olPgb00colPgb0_l00003oo`3
o003o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o003?o`3o000ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_o
lPgb00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003ol0o`oo0?l00:oo0?l003o`000?ol0ocoo0?l00koo0?l00?o0000oo8=l_ob
3O802Oob3O82o`0000Ooo0?l00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003oo0?l
oo`3o00?oo`3o003o`000?ob3O;olPgb00KolPgb0_l0000:oo`3o003o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_ob3O800ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo0?loo`3o00>oo`3o005o`000?ol0ocoo0?loo`3o?l000000oob3O82o`0000koo0?l00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o003o`000?ol0oco
o0?l00?oo0?l00?o0000oo8=l_l000004Ool0o`00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo0?loo`3o005oo`3o003o`000?ol0ocoo0?l013oo0?l00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00Ko
o0?l00?o0000oo`3o?ol0o`04Ool0o`5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o008oo`3o003o`00
0?ol0ocoo0?l013oo0?l00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3
o007oo`3o0;o00002ool0o`00ol0003oo0?loo`3o00?oo`3o003o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo0?loo`3o00=oo`3
o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o0?loo`3o003oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000oo`3o?ol0o`02ool0o`2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3ool0o`00ol0003oo0?loo`3o009oo`3o0;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?ol0ocoo0?lo`0001?oo0?l
1Ol00004oo`3o0;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004ool0o`2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
oo`3o003o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo0?l0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo0?l00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo0?l
oo`3o007oo`3o003o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003oo`3o0Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool00ol00?l6oooo00Wo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00?o003o0oooo`03o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0008o`00o`03oooo0?l00?oo003o00?o003o0_ooo`09o`00o`;oool01?l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Wo003o00?oool0o`00ool00?l00ol00?l00ooo
o`3o003oo`00o`08o`00o`03oooo0?l00?oo003o00;o003o0_ooo`05o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003
o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01_l00?l4oooo0003o`00ooooo`3oool000Wo
003o0_ooo`0?o`00o`;oool00ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0:o`00o`03oooo
0?l00?oo003o00go003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool02ol00?l00oooo`3o003oo`00o`0<o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l00oooo`3o003oo`00o`0:o`00o`?oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l2oooo00[o003o0oooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000go003o00?oool0o`00ool00?l01_l00?l5oooo00?o003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00go003o0_ooo`04o`00o`Koool01Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00
o`;oool01?l00?l4oooo00Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So
003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l00oooo`3o
003oo`00o`04o`00o`;oool01Ol00?l00oooo`3o003oo`00o`07o`00o`;oool01_l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
6?l00?l2oooo00Ko003o0_ooo`05o`00o`;oool01Ol00?l00oooo`3o003oo`00o`08o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Co003o0_ooo`03o`00o`?oool01Ol0
0?l00oooo`3o003oo`00o`08o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol0
0?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`05
o`00o`Koool01ol00?l6oooo00Go003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool0
06Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00o`Coool02?l00?l7oooo
00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(260) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.99 .01 .99 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.991 .009 .991 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.991 .009 .991 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.989 .011 .989 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.947 .053 .947 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.988 .012 .988 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.947 .053 .947 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.944 .056 .944 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.917 .083 .917 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.984 .016 .984 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.896 .104 .896 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.99 .01 .99 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.817 .183 .817 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.825 .175 .825 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.986 .014 .986 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.991 .009 .991 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.723 .277 .723 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.87 .13 .87 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.983 .017 .983 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.985 .015 .985 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.941 .059 .941 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.522 .478 .522 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.85 .15 .85 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.708 .292 .708 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.697 .303 .697 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.762 .238 .762 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.884 .116 .884 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.92 .08 .92 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.99 .01 .99 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.684 .316 .684 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.852 .148 .852 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.553 .447 .553 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.905 .095 .905 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.86 .14 .86 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.778 .222 .778 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.838 .162 .838 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.65 .35 .65 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.896 .104 .896 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.713 .287 .713 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.992 .008 .992 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.925 .075 .925 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.649 .351 .649 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.345 .655 .345 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.385 .615 .385 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.952 .048 .952 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.958 .042 .958 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.819 .181 .819 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.99 .01 .99 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.668 .332 .668 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.649 .351 .649 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.447 .553 .447 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.463 .537 .463 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.254 .746 .254 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.638 .362 .638 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.708 .292 .708 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.99 .01 .99 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.692 .308 .692 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.586 .414 .586 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.935 .065 .935 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.334 .666 .334 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.86 .14 .86 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.801 .199 .801 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.444 .556 .444 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.241 .759 .241 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.495 .505 .495 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.031 .969 .031 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.07 .93 .07 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.287 .713 .287 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.347 .653 .347 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.379 .621 .379 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.855 .145 .855 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.233 .767 .233 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.261 .739 .261 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.694 .306 .694 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.943 .057 .943 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.989 .011 .989 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.186 .814 .186 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.247 .753 .247 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.452 .548 .452 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.988 .012 .988 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.66 .34 .66 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.306 .694 .306 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.365 .635 .365 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.075 .925 .075 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.425 .575 .425 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.22 .78 .22 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.941 .059 .941 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.188 .812 .188 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.025 .975 .025 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.794 .206 .794 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.116 .884 .116 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.07 .93 .07 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.528 .472 .528 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.888 .112 .888 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.284 .716 .284 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.083 .917 .083 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.422 .578 .422 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.135 .865 .135 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.178 .822 .178 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.902 .098 .902 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.082 .918 .082 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.02 .98 .02 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.008 .992 .008 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.176 .824 .176 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.093 .907 .093 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.693 .307 .693 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.261 .739 .261 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.987 .013 .987 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.326 .674 .326 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.155 .845 .155 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.18 .82 .18 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.235 .765 .235 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.103 .897 .103 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.062 .938 .062 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.268 .732 .268 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.505 .495 .505 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.989 .011 .989 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.757 .243 .757 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.232 .768 .232 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.332 .668 .332 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.238 .762 .238 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.942 .058 .942 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.11 .89 .11 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.064 .936 .064 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.258 .742 .258 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.601 .399 .601 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.04 .96 .04 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.989 .011 .989 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.136 .864 .136 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.824 .176 .824 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.951 .049 .951 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.526 .474 .526 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.558 .442 .558 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.19 .81 .19 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.878 .122 .878 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.11 .89 .11 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.302 .698 .302 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.541 .459 .541 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.134 .866 .134 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.27 .73 .27 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.364 .636 .364 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.989 .011 .989 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.046 .954 .046 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.989 .011 .989 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.919 .081 .919 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.288 .712 .288 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.238 .762 .238 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.099 .901 .099 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.752 .248 .752 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.209 .791 .209 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.936 .064 .936 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.287 .713 .287 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.315 .685 .315 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.321 .679 .321 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.565 .435 .565 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.742 .258 .742 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.503 .497 .503 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.097 .903 .097 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.11 .89 .11 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.19 .81 .19 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.471 .529 .471 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.789 .211 .789 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.989 .011 .989 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.93 .07 .93 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.217 .783 .217 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.246 .754 .246 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.27 .73 .27 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.801 .199 .801 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.635 .365 .635 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.989 .011 .989 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.484 .516 .484 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.831 .169 .831 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.935 .065 .935 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.989 .011 .989 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.161 .839 .161 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.255 .745 .255 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.922 .078 .922 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.226 .774 .226 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.57 .43 .57 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.598 .402 .598 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.401 .599 .401 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.42 .58 .42 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.858 .142 .858 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.774 .226 .774 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.78 .22 .78 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.837 .163 .837 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.35 .65 .35 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.95 .05 .95 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.76 .24 .76 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.394 .606 .394 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.398 .602 .398 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.668 .332 .668 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.442 .558 .442 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.988 .012 .988 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.941 .059 .941 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.818 .182 .818 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.937 .063 .937 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.359 .641 .359 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.913 .087 .913 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.742 .258 .742 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.639 .361 .639 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.99 .01 .99 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.618 .382 .618 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.5 .5 .5 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.99 .01 .99 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.736 .264 .736 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.985 .015 .985 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.991 .009 .991 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.573 .427 .573 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.987 .013 .987 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.551 .449 .551 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.988 .012 .988 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.666 .334 .666 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.835 .165 .835 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.717 .283 .717 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.893 .107 .893 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.912 .088 .912 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.764 .236 .764 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.637 .363 .637 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.751 .249 .751 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.858 .142 .858 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.909 .091 .909 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.868 .132 .868 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.881 .119 .881 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.985 .015 .985 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.768 .232 .768 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.935 .065 .935 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.987 .013 .987 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.95 .05 .95 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.932 .068 .932 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.777 .223 .777 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.941 .059 .941 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.914 .086 .914 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.846 .154 .846 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.988 .012 .988 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.985 .015 .985 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.925 .075 .925 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.989 .011 .989 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.988 .012 .988 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.988 .012 .988 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.987 .013 .987 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.989 .011 .989 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005oo`3o003o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo0?l
oo`3o007oo`3o003o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo@;m0_l0000@ood2o@03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
oo`3o0?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003okQ7^onhAk_l0000>ood2o@03o`000?ol0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009oo`3o0?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000onhAk_o^4Nh00_o^4Nh00ol0003oo@;mood2o@0;ood2o@03o`000?ol
0ocoo0?l00Woo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?oo`3o003o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?o^4NkokQ7^00?okQ7^00?o0000
ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?ol0ocoo0?l
00koo0?l00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l
00_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP06onhAkP03
o`000?om0_goo@;m00Koo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo0?l
oo`3o00>oo`3o0;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@05ood2o@03o`000?ol0ocoo0?l00coo0?l
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?o`3o3o0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000cokQ7^00Co0000ood2oOom0_goo@;m0ol0000@oo`3o003o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?ol0ocoo0?l00coo0?l0_l00003oo0?l003o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003ojaC[on/Dj`05on/Dj`03o`000?o^
4NkokQ7^00_okQ7^0ol00003on`Ck003o`000?ol0ocoo0?l00coo0?l0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo0?l00?o0000
oo0?l?o`3o000oo`3o000ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003ojaC[on/Dj`06
on/Dj`03o`000?o^4NkokQ7^00[okQ7^00?o0000on`Ck?o/4n`01?o/4n`00ol0003oo0?loo`3o00:
oo`3o004o`000?oY5^WojAKYonTFj@;o00002_ol0o`2o`000003onTFjOl0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l005oo0?l003o`000?ol0oco
o0?l00Woo0?l00?o0000oo4>lOl000002oom0_d00ol0003ojaC[on/Dj`06on/Dj`03o`000?o^4Nko
kQ7^00WokQ7^00?o0000on`Ck?o/4n`01_o/4n`00ol0003oo0?loo`3o008oo`3o003o`000?oY5^Wo
jAKY00CojAKY0_l00005oo`3o0?o00001?oY5^T00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00Soo0?l0_l00008oo0?l003o`000?ol0ocoo0?l00Ooo0?l0_l00003oo4>
l@03o`000?om0_goo@;m00Ooo@;m00?o0000on/Djoo[5>/01oo[5>/00ol0003okQ7^onhAkP09onhA
kP03o`000?o/4ncok1?/00Ook1?/00?o0000oo`3o?ol0o`01Ool0o`2o`0000WojAKY0_l000000ool
0oco0000o`000007onTFj@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo0?l00?o0000oo0?l?o`
3o002?o`3o000ol0003oo0?loo`3o006oo`3o003o`000?oa3_7ol@ka00?ol@ka00?o0000ood2oOom
0_d01oom0_d00ol0003ojaC[on/Dj`08on/Dj`03o`000?o^4NkokQ7^00OokQ7^00?o0000on`Ck?o/
4n`02Oo/4n`00ol0003oo0?loo`3o003oo`3o003o`000?oY5^WojAKY00_ojAKY00?o0000onTFjOoY
5^T01ooY5^T00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003oka3_o`000005oo`3o0;o00002oo`3o02o`0000Koo0?l
00?o0000oo4>lOoa3_401Ooa3_400ol0003oo@;mood2o@06ood2o@03o`000?o[5>_ojaC[00SojaC[
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ok1?/on`Ck00;on`Ck005o`000?ol0ocoo0?loo`3o?l0
00003_oY5^T00ol0003ojAKYonTFj@08onTFj@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o_4>ooka3_onl@kol0
00000ool0o`00ol0003ol0o`oo0?l00:oo0?l004o`000?oS7>?ohacSo`0000?oo0?l0_l00008oo4>
l@03o`000?om0_goo@;m00Koo@;m00?o0000on/Djoo[5>/02Oo[5>/00ol0003okQ7^onhAkP05onhA
kP03o`000?o/4ncok1?/00cok1?/00?o0000oo`3o?l000003ooY5^T00ol0003ojAKYonTFj@08onTF
j@03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003oka3_onl@k`03onl@k`03o`000?ol0oco000000_o
l0o`0_l00004on<Lh`03o`000?ol0oco000000_ol@ka00?o0000ood2oOom0_d01Oom0_d00ol0003o
jaC[on/Dj`09on/Dj`03o`000?o^4NkokQ7^00CokQ7^00?o0000on`Ck?o/4n`03_o/4n`00ol0003o
jAKYonTFj@0>onTFj@03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000onl@koo_4>l0
1?o_4>l00ol0003ol0o`oo0?l009oo0?l003o`000?oS7>?ohacS00GohacS00?o0000oo4>lOoa3_40
2_oa3_400ol0003oo@;mood2o@05ood2o@03o`000?o[5>_ojaC[00[ojaC[00?o0000onhAk_o^4Nh0
0oo^4Nh00ol0003ok1?/on`Ck00>on`Ck003o`000?oY5^WojAKY00gojAKY00?o0000onTFjOoY5^T0
2_oY5^T00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oka3_onl@
k`05onl@k`03o`000?o`3o3ol0o`00Ool0o`0_l00008on<Lh`03o`000?oa3_7ol@ka00_ol@ka00?o
0000ood2oOom0_d01?om0_d00ol0003ojaC[on/Dj`0:on/Dj`04o`000?o^4NkokQ7^onhAkP?o0000
3oo/4n`00ol0003ojAKYonTFj@0>onTFj@03o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o_4>ooka3_00Ooka3_00?o0000oo0?l?o`3o001?o`3o02o`0000_ohacS1?l0
0009oo4>l@03o`000?om0_goo@;m00?oo@;m00?o0000on/Djoo[5>/02oo[5>/01?l0003okQ7^o`00
0?l00003oldbc@;o00003?o/4n`2o`00013ojAKY00?o0000onTFjOoY5^T02ooY5^T00ol0003oo0?l
oo`3o00=oo`3o004o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003oka3_
onl@k`07onl@k`03o`000?o`3o3ol0o`00?ol0o`00?o0000on<LhooS7><02ooS7><01?l0003o`Ck1
ol4n`Oo1?/45o`0000Gol@ka00?o0000ood2oOom0_d00_om0_d00ol0003ojaC[on/Dj`0<on/Dj`03
o`000?o=</gocC;=00GocC;=0_l00008on`Ck0;o00000_o2?L800ol0003ojAKYonTFj@0=onTFj@03
o`000?oY5^WojAKY00_ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003oka3_onl@k`09onl@k`03o`000?o`3o3ol0o`00;o0000
3OoS7><00ol0003o`Ck1ol4n`@07ol4n`@Ko00000_om0_d4o`0000gojaC[00?o0000oldbcOo=</d0
1oo=</d2o`0000Gok1?/00?o0000ol8m`_o2?L800oo2?L800ol0003ojAKYonTFj@0<onTFj@03o`00
0?oY5^WojAKY00cojAKY00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o_4>ooka3_00Woka3_00?o
0000oo0?l?l000003ooS7><00ol0003o`Ck1ol4n`@0<ol4n`@?o00001?oP7n03o`0000WojaC[00?o
0000oldbcOo=</d02_o=</d2o`000003on`Ck?l0003o000000Oo`Sg200?o0000onTFjOoY5^T02ooY
5^T00ol0003ojAKYonTFj@0<onTFj@03o`000?ol0ocoo0?l00Koo0?l1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000
on<LhooS7><03_oS7><00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oP7n3oh1oP00Koh1oP0ol00005
on/Dj`03o`000?o=</gocC;=00gocC;=00?o0000ol8m`_o2?L802?o2?L800ol0003ojAKYonTFj@09
onTFj@03o`000?oY5^WojAKY00gojAKY00Co0000oo`3o?ol0ocoo0?l1Ol00003onhAkP03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
onl@koo_4>l02oo_4>l2o`0000oohacS00?o0000ol4n`Oo1?/403Oo1?/400ol0003oh1oPon0Oh00:
on0Oh0?o000000?ojaC[o`000?o=</d03oo=</d00ol0003o`Sg2ol8m`P09ol8m`P03o`000?oY5^Wo
jAKY00SojAKY00?o0000onTFjOoY5^T03_oY5^T3o`0000SokQ7^00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o_4>ooka3_00Soka3_0ol000000oo=
</go0000on<Lh`0>on<Lh`03o`000?o1?/7o`Ck100go`Ck100?o0000on0Oh?oP7n003OoP7n000ol0
003ocC;=oldbc@0?oldbc@03o`000?o2?L;o`Sg200[o`Sg22ol0000;onTFj@Go00003?o^4Nh00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003ok1?/o`000?om0_go0000
00Soka3_0ol00005oldbc@03o`000?oS7>?ohacS00cohacS00?o0000ol4n`Oo1?/403Oo1?/400ol0
003oh1oPon0Oh00=on0Oh0;o00004?o=</d00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?nm@[go_D:m
00Oo_D:m00?o0000onTFjOoY5^T00_oY5^T7o`0000Co`cc300?o0000onhAk_o^4Nh02_o^4Nh00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003ok1?/on`Ck?o/4n`2o`00
00Goka3_0ol00009oldbc@;o00002ooS7><00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oP7n3oh1oP
00goh1oP00Co0000oke2_Onm@[go00003oo=</d00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nm@[go
_D:m00Wo_D:m1?l0000;ol<l``03o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000on`Ck?o/4n`01?o/4n`00ol0003oka3_o`000002o`00
00cocC;=00Co0000ojQGZ?l0003o00002OoS7><00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oP7n3o
h1oP00goh1oP00Go0000oke2_Onm@[go_D:mo`00000=oldbc@03o`000?o2?L;o`Sg200[o`Sg200?o
0000oke2_Onm@[d02Onm@[d00ol0003o`cc3ol<l``0<ol<l``03o`000?o^4NkokQ7^00[okQ7^00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000on`Ck?o/4n`01_o/4n`0
0ol0003ocC;=oldbc@0<oldbc@03o`000?nXEjSoZ5NX00;oZ5NX0_l00007on<Lh`03o`000?o1?/7o
`Ck100co`Ck100?o0000on0Oh?oP7n003OoP7n000ol0003o_D:moke2_@03oke2_@03o`000?o=</go
cC;=00[ocC;=00?o0000ol8m`_o2?L802_o2?L800ol0003o_D:moke2_@09oke2_@03o`000?o3?<?o
`cc300co`cc300?o0000onhAk_o^4Nh02oo^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003ok1?/on`Ck006on`Ck003o`000?o=</gocC;=00_ocC;=00?o0000ojQG
Z?nXEjP01OnXEjP00ol0003ohacSon<Lh`03on<Lh`03o`000?o1?/7o`Ck100go`Ck100?o0000on0O
h?oP7n003OoP7n000ol0003o_D:moke2_@04oke2_@03o`000?o=</gocC;=00WocC;=00?o0000ol8m
`_o2?L802Oo2?L800ol0003o_D:moke2_@0:oke2_@03o`000?o3?<?o`cc300co`cc300?o0000onhA
k_o^4Nh02oo^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
k1?/on`Ck007on`Ck003o`000?o=</gocC;=00_ocC;=00?o0000ojQGZ?nXEjP01_nXEjP2o`0000?o
hacS00?o0000ol4n`Oo1?/403Oo1?/400ol0003oh1oPon0Oh00<on0Oh003o`000?nm@[go_D:m00Ko
_D:m00?o0000oldbcOo=</d02?o=</d00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nm@[go_D:m00[o
_D:m00?o0000ol<l`oo3?<<03?o3?<<00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000on`Ck?o/4n`02?o/4n`00ol0003ocC;=oldbc@0:oldbc@03o`00
0?nXEjSoZ5NX00WoZ5NX0_l000000ooS7>?o0000ol4n`@0<ol4n`@?o00003_oP7n000ol0003o_D:m
oke2_@07oke2_@03o`000?o=</gocC;=00OocC;=00?o0000ol8m`_o2?L802Oo2?L800ol0003o_D:m
oke2_@0;oke2_@03o`000?o3?<?o`cc300co`cc300?o0000onhAk_o^4Nh02_o^4Nh00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000on`Ck?o/4n`02_o/4n`00ol0003ocC;=oldb
c@09oldbc@03o`000?nXEjSoZ5NX00_oZ5NX00?o0000ol4n`Oo1?/402_o1?/42o`0000?oVFJI00?o
0000on0Oh?oP7n002_oP7n000ol0003o_D:moke2_@09oke2_@03o`000?o=</gocC;=00KocC;=00?o
0000ol8m`_o2?L802?o2?L800ol0003o_D:moke2_@0<oke2_@03o`000?o3?<?o`cc300co`cc300?o
0000onhAk_o^4Nh02_o^4Nh00ol0003oo@;mood2o@04ood2o@Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000oldbcOo=</d02?o=</d0
0ol0003oZ5NXojQGZ00<ojQGZ003o`000?o1?/7o`Ck100So`Ck10_l00006oiUVV@;o00002_oP7n00
0ol0003o_D:moke2_@0:oke2_@03o`000?o=</gocC;=00GocC;=00?o0000ol8m`_o2?L802?o2?L80
0ol0003o_D:moke2_@0<oke2_@03o`000?o3?<?o`cc300co`cc300?o0000onhAk_o^4Nh02oo^4Nh0
0ol0003oo@;mo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
on`Ck003o`000?o=</gocC;=00OocC;=00?o0000ojQGZ?nXEjP03_nXEjP00ol0003o`Ck1ol4n`@04
ol4n`@?o00002_nIIYT00ol0003oh1oPon0Oh007on0Oh003o`000?nm@[go_D:m00_o_D:m00?o0000
oldbcOo=</d00oo=</d00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nm@[go_D:m00co_D:m00?o0000
ol<l`oo3?<<03?o3?<<00ol0003okQ7^onhAkP0;onhAkP;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003ok1?/on`Ck00<on`Ck003o`000?o=</gocC;=00OocC;=00?o0000ojQGZ?nXEjP03onXEjP01?l0
003o`Ck1ol4n`Oo1?/42o`0000koVFJI0_l00006on0Oh003o`000?nm@[go_D:m00go_D:m00?o0000
oldbcOo=</d00_o=</d00ol0003o`Sg2ol8m`P08ol8m`P03o`000?nm@[go_D:m00co_D:m0ol0000=
ol<l``03o`000?o^4NkokQ7^00_okQ7^00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ook1?/00?o0000oldbcOo=</d01_o=</d00ol0003oZ5NXojQGZ00@ojQGZ0Co00004_nIIYT00ol0
003oh1oPon0Oh003on0Oh003o`000?nm@[go_D:m00ko_D:m00Go0000oldbcOo=</gocC;=o`000005
ol8m`POo00003?nm@[d01Ol0003oSG:=ohebSOn=LXgo000000co`cc300?o0000onhAk_o^4Nh02?o^
4Nh3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ook1?/00?o0000oldbcOo=</d01_o=</d00ol0003oZ5NXojQGZ00=
ojQGZ0?o000000CoK9=/o`000?l0003o00004onIIYT2o`0000;oh1oP00?o0000oke2_Onm@[d04?nm
@[d00ol0003ocC;=o`000006o`0000OoZeB[00?o0000oke2_Onm@[d02?nm@[d00ol0003oSG:=oheb
S@03ohebS@;o00002?o3?<<3o`0000KokQ7^1?l00002onTFj@03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003ol0o`o`000?o7><L3o`0000gok1?/00?o0000oldbcOo=</d01?o=</d00ol0003oZ5NXojQG
Z00;ojQGZ0?o00000om/Tf`01Ol0003oK9=/o`000?mC[5?o000001CoVFJI00?o0000on0Oh?l00000
4onm@[d00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?nm@[go_D:m00Go_D:m0_l00008ohebS@03o`00
0?o3?<?o`cc300Go00000oo0?l000ol0003okQ7^onhAkP03o`0000OojAKY00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?o`3o3ol0o`o`0000CoacS70ol0000:on`Ck003o`000?o=</gocC;=00?ocC;=
00?o0000ojQGZ?nXEjP02OnXEjP3o`0000GoK9=/00Co0000ofbCK?m/Tfco00000_mC[5<00ol0003o
VFJIoiUVV@0BoiUVV@03o`000?nm@[go_D:m01;o_D:m00?o0000oj]DZon[E:/03_n[E:/00ol0003o
_D:moke2_@03oke2_@03o`000?n=LXgoSG:=00WoSG:=0_l00009ol0o`0;o00002_oY5^T00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo0?l?o`3o3ol0o`o`000007olLha`;o00001oo/4n`5o`0000;o
cC;=00?o0000ojQGZ?nXEjP01_nXEjP3o`0000SoK9=/00Co0000ofbCK?m/Tfco00000omC[5<00ol0
003oVFJIoiUVV@0AoiUVV@03o`000?nm@[go_D:m017o_D:m00?o0000oj]DZon[E:/04?n[E:/01Ol0
003o_D:moke2_Onm@[go000000coSG:=00?o0000ol0o`?o0?l002?o0?l000ol0003ojAKYonTFj@0:
onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Col0o`00?o0000olLhaoo7><L01oo7><L3o`00
0004on`Ck?l0003o0000o`0000Go/Dja0_l00006ojQGZ0?o00002_m/Tf`01Ol0003oK9=/ofbCK?m/
Tfco000000CoDjaC00?o0000oiUVVOnIIYT04?nIIYT00ol0003o_D:moke2_@0Aoke2_@03o`000?n[
E:_oZeB[017oZeB[00?o0000oke2_Ol000003On=LXd00ol0003o`3o0ol0o`008ol0o`003o`000?oY
5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?o`3o3ol0o`00Col0o`00?o0000
olLhaoo7><L02_o7><L00ol0003o/Djaok5>/@08ok5>/@03o`000?nXEjSoZ5NX00?o00003Om/Tf`0
1Ol0003oK9=/ofbCK?m/Tfco000000GoDjaC00?o0000oiUVVOnIIYT03onIIYT00ol0003o_D:moke2
_@0Aoke2_@03o`000?n[E:_oZeB[01;oZeB[00?o0000ohebSOn=LXd03?n=LXd00ol0003o`3o0ol0o
`008ol0o`003o`000?oY5^WojAKY00_ojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo0?l?o`3o001Oo`3o00
0ol0003oacS7olLha`0:olLha`03o`000?naC[7o/Dja00Wo/Dja0_l0000?ofbCK003o`000?m/Tfco
K9=/00;oK9=/00?o0000oe>/DomC[5<01?mC[5<00ol0003oVFJIoiUVV@0=oiUVV@?o00004Onm@[d0
0ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n=LXgoSG:=00_oSG:=00?o0000ol0o`?o0?l002Oo0?l00
0ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008ood2o@;o00002?o`3o00
0ol0003oacS7olLha`0:olLha`03o`000?naC[7o/Dja00Wo/Dja00?o0000ofbCK?m/Tf`03Om/Tf`0
0ol0003oK9=/ofbCK003ofbCK003o`000?mC[5?oDjaC00GoDjaC00?o0000oiUVVOnIIYT02_nIIYT2
o`0000?oRWF:00?o0000oke2_Onm@[d03_nm@[d00ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n=LXgo
SG:=00_oSG:=00?o0000ol0o`?o0?l002Oo0?l000ol0003ojAKYonTFj@0;onTFj@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo@;m00?o0000oo0?l?o`3o001oo`3o02o`0000_oacS700?o0000ok5>
/OnaC[402onaC[400ol0003oK9=/ofbCK00<ofbCK003o`000?m/TfcoK9=/00?oK9=/00?o0000oe>/
DomC[5<01_mC[5<00ol0003oVFJIoiUVV@07oiUVV@;o00001_n:MHX2o`0000ko_D:m00?o0000oj]D
Zon[E:/04on[E:/00ol0003oSG:=ohebS@0;ohebS@03o`000?o0?l3o`3o000Wo`3o000?o0000onTF
jOoY5^T03?oY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000ood2oOom0_goo@;mo`000009oo0?
l003o`000?oI9]Wo000000_oacS700?o0000ok5>/OnaC[402onaC[400ol0003oK9=/ofbCK00;ofbC
K003o`000?m/TfcoK9=/00CoK9=/00?o0000oe>/DomC[5<01omC[5<00ol0003oVFJIoiUVV@05oiUV
V@03o`000?n:MH[oRWF:00SoRWF:00?o0000oke2_Onm@[d02_nm@[d00ol0003oZeB[oj]DZ`0Doj]D
Z`03o`000?n=LXgoSG:=00_oSG:=00?o0000ol0o`?o0?l002Oo0?l000ol0003ojAKYonTFj@0<onTF
j@03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mo`000009oo0?l004o`000?oI9]WofBKIo`00
00_oacS700?o0000ok5>/OnaC[402onaC[400ol0003oK9=/ofbCK00;ofbCK003o`000?m/TfcoK9=/
00CoK9=/00?o0000oe>/DomC[5<02?mC[5<00ol0003oVFJIoiUVV@02oiUVV@;o00003?n:MHX2o`00
00[o_D:m00?o0000oj]DZon[E:/05?n[E:/00ol0003oSG:=ohebS@0;ohebS@03o`000?o0?l3o`3o0
00Wo`3o000?o0000onTFjOoY5^T03OoY5^T00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ol0o`oo0?l007oo0?l003
o`000?oI9]WofBKI00;ofBKI00?o0000olLhaoo7><L02?o7><L00ol0003o/Djaok5>/@0<ok5>/@03
o`000?m/TfcoK9=/00WoK9=/00?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oDjaCoe>/D`09oe>/D`04
o`000?nIIYWo0000o`00013oRWF:0_l00008oke2_@03o`000?n[E:_oZeB[01CoZeB[0ol0000;oheb
S@03o`000?o0?l3o`3o000Wo`3o000?o0000onTFjOoY5^T03OoY5^T01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ol0o`oo0?l006oo0?l003o`000?oI9]WofBKI00?ofBKI00?o0000olLh
aoo7><L02?o7><L00ol0003o/Djaok5>/@0;ok5>/@;o00002_m/Tf`00ol0003oK9=/ofbCK006ofbC
K003o`000?mC[5?oDjaC00[oDjaC00?o0000ohYeR_n:MHX04_n:MHX00ol0003o_D:moke2_@04oke2
_@03o`000?n[E:_oZeB[01GoZeB[00?o0000oi9]T_nBKI801Ol00005ohebS@03o`000?o0?l3o`3o0
00[o`3o000?o0000onTFjOoY5^T03_oY5^T3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l004oo0?l003
o`000?oI9]WofBKI00CofBKI00?o0000olLhaoo7><L01oo7><L00ol0003o/Djaok5>/@0;ok5>/@04
o`000?maSW7oLHiao`0000WoK9=/00?o0000ofbCK?m/Tf`01_m/Tf`00ol0003oDjaCoe>/D`0:oe>/
D`03o`000?n:MH[oRWF:01?oRWF:0_l00003oke2_@Co00005?n[E:/00ol0003oTVfBoi9]TP06oi9]
TPCo000000?oSG:=o`000?o0?l002oo0?l000ol0003ojAKYonTFj@0>onTFj@03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003ol0o`oo0?l003oo0?l003o`000?oI9]WofBKI00GofBKI00?o0000olLhaoo7
><L01oo7><L00ol0003o/Djaok5>/@09ok5>/@;o00001?maSW400ol0003oK9=/ofbCK005ofbCK003
o`000?m/TfcoK9=/00OoK9=/00?o0000oe>/DomC[5<02_mC[5<00ol0003oRWF:ohYeRP0EohYeRP03
o`000?nm@[go000000CoVFJI0ol0000@oj]DZ`03o`000?nBKI;oTVfB00_oTVfB0_l0000<ol0o`003
o`000?oY5^WojAKY00cojAKY0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo0?l?o`3o000_o`3o000ol0003ofBKI
omTVf@06omTVf@03o`000?o7><OoacS700OoacS700?o0000ok5>/OnaC[402?naC[400ol0003oLHia
og6>L@05og6>L@03o`000?m/TfcoK9=/00CoK9=/00?o0000ofbCK?m/Tf`01om/Tf`00ol0003oDjaC
oe>/D`0:oe>/D`03o`000?n:MH[oRWF:01KoRWF:00?o0000oiUVVOnIIYT01_nIIYT3o`0000coZeB[
00?o0000oi9]T_nBKI803OnBKI800ol0003o`3o0ol0o`009ol0o`0Go00002OoY5^T2o`000003on`C
k?l0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003oo0?l?l0003ofBKI00WofBKI00?o0000olLhaoo7><L01_o7
><L00ol0003o/Djaok5>/@07ok5>/@03o`000?maSW7oLHia00OoLHia00?o0000ofbCK?m/Tf`00_m/
Tf`00ol0003oK9=/ofbCK008ofbCK003o`000?mC[5?oDjaC00WoDjaC00?o0000ohYeR_n:MHX05on:
MHX00ol0003oVFJIoiUVV@09oiUVV@?o00002On[E:/00ol0003oTVfBoi9]TP0>oi9]TPKo00001?o0
?l000ol0003oaSW6olHiaP03olHiaPGo00000_oY5^T2o`0000Cok1?/00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oU6^GoiA[UonDJiOl000002ooI9]T00ol0003oacS7olLha`06olLha`03o`000?na
C[7o/Dja00Go/Dja0_l0000;og6>L@04o`000?m/TfcoK9=/o`0000_oK9=/00?o0000oe>/DomC[5<0
2OmC[5<00ol0003oRWF:ohYeRP0FohYeRP03o`000?nIIYWoVFJI00goVFJI0ol00005oj]DZ`03o`00
0?nBKI;oTVfB00ooTVfB00?o0000oj=LXonSG:<00onSG:<4o`0000_oaSW60_l00006on`Ck003o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003oiA[UonDJi@02onDJi@ko00001_o7><L00ol0003o/Djaok5>
/@05ok5>/@03o`000?maSW7oLHia00coLHia00?o0000ofbCK?l000002om/Tf`00ol0003oDjaCoe>/
D`07oe>/D`?o00006?n:MHX00ol0003oVFJIoiUVV@0@oiUVV@?o000000?oZeB[o`000?nBKI804?nB
KI800ol0003oXebSoj=LX`07oj=LX`03o`000?o6>LKoaSW600[oaSW600?o0000on`Ck?o/4n`01Oo/
4n`00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005onDJi@03o`000?neB[Go]DZe00_o]DZe0_l00004
olLha`03o`000?naC[7o/Dja00?o/Dja0_l0000@og6>L@03o`000?m/TfcoK9=/00[oK9=/00?o0000
oe>/DomC[5<00omC[5<4o`0000;o>l@k00?o0000ohYeR_n:MHX05On:MHX00ol0003oVFJIoiUVV@0D
oiUVV@03o`000?nBKI;oTVfB013oTVfB00?o0000oj=LXonSG:<01onSG:<00ol0003oaSW6olHiaP0:
olHiaP03o`000?o/4ncok1?/00Gok1?/00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oU6^GoiA[U
00GoiA[U00?o0000okE:]OneB[D03OneB[D6o`0000?o/Dja00?o0000og6>LOmaSW404?maSW400ol0
003oK9=/ofbCK00:ofbCK003o`000?mC[5?o000000?o00001olka3/00ol0003oRWF:ohYeRP0DohYe
RP03o`000?nIIYWoVFJI01CoVFJI00?o0000oi9]T_nBKI803onBKI800ol0003oXebSoj=LX`08oj=L
X`03o`000?o6>LKoaSW600[oaSW600?o0000on`Ck?o/4n`01Oo/4n`00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onDJiOoU6^D01_oU6^D00ol0003o]DZeokE:]@0=okE:]@03o`000?nVFJKoYUVV00?o
YUVV00?o0000ok5>/Ol000004omaSW44o`0000WoK9=/0_l0000<oc_4>`03o`000?n:MH[oRWF:01?o
RWF:00?o0000oiUVVOnIIYT05OnIIYT00ol0003oTVfBoi9]TP0>oi9]TP03o`000?nSG:?oXebS00So
XebS00?o0000olHia_o6>LH02Oo6>LH00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oU6^GoiA[U00SoiA[U00?o0000okE:]OneB[D02oneB[D00ol0003oYUVVojIIYP05ojIIYP03o`00
0?maSW7oLHia01;oLHia00Co0000odRgB?m8]dSoB;M81Ol00003ofbCK003o`000?lka3_o>l@k00go
>l@k0ol0000@ohYeRP;o00006?nIIYT00ol0003oTVfBoi9]TP0=oi9]TP03o`000?nSG:?oXebS00Wo
XebS00?o0000olHia_o6>LH02Oo6>LH00ol0003ok1?/on`Ck007on`Ck003o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_oiA[U00?o0000okE:]OneB[D02_neB[D00ol0003oYUVVojIIYP06ojIIYP03o`00
0?maSW7oLHia017oLHia00?o0000odRgB?m8]dP01om8]dP3o`00013o>l@k00?o0000oc3?<?l`cc00
1Ol00009ohYeRP;o000000?oBKI9o`000?nIIYT05onIIYT00ol0003oTVfBoi9]TP0=oi9]TP03o`00
0?nSG:?oXebS00WoXebS00?o0000olHia_o6>LH02?o6>LH2o`0000[ok1?/00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?ob3O;olPgb00;olPgb00?o0000onDJiOoU6^D02OoU6^D00ol0003o]DZeokE:
]@0:okE:]@03o`000?nVFJKoYUVV00OoYUVV00?o0000og6>LOmaSW403omaSW400ol0003oB;M8odRg
B00:odRgB003o`000?lka3_o>l@k00go>l@k00?o0000oc3?<?l`cc001_l`cc04o`0000CoRWF:00?o
0000odVfBOm9]TT00_m9]TT00ol0003oVFJIoiUVV@0FoiUVV@03o`000?nBKI;oTVfB00_oTVfB00?o
0000oj=LXonSG:<02onSG:<00ol0003oaSW6olHiaP06olHiaP03o`000?oH9mSo000000[ok1?/00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D02?oU6^D=
o`0000[oYUVV00?o0000og6>LOmaSW403omaSW400ol0003oB;M8odRgB00;odRgB003o`000?lka3_o
>l@k00co>l@k00?o0000oc3?<?l`cc002_l`cc04o`0000GoBKI900?o0000oiUVVOnIIYT05_nIIYT0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?nSG:?oXebS00coXebS00?o0000olHia_o6>LH01?o6>LH2
o`0000?of2OH00?o0000on`Ck?o/4n`02?o/4n`00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo8=
l_ob3O800oob3O800ol0003oiA[UonDJi@07onDJi@03o`000?nbCK;o/Tfb00Wo/Tfb00?o0000ojII
Y_nVFJH02OnVFJH00ol0003oLHiaog6>L@0=og6>L@03o`000?m8]dSoB;M800coB;M800?o0000oc_4
>olka3/03?lka3/00ol0003o<<l`oc3?<00;oc3?<003o`000?lIiQWo000000KoBKI900?o0000oiUV
VOnIIYT05_nIIYT00ol0003oTVfBoi9]TP09oi9]TP03o`000?nSG:?oXebS00coXebS00?o0000olHi
a_o6>LH00oo6>LH00ol0003of2OHomPWf003omPWf003o`000?o/4ncok1?/00Sok1?/00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D01_oU6^D00ol0003o
/Tfbok9=/P08ok9=/P03o`000?nVFJKoYUVV00_oYUVV00?o0000og6>LOmaSW402?maSW44o`0000oo
B;M800?o0000oc_4>olka3/02olka3/00ol0003o<<l`oc3?<00;oc3?<004o`000?lIiQWo6NHIo`00
00OoBKI900?o0000oiUVVOnIIYT05OnIIYT00ol0003oTVfBoi9]TP08oi9]TP03o`000?nSG:?oXebS
00goXebS00?o0000olHia_o6>LH00_o6>LH00ol0003of2OHomPWf005omPWf003o`000?o/4ncok1?/
00Ook1?/00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?ob3O;olPgb00GolPgb00?o0000onDJiOoU
6^D01OoU6^D00ol0003o/Tfbok9=/P08ok9=/P03o`000?nVFJKoYUVV00_oYUVV00?o0000og6>LOma
SW400omaSW45o`0000?oBKI900?o0000odRgB?m8]dP03_m8]dP00ol0003o>l@koc_4>`0:oc_4>`03
o`000?l`cc3o<<l`00[o<<l`00Go0000oaWV6OlIiQWo6NHIo`000007odVfB@03o`000?nIIYWoVFJI
01GoVFJI00?o0000oi9]T_nBKI802?nBKI800ol0003oXebSoj=LX`0=oj=LX`03o`000?o6>LKoaSW6
00;o00002?oH9mP00ol0003ok1?/on`Ck008on`Ck0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003olPgboo8=lP05oo8=lP03o`000?oU6^GoiA[U00Go
iA[U00?o0000ok9=/_nbCK802?nbCK800ol0003oYUVVojIIYP0<ojIIYPGo00002Om9]TT00ol0003o
B;M8odRgB00<odRgB0;o00003?lka3/00ol0003o<<l`oc3?<00:oc3?<005o`000?lIiQWo6NHIoaWV
6Ol000002?m9]TT00ol0003oVFJIoiUVV@0DoiUVV@?o00001onBKI800ol0003oXebSoj=LX`0>oj=L
X`03o`000?o6>LKo000000_of2OH00?o0000on`Ck?o/4n`01_o/4n`00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo8=l_ob3O801Oob3O800ol0003oiA[UonDJi@04onDJi@03o`000?nbCK;o/Tfb00Oo
/Tfb00?o0000ojIIY_nVFJH03?nVFJH01?l0003oLXebog:=L_l0000;odVfB@03o`000?m8]dSoB;M8
00_oB;M800Co0000oaC[5?lDjaCo00002_lka3/00ol0003o<<l`oc3?<00:oc3?<003o`000?lIiQWo
6NHI00;o6NHI00?o0000odVfBOm9]TT01_m9]TT00ol0003oVFJIoiUVV@0AoiUVV@?o00000omTVf@0
0ol0003oTVfBoi9]TP04oi9]TP03o`000?nSG:?oXebS00goXebS1?l0000;omPWf003o`000?o/4nco
k1?/00Gok1?/00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;olPgb00KolPgb00Co0000onDJ
iOoU6^GoiA[U1?l00008ok9=/P03o`000?nVFJKoYUVV00_oYUVV00?o0000og:=L_mbSG800_mbSG80
0ol0003oBKI9odVfB@08odVfB@03o`000?m8]dSoB;M800[oB;M800?o0000oaC[5?lDja@00_lDja@0
0ol0003o>l@koc_4>`03oc_4>`Go00002ol`cc000ol0003o6NHIoaWV6@03oaWV6@03o`000?m9]TWo
BKI900OoBKI900?o0000oiUVVOnIIYT03_nIIYT2o`0000OoI9]T00?o0000oi9]T_nBKI800_nBKI80
0ol0003oXebSoj=LX`0=oj=LX`03o`000?o4>lCoa3_400;oa3_400?o0000omPWf?oH9mP02OoH9mP0
0ol0003ok1?/on`Ck003on`Ck003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003olPgboo8=lP07oo8=
lP?o00001?oA;]400ol0003o/Tfbok9=/P05ok9=/P03o`000?nVFJKoYUVV00[oYUVV00?o0000og:=
L_mbSG800ombSG800ol0003oBKI9odVfB@09odVfB@03o`000?m8]dSoB;M800SoB;M800?o0000oaC[
5?lDja@01?lDja@5o`0000Co0?l000?o0000oc3?<?l`cc002Ol`cc000ol0003o6NHIoaWV6@03oaWV
6@03o`000?m9]TWoBKI900SoBKI900?o0000oiUVVOnIIYT02_nIIYT3o`0000[oI9]T00Go0000oi9]
T_nBKI;oTVfBo`00000>oj=LX`03o`000?o4>lCoa3_400Coa3_40_l00009omPWf003o`000?o/4nco
k1?/00;ok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?ob3O;olPgb00OolPgb00?o0000om4^
dOoA;]401OoA;]400ol0003o/Tfbok9=/P03ok9=/P03o`000?nVFJKoYUVV00[oYUVV00?o0000og:=
L_mbSG801?mbSG800ol0003oBKI9odVfB@09odVfB@03o`000?m8]dSoB;M800OoB;M800?o0000oaC[
5?lDja@01OlDja@00ol0003o0?l0o`3o0007o`3o0003o`000?l`cc3o<<l`00Oo<<l`00?o0000oaWV
6OlIiQT01?lIiQT00ol0003oBKI9odVfB@08odVfB@03o`000?nIIYWoVFJI00SoVFJI0_l0000>ofBK
I0Co00003?nSG:<2o`0000Woa3_400?o0000omPWf?oH9mP01ooH9mP01?l0003ok1?/on`Ck?l0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo8=l_ob3O801Oob3O800ol0003odBkAom4^d@07om4^d@;o00000onbCK800ol0
003oYUVVojIIYP09ojIIYP03o`000?mbSG;oLXeb00KoLXeb00?o0000odVfBOm9]TT02Om9]TT00ol0
003oB;M8odRgB005odRgB003o`000?lDjaCo5>/D00Ko5>/D00?o0000o`3o0?l0o`002?l0o`000ol0
003o<<l`oc3?<006oc3?<003o`000?lIiQWo6NHI00Co6NHI00?o0000odVfBOm9]TT02Om9]TT4o`00
00?oVFJI0ol0000@ofBKI005o`000?nl@kco_4>loka3_?l000002_nSG:<00ol0003oa3_4ol@ka00:
ol@ka0Ko00000ooH9mP00ol0003ok1?/o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo8=l_ob3O801?ob3O800ol0
003odBkAom4^d@0:om4^d@04o`000?nbCK;o/Tfbo`0000[oYUVV00?o0000og:=L_mbSG801ombSG80
0ol0003oBKI9odVfB@09odVfB@03o`000?m8]dSoB;M800CoB;M800?o0000oaC[5?lDja@01olDja@0
0ol0003o0?l0o`3o0008o`3o00;o00001_l`cc000ol0003o6NHIoaWV6@05oaWV6@03o`000?m9]TWo
BKI900WoBKI900Co0000ocW6>OliaSWo>LHi0ol0000BofBKI003o`000?nl@kco_4>l00?o_4>l0_l0
0006oj=LX`;o00003Oo4>l@00ol0003ol0o`oo0?l003oo0?l0Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo8=l_ob3O800oob3O80
0ol0003odBkAom4^d@0<om4^d@;o00002_nVFJH00ol0003oLXebog:=LP08og:=LP03o`000?m9]TWo
BKI900[oBKI900?o0000odRgB?m8]dP00_m8]dP00ol0003o5>/DoaC[5008oaC[5003o`000?l0o`3o
0?l000Ko0?l00_l00002oa3_4003o`000?l`cc3o<<l`00;o<<l`00?o0000oaWV6OlIiQT01_lIiQT0
0ol0003oBKI9odVfB@08odVfB@03o`000?liaSWo>LHi00Co>LHi00?o0000ofBKI?mTVf@03omTVf@0
0ol0003o_4>loka3_006oka3_0;o00000onSG:<00ol0003oa3_4ol@ka00=ol@ka003o`000?o`3o3o
l0o`00Ool0o`0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003olPgboo8=lP02oo8=lP03o`000?oA;]7odBkA
00kodBkA00?o0000ojIIY_nVFJH01onVFJH00ol0003oLXebog:=LP0:og:=LP03o`000?m9]TWoBKI9
00WoBKI900Go0000odRgB?m8]dSoB;M8o`00000;oaC[5003o`000?l0o`3o0?l000Co0?l00_l00005
oa3_4005o`000?l`cc3o<<l`oc3?<?l000002?lIiQT00ol0003oBKI9odVfB@08odVfB@03o`000?li
aSWo>LHi00Go>LHi00?o0000ofBKI?mTVf@03_mTVf@00ol0003o_4>loka3_008oka3_003o`000?nS
G:?o000000ooa3_400?o0000oo0?l?o`3o002?o`3o001?l0003oo0?lo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?ob3O;olPgbo`00017odBkA00?o0000ojIIY_nVFJH01_nVFJH00ol0003oLXeb
og:=LP0;og:=LP03o`000?m9]TWoBKI900WoBKI900Co0000odRgB?m8]dSo00003?lDja@00ol0003o
0?l0o`3o0002o`3o00;o00002?l@ka000ol0003o<<l`o`000009oaWV6@03o`000?m9]TWoBKI900So
BKI900?o0000ocW6>OliaST01OliaST00ol0003oI9]TofBKI00=ofBKI003o`000?nl@kco_4>l00[o
_4>l00?o0000ol@ka?o4>l@03_o4>l@00ol0003ol0o`oo0?l007oo0?l003o`000?ol0ocoo0?l00;o
o0?l00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Bom4^d@03o`00
0?nVFJKoYUVV00CoYUVV00?o0000og:=L_mbSG803?mbSG800ol0003oBKI9odVfB@0:odVfB@?o0000
3?lDja@00ol0003o0?l0o`3o0002o`0000_o4>l@00?o0000oaWV6OlIiQT02?lIiQT00ol0003oBKI9
odVfB@07odVfB@03o`000?liaSWo>LHi00Oo>LHi00?o0000ofBKI?mTVf@03?mTVf@00ol0003o_4>l
oka3_00;oka3_0;o00003_o4>l@00ol0003ol0o`oo0?l007oo0?l003o`000?ol0ocoo0?l00?oo0?l
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo4>lOoa3_400ooa3_400ol0003odBkAom4^d@0?om4^d@?o00000onV
FJH00ol0003oLXebog:=LP0>og:=LP03o`000?m9]TWoBKI900SoBKI900Co0000oagR7OlMhQgo7N8M
0_l0000:oaC[50?o00003Ol@ka000ol0003o6NHIoaWV6@08oaWV6@03o`000?m9]TWoBKI900OoBKI9
00?o0000ocW6>OliaST01oliaST00ol0003oI9]TofBKI00;ofBKI003o`000?nl@kco_4>l00co_4>l
00?o0000on4NhOl000000_l0000:ol@ka003o`000?o`3o3ol0o`00Sol0o`00?o0000oo`3o?ol0o`0
1Ool0o`2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003ol@kaoo4>l@04oo4>l@03o`000?oA;]7odBkA00codBkA0_l0
0003okU6^@03o`000?nVFJKo0000017oLXeb00?o0000odVfBOm9]TT01om9]TT00ol0003o7N8MoagR
7@04oagR7@;o00002?lDja@00ol0003o4>l@oa3_400>oa3_40;o00002?lIiQT00ol0003oBKI9odVf
B@06odVfB@03o`000?liaSWo>LHi00Wo>LHi00?o0000ofBKI?mTVf@02OmTVf@00ol0003o_4>loka3
_00=oka3_003o`000?oQ7^7ohAkQ00;ohAkQ0ol00007ol@ka003o`000?o`3o3ol0o`00Ool0o`00?o
0000oo`3o?ol0o`02?ol0o`2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?oA;]7o
dBkA00WodBkA0_l00006okU6^@03o`000?mbSG;oLXeb013oLXeb00?o0000odVfBOm9]TT01_m9]TT0
0ol0003o7N8MoagR7@07oagR7@03o`000?lDjaCo5>/D00Co5>/D0ol0000>oa3_4003o`000?l0o`3o
0?l000?o00001OlIiQT00ol0003oBKI9odVfB@06odVfB@03o`000?liaSWo>LHi00[o>LHi00?o0000
ofBKI?mTVf@02?mTVf@00ol0003o_4>loka3_00=oka3_003o`000?oQ7^7ohAkQ00GohAkQ0ol00004
ol@ka003o`000?o`3o3ol0o`00Ool0o`00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ol@kaoo4>l@06oo4>l@03o`000?oA;]7odBkA00GodBkA0ol00008okU6^@03o`000?mbSG;oLXeb
017oLXeb00Co0000odVfBOm9]TWoBKI91?l0000;oagR7@;o000000Co5>/Do`000?l0003o00000olW
f2L2o`0000_o4>l@00?o0000o`3o0?l0o`001?l0o`02o`0000?o6NHI00?o0000odVfBOm9]TT01_m9
]TT00ol0003o>LHiocW6>@0:ocW6>@03o`000?mTVfCoI9]T00OoI9]T00?o0000oka3_?nl@k`03_nl
@k`00ol0003ohAkQon4Nh@08on4Nh@Co00002_o`3o000ol0003oo0?loo`3o00;oo`3o0;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003ol@kaoo4>l@07oo4>l@03o`000?oA;]7odBkA00;odBkA0_l0000<okU6^@03o`000?mbSG;o
LXeb013oLXeb1?l00003oc_4>`03o`000?lMhQgo7N8M00_o7N8M00?o0000obOH9olWf2L01_lWf2L0
0ol0003o4>l@oa3_4007oa3_4003o`000?l0o`3o0?l000Oo0?l03?l0000>ocW6>@03o`000?mTVfCo
I9]T00KoI9]T00?o0000oka3_?nl@k`03_nl@k`00ol0003ohAkQon4Nh@0;on4Nh@03o`000?o`3o3o
l0o`00Ool0o`00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00Wol@ka00Co0000om4^
dOl0003o00003_niA[T00ol0003oLXebog:=LP0?og:=LP03o`000?lka3_o>l@k00Ko>l@k00?o0000
oagR7OlMhQd02_lMhQd00ol0003o9mPWobOH9`07obOH9`;o00001_l@ka000ol0003o0?l0o`3o0008
o`3o0003o`000?m@[e3oD:m@00SoD:m@00?o0000ocW6>OliaST03?liaST00ol0003oI9]TofBKI005
ofBKI003o`000?nl@kco_4>l00oo_4>l0_l0000=on4Nh@03o`000?o`3o3ol0o`00Kol0o`00?o0000
oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00[ol@ka00?o0000okU6^OniA[T03_niA[T00ol0
003oLXebog:=LP0>og:=LP03o`000?lka3_o>l@k00Oo>l@k00?o0000oagR7OlMhQd02_lMhQd00ol0
003o9mPWobOH9`09obOH9`;o00000ol@ka000ol0003o0?l0o`3o0009o`3o0003o`000?m@[e3oD:m@
00WoD:m@00?o0000ocW6>OliaST02_liaST4o`0000CoI9]T00?o0000oka3_?nl@k`04?nl@k`01?l0
003ogR7No`000?l0000<on4Nh@03o`000?o`3o3ol0o`00Gol0o`00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oa3_7ol@ka00[ol@ka00?o0000okU6^OniA[T03oniA[T@o`0000[o>l@k00?o0000oagR
7OlMhQd02OlMhQd00ol0003o1OX5o`00000<obOH9`05o`000?l@ka3o0000o`3o0?l000002_l0o`00
0ol0003oD:m@oe2_D009oe2_D003o`000?liaSWo>LHi00Oo>LHi0ol00004of^DJ`?o000000?oI9]T
o`000?nl@k`04Onl@k`01?l0003ogR7NomhQg_oN8Mh2o`0000_ohAkQ00?o0000oo0?l?o`3o000oo`
3o000ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003o^DJiokU6^@0?
okU6^@03o`000?mfRGKoMXUf00coMXUf00?o0000oc_4>olka3/02Olka3/00ol0003o7N8MoagR7@07
oagR7@04o`000?l5nPGo1OX5o`0000go9mPW00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m@[e3oD:m@00[oD:m@00?o0000ocW6>OliaST00oliaST3o`0000[oJiA[00?o0000oka3_?nl@k`0
4?nl@k`00ol0003ogR7NomhQgP04omhQgP;o00002_oQ7^400ol0003ol0o`oo0?l004o`0000ooo0?l
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000col@ka00?o0000okU6^OniA[T03oniA[T00ol0003oMXUfogJ9MP0<ogJ9MP03o`000?lk
a3_o>l@k00Wo>l@k00?o0000oagR7OlMhQd01_lMhQd00ol0003o1OX5o`Gj1@02o`Gj1@03o`000?lW
f2Oo9mPW00[o9mPW00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m@
[e3oD:m@00[oD:m@00?o0000ocW6>OliaST00ol0000=of^DJ`03o`000?nl@kco_4>l013o_4>l00?o
0000omhQg_oN8Mh01_oN8Mh2o`0000WohAkQ0_l00004oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003o^DJiokU6^@0=okU6^@?o00003omfRGH0
0ol0003o>l@koc_4>`08oc_4>`03o`000?lMhQgo7N8M00Go7N8M00?o0000o`Gj1Ol5nPD00ol5nPD0
0ol0003o9mPWobOH9`0:obOH9`03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003oD:m@oe2_D00;oe2_D0;o00004Om[U6/00ol0003o_4>loka3_00?oka3_003o`000?oN8Mko
gR7N00SogR7N0_l00007on4Nh@03o`000?ol0ocoo0?l00Coo0?l00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo4>lOoa3_402?oa3_400ol0003o^DJiokU6^@09okU6^@Go00000_n5NXD00ol0
003oMXUfogJ9MP0=ogJ9MP03o`000?lka3_o>l@k00Wo>l@k00?o0000oagR7OlMhQd01?lMhQd00ol0
003o1OX5o`Gj1@04o`Gj1@03o`000?lWf2Oo9mPW00So9mPW00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m@[e3oD:m@00_oD:m@00?o0000of^DJom[U6/04?m[U6/00ol0
003o_4>loka3_00?oka3_003o`000?oN8MkogR7N00[ogR7N0_l00004on4Nh@03o`000?ol0ocoo0?l
00Koo0?l0_l0000:oo`3o003o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003ol@kaoo4>l@07oo4>l@03o`000?niA[Wo^DJi00Co^DJi1Ol00007ohEjQ@03
o`000?mfRGKoMXUf00goMXUf00?o0000oc_4>olka3/02Olka3/00ol0003o7N8MoagR7@03oagR7@03
o`000?l5nPGo1OX500Go1OX500?o0000obOH9olWf2L02?lWf2L00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000oe2_D?m@[e002om@[e000ol0003oJiA[of^DJ`0@of^DJ`03
o`000?nl@kco_4>l00oo_4>l00?o0000omhQg_oN8Mh03?oN8Mh2o`000003on4NhOl0003oo0?l00[o
o0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00Ool@ka00?o0000okU6^Ol00000
1?l0000<ohEjQ@03o`000?mfRGKoMXUf00koMXUf00?o0000oc_4>olka3/02?lka3/00ol0003o7N8M
oagR7@02oagR7@03o`000?l5nPGo1OX500Oo1OX500?o0000obOH9olWf2L01olWf2L00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000oe2_D?m@[e002om@[e000ol0003oJiA[
of^DJ`0Aof^DJ`03o`000?nl@kco_4>l00go_4>l00?o0000omhQg_oN8Mh03ooN8Mh00ol0003oo0?l
oo`3o00;oo`3o0;o00001Ool0o`2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo4>lOoa3_401Ooa3_43o`00017oQGZ500?o0000ogJ9M_mfRGH03_mf
RGH00ol0003o>l@koc_4>`09oc_4>`04o`000?lMhQgo7N8Mo`0000[o1OX500?o0000obOH9olWf2L0
1olWf2L00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om@[e000ol0003o
JiA[of^DJ`0Aof^DJ`?o00003Onl@k`00ol0003ogR7NomhQgP0?omhQgP03o`000?ol0ocoo0?l00go
o0?l00Go0000oo`3o?ol0ocoo0?lo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_oa3_42o`0000;odbcC00?o0000ohEjQOn5NXD03on5NXD00ol0003o
MXUfogJ9MP0>ogJ9MP03o`000?lka3_o>l@k00So>l@k1Ol0000;o`Gj1@03o`000?lWf2Oo9mPW00Ko
9mPW00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=oe2_D003o`000?m[U6_oJiA[
017oJiA[00?o0000oe^TFomKY5/00ol0000:oka3_0Co00003OoN8Mh00ol0003oo0?loo`3o00?oo`3
o003o`000?ol0oco000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo8=l_ob3O;olPgb0_l00005om</d`03o`000?n5NXGoQGZ500koQGZ500?o0000ogJ9
M_mfRGH03_mfRGH00ol0003o>l@koc_4>`07oc_4>`03o`000?l`cc3o<<l`00?o<<l`00?o0000o`Gj
1Ol5nPD02?l5nPD00ol0003o9mPWobOH9`05obOH9`03o`000?l0o`3o0?l000[o0?l01Ol0000<oe2_
D003o`000?m[U6_oJiA[013oJiA[00?o0000oe^TFomKY5/01?mKY5/3o`0000Ko_4>l00?o0000om/T
fooK9=/00_oK9=/5o`0000SogR7N00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00?o
lPgb00?o0000om</dooC;=<01?oC;=<00ol0003oQGZ5ohEjQ@0=ohEjQ@03o`000?mfRGKoMXUf00oo
MXUf00?o0000oc_4>olka3/01?lka3/2o`0000Oo<<l`00?o0000o`Gj1Ol5nPD01ol5nPDEo`0000Go
2o@;00?o0000oe2_D?m@[e002?m@[e03o`00013oJiA[00?o0000oe^TFomKY5/02?mKY5/3o`0000;o
_4>l00?o0000om/TfooK9=/02?oK9=/5o`0000?ogR7N00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?ob3O;olPgb00ColPgb00?o0000om</dooC;=<01OoC;=<00ol0003oQGZ5ohEjQ@0;ohEjQ@Co0000
3omfRGH00ol0003o>l@koc_4>`03oc_4>`03o`000?l`cc3o<<l`00So<<l`00?o0000o`Gj1Ol5nPD0
1?l5nPD2o`0000So;]4^00?o0000oacS7?lLha`02?lLha`00ol0003o2o@;o`_d2`05o`_d2`;o0000
1_m@[e02o`0000?oAKY500?o0000of^DJom[U6/03?m[U6/00ol0003oFjAKoe^TF`0<oe^TF`;o0000
4?oK9=/3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003olPgboo8=lP05oo8=lP03o`000?oC;=?odbcC00KodbcC00?o
0000ohEjQOn5NXD02On5NXD00ol0003oSG:=o`000002oeRWF0?o00003?mfRGH01?l0003o>l@koc_4
>olka3/2o`0000co<<l`00?o0000o`Gj1Ol5nPD00_l5nPD00ol0003o;]4^obkA;P08obkA;P03o`00
0?lLhaco7><L00So7><L00?o0000o`_d2ol;m0/01ol;m0/00ol0003oD:m@oe2_D002oe2_D003o`00
0?m5^TGoAKY500CoAKY50_l0000;of^DJ`03o`000?mKY5_oFjAK00coFjAK00?o0000oiiQW_l00000
4_oK9=/00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003olPgboo8=lP06oo8=lP03o`000?oC;=?odbcC00OodbcC00?o
0000ohEjQOn5NXD01_n5NXD2o`0000;oSG:=00?o0000oeRWF?mHYeP00omHYeP3o`0000[oMXUf00?o
0000oc_4>ol000003ol`cc001?l0003o1OX5o`000?l0000;obkA;P03o`000?lLhaco7><L00So7><L
00?o0000o`_d2ol;m0/02?l;m0/01?l0003oD:m@o`000?l00009odFjA@03o`000?m[U6_oJiA[00Oo
JiA[00?o0000oe^TFomKY5/03?mKY5/01?l0003oWV6NoiiQW_l0000Com/Tf`03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo8=l_ob3O801oob3O800ol0003odbcCom</d`08om</d`03o`000?n5NXGoQGZ500Co
QGZ500?o0000ohebSOn=LXd00on=LXd00ol0003oF:MHoeRWF005oeRWF0?o00001_mfRGH4o`00013o
<<l`00?o0000obkA;_l^dBh03?l^dBh00ol0003o7><LoacS7007oacS7003o`000?l;m0_o2o@;00Wo
2o@;00?o0000odFjAOm5^TD02_m5^TD2o`0000KoJiA[00?o0000oe^TFomKY5/03?mKY5/00ol0003o
WV6NoiiQWP02oiiQWP03o`000?oK9=_ofbCK00oofbCK00?o0000onl@kol000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003olPgboo8=lP08oo8=lP03o`000?oC;=?odbcC00WodbcC00Co0000ohEjQOn5NXGo
QGZ50_l00006ohebS@03o`000?mHYeSoF:MH00SoF:MH0ol000000omfRGKo0000o`000004od:m@P03
o`000?l`cc3o<<l`00go<<l`00?o0000obkA;_l^dBh03?l^dBh00ol0003o7><LoacS7007oacS7003
o`000?l;m0_o2o@;00Wo2o@;00?o0000odFjAOm5^TD03?m5^TD00ol0003oJiA[of^DJ`03o`0000ko
FjAK00?o0000oiiQW_nNHIh00onNHIh00ol0003ofbCKom/Tf`0>om/Tf`05o`000?o_4>ooka3_onl@
kol000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003olPgboo8=lP09oo8=lP03o`000?oC;=?odbcC00[o
dbcC00?o0000ohEjQOl000002?n=LXd00ol0003oF:MHoeRWF00;oeRWF003o`000?m2_D;o@[e200Go
@[e200?o0000oc3?<?l`cc003?l`cc000ol0003o;]4^obkA;P0<obkA;P03o`000?lLhaco7><L00Oo
7><L00?o0000o`_d2ol;m0/02?l;m0/2o`0000ooAKY50_l00002ofFJI@03o`000?mKY5_oFjAK00_o
FjAK00?o0000oiiQW_nNHIh01?nNHIh00ol0003ofbCKom/Tf`0=om/Tf`03o`000?o_4>ooka3_00?o
ka3_00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo8=lP03o`000?oC;=?odbcC00_odbcC00?o0000ohebSOn=LXd0
1on=LXd00ol0003oF:MHoeRWF00;oeRWF003o`000?m2_D;o@[e200Ko@[e200?o0000oc3?<?l`cc00
2ol`cc02o`0000go;]4^00?o0000oacS7?lLha`01olLha`00ol0003o2o@;o`_d2`07o`_d2`04o`00
0?lHiaSo6>LHo`0000koAKY500?o0000ofFJIOmUVVD00_mUVVD00ol0003oFjAKoe^TF`09oe^TF`03
o`000?nNHIkoWV6N00KoWV6N00?o0000om/TfooK9=/02ooK9=/00ol0003oka3_onl@k`05onl@k`04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000SolPgb00?o0000om</dooC;=<02_oC;=<2o`0000Wo
SG:=00?o0000oeRWF?mHYeP02omHYeP00ol0003o@[e2od:m@P07od:m@P03o`000?l`cc3o<<l`00Wo
<<l`00Co0000o`3o0?l0o`3o00003?l^dBh00ol0003o7><LoacS7007oacS7003o`000?l;m0_o2o@;
00Ko2o@;00Go0000oaSW6?lHiaSo6>LHo`00000>odFjA@03o`000?mUVVGoIIYU00?oIIYU00?o0000
oe^TFomKY5/01omKY5/00ol0003oWV6NoiiQWP07oiiQWP03o`000?oK9=_ofbCK00[ofbCK00?o0000
onl@koo_4>l01oo_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo8=lP03o`000?oC;=?odbcC
00WodbcC00Co0000ol<l`oo3?<?o00002On=LXd00ol0003oF:MHoeRWF009oeRWF003o`000?m2_D;o
@[e200Wo@[e200?o0000oc3?<?l`cc001ol`cc000ol0003o0?l0o`3o0002o`3o0003o`000?l^dBko
;]4^00Wo;]4^00?o0000oacS7?lLha`01olLha`00ol0003o2o@;o`_d2`05o`_d2`03o`000?lHiaSo
6>LH00?o6>LH00?o0000odFjAOm5^TD02_m5^TD00ol0003oIIYUofFJI@05ofFJI@03o`000?mKY5_o
FjAK00GoFjAK00?o0000oiiQW_nNHIh02?nNHIh00ol0003ofbCKom/Tf`09om/Tf`03o`000?o_4>oo
ka3_00Soka3_00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_ob3O83o`0000WodbcC00?o0000ol<l
`oo3?<<00_o3?<<00ol0003oSG:=ohebS@06ohebS@03o`000?mHYeSoF:MH00WoF:MH00?o0000od:m
@_m2_D802_m2_D800ol0003o<<l`oc3?<005oc3?<003o`000?l0o`3o0?l000Co0?l000?o0000obkA
;_l^dBh02?l^dBh00ol0003o7><LoacS7007oacS7003o`000?l;m0_o2o@;00Co2o@;00?o0000oaSW
6?lHiaP01?lHiaP00ol0003oAKY5odFjA@0:odFjA@03o`000?mUVVGoIIYU00KoIIYU00?o0000oe^T
FomKY5/00omKY5/00ol0003oWV6NoiiQWP09oiiQWP03o`000?oK9=_ofbCK00SofbCK00?o0000onl@
koo_4>l02Oo_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onXEjP?o00001OoC;=<00ol0003o
`cc3ol<l``03ol<l``03o`000?n=LXgoSG:=00KoSG:=00?o0000oeRWF?mHYeP02OmHYeP00ol0003o
@[e2od:m@P0;od:m@P03o`000?l`cc3o<<l`00?o<<l`00?o0000o`3o0?l0o`001_l0o`000ol0003o
;]4^obkA;P08obkA;P03o`000?lLhaco7><L00Ko7><L00?o0000o`_d2ol;m0/00_l;m0/2o`0000So
6>LH00?o0000odFjAOm5^TD02Om5^TD00ol0003oIIYUofFJI@07ofFJI@05o`000?mKY5_oFjAKoe^T
Fol000003OnNHIh00ol0003ofbCKom/Tf`06om/Tf`03o`000?o_4>ooka3_00[oka3_00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?oZ5N[ojQGZ00GojQGZ0ol000000ooC;=?o0000ol<l``06ol<l``03
o`000?n=LXgoSG:=00GoSG:=00?o0000oeRWF?mHYeP02OmHYeP00ol0003o@[e2od:m@P0<od:m@P05
o`000?l`cc3o<<l`oc3?<?l000002_l0o`000ol0003o;]4^obkA;P07obkA;P03o`000?lLhaco7><L
00Ko7><L00?o0000o`_d2ol000000_l000000om9]TWo0000oaSW6007oaSW6003o`000?m5^TGoAKY5
00SoAKY500?o0000ofFJIOmUVVD02OmUVVD00ol0003oFjAKo`00000=oiiQWPCo00001OoK9=/00ol0
003oka3_onl@k`0;onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ojQGZonXEjP08onXEjP03
o`000?o3?<?o`cc300Oo`cc300?o0000ohebSOn=LXd01?n=LXd00ol0003oF:MHoeRWF009oeRWF003
o`000?m2_D;o@[e200go@[e200?o0000oc3?<?l000003?l0o`0:o`0000Oo7><L0ol00005odVfB@03
o`000?lHiaSo6>LH00Ko6>LH00?o0000odFjAOm5^TD01om5^TD00ol0003oIIYUofFJI@0:ofFJI@03
o`000?nNHIkoWV6N00_oWV6N00?o0000omDZeOoE:]D00_oE:]D3o`000003om/Tfol0003oka3_00_o
ka3_0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onXEj_oZ5NX02OoZ5NX00ol0003o`cc3ol<l``07ol<l``03o`00
0?n=LXgoSG:=00GoSG:=00?o0000oeRWF?mHYeP01omHYeP00ol0003o@[e2od:m@P0?od:m@P;o0000
2ol0o`000ol0003o?<<locc3?007occ3?003o`000?lLhaco7><L00;o7><L0ol00008odVfB@03o`00
0?lHiaSo6>LH00Ko6>LH00?o0000odFjAOm5^TD01om5^TD00ol0003oIIYUofFJI@0:ofFJI@03o`00
0?nNHIkoWV6N00[oWV6N00?o0000omDZeOoE:]D01_oE:]D00ol0003oka3_onl@k`08onl@k`?o0000
0_oc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onXEj_oZ5NX02OoZ5NX00ol0003o`cc3ol<l
``08ol<l``03o`000?n=LXgoSG:=00CoSG:=00?o0000oeRWF?mHYeP01omHYeP00ol0003o@[e2od:m
@P0>od:m@P04o`000?lAkQ7o4NhAo`0000Wo0?l000?o0000occ3??ll`c`02Oll`c`01?l0003o7><L
o`000?l0000<odVfB@03o`000?lHiaSo6>LH00Ko6>LH00?o0000odFjAOm5^TD01_m5^TD00ol0003o
IIYUofFJI@0;ofFJI@03o`000?nNHIkoWV6N00OoWV6N0_l00009omDZe@03o`000?o_4>ooka3_00Co
ka3_1?l00006oo<<l`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ojQGZonXEjP09onXEjP03o`00
0?o3?<?o`cc300So`cc300?o0000ohebSOn=LXd00on=LXd>o`0000go@[e200?o0000oa7^4OlAkQ40
0_lAkQ400ol0003o0?l0o`3o0005o`3o0003o`000?ll`cco?<<l00_o?<<l00?o0000odVfBOm9]TT0
3?m9]TT00ol0003o6>LHoaSW6006oaSW6003o`000?m5^TGoAKY500GoAKY500?o0000ofFJIOmUVVD0
3?mUVVD00ol0003oWV6NoiiQWP06oiiQWP03o`000?oE:]GoeB[E00[oeB[E00?o0000onl@koo_4>l0
0ol0000:oo<<l`?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ol<l`oo3?<<02?o3
?<<01Ol0003oSG:=ohebSOn=LXgo000000_oHYeR00?o0000o`Oh1ol7n0L00ol00009od:m@P03o`00
0?lAkQ7o4NhA00Co4NhA00?o0000o`3o0?l0o`000ol0o`000ol0003o?<<locc3?00<occ3?003o`00
0?m9]TWoBKI900goBKI900?o0000oaSW6?lHiaP01_lHiaP00ol0003oAKY5odFjA@03odFjA@?o0000
3OmUVVD00ol0003oWV6NoiiQWP05oiiQWP03o`000?oE:]GoeB[E00coeB[E0_l0000=oo<<l`03o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ol<l`oo3?<<02?o3
?<<4o`0000coHYeR00?o0000o`Oh1ol7n0L00ol7n0L3o`0000Go@[e200?o0000oa7^4OlAkQ401_lA
kQ401Ol0003o0?l0o`3o0?l0o`3o000000oo?<<l00?o0000odVfBOm9]TT03Om9]TT00ol0003o6>LH
oaSW6006oaSW6003o`000?m5^TGoAKY500?o00000olYeRT00ol0003oIIYUofFJI@0;ofFJI@03o`00
0?nNHIkoWV6N00?oWV6N00?o0000omDZeOoE:]D03OoE:]D00ol0003ol`ccoo<<l`0;oo<<l`03o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onXEj_oZ5NX02_oZ5NX3o`0000Ko`cc30ol0
0003ojm@[`03o`000?mRWF;oHYeR00[oHYeR00?o0000o`Oh1ol7n0L01_l7n0L3o`000003od:m@_l0
003o4NhA00Wo4NhA00?o0000o`3o0?l000004?ll`c`00ol0003oBKI9odVfB@0=odVfB@03o`000?lH
iaSo6>LH00Oo6>LH0_l00007obWF:@03o`000?mUVVGoIIYU00[oIIYU00Co0000oiiQW_nNHIkoWV6N
0ol0000?omDZe@03o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onXEj_oZ5NX02_oZ
5NX01?l0003ogR7NomhQg_oN8Mh2o`000004ol<l`ol0003o0000o`0000Ko[e2_00?o0000of:MH_mR
WF802_mRWF800ol0003o1oP7o`Oh1`09o`Oh1`03o`000?lAkQ7o4NhA00[o4NhA00?o0000occ3??ll
`c`03oll`c`00ol0003oBKI9odVfB@0>odVfB@03o`000?lHiaSo6>LH00Ko6>LH00?o0000obWF:OlY
eRT01olYeRT4o`0000SoIIYU00Co0000oiiQW_nNHIko00000onZEJX2o`0000goeB[E00?o0000oo<<
looc3?<02_oc3?<00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onXEj_oZ5NX02OoZ5NX00ol0003o
gR7NomhQgP04omhQgP03o`000?n_D:oo[e2_00Oo[e2_00?o0000of:MH_mRWF802OmRWF800ol0003o
1oP7o`Oh1`0:o`Oh1`03o`000?lAkQ7o4NhA00[o4NhA00?o0000occ3??ll`c`03oll`c`00ol0003o
BKI9odVfB@0>odVfB@03o`000?lHiaSo6>LH00Go6>LH00?o0000obWF:OlYeRT02?lYeRT01?l0003o
FJIIoeVVFOmIYUT7o`0000;oIIYU0_l00006ojYEZP;o00003?oE:]D00ol0003ol`ccoo<<l`09oo<<
l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ojQGZonXEjP08onXEjP03o`000?oN8MkogR7N00Go
gR7N00?o0000ojm@[on_D:l02?n_D:l00ol0003oHYeRof:MHP08of:MHP03o`000?l7n0Oo1oP700[o
1oP700?o0000oa7^4OlAkQ402olAkQ400ol0003o?<<locc3?00>occ3?003o`000?m9]TWoBKI900ko
BKI91Ol00002oaSW6003o`000?lYeRWo:MHY00Wo:MHY00?o0000oeVVFOmIYUT02?mIYUT3o`0000Wo
ZUFZ0_l0000:omDZe@03o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oZ5N[ojQGZ00SojQGZ00?o0000omhQg_oN8Mh01ooN8Mh00ol0003o[e2_ojm@[`07ojm@[`03o`00
0?mRWF;oHYeR00SoHYeR00?o0000o`Oh1ol7n0L02_l7n0L00ol0003o4NhAoa7^4@0:oa7^4@;o0000
3_ll`c`3o`0000goBKI90ol00005oe:]DP;o00002olYeRT00ol0003oFJIIoeVVF@0;oeVVF@;o0000
2_nZEJX2o`0000OoeB[E0ol00009oo<<l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:omhQgP03o`00
0?n_D:oo[e2_00Oo[e2_00?o0000of:MH_mRWF802?mRWF8>o`0000Wo4NhA0ol000000ol0o`3o0000
occ3?00:occ3?0?o00000_mDZe@00ol0003oBKI9odVfB@09odVfB@;o00002OmB[E800ol0003o:MHY
obWF:@09obWF:@03o`000?mIYUWoFJII00_oFJII00?o0000ogmoOol000002onZEJX2o`0000CoeB[E
00Co0000onPGj?oX5nSoj1OX0_l00007oo<<l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ook1?/00ol0003ogR7N
omhQgP09omhQgP03o`000?n_D:oo[e2_00Ko[e2_00?o0000of:MH_mRWF802?mRWF800ol0003o4NhA
oa7^4@0:oa7^4@03o`000?lAkQ7o4NhA00Co4NhA0ol00005o`3o0003o`000?ll`cco?<<l00Co?<<l
1?l00006oeB[E003o`000?m9]TWoBKI900KoBKI90_l0000;oe:]DP03o`000?lYeRWo:MHY00Wo:MHY
00?o0000oeVVFOmIYUT02_mIYUT01Ol0003oOgmoogmoOomoOgoo000000coZUFZ0_l000000ooE:]Go
0000onPGj005onPGj003o`000?oc3??ol`cc00?ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oN8MkogR7N00SogR7N00?o0000ojm@[on_D:l01_n_D:l00ol0003oHYeRof:MHP07of:MHP03o`00
0?lAkQ7o4NhA00_o4NhA00?o0000oa7^4OlAkQ400_lAkQ42o`0000Wo0?l000?o0000occ3??ll`c`0
0ol0000;oeB[E003o`000?m9]TWoBKI900;oBKI90ol0000>oe:]DP03o`000?lYeRWo:MHY00Oo:MHY
00?o0000oeVVFOmIYUT02omIYUT00ol0003oOgmoogmoO`02ogmoO`03o`000?nZEJ[oZUFZ00_oZUFZ
00?o0000onPGj?oX5nP01_oX5nP2o`0000?ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oN
8MkogR7N00OogR7N00?o0000ojm@[on_D:l01on_D:l00ol0003oHYeRof:MHP05of:MHP?o00003OlA
kQ44o`0000_o0?l00ol0000?oeB[E004o`000?m9]TWo0000o`00017oDZeB00?o0000obWF:OlYeRT0
1olYeRT00ol0003oFJIIoeVVF@0:oeVVF@03o`000?moOgooOgmo00CoOgmo00?o0000ojYEZ_nZEJX0
1onZEJX3o`0000_oj1OX1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o[e2_ojm@
[`06ojm@[`03o`000?mRWF;oHYeR00;oHYeR0ol00003od6n@@03o`000?lAkQ7o4NhA00[o4NhA00?o
0000o`3o0?l0o`002ol0o`000ol0003o0_d2o`00000AoeB[E003o`000?mB[E;oDZeB017oDZeB00?o
0000obWF:OlYeRT01olYeRT00ol0003oFJIIoeVVF@0:oeVVF@03o`000?moOgooOgmo00GoOgmo00Co
0000ojYEZ_nZEJ[oZUFZ1Ol00002okM8]`03o`000?oX5nSoj1OX00Woj1OX00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000omhQg_oN8Mh01ooN8Mh00ol0003o[e2_ojm@[`05ojm@[`?o0000
00?oHYeRo`000?l000001om1_T400ol0003o4NhAoa7^4@08oa7^4@?o00002_l0o`02o`0000;o0_d2
00?o0000oeB[E?mDZe@03omDZe@00ol0003oDZeBoe:]DP0Aoe:]DP03o`000?lYeRWo:MHY00Oo:MHY
00?o0000oeVVFOmIYUT02OmIYUT00ol0003oOgmoogmoO`07ogmoO`?o00001ongB;L00ol0003oj1OX
onPGj009onPGj003o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000omhQg_oN8Mh01ooN
8Mh4o`0000;o[e2_0_l00003ojIIYP03o`000?m1_T7o@Ki100So@Ki10_l00006oa7^4@;o00000olC
k1<00ol0003o0?l0o`3o0006o`3o0003o`000?l2o@;o0_d200?o0_d200?o0000oeB[E?mDZe@03_mD
Ze@00ol0003oDZeBoe:]DP0Boe:]DP03o`000?lYeRWo:MHY00Go:MHY00?o0000oeVVFOmIYUT02OmI
YUT00ol0003oOgmoogmoO`08ogmoO`03o`000?ngB;Oo]dRg00Oo]dRg00?o0000onPGj?oX5nP02?oX
5nP00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oN8MkogR7N00CogR7N0_l00004
on8MhP;o00001OnVFJH00ol0003o@Ki1od6n@@0:od6n@@03o`000?lAkQ7o4NhA00;o4NhA00?o0000
oa?/4olCk1<01?lCk1<00ol0003o0?l0o`3o0004o`3o0003o`000?l2o@;o0_d200Co0_d200?o0000
oeB[E?mDZe@03_mDZe@00ol0003oDZeBoe:]DP0Boe:]DP[o00002_mIYUT00ol0003oOgmoogmoO`08
ogmoO`03o`000?ngB;Oo]dRg00Oo]dRg00?o0000onPGj?oX5nP02?oX5nP00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003ogR7NomhQg_oN8Mh2o`0000OohQgR00?o0000ojIIY_nVFJH01?nVFJH0
0ol0003o@Ki1od6n@@0:od6n@@04o`000?lAkQ7o0000o`0000So4n`C00Co0000o`3o0?l0o`3o0?l0
0_l00007o`;m0P03o`000?mDZeCoE:]D00koE:]D00?o0000oe:]D_mB[E804_mB[E800ol0003o@Ki1
od6n@@07od6n@@03o`000?mIYUWoFJII00KoFJII00?o0000ogmoOomoOgl02_moOgl00ol0003o]dRg
okM8]`06okM8]`03o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oN
8Mko0000o`0000WohQgR00?o0000ojIIY_nVFJH01?nVFJH00ol0003o@Ki1od6n@@0;od6n@@03o`00
0?lCk1?o4n`C00Wo4n`C00?o0000o`3o0?l000002Ol2o@800ol0003oE:]DoeB[E00>oeB[E0;o0000
4_mB[E800ol0003o@Ki1od6n@@09od6n@@;o00001_mIYUT00ol0003oOgmoogmoO`0:ogmoO`03o`00
0?ngB;Oo]dRg00Ko]dRg00?o0000onPGj?oX5nP02?oX5nP00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000on8Mh_oR7N802OoR7N800ol0003oYUVVojIIYP05ojIIYP03o`000?m1_T7o@Ki100[o@Ki100?o
0000oa?/4olCk1<02_lCk1<2o`0000Wo0_d200?o0000oeB[E?mDZe@03_mDZe@00ol0003o?<<lo`00
0002o`0000ooDZeB00?o0000od6n@Om1_T402om1_T400ol0003oFJIIoeVVF@03o`0000goOgmo00?o
0000okM8]ongB;L01_ngB;L00ol0003oj1OXonPGj007onPGj003o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ohQgRon8MhP09on8MhP03o`000?nVFJKoYUVV00GoYUVV00?o0000od6n@Om1_T402Om1_T42
o`0000_o4n`C0_l0000;o`;m0P03o`000?mDZeCoE:]D00coE:]D00?o0000occ3??ll`c`00oll`c`3
o`0000coDZeB00?o0000od6n@Om1_T403?m1_T42o`0000;oLHia00?o0000ogmoOomoOgl03?moOgl0
0ol0003o]dRgokM8]`05okM8]`03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oR7N;ohQgR00[ohQgR00?o0000ojIIY_nVFJH01_nVFJH00ol0003o@Ki1od6n@@07od6n
@@03o`000?lm`Sgo000000[o4n`C00Co0000o`Ki1_l6n@Ko00002_l2o@800ol0003oE:]DoeB[E00<
oeB[E003o`000?ll`cco?<<l00Ko?<<l0_l00008oe:]DP;o00003om1_T400ol0003oLHiaog6>L@02
og6>L@03o`000?moOgooOgmo00_oOgmo00?o0000okM8]ongB;L01OngB;L00ol0003oj1OXonPGj007
onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ohQgRon8MhP0:on8MhP03o`000?nVFJKoYUVV
00KoYUVV00?o0000od6n@Om1_T401_m1_T401Ol0003o?L8mocg2?Olm`Sgo000000So4n`C00?o0000
o`Ki1_l6n@H00_l6n@H00ol0003o0_d2o`;m0P06o`;m0PCo00003?mDZe@00ol0003o?<<locc3?008
occ3?0?o00000_mB[E83o`000003ocO8=ol0003o@Ki100go@Ki100?o0000og6>LOmaSW401?maSW40
0ol0003oOgmoogmoO`0:ogmoO`03o`000?ngB;Oo]dRg00Go]dRg00?o0000onPGj?oX5nP01_oX5nP0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000on8Mh_oR7N802ooR7N800ol0003oYUVVojIIYP07ojII
YP03o`000?m1_T7o@Ki100?o@Ki10_l00005ocg2?@03o`000?lCk1?o4n`C00Co4n`C00?o0000o`Ki
1_l6n@H00ol6n@H00ol0003o0_d2o`;m0P05o`;m0P03o`000?lJiA[o6^DJ00;o6^DJ0ol00007oeB[
E0;o00003_ll`c`2o`0000Go=lPg00?o0000od6n@Om1_T402_m1_T400ol0003oLHiaog6>L@05og6>
L@03o`000?moOgooOgmo00_oOgmo00?o0000okM8]ongB;L01?ngB;L00ol0003oj1OXonPGj006onPG
j003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ohQgRon8MhP0;on8MhP03o`000?nVFJKoYUVV00Oo
YUVV00?o0000od6n@Om1_T400_m1_T400ol0003o?L8mocg2?@06ocg2?@03o`000?lCk1?o4n`C00;o
4n`C00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o0_d2o`;m0P02o`;m0P;o00002?lJiAX3o`0000;o
E:]D0_l000000olRgB;o0000occ3?00=occ3?003o`000?lgb3Oo=lPg00Go=lPg00?o0000od6n@Om1
_T402?m1_T400ol0003oLHiaog6>L@07og6>L@03o`000?moOgooOgmo00[oOgmo00?o0000okM8]ong
B;L01?ngB;L00ol0003oj1OXonPGj006onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ohQgR
on8MhP0<on8MhP03o`000?nVFJKoYUVV00SoYUVV00Co0000od6n@Om1_T7o00002Olm`Sd01Ol0003o
4n`Coa?/4olCk1?o000000So1_T600Go0000o`;m0_l2o@;o0_d2o`00000=oa[U6P;o00001?lRgB80
0ol0003o?<<locc3?00;occ3?003o`000?lgb3Oo=lPg00Ko=lPg00?o0000od6n@Om1_T401om1_T40
0ol0003oLHiaog6>L@08og6>L@Co00002?moOgl00ol0003o]dRgokM8]`04okM8]`03o`000?oX5nSo
j1OX00Koj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oR7N;ohQgR00_ohQgR0ol00009ojII
YP03o`000?m1_T7o000000_o?L8m00?o0000oa?/4ol000002_l6n@H00ol0003o0_d2o`00000?oa[U
6P03o`000?lRgB;o8]dR00;o8]dR00?o0000occ3??ll`c`02oll`c`00ol0003o=lPgocO8=`06ocO8
=`03o`000?m1_T7o@Ki100Ko@Ki100?o0000og6>LOmaSW402OmaSW401?l0003oXebSoj=LXonSG:<7
o`0000;oOgmo00?o0000okM8]ongB;L00ongB;L00ol0003oj1OXonPGj005onPGj003o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oR7N;ohQgR00SohQgR0ol00003omXUfP03o`000?nVFJKoYUVV00OoYUVV00?o0000ocg2
?Olm`Sd02olm`Sd00ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?lJiA[o6^DJ00go6^DJ00?o0000ob;M
8_lRgB801?lRgB800ol0003o?<<locc3?009occ3?003o`000?lgb3Oo=lPg00So=lPg00?o0000od6n
@Om1_T400om1_T42o`0000coLHia00?o0000oj=LXonSG:<02?nSG:<<o`0000?oj1OX0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on8Mh_oR7N801_oR7N83o`0000OofRGJ00?o0000ojIIY_nVFJH01_nVFJH00ol0003o
?L8mocg2?@0;ocg2?@03o`000?l6n@Ko1_T600Wo1_T60_l0000>oa[U6P03o`000?lRgB;o8]dR00Go
8]dR00?o0000occ3??ll`c`02Oll`c`00ol0003o=lPgocO8=`09ocO8=`03o`000?m1_T7o000000;o
00000_mVVFH00ol0003oLHiaog6>L@08og6>L@03o`000?nSG:?oXebS00coXebS00?o0000on@Ki?oT
6n@01_oT6n@3o`0000?oo0?l0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ohQgRon8MhP03on8MhP?o00002ooJ9MX00ol0003oYUVV
ojIIYP04ojIIYP03o`000?lm`Sgo?L8m00_o?L8m0ol00007o`Ki1P?o000000?o5NXEo`000?lJiAX0
3OlJiAX00ol0003o8]dRob;M8P06ob;M8P03o`000?ll`cco?<<l00So?<<l00?o0000ocO8=olgb3L0
2_lgb3L00ol0003oIYUVofJIIP04ofJIIP03o`000?maSW7oLHia00OoLHia00?o0000oj=LXonSG:<0
2onSG:<00ol0003oi1_Ton@Ki008on@Ki003o`000?ol0ocoo0?l00Coo0?l0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004on8Mh_l0
003o0000o`0000oofRGJ00?o0000ojIIY_nVFJH00onVFJH>o`0000?o;m0_0_l00002o`Ki1P?o0000
1OlEjQD00ol0003o6^DJoa[U6P0:oa[U6P03o`000?lRgB;o8]dR00Oo8]dR00?o0000occ3??ll`c`0
2?ll`c`00ol0003o=lPgocO8=`0:ocO8=`03o`000?mVVFKoIYUV00GoIYUV00?o0000og6>LOmaSW40
1_maSW400ol0003oXebSoj=LX`0;oj=LX`03o`000?oT6nCoi1_T00Soi1_T00?o0000oo`3o?ol0o`0
1ool0o`2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;ofRGJ00?o0000ojIIY_nVFJH00_nVFJH00ol0003oOX5nogj1
OP0:ogj1OP03o`000?l_d2oo;m0_00?o;m0_0_l00009oaGZ5@03o`000?lJiA[o6^DJ00Wo6^DJ00?o
0000ob;M8_lRgB802?lRgB82o`0000So?<<l00?o0000ocO8=olgb3L02Olgb3L00ol0003oIYUVofJI
IP07ofJIIP03o`000?maSW7oLHia00CoLHia00?o0000oj=LXonSG:<02onSG:<00ol0003oi1_Ton@K
i009on@Ki003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ofRGJomXUfP0?omXUfP?o000000?oYUVV
o`000?mnPGh02omnPGh00ol0003o;m0_obo@;`04obo@;`03o`000?lEjQGo5NXE00Wo5NXE00?o0000
oa[U6_lJiAX01olJiAX00ol0003o8]dRob;M8P09ob;M8P04o`000?lRgB;o0000o`0000Ko?<<l00?o
0000ocO8=olgb3L02Olgb3L00ol0003oIYUVofJIIP08ofJIIP03o`000?maSW7oLHia00?oLHia00?o
0000oj=LXonSG:<02onSG:<00ol0003oi1_Ton@Ki009on@Ki003o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ofRGJomXUfP0<omXUfP;o00000ooF:MH2o`0000coOX5n00?o0000obo@;ol_d2l01?l_d2l0
0ol0003o5NXEoaGZ5@0:oaGZ5@Wo00002olRgB800ol0003o8]dRob;M8P02ob;M8P?o00000_ll`c`0
0ol0003o=lPgocO8=`0:ocO8=`03o`000?mVVFKoIYUV00WoIYUV00?o0000og6>LOmaSW400_maSW40
0ol0003oXebSoj=LX`0:oj=LX`03o`000?oT6nCoi1_T00Woi1_T00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oJ9MX2o`0000GoeRWF00?o0000oj=LXol000002_mnPGh00ol0003o;m0_obo@;`06obo@
;`03o`000?lEjQGo5NXE00Wo5NXE00?o0000o`o`3ol?l0l01Ol?l0l00ol0003o8]dRob;M8P09ob;M
8P03o`000?lRgB;o8]dR00Go8]dR0ol00009ocO8=`?o00003OmVVFH01Ol0003oLHiaog6>LOmaSW7o
000000coXebS00?o0000on@Ki?oT6n@02OoT6n@00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omXU
f_oJ9MX01OoJ9MX2o`0000OoeRWF00Co0000oj=LXonSG:?o00002OmnPGh00ol0003o;m0_obo@;`06
obo@;`03o`000?lEjQGo5NXE00So5NXE00?o0000o`o`3ol?l0l01ol?l0l00ol0003o8]dRob;M8P07
ob;M8P03o`000?lRgB;o8]dR00So8]dR0ol00002ocO8=`Go00000_ln`Ch00ol0003oIYUVofJIIP0<
ofJIIP03o`000?maSW7o000000coXebS00?o0000on@Ki?oT6n@02_oT6n@00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000omXUf_oJ9MX00_oJ9MX2o`0000SoeRWF00?o0000oj=LXonSG:<00_nSG:<5o`00
00CoOX5n00?o0000obo@;ol_d2l01_l_d2l00ol0003o5NXEoaGZ5@08oaGZ5@03o`000?l?l0oo3o0?
00Oo3o0?00?o0000ob;M8_lRgB801olRgB800ol0003o8]dRob;M8P08ob;M8P03o`000?lLhaco7><L
00;o00002?ln`Ch00ol0003oIYUVofJIIP0<ofJIIPCo00002_nSG:<00ol0003oi1_Ton@Ki00:on@K
i003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ofRGJo`000?l0000:omHYeP03o`000?nSG:?oXebS
00;oXebS00?o0000oeFZEOmEZUD00_mEZUD4o`0000Wo;m0_00?o0000oaGZ5OlEjQD02?lEjQD00ol0
003o3o0?o`o`3`08o`o`3`03o`000?lRgB;o8]dR00Go8]dR00?o0000ob;M8_lRgB802?lRgB801Ol0
003o7><LoacS7?lLhaco000000[o?/4n0ol0000;ofJIIP04o`000?oA;]7odBkAom4^d@Co00001OnS
G:<00ol0003oi1_Ton@Ki00;on@Ki003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003oeRWFomHYeP0:
omHYeP03o`000?nSG:?oXebS00?oXebS00?o0000oeFZEOmEZUD01?mEZUD00ol0003o;m0_obo@;`07
obo@;`03o`000?lEjQGo5NXE00Ko5NXE0_l0000;o`o`3`03o`000?lRgB;o8]dR00Go8]dR00?o0000
ob;M8_lRgB802?lRgB800ol0003o7><LoacS7002oacS7003o`000?ln`Cko?/4n00Oo?/4n00?o0000
oi5^TOnAKY401?l00006ofJIIP03o`000?oA;]7odBkA00KodBkA0ol00002oj=LX`03o`000?oT6nCo
i1_T00_oi1_T00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oF:MKoeRWF00WoeRWF00?o0000oj=L
XonSG:<01?nSG:<00ol0003oEJYEoeFZE@05oeFZE@03o`000?l_d2oo;m0_00Oo;m0_00?o0000oaGZ
5OlEjQD00_lEjQD3o`000003ob;M8_l0003o3o0?00[o3o0?00?o0000ob;M8_lRgB801OlRgB800ol0
003o8]dRob;M8P07ob;M8P03o`000?lLhaco7><L00?o7><L00?o0000ock1?_ln`Ch01oln`Ch00ol0
003oTFjAoi5^T@04oi5^T@?o00000_mVVFH00ol0003odBkAom4^d@0:om4^d@;o00003_oT6n@00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omHYe_oF:MH02OoF:MH00ol0003oXebSoj=LX`04oj=LX`03
o`000?mEZUGoEJYE00KoEJYE0_l00007obo@;`03o`000?lEjQGo000000;o00001OlRgB800ol0003o
3o0?o`o`3`08o`o`3`?o00001?lRgB800ol0003o8]dRob;M8P08ob;M8P03o`000?lLhaco7><L00Co
7><L00?o0000ock1?_ln`Ch01_ln`Ch00ol0003oTFjAoi5^T@07oi5^T@;o00003_oA;]400ol0003o
i1_Ton@Ki00;on@Ki003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003oeRWFomHYeP08omHYeP03o`00
0?nSG:?oXebS00GoXebS00?o0000oeFZEOmEZUD01?mEZUD00ol0003oF:MHoeRWF003o`0000Co;m0_
0_l00008ob;M8P03o`000?l?l0oo3o0?00Oo3o0?00Co0000od:m@_m2_D;o@[e20ol000000olRgB;o
0000ob;M8P09ob;M8P03o`000?lLhaco7><L00Co7><L00?o0000ock1?_ln`Ch01Oln`Ch00ol0003o
TFjAoi5^T@09oi5^T@03o`000?oA;]7odBkA00godBkA00?o0000on@Ki?oT6n@02_oT6n@00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omHYe_oF:MH01ooF:MH00ol0003oXebSoj=LX`06oj=LX`03o`00
0?mEZUGoEJYE00?oEJYE00?o0000oeRWF?mHYeP01?mHYeP2o`000003obo@;ol0003o8]dR00[o8]dR
00?o0000o`o`3ol?l0l01Ol?l0l00ol0003o@[e2od:m@P05od:m@P03o`000?lRgB;o8]dR00Oo8]dR
0ol00007oacS7003o`000?ln`Cko?/4n00Co?/4n00?o0000oi5^TOnAKY402OnAKY400ol0003odBkA
om4^d@0=om4^d@03o`000?oT6nCoi1_T00[oi1_T00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oF
:MKoeRWF00GoeRWF0ol00009oj=LX`05o`000?mEZUGoEJYEoeFZEOl000002OmHYeP00ol0003o8]dR
ob;M8P0;ob;M8P03o`000?l?l0oo3o0?00?o3o0?00?o0000od:m@_m2_D801_m2_D800ol0003o8]dR
ob;M8P06ob;M8P05o`000?lebSGo=LXeocG:=Ol000001olLha`00ol0003o?/4nock1?P03ock1?P03
o`000?nAKY7oTFjA00WoTFjA00?o0000om4^dOoA;]403_oA;]400ol0003oi1_Ton@Ki009on@Ki003
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003oeRWFo`000004o`0000;oiA[U00?o0000oj=LXonSG:<0
1onSG:<01?l0003oEJYEoeFZEOl00009oeRWF0;o00003OlRgB800ol0003o3o0?o`o`3`02o`o`3`03
o`000?m2_D;o@[e200So@[e200?o0000ob;M8_lRgB800olRgB82o`0000Go=LXe00?o0000oacS7?lL
ha`01?lLha`00ol0003o?/4nock1?P03ock1?P03o`000?nAKY7oTFjA00WoTFjA00?o0000om4^dOoA
;]403_oA;]400ol0003oi1_Ton@Ki009on@Ki003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SoiA[U
00?o0000oj=LXonSG:<01_nSG:<00ol0003oEJYEo`000009oeRWF004o`000?m>/DkoC[5>o`0000go
8]dR00Co0000o`o`3ol?l0oo00003?m2_D801Ol0003o8]dRob;M8_lRgB;o000000So=LXe0_l00005
oacS7003o`000?ln`Cko?/4n00;o?/4n00?o0000oi5^TOnAKY402OnAKY400ol0003odBkAom4^d@0>
om4^d@03o`000?oT6nCoi1_T00Woi1_T00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oU6^GoiA[U
00OoiA[U00?o0000oj=LXonSG:<01onSG:<00ol0003oF:MHoeRWF007oeRWF003o`000?m>/DkoC[5>
00;oC[5>00?o0000ob;M8_lRgB802_lRgB800ol0003o3o0?o`00000>od:m@P03o`000?lRgB;o0000
00_o=LXe00?o0000oacS7?lLha`00_lLha`01Ol0003o?/4nock1?_ln`Cko000000coTFjA00?o0000
om4^dOoA;]403_oA;]43o`0000Woi1_T00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oU6^GoiA[U
00WoiA[U00?o0000oj=LXonSG:<01_nSG:<00ol0003oF:MHoeRWF006oeRWF003o`000?m>/DkoC[5>
00?oC[5>00?o0000ob;M8_lRgB802olRgB800ol0003o@[e2od:m@P0>od:m@P03o`000?lebSGo=LXe
00_o=LXe0_l00003oacS7004o`000?ln`Cko?/4no`0000[oTFjA0ol0000>om4^d@;o00000ool0o`2
o`0000Ooi1_T00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oU6^GoiA[U00[oiA[U00?o0000oj=L
XonSG:<01?nSG:<00ol0003oF:MHoeRWF006oeRWF003o`000?m>/DkoC[5>00GoC[5>00?o0000ob;M
8_lRgB801olRgB83o`00017o@[e200?o0000ocG:=OlebSD03OlebSD01Ol0003o7><LoacS7?l0003o
?/4n00Co00000onAKY45o`0000;ofbCK00?o0000om4^dOoA;]402_oA;]42o`0000Ooo0?l0_l00004
on@Ki003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oiA[UonDJi@0;onDJi@03o`000?nSG:?oXebS
00CoXebS00?o0000oeRWF?mHYeP01OmHYeP00ol0003oC[5>odjaCP06odjaCP03o`000?lRgB;o8]dR
00Co8]dR0ol00002obgB;@03o`000?m2_D;o@[e200oo@[e20_l0000?ocG:=@04o`000?lLhaco0000
o`0000CoNhAk0ol00008om/Tf`03o`000?oA;]7odBkA00OodBkA0_l0000;oo`3o0;o00000_oT6n@0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onDJiOoU6^D03?oU6^D6o`0000OoF:MH00?o0000odja
C_m>/Dh02?m>/Dh00ol0003o8]dRob;M8P03o`0000Ko;M8]00?o0000od:m@_m2_D803Om2_D801?l0
003oAKY5odFjAOl0000?ocG:=@03o`000?mkQ7_oNhAk00GoNhAk00?o0000om/TfooK9=/02?oK9=/0
0ol0003odBkAom4^d@05om4^d@03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oU6^D00ol0003oZeB[oj]DZ`04oj]D
Z`03o`000?mHYeSoF:MH00?oF:MH00?o0000odjaC_m>/Dh02_m>/Dh2o`0000[o;M8]00?o0000od:m
@_m2_D802om2_D800ol0003oAKY5odFjA@02odFjA@03o`000?lebSGo=LXe00_o=LXe0_l00007og^4
N`03o`000?oK9=_ofbCK00WofbCK00?o0000om4^dOoA;]400_oA;]42o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onDJiOoU6^D02ooU6^D00ol0003oZeB[oj]DZ`06oj]DZ`05o`000?mHYeSoF:MHoeRW
F?l000003Om>/Dh00ol0003o;M8]obgB;@0:obgB;@03o`000?m2_D;o@[e200Wo@[e200?o0000odFj
AOm5^TD01?m5^TD00ol0003o=LXeocG:=@08ocG:=@;o000000?o<<l`o`000?mkQ7/01omkQ7/00ol0
003ofbCKom/Tf`09om/Tf`04o`000?oA;]7o0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oU6^GoiA[U
00WoiA[U00?o0000oj]DZon[E:/02?n[E:/00ol0003oF:MHo`00000=odjaCP03o`000?l]dRgo;M8]
00_o;M8]00?o0000od:m@_m2_D802?m2_D800ol0003oAKY5odFjA@06odFjA@03o`000?lebSGo=LXe
00Go=LXe0_l00003oc3?<003o`000?mkQ7_oNhAk00KoNhAk00?o0000om/TfooK9=/02_oK9=/00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003oiA[UonDJi@07onDJi@03o`000?n[E:_oZeB[00[oZeB[00?o0000odjaC_m>
/Dh03?m>/Dh00ol0003o;M8]obgB;@0<obgB;@03o`000?m2_D;o@[e200Ko@[e200?o0000odFjAOm5
^TD02?m5^TD00ol0003o=LXeocG:=@02ocG:=@;o00001_l`cc000ol0003oNhAkog^4N`05og^4N`03
o`000?oK9=_ofbCK00[ofbCK00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oU6^GoiA[U00GoiA[U
00?o0000oj]DZon[E:/03?n[E:/2o`0000coC[5>00?o0000obgB;Ol]dRd03Ol]dRd00ol0003o@[e2
od:m@P04od:m@P03o`000?m5^TGoAKY500[oAKY500Co0000ocG:=Ol0003o00002?l`cc000ol0003o
NhAkog^4N`06og^4N`03o`000?oK9=_ofbCK00WofbCK00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oU6^D00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?mQWV7o000000;o00002?m>/Dh00ol0003o;M8]
obgB;@0?obgB;@Ko00003_m5^TD00ol0003o<<l`oc3?<008oc3?<003o`000?mkQ7_oNhAk00KoNhAk
00?o0000om/TfooK9=/02OoK9=/00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onLHiooW6>OoiaSW
0_l0000?oj]DZ`03o`000?mQWV7oHIiQ00?oHIiQ0ol00005odjaCP;o00004?l]dRd01_l0003o7><L
oacS7?l0003o2_D:o`0000koAKY500?o0000oc3?<?l`cc002Ol`cc000ol0003oNhAkog^4N`05og^4
N`03o`000?oK9=_ofbCK00WofbCK00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onLHiooW6>L00ooW6>L00ol0003o
ZeB[oj]DZ`0=oj]DZ`03o`000?mQWV7oHIiQ00KoHIiQ0ol000001?m>/Dko0000obgB;Ol]dRd3o`00
00co;M8]00Go0000oacS7?lLhaco7><Lo`000002o`[e2P03o`000?m5^TGoAKY500_oAKY500?o0000
oc3?<?l`cc002Ol`cc000ol0003oNhAkog^4N`06og^4N`03o`000?oK9=_ofbCK00SofbCK0_l0000A
oo`3o0?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003oiaSWonLHi`04onLHi`oo00003?mQWV400ol0003o;M8]obgB;@04obgB
;@?o00002?l]dRd00ol0003o7><LoacS7002oacS7005o`000?l:m@[o2_D:o`[e2_l000003?m5^TD0
0ol0003o<<l`oc3?<009oc3?<003o`000?mkQ7_oNhAk00GoNhAk3?l00002onl@k`;o00003Ool0o`2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oiaSWonLHi`05onLHi`03o`000?nVFJKoYUVV00_oYUVV00?o0000of6N
HOmQWV402_mQWV400ol0003o;M8]obgB;@07obgB;@;o00001Ol]dRd00ol0003o7><LoacS7003oacS
7003o`000?l:m@[o2_D:00;o2_D:00?o0000odFjAOm5^TD02Om5^TD00ol0003o<<l`oc3?<00:oc3?
<003o`000?mkQ7_oNhAk00?oNhAk00?o0000olHia_o6>LH02Oo6>LH00ol0003oka3_onl@k`02onl@
k`;o00002Ool0o`2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiaSWonLHi`06onLHi`03o`000?nVFJKoYUVV00[o
YUVV00?o0000of6NHOmQWV402omQWV400ol0003o;M8]obgB;@09obgB;@?o000000?o;M8]o`000?lL
ha`01OlLha`00ol0003o2_D:o`[e2P03o`[e2P03o`000?m5^TGoAKY500SoAKY53_l00003og^4N`;o
00002oo6>LH00ol0003oka3_onl@k`05onl@k`03o`000?ol0ocoo0?l00?oo0?l0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onLHiooW6>L01OoW6>L00ol0003o]TVfo`00000;ojIIYP03o`000?mQWV7oHIiQ00[oHIiQ
0_l0000>obgB;@03o`000?lLhaco7><L00Go7><L00?o0000o`[e2_l:m@X00ol:m@X00ol0003oAKY5
odFjA@08odFjA@03o`000?mhQgSoN8Mh00_oN8Mh00?o0000og^4Nol000003Oo6>LH00ol0003oka3_
onl@k`06onl@k`;o000000?oo0?lo`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oW6>OoiaSW00KoiaSW00Co
0000okI9]_nfBKKo00002_nVFJH00ol0003oHIiQof6NH@09of6NH@03o`000?lo`3oo000000ko;M8]
00?o0000oacS7?lLha`01OlLha`00ol0003o2_D:o`[e2P04o`[e2P03o`000?m5^TGoAKY500KoAKY5
00?o0000ogR7N?mhQgP03OmhQgP00ol0003oaSW6olHiaP0<olHiaP03o`000?o_4>ooka3_00Soka3_
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oW6>OoiaSW00GoiaSW00?o0000okI9]_nfBKH00_nf
BKH00ol0003oYUVVojIIYP06ojIIYP03o`000?mQWV7oHIiQ00SoHIiQ0_l00003oco0?`03o`000?l]
dRgo;M8]00_o;M8]00?o0000oacS7?lLha`01OlLha`00ol0003o2_D:o`[e2P05o`[e2P03o`000?m5
^TGoAKY500GoAKY500?o0000ogR7N?mhQgP03OmhQgP00ol0003oaSW6olHiaP0;olHiaP03o`000?o_
4>ooka3_00Woka3_00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oW6>OoiaSW00KoiaSW00?o0000
okI9]_nfBKH00onfBKH00ol0003oYUVVojIIYP05ojIIYP03o`000?mQWV7oHIiQ00OoHIiQ00?o0000
oco0?olo`3l00olo`3l00ol0003o;M8]obgB;@0:obgB;@03o`000?lLhaco7><L00Ko7><L00?o0000
o`[e2_l:m@X01_l:m@X00ol0003oAKY5odFjA@04odFjA@03o`000?mhQgSoN8Mh00goN8Mh3ol0000;
onl@k`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oW6>OoiaSW00KoiaSW00?o0000okI9]_nfBKH01OnfBKH00ol0
003oYUVVojIIYP04ojIIYP03o`000?mQWV7oHIiQ00GoHIiQ0_l00006oco0?`03o`000?l]dRgo;M8]
00Wo;M8]0_l00008oacS7003o`000?l:m@[o2_D:00Ko2_D:1Ol000000om5^TGo0000ogR7N00?ogR7
N003o`000?o7><OoacS700_oacS700?o0000onl@koo_4>l02Oo_4>l00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?oW6>OoiaSW00KoiaSW00?o0000okI9]_nfBKH01_nfBKH00ol0003o
YUVVojIIYP04o`0000KoHIiQ00?o0000oco0?olo`3l01olo`3l00ol0003o;M8]obgB;@05obgB;@?o
000000?o5nPGo`000?lLha`01olLha`00ol0003o2_D:o`[e2P05o`[e2P03o`000?m=/TgoCK9=00?o
CK9=0_l0000?ogR7N0;o00003Oo7><L00ol0003oka3_onl@k`08onl@k`03o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WoiaSW00?o0000okI9]_nfBKH01onfBKH2o`0000CoUVVF00Co0000of6NHOmQWV7o
HIiQ0_l0000:oco0?`03o`000?l]dRgo;M8]00;o;M8]0ol00005oaOX5`03o`000?lLhaco7><L00Go
7><L00?o0000o`[e2_l:m@X01?l:m@X00ol0003oCK9=odfbC@06odfbC@03o`000?mhQgSoN8Mh00[o
N8Mh0_l00002oj9MXP03o`000?o7><OoacS700[oacS700?o0000onl@koo_4>l02?o_4>l00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onLHiooW6>L01_oW6>L00ol0003o]TVfokI9]P08okI9]P03o`00
0?nFJIKoUVVF00CoUVVF00?o0000of6NHOl000003?lo`3l00ol0003o;M8]o`000002o`0000Wo5nPG
00?o0000oacS7?lLha`01?lLha`00ol0003o2_D:o`[e2P03o`[e2P03o`000?m=/TgoCK9=00SoCK9=
1_l00004ogR7N0;o00001OnRGJ800ol0003oacS7olLha`09olLha`03o`000?o_4>ooka3_00Soka3_
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?oW6>OoiaSW00GoiaSW00?o0000okI9]_nfBKH01onf
BKH00ol0003oUVVFoiIYUP06oiIYUP03o`000?lo`3oo?l0o00co?l0o00?o0000oaOX5olGj1L02_lG
j1L00ol0003o7><LoacS7004oacS7004o`000?l:m@[o2_D:o`[e2P;o00002om=/Td00ol0003oP7n0
oh1oP003oh1oP0Co00002?nRGJ800ol0003oacS7olLha`08olLha`03o`000?o_4>ooka3_00Ooka3_
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onLHiooW6>L00ooW6>L00ol0003o]TVfokI9]P07okI9]P03o`000?nF
JIKoUVVF00OoUVVF00?o0000oco0?olo`3l03?lo`3l00ol0003o5nPGoaOX5`0;oaOX5`03o`000?lL
haco7><L00?o7><L00Co0000o`[e2_l:m@[o00003Om=/Td00ol0003oP7n0oh1oP006oh1oP003o`00
0?nRGJ;oXUfR00OoXUfR00?o0000olLhaoo7><L01oo7><L00ol0003oka3_onl@k`06onl@k`04o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oW6>OoiaSW00;oiaSW00?o0000okI9]_nfBKH0
1_nfBKH00ol0003oUVVFoiIYUP09oiIYUP03o`000?lo`3oo?l0o00Wo?l0o0_l0000>oaOX5`?o0000
0olLha`00ol0003o2_D:o`00000=odfbC@03o`000?n0Oh3oP7n000OoP7n000?o0000oj9MX_nRGJ80
2?nRGJ8:o`0000Koka3_0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo]TVf00?o
0000oiIYU_nFJIH02_nFJIH00ol0003o?l0ooco0?`06oco0?`;o000000?o><Lho`000?lGj1L02olG
j1L2o`0000?o@[e21Ol0000>odfbC@03o`000?n0Oh3oP7n000OoP7n000?o0000oj9MX_nRGJ802?nR
GJ800ol0003oeRWFomHYeP06omHYeP03o`000?o_4>ooka3_00?oka3_00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003og2?Lom`Sg003om`Sg0Co00000_nfBKH00ol0003oUVVFoiIYUP0;
oiIYUP03o`000?lo`3oo?l0o00?o?l0o0ol00004ocS7>003o`000?lGj1Oo5nPG00Oo5nPG0_l00008
od:m@P03o`000?m=/TgoCK9=00goCK9=00?o0000oh1oP?n0Oh002?n0Oh000ol0003oXUfRoj9MXP07
oj9MXP03o`000?oF:MKoeRWF00OoeRWF0ol000000oo_4>oo0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oL8mcog2?L00Oog2?L0_l0000?oiIYUP03o`000?lo`3oo?l0o00;o00002?lhacP00ol0
003o5nPGoaOX5`05oaOX5`03o`000?m2_D;o@[e200So@[e200?o0000odfbCOm=/Td03Om=/Td00ol0
003oP7n0oh1oP008oh1oP003o`000?nRGJ;oXUfR00KoXUfR00?o0000omHYe_oF:MH02?oF:MH01?l0
003ol0o`oo0?l?l0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003og2?Lom`Sg009om`S
g003o`000?nFJIKoUVVF00koUVVF0_l0000;ocS7>003o`000?lGj1Oo5nPG00;o5nPG0_l0000;od:m
@P03o`000?m=/TgoCK9=00goCK9=00?o0000oh1oP?n0Oh002?n0Oh000ol0003oXUfRoj9MXP06oj9M
XP03o`000?oF:MKoeRWF00OoeRWF00Go0000oo0?l?o`3o3ol0o`o`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003og2?Lom`Sg00:om`Sg003o`000?nFJIKoUVVF00goUVVF0_l0000<ocS7>004o`000?lGj1Oo0000
o`0000go@[e200?o0000odfbCOm=/Td03?m=/Td00ol0003oP7n0oh1oP009oh1oP003o`000?nRGJ;o
XUfR00KoXUfR00?o0000omHYe_oF:MH01_oF:MH00ol0003ol0o`oo0?l003oo0?l003o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003og2?Lom`Sg00:om`Sg003o`000?nFJIKoUVVF00coUVVF00Co0000oefR
GOmMXUgo00003?lhacP00ol0003o@[e2od:m@P0>od:m@P03o`000?m=/TgoCK9=00SoCK9=1?l0000;
oh1oP003o`000?nRGJ;oXUfR00KoXUfR00?o0000omHYe_oF:MH01OoF:MH00ol0003ol0o`oo0?l004
oo0?l003o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003og2?Lom`Sg00;om`Sg003o`000?nFJIKoUVVF
00_oUVVF00?o0000oefRGOmMXUd00_mMXUd00ol0003o><LhocS7>009ocS7>003o`000?m2_D;o@[e2
00ko@[e200Co0000odfbCOm=/TgoCK9=1ol00003oefRG@03o`000?n0Oh3oP7n000WoP7n000?o0000
oj9MX_nRGJ801_nRGJ800ol0003oeRWFomHYeP04omHYeP03o`000?o`3o3ol0o`00Kol0o`00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oL8mcog2?L00cog2?L00?o0000oiIYU_nFJIH02_nFJIH00ol0
003oGJ9MoefRG@03oefRG@03o`000?lhacSo><Lh00So><Lh00?o0000od:m@_m2_D803_m2_D84o`00
00_oGJ9M00?o0000oh1oP?n0Oh002?n0Oh000ol0003oXUfRoj9MXP05oj9MXP03o`000?oF:MKoeRWF
00GoeRWF00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000om`Sg?oL
8m`03?oL8m`7o`0000GoUVVF00?o0000oefRGOmMXUd01OmMXUd00ol0003o><LhocS7>007ocS7>003
o`000?m2_D;o@[e200ko@[e200?o0000oefRGOmMXUd03OmMXUd00ol0003oP7n0oh1oP008oh1oP003
o`000?nRGJ;oXUfR00CoXUfR00?o0000omHYe_oF:MH01?oF:MH00ol0003ol0o`oo0?l007oo0?l003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003og2?Lom`Sg00=om`Sg003o`000?neB[Go]DZe00Co]DZe
1Ol00009oefRG@03o`000?lhacSo><Lh00Ko><Lh00?o0000od:m@_m2_D803_m2_D800ol0003oGJ9M
oefRG@0=oefRG@03o`000?n0Oh3oP7n000SoP7n000Co0000oj9MX_nRGJ;oXUfR1Ol00004omHYeP03
o`000?o`3o3ol0o`00Wol0o`1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=om`Sg003o`000?neB[Go]DZe00Wo]DZe
0_l00009oefRG@03o`000?lhacSo><Lh00Ko><Lh00?o0000od:m@_m2_D803?m2_D800ol0003oGJ9M
oefRG@0?oefRG@Ko00001?n0Oh04o`0000Goe2_D0_l000000ooF:MKo0000oo0?l00;oo0?l004o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o[5>_ojaC[on/Dj`?o00002_oL8m`00ol0003o
]DZeokE:]@09okE:]@03o`000?mcS7?o000000;o00001omMXUd00ol0003o><LhocS7>005ocS7>003
o`000?m2_D;o@[e200So@[e21Ol0000AoefRG@03o`000?n@Ki3oT6n@00?oT6n@1?l0000;om@[e003
o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000on/Djoo[5>/01Oo[5>/2o`0000Oog2?L
00?o0000okE:]OneB[D02_neB[D00ol0003oLhacog><L`02og><L`?o00001OmMXUd00ol0003o><Lh
ocS7>004ocS7>004o`000?m2_D;o@[e2od:m@POo00001?m4^d@00ol0003oGJ9MoefRG@0>oefRG@03
o`000?n@Ki3oT6n@00OoT6n@00?o0000om@[e?oD:m@02OoD:m@00ol0003ol0o`oo0?l009oo0?l003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ojaC[on/Dj`08on/Dj`;o00001?oL8m`00ol0003o]DZe
okE:]@0;okE:]@03o`000?mcS7?oLhac00GoLhac0ol00003oefRG@04o`000?lhacSo><LhocS7>0Ko
00003?m4^d@00ol0003oGJ9MoefRG@0=oefRG@03o`000?n@Ki3oT6n@00OoT6n@00?o0000om@[e?oD
:m@02_oD:m@00ol0003ol0o`oo0?l008oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=on/Dj`?o000000?og2?Lo`000?neB[D0
3?neB[D00ol0003oLhacog><L`08og><L`?o000000CoGJ9Mo`000?l0003o00000_n7N8L00ol0003o
A;]4odBkA00=odBkA003o`000?mMXUgoGJ9M00coGJ9M00?o0000oi1_T?n@Ki002?n@Ki000ol0003o
e2_Dom@[e00;om@[e003o`000?o`3o3ol0o`00Kol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo0?loo`3o?ol0oco000000oo
jaC[00?o0000okE:]OneB[D03?neB[D00ol0003oLhacog><L`0;og><L`03o`000?n7N8OoQgR700?o
QgR700?o0000odBkA?m4^d@03?m4^d@00ol0003o?<<lo`00000=oefRG@03o`000?n@Ki3oT6n@00So
T6n@00?o0000om@[e?oD:m@03?oD:m@3o`0000Gol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o003oo`3o003o`00
0?o[5>_ojaC[00cojaC[00?o0000okE:]OneB[D03?neB[D00ol0003oLhacog><L`0:og><L`03o`00
0?n7N8OoQgR700GoQgR700?o0000odBkA?m4^d@02_m4^d@01?l0003o?<<locc3??ll`c`2o`0000[o
GJ9M00?o0000oi1_T?n@Ki002On@Ki000ol0003oe2_Dom@[e00<om@[e003o`000?oc3??ol`cc00?o
000000?ol0o`o`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo0?loo`3o004oo`3o003o`000?o[5>_ojaC[00_ojaC[00?o0000okE:]OneB[D0
3?neB[D00ol0003oLhacog><L`09og><L`03o`000?n7N8OoQgR700KoQgR700?o0000odBkA?m4^d@0
2Om4^d@00ol0003o?<<locc3?002occ3?003o`000?n6NHKo000000;o00001omMXUd00ol0003oT6n@
oi1_T009oi1_T003o`000?oD:mCoe2_D00_oe2_D00?o0000oo<<looc3?<01?oc3?<00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?ol
0ocoo0?l00Koo0?l00?o0000on/Djoo[5>/02oo[5>/00ol0003o]DZeokE:]@0;okE:]@03o`000?mc
S7?oLhac00SoLhac00?o0000ohMhQon7N8L01on7N8L00ol0003oA;]4odBkA008odBkA003o`000?ll
`cco?<<l00?o?<<l00?o0000ohIiQ_n6NHH00_n6NHH2o`0000CoGJ9M00?o0000oi1_T?n@Ki002_n@
Ki000ol0003oe2_Dom@[e00:om@[e003o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo0?loo`3o007
oo`3o003o`000?o[5>_ojaC[00[ojaC[0ol0000;okE:]@Ko00001?mcS7<00ol0003oQgR7ohMhQ`08
ohMhQ`03o`000?m4^dCoA;]400OoA;]400?o0000occ3??ll`c`00oll`c`00ol0003oQWV6ohIiQP05
ohIiQP?o000000?oGJ9Mo`000?n@Ki002on@Ki000ol0003oe2_Dom@[e009om@[e003o`000?oc3??o
l`cc00Ool`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo0?loo`3o008oo`3o003o`000?o[5>_ojaC[00WojaC[00?o0000om4^
dOoA;]401?l00006okE:]@03o`000?naC[7o/Dja00Co/Dja1?l0000<ohMhQ`03o`000?m4^dCoA;]4
00GoA;]400?o0000occ3??ll`c`01?ll`c`00ol0003oQWV6ohIiQP08ohIiQP03o`000?n@Ki3oT6n@
00_oT6n@00?o0000om@[e?oD:m@02?oD:m@00ol0003ol`ccoo<<l`08oo<<l`Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo0?loo`3o00:oo`3o003
o`000?o[5>_ojaC[00OojaC[00?o0000om4^dOoA;]401OoA;]43o`0000;o]DZe00?o0000ok5>/Ona
C[402?naC[400ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?m4^dCoA;]400CoA;]400?o0000occ3??ll
`c`01Oll`c`00ol0003oQWV6ohIiQP08ohIiQP03o`000?n@Ki3oT6n@00WoT6n@1?l00008om@[e003
o`000?oc3??ol`cc00Wol`cc00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[
on/Dj`05on/Dj`03o`000?oA;]7odBkA00WodBkA0_l0000<ok5>/@03o`000?n7N8OoQgR700WoQgR7
00?o0000odBkA?m4^d@00om4^d@00ol0003o?<<locc3?005occ3?003o`000?n6NHKoQWV600[oQWV6
00?o0000oi1_T?n@Ki001?n@Ki04o`0000CobCK900?o0000om@[e?oD:m@01?oD:m@00ol0003ol`cc
oo<<l`0:oo<<l`03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o[5>_ojaC[00?ojaC[00?o0000om4^dOoA;]402ooA
;]400ol0003o/Djaok5>/@0:ok5>/@03o`000?n7N8OoQgR700WoQgR700?o0000odBkA?m4^d@00_m4
^d@00ol0003o?<<locc3?006occ3?003o`000?n6NHKoQWV600[oQWV600?o0000oi1_T?n@Ki001?l0
0009olTfb@Ko00003?oc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?ol0ocoo0?l00coo0?l00Co0000on/Djoo[5>_ojaC[0_l0
000=om4^d@03o`000?naC[7o/Dja00[o/Dja00?o0000ohMhQon7N8L02On7N8L01Ol0003oA;]4odBk
A?m4^dCo000000Wo?<<l00?o0000ohIiQ_n6NHH02on6NHH2o`0000gobCK900?o0000onl@koo_4>l0
0_o_4>l00ol0003ol`ccoo<<l`0:oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojaC[o`00
0002oo<<l`;o00002ooA;]400ol0003o/Djaok5>/@0;ok5>/@03o`000?n7N8OoQgR700WoQgR700?o
0000odBkA?l000002Oll`c`00ol0003oQWV6ohIiQP0<ohIiQP03o`000?o9=/WobCK900cobCK900?o
0000onl@koo_4>l00oo_4>l00ol0003ol`ccoo<<l`09oo<<l`03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000oo`3o?ol0o`03Ool0o`0
0ol0003ol`ccoo<<l`03oo<<l`;o00002_oA;]400ol0003o/Djaok5>/@0:ok5>/@03o`000?n7N8Oo
QgR700SoQgR71Ol00008occ3?003o`000?n6NHKoQWV600coQWV600?o0000olTfbOo9=/T02oo9=/T0
0ol0003oka3_onl@k`05onl@k`03o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo0?loo`3o00<oo`3
o0;o00001ooc3?<2o`0000SodBkA00?o0000ok5>/OnaC[402_naC[400ol0003oQgR7ohMhQ`07ohMh
Q`03o`000?n1OX7oPGj100?oPGj10ol00005occ3?003o`000?n6NHKoQWV600_oQWV600?o0000olTf
bOo9=/T03?o9=/T00ol0003oka3_onl@k`06onl@k`03o`000?oc3??ol`cc00Ool`cc00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o0?loo`3o00;oo`3o003o`000?om0_go000000Wol`cc00?o0000om4^dOoA;]401OoA;]42o`0000co
/Dja00?o0000ohMhQon7N8L01On7N8L00ol0003oPGj1oh5nP@07oh5nP@?o000000?o?<<lo`000?n6
NHH03On6NHH00ol0003obCK9olTfb@0<olTfb@03o`000?o_4>ooka3_00Koka3_00?o0000oo<<looc
3?<01_oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?ol0ocoo0?l00Soo0?l0_l00003ood2o@03o`000?oc3??ol`cc00Ool`cc
0_l00004om4^d@03o`000?oL8mcog2?L00;o00002_naC[400ol0003oQgR7ohMhQ`03ohMhQ`;o0000
3On1OX42o`0000goQWV60ol0000=olTfb@03o`000?o_4>ooka3_00Ooka3_00?o0000oo<<looc3?<0
1Ooc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?ol0o`00ol0003oo@;mood2o@04ood2o@03o`000?oc3??ol`cc00Sol`cc0_l0
00000ooA;]7o0000om`Sg004om`Sg003o`000?naC[7o/Dja00Oo/Dja00Co0000ohMhQon7N8OoQgR7
0_l00002ok5>/@03o`000?n1OX7oPGj100coPGj13Ol00003ol0o`003o`000?o9=/WobCK900[obCK9
00?o0000onl@koo_4>l02?o_4>l01?l0003ol`ccoo<<looc3?<4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004oo`3o0;o00002?om0_d00ol0003ol`cc
oo<<l`09oo<<l`03o`000?oL8mcog2?L00Gog2?L0_l00008ok5>/@03o`000?n7N8Oo000000Go/Dja
00?o0000oh5nPOn1OX402on1OX400ol0003oSW6>ohiaSP09ohiaSP03o`000?o0?l3o`3o000;o`3o0
0_l00009olTfb@03o`000?o_4>ooka3_00[oka3_0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ool0oco0000ood2
o@0:ood2o@03o`000?oc3??ol`cc00Sol`cc00?o0000om`Sg?oL8m`01ooL8m`4o`0000?o/Dja0ol0
0007ok5>/@03o`000?n1OX7oPGj100[oPGj100?o0000ohiaS_n>LHh02On>LHh00ol0003o`3o0ol0o
`004ol0o`0;o00001oo9=/T00ol0003oka3_onl@k`0:onl@k`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000om`Sg?oL8m`02?oL8m`0
1?l0003ofRGJomXUf_oJ9MX3o`0000;obcC;00?o0000ok5>/OnaC[401_naC[400ol0003oPGj1oh5n
P@08oh5nP@03o`000?n>LHkoSW6>00[oSW6>00?o0000ol0o`?o0?l001_o0?l000ol0003obCK9olTf
b@04olTfb@03o`000?o_4>ooka3_00Woka3_00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003og2?Lom`Sg008om`Sg003o`000?oJ9M[o
fRGJ00CofRGJ00Go0000ol/dboo;=<_obcC;o`000008ok5>/@03o`000?n1OX7oPGj100OoPGj100?o
0000ohiaS_n>LHh02_n>LHh00ol0003o`3o0ol0o`007ol0o`0;o00001?o9=/T00ol0003oka3_onl@
k`08onl@k`03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo<<looc3?<00ooc3?<0
0ol0003og2?Lom`Sg008om`Sg003o`000?oJ9M[ofRGJ00CofRGJ00?o0000ol/dboo;=</00_o;=</0
0ol0003o/Djaok5>/@07ok5>/@03o`000?n1OX7oPGj100KoPGj100?o0000ohiaS_n>LHh02_n>LHh0
0ol0003o`3o0ol0o`009ol0o`005o`000?o9=/WobCK9olTfbOl000002Oo_4>l00ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_og2?L00?o0000omXUf_oJ9MX01?oJ9MX00ol0003obcC;ol/db`03
ol/db`03o`000?naC[7o/Dja00Oo/Dja00?o0000oh5nPOn1OX401On1OX400ol0003oSW6>ohiaSP0:
ohiaSP03o`000?o0?l3o`3o000Wo`3o01?l00009onl@k`03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oe2_Gom@[e
ooD:mOl000002_oL8m`00ol0003ofRGJomXUfP05omXUfP03o`000?o;=<_obcC;00?obcC;00?o0000
ok5>/OnaC[402?naC[400ol0003oPGj1oh5nP@04oh5nP@03o`000?n>LHkoSW6>00WoSW6>00?o0000
ol0o`?o0?l002?o0?l02o`0000?oka3_00?o0000onl@koo_4>l01_o_4>l00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003og2?Lom`Sg006om`Sg003o`000?oJ9M[ofRGJ
00GofRGJ00?o0000ol/dboo;=</01?o;=</00ol0003o/Djaok5>/@09ok5>/@03o`000?n1OX7oPGj1
00;oPGj100?o0000ohiaS_n>LHh02_n>LHh00ol0003o`3o0ol0o`006ol0o`0;o00001_o_4>l8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oL8mcog2?L00Gog2?L00?o0000omXUf_oJ
9MX01OoJ9MX00ol0003obcC;ol/db`05ol/db`03o`000?naC[7o/Dja00Wo/Dja00Go0000oh5nPOn1
OX7oPGj1o`00000<ohiaSP03o`000?o0?l3o`3o000Co`3o00_l00008onl@k`03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oe2_Gom@[e00Oom@[e00?o0000om`Sg?oL
8m`00ooL8m`00ol0003ofRGJomXUfP06omXUfP03o`000?o;=<_obcC;00GobcC;00?o0000ok5>/Ona
C[402_naC[400ol0003oPGj1o`000004o`0000WoSW6>00?o0000ol0o`?o0?l000_o0?l02o`0000[o
ka3_00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om@[eooD:m@07ooD:m@03o`00
0?oL8mcog2?L00;og2?L00?o0000omXUf_oJ9MX01_oJ9MX00ol0003obcC;ol/db`07ol/db`;o0000
2onaC[400ol0003odRgBom8]dP03om8]dPOo00000_n>LHh00ol0003o`3o0ol0o`002o`0000_oka3_
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooD:mOoe2_D02Ooe
2_D01Ol0003og2?Lom`Sg?oL8mco000000SofRGJ00?o0000ol/dboo;=</01oo;=</00ol0003oiQWV
o`000002o`0000So/Dja00?o0000om8]d_oB;M802_oB;M85o`0000goka3_00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooD:m@03o`000?oL8mco000000WofRGJ00?o
0000ol/dboo;=</01_o;=</00ol0003oiQWVonHIiP03onHIiP?o00001?naC[400ol0003odRgBom8]
dP0=om8]dP03o`000?o_4>ooka3_00goka3_00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oom0_d2o`0000_om@[e00?o0000omXUf_oJ9MX01ooJ9MX00ol0003obcC;ol/db`07
ol/db`03o`000?oV6NKoiQWV00KoiQWV0ol000000onaC[7o0000om8]dP0>om8]dP03o`000?o_4>oo
ka3_00coka3_00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00Koo@;m0_l00009ooD:
m@03o`000?oJ9M[ofRGJ00;ofRGJ1_l00008ol/db`03o`000?oV6NKoiQWV00[oiQWV00?o0000om8]
d_oB;M803ooB;M800ol0003oka3_onl@k`0:onl@k`;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00So
o@;m0_l00007ooD:m@Go00001_oa3_400ol0003obcC;ol/db`05ol/db`03o`000?oV6NKoiQWV00[o
iQWV00?o0000om8]d_oB;M803ooB;M800ol0003oka3_onl@k`07onl@k`?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?om0_goo@;m00[oo@;m0_l00005ooD:m@03o`000?oa3_7ol@ka00Wol@ka00?o0000ol/dboo;
=</00oo;=</00ol0003oiQWVonHIiP0;onHIiP03o`000?oB;M;odRgB00oodRgB00?o0000onl@koo_
4>l01Oo_4>l2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2o@0<ood2o@;o000000?om@[eo`000?l00000
3Ooa3_400ol0003obcC;ol/db`02ol/db`03o`000?oV6NKoiQWV00_oiQWV5?l00004onl@k`;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ood2oOom0_d03_om0_d00ol0003oo@;mo`00000>oo4>l@04o`000?o;=<_obcC;o`0000koiQWV
00?o0000oo<<looc3?<04?oc3?<00ol0003oka3_o`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo@;mood2
o@0=ood2o@05o`000?om0_goo@;mood2oOl000003_oa3_400ol0003obcC;o`00000>onHIiP03o`00
0?oc3??ol`cc017ol`cc00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?om0_goo@;m00coo@;m00?o
0000ood2oOom0_d00_om0_d00ol0003ol@kaoo4>l@0=oo4>l@03o`000?oV6NKoiQWV00WoiQWV1Ol0
000Boo<<l`;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d0
0ol0003ol@kaoo4>l@0<oo4>l@03o`000?oV6NKoiQWV00;oiQWV1ol00004oo`3o003o`000?oc3??o
l`cc00ool`cc00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ood2oOom0_d02?om0_d00ol0003oo@;mood2o@06ood2
o@03o`000?oa3_7ol@ka00col@ka1?l0000<oo`3o003o`000?oc3??ol`cc00col`cc0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Oo
o@;m00?o0000oo4>lOoa3_403?oa3_400ol0003oo0?loo`3o00=oo`3o003o`000?oc3??ol`cc00_o
l`cc00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003ol@kaoo4>l@0:oo4>l@03o`000?ol0ocoo0?l00koo0?l00?o0000oo<<looc
3?<02Ooc3?<2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003oo0?l
oo`3o00?oo`3o003o`000?oc3??ol`cc00Kol`cc0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ood2oOl0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_oc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo0?loo`3o00>oo`3o005o`000?om0_goo@;mood2oOl000000ooc3?<2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o003o`000?om0_go
o@;m00?oo@;m00?o0000oo<<lol000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3
o007oo`3o0;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0oco
o0?l00Goo0?l00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o0?loo`3o003oo`3o003o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?ol0ocoo0?lo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01_l00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Go003o0_ooo`03o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0008o`00o`03oooo0?l00?oo003o00?o003o0_ooo`03o`00o`;oool01Ol00?l0
0oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00
o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00
o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`002Ol00?l00ooo
o`3o003oo`00o`03o`00o`04oooo0?l00?oo003oo`00o`;oool01Ol00?l2oooo00?o003o0_ooo`05
o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo
0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01_l00?l4oooo
0003o`00ooooo`3oool000Wo003o0_ooo`07o`00o`;oool01_l00?l2oooo00?o003o00?oool0o`00
ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003
o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go
003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o003oo`00o`05o`00o`;oool01_l00?l2oooo00;o
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo
0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co
003o0_ooo`0;o`00o`03oooo0?l00?oo003o00Co003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l0
0_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o
00Coool0o`00ooooo`3oool03?l00?l00oooo`3o003oo`00o`03o`00o`;oool01Ol00?l3oooo00;o
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo
0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o0_ooo`04o`00o`?oool00ol00?l3oooo00?o
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo
0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`03o`00o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`02o`00o`;oool0
00?o003ooooo0?ooo`000oooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0ooo
o`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`0=o`00o`;oool01?l00?l00oooo`3o003oo`00
o`08o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00go003o0_ooo`04o`00o`;oool02Ol00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00
o`03oooo0?l00?oo003o00Oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01_l00?l2oooo00Go
003o0_ooo`05o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00
J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003o
o`00o`04o`00o`;oool00ol00?l3oooo00Ko003o0_ooo`08o`00o`;oool01?l00?l2oooo00Ko003o
00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o1Oooo`05o`00o`Koool02Ol00?l2oooo00Oo003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Q
o`00o`Coool03?l00?l3oooo00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(270) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.99 .01 .99 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.991 .009 .991 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.991 .009 .991 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.99 .01 .99 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.95 .05 .95 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.988 .012 .988 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.95 .05 .95 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.947 .053 .947 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.921 .079 .921 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.984 .016 .984 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.901 .099 .901 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.99 .01 .99 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.823 .177 .823 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.832 .168 .832 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.986 .014 .986 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.731 .269 .731 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.876 .124 .876 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.983 .017 .983 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.986 .014 .986 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.945 .055 .945 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.533 .467 .533 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.862 .138 .862 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.723 .277 .723 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.713 .287 .713 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.775 .225 .775 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.888 .112 .888 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.923 .077 .923 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.991 .009 .991 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.698 .302 .698 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.858 .142 .858 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.57 .43 .57 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.91 .09 .91 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.865 .135 .865 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.785 .215 .785 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.846 .154 .846 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.656 .344 .656 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.9 .1 .9 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.727 .273 .727 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.993 .007 .993 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.928 .072 .928 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.659 .341 .659 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.346 .654 .346 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.392 .608 .392 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.956 .044 .956 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.96 .04 .96 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.829 .171 .829 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.99 .01 .99 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.681 .319 .681 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.665 .335 .665 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.445 .555 .445 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.46 .54 .46 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.259 .741 .259 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.652 .348 .652 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.717 .283 .717 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.991 .009 .991 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.699 .301 .699 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.595 .405 .595 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.938 .062 .938 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.357 .643 .357 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.868 .132 .868 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.809 .191 .809 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.443 .557 .443 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.25 .75 .25 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.515 .485 .515 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.033 .967 .033 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.07 .93 .07 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.277 .723 .277 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.361 .639 .361 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.388 .612 .388 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.863 .137 .863 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.223 .777 .223 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.251 .749 .251 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.705 .295 .705 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.945 .055 .945 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.989 .011 .989 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.192 .808 .192 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.252 .748 .252 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.475 .525 .475 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.989 .011 .989 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.667 .333 .667 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.306 .694 .306 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.388 .612 .388 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.072 .928 .072 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.429 .571 .429 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.223 .777 .223 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.944 .056 .944 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.174 .826 .174 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.024 .976 .024 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.805 .195 .805 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.104 .896 .104 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.061 .939 .061 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.537 .463 .537 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.892 .108 .892 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.273 .727 .273 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.075 .925 .075 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.424 .576 .424 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.127 .873 .127 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.174 .826 .174 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.907 .093 .907 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.071 .929 .071 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.008 .992 .008 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.001 .999 .001 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.166 .834 .166 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.091 .909 .091 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.706 .294 .706 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.254 .746 .254 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.988 .012 .988 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.319 .681 .319 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.139 .861 .139 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.164 .836 .164 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.219 .781 .219 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.091 .909 .091 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.051 .949 .051 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.272 .728 .272 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.518 .482 .518 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.989 .011 .989 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.763 .237 .763 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.222 .778 .222 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.317 .683 .317 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.25 .75 .25 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.946 .054 .946 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.103 .897 .103 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.052 .948 .052 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.245 .755 .245 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.604 .396 .604 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.036 .964 .036 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.99 .01 .99 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.123 .877 .123 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.832 .168 .832 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.954 .046 .954 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.536 .464 .536 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.572 .428 .572 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.177 .823 .177 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.881 .119 .881 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.095 .905 .095 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.298 .702 .298 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.532 .468 .532 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.124 .876 .124 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.264 .736 .264 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.365 .635 .365 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.989 .011 .989 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.034 .966 .034 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.989 .011 .989 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.922 .078 .922 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.272 .728 .272 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.224 .776 .224 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.087 .913 .087 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.765 .235 .765 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.204 .796 .204 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.939 .061 .939 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.274 .726 .274 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.3 .7 .3 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.307 .693 .307 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.577 .423 .577 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.744 .256 .744 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.514 .486 .514 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.085 .915 .085 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.113 .887 .113 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.199 .801 .199 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.483 .517 .483 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.797 .203 .797 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.99 .01 .99 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.933 .067 .933 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.212 .788 .212 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.259 .741 .259 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.257 .743 .257 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.806 .194 .806 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.65 .35 .65 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.989 .011 .989 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.497 .503 .497 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.838 .162 .838 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.938 .062 .938 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.155 .845 .155 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.252 .748 .252 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.925 .075 .925 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.215 .785 .215 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.583 .417 .583 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.591 .409 .591 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.411 .589 .411 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.412 .588 .412 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.865 .135 .865 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.787 .213 .787 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.793 .207 .793 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.846 .154 .846 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.353 .647 .353 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.952 .048 .952 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.767 .233 .767 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.389 .611 .389 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.398 .602 .398 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.67 .33 .67 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.452 .548 .452 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.989 .011 .989 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.944 .056 .944 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.823 .177 .823 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.94 .06 .94 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.363 .637 .363 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.916 .084 .916 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.749 .251 .749 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.649 .351 .649 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.99 .01 .99 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.627 .373 .627 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.507 .493 .507 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.99 .01 .99 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.737 .263 .737 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.985 .015 .985 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.991 .009 .991 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.573 .427 .573 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.987 .013 .987 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.563 .437 .563 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.988 .012 .988 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.682 .318 .682 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.842 .158 .842 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.73 .27 .73 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.895 .105 .895 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.915 .085 .915 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.772 .228 .772 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.641 .359 .641 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.759 .241 .759 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.863 .137 .863 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.912 .088 .912 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.874 .126 .874 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.887 .113 .887 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.985 .015 .985 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.777 .223 .777 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.939 .061 .939 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.988 .012 .988 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.953 .047 .953 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.934 .066 .934 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.787 .213 .787 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.943 .057 .943 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.917 .083 .917 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.856 .144 .856 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.988 .012 .988 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.986 .014 .986 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.928 .072 .928 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.989 .011 .989 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.988 .012 .988 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.989 .011 .989 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.988 .012 .988 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.989 .011 .989 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003okQ7^onhAk_l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000onhAk_o^4Nh00_o^4Nh00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?o^4NkokQ7^00?okQ7^00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP06onhAkP03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oa3_7o0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000cokQ7^00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003oo4>l@03o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003ok1?/on`Ck005on`Ck003o`000?o^
4NkokQ7^00_okQ7^0ol00003on`Ck003o`000?om0_goo@;m00coo@;m0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
oo4>lOoa3_400ooa3_400ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003ok1?/on`Ck006
on`Ck003o`000?o^4NkokQ7^00[okQ7^00?o0000on`Ck?o/4n`01?o/4n`00ol0003oo@;mood2o@0:
ood2o@04o`000?oZ5N[ojQGZonXEjP;o00002_ol0o`2o`000003onXEj_l0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?ol0oco
o0?l00Woo0?l00?o0000oo8=l_l000002oom0_d00ol0003ok1?/on`Ck006on`Ck003o`000?o^4Nko
kQ7^00WokQ7^00?o0000on`Ck?o/4n`01_o/4n`00ol0003oo@;mood2o@08ood2o@03o`000?oZ5N[o
jQGZ00CojQGZ0_l00005oo`3o0?o00001?oZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008oo4>l@03o`000?ol0ocoo0?l00Ooo0?l0_l00003oo8=
lP03o`000?om0_goo@;m00Ooo@;m00?o0000on`Ck?o/4n`01oo/4n`00ol0003okQ7^onhAkP09onhA
kP03o`000?o/4ncok1?/00Ook1?/00?o0000ood2oOom0_d01Oom0_d2o`0000WojQGZ0_l000000ool
0oco0000o`000007onXEjP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000oo4>lOoa
3_402?oa3_400ol0003oo0?loo`3o006oo`3o003o`000?ob3O;olPgb00?olPgb00?o0000ood2oOom
0_d01oom0_d00ol0003ok1?/on`Ck008on`Ck003o`000?o^4NkokQ7^00OokQ7^00?o0000on`Ck?o/
4n`02Oo/4n`00ol0003oo@;mood2o@03ood2o@03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000onXEj_oZ
5NX01ooZ5NX00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`o`000005ood2o@;o00002ooa3_42o`0000Koo0?l
00?o0000oo8=l_ob3O801Oob3O800ol0003oo@;mood2o@06ood2o@03o`000?o/4ncok1?/00Sok1?/
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ok1?/on`Ck00;on`Ck005o`000?om0_goo@;mood2oOl0
00003_oZ5NX00ol0003ojQGZonXEjP08onXEjP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o`3o3ol0o`oo0?l?l0
00000oom0_d00ol0003ol@kaoo4>l@0:oo4>l@04o`000?oT6nCoi1_To`0000?oo0?l0_l00008oo8=
lP03o`000?om0_goo@;m00Koo@;m00?o0000on`Ck?o/4n`02Oo/4n`00ol0003okQ7^onhAkP05onhA
kP03o`000?o/4ncok1?/00cok1?/00?o0000ood2oOl000003ooZ5NX00ol0003ojQGZonXEjP08onXE
jP03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l003oo0?l003o`000?om0_go000000_o
l@ka0_l00004on@Ki003o`000?ol0oco000000_olPgb00?o0000ood2oOom0_d01Oom0_d00ol0003o
k1?/on`Ck009on`Ck003o`000?o^4NkokQ7^00CokQ7^00?o0000on`Ck?o/4n`03_o/4n`00ol0003o
jQGZonXEjP0>onXEjP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo0?l?o`3o00
1?o`3o000ol0003ol@kaoo4>l@09oo4>l@03o`000?oT6nCoi1_T00Goi1_T00?o0000oo8=l_ob3O80
2_ob3O800ol0003oo@;mood2o@05ood2o@03o`000?o/4ncok1?/00[ok1?/00?o0000onhAk_o^4Nh0
0oo^4Nh00ol0003ok1?/on`Ck00>on`Ck003o`000?oZ5N[ojQGZ00gojQGZ00?o0000onXEj_oZ5NX0
2_oZ5NX00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?
l005oo0?l003o`000?oa3_7ol@ka00Ool@ka0_l00008on@Ki003o`000?ob3O;olPgb00_olPgb00?o
0000ood2oOom0_d01?om0_d00ol0003ok1?/on`Ck00:on`Ck004o`000?o^4NkokQ7^onhAkP?o0000
3oo/4n`00ol0003ojQGZonXEjP0>onXEjP03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o`3o3ol0o`00Ool0o`00?o0000oo4>lOoa3_401?oa3_42o`0000_oi1_T1?l0
0009oo8=lP03o`000?om0_goo@;m00?oo@;m00?o0000on`Ck?o/4n`02oo/4n`01?l0003okQ7^o`00
0?l00003olhacP;o00003?o/4n`2o`00013ojQGZ00?o0000onXEj_oZ5NX02ooZ5NX00ol0003oo0?l
oo`3o00=oo`3o004o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ol0o`
oo0?l007oo0?l003o`000?oa3_7ol@ka00?ol@ka00?o0000on@Ki?oT6n@02ooT6n@01?l0003o`cc3
ol<l`oo3?<<5o`0000GolPgb00?o0000ood2oOom0_d00_om0_d00ol0003ok1?/on`Ck00<on`Ck003
o`000?o><LkocS7>00GocS7>0_l00008on`Ck0;o00000_o4>l@00ol0003ojQGZonXEjP0=onXEjP03
o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ol0o`oo0?l009oo0?l003o`000?oa3_7ol@ka00;o0000
3OoT6n@00ol0003o`cc3ol<l``07ol<l``Ko00000_om0_d4o`0000gok1?/00?o0000olhac_o><Lh0
1oo><Lh2o`0000Gok1?/00?o0000ol@ka?o4>l@00oo4>l@00ol0003ojQGZonXEjP0<onXEjP03o`00
0?oZ5N[ojQGZ00cojQGZ00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Wol0o`00?o
0000oo4>lOl000003ooT6n@00ol0003o`cc3ol<l``0<ol<l``?o00001?oQ7^43o`0000Wok1?/00?o
0000olhac_o><Lh02_o><Lh2o`000003on`Ck?l0003o000000Ooa3_400?o0000onXEj_oZ5NX02ooZ
5NX00ol0003ojQGZonXEjP0<onXEjP03o`000?ol0ocoo0?l00Koo0?l1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000
on@Ki?oT6n@03_oT6n@00ol0003o`cc3ol<l``0=ol<l``03o`000?oQ7^7ohAkQ00KohAkQ0ol00005
on`Ck003o`000?o><LkocS7>00gocS7>00?o0000ol@ka?o4>l@02?o4>l@00ol0003ojQGZonXEjP09
onXEjP03o`000?oZ5N[ojQGZ00gojQGZ00Co0000oo`3o?ol0ocoo0?l1Ol00003onl@k`03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo0?l?o`3o002oo`3o02o`0000ooi1_T00?o0000ol<l`oo3?<<03Oo3?<<00ol0003ohAkQon4Nh@0:
on4Nh@?o000000?ok1?/o`000?o><Lh03oo><Lh00ol0003oa3_4ol@ka009ol@ka003o`000?oZ5N[o
jQGZ00SojQGZ00?o0000onXEj_oZ5NX03_oZ5NX3o`0000Soka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o`3o3ol0o`00Sol0o`0ol000000oo?
<<oo0000on@Ki00>on@Ki003o`000?o3?<?o`cc300go`cc300?o0000on4NhOoQ7^403OoQ7^400ol0
003ocS7>olhacP0?olhacP03o`000?o4>lCoa3_400[oa3_42ol0000;onXEjPGo00003?o_4>l00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003okA;]o`000?om0_go0000
00Sol0o`0ol00005oll`c`03o`000?oT6nCoi1_T00coi1_T00?o0000ol<l`oo3?<<03Oo3?<<00ol0
003ohAkQon4Nh@0=on4Nh@;o00004?o><Lh00ol0003oa3_4ol@ka00:ol@ka003o`000?no@;oo_d2o
00Oo_d2o00?o0000onXEj_oZ5NX00_oZ5NX7o`0000CoaC[500?o0000onl@koo_4>l02_o_4>l00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003okA;]ondBkOo]4^d2o`00
00Gol0o`0ol00009oll`c`;o00002ooT6n@00ol0003o`cc3ol<l``0=ol<l``03o`000?oQ7^7ohAkQ
00gohAkQ00Co0000oki1__nn@Kko00003oo><Lh00ol0003oa3_4ol@ka009ol@ka003o`000?no@;oo
_d2o00Wo_d2o1?l0000;olDja@03o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000ondBkOo]4^d01?o]4^d00ol0003ol0o`o`000002o`00
00cocc3?00Co0000ojYEZ_l0003o00002OoT6n@00ol0003o`cc3ol<l``0=ol<l``03o`000?oQ7^7o
hAkQ00gohAkQ00Go0000oki1__nn@Kko_T6no`00000=olhacP03o`000?o4>lCoa3_400[oa3_400?o
0000okm0_ono@;l02Ono@;l00ol0003oaC[5olDja@0<olDja@03o`000?o_4>ooka3_00[oka3_00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ondBkOo]4^d01_o]4^d0
0ol0003occ3?oll`c`0<oll`c`03o`000?nZEJ[oZUFZ00;oZUFZ0_l00007on@Ki003o`000?o3?<?o
`cc300co`cc300?o0000on4NhOoQ7^403OoQ7^400ol0003o_T6noki1_P03oki1_P03o`000?o><Lko
cS7>00[ocS7>00?o0000ol@ka?o4>l@02_o4>l@00ol0003o_d2ookm0_`09okm0_`03o`000?o5>/Go
aC[500coaC[500?o0000onl@koo_4>l02oo_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003okA;]ondBk@06ondBk@03o`000?o?<<oocc3?00_occ3?00?o0000ojYE
Z_nZEJX01OnZEJX00ol0003oi1_Ton@Ki003on@Ki003o`000?o3?<?o`cc300go`cc300?o0000on4N
hOoQ7^403OoQ7^400ol0003o_T6noki1_P04oki1_P03o`000?o><LkocS7>00WocS7>00?o0000ol@k
a?o4>l@02Oo4>l@00ol0003o_d2ookm0_`0:okm0_`03o`000?o5>/GoaC[500coaC[500?o0000onl@
koo_4>l02oo_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
kA;]ondBk@07ondBk@03o`000?o?<<oocc3?00_occ3?00?o0000ojYEZ_nZEJX01_nZEJX2o`0000?o
i1_T00?o0000ol<l`oo3?<<03Oo3?<<00ol0003ohAkQon4Nh@0<on4Nh@03o`000?nn@Kko_T6n00Ko
_T6n00?o0000olhac_o><Lh02?o><Lh00ol0003oa3_4ol@ka009ol@ka003o`000?no@;oo_d2o00[o
_d2o00?o0000olDjaOo5>/D03?o5>/D00ol0003oka3_onl@k`0;onl@k`03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000ondBkOo]4^d02?o]4^d00ol0003occ3?oll`c`0:oll`c`03o`00
0?nZEJ[oZUFZ00WoZUFZ0_l000000ooT6nCo0000ol<l``0<ol<l``?o00003_oQ7^400ol0003o_T6n
oki1_P07oki1_P03o`000?o><LkocS7>00OocS7>00?o0000ol@ka?o4>l@02Oo4>l@00ol0003o_d2o
okm0_`0;okm0_`03o`000?o5>/GoaC[500coaC[500?o0000onl@koo_4>l02_o_4>l00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000ondBkOo]4^d02_o]4^d00ol0003occ3?oll`
c`09oll`c`03o`000?nZEJ[oZUFZ00_oZUFZ00?o0000ol<l`oo3?<<02_o3?<<2o`0000?oVVFJ00?o
0000on4NhOoQ7^402_oQ7^400ol0003o_T6noki1_P09oki1_P03o`000?o><LkocS7>00KocS7>00?o
0000ol@ka?o4>l@02?o4>l@00ol0003o_d2ookm0_`0<okm0_`03o`000?o5>/GoaC[500coaC[500?o
0000onl@koo_4>l02_o_4>l00ol0003oo@;mood2o@04ood2o@Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000oll`coo?<<l02?o?<<l0
0ol0003oZUFZojYEZP0<ojYEZP03o`000?o3?<?o`cc300So`cc30_l00006oiYUVP;o00002_oQ7^40
0ol0003o_T6noki1_P0:oki1_P03o`000?o><LkocS7>00GocS7>00?o0000ol@ka?o4>l@02?o4>l@0
0ol0003o_d2ookm0_`0<okm0_`03o`000?o5>/GoaC[500coaC[500?o0000onl@koo_4>l02oo_4>l0
0ol0003oo@;mo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
ondBk@03o`000?o?<<oocc3?00Oocc3?00?o0000ojYEZ_nZEJX03_nZEJX00ol0003o`cc3ol<l``04
ol<l``?o00002_nJIIX00ol0003ohAkQon4Nh@07on4Nh@03o`000?nn@Kko_T6n00_o_T6n00?o0000
olhac_o><Lh00oo><Lh00ol0003oa3_4ol@ka009ol@ka003o`000?no@;oo_d2o00co_d2o00?o0000
olDjaOo5>/D03?o5>/D00ol0003oka3_onl@k`0;onl@k`;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003okA;]ondBk@0<ondBk@03o`000?o?<<oocc3?00Oocc3?00?o0000ojYEZ_nZEJX03onZEJX01?l0
003o`cc3ol<l`oo3?<<2o`0000koVVFJ0_l00006on4Nh@03o`000?nn@Kko_T6n00go_T6n00?o0000
olhac_o><Lh00_o><Lh00ol0003oa3_4ol@ka008ol@ka003o`000?no@;oo_d2o00co_d2o0ol0000=
olDja@03o`000?o_4>ooka3_00_oka3_00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ookA;]00?o0000oll`coo?<<l01_o?<<l00ol0003oZUFZojYEZP0@ojYEZPCo00004_nJIIX00ol0
003ohAkQon4Nh@03on4Nh@03o`000?nn@Kko_T6n00ko_T6n00Go0000olhac_o><LkocS7>o`000005
ol@ka0Oo00003?no@;l01Ol0003oT6n@oi1_T?n@Ki3o000000coaC[500?o0000onl@koo_4>l02?o_
4>l3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ookA;]00?o0000oll`coo?<<l01_o?<<l00ol0003oZUFZojYEZP0=
ojYEZP?o000000CoKI9]o`000?l0003o00004onJIIX2o`0000;ohAkQ00?o0000oki1__nn@Kh04?nn
@Kh00ol0003ocS7>o`000006o`0000OoZeB[00?o0000okm0_ono@;l02?no@;l00ol0003oT6n@oi1_
T003oi1_T0;o00002?o5>/D3o`0000Koka3_1?l00002onXEjP03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003ol@kao`000?o8=lP3o`0000gokA;]00?o0000oll`coo?<<l01?o?<<l00ol0003oZUFZojYE
ZP0;ojYEZP?o00000om]TVd01Ol0003oK9=/o`000?mA[U7o000001CoVVFJ00?o0000on4NhOl00000
4onn@Kh00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?no@;oo_d2o00Go_d2o0_l00008oi1_T003o`00
0?o5>/GoaC[500Go00000oo2?L800ol0003oka3_onl@k`03o`0000OojQGZ00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?oa3_7ol@kao`0000Cob3O80ol0000:ondBk@03o`000?o?<<oocc3?00?occ3?
00?o0000ojYEZ_nZEJX02OnZEJX3o`0000GoKI9]00Co0000ofbCK?m/Tfco00000_mA[U400ol0003o
VVFJoiYUVP0BoiYUVP03o`000?nn@Kko_T6n01;o_T6n00?o0000oj]DZon[E:/03_n[E:/00ol0003o
_d2ookm0_`03okm0_`03o`000?n@Ki3oT6n@00WoT6n@0_l00009ol8m`P;o00002_oZ5NX00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo4>lOoa3_7ol@kao`000007olPgb0;o00001oo]4^d5o`0000;o
cc3?00?o0000ojYEZ_nZEJX01_nZEJX3o`0000SoKI9]00Co0000ofbCK?m/Tfco00000omA[U400ol0
003oVVFJoiYUVP0AoiYUVP03o`000?nn@Kko_T6n017o_T6n00?o0000oj]DZon[E:/04?n[E:/01Ol0
003o_d2ookm0_ono@;oo000000coT6n@00?o0000ol8m`_o2?L802?o2?L800ol0003ojQGZonXEjP0:
onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Col@ka00?o0000olPgb?o8=lP01oo8=lP3o`00
0004ondBkOl0003o0000o`0000Go/Tfb0_l00006ojYEZP?o00002_m]TVd01Ol0003oK9=/ofbCK?m/
Tfco000000CoDJiA00?o0000oiYUV_nJIIX04?nJIIX00ol0003o_T6noki1_P0Aoki1_P03o`000?n[
E:_oZeB[017oZeB[00?o0000okm0_ol000003On@Ki000ol0003o`Sg2ol8m`P08ol8m`P03o`000?oZ
5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00Col@ka00?o0000
olPgb?o8=lP02_o8=lP00ol0003o/Tfbok9=/P08ok9=/P03o`000?nZEJ[oZUFZ00?o00003Om]TVd0
1Ol0003oK9=/ofbCK?m/Tfco000000GoDJiA00?o0000oiYUV_nJIIX03onJIIX00ol0003o_T6noki1
_P0Aoki1_P03o`000?n[E:_oZeB[01;oZeB[00?o0000oi1_T?n@Ki003?n@Ki000ol0003o`Sg2ol8m
`P08ol8m`P03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo4>lOoa3_401Ooa3_40
0ol0003ob3O8olPgb00:olPgb003o`000?nbCK;o/Tfb00Wo/Tfb0_l0000?offBK@03o`000?m/Tfco
K9=/00;oK9=/00?o0000oe6^DOmA[U401?mA[U400ol0003oVVFJoiYUVP0=oiYUVP?o00004Onn@Kh0
0ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n@Ki3oT6n@00_oT6n@00?o0000ol8m`_o2?L802Oo2?L80
0ol0003ojQGZonXEjP0;onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000oo`3o?ol0ocoo0?lo`000008ood2o@;o00002?oa3_40
0ol0003ob3O8olPgb00:olPgb003o`000?nbCK;o/Tfb00Wo/Tfb00?o0000offBKOm]TVd03Om]TVd0
0ol0003oK9=/ofbCK003ofbCK003o`000?mA[U7oDJiA00GoDJiA00?o0000oiYUV_nJIIX02_nJIIX2
o`0000?oR7N800?o0000oki1__nn@Kh03_nn@Kh00ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?n@Ki3o
T6n@00_oT6n@00?o0000ol8m`_o2?L802Oo2?L800ol0003ojQGZonXEjP0;onXEjP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000oo`3
o?ol0o`00ool0o`2o`0000Goo@;m00?o0000oo4>lOoa3_401ooa3_42o`0000_ob3O800?o0000ok9=
/_nbCK802onbCK800ol0003oKI9]offBK@0<offBK@03o`000?m/TfcoK9=/00?oK9=/00?o0000oe6^
DOmA[U401_mA[U400ol0003oVVFJoiYUVP07oiYUVP;o00001_n8MhP2o`0000ko_T6n00?o0000oj]D
Zon[E:/04on[E:/00ol0003oT6n@oi1_T00;oi1_T003o`000?o2?L;o`Sg200Wo`Sg200?o0000onXE
j_oZ5NX03?oZ5NX00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?ol0ocoo0?l00Koo0?l00Go0000ood2oOom0_goo@;mo`000009oo4>
l@03o`000?oL8mco000000_ob3O800?o0000ok9=/_nbCK802onbCK800ol0003oKI9]offBK@0;offB
K@03o`000?m/TfcoK9=/00CoK9=/00?o0000oe6^DOmA[U401omA[U400ol0003oVVFJoiYUVP05oiYU
VP03o`000?n8MhSoR7N800SoR7N800?o0000oki1__nn@Kh02_nn@Kh00ol0003oZeB[oj]DZ`0Doj]D
Z`03o`000?n@Ki3oT6n@00_oT6n@00?o0000ol8m`_o2?L802Oo2?L800ol0003ojQGZonXEjP0<onXE
jP03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mo`000009oo4>l@04o`000?oL8mcog2?Lo`00
00_ob3O800?o0000ok9=/_nbCK802onbCK800ol0003oKI9]offBK@0;offBK@03o`000?m/TfcoK9=/
00CoK9=/00?o0000oe6^DOmA[U402?mA[U400ol0003oVVFJoiYUVP02oiYUVP;o00003?n8MhP2o`00
00[o_T6n00?o0000oj]DZon[E:/05?n[E:/00ol0003oT6n@oi1_T00;oi1_T003o`000?o2?L;o`Sg2
00Wo`Sg200?o0000onXEj_oZ5NX03OoZ5NX00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`02Ool0o`00ol0003ol@kaoo4>l@07oo4>l@03
o`000?oL8mcog2?L00;og2?L00?o0000olPgb?o8=lP02?o8=lP00ol0003o/Tfbok9=/P0<ok9=/P03
o`000?m]TVgoKI9]00WoKI9]00?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oDJiAoe6^D@09oe6^D@04
o`000?nJII[o0000o`00013oR7N80_l00008oki1_P03o`000?n[E:_oZeB[01CoZeB[0ol0000;oi1_
T003o`000?o2?L;o`Sg200Wo`Sg200?o0000onXEj_oZ5NX03OoZ5NX01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ol@kaoo4>l@06oo4>l@03o`000?oL8mcog2?L00?og2?L00?o0000olPg
b?o8=lP02?o8=lP00ol0003o/Tfbok9=/P0;ok9=/P;o00002_m]TVd00ol0003oK9=/ofbCK006ofbC
K003o`000?mA[U7oDJiA00[oDJiA00?o0000ohQgR?n8MhP04_n8MhP00ol0003o_T6noki1_P04oki1
_P03o`000?n[E:_oZeB[01GoZeB[00?o0000oi9]T_nBKI801Ol00005oi1_T003o`000?o2?L;o`Sg2
00[o`Sg200?o0000onXEj_oZ5NX03_oZ5NX3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ol@kaoo4>l@04oo4>l@03
o`000?oL8mcog2?L00Cog2?L00?o0000olPgb?o8=lP01oo8=lP00ol0003o/Tfbok9=/P0;ok9=/P04
o`000?maSW7oLHiao`0000WoKI9]00?o0000ofbCK?m/Tf`01_m/Tf`00ol0003oDJiAoe6^D@0:oe6^
D@03o`000?n8MhSoR7N801?oR7N80_l00003oki1_PCo00005?n[E:/00ol0003oTVfBoi9]TP06oi9]
TPCo000000?oT6n@o`000?o2?L802oo2?L800ol0003ojQGZonXEjP0>onXEjP03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000oo`3o?ol
0o`02ool0o`00ol0003ol@kaoo4>l@03oo4>l@03o`000?oL8mcog2?L00Gog2?L00?o0000olPgb?o8
=lP01oo8=lP00ol0003o/Tfbok9=/P09ok9=/P;o00001?maSW400ol0003oKI9]offBK@05offBK@03
o`000?m/TfcoK9=/00OoK9=/00?o0000oe6^DOmA[U402_mA[U400ol0003oR7N8ohQgR00EohQgR003
o`000?nn@Kko000000CoUfRG0ol0000@oj]DZ`03o`000?nBKI;oTVfB00_oTVfB0_l0000<ol8m`P03
o`000?oZ5N[ojQGZ00cojQGZ0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo4>lOoa3_400_oa3_400ol0003og2?L
om`Sg006om`Sg003o`000?o8=lSob3O800Oob3O800?o0000ok9=/_nbCK802?nbCK800ol0003oLHia
og6>L@05og6>L@03o`000?m]TVgoKI9]00CoKI9]00?o0000ofbCK?m/Tf`01om/Tf`00ol0003oDJiA
oe6^D@0:oe6^D@03o`000?n8MhSoR7N801KoR7N800?o0000oiMXUonGJ9L01_nGJ9L3o`0000coZeB[
00?o0000oi9]T_nBKI803OnBKI800ol0003o`Sg2ol8m`P09ol8m`PGo00002OoZ5NX2o`000003ondB
kOl0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000oo`3o?ol0o`03?ol0o`3o`000003oo4>lOl0003og2?L00Wog2?L00?o0000olPgb?o8=lP01_o8
=lP00ol0003o/Tfbok9=/P07ok9=/P03o`000?maSW7oLHia00OoLHia00?o0000offBKOm]TVd00_m]
TVd00ol0003oK9=/ofbCK008ofbCK003o`000?mA[U7oDJiA00WoDJiA00?o0000ohQgR?n8MhP05on8
MhP00ol0003oUfRGoiMXU`09oiMXU`?o00002On[E:/00ol0003oTVfBoi9]TP0>oi9]TPKo00001?o2
?L800ol0003obCK9olTfb@03olTfb@Go00000_oZ5NX2o`0000CokA;]00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o00<
oo`3o005o`000?oV6NKoiQWVonHIi_l000002ooL8m`00ol0003ob3O8olPgb006olPgb003o`000?nb
CK;o/Tfb00Go/Tfb0_l0000;og6>L@04o`000?m]TVgoKI9]o`0000_oK9=/00?o0000oe6^DOmA[U40
2OmA[U400ol0003oR7N8ohQgR00FohQgR003o`000?nGJ9OoUfRG00goUfRG0ol00005oj]DZ`03o`00
0?nBKI;oTVfB00ooTVfB00?o0000ojAKY?nTFj@00onTFj@4o`0000_obCK90_l00006ondBk@03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000oo`3o?ol0o`02ool0o`00ol0003oiQWVonHIiP02onHIiPko00001_o8=lP00ol0003o/Tfbok9=
/P05ok9=/P03o`000?maSW7oLHia00coLHia00?o0000offBKOl000002om/Tf`00ol0003oDJiAoe6^
D@07oe6^D@?o00006?n8MhP00ol0003oUfRGoiMXU`0@oiMXU`?o000000?oZeB[o`000?nBKI804?nB
KI800ol0003oY5^TojAKY007ojAKY003o`000?o9=/WobCK900[obCK900?o0000ondBkOo]4^d01Oo]
4^d00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?ol0ocoo0?l00Woo0?l0_l00005onHIiP03o`000?niA[Wo^DJi00_o^DJi0_l00004
olPgb003o`000?nbCK;o/Tfb00?o/Tfb0_l0000@og6>L@03o`000?m/TfcoK9=/00[oK9=/00?o0000
oe6^DOmA[U400omA[U44o`0000;o><Lh00?o0000ohQgR?n8MhP05On8MhP00ol0003oUfRGoiMXU`0D
oiMXU`03o`000?nBKI;oTVfB013oTVfB00?o0000ojAKY?nTFj@01onTFj@00ol0003obCK9olTfb@0:
olTfb@03o`000?o]4^gokA;]00GokA;]00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo0?loo`3o008oo`3o003o`000?oV6NKoiQWV
00GoiQWV00?o0000okU6^OniA[T03OniA[T6o`0000?o/Tfb00?o0000og6>LOmaSW404?maSW400ol0
003oK9=/ofbCK00:ofbCK003o`000?mA[U7o000000?o00001olhacP00ol0003oR7N8ohQgR00DohQg
R003o`000?nGJ9OoUfRG01CoUfRG00?o0000oi9]T_nBKI803onBKI800ol0003oY5^TojAKY008ojAK
Y003o`000?o9=/WobCK900[obCK900?o0000ondBkOo]4^d01Oo]4^d00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onHIi_oV6NH01_oV6NH00ol0003o^DJiokU6^@0=okU6^@03o`000?nWF:OoYeRW00?o
YeRW00?o0000ok9=/_l000004omaSW44o`0000WoK9=/0_l0000<ocS7>003o`000?n8MhSoR7N801?o
R7N800?o0000oiMXUonGJ9L05OnGJ9L00ol0003oTVfBoi9]TP0>oi9]TP03o`000?nTFjCoY5^T00So
Y5^T00?o0000olTfbOo9=/T02Oo9=/T00ol0003okA;]ondBk@07ondBk@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006oo`3o003o`00
0?oV6NKoiQWV00SoiQWV00?o0000okU6^OniA[T02oniA[T00ol0003oYeRWojMHY`05ojMHY`03o`00
0?maSW7oLHia01;oLHia00Co0000odFjAOm5^TGoAKY51Ol00003ofbCK003o`000?lhacSo><Lh00go
><Lh0ol0000@ohQgR0;o00006?nGJ9L00ol0003oTVfBoi9]TP0=oi9]TP03o`000?nTFjCoY5^T00Wo
Y5^T00?o0000olTfbOo9=/T02Oo9=/T00ol0003okA;]ondBk@07ondBk@03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_oiQWV00?o0000okU6^OniA[T02_niA[T00ol0003oYeRWojMHY`06ojMHY`03o`00
0?maSW7oLHia017oLHia00?o0000odFjAOm5^TD01om5^TD3o`00013o><Lh00?o0000obgB;Ol]dRd0
1Ol00009ohQgR0;o000000?oA[U6o`000?nGJ9L05onGJ9L00ol0003oTVfBoi9]TP0=oi9]TP03o`00
0?nTFjCoY5^T00WoY5^T00?o0000olTfbOo9=/T02?o9=/T2o`0000[okA;]00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?oc3??ol`cc00;ol`cc00?o0000onHIi_oV6NH02OoV6NH00ol0003o^DJiokU6
^@0:okU6^@03o`000?nWF:OoYeRW00OoYeRW00?o0000og6>LOmaSW403omaSW400ol0003oAKY5odFj
A@0:odFjA@03o`000?lhacSo><Lh00go><Lh00?o0000obgB;Ol]dRd01_l]dRd4o`0000CoR7N800?o
0000odJiA_m6^DH00_m6^DH00ol0003oUfRGoiMXU`0FoiMXU`03o`000?nBKI;oTVfB00_oTVfB00?o
0000ojAKY?nTFj@02onTFj@00ol0003obCK9olTfb@06olTfb@03o`000?oK9=_o000000[okA;]00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000onHIi_oV6NH02?oV6NH=
o`0000[oYeRW00?o0000og6>LOmaSW403omaSW400ol0003oAKY5odFjA@0;odFjA@03o`000?lhacSo
><Lh00co><Lh00?o0000obgB;Ol]dRd02_l]dRd4o`0000GoA[U600?o0000oiMXUonGJ9L05_nGJ9L0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?nTFjCoY5^T00coY5^T00?o0000olTfbOo9=/T01?o9=/T2
o`0000?ofbCK00?o0000ondBkOo]4^d02?o]4^d00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo<<
looc3?<00ooc3?<00ol0003oiQWVonHIiP07onHIiP03o`000?nfBKKo]TVf00Wo]TVf00?o0000ojMH
YonWF:L02OnWF:L00ol0003oLHiaog6>L@0=og6>L@03o`000?m5^TGoAKY500coAKY500?o0000ocS7
>?lhacP03?lhacP00ol0003o;M8]obgB;@0;obgB;@03o`000?lFjAKo000000KoA[U600?o0000oiMX
UonGJ9L05_nGJ9L00ol0003oTVfBoi9]TP09oi9]TP03o`000?nTFjCoY5^T00coY5^T00?o0000olTf
bOo9=/T00oo9=/T00ol0003ofbCKom/Tf`03om/Tf`03o`000?o]4^gokA;]00SokA;]00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?oc3??ol`cc00Col`cc00?o0000onHIi_oV6NH01_oV6NH00ol0003o
]TVfokI9]P08okI9]P03o`000?nWF:OoYeRW00_oYeRW00?o0000og6>LOmaSW402?maSW44o`0000oo
AKY500?o0000ocS7>?lhacP02olhacP00ol0003o;M8]obgB;@0;obgB;@04o`000?lFjAKo5^TFo`00
00OoA[U600?o0000oiMXUonGJ9L05OnGJ9L00ol0003oTVfBoi9]TP08oi9]TP03o`000?nTFjCoY5^T
00goY5^T00?o0000olTfbOo9=/T00_o9=/T00ol0003ofbCKom/Tf`05om/Tf`03o`000?o]4^gokA;]
00OokA;]00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?oc3??ol`cc00Gol`cc00?o0000onHIi_oV
6NH01OoV6NH00ol0003o]TVfokI9]P08okI9]P03o`000?nWF:OoYeRW00_oYeRW00?o0000og6>LOma
SW400omaSW45o`0000?oA[U600?o0000odFjAOm5^TD03_m5^TD00ol0003o><LhocS7>00:ocS7>003
o`000?l]dRgo;M8]00[o;M8]00Go0000oaKY5_lFjAKo5^TFo`000007odJiAP03o`000?nGJ9OoUfRG
01GoUfRG00?o0000oi9]T_nBKI802?nBKI800ol0003oY5^TojAKY00=ojAKY003o`000?o9=/WobCK9
00;o00002?oK9=/00ol0003okA;]ondBk@08ondBk@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oV6NKoiQWV00Go
iQWV00?o0000okI9]_nfBKH02?nfBKH00ol0003oYeRWojMHY`0<ojMHY`Go00002Om6^DH00ol0003o
AKY5odFjA@0<odFjA@;o00003?lhacP00ol0003o;M8]obgB;@0:obgB;@05o`000?lFjAKo5^TFoaKY
5_l000002?m6^DH00ol0003oUfRGoiMXU`0DoiMXU`?o00001onBKI800ol0003oY5^TojAKY00>ojAK
Y003o`000?o9=/Wo000000_ofbCK00?o0000ondBkOo]4^d01_o]4^d00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003oiQWVonHIiP04onHIiP03o`000?nfBKKo]TVf00Oo
]TVf00?o0000ojMHYonWF:L03?nWF:L01?l0003oLHiaog6>LOl0000;odJiAP03o`000?m5^TGoAKY5
00_oAKY500Co0000oa;]4_lBkA;o00002_lhacP00ol0003o;M8]obgB;@0:obgB;@03o`000?lFjAKo
5^TF00;o5^TF00?o0000odJiA_m6^DH01_m6^DH00ol0003oUfRGoiMXU`0AoiMXU`?o00000omSW6<0
0ol0003oTVfBoi9]TP04oi9]TP03o`000?nTFjCoY5^T00goY5^T1?l0000;om/Tf`03o`000?o]4^go
kA;]00GokA;]00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oc3??ol`cc00Kol`cc00Co0000onHI
i_oV6NKoiQWV1?l00008okI9]P03o`000?nWF:OoYeRW00_oYeRW00?o0000og6>LOmaSW400_maSW40
0ol0003oA[U6odJiAP08odJiAP03o`000?m5^TGoAKY500[oAKY500?o0000oa;]4_lBkA800_lBkA80
0ol0003o><LhocS7>003ocS7>0Go00002ol]dRd00ol0003o5^TFoaKY5P03oaKY5P03o`000?m6^DKo
A[U600OoA[U600?o0000oiMXUonGJ9L03_nGJ9L2o`0000OoHiaS00?o0000oi9]T_nBKI800_nBKI80
0ol0003oY5^TojAKY00=ojAKY003o`000?o6>LKoaSW600;oaSW600?o0000om/TfooK9=/02OoK9=/0
0ol0003okA;]ondBk@03ondBk@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`07oo<<
l`?o00001?oB;M800ol0003o]TVfokI9]P05okI9]P03o`000?nWF:OoYeRW00[oYeRW00?o0000og6>
LOmaSW400omaSW400ol0003oA[U6odJiAP09odJiAP03o`000?m5^TGoAKY500SoAKY500?o0000oa;]
4_lBkA801?lBkA85o`0000Co0?l000?o0000obgB;Ol]dRd02Ol]dRd00ol0003o5^TFoaKY5P03oaKY
5P03o`000?m6^DKoA[U600SoA[U600?o0000oiMXUonGJ9L02_nGJ9L3o`0000[oHiaS00Go0000oi9]
T_nBKI;oTVfBo`00000>ojAKY003o`000?o6>LKoaSW600CoaSW60_l00009om/Tf`03o`000?o]4^go
kA;]00;okA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000om8]
d_oB;M801OoB;M800ol0003o]TVfokI9]P03okI9]P03o`000?nWF:OoYeRW00[oYeRW00?o0000og6>
LOmaSW401?maSW400ol0003oA[U6odJiAP09odJiAP03o`000?m5^TGoAKY500OoAKY500?o0000oa;]
4_lBkA801OlBkA800ol0003o0?l0o`3o0007o`3o0003o`000?l]dRgo;M8]00Oo;M8]00?o0000oaKY
5_lFjAH01?lFjAH00ol0003oA[U6odJiAP08odJiAP03o`000?nGJ9OoUfRG00SoUfRG0_l0000>of>L
H`Co00003?nTFj@2o`0000WoaSW600?o0000om/TfooK9=/01ooK9=/01?l0003okA;]ondBkOl0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003odRgBom8]dP07om8]dP;o00000onfBKH00ol0
003oYeRWojMHY`09ojMHY`03o`000?maSW7oLHia00KoLHia00?o0000odJiA_m6^DH02Om6^DH00ol0
003oAKY5odFjA@05odFjA@03o`000?lBkA;o4^dB00Ko4^dB00?o0000o`3o0?l0o`002?l0o`000ol0
003o;M8]obgB;@06obgB;@03o`000?lFjAKo5^TF00Co5^TF00?o0000odJiA_m6^DH02Om6^DH4o`00
00?oUfRG0ol0000@of>LH`05o`000?nl@kco_4>loka3_?l000002_nTFj@00ol0003oaSW6olHiaP0:
olHiaPKo00000ooK9=/00ol0003okA;]o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo<<looc3?<01?oc3?<00ol0
003odRgBom8]dP0:om8]dP04o`000?nfBKKo]TVfo`0000[oYeRW00?o0000og6>LOmaSW401omaSW40
0ol0003oA[U6odJiAP09odJiAP03o`000?m5^TGoAKY500CoAKY500?o0000oa;]4_lBkA801olBkA80
0ol0003o0?l0o`3o0008o`3o00;o00001_l]dRd00ol0003o5^TFoaKY5P05oaKY5P03o`000?m6^DKo
A[U600WoA[U600Co0000ocO8=olgb3Oo=lPg0ol0000Bof>LH`03o`000?nl@kco_4>l00?o_4>l0_l0
0006ojAKY0;o00003Oo6>LH00ol0003ol@kaoo4>l@03oo4>l@Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo<<looc3?<00ooc3?<0
0ol0003odRgBom8]dP0<om8]dP;o00002_nWF:L00ol0003oLHiaog6>L@08og6>L@03o`000?m6^DKo
A[U600[oA[U600?o0000odFjAOm5^TD00_m5^TD00ol0003o4^dBoa;]4P08oa;]4P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`gb3@03o`000?l]dRgo;M8]00;o;M8]00?o0000oaKY5_lFjAH01_lFjAH0
0ol0003oA[U6odJiAP08odJiAP03o`000?lgb3Oo=lPg00Co=lPg00?o0000of>LHomSW6<03omSW6<0
0ol0003o_4>loka3_006oka3_0;o00000onTFj@00ol0003oaSW6olHiaP0=olHiaP03o`000?oa3_7o
l@ka00Ool@ka0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003ol`ccoo<<l`02oo<<l`03o`000?oB;M;odRgB
00kodRgB00?o0000ojMHYonWF:L01onWF:L00ol0003oLHiaog6>L@0:og6>L@03o`000?m6^DKoA[U6
00WoA[U600Go0000odFjAOm5^TGoAKY5o`00000;oa;]4P03o`000?l0o`3o0?l000Co0?l00_l00005
o`gb3@05o`000?l]dRgo;M8]obgB;Ol000002?lFjAH00ol0003oA[U6odJiAP08odJiAP03o`000?lg
b3Oo=lPg00Go=lPg00?o0000of>LHomSW6<03_mSW6<00ol0003o_4>loka3_008oka3_003o`000?nT
FjCo000000ooaSW600?o0000oo4>lOoa3_402?oa3_401?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?oc3??ol`cco`00017odRgB00?o0000ojMHYonWF:L01_nWF:L00ol0003oLHia
og6>L@0;og6>L@03o`000?m6^DKoA[U600WoA[U600Co0000odFjAOm5^TGo00003?lBkA800ol0003o
0?l0o`3o0002o`3o00;o00002?l=lPd00ol0003o;M8]o`000009oaKY5P03o`000?m6^DKoA[U600So
A[U600?o0000ocO8=olgb3L01Olgb3L00ol0003oHiaSof>LH`0=of>LH`03o`000?nl@kco_4>l00[o
_4>l00?o0000olHia_o6>LH03_o6>LH00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Bom8]dP03o`00
0?nWF:OoYeRW00CoYeRW00?o0000og6>LOmaSW403?maSW400ol0003oA[U6odJiAP0:odJiAP?o0000
3?lBkA800ol0003o0?l0o`3o0002o`0000_o3O8=00?o0000oaKY5_lFjAH02?lFjAH00ol0003oA[U6
odJiAP07odJiAP03o`000?lgb3Oo=lPg00Oo=lPg00?o0000of>LHomSW6<03?mSW6<00ol0003o_4>l
oka3_00;oka3_0;o00003_o6>LH00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo8=l_ob3O800oob3O800ol0003odRgBom8]dP0?om8]dP?o00000onW
F:L00ol0003oLHiaog6>L@0>og6>L@03o`000?m6^DKoA[U600SoA[U600Co0000oa[U6_lJiA[o6^DJ
0_l0000:oa;]4P?o00003Ol=lPd00ol0003o5^TFoaKY5P08oaKY5P03o`000?m6^DKoA[U600OoA[U6
00?o0000ocO8=olgb3L01olgb3L00ol0003oHiaSof>LH`0;of>LH`03o`000?nl@kco_4>l00co_4>l
00?o0000on<Lhol000000_l0000:olHiaP03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP04oo8=lP03o`000?oB;M;odRgB00codRgB0_l0
0003ok]4^`03o`000?nWF:Oo0000017oLHia00?o0000odJiA_m6^DH01om6^DH00ol0003o6^DJoa[U
6P04oa[U6P;o00002?lBkA800ol0003o3O8=o`gb3@0>o`gb3@;o00002?lFjAH00ol0003oA[U6odJi
AP06odJiAP03o`000?lgb3Oo=lPg00Wo=lPg00?o0000of>LHomSW6<02OmSW6<00ol0003o_4>loka3
_00=oka3_003o`000?oS7>?ohacS00;ohacS0ol00007olHiaP03o`000?oa3_7ol@ka00Ool@ka00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP05oo8=lP03o`000?oB;M;o
dRgB00WodRgB0_l00006ok]4^`03o`000?maSW7oLHia013oLHia00?o0000odJiA_m6^DH01_m6^DH0
0ol0003o6^DJoa[U6P07oa[U6P03o`000?lBkA;o4^dB00Co4^dB0ol0000>o`gb3@03o`000?l0o`3o
0?l000?o00001OlFjAH00ol0003oA[U6odJiAP06odJiAP03o`000?lgb3Oo=lPg00[o=lPg00?o0000
of>LHomSW6<02?mSW6<00ol0003o_4>loka3_00=oka3_003o`000?oS7>?ohacS00GohacS0ol00004
olHiaP03o`000?oa3_7ol@ka00Ool@ka00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003olPgboo8=lP06oo8=lP03o`000?oB;M;odRgB00GodRgB0ol00008ok]4^`03o`000?maSW7oLHia
017oLHia00Co0000odJiA_m6^DKoA[U61?l0000;oa[U6P;o000000Co4^dBo`000?l0003o00000olS
g2<2o`0000_o3O8=00?o0000o`3o0?l0o`001?l0o`02o`0000?o5^TF00?o0000odJiA_m6^DH01_m6
^DH00ol0003o=lPgocO8=`0:ocO8=`03o`000?mSW6?oHiaS00OoHiaS00?o0000oka3_?nl@k`03_nl
@k`00ol0003ohacSon<Lh`08on<Lh`Co00002_oa3_400ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003olPgboo8=lP07oo8=lP03o`000?oB;M;odRgB00;odRgB0_l0000<ok]4^`03o`000?maSW7o
LHia013oLHia1?l00003ocW6>@03o`000?lJiA[o6^DJ00_o6^DJ00?o0000ob?L8olSg2<01_lSg2<0
0ol0003o3O8=o`gb3@07o`gb3@03o`000?l0o`3o0?l000Oo0?l03?l0000>ocO8=`03o`000?mSW6?o
HiaS00KoHiaS00?o0000oka3_?nl@k`03_nl@k`00ol0003ohacSon<Lh`0;on<Lh`03o`000?oa3_7o
l@ka00Ool@ka00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00WolPgb00Co0000om8]
d_l0003o00003_nkA;/00ol0003oLHiaog6>L@0?og6>L@03o`000?liaSWo>LHi00Ko>LHi00?o0000
oa[U6_lJiAX02_lJiAX00ol0003o8m`Sob?L8`07ob?L8`;o00001_l=lPd00ol0003o0?l0o`3o0008
o`3o0003o`000?m</dcoC;=<00SoC;=<00?o0000ocO8=olgb3L03?lgb3L00ol0003oHiaSof>LH`05
of>LH`03o`000?nl@kco_4>l00oo_4>l0_l0000=on<Lh`03o`000?oa3_7ol@ka00Kol@ka00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00[olPgb00?o0000ok]4^onkA;/03_nkA;/00ol0
003oLHiaog6>L@0>og6>L@03o`000?liaSWo>LHi00Oo>LHi00?o0000oa[U6_lJiAX02_lJiAX00ol0
003o8m`Sob?L8`09ob?L8`;o00000ol=lPd00ol0003o0?l0o`3o0009o`3o0003o`000?m</dcoC;=<
00WoC;=<00?o0000ocO8=olgb3L02_lgb3L4o`0000CoHiaS00?o0000oka3_?nl@k`04?nl@k`01?l0
003ogb3Oo`000?l0000<on<Lh`03o`000?oa3_7ol@ka00Gol@ka00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?ob3O;olPgb00[olPgb00?o0000ok]4^onkA;/03onkA;/@o`0000[o>LHi00?o0000oa[U
6_lJiAX02OlJiAX00ol0003o0_d2o`00000<ob?L8`05o`000?l=lPgo0000o`3o0?l000002_l0o`00
0ol0003oC;=<odbcC009odbcC003o`000?lgb3Oo=lPg00Oo=lPg0ol00004ofVFJ@?o000000?oHiaS
o`000?nl@k`04Onl@k`01?l0003ogb3OomlPgooO8=l2o`0000_ohacS00?o0000oo4>lOoa3_400ooa
3_400ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O802_ob3O800ol0003o^dBkok]4^`0?
ok]4^`03o`000?meRWGoMHYe00coMHYe00?o0000ocW6>OliaST02OliaST00ol0003o6^DJoa[U6P07
oa[U6P04o`000?l2o@;o0_d2o`0000go8m`S00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m</dcoC;=<00[oC;=<00?o0000ocO8=olgb3L00olgb3L3o`0000[oJIIY00?o0000oka3_?nl@k`0
4?nl@k`00ol0003ogb3OomlPg`04omlPg`;o00002_oS7><00ol0003ol@kaoo4>l@04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000colPgb00?o0000ok]4^onkA;/03onkA;/00ol0003oMHYeogF:M@0<ogF:M@03o`000?li
aSWo>LHi00Wo>LHi00?o0000oa[U6_lJiAX01_lJiAX00ol0003o0_d2o`;m0P02o`;m0P03o`000?lS
g2?o8m`S00[o8m`S00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m<
/dcoC;=<00[oC;=<00?o0000ocO8=olgb3L00ol0000=ofVFJ@03o`000?nl@kco_4>l013o_4>l00?o
0000omlPgooO8=l01_oO8=l2o`0000WohacS0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo8=l_ob3O802_ob3O800ol0003o^dBkok]4^`0=ok]4^`?o00003omeRWD0
0ol0003o>LHiocW6>@08ocW6>@03o`000?lJiA[o6^DJ00Go6^DJ00?o0000o`;m0_l2o@800ol2o@80
0ol0003o8m`Sob?L8`0:ob?L8`03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003oC;=<odbcC00;odbcC0;o00004OmYUVT00ol0003o_4>loka3_00?oka3_003o`000?oO8=oo
gb3O00Sogb3O0_l00007on<Lh`03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo8=l_ob3O802?ob3O800ol0003o^dBkok]4^`09ok]4^`Go00000_n8MhP00ol0
003oMHYeogF:M@0=ogF:M@03o`000?liaSWo>LHi00Wo>LHi00?o0000oa[U6_lJiAX01?lJiAX00ol0
003o0_d2o`;m0P04o`;m0P03o`000?lSg2?o8m`S00So8m`S00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m</dcoC;=<00_oC;=<00?o0000ofVFJOmYUVT04?mYUVT00ol0
003o_4>loka3_00?oka3_003o`000?oO8=oogb3O00[ogb3O0_l00004on<Lh`03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003olPgboo8=lP07oo8=lP03o`000?nkA;_o^dBk00Co^dBk1Ol00007ohQgR003
o`000?meRWGoMHYe00goMHYe00?o0000ocW6>OliaST02OliaST00ol0003o6^DJoa[U6P03oa[U6P03
o`000?l2o@;o0_d200Go0_d200?o0000ob?L8olSg2<02?lSg2<00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000odbcC?m</d`02om</d`00ol0003oJIIYofVFJ@0@ofVFJ@03
o`000?nl@kco_4>l00oo_4>l00?o0000omlPgooO8=l03?oO8=l2o`000003on<Lhol0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00OolPgb00?o0000ok]4^ol00000
1?l0000<ohQgR003o`000?meRWGoMHYe00koMHYe00?o0000ocW6>OliaST02?liaST00ol0003o6^DJ
oa[U6P02oa[U6P03o`000?l2o@;o0_d200Oo0_d200?o0000ob?L8olSg2<01olSg2<00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000odbcC?m</d`02om</d`00ol0003oJIIY
ofVFJ@0AofVFJ@03o`000?nl@kco_4>l00go_4>l00?o0000omlPgooO8=l03ooO8=l00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo8=l_ob3O801Oob3O83o`00017oR7N800?o0000ogF:MOmeRWD03_me
RWD00ol0003o>LHiocW6>@09ocW6>@04o`000?lJiA[o6^DJo`0000[o0_d200?o0000ob?L8olSg2<0
1olSg2<00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om</d`00ol0003o
JIIYofVFJ@0AofVFJ@?o00003Onl@k`00ol0003ogb3OomlPg`0?omlPg`03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_ob3O82o`0000;oe2_D00?o0000ohQgR?n8MhP03on8MhP00ol0003o
MHYeogF:M@0>ogF:M@03o`000?liaSWo>LHi00So>LHi1Ol0000;o`;m0P03o`000?lSg2?o8m`S00Ko
8m`S00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=odbcC003o`000?mYUVWoJIIY
017oJIIY00?o0000oebSG?mLXe`00ol0000:oka3_0Co00003OoO8=l00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo<<looc3??ol`cc0_l00005om@[e003o`000?n8MhSoR7N800koR7N800?o0000ogF:
MOmeRWD03_meRWD00ol0003o>LHiocW6>@07ocW6>@03o`000?l/dbco;=</00?o;=</00?o0000o`;m
0_l2o@802?l2o@800ol0003o8m`Sob?L8`05ob?L8`03o`000?l0o`3o0?l000[o0?l01Ol0000<odbc
C003o`000?mYUVWoJIIY013oJIIY00?o0000oebSG?mLXe`01?mLXe`3o`0000Ko_4>l00?o0000om`S
g?oL8m`00_oL8m`5o`0000Sogb3O00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00?o
l`cc00?o0000om@[e?oD:m@01?oD:m@00ol0003oR7N8ohQgR00=ohQgR003o`000?meRWGoMHYe00oo
MHYe00?o0000ocW6>OliaST01?liaST2o`0000Oo;=</00?o0000o`;m0_l2o@801ol2o@8Eo`0000Go
2?L800?o0000odbcC?m</d`02?m</d`3o`00013oJIIY00?o0000oebSG?mLXe`02?mLXe`3o`0000;o
_4>l00?o0000om`Sg?oL8m`02?oL8m`5o`0000?ogb3O00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?oc3??ol`cc00Col`cc00?o0000om@[e?oD:m@01OoD:m@00ol0003oR7N8ohQgR00;ohQgR0Co0000
3omeRWD00ol0003o>LHiocW6>@03ocW6>@03o`000?l/dbco;=</00So;=</00?o0000o`;m0_l2o@80
1?l2o@82o`0000So:MHY00?o0000oaSW6?lHiaP02?lHiaP00ol0003o2?L8o`Sg2005o`Sg20;o0000
1_m</d`2o`0000?o@Ki100?o0000ofVFJOmYUVT03?mYUVT00ol0003oG:=LoebSG00<oebSG0;o0000
4?oL8m`3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oD:mCoe2_D00Koe2_D00?o
0000ohQgR?n8MhP02On8MhP00ol0003oTFjAo`000002oeRWF0?o00003?meRWD01?l0003o>LHiocW6
>OliaST2o`0000co;=</00?o0000o`;m0_l2o@800_l2o@800ol0003o:MHYobWF:@08obWF:@03o`00
0?lHiaSo6>LH00So6>LH00?o0000o`Sg2?l8m`P01ol8m`P00ol0003oC;=<odbcC002odbcC003o`00
0?m1_T7o@Ki100Co@Ki10_l0000;ofVFJ@03o`000?mLXecoG:=L00coG:=L00?o0000oj1OX?l00000
4_oL8m`00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003ol`ccoo<<l`06oo<<l`03o`000?oD:mCoe2_D00Ooe2_D00?o
0000ohQgR?n8MhP01_n8MhP2o`0000;oTFjA00?o0000oeRWF?mHYeP00omHYeP3o`0000[oMHYe00?o
0000ocW6>Ol000003ol/db`01?l0003o0_d2o`000?l0000;obWF:@03o`000?lHiaSo6>LH00So6>LH
00?o0000o`Sg2?l8m`P02?l8m`P01?l0003oC;=<o`000?l00009od6n@@03o`000?mYUVWoJIIY00Oo
JIIY00?o0000oebSG?mLXe`03?mLXe`01?l0003oX5nPoj1OX?l0000Com`Sg003o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo<<looc3?<01ooc3?<00ol0003oe2_Dom@[e008om@[e003o`000?n8MhSoR7N800Co
R7N800?o0000oi5^TOnAKY400onAKY400ol0003oF:MHoeRWF005oeRWF0?o00001_meRWD4o`00013o
;=</00?o0000obWF:OlYeRT03?lYeRT00ol0003o6>LHoaSW6007oaSW6003o`000?l8m`So2?L800Wo
2?L800?o0000od6n@Om1_T402_m1_T42o`0000KoJIIY00?o0000oebSG?mLXe`03?mLXe`00ol0003o
X5nPoj1OX002oj1OX003o`000?oL8mcog2?L00oog2?L00?o0000oo0?l?l000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003ol`ccoo<<l`08oo<<l`03o`000?oD:mCoe2_D00Woe2_D00Co0000ohQgR?n8MhSo
R7N80_l00006oi5^T@03o`000?mHYeSoF:MH00SoF:MH0ol000000omeRWGo0000o`000004od2o@003
o`000?l/dbco;=</00go;=</00?o0000obWF:OlYeRT03?lYeRT00ol0003o6>LHoaSW6007oaSW6003
o`000?l8m`So2?L800Wo2?L800?o0000od6n@Om1_T403?m1_T400ol0003oJIIYofVFJ@03o`0000ko
G:=L00?o0000oj1OX?nPGj000onPGj000ol0003og2?Lom`Sg00>om`Sg005o`000?o`3o3ol0o`oo0?
l?l000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`09oo<<l`03o`000?oD:mCoe2_D00[o
e2_D00?o0000ohQgR?l000002?nAKY400ol0003oF:MHoeRWF00;oeRWF003o`000?m0_d3o@;m000Go
@;m000?o0000obcC;?l/db`03?l/db`00ol0003o:MHYobWF:@0<obWF:@03o`000?lHiaSo6>LH00Oo
6>LH00?o0000o`Sg2?l8m`P02?l8m`P2o`0000oo@Ki10_l00002ofFJI@03o`000?mLXecoG:=L00_o
G:=L00?o0000oj1OX?nPGj001?nPGj000ol0003og2?Lom`Sg00=om`Sg003o`000?o`3o3ol0o`00?o
l0o`00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo<<l`03o`000?oD:mCoe2_D00_oe2_D00?o0000oi5^TOnAKY40
1onAKY400ol0003oF:MHoeRWF00;oeRWF003o`000?m0_d3o@;m000Ko@;m000?o0000obcC;?l/db`0
2ol/db`2o`0000go:MHY00?o0000oaSW6?lHiaP01olHiaP00ol0003o2?L8o`Sg2007o`Sg2004o`00
0?lEjQGo5NXEo`0000ko@Ki100?o0000ofFJIOmUVVD00_mUVVD00ol0003oG:=LoebSG009oebSG003
o`000?nPGj3oX5nP00KoX5nP00?o0000om`Sg?oL8m`02ooL8m`00ol0003ol0o`oo0?l005oo0?l004
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Sol`cc00?o0000om@[e?oD:m@02_oD:m@2o`0000Wo
TFjA00?o0000oeRWF?mHYeP02omHYeP00ol0003o@;m0od2o@007od2o@003o`000?l/dbco;=</00Wo
;=</00Co0000o`3o0?l0o`3o00003?lYeRT00ol0003o6>LHoaSW6007oaSW6003o`000?l8m`So2?L8
00Ko2?L800Go0000oaGZ5OlEjQGo5NXEo`00000>od6n@@03o`000?mUVVGoIIYU00?oIIYU00?o0000
oebSG?mLXe`01omLXe`00ol0003oX5nPoj1OX007oj1OX003o`000?oL8mcog2?L00[og2?L00?o0000
oo0?l?o`3o001oo`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo<<l`03o`000?oD:mCoe2_D
00Woe2_D00Co0000olHia_o6>LKo00002OnAKY400ol0003oF:MHoeRWF009oeRWF003o`000?m0_d3o
@;m000Wo@;m000?o0000obcC;?l/db`01ol/db`00ol0003o0?l0o`3o0002o`3o0003o`000?lYeRWo
:MHY00Wo:MHY00?o0000oaSW6?lHiaP01olHiaP00ol0003o2?L8o`Sg2005o`Sg2003o`000?lEjQGo
5NXE00?o5NXE00?o0000od6n@Om1_T402_m1_T400ol0003oIIYUofFJI@05ofFJI@03o`000?mLXeco
G:=L00GoG:=L00?o0000oj1OX?nPGj002?nPGj000ol0003og2?Lom`Sg009om`Sg003o`000?o`3o3o
l0o`00Sol0o`00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oc3?<3o`0000Woe2_D00?o0000olHi
a_o6>LH00_o6>LH00ol0003oTFjAoi5^T@06oi5^T@03o`000?mHYeSoF:MH00WoF:MH00?o0000od2o
@?m0_d002_m0_d000ol0003o;=</obcC;005obcC;003o`000?l0o`3o0?l000Co0?l000?o0000obWF
:OlYeRT02?lYeRT00ol0003o6>LHoaSW6007oaSW6003o`000?l8m`So2?L800Co2?L800?o0000oaGZ
5OlEjQD01?lEjQD00ol0003o@Ki1od6n@@0:od6n@@03o`000?mUVVGoIIYU00KoIIYU00?o0000oebS
G?mLXe`00omLXe`00ol0003oX5nPoj1OX009oj1OX003o`000?oL8mcog2?L00Sog2?L00?o0000oo0?
l?o`3o002Oo`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003on/Dj`?o00001OoD:m@00ol0003o
aSW6olHiaP03olHiaP03o`000?nAKY7oTFjA00KoTFjA00?o0000oeRWF?mHYeP02OmHYeP00ol0003o
@;m0od2o@00;od2o@003o`000?l/dbco;=</00?o;=</00?o0000o`3o0?l0o`001_l0o`000ol0003o
:MHYobWF:@08obWF:@03o`000?lHiaSo6>LH00Ko6>LH00?o0000o`Sg2?l8m`P00_l8m`P2o`0000So
5NXE00?o0000od6n@Om1_T402Om1_T400ol0003oIIYUofFJI@07ofFJI@05o`000?mLXecoG:=LoebS
G?l000003OnPGj000ol0003og2?Lom`Sg006om`Sg003o`000?o`3o3ol0o`00[ol0o`00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o[5>_ojaC[00GojaC[0ol000000ooD:mCo0000olHiaP06olHiaP03
o`000?nAKY7oTFjA00GoTFjA00?o0000oeRWF?mHYeP02OmHYeP00ol0003o@;m0od2o@00<od2o@005
o`000?l/dbco;=</obcC;?l000002_l0o`000ol0003o:MHYobWF:@07obWF:@03o`000?lHiaSo6>LH
00Ko6>LH00?o0000o`Sg2?l000000_l000000om5^TGo0000oaGZ5@07oaGZ5@03o`000?m1_T7o@Ki1
00So@Ki100?o0000ofFJIOmUVVD02OmUVVD00ol0003oG:=Lo`00000=oj1OX0Co00001OoL8m`00ol0
003ol0o`oo0?l00;oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ojaC[on/Dj`08on/Dj`03
o`000?o6>LKoaSW600OoaSW600?o0000oi5^TOnAKY401?nAKY400ol0003oF:MHoeRWF009oeRWF003
o`000?m0_d3o@;m000go@;m000?o0000obcC;?l000003?l0o`0:o`0000Oo6>LH0ol00005odFjA@03
o`000?lEjQGo5NXE00Ko5NXE00?o0000od6n@Om1_T401om1_T400ol0003oIIYUofFJI@0:ofFJI@03
o`000?nPGj3oX5nP00_oX5nP00?o0000omLXeooG:=L00_oG:=L3o`000003om`Sg?l0003ol0o`00_o
l0o`0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000on/Djoo[5>/02Oo[5>/00ol0003oaSW6olHiaP07olHiaP03o`00
0?nAKY7oTFjA00GoTFjA00?o0000oeRWF?mHYeP01omHYeP00ol0003o@;m0od2o@00?od2o@0;o0000
2ol0o`000ol0003o><LhocS7>007ocS7>003o`000?lHiaSo6>LH00;o6>LH0ol00008odFjA@03o`00
0?lEjQGo5NXE00Ko5NXE00?o0000od6n@Om1_T401om1_T400ol0003oIIYUofFJI@0:ofFJI@03o`00
0?nPGj3oX5nP00[oX5nP00?o0000omLXeooG:=L01_oG:=L00ol0003ol0o`oo0?l008oo0?l0?o0000
0_oc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000on/Djoo[5>/02Oo[5>/00ol0003oaSW6olHi
aP08olHiaP03o`000?nAKY7oTFjA00CoTFjA00?o0000oeRWF?mHYeP01omHYeP00ol0003o@;m0od2o
@00>od2o@004o`000?l?l0oo3o0?o`0000Wo0?l000?o0000ocS7>?lhacP02OlhacP01?l0003o6>LH
o`000?l0000<odFjA@03o`000?lEjQGo5NXE00Ko5NXE00?o0000od6n@Om1_T401_m1_T400ol0003o
IIYUofFJI@0;ofFJI@03o`000?nPGj3oX5nP00OoX5nP0_l00009omLXe`03o`000?o`3o3ol0o`00Co
l0o`1?l00006oo<<l`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ojaC[on/Dj`09on/Dj`03o`00
0?o6>LKoaSW600SoaSW600?o0000oi5^TOnAKY400onAKY4>o`0000go@;m000?o0000o`o`3ol?l0l0
0_l?l0l00ol0003o0?l0o`3o0005o`3o0003o`000?lhacSo><Lh00_o><Lh00?o0000odFjAOm5^TD0
3?m5^TD00ol0003o5NXEoaGZ5@06oaGZ5@03o`000?m1_T7o@Ki100Go@Ki100?o0000ofFJIOmUVVD0
3?mUVVD00ol0003oX5nPoj1OX006oj1OX003o`000?oG:=OoebSG00[oebSG00?o0000oo0?l?o`3o00
0ol0000:oo<<l`?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o[5>_ojaC[00_ojaC[00?o0000olHia_o6>LH02?o6
>LH01Ol0003oTFjAoi5^TOnAKY7o000000_oI9]T00?o0000o`Sg2?l8m`P00ol00009od2o@003o`00
0?l?l0oo3o0?00Co3o0?00?o0000o`3o0?l0o`000ol0o`000ol0003o><LhocS7>00<ocS7>003o`00
0?m5^TGoAKY500goAKY500?o0000oaGZ5OlEjQD01_lEjQD00ol0003o@Ki1od6n@@03od6n@@?o0000
3OmUVVD00ol0003oX5nPoj1OX005oj1OX003o`000?oG:=OoebSG00coebSG0_l0000=oo<<l`03o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o[5>_ojaC[00_ojaC[00?o0000olHia_o6>LH02?o6
>LH4o`0000coI9]T00?o0000o`Sg2?l8m`P00ol8m`P3o`0000Go@;m000?o0000o`o`3ol?l0l01_l?
l0l01Ol0003o0?l0o`3o0?l0o`3o000000oo><Lh00?o0000odFjAOm5^TD03Om5^TD00ol0003o5NXE
oaGZ5@06oaGZ5@03o`000?m1_T7o@Ki100?o00000olWf2L00ol0003oIIYUofFJI@0;ofFJI@03o`00
0?nPGj3oX5nP00?oX5nP00?o0000omLXeooG:=L03OoG:=L00ol0003ol`ccoo<<l`0;oo<<l`03o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000on/Djoo[5>/02_o[5>/3o`0000KoaSW60ol0
0003ok9=/P03o`000?mTVfCoI9]T00[oI9]T00?o0000o`Sg2?l8m`P01_l8m`P3o`000003od2o@?l0
003o3o0?00Wo3o0?00?o0000o`3o0?l000004?lhacP00ol0003oAKY5odFjA@0=odFjA@03o`000?lE
jQGo5NXE00Oo5NXE0_l00007obOH9`03o`000?mUVVGoIIYU00[oIIYU00Co0000oj1OX?nPGj3oX5nP
0ol0000?omLXe`03o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000on/Djoo[5>/02_o[
5>/01?l0003oh1oPon0Oh?oP7n02o`000004olHia_l0003o0000o`0000Ko/Tfb00?o0000ofBKI?mT
Vf@02_mTVf@00ol0003o2?L8o`Sg2009o`Sg2003o`000?l?l0oo3o0?00[o3o0?00?o0000ocS7>?lh
acP03olhacP00ol0003oAKY5odFjA@0>odFjA@03o`000?lEjQGo5NXE00Ko5NXE00?o0000obOH9olW
f2L01olWf2L4o`0000SoIIYU00Co0000oj1OX?nPGj3o00000on^DJh2o`0000goebSG00?o0000oo<<
looc3?<02_oc3?<00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000on/Djoo[5>/02Oo[5>/00ol0003o
h1oPon0Oh004on0Oh003o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ofBKI?mTVf@02OmTVf@00ol0003o
2?L8o`Sg200:o`Sg2003o`000?l?l0oo3o0?00[o3o0?00?o0000ocS7>?lhacP03olhacP00ol0003o
AKY5odFjA@0>odFjA@03o`000?lEjQGo5NXE00Go5NXE00?o0000obOH9olWf2L02?lWf2L01?l0003o
FZEJoeZUF_mJYEX7o`0000;oIIYU0_l00006ojiA[P;o00003?oG:=L00ol0003ol`ccoo<<l`09oo<<
l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ojaC[on/Dj`08on/Dj`03o`000?oP7n3oh1oP00Go
h1oP00?o0000ok9=/_nbCK802?nbCK800ol0003oI9]TofBKI008ofBKI003o`000?l8m`So2?L800[o
2?L800?o0000o`o`3ol?l0l02ol?l0l00ol0003o><LhocS7>00>ocS7>003o`000?m5^TGoAKY500ko
AKY51Ol00002oaGZ5@03o`000?lWf2Oo9mPW00Wo9mPW00?o0000oeZUF_mJYEX02?mJYEX3o`0000Wo
[U6^0_l0000:omLXe`03o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o[5>_ojaC[00SojaC[00?o0000on0Oh?oP7n001ooP7n000ol0003o/Tfbok9=/P07ok9=/P03o`00
0?mTVfCoI9]T00SoI9]T00?o0000o`Sg2?l8m`P02_l8m`P00ol0003o3o0?o`o`3`0:o`o`3`;o0000
3_lhacP3o`0000goAKY50ol00005odjaCP;o00002olWf2L00ol0003oFZEJoeZUFP0;oeZUFP;o0000
2_n^DJh2o`0000OoebSG0ol00009oo<<l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:on0Oh003o`00
0?nbCK;o/Tfb00Oo/Tfb00?o0000ofBKI?mTVf@02?mTVf@>o`0000Wo3o0?0ol000000ol0o`3o0000
ocS7>00:ocS7>0?o00000_mA[U400ol0003oAKY5odFjA@09odFjA@;o00002Om>/Dh00ol0003o9mPW
obOH9`09obOH9`03o`000?mJYE[oFZEJ00_oFZEJ00?o0000oh5nPOl000002on^DJh2o`0000CoebSG
00Co0000onTFjOoY5^WojAKY0_l00007oo<<l`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ook1?/00ol0003oh1oP
on0Oh009on0Oh003o`000?nbCK;o/Tfb00Ko/Tfb00?o0000ofBKI?mTVf@02?mTVf@00ol0003o4NhA
oa7^4@0:oa7^4@03o`000?l?l0oo3o0?00Co3o0?0ol00005o`3o0003o`000?lhacSo><Lh00Co><Lh
1?l00006oe6^D@03o`000?m5^TGoAKY500KoAKY50_l0000;odjaCP03o`000?lWf2Oo9mPW00Wo9mPW
00?o0000oeZUF_mJYEX02_mJYEX01Ol0003oPGj1oh5nPOn1OX7o000000co[U6^0_l000000ooG:=Oo
0000onTFj@05onTFj@03o`000?oc3??ol`cc00?ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?oP7n3oh1oP00Soh1oP00?o0000ok9=/_nbCK801_nbCK800ol0003oI9]TofBKI007ofBKI003o`00
0?lAkQ7o4NhA00_o4NhA00?o0000o`o`3ol?l0l00_l?l0l2o`0000Wo0?l000?o0000ocS7>?lhacP0
0ol0000;oe6^D@03o`000?m5^TGoAKY500;oAKY50ol0000>odjaCP03o`000?lWf2Oo9mPW00Oo9mPW
00?o0000oeZUF_mJYEX02omJYEX00ol0003oPGj1oh5nP@02oh5nP@03o`000?n^DJko[U6^00_o[U6^
00?o0000onTFjOoY5^T01_oY5^T2o`0000?ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oP
7n3oh1oP00Ooh1oP00?o0000ok9=/_nbCK801onbCK800ol0003oI9]TofBKI005ofBKI0?o00003OlA
kQ44o`0000_o0?l00ol0000?oe6^D@04o`000?m5^TGo0000o`00017oC[5>00?o0000obOH9olWf2L0
1olWf2L00ol0003oFZEJoeZUFP0:oeZUFP03o`000?n1OX7oPGj100CoPGj100?o0000ojiA[_n^DJh0
1on^DJh3o`0000_ojAKY1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on0Oh?oP7n002?oP7n000ol0003o/Tfbok9=
/P06ok9=/P03o`000?mTVfCoI9]T00;oI9]T0ol00003od:m@P03o`000?lAkQ7o4NhA00[o4NhA00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aoe6^D@03o`000?m>/DkoC[5>017oC[5>00?o
0000obOH9olWf2L01olWf2L00ol0003oFZEJoeZUFP0:oeZUFP03o`000?n1OX7oPGj100GoPGj100Co
0000ojiA[_n^DJko[U6^1Ol00002okY5^P03o`000?oY5^WojAKY00WojAKY00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ok1?_on`Ck00kon`Ck00?o0000on0Oh?oP7n001ooP7n000ol0003o/Tfbok9=/P05ok9=/P?o0000
00?oI9]To`000?l000001om2_D800ol0003o4NhAoa7^4@08oa7^4@?o00002_l0o`02o`0000;o0?l0
00?o0000oe6^DOmA[U403omA[U400ol0003oC[5>odjaCP0AodjaCP03o`000?lWf2Oo9mPW00Oo9mPW
00?o0000oeZUF_mJYEX02OmJYEX00ol0003oPGj1oh5nP@07oh5nP@?o00001onjAKX00ol0003ojAKY
onTFj@09onTFj@03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ok1?_on`Ck00kon`Ck00?o0000on0Oh?oP7n001ooP
7n04o`0000;o/Tfb0_l00003ojQGZ003o`000?m2_D;o@[e200So@[e20_l00006oa7^4@;o00000olB
kA800ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000oe6^DOmA[U403_mA
[U400ol0003oC[5>odjaCP0BodjaCP03o`000?lWf2Oo9mPW00Go9mPW00?o0000oeZUF_mJYEX02OmJ
YEX00ol0003oPGj1oh5nP@08oh5nP@03o`000?njAK[o^TFj00Oo^TFj00?o0000onTFjOoY5^T02?oY
5^T00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oP7n3oh1oP00Coh1oP0_l00004
on<Lh`;o00001OnXEjP00ol0003o@[e2od:m@P0:od:m@P03o`000?lAkQ7o4NhA00;o4NhA00?o0000
oa;]4_lBkA801?lBkA800ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
oe6^DOmA[U403_mA[U400ol0003oC[5>odjaCP0BodjaCP[o00002_mJYEX00ol0003oPGj1oh5nP@08
oh5nP@03o`000?njAK[o^TFj00Oo^TFj00?o0000onTFjOoY5^T02?oY5^T00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo/4
nook1?/03ook1?/01?l0003oh1oPon0Oh?oP7n02o`0000OohacS00?o0000ojQGZ?nXEjP01?nXEjP0
0ol0003o@[e2od:m@P0:od:m@P04o`000?lAkQ7o0000o`0000So4^dB00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?mA[U7oDJiA00koDJiA00?o0000odjaC_m>/Dh04_m>/Dh00ol0003o@;m0
od2o@007od2o@003o`000?mJYE[oFZEJ00KoFZEJ00?o0000oh5nPOn1OX402_n1OX400ol0003o^TFj
okY5^P06okY5^P03o`000?oY5^WojAKY00SojAKY00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003on`Ckoo/4n`0?oo/4n`04o`000?oP
7n3o0000o`0000WohacS00?o0000ojQGZ?nXEjP01?nXEjP00ol0003o@[e2od:m@P0;od:m@P03o`00
0?lBkA;o4^dB00Wo4^dB00?o0000o`3o0?l000002Ol0o`000ol0003oDJiAoe6^D@0>oe6^D@;o0000
4_m>/Dh00ol0003o@;m0od2o@009od2o@0;o00001_mJYEX00ol0003oPGj1oh5nP@0:oh5nP@03o`00
0?njAK[o^TFj00Ko^TFj00?o0000onTFjOoY5^T02?oY5^T00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ok1?_on`Ck013on`Ck00?o
0000on<LhooS7><02OoS7><00ol0003oZ5NXojQGZ005ojQGZ003o`000?m2_D;o@[e200[o@[e200?o
0000oa;]4_lBkA802_lBkA82o`0000Wo0?l000?o0000oe6^DOmA[U403_mA[U400ol0003o>LHio`00
0002o`0000ooC[5>00?o0000od2o@?m0_d002om0_d000ol0003oFZEJoeZUFP03o`0000goPGj100?o
0000okY5^_njAKX01_njAKX00ol0003ojAKYonTFj@07onTFj@03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo/4nook1?/03ook1?/0
0ol0003ohacSon<Lh`09on<Lh`03o`000?nXEjSoZ5NX00GoZ5NX00?o0000od:m@_m2_D802Om2_D82
o`0000_o4^dB0_l0000;o`3o0003o`000?mA[U7oDJiA00coDJiA00?o0000ocW6>OliaST00oliaST3
o`0000coC[5>00?o0000od2o@?m0_d003?m0_d02o`0000;oLhac00?o0000oh5nPOn1OX403?n1OX40
0ol0003o^TFjokY5^P05okY5^P03o`000?oY5^WojAKY00OojAKY00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?oS7>?ohacS00[ohacS00?o0000ojQGZ?nXEjP01_nXEjP00ol0003o@[e2od:m@P07od:m
@P03o`000?lo_coo000000[o4^dB00Co0000o`Ki1_l6n@Ko00002_l0o`000ol0003oDJiAoe6^D@0<
oe6^D@03o`000?liaSWo>LHi00Ko>LHi0_l00008odjaCP;o00003om0_d000ol0003oLhacog><L`02
og><L`03o`000?n1OX7oPGj100_oPGj100?o0000okY5^_njAKX01OnjAKX00ol0003ojAKYonTFj@07
onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ohacSon<Lh`0:on<Lh`03o`000?nXEjSoZ5NX
00KoZ5NX00?o0000od:m@_m2_D801_m2_D801Ol0003o?kloocno?olo_coo000000So4^dB00?o0000
o`Ki1_l6n@H00_l6n@H00ol0003o0?l0o`3o0006o`3o00Co00003?mA[U400ol0003o>LHiocW6>@08
ocW6>@?o00000_m>/Dh3o`000003ocK9=_l0003o@;m000go@;m000?o0000og><LomcS7<01?mcS7<0
0ol0003oPGj1oh5nP@0:oh5nP@03o`000?njAK[o^TFj00Go^TFj00?o0000onTFjOoY5^T01_oY5^T0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ok1?_on`Ck00con`Ck00?o0000on<LhooS7><02ooS7><00ol0003oZ5NXojQGZ007ojQG
Z003o`000?m2_D;o@[e200?o@[e20_l00005ocno?`03o`000?lBkA;o4^dB00Co4^dB00?o0000o`Ki
1_l6n@H00ol6n@H00ol0003o0?l0o`3o0005o`3o0003o`000?lGj1Oo5nPG00;o5nPG0ol00007oe6^
D@;o00003_liaST2o`0000Go=/Tf00?o0000od2o@?m0_d002_m0_d000ol0003oLhacog><L`05og><
L`03o`000?n1OX7oPGj100_oPGj100?o0000okY5^_njAKX01?njAKX00ol0003ojAKYonTFj@06onTF
j@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo/4nook1?/03?ok1?/00ol0003ohacSon<Lh`0;on<Lh`03o`000?nXEjSoZ5NX00Oo
Z5NX00?o0000od:m@_m2_D800_m2_D800ol0003o?kloocno?`06ocno?`03o`000?lBkA;o4^dB00;o
4^dB00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o0?l0o`3o0002o`3o00;o00002?lGj1L3o`0000;o
DJiA0_l000000olOh1oo0000ocW6>@0=ocW6>@03o`000?lfbCKo=/Tf00Go=/Tf00?o0000od2o@?m0
_d002?m0_d000ol0003oLhacog><L`07og><L`03o`000?n1OX7oPGj100[oPGj100?o0000okY5^_nj
AKX01?njAKX00ol0003ojAKYonTFj@06onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo/4nook1?/02ook1?/00ol0003ohacS
on<Lh`0<on<Lh`03o`000?nXEjSoZ5NX00SoZ5NX00Co0000od:m@_m2_D;o00002Olo_cl01Ol0003o
4^dBoa;]4_lBkA;o000000So1_T600Go0000o`3o0?l0o`3o0?l0o`00000=oaOX5`;o00001?lOh1l0
0ol0003o>LHiocW6>@0;ocW6>@03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000od2o@?m0_d001om0_d00
0ol0003oLhacog><L`08og><L`Co00002?n1OX400ol0003o^TFjokY5^P04okY5^P03o`000?oY5^Wo
jAKY00KojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oS7>?ohacS00_ohacS0ol00009ojQG
Z003o`000?m2_D;o000000_o?klo00?o0000oa;]4_l000002_l6n@H00ol0003o0?l0o`00000?oaOX
5`03o`000?lOh1oo7n0O00;o7n0O00?o0000ocW6>OliaST02oliaST00ol0003o=/TfocK9=P06ocK9
=P03o`000?m0_d3o@;m000Ko@;m000?o0000og><LomcS7<02OmcS7<01?l0003oYUVVojIIY_nVFJH7
o`0000;oPGj100?o0000okY5^_njAKX00onjAKX00ol0003ojAKYonTFj@05onTFj@03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo/4
n`03o`000?oS7>?ohacS00SohacS0ol00003om/Tf`03o`000?nXEjSoZ5NX00OoZ5NX00?o0000ocno
?olo_cl02olo_cl00ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?lGj1Oo5nPG00go5nPG00?o0000oaoP
7olOh1l01?lOh1l00ol0003o>LHiocW6>@09ocW6>@03o`000?lfbCKo=/Tf00So=/Tf00?o0000od2o
@?m0_d000om0_d02o`0000coLhac00?o0000ojIIY_nVFJH02?nVFJH<o`0000?ojAKY0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ok1?_on`Ck00Oo
n`Ck00?o0000on<LhooS7><01_oS7><3o`0000OofbCK00?o0000ojQGZ?nXEjP01_nXEjP00ol0003o
?kloocno?`0;ocno?`03o`000?l6n@Ko1_T600Wo1_T60_l0000>oaOX5`03o`000?lOh1oo7n0O00Go
7n0O00?o0000ocW6>OliaST02OliaST00ol0003o=/TfocK9=P09ocK9=P03o`000?m0_d3o000000;o
00000_mYUVT00ol0003oLhacog><L`08og><L`03o`000?nVFJKoYUVV00coYUVV00?o0000onDJiOoU
6^D01_oU6^D3o`0000?oo0?l0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo/4nook1?/01_ok1?/00ol0003ohacSon<Lh`03on<Lh`?o00002ooK9=/00ol0003oZ5NX
ojQGZ004ojQGZ003o`000?lo_coo?klo00_o?klo0ol00007o`Ki1P?o000000?o4n`Co`000?lGj1L0
3OlGj1L00ol0003o7n0OoaoP7`06oaoP7`03o`000?liaSWo>LHi00So>LHi00?o0000ocK9=_lfbCH0
2_lfbCH00ol0003oJIIYofVFJ@04ofVFJ@03o`000?mcS7?oLhac00OoLhac00?o0000ojIIY_nVFJH0
2onVFJH00ol0003oiA[UonDJi@08onDJi@03o`000?ol0ocoo0?l00Coo0?l0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo/4nook1?/00ook1?/4o`000004on<Lhol0
003o0000o`0000oofbCK00?o0000ojQGZ?nXEjP00onXEjP>o`0000?o<Lha0_l00002o`Ki1P?o0000
1OlCk1<00ol0003o5nPGoaOX5`0:oaOX5`03o`000?lOh1oo7n0O00Oo7n0O00?o0000ocW6>OliaST0
2?liaST00ol0003o=/TfocK9=P0:ocK9=P03o`000?mYUVWoJIIY00GoJIIY00?o0000og><LomcS7<0
1_mcS7<00ol0003oYUVVojIIYP0;ojIIYP03o`000?oU6^GoiA[U00SoiA[U00?o0000oo`3o?ol0o`0
1ool0o`2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ok
1?_o000000;o00001?ok1?/2o`0001;ofbCK00?o0000ojQGZ?nXEjP00_nXEjP00ol0003oPgb3oh=l
P`0:oh=lP`03o`000?lacS7o<Lha00?o<Lha0_l00009oa?/4`03o`000?lGj1Oo5nPG00Wo5nPG00?o
0000oaoP7olOh1l02?lOh1l2o`0000So>LHi00?o0000ocK9=_lfbCH02OlfbCH00ol0003oJIIYofVF
J@07ofVFJ@03o`000?mcS7?oLhac00CoLhac00?o0000ojIIY_nVFJH02onVFJH00ol0003oiA[UonDJ
i@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ofbCKom/Tf`0?om/Tf`?o000000?oZ5NX
o`000?n3O8<02on3O8<00ol0003o<Lhaoc7><@04oc7><@03o`000?lCk1?o4n`C00Wo4n`C00?o0000
oaOX5olGj1L01olGj1L00ol0003o7n0OoaoP7`09oaoP7`04o`000?lOh1oo0000o`0000Ko>LHi00?o
0000ocK9=_lfbCH02OlfbCH00ol0003oJIIYofVFJ@08ofVFJ@03o`000?mcS7?oLhac00?oLhac00?o
0000ojIIY_nVFJH02onVFJH00ol0003oiA[UonDJi@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ofbCKom/Tf`0<om/Tf`;o00000ooH9mP2o`0000coPgb300?o0000oc7><OlacS401?lacS40
0ol0003o4n`Coa?/4`0:oa?/4`Wo00002olOh1l00ol0003o7n0OoaoP7`02oaoP7`?o00000_liaST0
0ol0003o=/TfocK9=P0:ocK9=P03o`000?mYUVWoJIIY00WoJIIY00?o0000og><LomcS7<00_mcS7<0
0ol0003oYUVVojIIYP0:ojIIYP03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oK9=/2o`0000Gof2OH00?o0000ojIIY_l000002_n3O8<00ol0003o<Lhaoc7><@06oc7>
<@03o`000?lCk1?o4n`C00Wo4n`C00?o0000o`gb3Ol=lPd01Ol=lPd00ol0003o7n0OoaoP7`09oaoP
7`03o`000?lOh1oo7n0O00Go7n0O0ol00009ocK9=P?o00003OmYUVT01Ol0003oLhacog><LomcS7?o
000000coYUVV00?o0000onDJiOoU6^D02OoU6^D00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000om/T
fooK9=/01OoK9=/2o`0000Oof2OH00Co0000ojIIY_nVFJKo00002On3O8<00ol0003o<Lhaoc7><@06
oc7><@03o`000?lCk1?o4n`C00So4n`C00?o0000o`gb3Ol=lPd01ol=lPd00ol0003o7n0OoaoP7`07
oaoP7`03o`000?lOh1oo7n0O00So7n0O0ol00002ocK9=PGo00000_m2_D800ol0003oJIIYofVFJ@0<
ofVFJ@03o`000?mcS7?o000000coYUVV00?o0000onDJiOoU6^D02_oU6^D00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000om/TfooK9=/00_oK9=/2o`0000Sof2OH00?o0000ojIIY_nVFJH00_nVFJH5o`00
00CoPgb300?o0000oc7><OlacS401_lacS400ol0003o4n`Coa?/4`08oa?/4`03o`000?l=lPgo3O8=
00Oo3O8=00?o0000oaoP7olOh1l01olOh1l00ol0003o7n0OoaoP7`08oaoP7`03o`000?lLhaco7><L
00;o00002?m2_D800ol0003oJIIYofVFJ@0<ofVFJ@Co00002_nVFJH00ol0003oiA[UonDJi@0:onDJ
i@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ofbCKo`000?l0000:omPWf003o`000?nVFJKoYUVV
00;oYUVV00?o0000oe^TFomKY5/00_mKY5/4o`0000Wo<Lha00?o0000oa?/4olCk1<02?lCk1<00ol0
003o3O8=o`gb3@08o`gb3@03o`000?lOh1oo7n0O00Go7n0O00?o0000oaoP7olOh1l02?lOh1l01Ol0
003o7><LoacS7?lLhaco000000[o@[e20ol0000;ofVFJ@04o`000?oB;M;odRgBom8]dPCo00001OnV
FJH00ol0003oiA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003of2OHomPWf00:
omPWf003o`000?nVFJKoYUVV00?oYUVV00?o0000oe^TFomKY5/01?mKY5/00ol0003o<Lhaoc7><@07
oc7><@03o`000?lCk1?o4n`C00Ko4n`C0_l0000;o`gb3@03o`000?lOh1oo7n0O00Go7n0O00?o0000
oaoP7olOh1l02?lOh1l00ol0003o7><LoacS7002oacS7003o`000?m2_D;o@[e200Oo@[e200?o0000
oiEZUOnEJYD01?l00006ofVFJ@03o`000?oB;M;odRgB00KodRgB0ol00002ojIIYP03o`000?oU6^Go
iA[U00_oiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oH9mSof2OH00Wof2OH00?o0000ojII
Y_nVFJH01?nVFJH00ol0003oFjAKoe^TF`05oe^TF`03o`000?lacS7o<Lha00Oo<Lha00?o0000oa?/
4olCk1<00_lCk1<3o`000003ob3O8?l0003o3O8=00[o3O8=00?o0000oaoP7olOh1l01OlOh1l00ol0
003o7n0OoaoP7`07oaoP7`03o`000?lLhaco7><L00?o7><L00?o0000od:m@_m2_D801om2_D800ol0
003oUFZEoiEZU@04oiEZU@?o00000_mYUVT00ol0003odRgBom8]dP0:om8]dP;o00003_oU6^D00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omPWf?oH9mP02OoH9mP00ol0003oYUVVojIIYP04ojIIYP03
o`000?mKY5_oFjAK00KoFjAK0_l00007oc7><@03o`000?lCk1?o000000;o00001OlPgb000ol0003o
3O8=o`gb3@08o`gb3@?o00001?lOh1l00ol0003o7n0OoaoP7`08oaoP7`03o`000?lLhaco7><L00Co
7><L00?o0000od:m@_m2_D801_m2_D800ol0003oUFZEoiEZU@07oiEZU@;o00003_oB;M800ol0003o
iA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003of2OHomPWf008omPWf003o`00
0?nVFJKoYUVV00GoYUVV00?o0000oe^TFomKY5/01?mKY5/00ol0003oG:=LoebSG003o`0000Co<Lha
0_l00008ob3O8003o`000?l=lPgo3O8=00Oo3O8=00Co0000ock1?_ln`Cko?/4n0ol000000olOh1oo
0000oaoP7`09oaoP7`03o`000?lLhaco7><L00Co7><L00?o0000od:m@_m2_D801Om2_D800ol0003o
UFZEoiEZU@09oiEZU@03o`000?oB;M;odRgB00godRgB00?o0000onDJiOoU6^D02_oU6^D00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omPWf?oH9mP01ooH9mP00ol0003oYUVVojIIYP06ojIIYP03o`00
0?mKY5_oFjAK00?oFjAK00?o0000oebSG?mLXe`01?mLXe`2o`000003oc7><Ol0003o8=lP00[o8=lP
00?o0000o`gb3Ol=lPd01Ol=lPd00ol0003o?/4nock1?P05ock1?P03o`000?lOh1oo7n0O00Oo7n0O
0ol00007oacS7003o`000?m2_D;o@[e200Co@[e200?o0000oiEZUOnEJYD02OnEJYD00ol0003odRgB
om8]dP0=om8]dP03o`000?oU6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oH
9mSof2OH00Gof2OH0ol00009ojIIYP05o`000?mKY5_oFjAKoe^TFol000002OmLXe`00ol0003o8=lP
ob3O800;ob3O8003o`000?l=lPgo3O8=00?o3O8=00?o0000ock1?_ln`Ch01_ln`Ch00ol0003o7n0O
oaoP7`06oaoP7`05o`000?ldbcCo=</docC;=?l000001olLha`00ol0003o@[e2od:m@P03od:m@P03
o`000?nEJYGoUFZE00WoUFZE00?o0000om8]d_oB;M803_oB;M800ol0003oiA[UonDJi@09onDJi@03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003of2OHo`000004o`0000;oiQWV00?o0000ojIIY_nVFJH0
1onVFJH01?l0003oFjAKoe^TFol00009oebSG0;o00003OlPgb000ol0003o3O8=o`gb3@02o`gb3@03
o`000?ln`Cko?/4n00So?/4n00?o0000oaoP7olOh1l00olOh1l2o`0000Go=</d00?o0000oacS7?lL
ha`01?lLha`00ol0003o@[e2od:m@P03od:m@P03o`000?nEJYGoUFZE00WoUFZE00?o0000om8]d_oB
;M803_oB;M800ol0003oiA[UonDJi@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SoiQWV
00?o0000ojIIY_nVFJH01_nVFJH00ol0003oFjAKo`000009oebSG004o`000?m>/DkoC[5>o`0000go
8=lP00Co0000o`gb3Ol=lPgo00003?ln`Ch01Ol0003o7n0OoaoP7olOh1oo000000So=</d0_l00005
oacS7003o`000?m2_D;o@[e200;o@[e200?o0000oiEZUOnEJYD02OnEJYD00ol0003odRgBom8]dP0>
om8]dP03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oV6NKoiQWV
00OoiQWV00?o0000ojIIY_nVFJH01onVFJH00ol0003oG:=LoebSG007oebSG003o`000?m>/DkoC[5>
00;oC[5>00?o0000ob3O8?lPgb002_lPgb000ol0003o3O8=o`00000>ock1?P03o`000?lOh1oo0000
00_o=</d00?o0000oacS7?lLha`00_lLha`01Ol0003o@[e2od:m@_m2_D;o000000coUFZE00?o0000
om8]d_oB;M803_oB;M83o`0000WoiA[U00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oV6NKoiQWV
00WoiQWV00?o0000ojIIY_nVFJH01_nVFJH00ol0003oG:=LoebSG006oebSG003o`000?m>/DkoC[5>
00?oC[5>00?o0000ob3O8?lPgb002olPgb000ol0003o?/4nock1?P0>ock1?P03o`000?ldbcCo=</d
00_o=</d0_l00003oacS7004o`000?m2_D;o@[e2o`0000[oUFZE0ol0000>om8]dP;o00000ool0o`2
o`0000OoiA[U00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oV6NKoiQWV00[oiQWV00?o0000ojII
Y_nVFJH01?nVFJH00ol0003oG:=LoebSG006oebSG003o`000?m>/DkoC[5>00GoC[5>00?o0000ob3O
8?lPgb001olPgb03o`00017o?/4n00?o0000ocC;=?ldbc@03Oldbc@01Ol0003o7><LoacS7?l0003o
@[e200Co00000onEJYD5o`0000;ogB;M00?o0000om8]d_oB;M802_oB;M82o`0000Ooo0?l0_l00004
onDJi@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oiQWVonHIiP0;onHIiP03o`000?nVFJKoYUVV
00CoYUVV00?o0000oebSG?mLXe`01OmLXe`00ol0003oC[5>odjaCP06odjaCP03o`000?lPgb3o8=lP
00Co8=lP0ol00002ob[E:P03o`000?ln`Cko?/4n00oo?/4n0_l0000?ocC;=004o`000?lLhaco0000
o`0000CoOh1o0ol00008omdRg@03o`000?oB;M;odRgB00OodRgB0_l0000;oo`3o0;o00000_oU6^D0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onHIi_oV6NH03?oV6NH6o`0000OoG:=L00?o0000odja
C_m>/Dh02?m>/Dh00ol0003o8=lPob3O8003o`0000Ko:]DZ00?o0000ock1?_ln`Ch03Oln`Ch01?l0
003o@ka3od>l@ol0000?ocC;=003o`000?moP7ooOh1o00GoOh1o00?o0000omdRgOoM8]d02?oM8]d0
0ol0003odRgBom8]dP05om8]dP03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oV6NH00ol0003o[U6^ojiA[P04ojiA
[P03o`000?mLXecoG:=L00?oG:=L00?o0000odjaC_m>/Dh02_m>/Dh2o`0000[o:]DZ00?o0000ock1
?_ln`Ch02oln`Ch00ol0003o@ka3od>l@`02od>l@`03o`000?ldbcCo=</d00_o=</d0_l00007ogn0
O`03o`000?oM8]gogB;M00WogB;M00?o0000om8]d_oB;M800_oB;M82o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onHIi_oV6NH02ooV6NH00ol0003o[U6^ojiA[P06ojiA[P05o`000?mLXecoG:=LoebS
G?l000003Om>/Dh00ol0003o:]DZob[E:P0:ob[E:P03o`000?ln`Cko?/4n00Wo?/4n00?o0000od>l
@om3_4<01?m3_4<00ol0003o=</docC;=008ocC;=0;o000000?o</dbo`000?moP7l01omoP7l00ol0
003ogB;MomdRg@09omdRg@04o`000?oB;M;o0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oV6NKoiQWV
00WoiQWV00?o0000ojiA[_n^DJh02?n^DJh00ol0003oG:=Lo`00000=odjaCP03o`000?lZeB[o:]DZ
00_o:]DZ00?o0000ock1?_ln`Ch02?ln`Ch00ol0003o@ka3od>l@`06od>l@`03o`000?ldbcCo=</d
00Go=</d0_l00003oc;=<P03o`000?moP7ooOh1o00KoOh1o00?o0000omdRgOoM8]d02_oM8]d00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003oiQWVonHIiP07onHIiP03o`000?n^DJko[U6^00[o[U6^00?o0000odjaC_m>
/Dh03?m>/Dh00ol0003o:]DZob[E:P0<ob[E:P03o`000?ln`Cko?/4n00Ko?/4n00?o0000od>l@om3
_4<02?m3_4<00ol0003o=</docC;=002ocC;=0;o00001_lbcC800ol0003oOh1oogn0O`05ogn0O`03
o`000?oM8]gogB;M00[ogB;M00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oV6NKoiQWV00GoiQWV
00?o0000ojiA[_n^DJh03?n^DJh2o`0000coC[5>00?o0000ob[E:_lZeBX03OlZeBX00ol0003o?/4n
ock1?P04ock1?P03o`000?m3_4?o@ka300[o@ka300Co0000ocC;=?l0003o00002?lbcC800ol0003o
Oh1oogn0O`06ogn0O`03o`000?oM8]gogB;M00WogB;M00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oV6NH00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mSW6?o000000;o00002?m>/Dh00ol0003o:]DZ
ob[E:P0?ob[E:PKo00003_m3_4<00ol0003o</dboc;=<P08oc;=<P03o`000?moP7ooOh1o00KoOh1o
00?o0000omdRgOoM8]d02OoM8]d00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onPGj?oX5nSoj1OX
0_l0000?ojiA[P03o`000?mSW6?oHiaS00?oHiaS0ol00005odjaCP;o00004?lZeBX01_l0003o6^DJ
oa[U6_l0003o2OH9o`0000ko@ka300?o0000oc;=<_lbcC802OlbcC800ol0003oOh1oogn0O`05ogn0
O`03o`000?oM8]gogB;M00WogB;M00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onPGj?oX5nP00ooX5nP00ol0003o
[U6^ojiA[P0=ojiA[P03o`000?mSW6?oHiaS00KoHiaS0ol000001?m>/Dko0000obcC;?l/db`3o`00
00co:]DZ00Go0000oa[U6_lJiA[o6^DJo`000002o`Wf2@03o`000?m3_4?o@ka300_o@ka300?o0000
oc;=<_lbcC802OlbcC800ol0003oOh1oogn0O`06ogn0O`03o`000?oM8]gogB;M00SogB;M0_l0000A
oo`3o0?o000000?oo0?lo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003oj1OXonPGj004onPGj0oo00003?mSW6<00ol0003o;=</obcC;004obcC
;0?o00002?lZeBX00ol0003o6^DJoa[U6P02oa[U6P05o`000?l9mPWo2OH9o`Wf2Ol000003?m3_4<0
0ol0003o</dboc;=<P09oc;=<P03o`000?moP7ooOh1o00GoOh1o3?l00002oo0?l0;o00003Ool0o`2
o`0000Goo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oj1OXonPGj005onPGj003o`000?nZEJ[oZUFZ00_oZUFZ00?o0000of>L
HomSW6<02_mSW6<00ol0003o;=</obcC;007obcC;0;o00001OlZeBX00ol0003o6^DJoa[U6P03oa[U
6P03o`000?l9mPWo2OH900;o2OH900?o0000od>l@om3_4<02Om3_4<00ol0003o</dboc;=<P0:oc;=
<P03o`000?moP7ooOh1o00?oOh1o00?o0000olTfbOo9=/T02Oo9=/T00ol0003ol0o`oo0?l002oo0?
l0;o00002Ool0o`2o`0000Ooo0?l00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oj1OXonPGj006onPGj003o`000?nZEJ[oZUFZ00[o
ZUFZ00?o0000of>LHomSW6<02omSW6<00ol0003o;=</obcC;009obcC;0?o000000?o:]DZo`000?lJ
iAX01OlJiAX00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?m3_4?o@ka300So@ka33_l00003ogn0O`;o
00002oo9=/T00ol0003ol0o`oo0?l005oo0?l003o`000?ol0ocoo0?l00?oo0?l0ol00009oo`3o003
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onPGj?oX5nP01OoX5nP00ol0003o^TFjo`00000;ojYEZP03o`000?mSW6?oHiaS00[oHiaS
0_l0000>obcC;003o`000?lJiA[o6^DJ00Go6^DJ00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o@ka3
od>l@`08od>l@`03o`000?mkQ7_oNhAk00_oNhAk00?o0000ogn0Ool000003Oo9=/T00ol0003ol0o`
oo0?l006oo0?l0;o000000?oo0?lo`000?l000003Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oX5nSoj1OX00Koj1OX00Co
0000okY5^_njAK[o00002_nZEJX00ol0003oHiaSof>LH`09of>LH`03o`000?m0_d3o000000ko;=</
00?o0000oa[U6_lJiAX01OlJiAX00ol0003o2OH9o`Wf2@04o`Wf2@03o`000?m3_4?o@ka300Ko@ka3
00?o0000og^4NomkQ7/03OmkQ7/00ol0003obCK9olTfb@0<olTfb@03o`000?o`3o3ol0o`00Sol0o`
00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oX5nSoj1OX00Goj1OX00?o0000okY5^_njAKX00_nj
AKX00ol0003oZUFZojYEZP06ojYEZP03o`000?mSW6?oHiaS00SoHiaS0_l00003od2o@003o`000?l/
dbco;=</00_o;=</00?o0000oa[U6_lJiAX01OlJiAX00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?m3
_4?o@ka300Go@ka300?o0000og^4NomkQ7/03OmkQ7/00ol0003obCK9olTfb@0;olTfb@03o`000?o`
3o3ol0o`00Wol0o`00?o0000oo`3o?ol0o`03Ool0o`00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oX5nSoj1OX00Koj1OX00?o0000
okY5^_njAKX00onjAKX00ol0003oZUFZojYEZP05ojYEZP03o`000?mSW6?oHiaS00OoHiaS00?o0000
od2o@?m0_d000om0_d000ol0003o;=</obcC;00:obcC;003o`000?lJiA[o6^DJ00Ko6^DJ00?o0000
o`Wf2Ol9mPT01_l9mPT00ol0003o@ka3od>l@`04od>l@`03o`000?mkQ7_oNhAk00goNhAk3ol0000;
oo0?l003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oX5nSoj1OX00Koj1OX00?o0000okY5^_njAKX01OnjAKX00ol0
003oZUFZojYEZP04ojYEZP03o`000?mSW6?oHiaS00GoHiaS0_l00006od2o@003o`000?l/dbco;=</
00Wo;=</0_l00008oa[U6P03o`000?l9mPWo2OH900Ko2OH91Ol000000om3_4?o0000og^4N`0?og^4
N`03o`000?o;=<_obcC;00_obcC;00?o0000oo0?l?o`3o002Oo`3o000ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?oX5nSoj1OX00Koj1OX00?o0000okY5^_njAKX01_njAKX00ol0003o
ZUFZojYEZP04o`0000KoHiaS00?o0000od2o@?m0_d001om0_d000ol0003o;=</obcC;005obcC;0?o
000000?o5nPGo`000?lJiAX01olJiAX00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?m</dcoC;=<00?o
C;=<0_l0000?og^4N`;o00003Oo;=</00ol0003ol0o`oo0?l008oo0?l003o`000?ol0ocoo0?l00go
o0?l00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000Woj1OX00?o0000okY5^_njAKX01onjAKX2o`0000CoV6NH00Co0000of>LHomSW6?o
HiaS0_l0000:od2o@003o`000?l/dbco;=</00;o;=</0ol00005oaOX5`03o`000?lJiA[o6^DJ00Go
6^DJ00?o0000o`Wf2Ol9mPT01?l9mPT00ol0003oC;=<odbcC006odbcC003o`000?mkQ7_oNhAk00[o
NhAk0_l00002ojIIYP03o`000?o;=<_obcC;00[obcC;00?o0000oo0?l?o`3o002?o`3o000ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onPGj?oX5nP01_oX5nP00ol0003o^TFjokY5^P08okY5^P03o`00
0?nHIiSoV6NH00CoV6NH00?o0000of>LHol000003?m0_d000ol0003o;=</o`000002o`0000Wo5nPG
00?o0000oa[U6_lJiAX01?lJiAX00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?m</dcoC;=<00SoC;=<
1_l00004og^4N`;o00001OnVFJH00ol0003obcC;ol/db`09ol/db`03o`000?o`3o3ol0o`00Sol0o`
00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?oX5nSoj1OX00Goj1OX00?o0000okY5^_njAKX01onj
AKX00ol0003oV6NHoiQWV006oiQWV003o`000?m0_d3o@;m000co@;m000?o0000oaOX5olGj1L02_lG
j1L00ol0003o6^DJoa[U6P04oa[U6P04o`000?l9mPWo2OH9o`Wf2@;o00002om</d`00ol0003oPgb3
oh=lP`03oh=lP`Co00002?nVFJH00ol0003obcC;ol/db`08ol/db`03o`000?o`3o3ol0o`00Ool0o`
0ol0000=oo`3o003o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onPGj?oX5nP00ooX5nP00ol0003o^TFjokY5^P07okY5^P03o`000?nH
IiSoV6NH00OoV6NH00?o0000od2o@?m0_d003?m0_d000ol0003o5nPGoaOX5`0;oaOX5`03o`000?lJ
iA[o6^DJ00?o6^DJ00Co0000o`Wf2Ol9mPWo00003Om</d`00ol0003oPgb3oh=lP`06oh=lP`03o`00
0?nVFJKoYUVV00OoYUVV00?o0000ol/dboo;=</01oo;=</00ol0003ol0o`oo0?l006oo0?l004o`00
0?om0_goo@;mood2o@;o00002ool0o`00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oX5nSoj1OX00;oj1OX00?o0000okY5^_njAKX0
1_njAKX00ol0003oV6NHoiQWV009oiQWV003o`000?m0_d3o@;m000Wo@;m00_l0000>oaOX5`?o0000
0olJiAX00ol0003o2OH9o`00000=odbcC003o`000?n3O8?oPgb300OoPgb300?o0000ojIIY_nVFJH0
2?nVFJH:o`0000Kol0o`0_l00006ood2o@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo^TFj00?o
0000oiQWV?nHIiP02_nHIiP00ol0003o@;m0od2o@006od2o@0;o000000?o>LHio`000?lGj1L02olG
j1L2o`0000?o@Ki11Ol0000>odbcC003o`000?n3O8?oPgb300OoPgb300?o0000ojIIY_nVFJH02?nV
FJH00ol0003of2OHomPWf006omPWf003o`000?o`3o3ol0o`00?ol0o`00?o0000ood2oOom0_d01oom
0_d2o`0000Soo0?l00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ogB;MomdRg@03omdRg@Co00000_njAKX00ol0003oV6NHoiQWV00;
oiQWV003o`000?m0_d3o@;m000?o@;m00ol00004ocW6>@03o`000?lGj1Oo5nPG00Oo5nPG0_l00008
od6n@@03o`000?m</dcoC;=<00goC;=<00?o0000oh=lPon3O8<02?n3O8<00ol0003oYUVVojIIYP07
ojIIYP03o`000?oH9mSof2OH00Oof2OH0ol000000oo`3o3o0000ood2o@0;ood2o@;o00001Ool0o`0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oM8]gogB;M00OogB;M0_l0000?oiQWV003o`000?m0_d3o@;m000;o00002?liaST00ol0
003o5nPGoaOX5`05oaOX5`03o`000?m1_T7o@Ki100So@Ki100?o0000odbcC?m</d`03Om</d`00ol0
003oPgb3oh=lP`08oh=lP`03o`000?nVFJKoYUVV00KoYUVV00?o0000omPWf?oH9mP02?oH9mP01?l0
003ol@kaoo4>lOl0000?ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ogB;MomdRg@09omdR
g@03o`000?nHIiSoV6NH00koV6NH0_l0000;ocW6>@03o`000?lGj1Oo5nPG00;o5nPG0_l0000;od6n
@@03o`000?m</dcoC;=<00goC;=<00?o0000oh=lPon3O8<02?n3O8<00ol0003oYUVVojIIYP06ojII
YP03o`000?oH9mSof2OH00Oof2OH00Go0000oo4>lOoa3_7ol@kao`00000@ood2o@;o000000?oo0?l
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ogB;MomdRg@0:omdRg@03o`000?nHIiSoV6NH00goV6NH0_l0000<ocW6>@04o`000?lGj1Oo0000
o`0000go@Ki100?o0000odbcC?m</d`03?m</d`00ol0003oPgb3oh=lP`09oh=lP`03o`000?nVFJKo
YUVV00KoYUVV00?o0000omPWf?oH9mP01_oH9mP00ol0003ol@kaoo4>l@03oo4>l@03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ogB;MomdRg@0:omdRg@03o`000?nHIiSoV6NH00coV6NH00Co0000of>L
HomSW6?o00003?liaST00ol0003o@Ki1od6n@@0>od6n@@03o`000?m</dcoC;=<00SoC;=<1?l0000;
oh=lP`03o`000?nVFJKoYUVV00KoYUVV00?o0000omPWf?oH9mP01OoH9mP00ol0003ol@kaoo4>l@04
oo4>l@03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ogB;MomdRg@0;omdRg@03o`000?nHIiSoV6NH
00_oV6NH00?o0000of>LHomSW6<00_mSW6<00ol0003o>LHiocW6>@09ocW6>@03o`000?m1_T7o@Ki1
00ko@Ki100Co0000odbcC?m</dcoC;=<1ol00003oefRG@03o`000?n3O8?oPgb300WoPgb300?o0000
ojIIY_nVFJH01_nVFJH00ol0003of2OHomPWf004omPWf003o`000?oa3_7ol@ka00Kol@ka00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oM8]gogB;M00cogB;M00?o0000oiQWV?nHIiP02_nHIiP00ol0
003oHiaSof>LH`03of>LH`03o`000?liaSWo>LHi00So>LHi00?o0000od6n@Om1_T403_m1_T44o`00
00_oGJ9M00?o0000oh=lPon3O8<02?n3O8<00ol0003oYUVVojIIYP05ojIIYP03o`000?oH9mSof2OH
00Gof2OH00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000omdRgOoM
8]d03?oM8]d7o`0000GoV6NH00?o0000of>LHomSW6<01OmSW6<00ol0003o>LHiocW6>@07ocW6>@03
o`000?m1_T7o@Ki100ko@Ki100?o0000oefRGOmMXUd03OmMXUd00ol0003oPgb3oh=lP`08oh=lP`03
o`000?nVFJKoYUVV00CoYUVV00?o0000omPWf?oH9mP01?oH9mP00ol0003ol@kaoo4>l@07oo4>l@03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ogB;MomdRg@0=omdRg@03o`000?ngB;Oo]dRg00Co]dRg
1Ol00009of>LH`03o`000?liaSWo>LHi00Ko>LHi00?o0000od6n@Om1_T403_m1_T400ol0003oGJ9M
oefRG@0=oefRG@03o`000?n3O8?oPgb300SoPgb300Co0000ojIIY_nVFJKoYUVV1Ol00004omPWf003
o`000?oa3_7ol@ka00Wol@ka1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=omdRg@03o`000?ngB;Oo]dRg00Wo]dRg
0_l00009of>LH`03o`000?liaSWo>LHi00Ko>LHi00?o0000od6n@Om1_T403?m1_T400ol0003oGJ9M
oefRG@0?oefRG@Ko00001?n3O8<4o`0000GoeRWF0_l000000ooH9mSo0000oo4>l@0;oo4>l@04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o/4ncok1?/on`Ck0?o00002_oM8]d00ol0003o
]dRgokM8]`09okM8]`03o`000?miQWWo000000;o00001omSW6<00ol0003o>LHiocW6>@05ocW6>@03
o`000?m1_T7o@Ki100So@Ki11Ol0000AoefRG@03o`000?nCK9?oTfbC00?oTfbC1?l0000;omHYeP03
o`000?oa3_7ol@ka00[ol@ka00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000on`Ck?o/4n`01Oo/4n`2o`0000OogB;M
00?o0000okM8]ongB;L02_ngB;L00ol0003oNHIiogV6N@02ogV6N@?o00001OmSW6<00ol0003o>LHi
ocW6>@04ocW6>@04o`000?m1_T7o@Ki1od6n@@Oo00001?m5^TD00ol0003oGJ9MoefRG@0>oefRG@03
o`000?nCK9?oTfbC00OoTfbC00?o0000omHYe_oF:MH02OoF:MH00ol0003ol@kaoo4>l@09oo4>l@03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ok1?/on`Ck008on`Ck0;o00001?oM8]d00ol0003o]dRg
okM8]`0;okM8]`03o`000?miQWWoNHIi00GoNHIi0ol00003of>LH`04o`000?liaSWo>LHiocW6>@Ko
00003?m5^TD00ol0003oGJ9MoefRG@0=oefRG@03o`000?nCK9?oTfbC00OoTfbC00?o0000omHYe_oF
:MH02_oF:MH00ol0003ol@kaoo4>l@08oo4>l@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=on`Ck0?o000000?ogB;Mo`000?ngB;L0
3?ngB;L00ol0003oNHIiogV6N@08ogV6N@?o000000CoHiaSo`000?l0003o00000_n9MXT00ol0003o
AKY5odFjA@0=odFjA@03o`000?mMXUgoGJ9M00coGJ9M00?o0000oi=/TonCK9<02?nCK9<00ol0003o
eRWFomHYeP0;omHYeP03o`000?oa3_7ol@ka00Kol@ka00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
k1?/00?o0000okM8]ongB;L03?ngB;L00ol0003oNHIiogV6N@0;ogV6N@03o`000?n9MXWoRGJ900?o
RGJ900?o0000odFjAOm5^TD03?m5^TD00ol0003o?kloo`00000=oefRG@03o`000?nCK9?oTfbC00So
TfbC00?o0000omHYe_oF:MH03?oF:MH3o`0000Gol@ka00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o/4ncok1?/00cok1?/00?o0000okM8]ongB;L03?ngB;L00ol0003oNHIiogV6N@0:ogV6N@03o`00
0?n9MXWoRGJ900GoRGJ900?o0000odFjAOm5^TD02_m5^TD01?l0003o?kloocno?olo_cl2o`0000[o
GJ9M00?o0000oi=/TonCK9<02OnCK9<00ol0003oeRWFomHYeP0<omHYeP03o`000?oc3??ol`cc00?o
000000?ol@kao`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000okM8]ongB;L0
3?ngB;L00ol0003oNHIiogV6N@09ogV6N@03o`000?n9MXWoRGJ900KoRGJ900?o0000odFjAOm5^TD0
2Om5^TD00ol0003o?kloocno?`02ocno?`03o`000?n9MXWo000000;o00001omMXUd00ol0003oTfbC
oi=/T`09oi=/T`03o`000?oF:MKoeRWF00_oeRWF00?o0000oo<<looc3?<01?oc3?<00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000on`Ck?o/4n`02oo/4n`00ol0003o]dRgokM8]`0;okM8]`03o`000?mi
QWWoNHIi00SoNHIi00?o0000ohUfROn9MXT01on9MXT00ol0003oAKY5odFjA@08odFjA@03o`000?lo
_coo?klo00?o?klo00?o0000ohUfROn9MXT00_n9MXT2o`0000CoGJ9M00?o0000oi=/TonCK9<02_nC
K9<00ol0003oeRWFomHYeP0:omHYeP03o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o/4ncok1?/00[ok1?/0ol0000;okM8]`Ko00001?miQWT00ol0003oRGJ9ohUfR@08
ohUfR@03o`000?m5^TGoAKY500OoAKY500?o0000ocno?olo_cl00olo_cl00ol0003oRGJ9ohUfR@05
ohUfR@?o000000?oGJ9Mo`000?nCK9<02onCK9<00ol0003oeRWFomHYeP09omHYeP03o`000?oc3??o
l`cc00Ool`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o/4ncok1?/00Wok1?/00?o0000om@[
e?oD:m@01?l00006okM8]`03o`000?ndBkCo]4^d00Co]4^d1?l0000<ohUfR@03o`000?m5^TGoAKY5
00GoAKY500?o0000ocno?olo_cl01?lo_cl00ol0003oRGJ9ohUfR@08ohUfR@03o`000?nCK9?oTfbC
00_oTfbC00?o0000omHYe_oF:MH02?oF:MH00ol0003ol`ccoo<<l`08oo<<l`Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o/4ncok1?/00Ook1?/00?o0000om@[e?oD:m@01OoD:m@3o`0000;o]dRg00?o0000okA;]?nd
Bk@02?ndBk@00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?m5^TGoAKY500CoAKY500?o0000ocno?olo
_cl01Olo_cl00ol0003oRGJ9ohUfR@08ohUfR@03o`000?nCK9?oTfbC00WoTfbC1?l00008omHYeP03
o`000?oc3??ol`cc00Wol`cc00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ok1?/
on`Ck005on`Ck003o`000?oD:mCoe2_D00Woe2_D0_l0000<okA;]003o`000?n9MXWoRGJ900WoRGJ9
00?o0000odFjAOm5^TD00om5^TD00ol0003o?kloocno?`05ocno?`03o`000?n9MXWoRGJ900[oRGJ9
00?o0000oi=/TonCK9<01?nCK9<4o`0000Coc3?<00?o0000omHYe_oF:MH01?oF:MH00ol0003ol`cc
oo<<l`0:oo<<l`03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o/4ncok1?/00?ok1?/00?o0000om@[e?oD:m@02ooD
:m@00ol0003o]4^dokA;]00:okA;]003o`000?n9MXWoRGJ900WoRGJ900?o0000odFjAOm5^TD00_m5
^TD00ol0003o?kloocno?`06ocno?`03o`000?n9MXWoRGJ900[oRGJ900?o0000oi=/TonCK9<01?l0
0009ol`cc0Ko00003?oc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000on`Ck?o/4ncok1?/0_l0
000=om@[e003o`000?ndBkCo]4^d00[o]4^d00?o0000ohUfROn9MXT02On9MXT01Ol0003oAKY5odFj
AOm5^TGo000000Wo?klo00?o0000ohUfROn9MXT02on9MXT2o`0000goc3?<00?o0000oo0?l?o`3o00
0_o`3o000ol0003ol`ccoo<<l`0:oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ok1?/o`00
0002oo@;m0;o00002ooD:m@00ol0003o]4^dokA;]00;okA;]003o`000?n9MXWoRGJ900WoRGJ900?o
0000odFjAOl000002Olo_cl00ol0003oRGJ9ohUfR@0<ohUfR@03o`000?o<<lcoc3?<00coc3?<00?o
0000oo0?l?o`3o000oo`3o000ol0003ol`ccoo<<l`09oo<<l`03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om0_doo@;m003oo@;m0;o00002_oD:m@00ol0003o]4^dokA;]00:okA;]003o`000?n9MXWo
RGJ900SoRGJ91Ol00008ocno?`03o`000?n9MXWoRGJ900coRGJ900?o0000ol`cc?o<<l`02oo<<l`0
0ol0003ol0o`oo0?l005oo0?l003o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ood2o@2o`0000Soe2_D00?o0000okA;]?ndBk@02_ndBk@00ol0003oRGJ9ohUfR@07ohUf
R@03o`000?n4NhCoQ7^400?oQ7^40ol00005ocno?`03o`000?n9MXWoRGJ900_oRGJ900?o0000ol`c
c?o<<l`03?o<<l`00ol0003ol0o`oo0?l006oo0?l003o`000?oc3??ol`cc00Ool`cc00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Wom0_d00?o0000om@[e?oD:m@01OoD:m@2o`0000co
]4^d00?o0000ohUfROn9MXT01On9MXT00ol0003oQ7^4ohAkQ007ohAkQ0?o000000?o?kloo`000?n9
MXT03On9MXT00ol0003oc3?<ol`cc00<ol`cc003o`000?o`3o3ol0o`00Kol0o`00?o0000oo<<looc
3?<01_oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?od2oCom0_d00Oom0_d
0_l00004om@[e003o`000?oN8MkogR7N00;o00002_ndBk@00ol0003oRGJ9ohUfR@03ohUfR@;o0000
3On4Nh@2o`0000goRGJ90ol0000=ol`cc003o`000?o`3o3ol0o`00Ool0o`00?o0000oo<<looc3?<0
1Ooc3?<00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?od2oCom0_d00Som0_d0_l0
00000ooD:mCo0000omhQgP04omhQgP03o`000?ndBkCo]4^d00Oo]4^d00Co0000ohUfROn9MXWoRGJ9
0_l00002okA;]003o`000?n4NhCoQ7^400coQ7^43Ol00003ol<l``03o`000?o<<lcoc3?<00[oc3?<
00?o0000oo0?l?o`3o002?o`3o001?l0003ol`ccoo<<looc3?<4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003om0_d
oo@;m009oo@;m003o`000?oN8MkogR7N00GogR7N0_l00008okA;]003o`000?n9MXWo000000Go]4^d
00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003oTVfBoi9]TP09oi9]TP03o`000?o3?<?o`cc300;o`cc3
0_l00009ol`cc003o`000?o`3o3ol0o`00[ol0o`0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?od2oCom0_d00Som0_d00?o0000omhQg_oN8Mh01ooN8Mh4o`0000?o]4^d0ol0
0007okA;]003o`000?n4NhCoQ7^400[oQ7^400?o0000oi9]T_nBKI802OnBKI800ol0003o`cc3ol<l
``04ol<l``;o00001oo<<l`00ol0003ol0o`oo0?l00:oo0?l003o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Oom0_d00?o0000omhQg_oN8Mh02?oN8Mh0
1?l0003og2?Lom`Sg?oL8m`3o`0000;ocS7>00?o0000okA;]?ndBk@01_ndBk@00ol0003oQ7^4ohAk
Q008ohAkQ003o`000?nBKI;oTVfB00[oTVfB00?o0000ol<l`oo3?<<01_o3?<<00ol0003oc3?<ol`c
c004ol`cc003o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000oo@;m?od2o@01Ood2o@00ol0003ogR7NomhQgP08omhQgP03o`000?oL8mco
g2?L00Cog2?L00Go0000olhac_o><LkocS7>o`000008okA;]003o`000?n4NhCoQ7^400OoQ7^400?o
0000oi9]T_nBKI802_nBKI800ol0003o`cc3ol<l``07ol<l``;o00001?o<<l`00ol0003ol0o`oo0?
l008oo0?l003o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@00ood2o@0
0ol0003ogR7NomhQgP08omhQgP03o`000?oL8mcog2?L00Cog2?L00?o0000olhac_o><Lh00_o><Lh0
0ol0003o]4^dokA;]007okA;]003o`000?n4NhCoQ7^400KoQ7^400?o0000oi9]T_nBKI802_nBKI80
0ol0003o`cc3ol<l``09ol<l``05o`000?o<<lcoc3?<ol`cc?l000002Oo`3o000ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_ogR7N00?o0000om`Sg?oL8m`01?oL8m`00ol0003ocS7>olhacP03
olhacP03o`000?ndBkCo]4^d00Oo]4^d00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003oTVfBoi9]TP0:
oi9]TP03o`000?o3?<?o`cc300Wo`cc31?l00009oo0?l003o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oe2_Gom@[e
ooD:mOl000002_oN8Mh00ol0003og2?Lom`Sg005om`Sg003o`000?o><LkocS7>00?ocS7>00?o0000
okA;]?ndBk@02?ndBk@00ol0003oQ7^4ohAkQ004ohAkQ003o`000?nBKI;oTVfB00WoTVfB00?o0000
ol<l`oo3?<<02?o3?<<2o`0000?ol0o`00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003ogR7NomhQgP06omhQgP03o`000?oL8mcog2?L
00Gog2?L00?o0000olhac_o><Lh01?o><Lh00ol0003o]4^dokA;]009okA;]003o`000?n4NhCoQ7^4
00;oQ7^400?o0000oi9]T_nBKI802_nBKI800ol0003o`cc3ol<l``06ol<l``;o00001_o`3o08o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oN8MkogR7N00GogR7N00?o0000om`Sg?oL
8m`01OoL8m`00ol0003ocS7>olhacP05olhacP03o`000?ndBkCo]4^d00Wo]4^d00Go0000ohAkQ?n4
NhCoQ7^4o`00000<oi9]TP03o`000?o3?<?o`cc300Co`cc30_l00008oo0?l003o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oe2_Gom@[e00Oom@[e00?o0000omhQg_oN
8Mh00ooN8Mh00ol0003og2?Lom`Sg006om`Sg003o`000?o><LkocS7>00GocS7>00?o0000okA;]?nd
Bk@02_ndBk@00ol0003oQ7^4o`000004o`0000WoTVfB00?o0000ol<l`oo3?<<00_o3?<<2o`0000[o
l0o`00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om@[eooD:m@07ooD:m@03o`00
0?oN8MkogR7N00;ogR7N00?o0000om`Sg?oL8m`01_oL8m`00ol0003ocS7>olhacP07olhacP;o0000
2ondBk@00ol0003oe2_Dom@[e003om@[e0Oo00000_nBKI800ol0003o`cc3ol<l``02o`0000_ol0o`
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooD:mOoe2_D02Ooe
2_D01Ol0003ogR7NomhQg_oN8Mko000000Sog2?L00?o0000olhac_o><Lh01oo><Lh00ol0003oj1OX
o`000002o`0000So]4^d00?o0000om@[e?oD:m@02_oD:m@5o`0000gol0o`00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooD:m@03o`000?oN8Mko000000Wog2?L00?o
0000olhac_o><Lh01_o><Lh00ol0003oj1OXonPGj003onPGj0?o00001?ndBk@00ol0003oe2_Dom@[
e00=om@[e003o`000?o`3o3ol0o`00gol0o`00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_om@[e00?o0000om`Sg?oL8m`01ooL8m`00ol0003ocS7>olhacP07
olhacP03o`000?oX5nSoj1OX00Koj1OX0ol000000ondBkCo0000om@[e00>om@[e003o`000?o`3o3o
l0o`00col0o`00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooD:
m@03o`000?oL8mcog2?L00;og2?L1_l00008olhacP03o`000?oX5nSoj1OX00[oj1OX00?o0000om@[
e?oD:m@03ooD:m@00ol0003ol0o`oo0?l00:oo0?l0;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooD:m@Go00001_oa3_400ol0003ocS7>olhacP05olhacP03o`000?oX5nSoj1OX00[o
j1OX00?o0000om@[e?oD:m@03ooD:m@00ol0003ol0o`oo0?l007oo0?l0?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooD:m@03o`000?oa3_7ol@ka00Wol@ka00?o0000olhac_o>
<Lh00oo><Lh00ol0003oj1OXonPGj00;onPGj003o`000?oD:mCoe2_D00ooe2_D00?o0000oo0?l?o`
3o001Oo`3o02o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?om@[eo`000?l00000
3Ooa3_400ol0003ocS7>olhacP02olhacP03o`000?oX5nSoj1OX00_oj1OX5?l00004oo0?l0;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo4>l@04o`000?o><LkocS7>o`0000koj1OX
00?o0000oo@;m?od2o@04?od2o@00ol0003ol0o`o`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_oa3_400ol0003ocS7>o`00000>onPGj003o`00
0?od2oCom0_d017om0_d00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003ol@kaoo4>l@0=oo4>l@03o`000?oX5nSoj1OX00Woj1OX1Ol0
000Boo@;m0;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003ol@kaoo4>l@0<oo4>l@03o`000?oX5nSoj1OX00;oj1OX1ol00004oo`3o003o`000?od2oCo
m0_d00oom0_d00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?oa3_7ol@ka00col@ka1?l0000<oo`3o003o`000?od2oCom0_d00com0_d0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo4>lOoa3_403?oa3_400ol0003oo0?loo`3o00=oo`3o003o`000?od2oCom0_d00_o
m0_d00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003ol@kaoo4>l@0:oo4>l@03o`000?ol0ocoo0?l00koo0?l00?o0000oo@;m?od
2o@02Ood2o@2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_402_oa3_400ol0003oo0?l
oo`3o00?oo`3o003o`000?od2oCom0_d00Kom0_d0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_od2o@00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo0?loo`3o00>oo`3o005o`000?om0_goo@;mood2oOl000000ood2o@2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o003o`000?om0_go
o@;m00?oo@;m00?o0000oo@;m?l000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3
o007oo`3o0;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0oco
o0?l00Goo0?l00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o0?loo`3o003oo`3o003o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?ol0ocoo0?lo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01ol00?l00oooo`3o003oo`00o`08o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000Oo003o2?ooo`07o`00o`03oooo0?l0
0?oo003o00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002?l00?l00oooo`3o003oo`00o`03o`00o`;oool01_l00?l0
0oooo`3o003oo`00o`06o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00
o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00
o`;oool00ol00?l00oooo`3o003oo`00o`02o`00o`;oool000?o003ooooo0?ooo`002Ol00?l00ooo
o`3o003oo`00o`03o`00o`03oooo0?l00?oo003o00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?oo
ool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Co
ool000?o003ooooo0?ooo`002Ol00?l2oooo00co003o00?oool0o`00ool00?l01Ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0:o`00o`03oooo0?l00?oo003o00[o003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00_o003o00?oool0o`00ool00?l02_l00?l00oooo`3o003oo`00o`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0<o`00o`03oooo0?l00?oo003o00Wo003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l2oooo00[o003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o00Wo003o00?o
ool0o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool03Ol00?l2oooo00[o003o00?oool0o`00ool00?l00_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00o`;oool02_l00?l00oooo`3o003oo`00o`02o`00
o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go
003o00?oool0o`00ool00?l05ol00?l2oooo00Ko003o00?oool0o`00ool00?l01?l00?l2oooo00_o
003o00Coool0o`00ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01_l00?l2oooo00Go
003o0_ooo`02o`00o`03oooo0?l00?oo003o00Ko003o00?oool0o`00ool00?l00_l00?l2oooo00Co
003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo
0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`04o`00o`;oool00ol00?l3oooo00?o003o
00?oool0o`00ool00?l01Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Ko003o
00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o1Oooo`05o`00o`Koool01?l00?l:oooo00Co003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Q
o`00o`Coool01Ol00?l:oooo00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(280) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.991 .009 .991 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.991 .009 .991 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.991 .009 .991 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.99 .01 .99 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.953 .047 .953 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.989 .011 .989 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.953 .047 .953 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.949 .051 .949 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.924 .076 .924 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.985 .015 .985 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.906 .094 .906 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.99 .01 .99 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.829 .171 .829 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.84 .16 .84 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.986 .014 .986 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.739 .261 .739 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.882 .118 .882 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.983 .017 .983 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.986 .014 .986 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.948 .052 .948 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.544 .456 .544 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.873 .127 .873 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.738 .262 .738 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.728 .272 .728 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.787 .213 .787 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.891 .109 .891 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.926 .074 .926 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.991 .009 .991 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.712 .288 .712 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.865 .135 .865 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.587 .413 .587 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.914 .086 .914 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.87 .13 .87 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.793 .207 .793 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.853 .147 .853 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.662 .338 .662 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.904 .096 .904 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.74 .26 .74 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.993 .007 .993 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.931 .069 .931 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.67 .33 .67 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.349 .651 .349 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.4 .6 .4 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.959 .041 .959 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.962 .038 .962 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.838 .162 .838 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.991 .009 .991 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.693 .307 .693 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.681 .319 .681 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.445 .555 .445 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.458 .542 .458 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.264 .736 .264 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.665 .335 .665 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.726 .274 .726 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.991 .009 .991 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.707 .293 .707 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.603 .397 .603 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.941 .059 .941 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.38 .62 .38 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.876 .124 .876 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.816 .184 .816 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.443 .557 .443 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.26 .74 .26 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.534 .466 .534 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.037 .963 .037 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.071 .929 .071 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.268 .732 .268 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.377 .623 .377 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.398 .602 .398 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.871 .129 .871 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.214 .786 .214 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.241 .759 .241 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.716 .284 .716 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.947 .053 .947 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.99 .01 .99 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.198 .802 .198 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.258 .742 .258 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.498 .502 .498 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.989 .011 .989 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.674 .326 .674 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.307 .693 .307 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.412 .588 .412 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.071 .929 .071 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.435 .565 .435 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.228 .772 .228 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.947 .053 .947 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.16 .84 .16 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.025 .975 .025 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.815 .185 .815 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.093 .907 .093 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.052 .948 .052 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.546 .454 .546 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.895 .105 .895 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.264 .736 .264 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.068 .932 .068 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.427 .573 .427 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.12 .88 .12 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.172 .828 .172 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.911 .089 .911 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.06 .94 .06 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.158 .842 .158 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.09 .91 .09 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.719 .281 .719 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.247 .753 .247 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.988 .012 .988 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.314 .686 .314 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.125 .875 .125 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.149 .851 .149 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.204 .796 .204 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.08 .92 .08 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.042 .958 .042 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.278 .722 .278 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.531 .469 .531 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.989 .011 .989 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.768 .232 .768 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.213 .787 .213 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.302 .698 .302 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.264 .736 .264 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.949 .051 .949 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.097 .903 .097 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.04 .96 .04 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.234 .766 .234 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.607 .393 .607 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.034 .966 .034 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.99 .01 .99 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.11 .89 .11 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.84 .16 .84 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.956 .044 .956 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.546 .454 .546 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.587 .413 .587 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.164 .836 .164 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.884 .116 .884 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.081 .919 .081 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.295 .705 .295 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.524 .476 .524 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.114 .886 .114 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.258 .742 .258 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.368 .632 .368 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.989 .011 .989 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.024 .976 .024 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.989 .011 .989 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.925 .075 .925 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.256 .744 .256 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.212 .788 .212 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.077 .923 .077 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.778 .222 .778 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.201 .799 .201 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.942 .058 .942 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.262 .738 .262 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.286 .714 .286 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.294 .706 .294 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.588 .412 .588 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.746 .254 .746 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.525 .475 .525 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.074 .926 .074 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.118 .882 .118 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.21 .79 .21 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.496 .504 .496 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.805 .195 .805 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.99 .01 .99 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.936 .064 .936 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.207 .793 .207 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.273 .727 .273 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.246 .754 .246 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.812 .188 .812 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.664 .336 .664 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.989 .011 .989 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.51 .49 .51 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.844 .156 .844 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.941 .059 .941 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.15 .85 .15 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.251 .749 .251 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.927 .073 .927 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.206 .794 .206 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.596 .404 .596 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.584 .416 .584 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.422 .578 .422 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.405 .595 .405 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.871 .129 .871 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.799 .201 .799 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.806 .194 .806 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.855 .145 .855 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.358 .642 .358 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.954 .046 .954 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.775 .225 .775 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.384 .616 .384 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.399 .601 .399 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.672 .328 .672 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.464 .536 .464 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.989 .011 .989 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.947 .053 .947 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.828 .172 .828 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.943 .057 .943 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.368 .632 .368 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.919 .081 .919 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.756 .244 .756 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.66 .34 .66 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.991 .009 .991 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.636 .364 .636 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.515 .485 .515 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.991 .009 .991 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.74 .26 .74 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.985 .015 .985 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.992 .008 .992 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.574 .426 .574 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.988 .012 .988 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.574 .426 .574 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.989 .011 .989 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.698 .302 .698 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.849 .151 .849 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.743 .257 .743 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.898 .102 .898 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.917 .083 .917 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.78 .22 .78 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.646 .354 .646 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.766 .234 .766 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.867 .133 .867 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.916 .084 .916 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.879 .121 .879 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.892 .108 .892 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.986 .014 .986 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.786 .214 .786 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.942 .058 .942 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.988 .012 .988 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.955 .045 .955 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.936 .064 .936 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.797 .203 .797 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.946 .054 .946 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.919 .081 .919 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.866 .134 .866 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.988 .012 .988 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.986 .014 .986 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.931 .069 .931 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.99 .01 .99 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.988 .012 .988 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.989 .011 .989 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.988 .012 .988 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.99 .01 .99 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003oka3_onl@kol0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000onl@koo_4>l00_o_4>l00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?o_4>ooka3_00?oka3_00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000onl@koo_4>l01Oo_4>l00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oka3_onl@k`06onl@k`03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ob3O;o0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000coka3_00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003oo8=lP03o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003ok1?/on`Ck005on`Ck003o`000?o_
4>ooka3_00_oka3_0ol00003ondBk@03o`000?om0_goo@;m00coo@;m0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
oo8=l_ob3O800oob3O800ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003ok1?/on`Ck006
on`Ck003o`000?o_4>ooka3_00[oka3_00?o0000ondBkOo]4^d01?o]4^d00ol0003oo@;mood2o@0:
ood2o@04o`000?o[5>_ojaC[on/Dj`;o00002_ol0o`2o`000003onXEj_l0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP05oo8=lP03o`000?ol0oco
o0?l00Woo0?l00?o0000oo8=l_l000002oom0_d00ol0003ok1?/on`Ck006on`Ck003o`000?o_4>oo
ka3_00Woka3_00?o0000ondBkOo]4^d01_o]4^d00ol0003oo@;mood2o@08ood2o@03o`000?o[5>_o
jaC[00CojaC[0_l00005oo`3o0?o00001?oZ5NX00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008oo8=lP03o`000?ol0ocoo0?l00Ooo0?l0_l00003oo8=
lP03o`000?om0_goo@;m00Ooo@;m00?o0000on`Ck?o/4n`01oo/4n`00ol0003oka3_onl@k`09onl@
k`03o`000?o]4^gokA;]00OokA;]00?o0000ood2oOom0_d01Oom0_d2o`0000WojaC[0_l000000ool
0oco0000o`000007onXEjP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000oo8=l_ob
3O802?ob3O800ol0003oo0?loo`3o006oo`3o003o`000?ob3O;olPgb00?olPgb00?o0000ood2oOom
0_d01oom0_d00ol0003ok1?/on`Ck008on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ondBkOo]
4^d02Oo]4^d00ol0003oo@;mood2o@03ood2o@03o`000?o[5>_ojaC[00_ojaC[00?o0000onXEj_oZ
5NX01ooZ5NX00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`o`000005ood2o@;o00002oob3O82o`0000Koo0?l
00?o0000oo8=l_ob3O801Oob3O800ol0003oo@;mood2o@06ood2o@03o`000?o/4ncok1?/00Sok1?/
00?o0000onl@koo_4>l01_o_4>l00ol0003okA;]ondBk@0;ondBk@05o`000?om0_goo@;mood2oOl0
00003_o[5>/00ol0003ojQGZonXEjP08onXEjP03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?o`3o3ol0o`oo0?l?l0
00000oom0_d00ol0003olPgboo8=lP0:oo8=lP04o`000?oU6^GoiA[Uo`0000?oo0?l0_l00008oo8=
lP03o`000?om0_goo@;m00Koo@;m00?o0000on`Ck?o/4n`02Oo/4n`00ol0003oka3_onl@k`05onl@
k`03o`000?o]4^gokA;]00cokA;]00?o0000ood2oOl000003oo[5>/00ol0003ojQGZonXEjP08onXE
jP03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l003oo0?l003o`000?om0_go000000_o
lPgb0_l00004onDJi@03o`000?ol0oco000000_olPgb00?o0000ood2oOom0_d01Oom0_d00ol0003o
k1?/on`Ck009on`Ck003o`000?o_4>ooka3_00Coka3_00?o0000ondBkOo]4^d03_o]4^d00ol0003o
jaC[on/Dj`0>on/Dj`03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo0?l?o`3o00
1?o`3o000ol0003olPgboo8=lP09oo8=lP03o`000?oU6^GoiA[U00GoiA[U00?o0000oo8=l_ob3O80
2_ob3O800ol0003oo@;mood2o@05ood2o@03o`000?o/4ncok1?/00[ok1?/00?o0000onl@koo_4>l0
0oo_4>l00ol0003okA;]ondBk@0>ondBk@03o`000?o[5>_ojaC[00gojaC[00?o0000onXEj_oZ5NX0
2_oZ5NX00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?
l005oo0?l003o`000?ob3O;olPgb00OolPgb0_l00008onDJi@03o`000?ob3O;olPgb00_olPgb00?o
0000ood2oOom0_d01?om0_d00ol0003ok1?/on`Ck00:on`Ck004o`000?o_4>ooka3_onl@k`?o0000
3oo]4^d00ol0003ojaC[on/Dj`0>on/Dj`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?o`3o3ol0o`00Ool0o`00?o0000oo8=l_ob3O801?ob3O82o`0000_oiA[U1?l0
0009oo8=lP03o`000?om0_goo@;m00?oo@;m00?o0000on`Ck?o/4n`02oo/4n`01?l0003oka3_o`00
0?l00003oll`c`;o00003?o]4^d2o`00013ojaC[00?o0000onXEj_oZ5NX02ooZ5NX00ol0003oo0?l
oo`3o00=oo`3o004o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ol0o`
oo0?l007oo0?l003o`000?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D02ooU6^D01?l0003oa3_4
ol@ka?o4>l@5o`0000GolPgb00?o0000ood2oOom0_d00_om0_d00ol0003ok1?/on`Ck00<on`Ck003
o`000?o?<<oocc3?00Gocc3?0_l00008ondBk@;o00000_o6>LH00ol0003ojaC[on/Dj`0=on/Dj`03
o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ol0o`oo0?l009oo0?l003o`000?ob3O;olPgb00;o0000
3OoU6^D00ol0003oa3_4ol@ka007ol@ka0Ko00000_om0_d4o`0000gok1?/00?o0000oll`coo?<<l0
1oo?<<l2o`0000GokA;]00?o0000olHia_o6>LH00oo6>LH00ol0003ojaC[on/Dj`0<on/Dj`03o`00
0?oZ5N[ojQGZ00cojQGZ00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Wol0o`00?o
0000oo8=l_l000003ooU6^D00ol0003oa3_4ol@ka00<ol@ka0?o00001?oR7N83o`0000Wok1?/00?o
0000oll`coo?<<l02_o?<<l2o`000003ondBkOl0003o000000OoaSW600?o0000on/Djoo[5>/02oo[
5>/00ol0003ojQGZonXEjP0<onXEjP03o`000?ol0ocoo0?l00Koo0?l1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000
onDJiOoU6^D03_oU6^D00ol0003oa3_4ol@ka00=ol@ka003o`000?oR7N;ohQgR00KohQgR0ol00005
on`Ck003o`000?o?<<oocc3?00gocc3?00?o0000olHia_o6>LH02?o6>LH00ol0003ojaC[on/Dj`09
on/Dj`03o`000?oZ5N[ojQGZ00gojQGZ00Co0000oo`3o?ol0ocoo0?l1Ol00003onl@k`03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo0?l?o`3o002oo`3o02o`0000ooiA[U00?o0000ol@ka?o4>l@03Oo4>l@00ol0003ohQgRon8MhP0:
on8MhP?o000000?ok1?/o`000?o?<<l03oo?<<l00ol0003oaSW6olHiaP09olHiaP03o`000?o[5>_o
jaC[00SojaC[00?o0000onXEj_oZ5NX03_oZ5NX3o`0000Soka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?o`3o3ol0o`00Sol0o`0ol000000oo@
;m3o0000onDJi@0>onDJi@03o`000?o4>lCoa3_400goa3_400?o0000on8Mh_oR7N803OoR7N800ol0
003occ3?oll`c`0?oll`c`03o`000?o6>LKoaSW600[oaSW62ol0000;onXEjPGo00003?o_4>l00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003okQ7^o`000?om0_go0000
00Sol0o`0ol00005om0_d003o`000?oU6^GoiA[U00coiA[U00?o0000ol@ka?o4>l@03Oo4>l@00ol0
003ohQgRon8MhP0=on8MhP;o00004?o?<<l00ol0003oaSW6olHiaP0:olHiaP03o`000?o1?/7o`Ck1
00Oo`Ck100?o0000onXEj_oZ5NX00_oZ5NX7o`0000CoacS700?o0000onl@koo_4>l02_o_4>l00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003okQ7^onhAk_o^4Nh2o`00
00Gol0o`0ol00009om0_d0;o00002ooU6^D00ol0003oa3_4ol@ka00=ol@ka003o`000?oR7N;ohQgR
00gohQgR00Co0000oki1__nn@Kko00003oo?<<l00ol0003oaSW6olHiaP09olHiaP03o`000?o1?/7o
`Ck100Wo`Ck11?l0000;olLha`03o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000onhAk_o^4Nh01?o^4Nh00ol0003ol0o`o`000002o`00
00cod2o@00Co0000ojaC[?l0003o00002OoU6^D00ol0003oa3_4ol@ka00=ol@ka003o`000?oR7N;o
hQgR00gohQgR00Go0000oki1__nn@Kko_T6no`00000=oll`c`03o`000?o6>LKoaSW600[oaSW600?o
0000ol4n`Oo1?/402Oo1?/400ol0003oacS7olLha`0<olLha`03o`000?o_4>ooka3_00[oka3_00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000onhAk_o^4Nh01_o^4Nh0
0ol0003od2o@om0_d00<om0_d003o`000?n/Djco[5>/00;o[5>/0_l00007onDJi@03o`000?o4>lCo
a3_400coa3_400?o0000on8Mh_oR7N803OoR7N800ol0003o_T6noki1_P03oki1_P03o`000?o?<<oo
cc3?00[occ3?00?o0000olHia_o6>LH02_o6>LH00ol0003o`Ck1ol4n`@09ol4n`@03o`000?o7><Oo
acS700coacS700?o0000onl@koo_4>l02oo_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003okQ7^onhAkP06onhAkP03o`000?o@;m3od2o@00_od2o@00?o0000ojaC
[?n/Dj`01On/Dj`00ol0003oiA[UonDJi@03onDJi@03o`000?o4>lCoa3_400goa3_400?o0000on8M
h_oR7N803OoR7N800ol0003o_T6noki1_P04oki1_P03o`000?o?<<oocc3?00Wocc3?00?o0000olHi
a_o6>LH02Oo6>LH00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o7><OoacS700coacS700?o0000onl@
koo_4>l02oo_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
kQ7^onhAkP07onhAkP03o`000?o@;m3od2o@00_od2o@00?o0000ojaC[?n/Dj`01_n/Dj`2o`0000?o
iA[U00?o0000ol@ka?o4>l@03Oo4>l@00ol0003ohQgRon8MhP0<on8MhP03o`000?nn@Kko_T6n00Ko
_T6n00?o0000oll`coo?<<l02?o?<<l00ol0003oaSW6olHiaP09olHiaP03o`000?o1?/7o`Ck100[o
`Ck100?o0000olLhaoo7><L03?o7><L00ol0003oka3_onl@k`0;onl@k`03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000onhAk_o^4Nh02?o^4Nh00ol0003od2o@om0_d00:om0_d003o`00
0?n/Djco[5>/00Wo[5>/0_l000000ooU6^Go0000ol@ka00<ol@ka0?o00003_oR7N800ol0003o_T6n
oki1_P07oki1_P03o`000?o?<<oocc3?00Oocc3?00?o0000olHia_o6>LH02Oo6>LH00ol0003o`Ck1
ol4n`@0;ol4n`@03o`000?o7><OoacS700coacS700?o0000onl@koo_4>l02_o_4>l00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000onhAk_o^4Nh02_o^4Nh00ol0003od2o@om0_
d009om0_d003o`000?n/Djco[5>/00_o[5>/00?o0000ol@ka?o4>l@02_o4>l@2o`0000?oVfBK00?o
0000on8Mh_oR7N802_oR7N800ol0003o_T6noki1_P09oki1_P03o`000?o?<<oocc3?00Kocc3?00?o
0000olHia_o6>LH02?o6>LH00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?o7><OoacS700coacS700?o
0000onl@koo_4>l02_o_4>l00ol0003oo@;mood2o@04ood2o@Co00000ool0o`00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000om0_d?o@;m002?o@;m00
0ol0003o[5>/ojaC[00<ojaC[003o`000?o4>lCoa3_400Soa3_40_l00006oi]TV`;o00002_oR7N80
0ol0003o_T6noki1_P0:oki1_P03o`000?o?<<oocc3?00Gocc3?00?o0000olHia_o6>LH02?o6>LH0
0ol0003o`Ck1ol4n`@0<ol4n`@03o`000?o7><OoacS700coacS700?o0000onl@koo_4>l02oo_4>l0
0ol0003oo@;mo`000003o`0000Soo0?l00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
onhAkP03o`000?o@;m3od2o@00Ood2o@00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003oa3_4ol@ka004
ol@ka0?o00002_nKI9/00ol0003ohQgRon8MhP07on8MhP03o`000?nn@Kko_T6n00_o_T6n00?o0000
oll`coo?<<l00oo?<<l00ol0003oaSW6olHiaP09olHiaP03o`000?o1?/7o`Ck100co`Ck100?o0000
olLhaoo7><L03?o7><L00ol0003oka3_onl@k`0;onl@k`;o00003Ool0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003okQ7^onhAkP0<onhAkP03o`000?o@;m3od2o@00Ood2o@00?o0000ojaC[?n/Dj`03on/Dj`01?l0
003oa3_4ol@ka?o4>l@2o`0000koVfBK0_l00006on8MhP03o`000?nn@Kko_T6n00go_T6n00?o0000
oll`coo?<<l00_o?<<l00ol0003oaSW6olHiaP08olHiaP03o`000?o1?/7o`Ck100co`Ck10ol0000=
olLha`03o`000?o_4>ooka3_00_oka3_00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ookQ7^00?o0000om0_d?o@;m001_o@;m000ol0003o[5>/ojaC[00@ojaC[0Co00004_nKI9/00ol0
003ohQgRon8MhP03on8MhP03o`000?nn@Kko_T6n00ko_T6n00Go0000oll`coo?<<oocc3?o`000005
olHiaPOo00003?o1?/401Ol0003oTVfBoi9]T_nBKI;o000000coacS700?o0000onl@koo_4>l02?o_
4>l3o`0000ooo0?l00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ookQ7^00?o0000om0_d?o@;m001_o@;m000ol0003o[5>/ojaC[00=
ojaC[0?o000000CoKi1_o`000?l0003o00004onKI9/2o`0000;ohQgR00?o0000oki1__nn@Kh04?nn
@Kh00ol0003occ3?o`000006o`0000Oo[5>/00?o0000ol4n`Oo1?/402?o1?/400ol0003oTVfBoi9]
TP03oi9]TP;o00002?o7><L3o`0000Koka3_1?l00002on/Dj`03o`000?ol0ocoo0?l00koo0?l00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003olPgbo`000?o;=</3o`0000gokQ7^00?o0000om0_d?o@;m001?o@;m000ol0003o[5>/ojaC
[00;ojaC[0?o00000om_T6l01Ol0003oKI9]o`000?m@[e3o000001CoVfBK00?o0000on8Mh_l00000
4onn@Kh00ol0003o[5>/ojaC[00=ojaC[003o`000?o1?/7o`Ck100Go`Ck10_l00008oi9]TP03o`00
0?o7><OoacS700Go00000oo4>l@00ol0003oka3_onl@k`03o`0000OojaC[00?o0000oo`3o?ol0o`0
3Ool0o`00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?ob3O;olPgbo`0000CobcC;0ol0000:onhAkP03o`000?o@;m3od2o@00?od2o@
00?o0000ojaC[?n/Dj`02On/Dj`3o`0000GoKi1_00Co0000offBKOm]TVgo00000_m@[e000ol0003o
VfBKoi]TV`0Boi]TV`03o`000?nn@Kko_T6n01;o_T6n00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003o
`Ck1ol4n`@03ol4n`@03o`000?nBKI;oTVfB00WoTVfB0_l00009ol@ka0;o00002_o[5>/00ol0003o
o0?loo`3o00=oo`3o003o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo8=l_ob3O;olPgbo`000007ol/db`;o00001oo^4Nh5o`0000;o
d2o@00?o0000ojaC[?n/Dj`01_n/Dj`3o`0000SoKi1_00Co0000offBKOm]TVgo00000om@[e000ol0
003oVfBKoi]TV`0Aoi]TV`03o`000?nn@Kko_T6n017o_T6n00?o0000ojaC[?n/Dj`04?n/Dj`01Ol0
003o`Ck1ol4n`Oo1?/7o000000coTVfB00?o0000ol@ka?o4>l@02?o4>l@00ol0003ojaC[on/Dj`0:
on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000ColPgb00?o0000ol/dboo;=</01oo;=</3o`00
0004onhAk_l0003o0000o`0000Go]4^d0_l00006ojaC[0?o00002_m_T6l01Ol0003oKI9]offBKOm]
TVgo000000CoD:m@00?o0000oi]TVonKI9/04?nKI9/00ol0003o_T6noki1_P0Aoki1_P03o`000?n/
Djco[5>/017o[5>/00?o0000ol4n`Ol000003OnBKI800ol0003oa3_4ol@ka008ol@ka003o`000?o[
5>_ojaC[00[ojaC[00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00ColPgb00?o0000
ol/dboo;=</02_o;=</00ol0003o]4^dokA;]008okA;]003o`000?n/Djco[5>/00?o00003Om_T6l0
1Ol0003oKI9]offBKOm]TVgo000000GoD:m@00?o0000oi]TVonKI9/03onKI9/00ol0003o_T6noki1
_P0Aoki1_P03o`000?n/Djco[5>/01;o[5>/00?o0000oi9]T_nBKI803?nBKI800ol0003oa3_4ol@k
a008ol@ka003o`000?o[5>_ojaC[00_ojaC[00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo8=l_ob3O801Oob3O80
0ol0003obcC;ol/db`0:ol/db`03o`000?ndBkCo]4^d00Wo]4^d0_l0000?ofn@K`03o`000?m]TVgo
KI9]00;oKI9]00?o0000oe2_D?m@[e001?m@[e000ol0003oVfBKoi]TV`0=oi]TV`?o00004Onn@Kh0
0ol0003o[5>/ojaC[00CojaC[003o`000?nBKI;oTVfB00_oTVfB00?o0000ol@ka?o4>l@02Oo4>l@0
0ol0003ojaC[on/Dj`0;on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?ob3O80
0ol0003obcC;ol/db`0:ol/db`03o`000?ndBkCo]4^d00Wo]4^d00?o0000ofn@Kom_T6l03Om_T6l0
0ol0003oKI9]offBK@03offBK@03o`000?m@[e3oD:m@00GoD:m@00?o0000oi]TVonKI9/02_nKI9/2
o`0000?oQWV600?o0000oki1__nn@Kh03_nn@Kh00ol0003o[5>/ojaC[00CojaC[003o`000?nBKI;o
TVfB00_oTVfB00?o0000ol@ka?o4>l@02Oo4>l@00ol0003ojaC[on/Dj`0;on/Dj`03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000oo8=l_ob3O801oob3O82o`0000_obcC;00?o0000okA;
]?ndBk@02ondBk@00ol0003oKi1_ofn@K`0<ofn@K`03o`000?m]TVgoKI9]00?oKI9]00?o0000oe2_
D?m@[e001_m@[e000ol0003oVfBKoi]TV`07oi]TV`;o00001_n6NHH2o`0000ko_T6n00?o0000ojaC
[?n/Dj`04on/Dj`00ol0003oTVfBoi9]TP0;oi9]TP03o`000?o4>lCoa3_400Woa3_400?o0000on/D
joo[5>/03?o[5>/00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009oo8=
lP03o`000?oO8=oo000000_obcC;00?o0000okA;]?ndBk@02ondBk@00ol0003oKi1_ofn@K`0;ofn@
K`03o`000?m]TVgoKI9]00CoKI9]00?o0000oe2_D?m@[e001om@[e000ol0003oVfBKoi]TV`05oi]T
V`03o`000?n6NHKoQWV600SoQWV600?o0000oki1__nn@Kh02_nn@Kh00ol0003o[5>/ojaC[00DojaC
[003o`000?nBKI;oTVfB00_oTVfB00?o0000ol@ka?o4>l@02Oo4>l@00ol0003ojaC[on/Dj`0<on/D
j`03o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009oo8=lP04o`000?oO8=oogb3Oo`00
00_obcC;00?o0000okA;]?ndBk@02ondBk@00ol0003oKi1_ofn@K`0;ofn@K`03o`000?m]TVgoKI9]
00CoKI9]00?o0000oe2_D?m@[e002?m@[e000ol0003oVfBKoi]TV`02oi]TV`;o00003?n6NHH2o`00
00[o_T6n00?o0000ojaC[?n/Dj`05?n/Dj`00ol0003oTVfBoi9]TP0;oi9]TP03o`000?o4>lCoa3_4
00Woa3_400?o0000on/Djoo[5>/03Oo[5>/00ol0003oo0?loo`3o006oo`3o0?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003olPgboo8=lP07oo8=lP03
o`000?oO8=oogb3O00;ogb3O00?o0000ol/dboo;=</02?o;=</00ol0003o]4^dokA;]00<okA;]003
o`000?m_T6ooKi1_00WoKi1_00?o0000offBKOm]TVd01Om]TVd00ol0003oD:m@oe2_D009oe2_D004
o`000?nKI9_o0000o`00013oQWV60_l00008oki1_P03o`000?n/Djco[5>/01Co[5>/0ol0000;oi9]
TP03o`000?o4>lCoa3_400Woa3_400?o0000on/Djoo[5>/03Oo[5>/01?l0003oo0?loo`3o?ol0o`5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003olPgboo8=lP06oo8=lP03o`000?oO8=oogb3O00?ogb3O00?o0000ol/d
boo;=</02?o;=</00ol0003o]4^dokA;]00;okA;]0;o00002_m_T6l00ol0003oKI9]offBK@06offB
K@03o`000?m@[e3oD:m@00[oD:m@00?o0000ohIiQ_n6NHH04_n6NHH00ol0003o_T6noki1_P04oki1
_P03o`000?n/Djco[5>/01Go[5>/00?o0000oi9]T_nBKI801Ol00005oi9]TP03o`000?o4>lCoa3_4
00[oa3_400?o0000on/Djoo[5>/03_o[5>/3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP04oo8=lP03
o`000?oO8=oogb3O00Cogb3O00?o0000ol/dboo;=</01oo;=</00ol0003o]4^dokA;]00;okA;]004
o`000?maSW7oLHiao`0000WoKi1_00?o0000offBKOm]TVd01_m]TVd00ol0003oD:m@oe2_D00:oe2_
D003o`000?n6NHKoQWV601?oQWV60_l00003oki1_PCo00005?n/Dj`00ol0003oTVfBoi9]TP06oi9]
TPCo000000?oTVfBo`000?o4>l@02oo4>l@00ol0003ojaC[on/Dj`0>on/Dj`03o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003olPgboo8=lP03oo8=lP03o`000?oO8=oogb3O00Gogb3O00?o0000ol/dboo;
=</01oo;=</00ol0003o]4^dokA;]009okA;]0;o00001?maSW400ol0003oKi1_ofn@K`05ofn@K`03
o`000?m]TVgoKI9]00OoKI9]00?o0000oe2_D?m@[e002_m@[e000ol0003oQWV6ohIiQP0EohIiQP03
o`000?nn@Kko000000CoUFZE0ol0000@ojaC[003o`000?nBKI;oTVfB00_oTVfB0_l0000<ol@ka003
o`000?o[5>_ojaC[00cojaC[0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O800_ob3O800ol0003ogb3O
omlPg`06omlPg`03o`000?o;=<_obcC;00OobcC;00?o0000okA;]?ndBk@02?ndBk@00ol0003oLHia
og6>L@05og6>L@03o`000?m_T6ooKi1_00CoKi1_00?o0000offBKOm]TVd01om]TVd00ol0003oD:m@
oe2_D00:oe2_D003o`000?n6NHKoQWV601KoQWV600?o0000oiEZUOnEJYD01_nEJYD3o`0000co[5>/
00?o0000oi9]T_nBKI803OnBKI800ol0003oa3_4ol@ka009ol@ka0Go00002Oo[5>/2o`000003onhA
k_l0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003oo8=l_l0003ogb3O00Wogb3O00?o0000ol/dboo;=</01_o;
=</00ol0003o]4^dokA;]007okA;]003o`000?maSW7oLHia00OoLHia00?o0000ofn@Kom_T6l00_m_
T6l00ol0003oKI9]offBK@08offBK@03o`000?m@[e3oD:m@00WoD:m@00?o0000ohIiQ_n6NHH05on6
NHH00ol0003oUFZEoiEZU@09oiEZU@?o00002On/Dj`00ol0003oTVfBoi9]TP0>oi9]TPKo00001?o4
>l@00ol0003oc3?<ol`cc003ol`cc0Go00000_o[5>/2o`0000CokQ7^00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?oW6>OoiaSWonLHiol000002ooO8=l00ol0003obcC;ol/db`06ol/db`03o`000?nd
BkCo]4^d00Go]4^d0_l0000;og6>L@04o`000?m_T6ooKi1_o`0000_oKI9]00?o0000oe2_D?m@[e00
2Om@[e000ol0003oQWV6ohIiQP0FohIiQP03o`000?nEJYGoUFZE00goUFZE0ol00005ojaC[003o`00
0?nBKI;oTVfB00ooTVfB00?o0000ojEJYOnUFZD00onUFZD4o`0000_oc3?<0_l00006onhAkP03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003oiaSWonLHi`02onLHi`ko00001_o;=</00ol0003o]4^dokA;
]005okA;]003o`000?maSW7oLHia00coLHia00?o0000ofn@Kol000002om]TVd00ol0003oD:m@oe2_
D007oe2_D0?o00006?n6NHH00ol0003oUFZEoiEZU@0@oiEZU@?o000000?o[5>/o`000?nBKI804?nB
KI800ol0003oYEZUojEJY@07ojEJY@03o`000?o<<lcoc3?<00[oc3?<00?o0000onhAk_o^4Nh01Oo^
4Nh00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005onLHi`03o`000?nl@kco_4>l00_o_4>l0_l00004
ol/db`03o`000?ndBkCo]4^d00?o]4^d0_l0000@og6>L@03o`000?m]TVgoKI9]00[oKI9]00?o0000
oe2_D?m@[e000om@[e04o`0000;o=/Tf00?o0000ohIiQ_n6NHH05On6NHH00ol0003oUFZEoiEZU@0D
oiEZU@03o`000?nBKI;oTVfB013oTVfB00?o0000ojEJYOnUFZD01onUFZD00ol0003oc3?<ol`cc00:
ol`cc003o`000?o^4NkokQ7^00GokQ7^00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oW6>OoiaSW
00GoiaSW00?o0000oka3_?nl@k`03Onl@k`6o`0000?o]4^d00?o0000og6>LOmaSW404?maSW400ol0
003oKI9]offBK@0:offBK@03o`000?m@[e3o000000?o00001olfbCH00ol0003oQWV6ohIiQP0DohIi
QP03o`000?nEJYGoUFZE01CoUFZE00?o0000oi9]T_nBKI803onBKI800ol0003oYEZUojEJY@08ojEJ
Y@03o`000?o<<lcoc3?<00[oc3?<00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onLHiooW6>L01_oW6>L00ol0003o_4>loka3_00=oka3_003o`000?nYEZWoZEJY00?o
ZEJY00?o0000okA;]?l000004omaSW44o`0000WoKI9]0_l0000<ocK9=P03o`000?n6NHKoQWV601?o
QWV600?o0000oiEZUOnEJYD05OnEJYD00ol0003oTVfBoi9]TP0>oi9]TP03o`000?nUFZGoYEZU00So
YEZU00?o0000ol`cc?o<<l`02Oo<<l`00ol0003okQ7^onhAkP07onhAkP03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?oW6>OoiaSW00SoiaSW00?o0000oka3_?nl@k`02onl@k`00ol0003oZEJYojUFZ@05ojUFZ@03o`00
0?maSW7oLHia01;oLHia00Co0000od>l@om3_4?o@ka31Ol00003offBK@03o`000?lfbCKo=/Tf00go
=/Tf0ol0000@ohIiQP;o00006?nEJYD00ol0003oTVfBoi9]TP0=oi9]TP03o`000?nUFZGoYEZU00Wo
YEZU00?o0000ol`cc?o<<l`02Oo<<l`00ol0003okQ7^onhAkP07onhAkP03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_oiaSW00?o0000oka3_?nl@k`02_nl@k`00ol0003oZEJYojUFZ@06ojUFZ@03o`00
0?maSW7oLHia017oLHia00?o0000od>l@om3_4<01om3_4<3o`00013o=/Tf00?o0000obWF:OlYeRT0
1Ol00009ohIiQP;o000000?o@ka3o`000?nEJYD05onEJYD00ol0003oTVfBoi9]TP0=oi9]TP03o`00
0?nUFZGoYEZU00WoYEZU00?o0000ol`cc?o<<l`02?o<<l`2o`0000[okQ7^00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?oc3??ol`cc00;ol`cc00?o0000onLHiooW6>L02OoW6>L00ol0003o_4>loka3
_00:oka3_003o`000?nYEZWoZEJY00OoZEJY00?o0000og6>LOmaSW403omaSW400ol0003o@ka3od>l
@`0:od>l@`03o`000?lfbCKo=/Tf00go=/Tf00?o0000obWF:OlYeRT01_lYeRT4o`0000CoQWV600?o
0000od>l@om3_4<00_m3_4<00ol0003oUFZEoiEZU@0FoiEZU@03o`000?nBKI;oTVfB00_oTVfB00?o
0000ojEJYOnUFZD02onUFZD00ol0003oc3?<ol`cc006ol`cc003o`000?oM8]go000000[okQ7^00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000onLHiooW6>L02?oW6>L=
o`0000[oZEJY00?o0000og6>LOmaSW403omaSW400ol0003o@ka3od>l@`0;od>l@`03o`000?lfbCKo
=/Tf00co=/Tf00?o0000obWF:OlYeRT02_lYeRT4o`0000Go@ka300?o0000oiEZUOnEJYD05_nEJYD0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?nUFZGoYEZU00coYEZU00?o0000ol`cc?o<<l`01?o<<l`2
o`0000?ogB;M00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo<<
looc3?<00ooc3?<00ol0003oiaSWonLHi`07onLHi`03o`000?njAK[o^TFj00Wo^TFj00?o0000ojUF
ZOnYEZT02OnYEZT00ol0003oLHiaog6>L@0=og6>L@03o`000?m3_4?o@ka300co@ka300?o0000ocK9
=_lfbCH03?lfbCH00ol0003o:MHYobWF:@0;obWF:@03o`000?lCk1?o000000Ko@ka300?o0000oiEZ
UOnEJYD05_nEJYD00ol0003oTVfBoi9]TP09oi9]TP03o`000?nUFZGoYEZU00coYEZU00?o0000ol`c
c?o<<l`00oo<<l`00ol0003ogB;MomdRg@03omdRg@03o`000?o^4NkokQ7^00SokQ7^00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?oc3??ol`cc00Col`cc00?o0000onLHiooW6>L01_oW6>L00ol0003o
^TFjokY5^P08okY5^P03o`000?nYEZWoZEJY00_oZEJY00?o0000og6>LOmaSW402?maSW44o`0000oo
@ka300?o0000ocK9=_lfbCH02olfbCH00ol0003o:MHYobWF:@0;obWF:@04o`000?lCk1?o4n`Co`00
00Oo@ka300?o0000oiEZUOnEJYD05OnEJYD00ol0003oTVfBoi9]TP08oi9]TP03o`000?nUFZGoYEZU
00goYEZU00?o0000ol`cc?o<<l`00_o<<l`00ol0003ogB;MomdRg@05omdRg@03o`000?o^4NkokQ7^
00OokQ7^00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?oc3??ol`cc00Gol`cc00?o0000onLHiooW
6>L01OoW6>L00ol0003o^TFjokY5^P08okY5^P03o`000?nYEZWoZEJY00_oZEJY00?o0000og6>LOma
SW400omaSW45o`0000?oA;]400?o0000od>l@om3_4<03_m3_4<00ol0003o=/TfocK9=P0:ocK9=P03
o`000?lYeRWo:MHY00[o:MHY00Go0000oa?/4olCk1?o4n`Co`000007od>l@`03o`000?nEJYGoUFZE
01GoUFZE00?o0000oi9]T_nBKI802?nBKI800ol0003oYEZUojEJY@0=ojEJY@03o`000?o<<lcoc3?<
00;o00002?oM8]d00ol0003okQ7^onhAkP08onhAkPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oW6>OoiaSW00Go
iaSW00?o0000okY5^_njAKX02?njAKX00ol0003oZEJYojUFZ@0<ojUFZ@Go00002Om4^d@00ol0003o
@ka3od>l@`0<od>l@`;o00003?lfbCH00ol0003o:MHYobWF:@0:obWF:@05o`000?lCk1?o4n`Coa?/
4ol000002?m3_4<00ol0003oUFZEoiEZU@0DoiEZU@?o00001onBKI800ol0003oYEZUojEJY@0>ojEJ
Y@03o`000?o<<lco000000_ogB;M00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003oiaSWonLHi`04onLHi`03o`000?njAK[o^TFj00Oo
^TFj00?o0000ojUFZOnYEZT03?nYEZT01?l0003oLHiaog6>LOl0000;odBkA003o`000?m3_4?o@ka3
00_o@ka300Co0000o`o`3ol?l0oo00002_lfbCH00ol0003o:MHYobWF:@0:obWF:@03o`000?lCk1?o
4n`C00;o4n`C00?o0000od>l@om3_4<01_m3_4<00ol0003oUFZEoiEZU@0AoiEZU@?o00000omRWF80
0ol0003oTVfBoi9]TP04oi9]TP03o`000?nUFZGoYEZU00goYEZU1?l0000;omdRg@03o`000?o^4Nko
kQ7^00GokQ7^00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oc3??ol`cc00Kol`cc00Co0000onLH
iooW6>OoiaSW1?l00008okY5^P03o`000?nYEZWoZEJY00_oZEJY00?o0000og6>LOmaSW400_maSW40
0ol0003oA;]4odBkA008odBkA003o`000?m3_4?o@ka300[o@ka300?o0000o`o`3ol?l0l00_l?l0l0
0ol0003o=/TfocK9=P03ocK9=PGo00002olYeRT00ol0003o4n`Coa?/4`03oa?/4`03o`000?m3_4?o
@ka300Oo@ka300?o0000oiEZUOnEJYD03_nEJYD2o`0000OoHYeR00?o0000oi9]T_nBKI800_nBKI80
0ol0003oYEZUojEJY@0=ojEJY@03o`000?o9=/WobCK900;obCK900?o0000omdRgOoM8]d02OoM8]d0
0ol0003okQ7^onhAkP03onhAkP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`07oo<<
l`?o00001?oD:m@00ol0003o^TFjokY5^P05okY5^P03o`000?nYEZWoZEJY00[oZEJY00?o0000og6>
LOmaSW400omaSW400ol0003oA;]4odBkA009odBkA003o`000?m3_4?o@ka300So@ka300?o0000o`o`
3ol?l0l01?l?l0l5o`0000Co0?l000?o0000obWF:OlYeRT02OlYeRT00ol0003o4n`Coa?/4`03oa?/
4`03o`000?m3_4?o@ka300So@ka300?o0000oiEZUOnEJYD02_nEJYD3o`0000[oHYeR00Go0000oi9]
T_nBKI;oTVfBo`00000>ojEJY@03o`000?o9=/WobCK900CobCK90_l00009omdRg@03o`000?o^4Nko
kQ7^00;okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000om@[
e?oD:m@01OoD:m@00ol0003o^TFjokY5^P03okY5^P03o`000?nYEZWoZEJY00[oZEJY00?o0000og6>
LOmaSW401?maSW400ol0003oA;]4odBkA009odBkA003o`000?m3_4?o@ka300Oo@ka300?o0000o`o`
3ol?l0l01Ol?l0l00ol0003o0?l0o`3o0007o`3o0003o`000?lYeRWo:MHY00Oo:MHY00?o0000oa?/
4olCk1<01?lCk1<00ol0003o@ka3od>l@`08od>l@`03o`000?nEJYGoUFZE00SoUFZE0_l0000>of:M
HPCo00003?nUFZD2o`0000WobCK900?o0000omdRgOoM8]d01ooM8]d01?l0003okQ7^onhAk_l0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003oe2_Dom@[e007om@[e0;o00000onjAKX00ol0
003oZEJYojUFZ@09ojUFZ@03o`000?maSW7oLHia00KoLHia00?o0000odBkA?m4^d@02Om4^d@00ol0
003o@ka3od>l@`05od>l@`03o`000?l?l0oo3o0?00Ko3o0?00?o0000o`3o0?l0o`002?l0o`000ol0
003o:MHYobWF:@06obWF:@03o`000?lCk1?o4n`C00Co4n`C00?o0000od>l@om3_4<02Om3_4<4o`00
00?oUFZE0ol0000@of:MHP05o`000?nm@[go_D:moke2_Ol000002_nUFZD00ol0003obCK9olTfb@0:
olTfb@Ko00000ooM8]d00ol0003okQ7^o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo<<looc3?<01?oc3?<00ol0
003oe2_Dom@[e00:om@[e004o`000?njAK[o^TFjo`0000[oZEJY00?o0000og6>LOmaSW401omaSW40
0ol0003oA;]4odBkA009odBkA003o`000?m3_4?o@ka300Co@ka300?o0000o`o`3ol?l0l01ol?l0l0
0ol0003o0?l0o`3o0008o`3o00;o00001_lYeRT00ol0003o4n`Coa?/4`05oa?/4`03o`000?m3_4?o
@ka300Wo@ka300Co0000ocC;=?ldbcCo=</d0ol0000Bof:MHP03o`000?nm@[go_D:m00?o_D:m0_l0
0006ojEJY@;o00003Oo9=/T00ol0003olPgboo8=lP03oo8=lPGo00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo<<looc3?<00ooc3?<0
0ol0003oe2_Dom@[e00<om@[e0;o00002_nYEZT00ol0003oLHiaog6>L@08og6>L@03o`000?m4^dCo
A;]400[oA;]400?o0000od>l@om3_4<00_m3_4<00ol0003o3o0?o`o`3`08o`o`3`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`[e2P03o`000?lYeRWo:MHY00;o:MHY00?o0000oa?/4olCk1<01_lCk1<0
0ol0003o@ka3od>l@`08od>l@`03o`000?ldbcCo=</d00Co=</d00?o0000of:MH_mRWF803omRWF80
0ol0003o_D:moke2_@06oke2_@;o00000onUFZD00ol0003obCK9olTfb@0=olTfb@03o`000?ob3O;o
lPgb00OolPgb0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003ol`ccoo<<l`02oo<<l`03o`000?oD:mCoe2_D
00koe2_D00?o0000ojUFZOnYEZT01onYEZT00ol0003oLHiaog6>L@0:og6>L@03o`000?m4^dCoA;]4
00WoA;]400Go0000od>l@om3_4?o@ka3o`00000;o`o`3`03o`000?l0o`3o0?l000Co0?l00_l00005
o`[e2P05o`000?lYeRWo:MHYobWF:Ol000002?lCk1<00ol0003o@ka3od>l@`08od>l@`03o`000?ld
bcCo=</d00Go=</d00?o0000of:MH_mRWF803_mRWF800ol0003o_D:moke2_@08oke2_@03o`000?nU
FZGo000000oobCK900?o0000oo8=l_ob3O802?ob3O801?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?oc3??ol`cco`00017oe2_D00?o0000ojUFZOnYEZT01_nYEZT00ol0003oLHia
og6>L@0;og6>L@03o`000?m4^dCoA;]400WoA;]400Co0000od>l@om3_4?o00003?l?l0l00ol0003o
0?l0o`3o0002o`3o00;o00002?l:m@X00ol0003o:MHYo`000009oa?/4`03o`000?m3_4?o@ka300So
@ka300?o0000ocC;=?ldbc@01Oldbc@00ol0003oHYeRof:MHP0=of:MHP03o`000?nm@[go_D:m00[o
_D:m00?o0000olTfbOo9=/T03_o9=/T00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000Bom@[e003o`00
0?nYEZWoZEJY00CoZEJY00?o0000og6>LOmaSW403?maSW400ol0003oA;]4odBkA00:odBkA0?o0000
3?l?l0l00ol0003o0?l0o`3o0002o`0000_o2_D:00?o0000oa?/4olCk1<02?lCk1<00ol0003o@ka3
od>l@`07od>l@`03o`000?ldbcCo=</d00Oo=</d00?o0000of:MH_mRWF803?mRWF800ol0003o_D:m
oke2_@0;oke2_@;o00003_o9=/T00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo8=l_ob3O800oob3O800ol0003oe2_Dom@[e00?om@[e0?o00000onY
EZT00ol0003oLHiaog6>L@0>og6>L@03o`000?m4^dCoA;]400SoA;]400Co0000oaOX5olGj1Oo5nPG
0_l0000:o`o`3`?o00003Ol:m@X00ol0003o4n`Coa?/4`08oa?/4`03o`000?m3_4?o@ka300Oo@ka3
00?o0000ocC;=?ldbc@01oldbc@00ol0003oHYeRof:MHP0;of:MHP03o`000?nm@[go_D:m00co_D:m
00?o0000on@Ki?l000000_l0000:olTfb@03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP04oo8=lP03o`000?oD:mCoe2_D00coe2_D0_l0
0003oke2_@03o`000?nYEZWo0000017oLHia00?o0000odBkA?m4^d@01om4^d@00ol0003o5nPGoaOX
5`04oaOX5`;o00002?l?l0l00ol0003o2_D:o`[e2P0>o`[e2P;o00002?lCk1<00ol0003o@ka3od>l
@`06od>l@`03o`000?ldbcCo=</d00Wo=</d00?o0000of:MH_mRWF802OmRWF800ol0003o_D:moke2
_@0=oke2_@03o`000?oT6nCoi1_T00;oi1_T0ol00007olTfb@03o`000?ob3O;olPgb00OolPgb00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP05oo8=lP03o`000?oD:mCo
e2_D00Woe2_D0_l00006oke2_@03o`000?maSW7oLHia013oLHia00?o0000odBkA?m4^d@01_m4^d@0
0ol0003o5nPGoaOX5`07oaOX5`03o`000?l?l0oo3o0?00Co3o0?0ol0000>o`[e2P03o`000?l0o`3o
0?l000?o00001OlCk1<00ol0003o@ka3od>l@`06od>l@`03o`000?ldbcCo=</d00[o=</d00?o0000
of:MH_mRWF802?mRWF800ol0003o_D:moke2_@0=oke2_@03o`000?oT6nCoi1_T00Goi1_T0ol00004
olTfb@03o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003olPgboo8=lP06oo8=lP03o`000?oD:mCoe2_D00Goe2_D0ol00008oke2_@03o`000?maSW7oLHia
017oLHia00Co0000odBkA?m4^dCoA;]41?l0000;oaOX5`;o000000Co3o0?o`000?l0003o00000olO
gal2o`0000_o2_D:00?o0000o`3o0?l0o`001?l0o`02o`0000?o4n`C00?o0000od>l@om3_4<01_m3
_4<00ol0003o=</docC;=00:ocC;=003o`000?mRWF;oHYeR00OoHYeR00?o0000oke2_Onm@[d03_nm
@[d00ol0003oi1_Ton@Ki008on@Ki0Co00002_ob3O800ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003olPgboo8=lP07oo8=lP03o`000?oD:mCoe2_D00;oe2_D0_l0000<oke2_@03o`000?maSW7o
LHia013oLHia1?l00003ocK9=P03o`000?lGj1Oo5nPG00_o5nPG00?o0000oaoO7olOgal01_lOgal0
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l0o`3o0?l000Oo0?l03?l0000>ocC;=003o`000?mRWF;o
HYeR00KoHYeR00?o0000oke2_Onm@[d03_nm@[d00ol0003oi1_Ton@Ki00;on@Ki003o`000?ob3O;o
lPgb00OolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00WolPgb00Co0000om@[
e?l0003o00003_nm@[d00ol0003oLHiaog6>L@0?og6>L@03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000
oaOX5olGj1L02_lGj1L00ol0003o7mlOoaoO7`07oaoO7`;o00001_l:m@X00ol0003o0?l0o`3o0008
o`3o0003o`000?m9]TWoBKI900SoBKI900?o0000ocC;=?ldbc@03?ldbc@00ol0003oHYeRof:MHP05
of:MHP03o`000?nm@[go_D:m00oo_D:m0_l0000=on@Ki003o`000?ob3O;olPgb00KolPgb00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00[olPgb00?o0000oke2_Onm@[d03_nm@[d00ol0
003oLHiaog6>L@0>og6>L@03o`000?lfbCKo=/Tf00Oo=/Tf00?o0000oaOX5olGj1L02_lGj1L00ol0
003o7mlOoaoO7`09oaoO7`;o00000ol:m@X00ol0003o0?l0o`3o0009o`3o0003o`000?m9]TWoBKI9
00WoBKI900?o0000ocC;=?ldbc@02_ldbc@4o`0000CoHYeR00?o0000oke2_Onm@[d04?nm@[d01?l0
003ohAkQo`000?l0000<on@Ki003o`000?ob3O;olPgb00GolPgb00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?ob3O;olPgb00[olPgb00?o0000oke2_Onm@[d03onm@[d@o`0000[o=/Tf00?o0000oaOX
5olGj1L02OlGj1L00ol0003o0?l0o`00000<oaoO7`05o`000?l:m@[o0000o`3o0?l000002_l0o`00
0ol0003oBKI9odVfB@09odVfB@03o`000?ldbcCo=</d00Oo=</d0ol00004ofNHI`?o000000?oHYeR
o`000?nm@[d04Onm@[d01?l0003ohAkQon4NhOoQ7^42o`0000_oi1_T00?o0000oo8=l_ob3O800oob
3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O802_ob3O800ol0003o_D:moke2_@0?
oke2_@03o`000?meRWGoMHYe00coMHYe00?o0000ocK9=_lfbCH02OlfbCH00ol0003o5nPGoaOX5`07
oaOX5`04o`000?l0o`3o0?l0o`0000go7mlO00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m9]TWoBKI900[oBKI900?o0000ocC;=?ldbc@00oldbc@3o`0000[oIiQW00?o0000oke2_Onm@[d0
4?nm@[d00ol0003ohAkQon4Nh@04on4Nh@;o00002_oT6n@00ol0003olPgboo8=lP04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000colPgb00?o0000oke2_Onm@[d03onm@[d00ol0003oMHYeogF:M@0<ogF:M@03o`000?lf
bCKo=/Tf00Wo=/Tf00?o0000oaOX5olGj1L01_lGj1L00ol0003o0?l0o`3o0002o`3o0003o`000?lO
gaoo7mlO00[o7mlO00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m9
]TWoBKI900[oBKI900?o0000ocC;=?ldbc@00ol0000=ofNHI`03o`000?nm@[go_D:m013o_D:m00?o
0000on4NhOoQ7^401_oQ7^42o`0000Woi1_T0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo8=l_ob3O802_ob3O800ol0003o_D:moke2_@0=oke2_@?o00003omeRWD0
0ol0003o=/TfocK9=P08ocK9=P03o`000?lGj1Oo5nPG00Go5nPG00?o0000o`3o0?l0o`000ol0o`00
0ol0003o7mlOoaoO7`0:oaoO7`03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003oBKI9odVfB@0;odVfB@;o00004OmWV6L00ol0003o_D:moke2_@0?oke2_@03o`000?oQ7^7o
hAkQ00SohAkQ0_l00007on@Ki003o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo8=l_ob3O802?ob3O800ol0003o_D:moke2_@09oke2_@Go00000_n;M8/00ol0
003oMHYeogF:M@0=ogF:M@03o`000?lfbCKo=/Tf00Wo=/Tf00?o0000oaOX5olGj1L01?lGj1L00ol0
003o0?l0o`3o0004o`3o0003o`000?lOgaoo7mlO00So7mlO00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m9]TWoBKI900_oBKI900?o0000ofNHIomWV6L04?mWV6L00ol0
003o_D:moke2_@0?oke2_@03o`000?oQ7^7ohAkQ00[ohAkQ0_l00004on@Ki003o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003olPgboo8=lP07oo8=lP03o`000?nm@[go_D:m00Co_D:m1Ol00007oh]dR`03
o`000?meRWGoMHYe00goMHYe00?o0000ocK9=_lfbCH02OlfbCH00ol0003o5nPGoaOX5`03oaOX5`03
o`000?l0o`3o0?l000Go0?l000?o0000oaoO7olOgal02?lOgal00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000odVfBOm9]TT02om9]TT00ol0003oIiQWofNHI`0@ofNHI`03
o`000?nm@[go_D:m00oo_D:m00?o0000on4NhOoQ7^403?oQ7^42o`000003on@Ki?l0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00OolPgb00?o0000oke2_Ol00000
1?l0000<oh]dR`03o`000?meRWGoMHYe00koMHYe00?o0000ocK9=_lfbCH02?lfbCH00ol0003o5nPG
oaOX5`02oaOX5`03o`000?l0o`3o0?l000Oo0?l000?o0000oaoO7olOgal01olOgal00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000odVfBOm9]TT02om9]TT00ol0003oIiQW
ofNHI`0AofNHI`03o`000?nm@[go_D:m00go_D:m00?o0000on4NhOoQ7^403ooQ7^400ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo8=l_ob3O801Oob3O83o`00017oRgB;00?o0000ogF:MOmeRWD03_me
RWD00ol0003o=/TfocK9=P09ocK9=P04o`000?lGj1Oo5nPGo`0000[o0?l000?o0000oaoO7olOgal0
1olOgal00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om9]TT00ol0003o
IiQWofNHI`0AofNHI`?o00003Onm@[d00ol0003ohAkQon4Nh@0?on4Nh@03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_ob3O82o`0000;oebSG00?o0000oh]dRon;M8/03on;M8/00ol0003o
MHYeogF:M@0>ogF:M@03o`000?lfbCKo=/Tf00So=/Tf1Ol0000;o`3o0003o`000?lOgaoo7mlO00Ko
7mlO00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=odVfB@03o`000?mWV6OoIiQW
017oIiQW00?o0000oejQG_mNXEh00ol0000:oke2_@Co00003OoQ7^400ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo<<looc3??ol`cc0_l00005omLXe`03o`000?n;M8_oRgB;00koRgB;00?o0000ogF:
MOmeRWD03_meRWD00ol0003o=/TfocK9=P07ocK9=P03o`000?lXebSo:=LX00?o:=LX00?o0000o`3o
0?l0o`002?l0o`000ol0003o7mlOoaoO7`05oaoO7`03o`000?l0o`3o0?l000[o0?l01Ol0000<odVf
B@03o`000?mWV6OoIiQW013oIiQW00?o0000oejQG_mNXEh01?mNXEh3o`0000Ko_D:m00?o0000omdR
gOoM8]d00_oM8]d5o`0000SohAkQ00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00?o
l`cc00?o0000omLXeooG:=L01?oG:=L00ol0003oRgB;oh]dR`0=oh]dR`03o`000?meRWGoMHYe00oo
MHYe00?o0000ocK9=_lfbCH01?lfbCH2o`0000Oo:=LX00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
1_T600?o0000odVfBOm9]TT02?m9]TT3o`00013oIiQW00?o0000oejQG_mNXEh02?mNXEh3o`0000;o
_D:m00?o0000omdRgOoM8]d02?oM8]d5o`0000?ohAkQ00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?oc3??ol`cc00Col`cc00?o0000omLXeooG:=L01OoG:=L00ol0003oRgB;oh]dR`0;oh]dR`Co0000
3omeRWD00ol0003o=/TfocK9=P03ocK9=P03o`000?lXebSo:=LX00So:=LX00?o0000o`3o0?l0o`00
1?l0o`02o`0000So9]TV00?o0000oaC[5?lDja@02?lDja@00ol0003o1_T6o`Ki1P05o`Ki1P;o0000
1_m9]TT2o`0000?o?/4n00?o0000ofNHIomWV6L03?mWV6L00ol0003oGZ5NoejQGP0<oejQGP;o0000
4?oM8]d3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oG:=OoebSG00KoebSG00?o
0000oh]dRon;M8/02On;M8/00ol0003oUVVFo`000002oeVVF@?o00003?meRWD01?l0003o=/TfocK9
=_lfbCH2o`0000co:=LX00?o0000o`3o0?l0o`000_l0o`000ol0003o9]TVobKI9P08obKI9P03o`00
0?lDjaCo5>/D00So5>/D00?o0000o`Ki1_l6n@H01ol6n@H00ol0003oBKI9odVfB@02odVfB@03o`00
0?ln`Cko?/4n00Co?/4n0_l0000;ofNHI`03o`000?mNXEkoGZ5N00coGZ5N00?o0000oj9MX_l00000
4_oM8]d00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003ol`ccoo<<l`06oo<<l`03o`000?oG:=OoebSG00OoebSG00?o
0000oh]dRon;M8/01_n;M8/2o`0000;oUVVF00?o0000oeVVFOmIYUT00omIYUT3o`0000[oMHYe00?o
0000ocK9=_l000003olXebP01?l0003o0?l0o`000?l0000;obKI9P03o`000?lDjaCo5>/D00So5>/D
00?o0000o`Ki1_l6n@H02?l6n@H01?l0003oBKI9o`000?l00009ock1?P03o`000?mWV6OoIiQW00Oo
IiQW00?o0000oejQG_mNXEh03?mNXEh01?l0003oXUfRoj9MX_l0000ComdRg@03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo<<looc3?<01ooc3?<00ol0003oebSGomLXe`08omLXe`03o`000?n;M8_oRgB;00Co
RgB;00?o0000oiIYU_nFJIH00onFJIH00ol0003oFJIIoeVVF@05oeVVF@?o00001_meRWD4o`00013o
:=LX00?o0000obKI9_lVfBH03?lVfBH00ol0003o5>/DoaC[5007oaC[5003o`000?l6n@Ko1_T600Wo
1_T600?o0000ock1?_ln`Ch02_ln`Ch2o`0000KoIiQW00?o0000oejQG_mNXEh03?mNXEh00ol0003o
XUfRoj9MXP02oj9MXP03o`000?oM8]gogB;M00oogB;M00?o0000oo4>lOl000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003ol`ccoo<<l`08oo<<l`03o`000?oG:=OoebSG00WoebSG00Co0000oh]dRon;M8_o
RgB;0_l00006oiIYUP03o`000?mIYUWoFJII00SoFJII0ol000000omeRWGo0000o`000004ocg2?@03
o`000?lXebSo:=LX00go:=LX00?o0000obKI9_lVfBH03?lVfBH00ol0003o5>/DoaC[5007oaC[5003
o`000?l6n@Ko1_T600Wo1_T600?o0000ock1?_ln`Ch03?ln`Ch00ol0003oIiQWofNHI`03o`0000ko
GZ5N00?o0000oj9MX_nRGJ800onRGJ800ol0003ogB;MomdRg@0>omdRg@05o`000?oa3_7ol@kaoo4>
lOl000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`09oo<<l`03o`000?oG:=OoebSG00[o
ebSG00?o0000oh]dRol000002?nFJIH00ol0003oFJIIoeVVF@0;oeVVF@03o`000?lm`Sgo?L8m00Go
?L8m00?o0000obSG:?lXebP03?lXebP00ol0003o9]TVobKI9P0<obKI9P03o`000?lDjaCo5>/D00Oo
5>/D00?o0000o`Ki1_l6n@H02?l6n@H2o`0000oo?/4n0_l00002ofJIIP03o`000?mNXEkoGZ5N00_o
GZ5N00?o0000oj9MX_nRGJ801?nRGJ800ol0003ogB;MomdRg@0=omdRg@03o`000?oa3_7ol@ka00?o
l@ka00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo<<l`03o`000?oG:=OoebSG00_oebSG00?o0000oiIYU_nFJIH0
1onFJIH00ol0003oFJIIoeVVF@0;oeVVF@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000obSG:?lXebP0
2olXebP2o`0000go9]TV00?o0000oaC[5?lDja@01olDja@00ol0003o1_T6o`Ki1P07o`Ki1P04o`00
0?lBkA;o4^dBo`0000ko?/4n00?o0000ofJII_mVVFH00_mVVFH00ol0003oGZ5NoejQGP09oejQGP03
o`000?nRGJ;oXUfR00KoXUfR00?o0000omdRgOoM8]d02ooM8]d00ol0003ol@kaoo4>l@05oo4>l@04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Sol`cc00?o0000omLXeooG:=L02_oG:=L2o`0000Wo
UVVF00?o0000oeVVFOmIYUT02omIYUT00ol0003o?L8mocg2?@07ocg2?@03o`000?lXebSo:=LX00Wo
:=LX00Co0000o`3o0?l0o`3o00003?lVfBH00ol0003o5>/DoaC[5007oaC[5003o`000?l6n@Ko1_T6
00Ko1_T600Go0000oa;]4_lBkA;o4^dBo`00000>ock1?P03o`000?mVVFKoIYUV00?oIYUV00?o0000
oejQG_mNXEh01omNXEh00ol0003oXUfRoj9MXP07oj9MXP03o`000?oM8]gogB;M00[ogB;M00?o0000
oo4>lOoa3_401ooa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo<<l`03o`000?oG:=OoebSG
00WoebSG00Co0000olTfbOo9=/Wo00002OnFJIH00ol0003oFJIIoeVVF@09oeVVF@03o`000?lm`Sgo
?L8m00Wo?L8m00?o0000obSG:?lXebP01olXebP00ol0003o0?l0o`3o0002o`3o0003o`000?lVfBKo
9]TV00Wo9]TV00?o0000oaC[5?lDja@01olDja@00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?lBkA;o
4^dB00?o4^dB00?o0000ock1?_ln`Ch02_ln`Ch00ol0003oIYUVofJIIP05ofJIIP03o`000?mNXEko
GZ5N00GoGZ5N00?o0000oj9MX_nRGJ802?nRGJ800ol0003ogB;MomdRg@09omdRg@03o`000?oa3_7o
l@ka00Sol@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oc3?<3o`0000WoebSG00?o0000olTf
bOo9=/T00_o9=/T00ol0003oUVVFoiIYUP06oiIYUP03o`000?mIYUWoFJII00WoFJII00?o0000ocg2
?Olm`Sd02_lm`Sd00ol0003o:=LXobSG:005obSG:003o`000?l0o`3o0?l000Co0?l000?o0000obKI
9_lVfBH02?lVfBH00ol0003o5>/DoaC[5007oaC[5003o`000?l6n@Ko1_T600Co1_T600?o0000oa;]
4_lBkA801?lBkA800ol0003o?/4nock1?P0:ock1?P03o`000?mVVFKoIYUV00KoIYUV00?o0000oejQ
G_mNXEh00omNXEh00ol0003oXUfRoj9MXP09oj9MXP03o`000?oM8]gogB;M00SogB;M00?o0000oo4>
lOoa3_402Ooa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003on`Ck0?o00001OoG:=L00ol0003o
bCK9olTfb@03olTfb@03o`000?nFJIKoUVVF00KoUVVF00?o0000oeVVFOmIYUT02OmIYUT00ol0003o
?L8mocg2?@0;ocg2?@03o`000?lXebSo:=LX00?o:=LX00?o0000o`3o0?l0o`001_l0o`000ol0003o
9]TVobKI9P08obKI9P03o`000?lDjaCo5>/D00Ko5>/D00?o0000o`Ki1_l6n@H00_l6n@H2o`0000So
4^dB00?o0000ock1?_ln`Ch02Oln`Ch00ol0003oIYUVofJIIP07ofJIIP05o`000?mNXEkoGZ5NoejQ
G_l000003OnRGJ800ol0003ogB;MomdRg@06omdRg@03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o/4ncok1?/00Gok1?/0ol000000ooG:=Oo0000olTfb@06olTfb@03
o`000?nFJIKoUVVF00GoUVVF00?o0000oeVVFOmIYUT02OmIYUT00ol0003o?L8mocg2?@0<ocg2?@05
o`000?lXebSo:=LXobSG:?l000002_l0o`000ol0003o9]TVobKI9P07obKI9P03o`000?lDjaCo5>/D
00Ko5>/D00?o0000o`Ki1_l000000_l000000om1_T7o0000oa;]4P07oa;]4P03o`000?ln`Cko?/4n
00So?/4n00?o0000ofJII_mVVFH02OmVVFH00ol0003oGZ5No`00000=oj9MXPCo00001OoM8]d00ol0
003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ok1?/on`Ck008on`Ck003
o`000?o9=/WobCK900OobCK900?o0000oiIYU_nFJIH01?nFJIH00ol0003oFJIIoeVVF@09oeVVF@03
o`000?lm`Sgo?L8m00go?L8m00?o0000obSG:?l000003?l0o`0:o`0000Oo5>/D0ol00005od6n@@03
o`000?lBkA;o4^dB00Ko4^dB00?o0000ock1?_ln`Ch01oln`Ch00ol0003oIYUVofJIIP0:ofJIIP03
o`000?nRGJ;oXUfR00_oXUfR00?o0000omTVfOoI9]T00_oI9]T3o`000003omdRgOl0003ol@ka00_o
l@ka0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000on`Ck?o/4n`02Oo/4n`00ol0003obCK9olTfb@07olTfb@03o`00
0?nFJIKoUVVF00GoUVVF00?o0000oeVVFOmIYUT01omIYUT00ol0003o?L8mocg2?@0?ocg2?@;o0000
2ol0o`000ol0003o=</docC;=007ocC;=003o`000?lDjaCo5>/D00;o5>/D0ol00008od6n@@03o`00
0?lBkA;o4^dB00Ko4^dB00?o0000ock1?_ln`Ch01oln`Ch00ol0003oIYUVofJIIP0:ofJIIP03o`00
0?nRGJ;oXUfR00[oXUfR00?o0000omTVfOoI9]T01_oI9]T00ol0003ol@kaoo4>l@08oo4>l@?o0000
0_od2o@00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000on`Ck?o/4n`02Oo/4n`00ol0003obCK9olTf
b@08olTfb@03o`000?nFJIKoUVVF00CoUVVF00?o0000oeVVFOmIYUT01omIYUT00ol0003o?L8mocg2
?@0>ocg2?@04o`000?l=lPgo3O8=o`0000Wo0?l000?o0000ocC;=?ldbc@02Oldbc@01?l0003o5>/D
o`000?l0000<od6n@@03o`000?lBkA;o4^dB00Ko4^dB00?o0000ock1?_ln`Ch01_ln`Ch00ol0003o
IYUVofJIIP0;ofJIIP03o`000?nRGJ;oXUfR00OoXUfR0_l00009omTVf@03o`000?oa3_7ol@ka00Co
l@ka1?l00006oo@;m003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ok1?/on`Ck009on`Ck003o`00
0?o9=/WobCK900SobCK900?o0000oiIYU_nFJIH00onFJIH>o`0000go?L8m00?o0000o`gb3Ol=lPd0
0_l=lPd00ol0003o0?l0o`3o0005o`3o0003o`000?ldbcCo=</d00_o=</d00?o0000od6n@Om1_T40
3?m1_T400ol0003o4^dBoa;]4P06oa;]4P03o`000?ln`Cko?/4n00Go?/4n00?o0000ofJII_mVVFH0
3?mVVFH00ol0003oXUfRoj9MXP06oj9MXP03o`000?oI9]WofBKI00[ofBKI00?o0000oo4>lOoa3_40
0ol0000:oo@;m0?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000olTfbOo9=/T02?o9
=/T01Ol0003oUVVFoiIYU_nFJIKo000000_oIYUV00?o0000o`Wf2Ol9mPT00ol00009ocg2?@03o`00
0?l=lPgo3O8=00Co3O8=00?o0000o`3o0?l0o`000ol0o`000ol0003o=</docC;=00<ocC;=003o`00
0?m1_T7o@Ki100go@Ki100?o0000oa;]4_lBkA801_lBkA800ol0003o?/4nock1?P03ock1?P?o0000
3OmVVFH00ol0003oXUfRoj9MXP05oj9MXP03o`000?oI9]WofBKI00cofBKI0_l0000=oo@;m003o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000olTfbOo9=/T02?o9
=/T4o`0000coIYUV00?o0000o`Wf2Ol9mPT00ol9mPT3o`0000Go?L8m00?o0000o`gb3Ol=lPd01_l=
lPd01Ol0003o0?l0o`3o0?l0o`3o000000oo=</d00?o0000od6n@Om1_T403Om1_T400ol0003o4^dB
oa;]4P06oa;]4P03o`000?ln`Cko?/4n00?o00000olVfBH00ol0003oIYUVofJIIP0;ofJIIP03o`00
0?nRGJ;oXUfR00?oXUfR00?o0000omTVfOoI9]T03OoI9]T00ol0003om0_doo@;m00;oo@;m003o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000on`Ck?o/4n`02_o/4n`3o`0000KobCK90ol0
0003okI9]P03o`000?mVVFKoIYUV00[oIYUV00?o0000o`Wf2Ol9mPT01_l9mPT3o`000003ocg2?Ol0
003o3O8=00Wo3O8=00?o0000o`3o0?l000004?ldbc@00ol0003o@Ki1od6n@@0=od6n@@03o`000?lB
kA;o4^dB00Oo4^dB0_l00007obKI9P03o`000?mVVFKoIYUV00[oIYUV00Co0000oj9MX_nRGJ;oXUfR
0ol0000?omTVf@03o`000?od2oCom0_d00_om0_d00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000on`Ck?o/4n`02_o/
4n`01?l0003ohAkQon4NhOoQ7^42o`000004olTfbOl0003o0000o`0000Ko]TVf00?o0000ofJII_mV
VFH02_mVVFH00ol0003o2OH9o`Wf2@09o`Wf2@03o`000?l=lPgo3O8=00[o3O8=00?o0000ocC;=?ld
bc@03oldbc@00ol0003o@Ki1od6n@@0>od6n@@03o`000?lBkA;o4^dB00Ko4^dB00?o0000obKI9_lV
fBH01olVfBH4o`0000SoIYUV00Co0000oj9MX_nRGJ;o00000onbCK82o`0000gofBKI00?o0000oo@;
m?od2o@02_od2o@00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000on`Ck?o/4n`02Oo/4n`00ol0003o
hAkQon4Nh@04on4Nh@03o`000?nfBKKo]TVf00Oo]TVf00?o0000ofJII_mVVFH02OmVVFH00ol0003o
2OH9o`Wf2@0:o`Wf2@03o`000?l=lPgo3O8=00[o3O8=00?o0000ocC;=?ldbc@03oldbc@00ol0003o
@Ki1od6n@@0>od6n@@03o`000?lBkA;o4^dB00Go4^dB00?o0000obKI9_lVfBH02?lVfBH01?l0003o
FjAKoe^TFomKY5/7o`0000;oIYUV0_l00006ok9=/P;o00003?oI9]T00ol0003om0_doo@;m009oo@;
m003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ok1?/on`Ck008on`Ck003o`000?oQ7^7ohAkQ00Go
hAkQ00?o0000okI9]_nfBKH02?nfBKH00ol0003oIYUVofJIIP08ofJIIP03o`000?l9mPWo2OH900[o
2OH900?o0000o`gb3Ol=lPd02ol=lPd00ol0003o=</docC;=00>ocC;=003o`000?m1_T7o@Ki100ko
@Ki11Ol00002oa;]4P03o`000?lVfBKo9]TV00Wo9]TV00?o0000oe^TFomKY5/02?mKY5/3o`0000Wo
/Tfb0_l0000:omTVf@03o`000?od2oCom0_d00Som0_d00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o/4ncok1?/00Sok1?/00?o0000on4NhOoQ7^401ooQ7^400ol0003o]TVfokI9]P07okI9]P03o`00
0?mVVFKoIYUV00SoIYUV00?o0000o`Wf2Ol9mPT02_l9mPT00ol0003o3O8=o`gb3@0:o`gb3@;o0000
3_ldbc@3o`0000go@Ki10ol00005od^dB`;o00002olVfBH00ol0003oFjAKoe^TF`0;oe^TF`;o0000
2_nbCK82o`0000OofBKI0ol00009oo@;m003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:on4Nh@03o`00
0?nfBKKo]TVf00Oo]TVf00?o0000ofJII_mVVFH02?mVVFH>o`0000Wo3O8=0ol000000ol0o`3o0000
ocC;=00:ocC;=0?o00000_m=/Td00ol0003o@Ki1od6n@@09od6n@@;o00002Om;]4/00ol0003o9]TV
obKI9P09obKI9P03o`000?mKY5_oFjAK00_oFjAK00?o0000oh=lPol000002onbCK82o`0000CofBKI
00Co0000onXEj_oZ5N[ojQGZ0_l00007oo@;m003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003ohAkQ
on4Nh@09on4Nh@03o`000?nfBKKo]TVf00Ko]TVf00?o0000ofJII_mVVFH02?mVVFH00ol0003o4^dB
oa;]4P0:oa;]4P03o`000?l=lPgo3O8=00Co3O8=0ol00005o`3o0003o`000?ldbcCo=</d00Co=</d
1?l00006odfbC@03o`000?m1_T7o@Ki100Ko@Ki10_l0000;od^dB`03o`000?lVfBKo9]TV00Wo9]TV
00?o0000oe^TFomKY5/02_mKY5/01Ol0003oPgb3oh=lPon3O8?o000000co/Tfb0_l000000ooI9]Wo
0000onXEjP05onXEjP03o`000?od2oCom0_d00?om0_d00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oQ7^7ohAkQ00SohAkQ00?o0000okI9]_nfBKH01_nfBKH00ol0003oIYUVofJIIP07ofJIIP03o`00
0?lBkA;o4^dB00_o4^dB00?o0000o`gb3Ol=lPd00_l=lPd2o`0000Wo0?l000?o0000ocC;=?ldbc@0
0ol0000;odfbC@03o`000?m1_T7o@Ki100;o@Ki10ol0000>od^dB`03o`000?lVfBKo9]TV00Oo9]TV
00?o0000oe^TFomKY5/02omKY5/00ol0003oPgb3oh=lP`02oh=lP`03o`000?nbCK;o/Tfb00_o/Tfb
00?o0000onXEj_oZ5NX01_oZ5NX2o`0000?om0_d00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oQ
7^7ohAkQ00OohAkQ00?o0000okI9]_nfBKH01onfBKH00ol0003oIYUVofJIIP05ofJIIP?o00003OlB
kA84o`0000_o0?l00ol0000?odfbC@04o`000?m1_T7o0000o`00017oBkA;00?o0000obKI9_lVfBH0
1olVfBH00ol0003oFjAKoe^TF`0:oe^TF`03o`000?n3O8?oPgb300CoPgb300?o0000ok9=/_nbCK80
1onbCK83o`0000_ojQGZ1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on4NhOoQ7^402?oQ7^400ol0003o]TVfokI9
]P06okI9]P03o`000?mVVFKoIYUV00;oIYUV0ol00003od>l@`03o`000?lBkA;o4^dB00[o4^dB00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AodfbC@03o`000?m;]4_oBkA;017oBkA;00?o
0000obKI9_lVfBH01olVfBH00ol0003oFjAKoe^TF`0:oe^TF`03o`000?n3O8?oPgb300GoPgb300Co
0000ok9=/_nbCK;o/Tfb1Ol00002oki1_P03o`000?oZ5N[ojQGZ00WojQGZ00Co0000oo`3o?ol0oco
o0?l0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000on4NhOoQ7^401ooQ7^400ol0003o]TVfokI9]P05okI9]P?o0000
00?oIYUVo`000?l000001om3_4<00ol0003o4^dBoa;]4P08oa;]4P?o00002_l0o`02o`0000;o0?l0
00?o0000odfbCOm=/Td03om=/Td00ol0003oBkA;od^dB`0Aod^dB`03o`000?lVfBKo9]TV00Oo9]TV
00?o0000oe^TFomKY5/02OmKY5/00ol0003oPgb3oh=lP`07oh=lP`?o00001onn@Kh00ol0003ojQGZ
onXEjP09onXEjP03o`000?ol0ocoo0?l00Coo0?l0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000on4NhOoQ7^401ooQ
7^44o`0000;o]TVf0_l00003oj]DZ`03o`000?m3_4?o@ka300So@ka30_l00006oa;]4P;o00000olB
kA800ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000odfbCOm=/Td03_m=
/Td00ol0003oBkA;od^dB`0Bod^dB`03o`000?lVfBKo9]TV00Go9]TV00?o0000oe^TFomKY5/02OmK
Y5/00ol0003oPgb3oh=lP`08oh=lP`03o`000?nn@Kko_T6n00Oo_T6n00?o0000onXEj_oZ5NX02?oZ
5NX00ol0003oo0?loo`3o007oo`3o0;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oQ7^7ohAkQ00CohAkQ0_l00004
on@Ki0;o00001On[E:/00ol0003o@ka3od>l@`0:od>l@`03o`000?lBkA;o4^dB00;o4^dB00?o0000
oa;]4_lBkA801?lBkA800ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
odfbCOm=/Td03_m=/Td00ol0003oBkA;od^dB`0Bod^dB`[o00002_mKY5/00ol0003oPgb3oh=lP`08
oh=lP`03o`000?nn@Kko_T6n00Oo_T6n00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo0?loo`3o009
oo`3o0?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ohAkQon4NhOoQ7^42o`0000Ooi1_T00?o0000oj]DZon[E:/01?n[E:/0
0ol0003o@ka3od>l@`0:od>l@`04o`000?lBkA;o0000o`0000So4^dB00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?m=/TgoCK9=00koCK9=00?o0000od^dBom;]4/04_m;]4/00ol0003o@;m0
od2o@007od2o@003o`000?mKY5_oFjAK00KoFjAK00?o0000oh=lPon3O8<02_n3O8<00ol0003o_T6n
oki1_P06oki1_P03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3o?ol0o`03?ol0o`00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oQ
7^7o0000o`0000Woi1_T00?o0000oj]DZon[E:/01?n[E:/00ol0003o@ka3od>l@`0;od>l@`03o`00
0?lBkA;o4^dB00Wo4^dB00?o0000o`3o0?l000002Ol0o`000ol0003oCK9=odfbC@0>odfbC@;o0000
4_m;]4/00ol0003o@;m0od2o@009od2o@0;o00001_mKY5/00ol0003oPgb3oh=lP`0:oh=lP`03o`00
0?nn@Kko_T6n00Ko_T6n00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo0?loo`3o00<oo`3o003o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000on@Ki?oT6n@02OoT6n@00ol0003oZeB[oj]DZ`05oj]DZ`03o`000?m3_4?o@ka300[o@ka300?o
0000oa;]4_lBkA802_lBkA82o`0000Wo0?l000?o0000odfbCOm=/Td03_m=/Td00ol0003o=/Tfo`00
0002o`0000ooBkA;00?o0000od2o@?m0_d002om0_d000ol0003oFjAKoe^TF`03o`0000goPgb300?o
0000oki1__nn@Kh01_nn@Kh00ol0003ojQGZonXEjP07onXEjP03o`000?ol0ocoo0?l00coo0?l00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oi1_Ton@Ki009on@Ki003o`000?n[E:_oZeB[00GoZeB[00?o0000od>l@om3_4<02Om3_4<2
o`0000_o4^dB0_l0000;o`3o0003o`000?m=/TgoCK9=00coCK9=00?o0000ocK9=_lfbCH00olfbCH3
o`0000coBkA;00?o0000od2o@?m0_d003?m0_d02o`0000;oMXUf00?o0000oh=lPon3O8<03?n3O8<0
0ol0003o_T6noki1_P05oki1_P03o`000?oZ5N[ojQGZ00OojQGZ00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oT6nCoi1_T00[oi1_T00?o0000oj]DZon[E:/01_n[E:/00ol0003o@ka3od>l@`07od>l
@`03o`000?m2_D;o000000[o4^dB00Co0000o`Ki1_l6n@Ko00002_l0o`000ol0003oCK9=odfbC@0<
odfbC@03o`000?lfbCKo=/Tf00Ko=/Tf0_l00008od^dB`;o00003om0_d000ol0003oMXUfogJ9MP02
ogJ9MP03o`000?n3O8?oPgb300_oPgb300?o0000oki1__nn@Kh01Onn@Kh00ol0003ojQGZonXEjP07
onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oi1_Ton@Ki00:on@Ki003o`000?n[E:_oZeB[
00KoZeB[00?o0000od>l@om3_4<01_m3_4<01Ol0003o@[e2od:m@_m2_D;o000000So4^dB00?o0000
o`Ki1_l6n@H00_l6n@H00ol0003o0?l0o`3o0006o`3o00Co00003?m=/Td00ol0003o=/TfocK9=P08
ocK9=P?o00000_m;]4/3o`000003ocC;=?l0003o@;m000go@;m000?o0000ogJ9M_mfRGH01?mfRGH0
0ol0003oPgb3oh=lP`0:oh=lP`03o`000?nn@Kko_T6n00Go_T6n00?o0000onXEj_oZ5NX01_oZ5NX0
0ol0003oo0?loo`3o00<oo`3o003o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000on@Ki?oT6n@02ooT6n@00ol0003oZeB[oj]DZ`07oj]D
Z`03o`000?m3_4?o@ka300?o@ka30_l00005od:m@P03o`000?lBkA;o4^dB00Co4^dB00?o0000o`Ki
1_l6n@H00ol6n@H00ol0003o0?l0o`3o0005o`3o0003o`000?lDjaCo5>/D00;o5>/D0ol00007odfb
C@;o00003_lfbCH2o`0000Go=</d00?o0000od2o@?m0_d002_m0_d000ol0003oMXUfogJ9MP05ogJ9
MP03o`000?n3O8?oPgb300_oPgb300?o0000oki1__nn@Kh01?nn@Kh00ol0003ojQGZonXEjP06onXE
jP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oi1_Ton@Ki00;on@Ki003o`000?n[E:_oZeB[00Oo
ZeB[00?o0000od>l@om3_4<00_m3_4<00ol0003o@[e2od:m@P06od:m@P03o`000?lBkA;o4^dB00;o
4^dB00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o0?l0o`3o0002o`3o00;o00002?lDja@3o`0000;o
CK9=0_l000000olLhaco0000ocK9=P0=ocK9=P03o`000?ldbcCo=</d00Go=</d00?o0000od2o@?m0
_d002?m0_d000ol0003oMXUfogJ9MP07ogJ9MP03o`000?n3O8?oPgb300[oPgb300?o0000oki1__nn
@Kh01?nn@Kh00ol0003ojQGZonXEjP06onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oi1_T
on@Ki00<on@Ki003o`000?n[E:_oZeB[00SoZeB[00Co0000od>l@om3_4?o00002Om2_D801Ol0003o
4^dBoa;]4_lBkA;o000000So1_T600Go0000o`3o0?l0o`3o0?l0o`00000=oaC[50;o00001?lLha`0
0ol0003o=/TfocK9=P0;ocK9=P03o`000?ldbcCo=</d00Ko=</d00?o0000od2o@?m0_d001om0_d00
0ol0003oMXUfogJ9MP08ogJ9MPCo00002?n3O8<00ol0003o_T6noki1_P04oki1_P03o`000?oZ5N[o
jQGZ00KojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oT6nCoi1_T00_oi1_T0ol00009oj]D
Z`03o`000?m3_4?o000000_o@[e200?o0000oa;]4_l000002_l6n@H00ol0003o0?l0o`00000?oaC[
5003o`000?lLhaco7><L00;o7><L00?o0000ocK9=_lfbCH02olfbCH00ol0003o=</docC;=006ocC;
=003o`000?m0_d3o@;m000Ko@;m000?o0000ogJ9M_mfRGH02OmfRGH01?l0003oZ5NXojQGZ?nXEjP7
o`0000;oPgb300?o0000oki1__nn@Kh00onn@Kh00ol0003ojQGZonXEjP05onXEjP03o`000?ol0oco
o0?l00coo0?l00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oT6nCoi1_T00Soi1_T0ol00003omdRg@03o`000?n[E:_oZeB[00OoZeB[00?o0000od:m
@_m2_D802om2_D800ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?lDjaCo5>/D00go5>/D00?o0000oacS
7?lLha`01?lLha`00ol0003o=/TfocK9=P09ocK9=P03o`000?ldbcCo=</d00So=</d00?o0000od2o
@?m0_d000om0_d02o`0000coMXUf00?o0000ojQGZ?nXEjP02?nXEjP<o`0000?ojQGZ0ol0000=oo`3
o003o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on@Ki?oT6n@01_oT6n@3o`0000OogB;M00?o0000oj]DZon[E:/01_n[E:/00ol0003o
@[e2od:m@P0;od:m@P03o`000?l6n@Ko1_T600Wo1_T60_l0000>oaC[5003o`000?lLhaco7><L00Go
7><L00?o0000ocK9=_lfbCH02OlfbCH00ol0003o=</docC;=009ocC;=003o`000?m0_d3o000000;o
00000_m/Tf`00ol0003oMXUfogJ9MP08ogJ9MP03o`000?nXEjSoZ5NX00coZ5NX00?o0000onDJiOoU
6^D01_oU6^D3o`0000?oo0?l0_l00009oo`3o0;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oi1_Ton@Ki003on@Ki0?o00002ooM8]d00ol0003oZeB[
oj]DZ`04oj]DZ`03o`000?m2_D;o@[e200_o@[e20ol00007o`Ki1P?o000000?o4NhAo`000?lDja@0
3OlDja@00ol0003o7><LoacS7006oacS7003o`000?lfbCKo=/Tf00So=/Tf00?o0000ocC;=?ldbc@0
2_ldbc@00ol0003oK9=/ofbCK004ofbCK003o`000?mfRGKoMXUf00OoMXUf00?o0000ojQGZ?nXEjP0
2onXEjP00ol0003oiA[UonDJi@08onDJi@03o`000?ol0ocoo0?l00Coo0?l0ol00004oo`3o0;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004on@Ki?l0
003o0000o`0000oogB;M00?o0000oj]DZon[E:/00on[E:/>o`0000?o</db0_l00002o`Ki1P?o0000
1OlAkQ400ol0003o5>/DoaC[500:oaC[5003o`000?lLhaco7><L00Oo7><L00?o0000ocK9=_lfbCH0
2?lfbCH00ol0003o=</docC;=00:ocC;=003o`000?m/TfcoK9=/00GoK9=/00?o0000ogJ9M_mfRGH0
1_mfRGH00ol0003oZ5NXojQGZ00;ojQGZ003o`000?oU6^GoiA[U00SoiA[U00?o0000oo`3o?ol0o`0
1ool0o`2o`000003oo`3o?l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ok1?/2o`0001;ogB;M00?o0000oj]DZon[E:/00_n[E:/00ol0003oR7N8ohQg
R00:ohQgR003o`000?lbcC;o</db00?o</db0_l00009oa7^4@03o`000?lDjaCo5>/D00Wo5>/D00?o
0000oacS7?lLha`02?lLha`2o`0000So=/Tf00?o0000ocC;=?ldbc@02Oldbc@00ol0003oK9=/ofbC
K007ofbCK003o`000?mfRGKoMXUf00CoMXUf00?o0000ojQGZ?nXEjP02onXEjP00ol0003oiA[UonDJ
i@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ogB;MomdRg@0?omdRg@?o000000?oZeB[
o`000?n8MhP02on8MhP00ol0003o</dboc;=<P04oc;=<P03o`000?lAkQ7o4NhA00Wo4NhA00?o0000
oaC[5?lDja@01olDja@00ol0003o7><LoacS7009oacS7004o`000?lMhQgo0000o`0000Ko=/Tf00?o
0000ocC;=?ldbc@02Oldbc@00ol0003oK9=/ofbCK008ofbCK003o`000?mfRGKoMXUf00?oMXUf00?o
0000ojQGZ?nXEjP02onXEjP00ol0003oiA[UonDJi@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ogB;MomdRg@0<omdRg@;o00000ooJ9MX2o`0000coR7N800?o0000oc;=<_lbcC801?lbcC80
0ol0003o4NhAoa7^4@0:oa7^4@Wo00002olLha`00ol0003o7N8MoagR7@02oagR7@?o00000_lfbCH0
0ol0003o=</docC;=00:ocC;=003o`000?m/TfcoK9=/00WoK9=/00?o0000ogJ9M_mfRGH00_mfRGH0
0ol0003oZ5NXojQGZ00:ojQGZ003o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oM8]d2o`0000GofRGJ00?o0000ojYEZ_l000002_n8MhP00ol0003o</dboc;=<P06oc;=
<P03o`000?lAkQ7o4NhA00Wo4NhA00?o0000o`[e2_l:m@X01Ol:m@X00ol0003o7><LoacS7009oacS
7003o`000?lMhQgo7N8M00Go7N8M0ol00009ocC;=0?o00003Om/Tf`01Ol0003oMXUfogJ9M_mfRGKo
000000coZ5NX00?o0000onDJiOoU6^D02OoU6^D00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omdR
gOoM8]d01OoM8]d2o`0000OofRGJ00Co0000ojYEZ_nZEJ[o00002On8MhP00ol0003o</dboc;=<P06
oc;=<P03o`000?lAkQ7o4NhA00So4NhA00?o0000o`[e2_l:m@X01ol:m@X00ol0003o7><LoacS7007
oacS7003o`000?lMhQgo7N8M00So7N8M0ol00002ocC;=0Go00000_m5^TD00ol0003oK9=/ofbCK00<
ofbCK003o`000?mfRGKo000000coZ5NX00?o0000onDJiOoU6^D02_oU6^D00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000omdRgOoM8]d00_oM8]d2o`0000SofRGJ00?o0000ojYEZ_nZEJX00_nZEJX5o`00
00CoR7N800?o0000oc;=<_lbcC801_lbcC800ol0003o4NhAoa7^4@08oa7^4@03o`000?l:m@[o2_D:
00Oo2_D:00?o0000oacS7?lLha`01olLha`00ol0003o7N8MoagR7@08oagR7@03o`000?lNhAko7^4N
00;o00002?m5^TD00ol0003oK9=/ofbCK00<ofbCK0Co00002_nXEjP00ol0003oiA[UonDJi@0:onDJ
i@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ogB;Mo`000?l0000:omXUfP03o`000?nZEJ[oZUFZ
00;oZUFZ00?o0000of6NHOmQWV400_mQWV44o`0000Wo</db00?o0000oa7^4OlAkQ402?lAkQ400ol0
003o2_D:o`[e2P08o`[e2P03o`000?lLhaco7><L00Go7><L00?o0000oagR7OlMhQd02?lMhQd01Ol0
003o7^4NoakQ7_lNhAko000000[oAKY50ol0000;ofbCK004o`000?oC;=?odbcCom</d`Co00001OnX
EjP00ol0003oiA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ofRGJomXUfP0:
omXUfP03o`000?nZEJ[oZUFZ00?oZUFZ00?o0000of6NHOmQWV401?mQWV400ol0003o</dboc;=<P07
oc;=<P03o`000?lAkQ7o4NhA00Ko4NhA0_l0000;o`[e2P03o`000?lLhaco7><L00Go7><L00?o0000
oagR7OlMhQd02?lMhQd00ol0003o7^4NoakQ7P02oakQ7P03o`000?m5^TGoAKY500OoAKY500?o0000
oiQWV?nHIiP01?l00006ofbCK003o`000?oC;=?odbcC00KodbcC0ol00002ojQGZ003o`000?oU6^Go
iA[U00_oiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000ojYE
Z_nZEJX01?nZEJX00ol0003oHIiQof6NH@05of6NH@03o`000?lbcC;o</db00Oo</db00?o0000oa7^
4OlAkQ400_lAkQ43o`000003oakQ7_l0003o2_D:00[o2_D:00?o0000oacS7?lLha`01OlLha`00ol0
003o7N8MoagR7@07oagR7@03o`000?lNhAko7^4N00?o7^4N00?o0000odFjAOm5^TD01om5^TD00ol0
003oV6NHoiQWV004oiQWV0?o00000_m/Tf`00ol0003odbcCom</d`0:om</d`;o00003_oU6^D00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omXUf_oJ9MX02OoJ9MX00ol0003oZUFZojYEZP04ojYEZP03
o`000?mQWV7oHIiQ00KoHIiQ0_l00007oc;=<P03o`000?lAkQ7o000000;o00001OlNhAh00ol0003o
2_D:o`[e2P08o`[e2P?o00001?lLha`00ol0003o7N8MoagR7@08oagR7@03o`000?lNhAko7^4N00Co
7^4N00?o0000odFjAOm5^TD01_m5^TD00ol0003oV6NHoiQWV007oiQWV0;o00003_oC;=<00ol0003o
iA[UonDJi@0;onDJi@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ofRGJomXUfP08omXUfP03o`00
0?nZEJ[oZUFZ00GoZUFZ00?o0000of6NHOmQWV401?mQWV400ol0003oH9mPof2OH003o`0000Co</db
0_l00008oakQ7P03o`000?l:m@[o2_D:00Oo2_D:00Co0000oc_4>olka3_o>l@k0ol000000olLhaco
0000oagR7@09oagR7@03o`000?lNhAko7^4N00Co7^4N00?o0000odFjAOm5^TD01Om5^TD00ol0003o
V6NHoiQWV009oiQWV003o`000?oC;=?odbcC00godbcC00?o0000onDJiOoU6^D02_oU6^D00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omXUf_oJ9MX01ooJ9MX00ol0003oZUFZojYEZP06ojYEZP03o`00
0?mQWV7oHIiQ00?oHIiQ00?o0000of2OH?mPWf001?mPWf02o`000003oc;=<_l0003o7^4N00[o7^4N
00?o0000o`[e2_l:m@X01Ol:m@X00ol0003o>l@koc_4>`05oc_4>`03o`000?lMhQgo7N8M00Oo7N8M
0ol00007oakQ7P03o`000?m5^TGoAKY500CoAKY500?o0000oiQWV?nHIiP02OnHIiP00ol0003odbcC
om</d`0=om</d`03o`000?oU6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oJ
9M[ofRGJ00GofRGJ0ol00009ojYEZP05o`000?mQWV7oHIiQof6NHOl000002OmPWf000ol0003o7^4N
oakQ7P0;oakQ7P03o`000?l:m@[o2_D:00?o2_D:00?o0000oc_4>olka3/01_lka3/00ol0003o7N8M
oagR7@06oagR7@05o`000?lcc3?o<l`coc?<<ol000001olNhAh00ol0003oAKY5odFjA@03odFjA@03
o`000?nHIiSoV6NH00WoV6NH00?o0000om</dooC;=<03_oC;=<00ol0003oiA[UonDJi@09onDJi@03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ofRGJo`000004o`0000;oiaSW00?o0000ojYEZ_nZEJX0
1onZEJX01?l0003oHIiQof6NHOl00009of2OH0;o00003OlNhAh00ol0003o2_D:o`[e2P02o`[e2P03
o`000?lka3_o>l@k00So>l@k00?o0000oagR7OlMhQd00olMhQd2o`0000Go<l`c00?o0000oakQ7_lN
hAh01?lNhAh00ol0003oAKY5odFjA@03odFjA@03o`000?nHIiSoV6NH00WoV6NH00?o0000om</dooC
;=<03_oC;=<00ol0003oiA[UonDJi@09onDJi@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SoiaSW
00?o0000ojYEZ_nZEJX01_nZEJX00ol0003oHIiQo`000009of2OH004o`000?m>/DkoC[5>o`0000go
7^4N00Co0000o`[e2_l:m@[o00003?lka3/01Ol0003o7N8MoagR7OlMhQgo000000So<l`c0_l00005
oakQ7P03o`000?m5^TGoAKY500;oAKY500?o0000oiQWV?nHIiP02OnHIiP00ol0003odbcCom</d`0>
om</d`03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oW6>OoiaSW
00OoiaSW00?o0000ojYEZ_nZEJX01onZEJX00ol0003oH9mPof2OH007of2OH003o`000?m>/DkoC[5>
00;oC[5>00?o0000oakQ7_lNhAh02_lNhAh00ol0003o2_D:o`00000>oc_4>`03o`000?lMhQgo0000
00_o<l`c00?o0000oakQ7_lNhAh00_lNhAh01Ol0003oAKY5odFjAOm5^TGo000000coV6NH00?o0000
om</dooC;=<03_oC;=<3o`0000WoiA[U00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oW6>OoiaSW
00WoiaSW00?o0000ojYEZ_nZEJX01_nZEJX00ol0003oH9mPof2OH006of2OH003o`000?m>/DkoC[5>
00?oC[5>00?o0000oakQ7_lNhAh02olNhAh00ol0003o>l@koc_4>`0>oc_4>`03o`000?lcc3?o<l`c
00_o<l`c0_l00003oakQ7P04o`000?m5^TGoAKY5o`0000[oV6NH0ol0000>om</d`;o00000ool0o`2
o`0000OoiA[U00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oW6>OoiaSW00[oiaSW00?o0000ojYE
Z_nZEJX01?nZEJX00ol0003oH9mPof2OH006of2OH003o`000?m>/DkoC[5>00GoC[5>00?o0000oakQ
7_lNhAh01olNhAh3o`00017o>l@k00?o0000oc?<<olcc3<03Olcc3<01Ol0003o7^4NoakQ7_l0003o
AKY500Co00000onHIiP5o`0000;ogR7N00?o0000om</dooC;=<02_oC;=<2o`0000Ooo0?l0_l00004
onDJi@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oiaSWonLHi`0;onLHi`03o`000?nZEJ[oZUFZ
00CoZUFZ00?o0000of2OH?mPWf001OmPWf000ol0003oC[5>odjaCP06odjaCP03o`000?lNhAko7^4N
00Co7^4N0ol00002obSG:003o`000?lka3_o>l@k00oo>l@k0_l0000?oc?<<`04o`000?lNhAko0000
o`0000CoPWf20ol00008omhQgP03o`000?oC;=?odbcC00OodbcC0_l0000;oo`3o0;o00000_oU6^D0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onLHiooW6>L03?oW6>L6o`0000OoH9mP00?o0000odja
C_m>/Dh02?m>/Dh00ol0003o7^4NoakQ7P03o`0000Ko:=LX00?o0000oc_4>olka3/03Olka3/01?l0
003o@[e2od:m@_l0000?oc?<<`03o`000?n2OH;oPWf200GoPWf200?o0000omhQg_oN8Mh02?oN8Mh0
0ol0003odbcCom</d`05om</d`03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oW6>L00ol0003o/Djaok5>/@04ok5>
/@03o`000?mPWf3oH9mP00?oH9mP00?o0000odjaC_m>/Dh02_m>/Dh2o`0000[o:=LX00?o0000oc_4
>olka3/02olka3/00ol0003o@[e2od:m@P02od:m@P03o`000?lcc3?o<l`c00_o<l`c0_l00007oh9m
PP03o`000?oN8MkogR7N00WogR7N00?o0000om</dooC;=<00_oC;=<2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onLHiooW6>L02ooW6>L00ol0003o/Djaok5>/@06ok5>/@05o`000?mPWf3oH9mPof2O
H?l000003Om>/Dh00ol0003o:=LXobSG:00:obSG:003o`000?lka3_o>l@k00Wo>l@k00?o0000od:m
@_m2_D801?m2_D800ol0003o<l`coc?<<`08oc?<<`;o000000?o=LXeo`000?n2OH801on2OH800ol0
003ogR7NomhQgP09omhQgP04o`000?oC;=?o0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oW6>OoiaSW
00WoiaSW00?o0000ok5>/OnaC[402?naC[400ol0003oH9mPo`00000=odjaCP03o`000?lXebSo:=LX
00_o:=LX00?o0000oc_4>olka3/02?lka3/00ol0003o@[e2od:m@P06od:m@P03o`000?lcc3?o<l`c
00Go<l`c0_l00003ocG:=@03o`000?n2OH;oPWf200KoPWf200?o0000omhQg_oN8Mh02_oN8Mh00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003oiaSWonLHi`07onLHi`03o`000?naC[7o/Dja00[o/Dja00?o0000odjaC_m>
/Dh03?m>/Dh00ol0003o:=LXobSG:00<obSG:003o`000?lka3_o>l@k00Ko>l@k00?o0000od:m@_m2
_D802?m2_D800ol0003o<l`coc?<<`02oc?<<`;o00001_lebSD00ol0003oPWf2oh9mPP05oh9mPP03
o`000?oN8MkogR7N00[ogR7N00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oW6>OoiaSW00GoiaSW
00?o0000ok5>/OnaC[403?naC[42o`0000coC[5>00?o0000obSG:?lXebP03OlXebP00ol0003o>l@k
oc_4>`04oc_4>`03o`000?m2_D;o@[e200[o@[e200Co0000oc?<<ol0003o00002?lebSD00ol0003o
PWf2oh9mPP06oh9mPP03o`000?oN8MkogR7N00WogR7N00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oW6>L00ol0003o/Djaok5>/@0=ok5>/@03o`000?mUVVGo000000;o00002?m>/Dh00ol0003o:=LX
obSG:00?obSG:0Ko00003_m2_D800ol0003o=LXeocG:=@08ocG:=@03o`000?n2OH;oPWf200KoPWf2
00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onTFjOoY5^WojAKY
0_l0000?ok5>/@03o`000?mUVVGoIIYU00?oIIYU0ol00005odjaCP;o00004?lXebP01_l0003o6>LH
oaSW6?l0003o2?L8o`0000ko@[e200?o0000ocG:=OlebSD02OlebSD00ol0003oPWf2oh9mPP05oh9m
PP03o`000?oN8MkogR7N00WogR7N00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onTFjOoY5^T00ooY5^T00ol0003o
/Djaok5>/@0=ok5>/@03o`000?mUVVGoIIYU00KoIIYU0ol000001?m>/Dko0000obcC;?l/db`3o`00
00co:=LX00Go0000oaSW6?lHiaSo6>LHo`000002o`Sg2003o`000?m2_D;o@[e200_o@[e200?o0000
ocG:=OlebSD02OlebSD00ol0003oPWf2oh9mPP06oh9mPP03o`000?oN8MkogR7N00SogR7N0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003ojAKYonTFj@04onTFj@oo00003?mUVVD00ol0003o;=</obcC;004obcC
;0?o00002?lXebP00ol0003o6>LHoaSW6002oaSW6005o`000?l8m`So2?L8o`Sg2?l000003?m2_D80
0ol0003o=LXeocG:=@09ocG:=@03o`000?n2OH;oPWf200GoPWf23?l00002oo4>l@;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003ojAKYonTFj@05onTFj@03o`000?n^DJko[U6^00_o[U6^00?o0000ofFJ
IOmUVVD02_mUVVD00ol0003o;=</obcC;007obcC;0;o00001OlXebP00ol0003o6>LHoaSW6003oaSW
6003o`000?l8m`So2?L800;o2?L800?o0000od:m@_m2_D802Om2_D800ol0003o=LXeocG:=@0:ocG:
=@03o`000?n2OH;oPWf200?oPWf200?o0000ol`cc?o<<l`02Oo<<l`00ol0003ol@kaoo4>l@02oo4>
l@;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojAKYonTFj@06onTFj@03o`000?n^DJko[U6^00[o
[U6^00?o0000ofFJIOmUVVD02omUVVD00ol0003o;=</obcC;009obcC;0?o000000?o:=LXo`000?lH
iaP01OlHiaP00ol0003o2?L8o`Sg2003o`Sg2003o`000?m2_D;o@[e200So@[e23_l00003oh9mPP;o
00002oo<<l`00ol0003ol@kaoo4>l@05oo4>l@03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onTFjOoY5^T01OoY5^T00ol0003o_D:mo`00000;ojiA[P03o`000?mUVVGoIIYU00[oIIYU
0_l0000>obcC;003o`000?lHiaSo6>LH00Go6>LH00?o0000o`Sg2?l8m`P00ol8m`P00ol0003o@[e2
od:m@P08od:m@P03o`000?mnPGkoOX5n00_oOX5n00?o0000oh9mP_l000003Oo<<l`00ol0003ol@ka
oo4>l@06oo4>l@;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oY5^WojAKY00KojAKY00Co
0000oke2_Onm@[go00002_n^DJh00ol0003oIIYUofFJI@09ofFJI@03o`000?m2_D;o000000ko;=</
00?o0000oaSW6?lHiaP01OlHiaP00ol0003o2?L8o`Sg2004o`Sg2003o`000?m2_D;o@[e200Ko@[e2
00?o0000ogj1O_mnPGh03OmnPGh00ol0003oc3?<ol`cc00<ol`cc003o`000?oa3_7ol@ka00Sol@ka
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oY5^WojAKY00GojAKY00?o0000oke2_Onm@[d00_nm
@[d00ol0003o[U6^ojiA[P06ojiA[P03o`000?mUVVGoIIYU00SoIIYU0_l00003od:m@P03o`000?l/
dbco;=</00_o;=</00?o0000oaSW6?lHiaP01OlHiaP00ol0003o2?L8o`Sg2005o`Sg2003o`000?m2
_D;o@[e200Go@[e200?o0000ogj1O_mnPGh03OmnPGh00ol0003oc3?<ol`cc00;ol`cc003o`000?oa
3_7ol@ka00Wol@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oY5^WojAKY00KojAKY00?o0000
oke2_Onm@[d00onm@[d00ol0003o[U6^ojiA[P05ojiA[P03o`000?mUVVGoIIYU00OoIIYU00?o0000
od:m@_m2_D800om2_D800ol0003o;=</obcC;00:obcC;003o`000?lHiaSo6>LH00Ko6>LH00?o0000
o`Sg2?l8m`P01_l8m`P00ol0003o@[e2od:m@P04od:m@P03o`000?mnPGkoOX5n00goOX5n3ol0000;
oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oY5^WojAKY00KojAKY00?o0000oke2_Onm@[d01Onm@[d00ol0
003o[U6^ojiA[P04ojiA[P03o`000?mUVVGoIIYU00GoIIYU0_l00006od:m@P03o`000?l/dbco;=</
00Wo;=</0_l00008oaSW6003o`000?l8m`So2?L800Ko2?L81Ol000000om2_D;o0000ogj1OP0?ogj1
OP03o`000?o><LkocS7>00_ocS7>00?o0000oo4>lOoa3_402Ooa3_400ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?oY5^WojAKY00KojAKY00?o0000oke2_Onm@[d01_nm@[d00ol0003o
[U6^ojiA[P04o`0000KoIIYU00?o0000od:m@_m2_D801om2_D800ol0003o;=</obcC;005obcC;0?o
000000?o5nPGo`000?lHiaP01olHiaP00ol0003o2?L8o`Sg2005o`Sg2003o`000?m;]4_oBkA;00?o
BkA;0_l0000?ogj1OP;o00003Oo><Lh00ol0003ol@kaoo4>l@08oo4>l@03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WojAKY00?o0000oke2_Onm@[d01onm@[d2o`0000CoVVFJ00Co0000ofFJIOmUVVGo
IIYU0_l0000:od:m@P03o`000?l/dbco;=</00;o;=</0ol00005oaOX5`03o`000?lHiaSo6>LH00Go
6>LH00?o0000o`Sg2?l8m`P01?l8m`P00ol0003oBkA;od^dB`06od^dB`03o`000?mnPGkoOX5n00[o
OX5n0_l00002ojUFZ@03o`000?o><LkocS7>00[ocS7>00?o0000oo4>lOoa3_402?oa3_400ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onTFjOoY5^T01_oY5^T00ol0003o_D:moke2_@08oke2_@03o`00
0?nJII[oVVFJ00CoVVFJ00?o0000ofFJIOl000003?m2_D800ol0003o;=</o`000002o`0000Wo5nPG
00?o0000oaSW6?lHiaP01?lHiaP00ol0003o2?L8o`Sg2003o`Sg2003o`000?m;]4_oBkA;00SoBkA;
1_l00004ogj1OP;o00001OnYEZT00ol0003ocS7>olhacP09olhacP03o`000?oa3_7ol@ka00Sol@ka
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?oY5^WojAKY00GojAKY00?o0000oke2_Onm@[d01onm
@[d00ol0003oVVFJoiYUVP06oiYUVP03o`000?m2_D;o@[e200co@[e200?o0000oaOX5olGj1L02_lG
j1L00ol0003o6>LHoaSW6004oaSW6004o`000?l8m`So2?L8o`Sg20;o00002om;]4/00ol0003oQWV6
ohIiQP03ohIiQPCo00002?nYEZT00ol0003ocS7>olhacP08olhacP03o`000?oa3_7ol@ka00Ool@ka
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onTFjOoY5^T00ooY5^T00ol0003o_D:moke2_@07oke2_@03o`000?nJ
II[oVVFJ00OoVVFJ00?o0000od:m@_m2_D803?m2_D800ol0003o5nPGoaOX5`0;oaOX5`03o`000?lH
iaSo6>LH00?o6>LH00Co0000o`Sg2?l8m`So00003Om;]4/00ol0003oQWV6ohIiQP06ohIiQP03o`00
0?nYEZWoZEJY00OoZEJY00?o0000olhac_o><Lh01oo><Lh00ol0003ol@kaoo4>l@06oo4>l@04o`00
0?om0_goo@;mood2o@;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oY5^WojAKY00;ojAKY00?o0000oke2_Onm@[d0
1_nm@[d00ol0003oVVFJoiYUVP09oiYUVP03o`000?m2_D;o@[e200Wo@[e20_l0000>oaOX5`?o0000
0olHiaP00ol0003o2?L8o`00000=od^dB`03o`000?n6NHKoQWV600OoQWV600?o0000ojUFZOnYEZT0
2?nYEZT:o`0000Kol@ka0_l00006ood2o@03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo_D:m00?o
0000oiYUV_nJIIX02_nJIIX00ol0003o@[e2od:m@P06od:m@P;o000000?o>/Djo`000?lGj1L02olG
j1L2o`0000?o?l0o1Ol0000>od^dB`03o`000?n6NHKoQWV600OoQWV600?o0000ojUFZOnYEZT02?nY
EZT00ol0003ofRGJomXUfP06omXUfP03o`000?oa3_7ol@ka00?ol@ka00?o0000ood2oOom0_d01oom
0_d2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ogR7NomhQgP03omhQgPCo00000_nm@[d00ol0003oVVFJoiYUVP0;
oiYUVP03o`000?m2_D;o@[e200?o@[e20ol00004oc[5>P03o`000?lGj1Oo5nPG00Oo5nPG0_l00008
oco0?`03o`000?m;]4_oBkA;00goBkA;00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oZEJYojUFZ@07
ojUFZ@03o`000?oJ9M[ofRGJ00OofRGJ0ol000000ooa3_7o0000ood2o@0;ood2o@;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oN8MkogR7N00OogR7N0_l0000?oiYUVP03o`000?m2_D;o@[e200;o00002?ljaCX00ol0
003o5nPGoaOX5`05oaOX5`03o`000?lo`3oo?l0o00So?l0o00?o0000od^dBom;]4/03Om;]4/00ol0
003oQWV6ohIiQP08ohIiQP03o`000?nYEZWoZEJY00KoZEJY00?o0000omXUf_oJ9MX02?oJ9MX01?l0
003olPgboo8=l_l0000?ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ogR7NomhQgP09omhQ
gP03o`000?nJII[oVVFJ00koVVFJ0_l0000;oc[5>P03o`000?lGj1Oo5nPG00;o5nPG0_l0000;oco0
?`03o`000?m;]4_oBkA;00goBkA;00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oZEJYojUFZ@06ojUF
Z@03o`000?oJ9M[ofRGJ00OofRGJ00Go0000oo8=l_ob3O;olPgbo`00000@ood2o@;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ogR7NomhQgP0:omhQgP03o`000?nJII[oVVFJ00goVVFJ0_l0000<oc[5>P04o`000?lGj1Oo0000
o`0000go?l0o00?o0000od^dBom;]4/03?m;]4/00ol0003oQWV6ohIiQP09ohIiQP03o`000?nYEZWo
ZEJY00KoZEJY00?o0000omXUf_oJ9MX01_oJ9MX00ol0003olPgboo8=lP03oo8=lP03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ogR7NomhQgP0:omhQgP03o`000?nJII[oVVFJ00coVVFJ00Co0000ofVF
JOmYUVWo00003?ljaCX00ol0003o?l0ooco0?`0>oco0?`03o`000?m;]4_oBkA;00SoBkA;1?l0000;
ohIiQP03o`000?nYEZWoZEJY00KoZEJY00?o0000omXUf_oJ9MX01OoJ9MX00ol0003olPgboo8=lP04
oo8=lP03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ogR7NomhQgP0;omhQgP03o`000?nJII[oVVFJ
00_oVVFJ00?o0000ofVFJOmYUVT00_mYUVT00ol0003o>/Djoc[5>P09oc[5>P03o`000?lo`3oo?l0o
00ko?l0o00Co0000od^dBom;]4_oBkA;1ol00003oejQGP03o`000?n6NHKoQWV600WoQWV600?o0000
ojUFZOnYEZT01_nYEZT00ol0003ofRGJomXUfP04omXUfP03o`000?ob3O;olPgb00KolPgb00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oN8MkogR7N00cogR7N00?o0000oiYUV_nJIIX02_nJIIX00ol0
003oJIIYofVFJ@03ofVFJ@03o`000?ljaC[o>/Dj00So>/Dj00?o0000oco0?olo`3l03_lo`3l4o`00
00_oGZ5N00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oZEJYojUFZ@05ojUFZ@03o`000?oJ9M[ofRGJ
00GofRGJ00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000omhQg_oN
8Mh03?oN8Mh7o`0000GoVVFJ00?o0000ofVFJOmYUVT01OmYUVT00ol0003o>/Djoc[5>P07oc[5>P03
o`000?lo`3oo?l0o00ko?l0o00?o0000oejQG_mNXEh03OmNXEh00ol0003oQWV6ohIiQP08ohIiQP03
o`000?nYEZWoZEJY00CoZEJY00?o0000omXUf_oJ9MX01?oJ9MX00ol0003olPgboo8=lP07oo8=lP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ogR7NomhQgP0=omhQgP03o`000?niA[Wo^DJi00Co^DJi
1Ol00009ofVFJ@03o`000?ljaC[o>/Dj00Ko>/Dj00?o0000oco0?olo`3l03_lo`3l00ol0003oGZ5N
oejQGP0=oejQGP03o`000?n6NHKoQWV600SoQWV600Co0000ojUFZOnYEZWoZEJY1Ol00004omXUfP03
o`000?ob3O;olPgb00WolPgb1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=omhQgP03o`000?niA[Wo^DJi00Wo^DJi
0_l00009ofVFJ@03o`000?ljaC[o>/Dj00Ko>/Dj00?o0000oco0?olo`3l03?lo`3l00ol0003oGZ5N
oejQGP0?oejQGPKo00001?n6NHH4o`0000Gof2OH0_l000000ooJ9M[o0000oo8=lP0;oo8=lP04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o]4^gokA;]ondBk@?o00002_oN8Mh00ol0003o
^DJiokU6^@09okU6^@03o`000?moP7oo000000;o00001omYUVT00ol0003o>/Djoc[5>P05oc[5>P03
o`000?lo`3oo?l0o00So?l0o1Ol0000AoejQGP03o`000?nFJIKoUVVF00?oUVVF1?l0000;omPWf003
o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000ondBkOo]4^d01Oo]4^d2o`0000OogR7N
00?o0000okU6^OniA[T02_niA[T00ol0003oOh1oogn0O`02ogn0O`?o00001OmYUVT00ol0003o>/Dj
oc[5>P04oc[5>P04o`000?lo`3oo?l0ooco0?`Oo00001?m7^4L00ol0003oGZ5NoejQGP0>oejQGP03
o`000?nFJIKoUVVF00OoUVVF00?o0000omPWf?oH9mP02OoH9mP00ol0003olPgboo8=lP09oo8=lP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003okA;]ondBk@08ondBk@;o00001?oN8Mh00ol0003o^DJi
okU6^@0;okU6^@03o`000?moP7ooOh1o00GoOh1o0ol00003ofVFJ@04o`000?ljaC[o>/Djoc[5>PKo
00003?m7^4L00ol0003oGZ5NoejQGP0=oejQGP03o`000?nFJIKoUVVF00OoUVVF00?o0000omPWf?oH
9mP02_oH9mP00ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ondBk@?o000000?ogR7No`000?niA[T0
3?niA[T00ol0003oOh1oogn0O`08ogn0O`?o000000CoJIIYo`000?l0003o00000_n;M8/00ol0003o
AkQ7odNhA`0=odNhA`03o`000?mNXEkoGZ5N00coGZ5N00?o0000oiIYU_nFJIH02?nFJIH00ol0003o
f2OHomPWf00;omPWf003o`000?ob3O;olPgb00KolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
kA;]00?o0000okU6^OniA[T03?niA[T00ol0003oOh1oogn0O`0;ogn0O`03o`000?n;M8_oRgB;00?o
RgB;00?o0000odNhAom7^4L03?m7^4L00ol0003o@ka3o`00000=oejQGP03o`000?nFJIKoUVVF00So
UVVF00?o0000omPWf?oH9mP03?oH9mP3o`0000GolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o]4^gokA;]00cokA;]00?o0000okU6^OniA[T03?niA[T00ol0003oOh1oogn0O`0:ogn0O`03o`00
0?n;M8_oRgB;00GoRgB;00?o0000odNhAom7^4L02_m7^4L01?l0003o@ka3od>l@om3_4<2o`0000[o
GZ5N00?o0000oiIYU_nFJIH02OnFJIH00ol0003of2OHomPWf00<omPWf003o`000?od2oCom0_d00?o
000000?olPgbo`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000okU6^OniA[T0
3?niA[T00ol0003oOh1oogn0O`09ogn0O`03o`000?n;M8_oRgB;00KoRgB;00?o0000odNhAom7^4L0
2Om7^4L00ol0003o@ka3od>l@`02od>l@`03o`000?n;M8_o000000;o00001omNXEh00ol0003oUVVF
oiIYUP09oiIYUP03o`000?oH9mSof2OH00_of2OH00?o0000oo@;m?od2o@01?od2o@00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000ondBkOo]4^d02oo]4^d00ol0003o^DJiokU6^@0;okU6^@03o`000?mo
P7ooOh1o00SoOh1o00?o0000oh]dRon;M8/01on;M8/00ol0003oAkQ7odNhA`08odNhA`03o`000?m3
_4?o@ka300?o@ka300?o0000oh]dRon;M8/00_n;M8/2o`0000CoGZ5N00?o0000oiIYU_nFJIH02_nF
JIH00ol0003of2OHomPWf00:omPWf003o`000?od2oCom0_d00Gom0_d00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o]4^gokA;]00[okA;]0ol0000;okU6^@Ko00001?moP7l00ol0003oRgB;oh]dR`08
oh]dR`03o`000?m7^4OoAkQ700OoAkQ700?o0000od>l@om3_4<00om3_4<00ol0003oRgB;oh]dR`05
oh]dR`?o000000?oGZ5No`000?nFJIH02onFJIH00ol0003of2OHomPWf009omPWf003o`000?od2oCo
m0_d00Oom0_d00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o]4^gokA;]00WokA;]00?o0000omHY
e_oF:MH01?l00006okU6^@03o`000?ngB;Oo]dRg00Co]dRg1?l0000<oh]dR`03o`000?m7^4OoAkQ7
00GoAkQ700?o0000od>l@om3_4<01?m3_4<00ol0003oRgB;oh]dR`08oh]dR`03o`000?nFJIKoUVVF
00_oUVVF00?o0000omPWf?oH9mP02?oH9mP00ol0003om0_doo@;m008oo@;m0Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o]4^gokA;]00OokA;]00?o0000omHYe_oF:MH01OoF:MH3o`0000;o^DJi00?o0000okM8]ong
B;L02?ngB;L00ol0003oRgB;oh]dR`0:oh]dR`03o`000?m7^4OoAkQ700CoAkQ700?o0000od>l@om3
_4<01Om3_4<00ol0003oRgB;oh]dR`08oh]dR`03o`000?nFJIKoUVVF00WoUVVF1?l00008omPWf003
o`000?od2oCom0_d00Wom0_d00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003okA;]
ondBk@05ondBk@03o`000?oF:MKoeRWF00WoeRWF0_l0000<okM8]`03o`000?n;M8_oRgB;00WoRgB;
00?o0000odNhAom7^4L00om7^4L00ol0003o@ka3od>l@`05od>l@`03o`000?n;M8_oRgB;00[oRgB;
00?o0000oiIYU_nFJIH01?nFJIH4o`0000CocS7>00?o0000omPWf?oH9mP01?oH9mP00ol0003om0_d
oo@;m00:oo@;m003o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o]4^gokA;]00?okA;]00?o0000omHYe_oF:MH02ooF
:MH00ol0003o]dRgokM8]`0:okM8]`03o`000?n;M8_oRgB;00WoRgB;00?o0000odNhAom7^4L00_m7
^4L00ol0003o@ka3od>l@`06od>l@`03o`000?n;M8_oRgB;00[oRgB;00?o0000oiIYU_nFJIH01?l0
0009olhacPKo00003?od2o@00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000ondBkOo]4^gokA;]0_l0
000=omHYeP03o`000?ngB;Oo]dRg00[o]dRg00?o0000oh]dRon;M8/02On;M8/01Ol0003oAkQ7odNh
Aom7^4Oo000000Wo@ka300?o0000oh]dRon;M8/02on;M8/2o`0000gocS7>00?o0000oo0?l?o`3o00
0_o`3o000ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003okA;]o`00
0002ooD:m@;o00002ooF:MH00ol0003o]dRgokM8]`0;okM8]`03o`000?n;M8_oRgB;00WoRgB;00?o
0000odNhAol000002Om3_4<00ol0003oRgB;oh]dR`0<oh]dR`03o`000?o><LkocS7>00cocS7>00?o
0000oo0?l?o`3o000oo`3o000ol0003om0_doo@;m009oo@;m003o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om@[eooD:m@03ooD:m@;o00002_oF:MH00ol0003o]dRgokM8]`0:okM8]`03o`000?n;M8_o
RgB;00SoRgB;1Ol00008od>l@`03o`000?n;M8_oRgB;00coRgB;00?o0000olhac_o><Lh02oo><Lh0
0ol0003ol0o`oo0?l005oo0?l003o`000?od2oCom0_d00Som0_d00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooe2_D2o`0000SoeRWF00?o0000okM8]ongB;L02_ngB;L00ol0003oRgB;oh]dR`07oh]d
R`03o`000?n7N8OoQgR700?oQgR70ol00005od>l@`03o`000?n;M8_oRgB;00_oRgB;00?o0000olha
c_o><Lh03?o><Lh00ol0003ol0o`oo0?l006oo0?l003o`000?od2oCom0_d00Oom0_d00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Wom@[e00?o0000omHYe_oF:MH01OoF:MH2o`0000co
]dRg00?o0000oh]dRon;M8/01On;M8/00ol0003oQgR7ohMhQ`07ohMhQ`?o000000?o@ka3o`000?n;
M8/03On;M8/00ol0003ocS7>olhacP0<olhacP03o`000?o`3o3ol0o`00Kol0o`00?o0000oo@;m?od
2o@01_od2o@00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?oe2_Gom@[e00Oom@[e
0_l00004omHYeP03o`000?oP7n3oh1oP00;o00002_ngB;L00ol0003oRgB;oh]dR`03oh]dR`;o0000
3On7N8L2o`0000goRgB;0ol0000=olhacP03o`000?o`3o3ol0o`00Ool0o`00?o0000oo@;m?od2o@0
1Ood2o@00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?oe2_Gom@[e00Som@[e0_l0
00000ooF:MKo0000on0Oh004on0Oh003o`000?ngB;Oo]dRg00Oo]dRg00Co0000oh]dRon;M8_oRgB;
0_l00002okQ7^003o`000?n7N8OoQgR700coQgR73Ol00003olLha`03o`000?o><LkocS7>00[ocS7>
00?o0000oo0?l?o`3o002?o`3o001?l0003om0_doo@;m?od2o@4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003om@[e
ooD:m@09ooD:m@03o`000?oP7n3oh1oP00Goh1oP0_l00008okM8]`03o`000?n;M8_o000000Go^4Nh
00?o0000ohMhQon7N8L02on7N8L00ol0003oUVVFoiIYUP09oiIYUP03o`000?o7><OoacS700;oacS7
0_l00009olhacP03o`000?o`3o3ol0o`00[ol0o`0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?oe2_Gom@[e00Som@[e00?o0000on0Oh?oP7n001ooP7n04o`0000?o]dRg0ol0
0007okQ7^003o`000?n7N8OoQgR700[oQgR700?o0000oiIYU_nFJIH02OnFJIH00ol0003oacS7olLh
a`04olLha`;o00001oo><Lh00ol0003ol0o`oo0?l00:oo0?l003o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oe2_Gom@[e00Oom@[e00?o0000on0Oh?oP7n002?oP7n00
1?l0003ogR7NomhQg_oN8Mh3o`0000;od2o@00?o0000okQ7^?nhAkP01_nhAkP00ol0003oQgR7ohMh
Q`08ohMhQ`03o`000?nFJIKoUVVF00[oUVVF00?o0000olLhaoo7><L01_o7><L00ol0003ocS7>olha
cP04olhacP03o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oh1oPon0Oh008on0Oh003o`000?oN8Mko
gR7N00CogR7N00Go0000om0_d?o@;m3od2o@o`000008okQ7^003o`000?n7N8OoQgR700OoQgR700?o
0000oiIYU_nFJIH02_nFJIH00ol0003oacS7olLha`07olLha`;o00001?o><Lh00ol0003ol0o`oo0?
l008oo0?l003o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D00ooe2_D0
0ol0003oh1oPon0Oh008on0Oh003o`000?oN8MkogR7N00CogR7N00?o0000om0_d?o@;m000_o@;m00
0ol0003o^4NhokQ7^007okQ7^003o`000?n7N8OoQgR700KoQgR700?o0000oiIYU_nFJIH02_nFJIH0
0ol0003oacS7olLha`09olLha`05o`000?o><LkocS7>olhac_l000002Oo`3o000ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oh1oP00?o0000omhQg_oN8Mh01?oN8Mh00ol0003od2o@om0_d003
om0_d003o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ohMhQon7N8L01On7N8L00ol0003oUVVFoiIYUP0:
oiIYUP03o`000?o7><OoacS700WoacS71?l00009oo0?l003o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?of2OKomPWf
ooH9m_l000002_oP7n000ol0003ogR7NomhQgP05omhQgP03o`000?o@;m3od2o@00?od2o@00?o0000
okQ7^?nhAkP02?nhAkP00ol0003oQgR7ohMhQ`04ohMhQ`03o`000?nFJIKoUVVF00WoUVVF00?o0000
olLhaoo7><L02?o7><L2o`0000?ol@ka00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003oh1oPon0Oh006on0Oh003o`000?oN8MkogR7N
00GogR7N00?o0000om0_d?o@;m001?o@;m000ol0003o^4NhokQ7^009okQ7^003o`000?n7N8OoQgR7
00;oQgR700?o0000oiIYU_nFJIH02_nFJIH00ol0003oacS7olLha`06olLha`;o00001_oa3_48o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003omPWfooH9mP05ooH9mP03o`000?oP7n3oh1oP00Goh1oP00?o0000omhQg_oN
8Mh01OoN8Mh00ol0003od2o@om0_d005om0_d003o`000?nhAkSo^4Nh00Wo^4Nh00Go0000ohMhQon7
N8OoQgR7o`00000<oiIYUP03o`000?o7><OoacS700CoacS70_l00008oo4>l@03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?of2OKomPWf00OomPWf00?o0000on0Oh?oP
7n000ooP7n000ol0003ogR7NomhQgP06omhQgP03o`000?o@;m3od2o@00God2o@00?o0000okQ7^?nh
AkP02_nhAkP00ol0003oQgR7o`000004o`0000WoUVVF00?o0000olLhaoo7><L00_o7><L2o`0000[o
l@ka00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003omPWfooH9mP07ooH9mP03o`00
0?oP7n3oh1oP00;oh1oP00?o0000omhQg_oN8Mh01_oN8Mh00ol0003od2o@om0_d007om0_d0;o0000
2onhAkP00ol0003oebSGomLXe`03omLXe`Oo00000_nFJIH00ol0003oacS7olLha`02o`0000_ol@ka
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooH9m_of2OH02Oof
2OH01Ol0003oh1oPon0Oh?oP7n3o000000SogR7N00?o0000om0_d?o@;m001oo@;m000ol0003ojAKY
o`000002o`0000So^4Nh00?o0000omLXeooG:=L02_oG:=L5o`0000gol@ka00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooH9mP03o`000?oP7n3o000000WogR7N00?o
0000om0_d?o@;m001_o@;m000ol0003ojAKYonTFj@03onTFj@?o00001?nhAkP00ol0003oebSGomLX
e`0=omLXe`03o`000?oa3_7ol@ka00gol@ka00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_omPWf00?o0000omhQg_oN8Mh01ooN8Mh00ol0003od2o@om0_d007
om0_d003o`000?oY5^WojAKY00KojAKY0ol000000onhAkSo0000omLXe`0>omLXe`03o`000?oa3_7o
l@ka00col@ka00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooH9
mP03o`000?oN8MkogR7N00;ogR7N1_l00008om0_d003o`000?oY5^WojAKY00[ojAKY00?o0000omLX
eooG:=L03ooG:=L00ol0003ol@kaoo4>l@0:oo4>l@;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooH9mPGo00001_ob3O800ol0003od2o@om0_d005om0_d003o`000?oY5^WojAKY00[o
jAKY00?o0000omLXeooG:=L03ooG:=L00ol0003ol@kaoo4>l@07oo4>l@?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooH9mP03o`000?ob3O;olPgb00WolPgb00?o0000om0_d?o@
;m000oo@;m000ol0003ojAKYonTFj@0;onTFj@03o`000?oG:=OoebSG00ooebSG00?o0000oo4>lOoa
3_401Ooa3_42o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?omPWfo`000?l00000
3Oob3O800ol0003od2o@om0_d002om0_d003o`000?oY5^WojAKY00_ojAKY5?l00004oo4>l@;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo8=lP04o`000?o@;m3od2o@o`0000kojAKY
00?o0000oo@;m?od2o@04?od2o@00ol0003ol@kao`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_ob3O800ol0003od2o@o`00000>onTFj@03o`00
0?od2oCom0_d017om0_d00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003olPgboo8=lP0=oo8=lP03o`000?oY5^WojAKY00WojAKY1Ol0
000Boo@;m0;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003olPgboo8=lP0<oo8=lP03o`000?oY5^WojAKY00;ojAKY1ol00004oo`3o003o`000?od2oCo
m0_d00oom0_d00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?ob3O;olPgb00colPgb1?l0000<oo`3o003o`000?od2oCom0_d00com0_d0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo8=l_ob3O803?ob3O800ol0003oo0?loo`3o00=oo`3o003o`000?od2oCom0_d00_o
m0_d00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003olPgboo8=lP0:oo8=lP03o`000?ol0ocoo0?l00koo0?l00?o0000oo@;m?od
2o@02Ood2o@2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo8=l_ob3O802_ob3O800ol0003oo0?l
oo`3o00?oo`3o003o`000?od2oCom0_d00Kom0_d0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aoo`3o0?o00001_od2o@00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo0?loo`3o00>oo`3o005o`000?om0_goo@;mood2oOl000000ood2o@2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o003o`000?om0_go
o@;m00?oo@;m00?o0000oo@;m?l000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3
o007oo`3o0;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0oco
o0?l00Goo0?l00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o0?loo`3o003oo`3o003o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?ol0ocoo0?lo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool01Ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Co003o0_ooo`04o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0008o`00o`03oooo0?l00?oo003o00?o003o0_ooo`02o`00o`;oool01_l00?l2
oooo00?o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo0009o`00o`03oooo0?l00?oo003o
00?o003o00?oool0o`00ool00?l00_ooo`06o`00o`;oool00ol00?l2oooo00Go003o00?oool0o`00
ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;o
ool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?oo
o`002Ol00?l2oooo00Oo003o0_ooo`06o`00o`;oool00ol00?l00oooo`3o003oo`00o`04o`00o`03
oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l0
0ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o
0_ooo`0:o`00o`03oooo0?l00?oo003o00Go003o0_ooo`05o`00o`?oool00_l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Coool0o`00ool00?oo003o
0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool01?l00?l2oooo00_o003o
00?oool0o`00ool00?l01Ol00?l2oooo00?o003o0oooo`03o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`0<o`00o`03oooo0?l00?oo003o00Go003o00?oool0o`00ool00?l00oooo`04o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0<o`00o`;oool01ol00?l4oooo00Go003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`04o`00o`Coool01_l00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool03Ol00?l2
oooo00Co003o0oooo`02o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00
o`;oool00ol00?l3oooo00Co003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00Ko
003o00?oool0o`00ool00?l01?l00?l2oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko
003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1_l00?l2oooo01So003o0_ooo`06o`00o`;oool01Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool0
0ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_oo
o`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`04o`00o`;oool00ol0
0?l3oooo00?o003o0_ooo`06o`00o`;oool00ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool01Ol00?l6oooo00Go003o0_ooo`04o`00o`;oool01Ol00?l2oooo00;o003o0_ooo`05
o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
027o003o1?ooo`08o`00o`Goool01ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(290) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.991 .009 .991 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.992 .008 .992 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.992 .008 .992 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.99 .01 .99 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.956 .044 .956 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.989 .011 .989 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.956 .044 .956 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.951 .049 .951 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.927 .073 .927 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.985 .015 .985 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.911 .089 .911 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.991 .009 .991 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.836 .164 .836 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.847 .153 .847 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.747 .253 .747 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.888 .112 .888 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.984 .016 .984 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.986 .014 .986 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.951 .049 .951 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.555 .445 .555 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.882 .118 .882 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.752 .248 .752 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.743 .257 .743 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.799 .201 .799 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.895 .105 .895 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.93 .07 .93 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.725 .275 .725 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.871 .129 .871 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.603 .397 .603 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.918 .082 .918 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.875 .125 .875 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.799 .201 .799 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.86 .14 .86 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.668 .332 .668 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.908 .092 .908 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.753 .247 .753 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.993 .007 .993 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.933 .067 .933 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.68 .32 .68 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.353 .647 .353 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.408 .592 .408 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.961 .039 .961 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.965 .035 .965 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.847 .153 .847 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.991 .009 .991 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.706 .294 .706 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.697 .303 .697 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.446 .554 .446 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.457 .543 .457 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.271 .729 .271 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.677 .323 .677 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.735 .265 .735 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.991 .009 .991 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.714 .286 .714 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.611 .389 .611 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.944 .056 .944 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.402 .598 .402 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.883 .117 .883 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.823 .177 .823 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.444 .556 .444 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.271 .729 .271 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.553 .447 .553 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.041 .959 .041 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.074 .926 .074 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.26 .74 .26 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.392 .608 .392 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.408 .592 .408 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.878 .122 .878 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.207 .793 .207 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.233 .767 .233 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.726 .274 .726 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.95 .05 .95 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.99 .01 .99 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.206 .794 .206 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.265 .735 .265 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.52 .48 .52 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.99 .01 .99 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.681 .319 .681 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.309 .691 .309 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.436 .564 .436 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.071 .929 .071 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.441 .559 .441 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.234 .766 .234 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.95 .05 .95 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.148 .852 .148 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.027 .973 .027 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.824 .176 .824 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.083 .917 .083 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.045 .955 .045 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.556 .444 .556 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.899 .101 .899 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.256 .744 .256 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.062 .938 .062 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.432 .568 .432 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.115 .885 .115 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.171 .829 .171 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.915 .085 .915 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.051 .949 .051 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.989 .011 .989 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.15 .85 .15 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.091 .909 .091 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.731 .269 .731 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.243 .757 .243 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.988 .012 .988 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.31 .69 .31 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.112 .888 .112 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.134 .866 .134 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.19 .81 .19 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.069 .931 .069 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.033 .967 .033 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.285 .715 .285 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.545 .455 .545 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.99 .01 .99 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.773 .227 .773 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.205 .795 .205 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.288 .712 .288 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.279 .721 .279 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.952 .048 .952 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.093 .907 .093 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.029 .971 .029 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.223 .777 .223 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.611 .389 .611 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.032 .968 .032 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.991 .009 .991 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.099 .901 .099 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.848 .152 .848 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.958 .042 .958 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.557 .443 .557 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.601 .399 .601 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.153 .847 .153 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.888 .112 .888 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.067 .933 .067 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.294 .706 .294 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.516 .484 .516 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.106 .894 .106 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.254 .746 .254 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.372 .628 .372 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.99 .01 .99 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.014 .986 .014 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.99 .01 .99 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.927 .073 .927 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.242 .758 .242 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.2 .8 .2 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.067 .933 .067 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.79 .21 .79 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.199 .801 .199 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.945 .055 .945 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.25 .75 .25 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.274 .726 .274 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.282 .718 .282 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.6 .4 .6 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.749 .251 .749 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.537 .463 .537 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.064 .936 .064 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.124 .876 .124 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.221 .779 .221 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.508 .492 .508 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.813 .187 .813 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.99 .01 .99 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.939 .061 .939 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.204 .796 .204 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.288 .712 .288 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.236 .764 .236 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.817 .183 .817 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.677 .323 .677 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.99 .01 .99 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.523 .477 .523 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.851 .149 .851 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.944 .056 .944 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.147 .853 .147 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.25 .75 .25 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.93 .07 .93 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.198 .802 .198 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.609 .391 .609 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.578 .422 .578 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.433 .567 .433 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.4 .6 .4 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.876 .124 .876 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.811 .189 .811 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.818 .182 .818 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.864 .136 .864 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.364 .636 .364 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.957 .043 .957 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.782 .218 .782 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.381 .619 .381 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.4 .6 .4 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.674 .326 .674 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.475 .525 .475 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.989 .011 .989 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.949 .051 .949 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.833 .167 .833 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.945 .055 .945 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.374 .626 .374 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.922 .078 .922 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.763 .237 .763 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.67 .33 .67 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.991 .009 .991 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.646 .354 .646 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.524 .476 .524 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.991 .009 .991 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.742 .258 .742 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.986 .014 .986 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.992 .008 .992 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.576 .424 .576 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.988 .012 .988 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.586 .414 .586 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.989 .011 .989 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.713 .287 .713 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.856 .144 .856 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.755 .245 .755 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.9 .1 .9 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.92 .08 .92 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.787 .213 .787 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.651 .349 .651 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.773 .227 .773 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.871 .129 .871 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.919 .081 .919 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.885 .115 .885 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.897 .103 .897 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.986 .014 .986 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.795 .205 .795 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.945 .055 .945 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.988 .012 .988 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.958 .042 .958 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.938 .062 .938 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.806 .194 .806 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.949 .051 .949 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.922 .078 .922 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.875 .125 .875 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.934 .066 .934 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.99 .01 .99 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.989 .011 .989 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.989 .011 .989 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.988 .012 .988 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.99 .01 .99 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?ol
0o`4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo0?loo`3o00=oo`3o005o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003ol0o`oo0?l?l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?ol0o`03ool0o`00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo0?l?o`3o000_o`3o000ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?ol0ocoo0?l00koo0?l00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?o`3o3ol0o`00?ol0o`00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo0?l?o`3o001Oo`3o000ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo0?loo`3o00>oo`3o003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l006oo0?l003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?ol0o`00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oc3??o0000013oo0?l00?o0000ood2oOom0_d02?om
0_d9o`0000col0o`00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?ol0ocoo0?l00ooo0?l
00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003oo<<l`03o`000?ol
0ocoo0?l00coo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003okA;]ondBk@05ondBk@03o`000?o`
3o3ol0o`00_ol0o`0ol00003onhAkP03o`000?om0_goo@;m00coo@;m0ol0000>oo`3o0;o00003Ool
0o`2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
oo<<looc3?<00ooc3?<00ol0003oo0?loo`3o00;oo`3o0;o00002oom0_d00ol0003okA;]ondBk@06
ondBk@03o`000?o`3o3ol0o`00[ol0o`00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oo@;mood2o@0:
ood2o@04o`000?o/4ncok1?/on`Ck0;o00002_ol0o`2o`000003on/Djol0003oo0?l00koo0?l00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?ol0oco
o0?l00Woo0?l00?o0000oo<<lol000002oom0_d00ol0003okA;]ondBk@06ondBk@03o`000?o`3o3o
l0o`00Wol0o`00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oo@;mood2o@08ood2o@03o`000?o/4nco
k1?/00Cok1?/0_l00005oo`3o0?o00001?o[5>/00ol0003oo0?loo`3o00=oo`3o003o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008oo<<l`03o`000?ol0ocoo0?l00Ooo0?l0_l00003oo<<
l`03o`000?om0_goo@;m00Ooo@;m00?o0000ondBkOo]4^d01oo]4^d00ol0003ol0o`oo0?l009oo0?
l003o`000?o^4NkokQ7^00OokQ7^00?o0000ood2oOom0_d01Oom0_d2o`0000Wok1?/0_l000000ool
0oco0000o`000007on/Dj`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000oo<<looc
3?<02?oc3?<00ol0003oo0?loo`3o006oo`3o003o`000?oc3??ol`cc00?ol`cc00?o0000ood2oOom
0_d01oom0_d00ol0003okA;]ondBk@08ondBk@03o`000?o`3o3ol0o`00Ool0o`00?o0000onhAk_o^
4Nh02Oo^4Nh00ol0003oo@;mood2o@03ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000on/Djoo[
5>/01oo[5>/00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ol@kao`000005ood2o@;o00002ooc3?<2o`0000Koo0?l
00?o0000oo<<looc3?<01Ooc3?<00ol0003oo@;mood2o@06ood2o@03o`000?o]4^gokA;]00SokA;]
00?o0000oo0?l?o`3o001_o`3o000ol0003okQ7^onhAkP0;onhAkP05o`000?om0_goo@;mood2oOl0
00003_o/4n`00ol0003ojaC[on/Dj`08on/Dj`03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?oa3_7ol@kaoo4>lOl0
00000oom0_d00ol0003ol`ccoo<<l`0:oo<<l`04o`000?oV6NKoiQWVo`0000?oo0?l0_l00008oo<<
l`03o`000?om0_goo@;m00Koo@;m00?o0000ondBkOo]4^d02Oo]4^d00ol0003ol0o`oo0?l005oo0?
l003o`000?o^4NkokQ7^00cokQ7^00?o0000ood2oOl000003oo/4n`00ol0003ojaC[on/Dj`08on/D
j`03o`000?ol0ocoo0?l00koo0?l00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@03oo4>l@03o`000?om0_go000000_o
l`cc0_l00004onHIiP03o`000?ol0oco000000_ol`cc00?o0000ood2oOom0_d01Oom0_d00ol0003o
kA;]ondBk@09ondBk@03o`000?o`3o3ol0o`00Col0o`00?o0000onhAk_o^4Nh03_o^4Nh00ol0003o
k1?/on`Ck00>on`Ck003o`000?o[5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo4>lOoa3_40
1?oa3_400ol0003ol`ccoo<<l`09oo<<l`03o`000?oV6NKoiQWV00GoiQWV00?o0000oo<<looc3?<0
2_oc3?<00ol0003oo@;mood2o@05ood2o@03o`000?o]4^gokA;]00[okA;]00?o0000oo0?l?o`3o00
0oo`3o000ol0003okQ7^onhAkP0>onhAkP03o`000?o/4ncok1?/00gok1?/00?o0000on/Djoo[5>/0
2_o[5>/00ol0003oo0?loo`3o00>oo`3o003o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>
l@05oo4>l@03o`000?oc3??ol`cc00Ool`cc0_l00008onHIiP03o`000?oc3??ol`cc00_ol`cc00?o
0000ood2oOom0_d01?om0_d00ol0003okA;]ondBk@0:ondBk@04o`000?o`3o3ol0o`oo0?l0?o0000
3oo^4Nh00ol0003ok1?/on`Ck00>on`Ck003o`000?o[5>_ojaC[00[ojaC[00?o0000oo`3o?ol0o`0
3ool0o`3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?oa3_7ol@ka00Ool@ka00?o0000oo<<looc3?<01?oc3?<2o`0000_oiQWV1?l0
0009oo<<l`03o`000?om0_goo@;m00?oo@;m00?o0000ondBkOo]4^d02oo]4^d01?l0003ol0o`o`00
0?l00003om4^d@;o00003?o^4Nh2o`00013ok1?/00?o0000on/Djoo[5>/02oo[5>/00ol0003oo0?l
oo`3o00=oo`3o004o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ol@ka
oo4>l@07oo4>l@03o`000?oc3??ol`cc00?ol`cc00?o0000onHIi_oV6NH02ooV6NH01?l0003oaC[5
olDjaOo5>/D5o`0000Gol`cc00?o0000ood2oOom0_d00_om0_d00ol0003okA;]ondBk@0<ondBk@03
o`000?oA;]7odBkA00GodBkA0_l00008onhAkP;o00000_o8=lP00ol0003ok1?/on`Ck00=on`Ck003
o`000?o[5>_ojaC[00_ojaC[00?o0000oo`3o?ol0o`03?ol0o`00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ood2oOom0_d00_om0_d3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ol@kaoo4>l@09oo4>l@03o`000?oc3??ol`cc00;o0000
3OoV6NH00ol0003oaC[5olDja@07olDja@Ko00000_om0_d4o`0000gokA;]00?o0000om4^dOoA;]40
1ooA;]42o`0000GokQ7^00?o0000olPgb?o8=lP00oo8=lP00ol0003ok1?/on`Ck00<on`Ck003o`00
0?o[5>_ojaC[00cojaC[00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?oa3_7ol@ka00Wol@ka00?o
0000oo<<lol000003ooV6NH00ol0003oaC[5olDja@0<olDja@?o00001?oS7><3o`0000WokA;]00?o
0000om4^dOoA;]402_oA;]42o`000003onhAk_l0003o000000Oob3O800?o0000on`Ck?o/4n`02oo/
4n`00ol0003ojaC[on/Dj`0<on/Dj`03o`000?ol0ocoo0?l00Koo0?l1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?om0_goo@;m00Koo@;m00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000
onHIi_oV6NH03_oV6NH00ol0003oaC[5olDja@0=olDja@03o`000?oS7>?ohacS00KohacS0ol00005
ondBk@03o`000?oA;]7odBkA00godBkA00?o0000olPgb?o8=lP02?o8=lP00ol0003ok1?/on`Ck009
on`Ck003o`000?o[5>_ojaC[00gojaC[00Co0000oo`3o?ol0ocoo0?l1Ol00003oo0?l003o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo4>lOoa3_402ooa3_42o`0000ooiQWV00?o0000olDjaOo5>/D03Oo5>/D00ol0003ohacSon<Lh`0:
on<Lh`?o000000?okA;]o`000?oA;]403ooA;]400ol0003ob3O8olPgb009olPgb003o`000?o/4nco
k1?/00Sok1?/00?o0000on/Djoo[5>/03_o[5>/3o`0000Sol0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?oa3_7ol@ka00Sol@ka0ol000000ooB
;M;o0000onHIiP0>onHIiP03o`000?o5>/GoaC[500goaC[500?o0000on<LhooS7><03OoS7><00ol0
003odBkAom4^d@0?om4^d@03o`000?o8=lSob3O800[ob3O82ol0000;on/Dj`Go00003?o`3o000ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d01Ol0003okQ7^o`000?om0_go0000
00Sol@ka0ol00005om8]dP03o`000?oV6NKoiQWV00coiQWV00?o0000olDjaOo5>/D03Oo5>/D00ol0
003ohacSon<Lh`0=on<Lh`;o00004?oA;]400ol0003ob3O8olPgb00:olPgb003o`000?o3?<?o`cc3
00Oo`cc300?o0000on/Djoo[5>/00_o[5>/7o`0000CobCK900?o0000oo0?l?o`3o002_o`3o000ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02Oom0_d01?l0003okQ7^onhAk_o^4Nh2o`00
00Gol@ka0ol00009om8]dP;o00002ooV6NH00ol0003oaC[5olDja@0=olDja@03o`000?oS7>?ohacS
00gohacS00Co0000okm0_ono@;oo00003ooA;]400ol0003ob3O8olPgb009olPgb003o`000?o3?<?o
`cc300Wo`cc31?l0000;olTfb@03o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Soo@;m00?o0000onhAk_o^4Nh01?o^4Nh00ol0003ol@kao`000002o`00
00codRgB00Co0000ojiA[_l0003o00002OoV6NH00ol0003oaC[5olDja@0=olDja@03o`000?oS7>?o
hacS00gohacS00Go0000okm0_ono@;oo_d2oo`00000=om4^d@03o`000?o8=lSob3O800[ob3O800?o
0000ol<l`oo3?<<02Oo3?<<00ol0003obCK9olTfb@0<olTfb@03o`000?o`3o3ol0o`00[ol0o`00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000onhAk_o^4Nh01_o^4Nh0
0ol0003odRgBom8]dP0<om8]dP03o`000?n^DJko[U6^00;o[U6^0_l00007onHIiP03o`000?o5>/Go
aC[500coaC[500?o0000on<LhooS7><03OoS7><00ol0003o_d2ookm0_`03okm0_`03o`000?oA;]7o
dBkA00[odBkA00?o0000olPgb?o8=lP02_o8=lP00ol0003o`cc3ol<l``09ol<l``03o`000?o9=/Wo
bCK900cobCK900?o0000oo0?l?o`3o002oo`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2
oOom0_d01_om0_d00ol0003okQ7^onhAkP06onhAkP03o`000?oB;M;odRgB00_odRgB00?o0000ojiA
[_n^DJh01On^DJh00ol0003oiQWVonHIiP03onHIiP03o`000?o5>/GoaC[500goaC[500?o0000on<L
hooS7><03OoS7><00ol0003o_d2ookm0_`04okm0_`03o`000?oA;]7odBkA00WodBkA00?o0000olPg
b?o8=lP02Oo8=lP00ol0003o`cc3ol<l``0:ol<l``03o`000?o9=/WobCK900cobCK900?o0000oo0?
l?o`3o002oo`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01Oom0_d00ol0003o
kQ7^onhAkP07onhAkP03o`000?oB;M;odRgB00_odRgB00?o0000ojiA[_n^DJh01_n^DJh2o`0000?o
iQWV00?o0000olDjaOo5>/D03Oo5>/D00ol0003ohacSon<Lh`0<on<Lh`03o`000?no@;oo_d2o00Ko
_d2o00?o0000om4^dOoA;]402?oA;]400ol0003ob3O8olPgb009olPgb003o`000?o3?<?o`cc300[o
`cc300?o0000olTfbOo9=/T03?o9=/T00ol0003ol0o`oo0?l00;oo0?l003o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ood2o@03o`00
0?om0_goo@;m00Coo@;m00?o0000onhAk_o^4Nh02?o^4Nh00ol0003odRgBom8]dP0:om8]dP03o`00
0?n^DJko[U6^00Wo[U6^0_l000000ooV6NKo0000olDja@0<olDja@?o00003_oS7><00ol0003o_d2o
okm0_`07okm0_`03o`000?oA;]7odBkA00OodBkA00?o0000olPgb?o8=lP02Oo8=lP00ol0003o`cc3
ol<l``0;ol<l``03o`000?o9=/WobCK900cobCK900?o0000oo0?l?o`3o002_o`3o000ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000onhAk_o^4Nh02_o^4Nh00ol0003odRgBom8]
dP09om8]dP03o`000?n^DJko[U6^00_o[U6^00?o0000olDjaOo5>/D02_o5>/D2o`0000?oW6>L00?o
0000on<LhooS7><02_oS7><00ol0003o_d2ookm0_`09okm0_`03o`000?oA;]7odBkA00KodBkA00?o
0000olPgb?o8=lP02?o8=lP00ol0003o`cc3ol<l``0<ol<l``03o`000?o9=/WobCK900cobCK900?o
0000oo0?l?o`3o002_o`3o000ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oom0_d0
0ol0003oo@;mood2o@02ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000om8]d_oB;M802?oB;M80
0ol0003o[U6^ojiA[P0<ojiA[P03o`000?o5>/GoaC[500SoaC[50_l00006oiaSW0;o00002_oS7><0
0ol0003o_d2ookm0_`0:okm0_`03o`000?oA;]7odBkA00GodBkA00?o0000olPgb?o8=lP02?o8=lP0
0ol0003o`cc3ol<l``0<ol<l``03o`000?o9=/WobCK900cobCK900?o0000oo0?l?o`3o002oo`3o00
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?oo@;m00Go0000ood2oOom0_goo@;mo`00000=
onhAkP03o`000?oB;M;odRgB00OodRgB00?o0000ojiA[_n^DJh03_n^DJh00ol0003oaC[5olDja@04
olDja@?o00002_nLHi`00ol0003ohacSon<Lh`07on<Lh`03o`000?no@;oo_d2o00_o_d2o00?o0000
om4^dOoA;]400ooA;]400ol0003ob3O8olPgb009olPgb003o`000?o3?<?o`cc300co`cc300?o0000
olTfbOo9=/T03?o9=/T00ol0003ol0o`oo0?l00;oo0?l0;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003okQ7^onhAkP0<onhAkP03o`000?oB;M;odRgB00OodRgB00?o0000ojiA[_n^DJh03on^DJh01?l0
003oaC[5olDjaOo5>/D2o`0000koW6>L0_l00006on<Lh`03o`000?no@;oo_d2o00go_d2o00?o0000
om4^dOoA;]400_oA;]400ol0003ob3O8olPgb008olPgb003o`000?o3?<?o`cc300co`cc30ol0000=
olTfb@03o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ookQ7^00?o0000om8]d_oB;M801_oB;M800ol0003o[U6^ojiA[P0@ojiA[PCo00004_nLHi`00ol0
003ohacSon<Lh`03on<Lh`03o`000?no@;oo_d2o00ko_d2o00Go0000om4^dOoA;]7odBkAo`000005
olPgb0Oo00003?o3?<<01Ol0003oUVVFoiIYU_nFJIKo000000cobCK900?o0000oo0?l?o`3o002?o`
3o03o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ookQ7^00?o0000om8]d_oB;M801_oB;M800ol0003o[U6^ojiA[P0=
ojiA[P?o000000CoL8m`o`000?l0003o00004onLHi`2o`0000;ohacS00?o0000okm0_ono@;l04?no
@;l00ol0003odBkAo`000006o`0000Oo[5>/00?o0000ol<l`oo3?<<02?o3?<<00ol0003oUVVFoiIY
UP03oiIYUP;o00002?o9=/T3o`0000Kol0o`1?l00002on`Ck003o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003ol`cco`000?o<<l`3o`0000gokQ7^00?o0000om8]d_oB;M801?oB;M800ol0003o[U6^ojiA
[P0;ojiA[P?o00000om`Sg001Ol0003oKY5^o`000?m?/4oo000001CoW6>L00?o0000on<Lhol00000
4ono@;l00ol0003o[5>/ojaC[00=ojaC[003o`000?o3?<?o`cc300Go`cc30_l00008oiIYUP03o`00
0?o9=/WobCK900Go00000oo5>/D00ol0003ol0o`oo0?l003o`0000Ook1?/00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?oc3??ol`cco`0000Coc3?<0ol0000:onhAkP03o`000?oB;M;odRgB00?odRgB
00?o0000ojiA[_n^DJh02On^DJh3o`0000GoL8m`00Co0000ofjAK_m^TFko00000_m?/4l00ol0003o
W6>LoiaSW00BoiaSW003o`000?no@;oo_d2o01;o_d2o00?o0000ojaC[?n/Dj`03_n/Dj`00ol0003o
`cc3ol<l``03ol<l``03o`000?nFJIKoUVVF00WoUVVF0_l00009olDja@;o00002_o/4n`00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo<<looc3??ol`cco`000007ol`cc0;o00001oo^4Nh5o`0000;o
dRgB00?o0000ojiA[_n^DJh01_n^DJh3o`0000SoL8m`00Co0000ofjAK_m^TFko00000om?/4l00ol0
003oW6>LoiaSW00AoiaSW003o`000?no@;oo_d2o017o_d2o00?o0000ojaC[?n/Dj`04?n/Dj`01Ol0
003o`cc3ol<l`oo3?<?o000000coUVVF00?o0000olDjaOo5>/D02?o5>/D00ol0003ok1?/on`Ck00:
on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Col`cc00?o0000ol`cc?o<<l`01oo<<l`3o`00
0004onhAk_l0003o0000o`0000Go]TVf0_l00006ojiA[P?o00002_m`Sg001Ol0003oKY5^ofjAK_m^
TFko000000CoCk1?00?o0000oiaSW?nLHi`04?nLHi`00ol0003o_d2ookm0_`0Aokm0_`03o`000?n/
Djco[5>/017o[5>/00?o0000ol<l`ol000003OnFJIH00ol0003oaC[5olDja@08olDja@03o`000?o/
4ncok1?/00[ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00Col`cc00?o0000
ol`cc?o<<l`02_o<<l`00ol0003o]TVfokI9]P08okI9]P03o`000?n^DJko[U6^00?o00003Om`Sg00
1Ol0003oKY5^ofjAK_m^TFko000000GoCk1?00?o0000oiaSW?nLHi`03onLHi`00ol0003o_d2ookm0
_`0Aokm0_`03o`000?n/Djco[5>/01;o[5>/00?o0000oiIYU_nFJIH03?nFJIH00ol0003oaC[5olDj
a@08olDja@03o`000?o/4ncok1?/00_ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo<<looc3?<01Ooc3?<0
0ol0003oc3?<ol`cc00:ol`cc003o`000?nfBKKo]TVf00Wo]TVf0_l0000?og2?L003o`000?m^TFko
KY5^00;oKY5^00?o0000odn`Com?/4l01?m?/4l00ol0003oW6>LoiaSW00=oiaSW0?o00004Ono@;l0
0ol0003o[5>/ojaC[00CojaC[003o`000?nFJIKoUVVF00_oUVVF00?o0000olDjaOo5>/D02Oo5>/D0
0ol0003ok1?/on`Ck00;on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?oc3?<0
0ol0003oc3?<ol`cc00:ol`cc003o`000?nfBKKo]TVf00Wo]TVf00?o0000og2?L?m`Sg003Om`Sg00
0ol0003oKY5^ofjAKP03ofjAKP03o`000?m?/4ooCk1?00GoCk1?00?o0000oiaSW?nLHi`02_nLHi`2
o`0000?oQ7^400?o0000okm0_ono@;l03_no@;l00ol0003o[5>/ojaC[00CojaC[003o`000?nFJIKo
UVVF00_oUVVF00?o0000olDjaOo5>/D02Oo5>/D00ol0003ok1?/on`Ck00;on`Ck003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000oo<<looc3?<01ooc3?<2o`0000_oc3?<00?o0000okI9
]_nfBKH02onfBKH00ol0003oL8m`og2?L00<og2?L003o`000?m^TFkoKY5^00?oKY5^00?o0000odn`
Com?/4l01_m?/4l00ol0003oW6>LoiaSW007oiaSW0;o00001_n4Nh@2o`0000ko_d2o00?o0000ojaC
[?n/Dj`04on/Dj`00ol0003oUVVFoiIYUP0;oiIYUP03o`000?o5>/GoaC[500WoaC[500?o0000on`C
k?o/4n`03?o/4n`00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009oo<<
l`03o`000?oQ7^7o000000_oc3?<00?o0000okI9]_nfBKH02onfBKH00ol0003oL8m`og2?L00;og2?
L003o`000?m^TFkoKY5^00CoKY5^00?o0000odn`Com?/4l01om?/4l00ol0003oW6>LoiaSW005oiaS
W003o`000?n4NhCoQ7^400SoQ7^400?o0000okm0_ono@;l02_no@;l00ol0003o[5>/ojaC[00DojaC
[003o`000?nFJIKoUVVF00_oUVVF00?o0000olDjaOo5>/D02Oo5>/D00ol0003ok1?/on`Ck00<on`C
k003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009oo<<l`04o`000?oQ7^7ohAkQo`00
00_oc3?<00?o0000okI9]_nfBKH02onfBKH00ol0003oL8m`og2?L00;og2?L003o`000?m^TFkoKY5^
00CoKY5^00?o0000odn`Com?/4l02?m?/4l00ol0003oW6>LoiaSW002oiaSW0;o00003?n4Nh@2o`00
00[o_d2o00?o0000ojaC[?n/Dj`05?n/Dj`00ol0003oUVVFoiIYUP0;oiIYUP03o`000?o5>/GoaC[5
00WoaC[500?o0000on`Ck?o/4n`03Oo/4n`00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`07oo<<l`03
o`000?oQ7^7ohAkQ00;ohAkQ00?o0000ol`cc?o<<l`02?o<<l`00ol0003o]TVfokI9]P0<okI9]P03
o`000?m`Sg3oL8m`00WoL8m`00?o0000ofjAK_m^TFh01Om^TFh00ol0003oCk1?odn`C`09odn`C`04
o`000?nLHico0000o`00013oQ7^40_l00008okm0_`03o`000?n/Djco[5>/01Co[5>/0ol0000;oiIY
UP03o`000?o5>/GoaC[500WoaC[500?o0000on`Ck?o/4n`03Oo/4n`01?l0003oo@;mood2oOom0_d5
o`0000?oo0?l00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003ol`ccoo<<l`06oo<<l`03o`000?oQ7^7ohAkQ00?ohAkQ00?o0000ol`c
c?o<<l`02?o<<l`00ol0003o]TVfokI9]P0;okI9]P;o00002_m`Sg000ol0003oKY5^ofjAKP06ofjA
KP03o`000?m?/4ooCk1?00[oCk1?00?o0000ohAkQ?n4Nh@04_n4Nh@00ol0003o_d2ookm0_`04okm0
_`03o`000?n/Djco[5>/01Go[5>/00?o0000oi=/TonCK9<01Ol00005oiIYUP03o`000?o5>/GoaC[5
00[oaC[500?o0000on`Ck?o/4n`03_o/4n`3o`0000Woo0?l00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<l`04oo<<l`03
o`000?oQ7^7ohAkQ00CohAkQ00?o0000ol`cc?o<<l`01oo<<l`00ol0003o]TVfokI9]P0;okI9]P04
o`000?maSW7oLHiao`0000WoL8m`00?o0000ofjAK_m^TFh01_m^TFh00ol0003oCk1?odn`C`0:odn`
C`03o`000?n4NhCoQ7^401?oQ7^40_l00003okm0_`Co00005?n/Dj`00ol0003oTfbCoi=/T`06oi=/
T`Co000000?oUVVFo`000?o5>/D02oo5>/D00ol0003ok1?/on`Ck00>on`Ck003o`000?ol0ocoo0?l
00[oo0?l00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003ol`ccoo<<l`03oo<<l`03o`000?oQ7^7ohAkQ00GohAkQ00?o0000ol`cc?o<
<l`01oo<<l`00ol0003o]TVfokI9]P09okI9]P;o00001?maSW400ol0003oL8m`og2?L005og2?L003
o`000?m^TFkoKY5^00OoKY5^00?o0000odn`Com?/4l02_m?/4l00ol0003oQ7^4ohAkQ00EohAkQ003
o`000?no@;oo000000CoTfbC0ol0000@ojaC[003o`000?nCK9?oTfbC00_oTfbC0_l0000<olDja@03
o`000?o/4ncok1?/00cok1?/0_l0000>oo`3o003o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo<<looc3?<00_oc3?<00ol0003ohAkQ
on4Nh@06on4Nh@03o`000?o<<lcoc3?<00Ooc3?<00?o0000okI9]_nfBKH02?nfBKH00ol0003oLHia
og6>L@05og6>L@03o`000?m`Sg3oL8m`00CoL8m`00?o0000ofjAK_m^TFh01om^TFh00ol0003oCk1?
odn`C`0:odn`C`03o`000?n4NhCoQ7^401KoQ7^400?o0000oi=/TonCK9<01_nCK9<3o`0000co[5>/
00?o0000oi=/TonCK9<03OnCK9<00ol0003oaC[5olDja@09olDja@Go00002Oo/4n`2o`000003onl@
kol0003oo0?l00koo0?l00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003oo<<lol0003ohAkQ00WohAkQ00?o0000ol`cc?o<<l`01_o<
<l`00ol0003o]TVfokI9]P07okI9]P03o`000?maSW7oLHia00OoLHia00?o0000og2?L?m`Sg000_m`
Sg000ol0003oKY5^ofjAKP08ofjAKP03o`000?m?/4ooCk1?00WoCk1?00?o0000ohAkQ?n4Nh@05on4
Nh@00ol0003oTfbCoi=/T`09oi=/T`?o00002On/Dj`00ol0003oTfbCoi=/T`0>oi=/T`Ko00001?o5
>/D00ol0003ocS7>olhacP03olhacPGo00000_o/4n`2o`0000Coka3_00?o0000oo`3o?ol0o`03?ol
0o`00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?oY5^WojAKYonTFjOl000002ooQ7^400ol0003oc3?<ol`cc006ol`cc003o`000?nf
BKKo]TVf00Go]TVf0_l0000;og6>L@04o`000?m`Sg3oL8m`o`0000_oKY5^00?o0000odn`Com?/4l0
2Om?/4l00ol0003oQ7^4ohAkQ00FohAkQ003o`000?nCK9?oTfbC00goTfbC0ol00005ojaC[003o`00
0?nCK9?oTfbC00ooTfbC00?o0000ojIIY_nVFJH00onVFJH4o`0000_ocS7>0_l00006onl@k`03o`00
0?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ojAKYonTFj@02onTFj@ko00001_o<<l`00ol0003o]TVfokI9
]P05okI9]P03o`000?maSW7oLHia00coLHia00?o0000og2?L?l000002om^TFh00ol0003oCk1?odn`
C`07odn`C`?o00006?n4Nh@00ol0003oTfbCoi=/T`0@oi=/T`?o000000?o[5>/o`000?nCK9<04?nC
K9<00ol0003oYUVVojIIYP07ojIIYP03o`000?o><LkocS7>00[ocS7>00?o0000onl@koo_4>l01Oo_
4>l00ol0003oo0?loo`3o00;oo`3o003o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005onTFj@03o`000?o0?l3o`3o000_o`3o00_l00004
ol`cc003o`000?nfBKKo]TVf00?o]TVf0_l0000@og6>L@03o`000?m^TFkoKY5^00[oKY5^00?o0000
odn`Com?/4l00om?/4l4o`0000;o=</d00?o0000ohAkQ?n4Nh@05On4Nh@00ol0003oTfbCoi=/T`0D
oi=/T`03o`000?nCK9?oTfbC013oTfbC00?o0000ojIIY_nVFJH01onVFJH00ol0003ocS7>olhacP0:
olhacP03o`000?o_4>ooka3_00Goka3_00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oY5^WojAKY
00GojAKY00?o0000ol0o`?o0?l003Oo0?l06o`0000?o]TVf00?o0000og6>LOmaSW404?maSW400ol0
003oKY5^ofjAKP0:ofjAKP03o`000?m?/4oo000000?o00001oldbc@00ol0003oQ7^4ohAkQ00DohAk
Q003o`000?nCK9?oTfbC01CoTfbC00?o0000oi=/TonCK9<03onCK9<00ol0003oYUVVojIIYP08ojII
YP03o`000?o><LkocS7>00[ocS7>00?o0000onl@koo_4>l01Oo_4>l00ol0003oo0?loo`3o00<oo`3
o003o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onTFjOoY5^T01_oY5^T00ol0003o`3o0ol0o`00=ol0o`003o`000?n[E:_oZeB[00?o
ZeB[00?o0000okI9]_l000004omaSW44o`0000WoKY5^0_l0000<ocC;=003o`000?n4NhCoQ7^401?o
Q7^400?o0000oi=/TonCK9<05OnCK9<00ol0003oTfbCoi=/T`0>oi=/T`03o`000?nVFJKoYUVV00So
YUVV00?o0000olhac_o><Lh02Oo><Lh00ol0003oka3_onl@k`07onl@k`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?oY5^WojAKY00SojAKY00?o0000ol0o`?o0?l002oo0?l000ol0003oZeB[oj]DZ`05oj]DZ`03o`00
0?maSW7oLHia01;oLHia00Co0000od6n@Om1_T7o@Ki11Ol00003ofjAKP03o`000?ldbcCo=</d00go
=</d0ol0000@ohAkQ0;o00006?nCK9<00ol0003oTfbCoi=/T`0=oi=/T`03o`000?nVFJKoYUVV00Wo
YUVV00?o0000olhac_o><Lh02Oo><Lh00ol0003oka3_onl@k`07onl@k`03o`000?ol0ocoo0?l00_o
o0?l00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ojAKY00?o0000ol0o`?o0?l002_o0?l000ol0003oZeB[oj]DZ`06oj]DZ`03o`00
0?maSW7oLHia017oLHia00?o0000od6n@Om1_T401om1_T43o`00013o=</d00?o0000obOH9olWf2L0
1Ol00009ohAkQ0;o000000?o?kloo`000?nCK9<05onCK9<00ol0003oTfbCoi=/T`0=oi=/T`03o`00
0?nVFJKoYUVV00WoYUVV00?o0000olhac_o><Lh02?o><Lh2o`0000[oka3_00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?od2oCom0_d00;om0_d00?o0000onTFjOoY5^T02OoY5^T00ol0003o`3o0ol0o
`00:ol0o`003o`000?n[E:_oZeB[00OoZeB[00?o0000og6>LOmaSW403omaSW400ol0003o@Ki1od6n
@@0:od6n@@03o`000?ldbcCo=</d00go=</d00?o0000obOH9olWf2L01_lWf2L4o`0000CoQ7^400?o
0000ocno?olo_cl00_lo_cl00ol0003oTfbCoi=/T`0Foi=/T`03o`000?nCK9?oTfbC00_oTfbC00?o
0000ojIIY_nVFJH02onVFJH00ol0003ocS7>olhacP06olhacP03o`000?oO7moo000000[oka3_00?o
0000oo`3o?ol0o`02_ol0o`00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?od2oCom0_d00?om0_d00?o0000onTFjOoY5^T02?oY5^T=
o`0000[oZeB[00?o0000og6>LOmaSW403omaSW400ol0003o@Ki1od6n@@0;od6n@@03o`000?ldbcCo
=</d00co=</d00?o0000obOH9olWf2L02_lWf2L4o`0000Go?klo00?o0000oi=/TonCK9<05_nCK9<0
0ol0003oTfbCoi=/T`0:oi=/T`03o`000?nVFJKoYUVV00coYUVV00?o0000olhac_o><Lh01?o><Lh2
o`0000?ogaoO00?o0000onl@koo_4>l02?o_4>l00ol0003oo0?loo`3o008oo`3o003o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo@;
m?od2o@00ood2o@00ol0003ojAKYonTFj@07onTFj@03o`000?nn@Kko_T6n00Wo_T6n00?o0000oj]D
Zon[E:/02On[E:/00ol0003oLHiaog6>L@0=og6>L@03o`000?m1_T7o@Ki100co@Ki100?o0000ocC;
=?ldbc@03?ldbc@00ol0003o9mPWobOH9`0;obOH9`03o`000?lAkQ7o000000Ko?klo00?o0000oi=/
TonCK9<05_nCK9<00ol0003oTfbCoi=/T`09oi=/T`03o`000?nVFJKoYUVV00coYUVV00?o0000olha
c_o><Lh00oo><Lh00ol0003ogaoOomlOg`03omlOg`03o`000?o_4>ooka3_00Soka3_00?o0000oo`3
o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?od2oCom0_d00Com0_d00?o0000onTFjOoY5^T01_oY5^T00ol0003o
_T6noki1_P08oki1_P03o`000?n[E:_oZeB[00_oZeB[00?o0000og6>LOmaSW402?maSW44o`0000oo
@Ki100?o0000ocC;=?ldbc@02oldbc@00ol0003o9mPWobOH9`0;obOH9`04o`000?lAkQ7o4NhAo`00
00Oo?klo00?o0000oi=/TonCK9<05OnCK9<00ol0003oTfbCoi=/T`08oi=/T`03o`000?nVFJKoYUVV
00goYUVV00?o0000olhac_o><Lh00_o><Lh00ol0003ogaoOomlOg`05omlOg`03o`000?o_4>ooka3_
00Ooka3_00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000onTFjOoY
5^T01OoY5^T00ol0003o_T6noki1_P08oki1_P03o`000?n[E:_oZeB[00_oZeB[00?o0000og6>LOma
SW400omaSW45o`0000?o@[e200?o0000od6n@Om1_T403_m1_T400ol0003o=</docC;=00:ocC;=003
o`000?lWf2Oo9mPW00[o9mPW00Go0000oa7^4OlAkQ7o4NhAo`000007ocno?`03o`000?nCK9?oTfbC
01GoTfbC00?o0000oi=/TonCK9<02?nCK9<00ol0003oYUVVojIIYP0=ojIIYP03o`000?o><LkocS7>
00;o00002?oO7ml00ol0003oka3_onl@k`08onl@k`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003om0_doo@;m005oo@;m003o`000?oY5^WojAKY00Go
jAKY00?o0000oki1__nn@Kh02?nn@Kh00ol0003oZeB[oj]DZ`0<oj]DZ`Go00002Om2_D800ol0003o
@Ki1od6n@@0<od6n@@;o00003?ldbc@00ol0003o9mPWobOH9`0:obOH9`05o`000?lAkQ7o4NhAoa7^
4Ol000002?lo_cl00ol0003oTfbCoi=/T`0Doi=/T`?o00001onCK9<00ol0003oYUVVojIIYP0>ojII
YP03o`000?o><Lko000000_ogaoO00?o0000onl@koo_4>l01_o_4>l00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000oo@;m?od2o@01Ood2o@00ol0003ojAKYonTFj@04onTFj@03o`000?nn@Kko_T6n00Oo
_T6n00?o0000oj]DZon[E:/03?n[E:/01?l0003oLXebog:=L_l0000;od:m@P03o`000?m1_T7o@Ki1
00_o@Ki100Co0000o`gb3Ol=lPgo00002_ldbc@00ol0003o9mPWobOH9`0:obOH9`03o`000?lAkQ7o
4NhA00;o4NhA00?o0000ocno?olo_cl01_lo_cl00ol0003oTfbCoi=/T`0Aoi=/T`?o00000omQWV40
0ol0003oTfbCoi=/T`04oi=/T`03o`000?nVFJKoYUVV00goYUVV1?l0000;omlOg`03o`000?o_4>oo
ka3_00Goka3_00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?od2oCom0_d00Kom0_d00Co0000onTF
jOoY5^WojAKY1?l00008oki1_P03o`000?n[E:_oZeB[00_oZeB[00?o0000og:=L_mbSG800_mbSG80
0ol0003o@[e2od:m@P08od:m@P03o`000?m1_T7o@Ki100[o@Ki100?o0000o`gb3Ol=lPd00_l=lPd0
0ol0003o=</docC;=003ocC;=0Go00002olWf2L00ol0003o4NhAoa7^4@03oa7^4@03o`000?lo_coo
?klo00Oo?klo00?o0000oi=/TonCK9<03_nCK9<2o`0000OoHIiQ00?o0000oi=/TonCK9<00_nCK9<0
0ol0003oYUVVojIIYP0=ojIIYP03o`000?o;=<_obcC;00;obcC;00?o0000omlOgooO7ml02OoO7ml0
0ol0003oka3_onl@k`03onl@k`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m007oo@;
m0?o00001?oF:MH00ol0003o_T6noki1_P05oki1_P03o`000?n[E:_oZeB[00[oZeB[00?o0000og:=
L_mbSG800ombSG800ol0003o@[e2od:m@P09od:m@P03o`000?m1_T7o@Ki100So@Ki100?o0000o`gb
3Ol=lPd01?l=lPd5o`0000Co0?l000?o0000obOH9olWf2L02OlWf2L00ol0003o4NhAoa7^4@03oa7^
4@03o`000?lo_coo?klo00So?klo00?o0000oi=/TonCK9<02_nCK9<3o`0000[oHIiQ00Go0000oi=/
TonCK9?oTfbCo`00000>ojIIYP03o`000?o;=<_obcC;00CobcC;0_l00009omlOg`03o`000?o_4>oo
ka3_00;oka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?od2oCom0_d00Oom0_d00?o0000omHY
e_oF:MH01OoF:MH00ol0003o_T6noki1_P03oki1_P03o`000?n[E:_oZeB[00[oZeB[00?o0000og:=
L_mbSG801?mbSG800ol0003o@[e2od:m@P09od:m@P03o`000?m1_T7o@Ki100Oo@Ki100?o0000o`gb
3Ol=lPd01Ol=lPd00ol0003o0?l0o`3o0007o`3o0003o`000?lWf2Oo9mPW00Oo9mPW00?o0000oa7^
4OlAkQ401?lAkQ400ol0003o?kloocno?`08ocno?`03o`000?nCK9?oTfbC00SoTfbC0_l0000>of6N
H@Co00003?nVFJH2o`0000WobcC;00?o0000omlOgooO7ml01ooO7ml01?l0003oka3_onl@kol0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000oo@;m?od2o@01Ood2o@00ol0003oeRWFomHYeP07omHYeP;o00000onn@Kh00ol0
003oZeB[oj]DZ`09oj]DZ`03o`000?mbSG;oLXeb00KoLXeb00?o0000od:m@_m2_D802Om2_D800ol0
003o@Ki1od6n@@05od6n@@03o`000?l=lPgo3O8=00Ko3O8=00?o0000o`3o0?l0o`002?l0o`000ol0
003o9mPWobOH9`06obOH9`03o`000?lAkQ7o4NhA00Co4NhA00?o0000ocno?olo_cl02Olo_cl4o`00
00?oTfbC0ol0000@of6NH@05o`000?nm@[go_D:moke2_Ol000002_nVFJH00ol0003obcC;ol/db`0:
ol/db`Ko00000ooO7ml00ol0003oka3_o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@01?od2o@00ol0
003oeRWFomHYeP0:omHYeP04o`000?nn@Kko_T6no`0000[oZeB[00?o0000og:=L_mbSG801ombSG80
0ol0003o@[e2od:m@P09od:m@P03o`000?m1_T7o@Ki100Co@Ki100?o0000o`gb3Ol=lPd01ol=lPd0
0ol0003o0?l0o`3o0008o`3o00;o00001_lWf2L00ol0003o4NhAoa7^4@05oa7^4@03o`000?lo_coo
?klo00Wo?klo00Co0000oc;=<_lbcC;o</db0ol0000Bof6NH@03o`000?nm@[go_D:m00?o_D:m0_l0
0006ojIIYP;o00003Oo;=</00ol0003olPgboo8=lP03oo8=lPGo00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000oo@;m?od2o@00ood2o@0
0ol0003oeRWFomHYeP0<omHYeP;o00002_n[E:/00ol0003oLXebog:=LP08og:=LP03o`000?m2_D;o
@[e200[o@[e200?o0000od6n@Om1_T400_m1_T400ol0003o3O8=o`gb3@08o`gb3@03o`000?l0o`3o
0?l000Ko0?l00_l00002o`Oh1`03o`000?lWf2Oo9mPW00;o9mPW00?o0000oa7^4OlAkQ401_lAkQ40
0ol0003o?kloocno?`08ocno?`03o`000?lbcC;o</db00Co</db00?o0000of6NHOmQWV403omQWV40
0ol0003o_D:moke2_@06oke2_@;o00000onVFJH00ol0003obcC;ol/db`0=ol/db`03o`000?ob3O;o
lPgb00OolPgb0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003om0_doo@;m002oo@;m003o`000?oF:MKoeRWF
00koeRWF00?o0000oj]DZon[E:/01on[E:/00ol0003oLXebog:=LP0:og:=LP03o`000?m2_D;o@[e2
00Wo@[e200Go0000od6n@Om1_T7o@Ki1o`00000;o`gb3@03o`000?l0o`3o0?l000Co0?l00_l00005
o`Oh1`05o`000?lWf2Oo9mPWobOH9ol000002?lAkQ400ol0003o?kloocno?`08ocno?`03o`000?lb
cC;o</db00Go</db00?o0000of6NHOmQWV403_mQWV400ol0003o_D:moke2_@08oke2_@03o`000?nV
FJKo000000oobcC;00?o0000oo8=l_ob3O802?ob3O801?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?od2oCom0_do`00017oeRWF00?o0000oj]DZon[E:/01_n[E:/00ol0003oLXeb
og:=LP0;og:=LP03o`000?m2_D;o@[e200Wo@[e200Co0000od6n@Om1_T7o00003?l=lPd00ol0003o
0?l0o`3o0002o`3o00;o00002?l7n0L00ol0003o9mPWo`000009oa7^4@03o`000?lo_coo?klo00So
?klo00?o0000oc;=<_lbcC801OlbcC800ol0003oHIiQof6NH@0=of6NH@03o`000?nm@[go_D:m00[o
_D:m00?o0000ol/dboo;=</03_o;=</00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000BomHYeP03o`00
0?n[E:_oZeB[00CoZeB[00?o0000og:=L_mbSG803?mbSG800ol0003o@[e2od:m@P0:od:m@P?o0000
3?l=lPd00ol0003o0?l0o`3o0002o`0000_o1oP700?o0000oa7^4OlAkQ402?lAkQ400ol0003o?klo
ocno?`07ocno?`03o`000?lbcC;o</db00Oo</db00?o0000of6NHOmQWV403?mQWV400ol0003o_D:m
oke2_@0;oke2_@;o00003_o;=</00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003oeRWFomHYeP0?omHYeP?o00000on[
E:/00ol0003oLXebog:=LP0>og:=LP03o`000?m2_D;o@[e200So@[e200Co0000oaGZ5OlEjQGo5NXE
0_l0000:o`gb3@?o00003Ol7n0L00ol0003o4NhAoa7^4@08oa7^4@03o`000?lo_coo?klo00Oo?klo
00?o0000oc;=<_lbcC801olbcC800ol0003oHIiQof6NH@0;of6NH@03o`000?nm@[go_D:m00co_D:m
00?o0000onDJiOl000000_l0000:ol/db`03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003ol`ccoo<<l`04oo<<l`03o`000?oF:MKoeRWF00coeRWF0_l0
0003okm0_`03o`000?n[E:_o0000017oLXeb00?o0000od:m@_m2_D801om2_D800ol0003o5NXEoaGZ
5@04oaGZ5@;o00002?l=lPd00ol0003o1oP7o`Oh1`0>o`Oh1`;o00002?lAkQ400ol0003o?kloocno
?`06ocno?`03o`000?lbcC;o</db00Wo</db00?o0000of6NHOmQWV402OmQWV400ol0003o_D:moke2
_@0=oke2_@03o`000?oU6^GoiA[U00;oiA[U0ol00007ol/db`03o`000?ob3O;olPgb00OolPgb00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oF:MKo
eRWF00WoeRWF0_l00006okm0_`03o`000?mbSG;oLXeb013oLXeb00?o0000od:m@_m2_D801_m2_D80
0ol0003o5NXEoaGZ5@07oaGZ5@03o`000?l=lPgo3O8=00Co3O8=0ol0000>o`Oh1`03o`000?l0o`3o
0?l000?o00001OlAkQ400ol0003o?kloocno?`06ocno?`03o`000?lbcC;o</db00[o</db00?o0000
of6NHOmQWV402?mQWV400ol0003o_D:moke2_@0=oke2_@03o`000?oU6^GoiA[U00GoiA[U0ol00004
ol/db`03o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ol`ccoo<<l`06oo<<l`03o`000?oF:MKoeRWF00GoeRWF0ol00008okm0_`03o`000?mbSG;oLXeb
017oLXeb00Co0000od:m@_m2_D;o@[e21?l0000;oaGZ5@;o000000Co3O8=o`000?l0003o00000olL
ha`2o`0000_o1oP700?o0000o`3o0?l0o`001?l0o`02o`0000?o4NhA00?o0000ocno?olo_cl01_lo
_cl00ol0003o</dboc;=<P0:oc;=<P03o`000?mQWV7oHIiQ00OoHIiQ00?o0000oke2_Onm@[d03_nm
@[d00ol0003oiA[UonDJi@08onDJi@Co00002_ob3O800ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003ol`ccoo<<l`07oo<<l`03o`000?oF:MKoeRWF00;oeRWF0_l0000<okm0_`03o`000?mbSG;o
LXeb013oLXeb1?l00003ocC;=003o`000?lEjQGo5NXE00_o5NXE00?o0000oacS7?lLha`01_lLha`0
0ol0003o1oP7o`Oh1`07o`Oh1`03o`000?l0o`3o0?l000Oo0?l03?l0000>oc;=<P03o`000?mQWV7o
HIiQ00KoHIiQ00?o0000oke2_Onm@[d03_nm@[d00ol0003oiA[UonDJi@0;onDJi@03o`000?ob3O;o
lPgb00OolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00Wol`cc00Co0000omHY
e_l0003o00003_no@;l00ol0003oLXebog:=LP0?og:=LP03o`000?ldbcCo=</d00Ko=</d00?o0000
oaGZ5OlEjQD02_lEjQD00ol0003o7><LoacS7007oacS70;o00001_l7n0L00ol0003o0?l0o`3o0008
o`3o0003o`000?m6^DKoA[U600SoA[U600?o0000oc;=<_lbcC803?lbcC800ol0003oHIiQof6NH@05
of6NH@03o`000?nm@[go_D:m00oo_D:m0_l0000=onDJi@03o`000?ob3O;olPgb00KolPgb00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00[ol`cc00?o0000okm0_ono@;l03_no@;l00ol0
003oLXebog:=LP0>og:=LP03o`000?ldbcCo=</d00Oo=</d00?o0000oaGZ5OlEjQD02_lEjQD00ol0
003o7><LoacS7009oacS70;o00000ol7n0L00ol0003o0?l0o`3o0009o`3o0003o`000?m6^DKoA[U6
00WoA[U600?o0000oc;=<_lbcC802_lbcC84o`0000CoHIiQ00?o0000oke2_Onm@[d04?nm@[d01?l0
003ohQgRo`000?l0000<onDJi@03o`000?ob3O;olPgb00GolPgb00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oc3??ol`cc00[ol`cc00?o0000okm0_ono@;l03ono@;l@o`0000[o=</d00?o0000oaGZ
5OlEjQD02OlEjQD00ol0003o0?l0o`00000<oacS7005o`000?l7n0Oo0000o`3o0?l000002_l0o`00
0ol0003oA[U6odJiAP09odJiAP03o`000?lbcC;o</db00Oo</db0ol00004ofJIIP?o000000?oHIiQ
o`000?nm@[d04Onm@[d01?l0003ohQgRon8Mh_oR7N82o`0000_oiA[U00?o0000oo8=l_ob3O800oob
3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003o_d2ookm0_`0?
okm0_`03o`000?mdRgCoM8]d00coM8]d00?o0000ocC;=?ldbc@02Oldbc@00ol0003o5NXEoaGZ5@07
oaGZ5@04o`000?l0o`3o0?l0o`0000go7><L00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m6^DKoA[U600[oA[U600?o0000oc;=<_lbcC800olbcC83o`0000[oIYUV00?o0000oke2_Onm@[d0
4?nm@[d00ol0003ohQgRon8MhP04on8MhP;o00002_oU6^D00ol0003olPgboo8=lP04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000col`cc00?o0000okm0_ono@;l03ono@;l00ol0003oM8]dogB;M00<ogB;M003o`000?ld
bcCo=</d00Wo=</d00?o0000oaGZ5OlEjQD01_lEjQD00ol0003o0?l0o`3o0002o`3o0003o`000?lL
haco7><L00[o7><L00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m6
^DKoA[U600[oA[U600?o0000oc;=<_lbcC800ol0000=ofJIIP03o`000?nm@[go_D:m013o_D:m00?o
0000on8Mh_oR7N801_oR7N82o`0000WoiA[U0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003o_d2ookm0_`0=okm0_`?o00003omdRg@0
0ol0003o=</docC;=008ocC;=003o`000?lEjQGo5NXE00Go5NXE00?o0000o`3o0?l0o`000ol0o`00
0ol0003o7><LoacS700:oacS7003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003oA[U6odJiAP0;odJiAP;o00004OmVVFH00ol0003o_D:moke2_@0?oke2_@03o`000?oR7N;o
hQgR00SohQgR0_l00007onDJi@03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo<<looc3?<02?oc3?<00ol0003o_d2ookm0_`09okm0_`Go00000_n>LHh00ol0
003oM8]dogB;M00=ogB;M003o`000?ldbcCo=</d00Wo=</d00?o0000oaGZ5OlEjQD01?lEjQD00ol0
003o0?l0o`3o0004o`3o0003o`000?lLhaco7><L00So7><L00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m6^DKoA[U600_oA[U600?o0000ofJII_mVVFH04?mVVFH00ol0
003o_D:moke2_@0?oke2_@03o`000?oR7N;ohQgR00[ohQgR0_l00004onDJi@03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003ol`ccoo<<l`07oo<<l`03o`000?no@;oo_d2o00Co_d2o1Ol00007ohiaSP03
o`000?mdRgCoM8]d00goM8]d00?o0000ocC;=?ldbc@02Oldbc@00ol0003o5NXEoaGZ5@03oaGZ5@03
o`000?l0o`3o0?l000Go0?l000?o0000oacS7?lLha`02?lLha`00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000odJiA_m6^DH02om6^DH00ol0003oIYUVofJIIP0@ofJIIP03
o`000?nm@[go_D:m00oo_D:m00?o0000on8Mh_oR7N803?oR7N82o`000003onDJiOl0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000okm0_ol00000
1?l0000<ohiaSP03o`000?mdRgCoM8]d00koM8]d00?o0000ocC;=?ldbc@02?ldbc@00ol0003o5NXE
oaGZ5@02oaGZ5@03o`000?l0o`3o0?l000Oo0?l000?o0000oacS7?lLha`01olLha`00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000odJiA_m6^DH02om6^DH00ol0003oIYUV
ofJIIP0AofJIIP03o`000?nm@[go_D:m00go_D:m00?o0000on8Mh_oR7N803ooR7N800ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo<<looc3?<01Ooc3?<3o`00017oSW6>00?o0000ogB;M?mdRg@03_md
Rg@00ol0003o=</docC;=009ocC;=004o`000?lEjQGo5NXEo`0000[o0?l000?o0000oacS7?lLha`0
1olLha`00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om6^DH00ol0003o
IYUVofJIIP0AofJIIP?o00003Onm@[d00ol0003ohQgRon8MhP0?on8MhP03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_oc3?<2o`0000;of2OH00?o0000ohiaS_n>LHh03on>LHh00ol0003o
M8]dogB;M00>ogB;M003o`000?ldbcCo=</d00So=</d1Ol0000;o`3o0003o`000?lLhaco7><L00Ko
7><L00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=odJiAP03o`000?mVVFKoIYUV
017oIYUV00?o0000oenPGomOX5l00ol0000:oke2_@Co00003OoR7N800ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000oo@;m?od2oCom0_d0_l00005omPWf003o`000?n>LHkoSW6>00koSW6>00?o0000ogB;
M?mdRg@03_mdRg@00ol0003o=</docC;=007ocC;=003o`000?lUfRGo9MXU00?o9MXU00?o0000o`3o
0?l0o`002?l0o`000ol0003o7><LoacS7005oacS7003o`000?l0o`3o0?l000[o0?l01Ol0000<odJi
AP03o`000?mVVFKoIYUV013oIYUV00?o0000oenPGomOX5l01?mOX5l3o`0000Ko_D:m00?o0000omhQ
g_oN8Mh00_oN8Mh5o`0000SohQgR00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00?o
m0_d00?o0000omPWf?oH9mP01?oH9mP00ol0003oSW6>ohiaSP0=ohiaSP03o`000?mdRgCoM8]d00oo
M8]d00?o0000ocC;=?ldbc@01?ldbc@2o`0000Oo9MXU00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0o`300?o0000odJiA_m6^DH02?m6^DH3o`00013oIYUV00?o0000oenPGomOX5l02?mOX5l3o`0000;o
_D:m00?o0000omhQg_oN8Mh02?oN8Mh5o`0000?ohQgR00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?od2oCom0_d00Com0_d00?o0000omPWf?oH9mP01OoH9mP00ol0003oSW6>ohiaSP0;ohiaSPCo0000
3omdRg@00ol0003o=</docC;=003ocC;=003o`000?lUfRGo9MXU00So9MXU00?o0000o`3o0?l0o`00
1?l0o`02o`0000So8]dR00?o0000oa7^4OlAkQ402?lAkQ400ol0003o0o`3o`?l0`05o`?l0`;o0000
1_m6^DH2o`0000?o?<<l00?o0000ofJII_mVVFH03?mVVFH00ol0003oGj1OoenPG`0<oenPG`;o0000
4?oN8Mh3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m005oo@;m003o`000?oH9mSof2OH00Kof2OH00?o
0000ohiaS_n>LHh02On>LHh00ol0003oVVFJo`000002oeZUFP?o00003?mdRg@01?l0003o=</docC;
=?ldbc@2o`0000co9MXU00?o0000o`3o0?l0o`000_l0o`000ol0003o8]dRob;M8P08ob;M8P03o`00
0?lAkQ7o4NhA00So4NhA00?o0000o`?l0ol3o0<01ol3o0<00ol0003oA[U6odJiAP02odJiAP03o`00
0?ll`cco?<<l00Co?<<l0_l0000;ofJIIP03o`000?mOX5ooGj1O00coGj1O00?o0000ojEJYOl00000
4_oN8Mh00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003om0_doo@;m006oo@;m003o`000?oH9mSof2OH00Oof2OH00?o
0000ohiaS_n>LHh01_n>LHh2o`0000;oVVFJ00?o0000oeZUF_mJYEX00omJYEX3o`0000[oM8]d00?o
0000ocC;=?l000003olUfRD01?l0003o0?l0o`000?l0000;ob;M8P03o`000?lAkQ7o4NhA00So4NhA
00?o0000o`?l0ol3o0<02?l3o0<01?l0003oA[U6o`000?l00009occ3?003o`000?mVVFKoIYUV00Oo
IYUV00?o0000oenPGomOX5l03?mOX5l01?l0003oYEZUojEJYOl0000ComhQgP03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000oo@;m?od2o@01ood2o@00ol0003of2OHomPWf008omPWf003o`000?n>LHkoSW6>00Co
SW6>00?o0000oiYUV_nJIIX00onJIIX00ol0003oFZEJoeZUFP05oeZUFP?o00001_mdRg@4o`00013o
9MXU00?o0000ob;M8_lRgB803?lRgB800ol0003o4NhAoa7^4@07oa7^4@03o`000?l3o0?o0o`300Wo
0o`300?o0000occ3??ll`c`02_ll`c`2o`0000KoIYUV00?o0000oenPGomOX5l03?mOX5l00ol0003o
YEZUojEJY@02ojEJY@03o`000?oN8MkogR7N00oogR7N00?o0000oo4>lOl000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003om0_doo@;m008oo@;m003o`000?oH9mSof2OH00Wof2OH00Co0000ohiaS_n>LHko
SW6>0_l00006oiYUVP03o`000?mJYE[oFZEJ00SoFZEJ0ol000000omdRgCo0000o`000004oc_4>`03
o`000?lUfRGo9MXU00go9MXU00?o0000ob;M8_lRgB803?lRgB800ol0003o4NhAoa7^4@07oa7^4@03
o`000?l3o0?o0o`300Wo0o`300?o0000occ3??ll`c`03?ll`c`00ol0003oIYUVofJIIP03o`0000ko
Gj1O00?o0000ojEJYOnUFZD00onUFZD00ol0003ogR7NomhQgP0>omhQgP05o`000?oa3_7ol@kaoo4>
lOl000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003om0_doo@;m009oo@;m003o`000?oH9mSof2OH00[o
f2OH00?o0000ohiaS_l000002?nJIIX00ol0003oFZEJoeZUFP0;oeZUFP03o`000?lka3_o>l@k00Go
>l@k00?o0000obGJ9OlUfRD03?lUfRD00ol0003o8]dRob;M8P0<ob;M8P03o`000?lAkQ7o4NhA00Oo
4NhA00?o0000o`?l0ol3o0<02?l3o0<2o`0000oo?<<l0_l00002ofJIIP03o`000?mOX5ooGj1O00_o
Gj1O00?o0000ojEJYOnUFZD01?nUFZD00ol0003ogR7NomhQgP0=omhQgP03o`000?oa3_7ol@ka00?o
l@ka00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo@;m003o`000?oH9mSof2OH00_of2OH00?o0000oiYUV_nJIIX0
1onJIIX00ol0003oFZEJoeZUFP0;oeZUFP03o`000?lka3_o>l@k00Ko>l@k00?o0000obGJ9OlUfRD0
2olUfRD2o`0000go8]dR00?o0000oa7^4OlAkQ401olAkQ400ol0003o0o`3o`?l0`07o`?l0`04o`00
0?l@ka3o4>l@o`0000ko?<<l00?o0000ofJII_mVVFH00_mVVFH00ol0003oGj1OoenPG`09oenPG`03
o`000?nUFZGoYEZU00KoYEZU00?o0000omhQg_oN8Mh02ooN8Mh00ol0003ol@kaoo4>l@05oo4>l@04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Som0_d00?o0000omPWf?oH9mP02_oH9mP2o`0000Wo
VVFJ00?o0000oeZUF_mJYEX02omJYEX00ol0003o>l@koc_4>`07oc_4>`03o`000?lUfRGo9MXU00Wo
9MXU00Co0000o`3o0?l0o`3o00003?lRgB800ol0003o4NhAoa7^4@07oa7^4@03o`000?l3o0?o0o`3
00Ko0o`300Go0000oa3_4?l@ka3o4>l@o`00000>occ3?003o`000?mVVFKoIYUV00?oIYUV00?o0000
oenPGomOX5l01omOX5l00ol0003oYEZUojEJY@07ojEJY@03o`000?oN8MkogR7N00[ogR7N00?o0000
oo4>lOoa3_401ooa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006oo@;m003o`000?oH9mSof2OH
00Wof2OH00Co0000ol`cc?o<<lco00002OnJIIX00ol0003oFZEJoeZUFP09oeZUFP03o`000?lka3_o
>l@k00Wo>l@k00?o0000obGJ9OlUfRD01olUfRD00ol0003o0?l0o`3o0002o`3o0003o`000?lRgB;o
8]dR00Wo8]dR00?o0000oa7^4OlAkQ401olAkQ400ol0003o0o`3o`?l0`05o`?l0`03o`000?l@ka3o
4>l@00?o4>l@00?o0000occ3??ll`c`02_ll`c`00ol0003oIYUVofJIIP05ofJIIP03o`000?mOX5oo
Gj1O00GoGj1O00?o0000ojEJYOnUFZD02?nUFZD00ol0003ogR7NomhQgP09omhQgP03o`000?oa3_7o
l@ka00Sol@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_od2o@3o`0000Wof2OH00?o0000ol`c
c?o<<l`00_o<<l`00ol0003oVVFJoiYUVP06oiYUVP03o`000?mJYE[oFZEJ00WoFZEJ00?o0000oc_4
>olka3/02_lka3/00ol0003o9MXUobGJ9@05obGJ9@03o`000?l0o`3o0?l000Co0?l000?o0000ob;M
8_lRgB802?lRgB800ol0003o4NhAoa7^4@07oa7^4@03o`000?l3o0?o0o`300Co0o`300?o0000oa3_
4?l@ka001?l@ka000ol0003o?<<locc3?00:occ3?003o`000?mVVFKoIYUV00KoIYUV00?o0000oenP
GomOX5l00omOX5l00ol0003oYEZUojEJY@09ojEJY@03o`000?oN8MkogR7N00SogR7N00?o0000oo4>
lOoa3_402Ooa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003ondBk@?o00001OoH9mP00ol0003o
c3?<ol`cc003ol`cc003o`000?nJII[oVVFJ00KoVVFJ00?o0000oeZUF_mJYEX02OmJYEX00ol0003o
>l@koc_4>`0;oc_4>`03o`000?lUfRGo9MXU00?o9MXU00?o0000o`3o0?l0o`001_l0o`000ol0003o
8]dRob;M8P08ob;M8P03o`000?lAkQ7o4NhA00Ko4NhA00?o0000o`?l0ol3o0<00_l3o0<2o`0000So
4>l@00?o0000occ3??ll`c`02Oll`c`00ol0003oIYUVofJIIP07ofJIIP05o`000?mOX5ooGj1OoenP
Gol000003OnUFZD00ol0003ogR7NomhQgP06omhQgP03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o]4^gokA;]00GokA;]0ol000000ooH9mSo0000ol`cc006ol`cc003
o`000?nJII[oVVFJ00GoVVFJ00?o0000oeZUF_mJYEX02OmJYEX00ol0003o>l@koc_4>`0<oc_4>`05
o`000?lUfRGo9MXUobGJ9Ol000002_l0o`000ol0003o8]dRob;M8P07ob;M8P03o`000?lAkQ7o4NhA
00Ko4NhA00?o0000o`?l0ol000000_l000000olm`Sgo0000oa3_4007oa3_4003o`000?ll`cco?<<l
00So?<<l00?o0000ofJII_mVVFH02OmVVFH00ol0003oGj1Oo`00000=ojEJY@Co00001OoN8Mh00ol0
003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003okA;]ondBk@08ondBk@03
o`000?o<<lcoc3?<00Ooc3?<00?o0000oiYUV_nJIIX01?nJIIX00ol0003oFZEJoeZUFP09oeZUFP03
o`000?lka3_o>l@k00go>l@k00?o0000obGJ9Ol000003?l0o`0:o`0000Oo4NhA0ol00005ocg2?@03
o`000?l@ka3o4>l@00Ko4>l@00?o0000occ3??ll`c`01oll`c`00ol0003oIYUVofJIIP0:ofJIIP03
o`000?nUFZGoYEZU00_oYEZU00?o0000om/TfooK9=/00_oK9=/3o`000003omhQg_l0003ol@ka00_o
l@ka0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000ondBkOo]4^d02Oo]4^d00ol0003oc3?<ol`cc007ol`cc003o`00
0?nJII[oVVFJ00GoVVFJ00?o0000oeZUF_mJYEX01omJYEX00ol0003o>l@koc_4>`0?oc_4>`;o0000
2ol0o`000ol0003o<<l`oc3?<007oc3?<003o`000?lAkQ7o4NhA00;o4NhA0ol00008ocg2?@03o`00
0?l@ka3o4>l@00Ko4>l@00?o0000occ3??ll`c`01oll`c`00ol0003oIYUVofJIIP0:ofJIIP03o`00
0?nUFZGoYEZU00[oYEZU00?o0000om/TfooK9=/01_oK9=/00ol0003ol@kaoo4>l@08oo4>l@?o0000
0_oe2_D00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000ondBkOo]4^d02Oo]4^d00ol0003oc3?<ol`c
c008ol`cc003o`000?nJII[oVVFJ00CoVVFJ00?o0000oeZUF_mJYEX01omJYEX00ol0003o>l@koc_4
>`0>oc_4>`04o`000?l;m0_o2o@;o`0000Wo0?l000?o0000oc3?<?l`cc002Ol`cc001?l0003o4NhA
o`000?l0000<ocg2?@03o`000?l@ka3o4>l@00Ko4>l@00?o0000occ3??ll`c`01_ll`c`00ol0003o
IYUVofJIIP0;ofJIIP03o`000?nUFZGoYEZU00OoYEZU0_l00009om/Tf`03o`000?oa3_7ol@ka00Co
l@ka1?l00006ooD:m@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003okA;]ondBk@09ondBk@03o`00
0?o<<lcoc3?<00Soc3?<00?o0000oiYUV_nJIIX00onJIIX>o`0000go>l@k00?o0000o`_d2ol;m0/0
0_l;m0/00ol0003o0?l0o`3o0005o`3o0003o`000?l`cc3o<<l`00_o<<l`00?o0000ocg2?Olm`Sd0
3?lm`Sd00ol0003o4>l@oa3_4006oa3_4003o`000?ll`cco?<<l00Go?<<l00?o0000ofJII_mVVFH0
3?mVVFH00ol0003oYEZUojEJY@06ojEJY@03o`000?oK9=_ofbCK00[ofbCK00?o0000oo4>lOoa3_40
0ol0000:ooD:m@?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000ol`cc?o<<l`02?o<
<l`01Ol0003oVVFJoiYUV_nJII[o000000_oJ9MX00?o0000o`[e2_l:m@X00ol00009oc_4>`03o`00
0?l;m0_o2o@;00Co2o@;00?o0000o`3o0?l0o`000ol0o`000ol0003o<<l`oc3?<00<oc3?<003o`00
0?lm`Sgo?L8m00go?L8m00?o0000oa3_4?l@ka001_l@ka000ol0003o?<<locc3?003occ3?0?o0000
3OmVVFH00ol0003oYEZUojEJY@05ojEJY@03o`000?oK9=_ofbCK00cofbCK0_l0000=ooD:m@03o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000ol`cc?o<<l`02?o<
<l`4o`0000coJ9MX00?o0000o`[e2_l:m@X00ol:m@X3o`0000Go>l@k00?o0000o`_d2ol;m0/01_l;
m0/01Ol0003o0?l0o`3o0?l0o`3o000000oo<<l`00?o0000ocg2?Olm`Sd03Olm`Sd00ol0003o4>l@
oa3_4006oa3_4003o`000?ll`cco?<<l00?o00000olUfRD00ol0003oIYUVofJIIP0;ofJIIP03o`00
0?nUFZGoYEZU00?oYEZU00?o0000om/TfooK9=/03OoK9=/00ol0003om@[eooD:m@0;ooD:m@03o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000ondBkOo]4^d02_o]4^d3o`0000Koc3?<0ol0
0003okU6^@03o`000?mXUfSoJ9MX00[oJ9MX00?o0000o`[e2_l:m@X01_l:m@X3o`000003oc_4>ol0
003o2o@;00Wo2o@;00?o0000o`3o0?l000004?l`cc000ol0003o?L8mocg2?@0=ocg2?@03o`000?l@
ka3o4>l@00Oo4>l@0_l00007obGJ9@03o`000?mVVFKoIYUV00[oIYUV00Co0000ojEJYOnUFZGoYEZU
0ol0000?om/Tf`03o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ondBkOo]4^d02_o]
4^d01?l0003ohacSon<LhooS7><2o`000004ol`cc?l0003o0000o`0000Ko^DJi00?o0000ofRGJ?mX
UfP02_mXUfP00ol0003o2_D:o`[e2P09o`[e2P03o`000?l;m0_o2o@;00[o2o@;00?o0000oc3?<?l`
cc003ol`cc000ol0003o?L8mocg2?@0>ocg2?@03o`000?l@ka3o4>l@00Ko4>l@00?o0000obGJ9OlU
fRD01olUfRD4o`0000SoIYUV00Co0000ojEJYOnUFZGo00000onfBKH2o`0000gofbCK00?o0000ooD:
mOoe2_D02_oe2_D00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ondBkOo]4^d02Oo]4^d00ol0003o
hacSon<Lh`04on<Lh`03o`000?niA[Wo^DJi00Oo^DJi00?o0000ofRGJ?mXUfP02OmXUfP00ol0003o
2_D:o`[e2P0:o`[e2P03o`000?l;m0_o2o@;00[o2o@;00?o0000oc3?<?l`cc003ol`cc000ol0003o
?L8mocg2?@0>ocg2?@03o`000?l@ka3o4>l@00Go4>l@00?o0000obGJ9OlUfRD02?lUfRD01?l0003o
GJ9MoefRGOmMXUd7o`0000;oIYUV0_l00006okI9]P;o00003?oK9=/00ol0003om@[eooD:m@09ooD:
m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003okA;]ondBk@08ondBk@03o`000?oS7>?ohacS00Go
hacS00?o0000okU6^OniA[T02?niA[T00ol0003oJ9MXofRGJ008ofRGJ003o`000?l:m@[o2_D:00[o
2_D:00?o0000o`_d2ol;m0/02ol;m0/00ol0003o<<l`oc3?<00>oc3?<003o`000?lm`Sgo?L8m00ko
?L8m1Ol00002oa3_4003o`000?lUfRGo9MXU00Wo9MXU00?o0000oefRGOmMXUd02?mMXUd3o`0000Wo
]TVf0_l0000:om/Tf`03o`000?oe2_Gom@[e00Som@[e00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o]4^gokA;]00SokA;]00?o0000on<LhooS7><01ooS7><00ol0003o^DJiokU6^@07okU6^@03o`00
0?mXUfSoJ9MX00SoJ9MX00?o0000o`[e2_l:m@X02_l:m@X00ol0003o2o@;o`_d2`0:o`_d2`;o0000
3_l`cc03o`0000go?L8m0ol00005odRgB0;o00002olUfRD00ol0003oGJ9MoefRG@0;oefRG@;o0000
2_nfBKH2o`0000OofbCK0ol00009ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:on<Lh`03o`00
0?niA[Wo^DJi00Oo^DJi00?o0000ofRGJ?mXUfP02?mXUfP>o`0000Wo2o@;0ol000000ol0o`3o0000
oc3?<00:oc3?<0?o00000_m9]TT00ol0003o?L8mocg2?@09ocg2?@;o00002Om8]dP00ol0003o9MXU
obGJ9@09obGJ9@03o`000?mMXUgoGJ9M00_oGJ9M00?o0000ohIiQ_l000002onfBKH2o`0000CofbCK
00Co0000on/Djoo[5>_ojaC[0_l00007ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003ohacS
on<Lh`09on<Lh`03o`000?niA[Wo^DJi00Ko^DJi00?o0000ofRGJ?mXUfP02?mXUfP00ol0003o4^dB
oa;]4P0:oa;]4P03o`000?l;m0_o2o@;00Co2o@;0ol00005o`3o0003o`000?l`cc3o<<l`00Co<<l`
1?l00006odVfB@03o`000?lm`Sgo?L8m00Ko?L8m0_l0000;odRgB003o`000?lUfRGo9MXU00Wo9MXU
00?o0000oefRGOmMXUd02_mMXUd01Ol0003oQWV6ohIiQ_n6NHKo000000co]TVf0_l000000ooK9=_o
0000on/Dj`05on/Dj`03o`000?oe2_Gom@[e00?om@[e00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oS7>?ohacS00SohacS00?o0000okU6^OniA[T01_niA[T00ol0003oJ9MXofRGJ007ofRGJ003o`00
0?lBkA;o4^dB00_o4^dB00?o0000o`_d2ol;m0/00_l;m0/2o`0000Wo0?l000?o0000oc3?<?l`cc00
0ol0000;odVfB@03o`000?lm`Sgo?L8m00;o?L8m0ol0000>odRgB003o`000?lUfRGo9MXU00Oo9MXU
00?o0000oefRGOmMXUd02omMXUd00ol0003oQWV6ohIiQP02ohIiQP03o`000?nfBKKo]TVf00_o]TVf
00?o0000on/Djoo[5>/01_o[5>/2o`0000?om@[e00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oS
7>?ohacS00OohacS00?o0000okU6^OniA[T01oniA[T00ol0003oJ9MXofRGJ005ofRGJ0?o00003OlB
kA84o`0000_o0?l00ol0000?odVfB@04o`000?lm`Sgo0000o`00017oB;M800?o0000obGJ9OlUfRD0
1olUfRD00ol0003oGJ9MoefRG@0:oefRG@03o`000?n6NHKoQWV600CoQWV600?o0000okI9]_nfBKH0
1onfBKH3o`0000_ojaC[1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on<LhooS7><02?oS7><00ol0003o^DJiokU6
^@06okU6^@03o`000?mXUfSoJ9MX00;oJ9MX0ol00003odFjA@03o`000?lBkA;o4^dB00[o4^dB00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AodVfB@03o`000?m8]dSoB;M8017oB;M800?o
0000obGJ9OlUfRD01olUfRD00ol0003oGJ9MoefRG@0:oefRG@03o`000?n6NHKoQWV600GoQWV600Co
0000okI9]_nfBKKo]TVf1Ol00002ol4n`@03o`000?o[5>_ojaC[00WojaC[00Co0000ood2oOom0_go
o@;m0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000on<LhooS7><01ooS7><00ol0003o^DJiokU6^@05okU6^@?o0000
00?oJ9MXo`000?l000001om5^TD00ol0003o4^dBoa;]4P08oa;]4P?o00002_l0o`02o`0000;o0?l0
00?o0000odVfBOm9]TT03om9]TT00ol0003oB;M8odRgB00AodRgB003o`000?lUfRGo9MXU00Oo9MXU
00?o0000oefRGOmMXUd02OmMXUd00ol0003oQWV6ohIiQP07ohIiQP?o00001oo1?/400ol0003ojaC[
on/Dj`09on/Dj`03o`000?om0_goo@;m00Coo@;m0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000on<LhooS7><01ooS
7><4o`0000;o^DJi0_l00003ojiA[P03o`000?m5^TGoAKY500SoAKY50_l00006oa;]4P;o00000olB
kA800ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000odVfBOm9]TT03_m9
]TT00ol0003oB;M8odRgB00BodRgB003o`000?lUfRGo9MXU00Go9MXU00?o0000oefRGOmMXUd02OmM
XUd00ol0003oQWV6ohIiQP08ohIiQP03o`000?o1?/7o`Ck100Oo`Ck100?o0000on/Djoo[5>/02?o[
5>/00ol0003oo@;mood2o@07ood2o@;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oS7>?ohacS00CohacS0_l00004
onDJi@;o00001On^DJh00ol0003oAKY5odFjA@0:odFjA@03o`000?lBkA;o4^dB00;o4^dB00?o0000
oa;]4_lBkA801?lBkA800ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
odVfBOm9]TT03_m9]TT00ol0003oB;M8odRgB00BodRgB0[o00002_mMXUd00ol0003oQWV6ohIiQP08
ohIiQP03o`000?o1?/7o`Ck100Oo`Ck100?o0000on/Djoo[5>/02?o[5>/00ol0003oo@;mood2o@09
ood2o@?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ohacSon<LhooS7><2o`0000OoiA[U00?o0000ojiA[_n^DJh01?n^DJh0
0ol0003oAKY5odFjA@0:odFjA@04o`000?lBkA;o0000o`0000So4^dB00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?m9]TWoBKI900koBKI900?o0000odRgB?m8]dP04_m8]dP00ol0003o?klo
ocno?`07ocno?`03o`000?mMXUgoGJ9M00KoGJ9M00?o0000ohIiQ_n6NHH02_n6NHH00ol0003o`Ck1
ol4n`@06ol4n`@03o`000?o[5>_ojaC[00SojaC[00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oS
7>?o0000o`0000WoiA[U00?o0000ojiA[_n^DJh01?n^DJh00ol0003oAKY5odFjA@0;odFjA@03o`00
0?lBkA;o4^dB00Wo4^dB00?o0000o`3o0?l000002Ol0o`000ol0003oBKI9odVfB@0>odVfB@;o0000
4_m8]dP00ol0003o?kloocno?`09ocno?`;o00001_mMXUd00ol0003oQWV6ohIiQP0:ohIiQP03o`00
0?o1?/7o`Ck100Ko`Ck100?o0000on/Djoo[5>/02?o[5>/00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onDJiOoU6^D02OoU6^D00ol0003o[U6^ojiA[P05ojiA[P03o`000?m5^TGoAKY500[oAKY500?o
0000oa;]4_lBkA802_lBkA82o`0000Wo0?l000?o0000odVfBOm9]TT03_m9]TT00ol0003o<l`co`00
0002o`0000ooB;M800?o0000ocno?olo_cl02olo_cl00ol0003oGJ9MoefRG@03o`0000goQWV600?o
0000ol4n`Oo1?/401_o1?/400ol0003ojaC[on/Dj`07on/Dj`03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oiA[UonDJi@09onDJi@03o`000?n^DJko[U6^00Go[U6^00?o0000odFjAOm5^TD02Om5^TD2
o`0000_o4^dB0_l0000;o`3o0003o`000?m9]TWoBKI900coBKI900?o0000oc?<<olcc3<00olcc3<3
o`0000coB;M800?o0000ocno?olo_cl03?lo_cl2o`0000;oNHIi00?o0000ohIiQ_n6NHH03?n6NHH0
0ol0003o`Ck1ol4n`@05ol4n`@03o`000?o[5>_ojaC[00OojaC[00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oU6^GoiA[U00[oiA[U00?o0000ojiA[_n^DJh01_n^DJh00ol0003oAKY5odFjA@07odFj
A@03o`000?m5^TGo000000[o4^dB00Co0000o`Ki1_l6n@Ko00002_l0o`000ol0003oBKI9odVfB@0<
odVfB@03o`000?lcc3?o<l`c00Ko<l`c0_l00008odRgB0;o00003olo_cl00ol0003oNHIiogV6N@02
ogV6N@03o`000?n6NHKoQWV600_oQWV600?o0000ol4n`Oo1?/401Oo1?/400ol0003ojaC[on/Dj`07
on/Dj`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oiA[UonDJi@0:onDJi@03o`000?n^DJko[U6^
00Ko[U6^00?o0000odFjAOm5^TD01_m5^TD01Ol0003oAKY5odFjAOm5^TGo000000So4^dB00?o0000
o`Ki1_l6n@H00_l6n@H00ol0003o0?l0o`3o0006o`3o00Co00003?m9]TT00ol0003o<l`coc?<<`08
oc?<<`?o00000_m8]dP3o`000003ocC;=?l0003o?klo00go?klo00?o0000ogV6NOmiQWT01?miQWT0
0ol0003oQWV6ohIiQP0:ohIiQP03o`000?o1?/7o`Ck100Go`Ck100?o0000on/Djoo[5>/01_o[5>/0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onDJiOoU6^D02ooU6^D00ol0003o[U6^ojiA[P07ojiA
[P03o`000?m5^TGoAKY500?oAKY50_l00005odFjA@03o`000?lBkA;o4^dB00Co4^dB00?o0000o`Ki
1_l6n@H00ol6n@H00ol0003o0?l0o`3o0005o`3o0003o`000?lAkQ7o4NhA00;o4NhA0ol00007odVf
B@;o00003_lcc3<2o`0000Go=</d00?o0000ocno?olo_cl02_lo_cl00ol0003oNHIiogV6N@05ogV6
N@03o`000?n6NHKoQWV600_oQWV600?o0000ol4n`Oo1?/401?o1?/400ol0003ojaC[on/Dj`06on/D
j`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiA[UonDJi@0;onDJi@03o`000?n^DJko[U6^00Oo
[U6^00?o0000odFjAOm5^TD00_m5^TD00ol0003oAKY5odFjA@06odFjA@03o`000?lBkA;o4^dB00;o
4^dB00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o0?l0o`3o0002o`3o00;o00002?lAkQ43o`0000;o
BKI90_l000000olIiQWo0000oc?<<`0=oc?<<`03o`000?ldbcCo=</d00Go=</d00?o0000ocno?olo
_cl02?lo_cl00ol0003oNHIiogV6N@07ogV6N@03o`000?n6NHKoQWV600[oQWV600?o0000ol4n`Oo1
?/401?o1?/400ol0003ojaC[on/Dj`06on/Dj`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiA[U
onDJi@0<onDJi@03o`000?n^DJko[U6^00So[U6^00Co0000odFjAOm5^TGo00002Om5^TD01Ol0003o
4^dBoa;]4_lBkA;o000000So1_T600Go0000o`3o0?l0o`3o0?l0o`00000=oa7^4@;o00001?lIiQT0
0ol0003o<l`coc?<<`0;oc?<<`03o`000?ldbcCo=</d00Ko=</d00?o0000ocno?olo_cl01olo_cl0
0ol0003oNHIiogV6N@08ogV6N@Co00002?n6NHH00ol0003o`Ck1ol4n`@04ol4n`@03o`000?o[5>_o
jaC[00KojaC[00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oU6^GoiA[U00_oiA[U0ol00009ojiA
[P03o`000?m5^TGo000000_oAKY500?o0000oa;]4_l000002_l6n@H00ol0003o0?l0o`00000?oa7^
4@03o`000?lIiQWo6NHI00;o6NHI00?o0000oc?<<olcc3<02olcc3<00ol0003o=</docC;=006ocC;
=003o`000?lo_coo?klo00Ko?klo00?o0000ogV6NOmiQWT02OmiQWT01?l0003oZeB[oj]DZon[E:/7
o`0000;oQWV600?o0000ol4n`Oo1?/400oo1?/400ol0003ojaC[on/Dj`05on/Dj`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oU6^GoiA[U00SoiA[U0ol00003omhQgP03o`000?n^DJko[U6^00Oo[U6^00?o0000odFj
AOm5^TD02om5^TD00ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?lAkQ7o4NhA00go4NhA00?o0000oaWV
6OlIiQT01?lIiQT00ol0003o<l`coc?<<`09oc?<<`03o`000?ldbcCo=</d00So=</d00?o0000ocno
?olo_cl00olo_cl2o`0000coNHIi00?o0000oj]DZon[E:/02?n[E:/<o`0000?ojaC[0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onDJiOoU6^D01_oU6^D3o`0000OogR7N00?o0000ojiA[_n^DJh01_n^DJh00ol0003o
AKY5odFjA@0;odFjA@03o`000?l6n@Ko1_T600Wo1_T60_l0000>oa7^4@03o`000?lIiQWo6NHI00Go
6NHI00?o0000oc?<<olcc3<02Olcc3<00ol0003o=</docC;=009ocC;=003o`000?lo_coo000000;o
00000_m^TFh00ol0003oNHIiogV6N@08ogV6N@03o`000?n[E:_oZeB[00coZeB[00?o0000onHIi_oV
6NH01_oV6NH3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oiA[UonDJi@03onDJi@?o00002ooN8Mh00ol0003o[U6^
ojiA[P04ojiA[P03o`000?m5^TGoAKY500_oAKY50ol00007o`Ki1P?o000000?o3o0?o`000?lAkQ40
3OlAkQ400ol0003o6NHIoaWV6@06oaWV6@03o`000?lcc3?o<l`c00So<l`c00?o0000ocC;=?ldbc@0
2_ldbc@00ol0003oKY5^ofjAKP04ofjAKP03o`000?miQWWoNHIi00OoNHIi00?o0000oj]DZon[E:/0
2on[E:/00ol0003oiQWVonHIiP08onHIiP03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onDJiOl0
003o0000o`0000oogR7N00?o0000ojiA[_n^DJh00on^DJh>o`0000?o=</d0_l00002o`Ki1P?o0000
1Ol?l0l00ol0003o4NhAoa7^4@0:oa7^4@03o`000?lIiQWo6NHI00Oo6NHI00?o0000oc?<<olcc3<0
2?lcc3<00ol0003o=</docC;=00:ocC;=003o`000?m^TFkoKY5^00GoKY5^00?o0000ogV6NOmiQWT0
1_miQWT00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?oV6NKoiQWV00SoiQWV00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ok1?/2o`0001;ogR7N00?o0000ojiA[_n^DJh00_n^DJh00ol0003oSG:=oheb
S@0:ohebS@03o`000?ldbcCo=</d00?o=</d0_l00009o`o`3`03o`000?lAkQ7o4NhA00Wo4NhA00?o
0000oaWV6OlIiQT02?lIiQT2o`0000So<l`c00?o0000ocC;=?ldbc@02Oldbc@00ol0003oKY5^ofjA
KP07ofjAKP03o`000?miQWWoNHIi00CoNHIi00?o0000oj]DZon[E:/02on[E:/00ol0003oiQWVonHI
iP09onHIiP03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ogR7NomhQgP0?omhQgP?o000000?o[U6^
o`000?n=LXd02on=LXd00ol0003o=</docC;=004ocC;=003o`000?l?l0oo3o0?00Wo3o0?00?o0000
oa7^4OlAkQ401olAkQ400ol0003o6NHIoaWV6@09oaWV6@04o`000?lKi1_o0000o`0000Ko<l`c00?o
0000ocC;=?ldbc@02Oldbc@00ol0003oKY5^ofjAKP08ofjAKP03o`000?miQWWoNHIi00?oNHIi00?o
0000oj]DZon[E:/02on[E:/00ol0003oiQWVonHIiP09onHIiP03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ogR7NomhQgP0<omhQgP;o00000ooL8m`2o`0000coSG:=00?o0000ocC;=?ldbc@01?ldbc@0
0ol0003o3o0?o`o`3`0:o`o`3`Wo00002olIiQT00ol0003o6n@Koa_T6`02oa_T6`?o00000_lcc3<0
0ol0003o=</docC;=00:ocC;=003o`000?m^TFkoKY5^00WoKY5^00?o0000ogV6NOmiQWT00_miQWT0
0ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oN8Mh2o`0000Gog2?L00?o0000ojeB[Ol000002_n=LXd00ol0003o=</docC;=006ocC;
=003o`000?l?l0oo3o0?00Wo3o0?00?o0000o`Sg2?l8m`P01Ol8m`P00ol0003o6NHIoaWV6@09oaWV
6@03o`000?lKi1_o6n@K00Go6n@K0ol00009ocC;=0?o00003Om^TFh01Ol0003oNHIiogV6NOmiQWWo
000000coZeB[00?o0000onHIi_oV6NH02OoV6NH00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000omhQ
g_oN8Mh01OoN8Mh2o`0000Oog2?L00Co0000ojeB[On]DZgo00002On=LXd00ol0003o=</docC;=006
ocC;=003o`000?l?l0oo3o0?00So3o0?00?o0000o`Sg2?l8m`P01ol8m`P00ol0003o6NHIoaWV6@07
oaWV6@03o`000?lKi1_o6n@K00So6n@K0ol00002ocC;=0Go00000_m9]TT00ol0003oKY5^ofjAKP0<
ofjAKP03o`000?miQWWo000000coZeB[00?o0000onHIi_oV6NH02_oV6NH00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000omhQg_oN8Mh00_oN8Mh2o`0000Sog2?L00?o0000ojeB[On]DZd00_n]DZd5o`00
00CoSG:=00?o0000ocC;=?ldbc@01_ldbc@00ol0003o3o0?o`o`3`08o`o`3`03o`000?l8m`So2?L8
00Oo2?L800?o0000oaWV6OlIiQT01olIiQT00ol0003o6n@Koa_T6`08oa_T6`03o`000?lOh1oo7n0O
00;o00002?m9]TT00ol0003oKY5^ofjAKP0<ofjAKPCo00002_n[E:/00ol0003oiQWVonHIiP0:onHI
iP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ogR7No`000?l0000:om`Sg003o`000?n]DZgo[E:]
00;o[E:]00?o0000ofJII_mVVFH00_mVVFH4o`0000Wo=</d00?o0000o`o`3ol?l0l02?l?l0l00ol0
003o2?L8o`Sg2008o`Sg2003o`000?lIiQWo6NHI00Go6NHI00?o0000oa_T6olKi1/02?lKi1/01Ol0
003o7n0OoaoP7olOh1oo000000[oBKI90ol0000;ofjAKP04o`000?oE:]GoeB[EomDZe@Co00001On[
E:/00ol0003oiQWVonHIiP0;onHIiP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003og2?Lom`Sg00:
om`Sg003o`000?n]DZgo[E:]00?o[E:]00?o0000ofJII_mVVFH01?mVVFH00ol0003o=</docC;=007
ocC;=003o`000?l?l0oo3o0?00Ko3o0?0_l0000;o`Sg2003o`000?lIiQWo6NHI00Go6NHI00?o0000
oa_T6olKi1/02?lKi1/00ol0003o7n0OoaoP7`02oaoP7`03o`000?m9]TWoBKI900OoBKI900?o0000
oi]TVonKI9/01?l00006ofjAKP03o`000?oE:]GoeB[E00KoeB[E0ol00002oj]DZ`03o`000?oV6NKo
iQWV00_oiQWV00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oL8mcog2?L00Wog2?L00?o0000ojeB
[On]DZd01?n]DZd00ol0003oIYUVofJIIP05ofJIIP03o`000?ldbcCo=</d00Oo=</d00?o0000o`o`
3ol?l0l00_l?l0l3o`000003oagR7Ol0003o2?L800[o2?L800?o0000oaWV6OlIiQT01OlIiQT00ol0
003o6n@Koa_T6`07oa_T6`03o`000?lOh1oo7n0O00?o7n0O00?o0000odVfBOm9]TT01om9]TT00ol0
003oVfBKoi]TV`04oi]TV`?o00000_m^TFh00ol0003oeB[EomDZe@0:omDZe@;o00003_oV6NH00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000om`Sg?oL8m`02OoL8m`00ol0003o[E:]ojeB[@04ojeB[@03
o`000?mVVFKoIYUV00KoIYUV0_l00007ocC;=003o`000?l?l0oo000000;o00001OlMhQd00ol0003o
2?L8o`Sg2008o`Sg20?o00001?lIiQT00ol0003o6n@Koa_T6`08oa_T6`03o`000?lOh1oo7n0O00Co
7n0O00?o0000odVfBOm9]TT01_m9]TT00ol0003oVfBKoi]TV`07oi]TV`;o00003_oE:]D00ol0003o
iQWVonHIiP0;onHIiP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003og2?Lom`Sg008om`Sg003o`00
0?n]DZgo[E:]00Go[E:]00?o0000ofJII_mVVFH01?mVVFH00ol0003oI9]TofBKI003o`0000Co=</d
0_l00008oagR7@03o`000?l8m`So2?L800Oo2?L800Co0000ocW6>OliaSWo>LHi0ol000000olIiQWo
0000oa_T6`09oa_T6`03o`000?lOh1oo7n0O00Co7n0O00?o0000odVfBOm9]TT01Om9]TT00ol0003o
VfBKoi]TV`09oi]TV`03o`000?oE:]GoeB[E00goeB[E00?o0000onHIi_oV6NH02_oV6NH00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000om`Sg?oL8m`01ooL8m`00ol0003o[E:]ojeB[@06ojeB[@03o`00
0?mVVFKoIYUV00?oIYUV00?o0000ofBKI?mTVf@01?mTVf@2o`000003ocC;=?l0003o7N8M00[o7N8M
00?o0000o`Sg2?l8m`P01Ol8m`P00ol0003o>LHiocW6>@05ocW6>@03o`000?lKi1_o6n@K00Oo6n@K
0ol00007oaoP7`03o`000?m9]TWoBKI900CoBKI900?o0000oi]TVonKI9/02OnKI9/00ol0003oeB[E
omDZe@0=omDZe@03o`000?oV6NKoiQWV00[oiQWV00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oL
8mcog2?L00Gog2?L0ol00009ojeB[@05o`000?mVVFKoIYUVofJII_l000002OmTVf@00ol0003o7N8M
oagR7@0;oagR7@03o`000?l8m`So2?L800?o2?L800?o0000ocW6>OliaST01_liaST00ol0003o6n@K
oa_T6`06oa_T6`05o`000?lbcC;o</dboc;=<_l000001olOh1l00ol0003oBKI9odVfB@03odVfB@03
o`000?nKI9_oVfBK00WoVfBK00?o0000omDZeOoE:]D03_oE:]D00ol0003oiQWVonHIiP09onHIiP03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003og2?Lo`000004o`0000;oj1OX00?o0000ojeB[On]DZd0
1on]DZd01?l0003oIYUVofJII_l00009ofBKI0;o00003OlMhQd00ol0003o2?L8o`Sg2002o`Sg2003
o`000?liaSWo>LHi00So>LHi00?o0000oa_T6olKi1/00olKi1/2o`0000Go</db00?o0000oaoP7olO
h1l01?lOh1l00ol0003oBKI9odVfB@03odVfB@03o`000?nKI9_oVfBK00WoVfBK00?o0000omDZeOoE
:]D03_oE:]D00ol0003oiQWVonHIiP09onHIiP03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000Soj1OX
00?o0000ojeB[On]DZd01_n]DZd00ol0003oIYUVo`000009ofBKI004o`000?m?/4ooCk1?o`0000go
7N8M00Co0000o`Sg2?l8m`So00003?liaST01Ol0003o6n@Koa_T6olKi1_o000000So</db0_l00005
oaoP7`03o`000?m9]TWoBKI900;oBKI900?o0000oi]TVonKI9/02OnKI9/00ol0003oeB[EomDZe@0>
omDZe@03o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oX5nSoj1OX
00Ooj1OX00?o0000ojeB[On]DZd01on]DZd00ol0003oI9]TofBKI007ofBKI003o`000?m?/4ooCk1?
00;oCk1?00?o0000oagR7OlMhQd02_lMhQd00ol0003o2?L8o`00000>ocW6>@03o`000?lKi1_o0000
00_o</db00?o0000oaoP7olOh1l00_lOh1l01Ol0003oBKI9odVfBOm9]TWo000000coVfBK00?o0000
omDZeOoE:]D03_oE:]D3o`0000WoiQWV00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oX5nSoj1OX
00Woj1OX00?o0000ojeB[On]DZd01_n]DZd00ol0003oI9]TofBKI006ofBKI003o`000?m?/4ooCk1?
00?oCk1?00?o0000oagR7OlMhQd02olMhQd00ol0003o>LHiocW6>@0>ocW6>@03o`000?lbcC;o</db
00_o</db0_l00003oaoP7`04o`000?m9]TWoBKI9o`0000[oVfBK0ol0000>omDZe@;o00000ool0o`2
o`0000OoiQWV00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oX5nSoj1OX00[oj1OX00?o0000ojeB
[On]DZd01?n]DZd00ol0003oI9]TofBKI006ofBKI003o`000?m?/4ooCk1?00GoCk1?00?o0000oagR
7OlMhQd01olMhQd3o`00017o>LHi00?o0000oc;=<_lbcC803OlbcC801Ol0003o7n0OoaoP7ol0003o
BKI900Co00000onKI9/5o`0000;oh1oP00?o0000omDZeOoE:]D02_oE:]D2o`0000Ooo0?l0_l00004
onHIiP03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003oj1OXonPGj00;onPGj003o`000?n]DZgo[E:]
00Co[E:]00?o0000ofBKI?mTVf@01OmTVf@00ol0003oCk1?odn`C`06odn`C`03o`000?lMhQgo7N8M
00Co7N8M0ol00002obKI9P03o`000?liaSWo>LHi00oo>LHi0_l0000?oc;=<P04o`000?lOh1oo0000
o`0000CoQGZ50ol00008on0Oh003o`000?oE:]GoeB[E00OoeB[E0_l0000;oo`3o0;o00000_oV6NH0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onPGj?oX5nP03?oX5nP6o`0000OoI9]T00?o0000odn`
Com?/4l02?m?/4l00ol0003o7N8MoagR7@03o`0000Ko9]TV00?o0000ocW6>OliaST03OliaST01?l0
003o@Ki1od6n@Ol0000?oc;=<P03o`000?n5NXGoQGZ500GoQGZ500?o0000on0Oh?oP7n002?oP7n00
0ol0003oeB[EomDZe@05omDZe@03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oX5nP00ol0003o]4^dokA;]004okA;
]003o`000?mTVfCoI9]T00?oI9]T00?o0000odn`Com?/4l02_m?/4l2o`0000[o9]TV00?o0000ocW6
>OliaST02oliaST00ol0003o@Ki1od6n@@02od6n@@03o`000?lbcC;o</db00_o</db0_l00007ohEj
Q@03o`000?oP7n3oh1oP00Woh1oP00?o0000omDZeOoE:]D00_oE:]D2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onPGj?oX5nP02ooX5nP00ol0003o]4^dokA;]006okA;]005o`000?mTVfCoI9]TofBK
I?l000003Om?/4l00ol0003o9]TVobKI9P0:obKI9P03o`000?liaSWo>LHi00Wo>LHi00?o0000od6n
@Om1_T401?m1_T400ol0003o</dboc;=<P08oc;=<P;o000000?o><Lho`000?n5NXD01on5NXD00ol0
003oh1oPon0Oh009on0Oh004o`000?oE:]Go0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oX5nSoj1OX
00Woj1OX00?o0000okA;]?ndBk@02?ndBk@00ol0003oI9]To`00000=odn`C`03o`000?lVfBKo9]TV
00_o9]TV00?o0000ocW6>OliaST02?liaST00ol0003o@Ki1od6n@@06od6n@@03o`000?lbcC;o</db
00Go</db0_l00003ocS7>003o`000?n5NXGoQGZ500KoQGZ500?o0000on0Oh?oP7n002_oP7n000ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003oj1OXonPGj007onPGj003o`000?ndBkCo]4^d00[o]4^d00?o0000odn`Com?
/4l03?m?/4l00ol0003o9]TVobKI9P0<obKI9P03o`000?liaSWo>LHi00Ko>LHi00?o0000od6n@Om1
_T402?m1_T400ol0003o</dboc;=<P02oc;=<P;o00001_lhacP00ol0003oQGZ5ohEjQ@05ohEjQ@03
o`000?oP7n3oh1oP00[oh1oP00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oX5nSoj1OX00Goj1OX
00?o0000okA;]?ndBk@03?ndBk@2o`0000coCk1?00?o0000obKI9_lVfBH03OlVfBH00ol0003o>LHi
ocW6>@04ocW6>@03o`000?m1_T7o@Ki100[o@Ki100Co0000oc;=<_l0003o00002?lhacP00ol0003o
QGZ5ohEjQ@06ohEjQ@03o`000?oP7n3oh1oP00Woh1oP00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oX5nP00ol0003o]4^dokA;]00=okA;]003o`000?mXUfSo000000;o00002?m?/4l00ol0003o9]TV
obKI9P0?obKI9PKo00003_m1_T400ol0003o><LhocS7>008ocS7>003o`000?n5NXGoQGZ500KoQGZ5
00?o0000on0Oh?oP7n002OoP7n000ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000on/Djoo[5>_ojaC[
0_l0000?okA;]003o`000?mXUfSoJ9MX00?oJ9MX0ol00005odn`C`;o00004?lVfBH01_l0003o5nPG
oaOX5ol0003o2?L8o`0000ko@Ki100?o0000ocS7>?lhacP02OlhacP00ol0003oQGZ5ohEjQ@05ohEj
Q@03o`000?oP7n3oh1oP00Woh1oP00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000on/Djoo[5>/00oo[5>/00ol0003o
]4^dokA;]00=okA;]003o`000?mXUfSoJ9MX00KoJ9MX0ol000001?m?/4oo0000ob_D:ol[e2/3o`00
00co9]TV00Go0000oaOX5olGj1Oo5nPGo`000002o`Sg2003o`000?m1_T7o@Ki100_o@Ki100?o0000
ocS7>?lhacP02OlhacP00ol0003oQGZ5ohEjQ@06ohEjQ@03o`000?oP7n3oh1oP00Soh1oP0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003ojaC[on/Dj`04on/Dj`oo00003?mXUfP00ol0003o:m@[ob_D:`04ob_D
:`?o00002?lVfBH00ol0003o5nPGoaOX5`02oaOX5`05o`000?l8m`So2?L8o`Sg2?l000003?m1_T40
0ol0003o><LhocS7>009ocS7>003o`000?n5NXGoQGZ500GoQGZ53?l00002oo4>l@;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003ojaC[on/Dj`05on/Dj`03o`000?nbCK;o/Tfb00_o/Tfb00?o0000ofRG
J?mXUfP02_mXUfP00ol0003o:m@[ob_D:`07ob_D:`;o00001OlVfBH00ol0003o5nPGoaOX5`03oaOX
5`03o`000?l8m`So2?L800;o2?L800?o0000od6n@Om1_T402Om1_T400ol0003o><LhocS7>00:ocS7
>003o`000?n5NXGoQGZ500?oQGZ500?o0000oll`coo?<<l02Oo?<<l00ol0003ol@kaoo4>l@02oo4>
l@;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ojaC[on/Dj`06on/Dj`03o`000?nbCK;o/Tfb00[o
/Tfb00?o0000ofRGJ?mXUfP02omXUfP00ol0003o:m@[ob_D:`09ob_D:`?o000000?o9]TVo`000?lG
j1L01OlGj1L00ol0003o2?L8o`Sg2003o`Sg2003o`000?m1_T7o@Ki100So@Ki13_l00003ohEjQ@;o
00002oo?<<l00ol0003ol@kaoo4>l@05oo4>l@03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000on/Djoo[5>/01Oo[5>/00ol0003o`3o0o`00000;ok9=/P03o`000?mXUfSoJ9MX00[oJ9MX
0_l0000>ob_D:`03o`000?lGj1Oo5nPG00Go5nPG00?o0000o`Sg2?l8m`P00ol8m`P00ol0003o@Ki1
od6n@@08od6n@@03o`000?n2OH;oPWf200_oPWf200?o0000ohEjQOl000003Oo?<<l00ol0003ol@ka
oo4>l@06oo4>l@;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o[5>_ojaC[00KojaC[00Co
0000ol0o`?o0?l3o00002_nbCK800ol0003oJ9MXofRGJ009ofRGJ003o`000?m3_4?o000000ko:m@[
00?o0000oaOX5olGj1L01OlGj1L00ol0003o2?L8o`Sg2004o`Sg2003o`000?m1_T7o@Ki100Ko@Ki1
00?o0000oh9mP_n2OH803On2OH800ol0003occ3?oll`c`0<oll`c`03o`000?oa3_7ol@ka00Sol@ka
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o[5>_ojaC[00GojaC[00?o0000ol0o`?o0?l000_o0
?l000ol0003o/Tfbok9=/P06ok9=/P03o`000?mXUfSoJ9MX00SoJ9MX0_l00003od>l@`03o`000?l[
e2_o:m@[00_o:m@[00?o0000oaOX5olGj1L01OlGj1L00ol0003o2?L8o`Sg2005o`Sg2003o`000?m1
_T7o@Ki100Go@Ki100?o0000oh9mP_n2OH803On2OH800ol0003occ3?oll`c`0;oll`c`03o`000?oa
3_7ol@ka00Wol@ka00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o[5>_ojaC[00KojaC[00?o0000
ol0o`?o0?l000oo0?l000ol0003o/Tfbok9=/P05ok9=/P03o`000?mXUfSoJ9MX00OoJ9MX00?o0000
od>l@om3_4<00om3_4<00ol0003o:m@[ob_D:`0:ob_D:`03o`000?lGj1Oo5nPG00Ko5nPG00?o0000
o`Sg2?l8m`P01_l8m`P00ol0003o@Ki1od6n@@04od6n@@03o`000?n2OH;oPWf200goPWf23ol0000;
oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o[5>_ojaC[00KojaC[00?o0000ol0o`?o0?l001Oo0?l000ol0
003o/Tfbok9=/P04ok9=/P03o`000?mXUfSoJ9MX00GoJ9MX0_l00006od>l@`03o`000?l[e2_o:m@[
00Wo:m@[0_l00008oaOX5`03o`000?l8m`So2?L800Ko2?L81Ol000000om1_T7o0000oh9mPP0?oh9m
PP03o`000?oA;]7odBkA00_odBkA00?o0000oo4>lOoa3_402Ooa3_400ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o[5>_ojaC[00KojaC[00?o0000ol0o`?o0?l001_o0?l000ol0003o
/Tfbok9=/P04o`0000KoJ9MX00?o0000od>l@om3_4<01om3_4<00ol0003o:m@[ob_D:`05ob_D:`?o
000000?o5nPGo`000?lGj1L01olGj1L00ol0003o2?L8o`Sg2005o`Sg2003o`000?m;]4_oBkA;00?o
BkA;0_l0000?oh9mPP;o00003OoA;]400ol0003ol@kaoo4>l@08oo4>l@03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WojaC[00?o0000ol0o`?o0?l001oo0?l02o`0000CoW6>L00Co0000ofRGJ?mXUfSo
J9MX0_l0000:od>l@`03o`000?l[e2_o:m@[00;o:m@[0ol00005oaOX5`03o`000?lGj1Oo5nPG00Go
5nPG00?o0000o`Sg2?l8m`P01?l8m`P00ol0003oBkA;od^dB`06od^dB`03o`000?n2OH;oPWf200[o
PWf20_l00002ojeB[@03o`000?oA;]7odBkA00[odBkA00?o0000oo4>lOoa3_402?oa3_400ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000on/Djoo[5>/01_o[5>/00ol0003o`3o0ol0o`008ol0o`003o`00
0?nLHicoW6>L00CoW6>L00?o0000ofRGJ?l000003?m3_4<00ol0003o:m@[o`000002o`0000Wo5nPG
00?o0000oaOX5olGj1L01?lGj1L00ol0003o2?L8o`Sg2003o`Sg2003o`000?m;]4_oBkA;00SoBkA;
1_l00004oh9mPP;o00001On]DZd00ol0003odBkAom4^d@09om4^d@03o`000?oa3_7ol@ka00Sol@ka
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o[5>_ojaC[00GojaC[00?o0000ol0o`?o0?l001oo0
?l000ol0003oW6>LoiaSW006oiaSW003o`000?m3_4?o@ka300co@ka300?o0000oaOX5olGj1L02_lG
j1L00ol0003o5nPGoaOX5`04oaOX5`04o`000?l8m`So2?L8o`Sg20;o00002om;]4/00ol0003oRGJ9
ohUfR@03ohUfR@Co00002?n]DZd00ol0003odBkAom4^d@08om4^d@03o`000?oa3_7ol@ka00Ool@ka
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000on/Djoo[5>/00oo[5>/00ol0003o`3o0ol0o`007ol0o`003o`000?nL
HicoW6>L00OoW6>L00?o0000od>l@om3_4<03?m3_4<00ol0003o5nPGoaOX5`0;oaOX5`03o`000?lG
j1Oo5nPG00?o5nPG00Co0000o`Sg2?l8m`So00003Om;]4/00ol0003oRGJ9ohUfR@06ohUfR@03o`00
0?n]DZgo[E:]00Oo[E:]00?o0000om4^dOoA;]401ooA;]400ol0003ol@kaoo4>l@06oo4>l@04o`00
0?om0_goo@;mood2o@;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o[5>_ojaC[00;ojaC[00?o0000ol0o`?o0?l00
1_o0?l000ol0003oW6>LoiaSW009oiaSW003o`000?m3_4?o@ka300Wo@ka30_l0000>oaOX5`?o0000
0olGj1L00ol0003o2?L8o`00000=od^dB`03o`000?n9MXWoRGJ900OoRGJ900?o0000ojeB[On]DZd0
2?n]DZd:o`0000Kol@ka0_l00006ood2o@03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo`3o000?o
0000oiaSW?nLHi`02_nLHi`00ol0003o@ka3od>l@`06od>l@`;o000000?o>l@ko`000?lGj1L02olG
j1L2o`0000?o?/4n1Ol0000>od^dB`03o`000?n9MXWoRGJ900OoRGJ900?o0000ojeB[On]DZd02?n]
DZd00ol0003ogB;MomdRg@06omdRg@03o`000?oa3_7ol@ka00?ol@ka00?o0000ood2oOom0_d01oom
0_d2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ogaoOomlOg`03omlOg`Co00000_o0?l000ol0003oW6>LoiaSW00;
oiaSW003o`000?m3_4?o@ka300?o@ka30ol00004oc_4>`03o`000?lGj1Oo5nPG00Oo5nPG0_l00008
ock1?P03o`000?m;]4_oBkA;00goBkA;00?o0000ohUfROn9MXT02?n9MXT00ol0003o[E:]ojeB[@07
ojeB[@03o`000?oM8]gogB;M00OogB;M0ol000000ooa3_7o0000ood2o@0;ood2o@;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oO7moogaoO00OogaoO0_l0000?oiaSW003o`000?m3_4?o@ka300;o00002?lka3/00ol0
003o5nPGoaOX5`05oaOX5`03o`000?ln`Cko?/4n00So?/4n00?o0000od^dBom;]4/03Om;]4/00ol0
003oRGJ9ohUfR@08ohUfR@03o`000?n]DZgo[E:]00Ko[E:]00?o0000omdRgOoM8]d02?oM8]d01?l0
003olPgboo8=l_l0000?ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ogaoOomlOg`09omlO
g`03o`000?nLHicoW6>L00koW6>L0_l0000;oc_4>`03o`000?lGj1Oo5nPG00;o5nPG0_l0000;ock1
?P03o`000?m;]4_oBkA;00goBkA;00?o0000ohUfROn9MXT02?n9MXT00ol0003o[E:]ojeB[@06ojeB
[@03o`000?oM8]gogB;M00OogB;M00Go0000oo8=l_ob3O;olPgbo`00000@ood2o@;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ogaoOomlOg`0:omlOg`03o`000?nLHicoW6>L00goW6>L0_l0000<oc_4>`04o`000?lGj1Oo0000
o`0000go?/4n00?o0000od^dBom;]4/03?m;]4/00ol0003oRGJ9ohUfR@09ohUfR@03o`000?n]DZgo
[E:]00Ko[E:]00?o0000omdRgOoM8]d01_oM8]d00ol0003olPgboo8=lP03oo8=lP03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ogaoOomlOg`0:omlOg`03o`000?nLHicoW6>L00coW6>L00Co0000ofn@
Kom_T6oo00003?lka3/00ol0003o?/4nock1?P0>ock1?P03o`000?m;]4_oBkA;00SoBkA;1?l0000;
ohUfR@03o`000?n]DZgo[E:]00Ko[E:]00?o0000omdRgOoM8]d01OoM8]d00ol0003olPgboo8=lP04
oo8=lP03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ogaoOomlOg`0;omlOg`03o`000?nLHicoW6>L
00_oW6>L00?o0000ofn@Kom_T6l00_m_T6l00ol0003o>l@koc_4>`09oc_4>`03o`000?ln`Cko?/4n
00ko?/4n00Co0000od^dBom;]4_oBkA;1ol00003oenPG`03o`000?n9MXWoRGJ900WoRGJ900?o0000
ojeB[On]DZd01_n]DZd00ol0003ogB;MomdRg@04omdRg@03o`000?ob3O;olPgb00KolPgb00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oO7moogaoO00cogaoO00?o0000oiaSW?nLHi`02_nLHi`00ol0
003oKi1_ofn@K`03ofn@K`03o`000?lka3_o>l@k00So>l@k00?o0000ock1?_ln`Ch03_ln`Ch4o`00
00_oGj1O00?o0000ohUfROn9MXT02?n9MXT00ol0003o[E:]ojeB[@05ojeB[@03o`000?oM8]gogB;M
00GogB;M00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000omlOgooO
7ml03?oO7ml7o`0000GoW6>L00?o0000ofn@Kom_T6l01Om_T6l00ol0003o>l@koc_4>`07oc_4>`03
o`000?ln`Cko?/4n00ko?/4n00?o0000oenPGomOX5l03OmOX5l00ol0003oRGJ9ohUfR@08ohUfR@03
o`000?n]DZgo[E:]00Co[E:]00?o0000omdRgOoM8]d01?oM8]d00ol0003olPgboo8=lP07oo8=lP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ogaoOomlOg`0=omlOg`03o`000?nl@kco_4>l00Co_4>l
1Ol00009ofn@K`03o`000?lka3_o>l@k00Ko>l@k00?o0000ock1?_ln`Ch03_ln`Ch00ol0003oGj1O
oenPG`0=oenPG`03o`000?n9MXWoRGJ900SoRGJ900Co0000ojeB[On]DZgo[E:]1Ol00004omdRg@03
o`000?ob3O;olPgb00WolPgb1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=omlOg`03o`000?nl@kco_4>l00Wo_4>l
0_l00009ofn@K`03o`000?lka3_o>l@k00Ko>l@k00?o0000ock1?_ln`Ch03?ln`Ch00ol0003oGj1O
oenPG`0?oenPG`Ko00001?n9MXT4o`0000GofBKI0_l000000ooM8]go0000oo8=lP0;oo8=lP04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o^4NkokQ7^onhAkP?o00002_oO7ml00ol0003o
_4>loka3_009oka3_003o`000?n5NXGo000000;o00001om_T6l00ol0003o>l@koc_4>`05oc_4>`03
o`000?ln`Cko?/4n00So?/4n1Ol0000AoenPG`03o`000?nIIYWoVFJI00?oVFJI1?l0000;omTVf@03
o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000onhAk_o^4Nh01Oo^4Nh2o`0000OogaoO
00?o0000oka3_?nl@k`02_nl@k`00ol0003oQGZ5ohEjQ@02ohEjQ@?o00001Om_T6l00ol0003o>l@k
oc_4>`04oc_4>`04o`000?ln`Cko?/4nock1?POo00001?m8]dP00ol0003oGj1OoenPG`0>oenPG`03
o`000?nIIYWoVFJI00OoVFJI00?o0000omTVfOoI9]T02OoI9]T00ol0003olPgboo8=lP09oo8=lP03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003okQ7^onhAkP08onhAkP;o00001?oO7ml00ol0003o_4>l
oka3_00;oka3_003o`000?n5NXGoQGZ500GoQGZ50ol00003ofn@K`04o`000?lka3_o>l@koc_4>`Ko
00003?m8]dP00ol0003oGj1OoenPG`0=oenPG`03o`000?nIIYWoVFJI00OoVFJI00?o0000omTVfOoI
9]T02_oI9]T00ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onhAkP?o000000?ogaoOo`000?nl@k`0
3?nl@k`00ol0003oQGZ5ohEjQ@08ohEjQ@?o000000CoKi1_o`000?l0003o00000_n>LHh00ol0003o
B;M8odRgB00=odRgB003o`000?mOX5ooGj1O00coGj1O00?o0000oiUVVOnIIYT02?nIIYT00ol0003o
fBKIomTVf@0;omTVf@03o`000?ob3O;olPgb00KolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
kQ7^00?o0000oka3_?nl@k`03?nl@k`00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n>LHkoSW6>00?o
SW6>00?o0000odRgB?m8]dP03?m8]dP00ol0003oAkQ7o`00000=oenPG`03o`000?nIIYWoVFJI00So
VFJI00?o0000omTVfOoI9]T03?oI9]T3o`0000GolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o^4NkokQ7^00cokQ7^00?o0000oka3_?nl@k`03?nl@k`00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`00
0?n>LHkoSW6>00GoSW6>00?o0000odRgB?m8]dP02_m8]dP01?l0003oAkQ7odNhAom7^4L2o`0000[o
Gj1O00?o0000oiUVVOnIIYT02OnIIYT00ol0003ofBKIomTVf@0<omTVf@03o`000?od2oCom0_d00?o
000000?olPgbo`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000oka3_?nl@k`0
3?nl@k`00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?n>LHkoSW6>00KoSW6>00?o0000odRgB?m8]dP0
2Om8]dP00ol0003oAkQ7odNhA`02odNhA`03o`000?n>LHko000000;o00001omOX5l00ol0003oVFJI
oiUVV@09oiUVV@03o`000?oI9]WofBKI00_ofBKI00?o0000oo@;m?od2o@01?od2o@00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02oo^4Nh00ol0003o_4>loka3_00;oka3_003o`000?n5
NXGoQGZ500SoQGZ500?o0000ohiaS_n>LHh01on>LHh00ol0003oB;M8odRgB008odRgB003o`000?m7
^4OoAkQ700?oAkQ700?o0000ohiaS_n>LHh00_n>LHh2o`0000CoGj1O00?o0000oiUVVOnIIYT02_nI
IYT00ol0003ofBKIomTVf@0:omTVf@03o`000?od2oCom0_d00Gom0_d00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o^4NkokQ7^00[okQ7^0ol0000;oka3_0Ko00001?n5NXD00ol0003oSW6>ohiaSP08
ohiaSP03o`000?m8]dSoB;M800OoB;M800?o0000odNhAom7^4L00om7^4L00ol0003oSW6>ohiaSP05
ohiaSP?o000000?oGj1Oo`000?nIIYT02onIIYT00ol0003ofBKIomTVf@09omTVf@03o`000?od2oCo
m0_d00Oom0_d00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o^4NkokQ7^00WokQ7^00?o0000omPW
f?oH9mP01?l00006oka3_003o`000?niA[Wo^DJi00Co^DJi1?l0000<ohiaSP03o`000?m8]dSoB;M8
00GoB;M800?o0000odNhAom7^4L01?m7^4L00ol0003oSW6>ohiaSP08ohiaSP03o`000?nIIYWoVFJI
00_oVFJI00?o0000omTVfOoI9]T02?oI9]T00ol0003om0_doo@;m008oo@;m0Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o^4NkokQ7^00OokQ7^00?o0000omPWf?oH9mP01OoH9mP3o`0000;o_4>l00?o0000okU6^Oni
A[T02?niA[T00ol0003oSW6>ohiaSP0:ohiaSP03o`000?m8]dSoB;M800CoB;M800?o0000odNhAom7
^4L01Om7^4L00ol0003oSW6>ohiaSP08ohiaSP03o`000?nIIYWoVFJI00WoVFJI1?l00008omTVf@03
o`000?od2oCom0_d00Wom0_d00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^
onhAkP05onhAkP03o`000?oH9mSof2OH00Wof2OH0_l0000<okU6^@03o`000?n>LHkoSW6>00WoSW6>
00?o0000odRgB?m8]dP00om8]dP00ol0003oAkQ7odNhA`05odNhA`03o`000?n>LHkoSW6>00[oSW6>
00?o0000oiUVVOnIIYT01?nIIYT4o`0000Cod2o@00?o0000omTVfOoI9]T01?oI9]T00ol0003om0_d
oo@;m00:oo@;m003o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o^4NkokQ7^00?okQ7^00?o0000omPWf?oH9mP02ooH
9mP00ol0003o^DJiokU6^@0:okU6^@03o`000?n>LHkoSW6>00WoSW6>00?o0000odRgB?m8]dP00_m8
]dP00ol0003oAkQ7odNhA`06odNhA`03o`000?n>LHkoSW6>00[oSW6>00?o0000oiUVVOnIIYT01?l0
0009om0_d0Ko00003?od2o@00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000onhAk_o^4NkokQ7^0_l0
000=omPWf003o`000?niA[Wo^DJi00[o^DJi00?o0000ohiaS_n>LHh02On>LHh01Ol0003oB;M8odRg
B?m8]dSo000000WoAkQ700?o0000ohiaS_n>LHh02on>LHh2o`0000god2o@00?o0000oo4>lOoa3_40
0_oa3_400ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003okQ7^o`00
0002ooH9mP;o00002ooH9mP00ol0003o^DJiokU6^@0;okU6^@03o`000?n>LHkoSW6>00WoSW6>00?o
0000odRgB?l000002Om7^4L00ol0003oSW6>ohiaSP0<ohiaSP03o`000?o@;m3od2o@00cod2o@00?o
0000oo4>lOoa3_400ooa3_400ol0003om0_doo@;m009oo@;m003o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003omPWfooH9mP03ooH9mP;o00002_oH9mP00ol0003o^DJiokU6^@0:okU6^@03o`000?n>LHko
SW6>00SoSW6>1Ol00008odNhA`03o`000?n>LHkoSW6>00coSW6>00?o0000om0_d?o@;m002oo@;m00
0ol0003ol@kaoo4>l@05oo4>l@03o`000?od2oCom0_d00Som0_d00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001oof2OH2o`0000Sof2OH00?o0000okU6^OniA[T02_niA[T00ol0003oSW6>ohiaSP07ohia
SP03o`000?n;M8_oRgB;00?oRgB;0ol00005odNhA`03o`000?n>LHkoSW6>00_oSW6>00?o0000om0_
d?o@;m003?o@;m000ol0003ol@kaoo4>l@06oo4>l@03o`000?od2oCom0_d00Oom0_d00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000WomPWf00?o0000omPWf?oH9mP01OoH9mP2o`0000co
^DJi00?o0000ohiaS_n>LHh01On>LHh00ol0003oRgB;oh]dR`07oh]dR`?o000000?oAkQ7o`000?n>
LHh03On>LHh00ol0003od2o@om0_d00<om0_d003o`000?oa3_7ol@ka00Kol@ka00?o0000oo@;m?od
2o@01_od2o@00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?of2OKomPWf00OomPWf
0_l00004omPWf003o`000?oR7N;ohQgR00;o00002_niA[T00ol0003oSW6>ohiaSP03ohiaSP;o0000
3On;M8/2o`0000goSW6>0ol0000=om0_d003o`000?oa3_7ol@ka00Ool@ka00?o0000oo@;m?od2o@0
1Ood2o@00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?of2OKomPWf00SomPWf0_l0
00000ooH9mSo0000on8MhP04on8MhP03o`000?niA[Wo^DJi00Oo^DJi00Co0000ohiaS_n>LHkoSW6>
0_l00002ok]4^`03o`000?n;M8_oRgB;00coRgB;3Ol00003olXebP03o`000?o@;m3od2o@00[od2o@
00?o0000oo4>lOoa3_402?oa3_401?l0003om0_doo@;m?od2o@4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003omPWf
ooH9mP09ooH9mP03o`000?oR7N;ohQgR00GohQgR0_l00008okU6^@03o`000?n>LHko000000Go^dBk
00?o0000oh]dRon;M8/02on;M8/00ol0003oVFJIoiUVV@09oiUVV@03o`000?o:=L[obSG:00;obSG:
0_l00009om0_d003o`000?oa3_7ol@ka00[ol@ka0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?of2OKomPWf00SomPWf00?o0000on8Mh_oR7N801ooR7N84o`0000?o^DJi0ol0
0007ok]4^`03o`000?n;M8_oRgB;00[oRgB;00?o0000oiUVVOnIIYT02OnIIYT00ol0003obSG:olXe
bP04olXebP;o00001oo@;m000ol0003ol@kaoo4>l@0:oo4>l@03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?of2OKomPWf00OomPWf00?o0000on8Mh_oR7N802?oR7N80
1?l0003oh1oPon0Oh?oP7n03o`0000;odRgB00?o0000ok]4^onkA;/01_nkA;/00ol0003oRgB;oh]d
R`08oh]dR`03o`000?nIIYWoVFJI00[oVFJI00?o0000olXeb_o:=LX01_o:=LX00ol0003od2o@om0_
d004om0_d003o`000?oa3_7ol@ka00Wol@ka00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003ohQgRon8MhP08on8MhP03o`000?oP7n3o
h1oP00Coh1oP00Go0000om8]d_oB;M;odRgBo`000008ok]4^`03o`000?n;M8_oRgB;00OoRgB;00?o
0000oiUVVOnIIYT02_nIIYT00ol0003obSG:olXebP07olXebP;o00001?o@;m000ol0003ol@kaoo4>
l@08oo4>l@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooH9m_of2OH00oof2OH0
0ol0003ohQgRon8MhP08on8MhP03o`000?oP7n3oh1oP00Coh1oP00?o0000om8]d_oB;M800_oB;M80
0ol0003o^dBkok]4^`07ok]4^`03o`000?n;M8_oRgB;00KoRgB;00?o0000oiUVVOnIIYT02_nIIYT0
0ol0003obSG:olXebP09olXebP05o`000?o@;m3od2o@om0_d?l000002Ooa3_400ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_ohQgR00?o0000on0Oh?oP7n001?oP7n000ol0003odRgBom8]dP03
om8]dP03o`000?nkA;_o^dBk00Oo^dBk00?o0000oh]dRon;M8/01On;M8/00ol0003oVFJIoiUVV@0:
oiUVV@03o`000?o:=L[obSG:00WobSG:1?l00009oo4>l@03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?og2?Oom`Sg
ooL8mol000002_oR7N800ol0003oh1oPon0Oh005on0Oh003o`000?oB;M;odRgB00?odRgB00?o0000
ok]4^onkA;/02?nkA;/00ol0003oRgB;oh]dR`04oh]dR`03o`000?nIIYWoVFJI00WoVFJI00?o0000
olXeb_o:=LX02?o:=LX2o`0000?ol@ka00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L00oog2?L00ol0003ohQgRon8MhP06on8MhP03o`000?oP7n3oh1oP
00Goh1oP00?o0000om8]d_oB;M801?oB;M800ol0003o^dBkok]4^`09ok]4^`03o`000?n;M8_oRgB;
00;oRgB;00?o0000oiUVVOnIIYT02_nIIYT00ol0003obSG:olXebP06olXebP;o00001_oa3_48o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oR7N;ohQgR00GohQgR00?o0000on0Oh?oP
7n001OoP7n000ol0003odRgBom8]dP05om8]dP03o`000?nkA;_o^dBk00Wo^dBk00Go0000oh]dRon;
M8_oRgB;o`00000<oiUVV@03o`000?o:=L[obSG:00CobSG:0_l00008oo4>l@03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on8Mh_oR
7N800ooR7N800ol0003oh1oPon0Oh006on0Oh003o`000?oB;M;odRgB00GodRgB00?o0000ok]4^onk
A;/02_nkA;/00ol0003oRgB;o`000004o`0000WoVFJI00?o0000olXeb_o:=LX00_o:=LX2o`0000[o
l@ka00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om`SgooL8m`07ooL8m`03o`00
0?oR7N;ohQgR00;ohQgR00?o0000on0Oh?oP7n001_oP7n000ol0003odRgBom8]dP07om8]dP;o0000
2onkA;/00ol0003ofBKIomTVf@03omTVf@Oo00000_nIIYT00ol0003obSG:olXebP02o`0000_ol@ka
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooL8moog2?L02Oog
2?L01Ol0003ohQgRon8Mh_oR7N;o000000Soh1oP00?o0000om8]d_oB;M801ooB;M800ol0003ojQGZ
o`000002o`0000So^dBk00?o0000omTVfOoI9]T02_oI9]T5o`0000gol@ka00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooL8m`03o`000?oR7N;o000000Woh1oP00?o
0000om8]d_oB;M801_oB;M800ol0003ojQGZonXEjP03onXEjP?o00001?nkA;/00ol0003ofBKIomTV
f@0=omTVf@03o`000?oa3_7ol@ka00gol@ka00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_om`Sg00?o0000on0Oh?oP7n001ooP7n000ol0003odRgBom8]dP07
om8]dP03o`000?oZ5N[ojQGZ00KojQGZ0ol000000onkA;_o0000omTVf@0>omTVf@03o`000?oa3_7o
l@ka00col@ka00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooL8
m`03o`000?oP7n3oh1oP00;oh1oP1_l00008om8]dP03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000omTV
fOoI9]T03ooI9]T00ol0003ol@kaoo4>l@0:oo4>l@;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooL8m`Go00001_oc3?<00ol0003odRgBom8]dP05om8]dP03o`000?oZ5N[ojQGZ00[o
jQGZ00?o0000omTVfOoI9]T03ooI9]T00ol0003ol@kaoo4>l@07oo4>l@?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooL8m`03o`000?oc3??ol`cc00Wol`cc00?o0000om8]d_oB
;M800ooB;M800ol0003ojQGZonXEjP0;onXEjP03o`000?oI9]WofBKI00oofBKI00?o0000oo4>lOoa
3_401Ooa3_42o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?om`Sgo`000?l00000
3Ooc3?<00ol0003odRgBom8]dP02om8]dP03o`000?oZ5N[ojQGZ00_ojQGZ5?l00004oo4>l@;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo<<l`04o`000?oB;M;odRgBo`0000kojQGZ
00?o0000ooD:mOoe2_D04?oe2_D00ol0003ol@kao`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_oc3?<00ol0003odRgBo`00000>onXEjP03o`00
0?oe2_Gom@[e017om@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oZ5N[ojQGZ00WojQGZ1Ol0
000BooD:m@;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?oZ5N[ojQGZ00;ojQGZ1ol00004ood2o@03o`000?oe2_Go
m@[e00oom@[e00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?oc3??ol`cc00col`cc1?l0000<ood2o@03o`000?oe2_Gom@[e00com@[e0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo<<looc3?<03?oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?oe2_Gom@[e00_o
m@[e00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003ol`ccoo<<l`0:oo<<l`03o`000?om0_goo@;m00koo@;m00?o0000ooD:mOoe
2_D02Ooe2_D2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003oo@;m
ood2o@0?ood2o@03o`000?oe2_Gom@[e00Kom@[e0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aood2o@?o00001_oe2_D00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooe2_D2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooD:mOl000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`Woool00ol00?l3oooo00co003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l8oooo00Go003o0oooo`09o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000So003o00?oool0o`00ool00?l00ol00?l2oooo00Ko003o0oooo`06o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002Ol00?l00oooo`3o003oo`00o`03o`00o`03oooo0?l00?oo003o
00Go003o0oooo`05o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0009o`00o`;oool03Ol00?l2oooo00Go
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02_l00?l00oooo`3o003oo`00o`0<o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00_o003o00?oool0o`00ool00?l02ol00?l2oooo00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00co003o00?oool0o`00ool00?l01Ol00?l5oooo0003o`00ooooo`3oool000;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00co003o0_ooo`05o`00o`;oool01?l00?l3oooo00;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l0
0?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`02o`00o`?oool01Ol0
0?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05
o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`00
0ol00?ooool0o`00o`02oooo00go003o0_ooo`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06
o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00ooo
o`3o003oo`00o`0Go`00o`;oool03Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo
00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo00Go003o0oooo`05o`00o`03
oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00o`;o
ool01_l00?l2oooo00;o003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7o
oooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01_l00?l2oooo00Go003o
0_ooo`03o`00o`;oool01_l00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Oo003o
0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l2oooo0003oc8bc?l00?oo003o00Co003o0_ooo`03o`00o`?oool01?l00?l00oooo`3o003oo`00
o`03o`00o`;oool01?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?ooo`3oool006Oo003o0Ooo
ool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`Goool01Ol00?l6
oooo00Go003o0_ooo`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol00?l1
ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo027o003o1?ooo`08o`00
o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(300) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.991 .009 .991 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.992 .008 .992 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.992 .008 .992 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.991 .009 .991 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.958 .042 .958 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.99 .01 .99 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.958 .042 .958 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.953 .047 .953 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.93 .07 .93 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.985 .015 .985 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.915 .085 .915 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.991 .009 .991 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.841 .159 .841 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.854 .146 .854 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.755 .245 .755 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.893 .107 .893 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.984 .016 .984 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.987 .013 .987 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.954 .046 .954 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.566 .434 .566 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.891 .109 .891 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.765 .235 .765 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.756 .244 .756 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.809 .191 .809 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.899 .101 .899 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.933 .067 .933 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.737 .263 .737 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.877 .123 .877 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.619 .381 .619 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.922 .078 .922 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.88 .12 .88 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.806 .194 .806 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.867 .133 .867 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.674 .326 .674 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.912 .088 .912 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.765 .235 .765 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.994 .006 .994 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.936 .064 .936 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.69 .31 .69 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.358 .642 .358 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.417 .583 .417 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.964 .036 .964 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.967 .033 .967 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.855 .145 .855 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.991 .009 .991 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.717 .283 .717 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.712 .288 .712 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.448 .552 .448 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.457 .543 .457 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.278 .722 .278 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.689 .311 .689 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.743 .257 .743 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.992 .008 .992 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.722 .278 .722 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.62 .38 .62 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.947 .053 .947 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.423 .577 .423 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.89 .11 .89 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.83 .17 .83 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.446 .554 .446 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.282 .718 .282 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.571 .429 .571 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.047 .953 .047 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.077 .923 .077 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.253 .747 .253 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.408 .592 .408 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.419 .581 .419 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.885 .115 .885 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.201 .799 .201 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.226 .774 .226 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.736 .264 .736 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.952 .048 .952 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.99 .01 .99 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.214 .786 .214 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.273 .727 .273 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.541 .459 .541 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.99 .01 .99 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.689 .311 .689 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.312 .688 .312 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.459 .541 .459 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.071 .929 .071 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.449 .551 .449 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.242 .758 .242 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.953 .047 .953 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.136 .864 .136 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.029 .971 .029 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.833 .167 .833 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.074 .926 .074 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.038 .962 .038 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.566 .434 .566 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.902 .098 .902 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.249 .751 .249 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.057 .943 .057 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.437 .563 .437 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.11 .89 .11 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.171 .829 .171 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.919 .081 .919 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.042 .958 .042 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.989 .011 .989 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.144 .856 .144 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.093 .907 .093 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.743 .257 .743 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.239 .761 .239 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.307 .693 .307 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.099 .901 .099 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.121 .879 .121 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.176 .824 .176 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.06 .94 .06 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.026 .974 .026 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.294 .706 .294 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.558 .442 .558 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.99 .01 .99 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.779 .221 .779 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.198 .802 .198 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.274 .726 .274 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.296 .704 .296 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.955 .045 .955 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.09 .91 .09 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.02 .98 .02 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.213 .787 .213 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.615 .385 .615 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.032 .968 .032 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.991 .009 .991 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.088 .912 .088 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.855 .145 .855 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.959 .041 .959 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.568 .432 .568 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.615 .385 .615 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.143 .857 .143 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.891 .109 .891 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.055 .945 .055 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.294 .706 .294 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.51 .49 .51 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.099 .901 .099 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.251 .749 .251 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.377 .623 .377 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.99 .01 .99 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.005 .995 .005 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.99 .01 .99 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.93 .07 .93 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.228 .772 .228 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.19 .81 .19 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.059 .941 .059 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.802 .198 .802 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.198 .802 .198 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.948 .052 .948 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.24 .76 .24 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.262 .738 .262 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.271 .729 .271 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.612 .388 .612 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.751 .249 .751 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.549 .451 .549 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.056 .944 .056 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.131 .869 .131 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.233 .767 .233 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.521 .479 .521 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.821 .179 .821 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.991 .009 .991 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.941 .059 .941 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.202 .798 .202 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.303 .697 .303 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.227 .773 .227 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.822 .178 .822 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.691 .309 .691 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.99 .01 .99 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.536 .464 .536 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.857 .143 .857 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.947 .053 .947 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.145 .855 .145 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.251 .749 .251 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.933 .067 .933 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.191 .809 .191 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.621 .379 .621 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.573 .427 .573 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.445 .555 .445 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.395 .605 .395 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.882 .118 .882 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.821 .179 .821 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.83 .17 .83 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.872 .128 .872 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.371 .629 .371 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.959 .041 .959 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.789 .211 .789 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.379 .621 .379 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.403 .597 .403 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.991 .009 .991 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.677 .323 .677 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.488 .512 .488 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.99 .01 .99 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.952 .048 .952 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.837 .163 .837 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.948 .052 .948 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.382 .618 .382 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.924 .076 .924 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.771 .229 .771 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.68 .32 .68 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.991 .009 .991 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.655 .345 .655 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.533 .467 .533 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.991 .009 .991 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.744 .256 .744 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.986 .014 .986 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.992 .008 .992 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.579 .421 .579 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.988 .012 .988 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.599 .401 .599 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.989 .011 .989 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.727 .273 .727 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.862 .138 .862 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.767 .233 .767 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.903 .097 .903 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.923 .077 .923 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.794 .206 .794 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.657 .343 .657 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.78 .22 .78 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.875 .125 .875 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.922 .078 .922 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.89 .11 .89 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.902 .098 .902 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.986 .014 .986 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.804 .196 .804 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.948 .052 .948 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.989 .011 .989 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.96 .04 .96 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.94 .06 .94 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.814 .186 .814 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.951 .049 .951 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.924 .076 .924 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.883 .117 .883 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.937 .063 .937 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.99 .01 .99 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.989 .011 .989 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.99 .01 .99 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.989 .011 .989 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.99 .01 .99 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004oo`3o0?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_ol0o`2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00<oo`3o003
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol0o`03_ol
0o`00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003ol0o`oo0?l?l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo0?l?o`3o000_o`3o000ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?o`3o3ol0o`00?ol0o`00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo0?l?o`3o001Oo`3o000ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l006oo0?l003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo0?loo`3o00@oo`3o003
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000oo`3o?ol0o`04?ol0o`<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oc3??o0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000col0o`00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?ol0ocoo0?l00ooo0?l
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003oo<<l`03o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP05onhAkP03o`000?o`
3o3ol0o`00_ol0o`0ol00003onhAkP03o`000?om0_goo@;m00coo@;m0ol0000>oo`3o0;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
oo<<looc3?<00ooc3?<00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003okQ7^onhAkP06
onhAkP03o`000?o`3o3ol0o`00[ol0o`00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oo@;mood2o@0:
ood2o@04o`000?o/4ncok1?/on`Ck0;o00002_ol0o`2o`000003on`Ck?l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?om0_go
o@;m00Woo@;m00?o0000oo@;m?l000002oom0_d00ol0003okQ7^onhAkP06onhAkP03o`000?o`3o3o
l0o`00Wol0o`00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oo@;mood2o@08ood2o@03o`000?o/4nco
k1?/00Cok1?/0_l00005oo`3o0?o00001?o/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008oo<<l`03o`000?om0_goo@;m00Ooo@;m0_l00003oo@;
m003o`000?om0_goo@;m00Ooo@;m00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ol0o`oo0?l009oo0?
l003o`000?o^4NkokQ7^00OokQ7^00?o0000ood2oOom0_d01Oom0_d2o`0000Wok1?/0_l000000ool
0oco0000o`000007on`Ck003o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000oo<<looc
3?<02?oc3?<00ol0003oo@;mood2o@06ood2o@03o`000?od2oCom0_d00?om0_d00?o0000ood2oOom
0_d01oom0_d00ol0003okQ7^onhAkP08onhAkP03o`000?o`3o3ol0o`00Ool0o`00?o0000onhAk_o^
4Nh02Oo^4Nh00ol0003oo@;mood2o@03ood2o@03o`000?o/4ncok1?/00_ok1?/00?o0000on`Ck?o/
4n`01oo/4n`00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003olPgbo`000005ood2o@;o00002ooc3?<2o`0000Koo@;m
00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@06ood2o@03o`000?o^4NkokQ7^00SokQ7^
00?o0000oo0?l?o`3o001_o`3o000ol0003okQ7^onhAkP0;onhAkP05o`000?om0_goo@;mood2oOl0
00003_o/4n`00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?ob3O;olPgboo8=l_l0
00000oom0_d00ol0003ol`ccoo<<l`0:oo<<l`04o`000?oV6NKoiQWVo`0000?oo@;m0_l00008oo@;
m003o`000?om0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003ol0o`oo0?l005oo0?
l003o`000?o^4NkokQ7^00cokQ7^00?o0000ood2oOl000003oo/4n`00ol0003ok1?/on`Ck008on`C
k003o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP03oo8=lP03o`000?om0_go000000_o
l`cc0_l00004onHIiP03o`000?om0_go000000_om0_d00?o0000ood2oOom0_d01Oom0_d00ol0003o
kQ7^onhAkP09onhAkP03o`000?o`3o3ol0o`00Col0o`00?o0000onhAk_o^4Nh03_o^4Nh00ol0003o
k1?/on`Ck00>on`Ck003o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo8=l_ob3O80
1?ob3O800ol0003ol`ccoo<<l`09oo<<l`03o`000?oV6NKoiQWV00GoiQWV00?o0000oo@;m?od2o@0
2_od2o@00ol0003oo@;mood2o@05ood2o@03o`000?o^4NkokQ7^00[okQ7^00?o0000oo0?l?o`3o00
0oo`3o000ol0003okQ7^onhAkP0>onhAkP03o`000?o/4ncok1?/00gok1?/00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=
lP05oo8=lP03o`000?oc3??ol`cc00Ool`cc0_l00008onHIiP03o`000?od2oCom0_d00_om0_d00?o
0000ood2oOom0_d01?om0_d00ol0003okQ7^onhAkP0:onhAkP04o`000?o`3o3ol0o`oo0?l0?o0000
3oo^4Nh00ol0003ok1?/on`Ck00>on`Ck003o`000?o/4ncok1?/00[ok1?/00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?ob3O;olPgb00OolPgb00?o0000oo<<looc3?<01?oc3?<2o`0000_oiQWV1?l0
0009oo@;m003o`000?om0_goo@;m00?oo@;m00?o0000onhAk_o^4Nh02oo^4Nh01?l0003ol0o`o`00
0?l00003om8]dP;o00003?o^4Nh2o`00013ok1?/00?o0000on`Ck?o/4n`02oo/4n`00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003olPgb
oo8=lP07oo8=lP03o`000?oc3??ol`cc00?ol`cc00?o0000onHIi_oV6NH02ooV6NH01?l0003oacS7
olLhaoo7><L5o`0000Gom0_d00?o0000ood2oOom0_d00_om0_d00ol0003okQ7^onhAkP0<onhAkP03
o`000?oB;M;odRgB00GodRgB0_l00008onhAkP;o00000_o9=/T00ol0003ok1?/on`Ck00=on`Ck003
o`000?o/4ncok1?/00_ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003olPgboo8=lP09oo8=lP03o`000?oc3??ol`cc00;o0000
3OoV6NH00ol0003oacS7olLha`07olLha`Ko00000_om0_d4o`0000gokQ7^00?o0000om8]d_oB;M80
1ooB;M82o`0000GokQ7^00?o0000olTfbOo9=/T00oo9=/T00ol0003ok1?/on`Ck00<on`Ck003o`00
0?o/4ncok1?/00cok1?/00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?ob3O;olPgb00WolPgb00?o
0000oo<<lol000003ooV6NH00ol0003oacS7olLha`0<olLha`?o00001?oT6n@3o`0000WokQ7^00?o
0000om8]d_oB;M802_oB;M82o`000003onhAk_l0003o000000OobCK900?o0000on`Ck?o/4n`02oo/
4n`00ol0003ok1?/on`Ck00<on`Ck003o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?ob3O;olPgb00_olPgb00?o0000
onHIi_oV6NH03_oV6NH00ol0003oacS7olLha`0=olLha`03o`000?oT6nCoi1_T00Koi1_T0ol00005
onhAkP03o`000?oB;M;odRgB00godRgB00?o0000olTfbOo9=/T02?o9=/T00ol0003ok1?/on`Ck009
on`Ck003o`000?o/4ncok1?/00gok1?/00Co0000ood2oOom0_goo@;m1Ol00003oo0?l003o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo8=l_ob3O802oob3O82o`0000ooiQWV00?o0000olLhaoo7><L03Oo7><L00ol0003oi1_Ton@Ki00:
on@Ki0?o000000?okQ7^o`000?oB;M803ooB;M800ol0003obCK9olTfb@09olTfb@03o`000?o/4nco
k1?/00Sok1?/00?o0000on`Ck?o/4n`03_o/4n`3o`0000Sol0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?ob3O;olPgb00SolPgb0ol000000ooD
:mCo0000onHIiP0>onHIiP03o`000?o7><OoacS700goacS700?o0000on@Ki?oT6n@03OoT6n@00ol0
003odRgBom8]dP0?om8]dP03o`000?o9=/WobCK900[obCK92ol0000;on`Ck0Go00003?o`3o000ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02_om0_d01Ol0003oka3_o`000?om0_go0000
00SolPgb0ol00005om@[e003o`000?oV6NKoiQWV00coiQWV00?o0000olLhaoo7><L03Oo7><L00ol0
003oi1_Ton@Ki00=on@Ki0;o00004?oB;M800ol0003obCK9olTfb@0:olTfb@03o`000?o5>/GoaC[5
00OoaC[500?o0000on`Ck?o/4n`00_o/4n`7o`0000CobcC;00?o0000oo0?l?o`3o002_o`3o000ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d01?l0003oka3_onl@koo_4>l2o`00
00GolPgb0ol00009om@[e0;o00002ooV6NH00ol0003oacS7olLha`0=olLha`03o`000?oT6nCoi1_T
00goi1_T00Co0000ol0o`?o0?l3o00003ooB;M800ol0003obCK9olTfb@09olTfb@03o`000?o5>/Go
aC[500WoaC[51?l0000;ol/db`03o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?om0_goo@;m00Soo@;m00?o0000onl@koo_4>l01?o_4>l00ol0003olPgbo`000002o`00
00coe2_D00Co0000ok1?/?l0003o00002OoV6NH00ol0003oacS7olLha`0=olLha`03o`000?oT6nCo
i1_T00goi1_T00Go0000ol0o`?o0?l3o`3o0o`00000=om8]dP03o`000?o9=/WobCK900[obCK900?o
0000olDjaOo5>/D02Oo5>/D00ol0003obcC;ol/db`0<ol/db`03o`000?o`3o3ol0o`00[ol0o`00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00Ooo@;m00?o0000onl@koo_4>l01_o_4>l0
0ol0003oe2_Dom@[e00<om@[e003o`000?n`Ck3o/4n`00;o/4n`0_l00007onHIiP03o`000?o7><Oo
acS700coacS700?o0000on@Ki?oT6n@03OoT6n@00ol0003o`3o0ol0o`003ol0o`003o`000?oB;M;o
dRgB00[odRgB00?o0000olTfbOo9=/T02_o9=/T00ol0003oaC[5olDja@09olDja@03o`000?o;=<_o
bcC;00cobcC;00?o0000oo0?l?o`3o002oo`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2
oOom0_d01_om0_d00ol0003oka3_onl@k`06onl@k`03o`000?oD:mCoe2_D00_oe2_D00?o0000ok1?
/?n`Ck001On`Ck000ol0003oiQWVonHIiP03onHIiP03o`000?o7><OoacS700goacS700?o0000on@K
i?oT6n@03OoT6n@00ol0003o`3o0ol0o`004ol0o`003o`000?oB;M;odRgB00WodRgB00?o0000olTf
bOo9=/T02Oo9=/T00ol0003oaC[5olDja@0:olDja@03o`000?o;=<_obcC;00cobcC;00?o0000oo0?
l?o`3o002oo`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d01Oom0_d00ol0003o
ka3_onl@k`07onl@k`03o`000?oD:mCoe2_D00_oe2_D00?o0000ok1?/?n`Ck001_n`Ck02o`0000?o
iQWV00?o0000olLhaoo7><L03Oo7><L00ol0003oi1_Ton@Ki00<on@Ki003o`000?o0?l3o`3o000Ko
`3o000?o0000om8]d_oB;M802?oB;M800ol0003obCK9olTfb@09olTfb@03o`000?o5>/GoaC[500[o
aC[500?o0000ol/dboo;=</03?o;=</00ol0003ol0o`oo0?l00;oo0?l003o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?om0_goo@;m00Coo@;m00?o0000onl@koo_4>l02?o_4>l00ol0003oe2_Dom@[e00:om@[e003o`00
0?n`Ck3o/4n`00Wo/4n`0_l000000ooV6NKo0000olLha`0<olLha`?o00003_oT6n@00ol0003o`3o0
ol0o`007ol0o`003o`000?oB;M;odRgB00OodRgB00?o0000olTfbOo9=/T02Oo9=/T00ol0003oaC[5
olDja@0;olDja@03o`000?o;=<_obcC;00cobcC;00?o0000oo0?l?o`3o002_o`3o000ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000onl@koo_4>l02_o_4>l00ol0003oe2_Dom@[
e009om@[e003o`000?n`Ck3o/4n`00_o/4n`00?o0000olLhaoo7><L02_o7><L2o`0000?oWF:M00?o
0000on@Ki?oT6n@02_oT6n@00ol0003o`3o0ol0o`009ol0o`003o`000?oB;M;odRgB00KodRgB00?o
0000olTfbOo9=/T02?o9=/T00ol0003oaC[5olDja@0<olDja@03o`000?o;=<_obcC;00cobcC;00?o
0000oo0?l?o`3o002_o`3o000ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003oo@;mood2o@02ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000om@[e?oD:m@02?oD:m@0
0ol0003o/4n`ok1?/00<ok1?/003o`000?o7><OoacS700SoacS70_l00006oieRW@;o00002_oT6n@0
0ol0003o`3o0ol0o`00:ol0o`003o`000?oB;M;odRgB00GodRgB00?o0000olTfbOo9=/T02?o9=/T0
0ol0003oaC[5olDja@0<olDja@03o`000?o;=<_obcC;00cobcC;00?o0000oo0?l?o`3o002oo`3o00
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ood2oOom0_goo@;mo`00000=
onl@k`03o`000?oD:mCoe2_D00Ooe2_D00?o0000ok1?/?n`Ck003_n`Ck000ol0003oacS7olLha`04
olLha`?o00002_nMHYd00ol0003oi1_Ton@Ki007on@Ki003o`000?o0?l3o`3o000_o`3o000?o0000
om8]d_oB;M800ooB;M800ol0003obCK9olTfb@09olTfb@03o`000?o5>/GoaC[500coaC[500?o0000
ol/dboo;=</03?o;=</00ol0003ol0o`oo0?l00;oo0?l0;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003oka3_onl@k`0<onl@k`03o`000?oD:mCoe2_D00Ooe2_D00?o0000ok1?/?n`Ck003on`Ck001?l0
003oacS7olLhaoo7><L2o`0000koWF:M0_l00006on@Ki003o`000?o0?l3o`3o000go`3o000?o0000
om8]d_oB;M800_oB;M800ol0003obCK9olTfb@08olTfb@03o`000?o5>/GoaC[500coaC[50ol0000=
ol/db`03o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ooka3_00?o0000om@[e?oD:m@01_oD:m@00ol0003o/4n`ok1?/00@ok1?/0Co00004_nMHYd00ol0
003oi1_Ton@Ki003on@Ki003o`000?o0?l3o`3o000ko`3o000Go0000om8]d_oB;M;odRgBo`000005
olTfb@Oo00003?o5>/D01Ol0003oVFJIoiUVVOnIIYWo000000cobcC;00?o0000oo0?l?o`3o002?o`
3o03o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ooka3_00?o0000om@[e?oD:m@01_oD:m@00ol0003o/4n`ok1?/00=
ok1?/0?o000000CoLXebo`000?l0003o00004onMHYd2o`0000;oi1_T00?o0000ol0o`?o0?l004?o0
?l000ol0003odRgBo`000006o`0000Oo[E:]00?o0000olDjaOo5>/D02?o5>/D00ol0003oVFJIoiUV
V@03oiUVV@;o00002?o;=</3o`0000Kol0o`1?l00002on`Ck003o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003om0_do`000?o><Lh3o`0000goka3_00?o0000om@[e?oD:m@01?oD:m@00ol0003o/4n`ok1?
/00;ok1?/0?o00000ombSG801Ol0003oKi1_o`000?m>/Dko000001CoWF:M00?o0000on@Ki?l00000
4oo0?l000ol0003o[E:]ojeB[@0=ojeB[@03o`000?o5>/GoaC[500GoaC[50_l00008oiUVV@03o`00
0?o;=<_obcC;00Go00000oo7><L00ol0003ol0o`oo0?l003o`0000Ook1?/00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?od2oCom0_do`0000CocS7>0ol0000:onl@k`03o`000?oD:mCoe2_D00?oe2_D
00?o0000ok1?/?n`Ck002On`Ck03o`0000GoLXeb00Co0000ofn@Kom_T6oo00000_m>/Dh00ol0003o
WF:MoieRW@0BoieRW@03o`000?o0?l3o`3o001;o`3o000?o0000ojeB[On]DZd03_n]DZd00ol0003o
aC[5olDja@03olDja@03o`000?nIIYWoVFJI00WoVFJI0_l00009olLha`;o00002_o/4n`00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo@;m?od2oCom0_do`000007olhacP;o00001oo_4>l5o`0000;o
e2_D00?o0000ok1?/?n`Ck001_n`Ck03o`0000SoLXeb00Co0000ofn@Kom_T6oo00000om>/Dh00ol0
003oWF:MoieRW@0AoieRW@03o`000?o0?l3o`3o0017o`3o000?o0000ojeB[On]DZd04?n]DZd01Ol0
003oaC[5olDjaOo5>/Go000000coVFJI00?o0000olLhaoo7><L02?o7><L00ol0003ok1?/on`Ck00:
on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Com0_d00?o0000olhac_o><Lh01oo><Lh3o`00
0004onl@kol0003o0000o`0000Go^4Nh0_l00006ok1?/0?o00002_mbSG801Ol0003oKi1_ofn@Kom_
T6oo000000CoC[5>00?o0000oieRWOnMHYd04?nMHYd00ol0003o`3o0ol0o`00Aol0o`003o`000?n]
DZgo[E:]017o[E:]00?o0000olDjaOl000003OnIIYT00ol0003oacS7olLha`08olLha`03o`000?o/
4ncok1?/00[ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Com0_d00?o0000
olhac_o><Lh02_o><Lh00ol0003o^4NhokQ7^008okQ7^003o`000?n`Ck3o/4n`00?o00003OmbSG80
1Ol0003oKi1_ofn@Kom_T6oo000000GoC[5>00?o0000oieRWOnMHYd03onMHYd00ol0003o`3o0ol0o
`00Aol0o`003o`000?n]DZgo[E:]01;o[E:]00?o0000oiUVVOnIIYT03?nIIYT00ol0003oacS7olLh
a`08olLha`03o`000?o/4ncok1?/00_ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo@;m?od2o@01Ood2o@0
0ol0003ocS7>olhacP0:olhacP03o`000?nhAkSo^4Nh00Wo^4Nh0_l0000?og:=LP03o`000?m_T6oo
Ki1_00;oKi1_00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oWF:MoieRW@0=oieRW@?o00004Oo0?l00
0ol0003o[E:]ojeB[@0CojeB[@03o`000?nIIYWoVFJI00_oVFJI00?o0000olLhaoo7><L02Oo7><L0
0ol0003ok1?/on`Ck00;on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?od2o@0
0ol0003ocS7>olhacP0:olhacP03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000og:=L_mbSG803OmbSG80
0ol0003oKi1_ofn@K`03ofn@K`03o`000?m>/DkoC[5>00GoC[5>00?o0000oieRWOnMHYd02_nMHYd2
o`0000?oPWf200?o0000ol0o`?o0?l003_o0?l000ol0003o[E:]ojeB[@0CojeB[@03o`000?nIIYWo
VFJI00_oVFJI00?o0000olLhaoo7><L02Oo7><L00ol0003ok1?/on`Ck00;on`Ck003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000oo@;m?od2o@01ood2o@2o`0000_ocS7>00?o0000okQ7
^?nhAkP02onhAkP00ol0003oLXebog:=LP0<og:=LP03o`000?m_T6ooKi1_00?oKi1_00?o0000odja
C_m>/Dh01_m>/Dh00ol0003oWF:MoieRW@07oieRW@;o00001_n2OH82o`0000ko`3o000?o0000ojeB
[On]DZd04on]DZd00ol0003oVFJIoiUVV@0;oiUVV@03o`000?o7><OoacS700WoacS700?o0000on`C
k?o/4n`03?o/4n`00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009oo@;
m003o`000?oT6nCo000000_ocS7>00?o0000okQ7^?nhAkP02onhAkP00ol0003oLXebog:=LP0;og:=
LP03o`000?m_T6ooKi1_00CoKi1_00?o0000odjaC_m>/Dh01om>/Dh00ol0003oWF:MoieRW@05oieR
W@03o`000?n2OH;oPWf200SoPWf200?o0000ol0o`?o0?l002_o0?l000ol0003o[E:]ojeB[@0DojeB
[@03o`000?nIIYWoVFJI00_oVFJI00?o0000olLhaoo7><L02Oo7><L00ol0003ok1?/on`Ck00<on`C
k003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009oo@;m004o`000?oT6nCoi1_To`00
00_ocS7>00?o0000okQ7^?nhAkP02onhAkP00ol0003oLXebog:=LP0;og:=LP03o`000?m_T6ooKi1_
00CoKi1_00?o0000odjaC_m>/Dh02?m>/Dh00ol0003oWF:MoieRW@02oieRW@;o00003?n2OH82o`00
00[o`3o000?o0000ojeB[On]DZd05?n]DZd00ol0003oVFJIoiUVV@0;oiUVV@03o`000?o7><OoacS7
00WoacS700?o0000on`Ck?o/4n`03Oo/4n`00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m007oo@;m003
o`000?oT6nCoi1_T00;oi1_T00?o0000olhac_o><Lh02?o><Lh00ol0003o^4NhokQ7^00<okQ7^003
o`000?mbSG;oLXeb00WoLXeb00?o0000ofn@Kom_T6l01Om_T6l00ol0003oC[5>odjaCP09odjaCP04
o`000?nMHYgo0000o`00013oPWf20_l00008ol0o`003o`000?n]DZgo[E:]01Co[E:]0ol0000;oiUV
V@03o`000?o7><OoacS700WoacS700?o0000on`Ck?o/4n`03Oo/4n`01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003om0_doo@;m006oo@;m003o`000?oT6nCoi1_T00?oi1_T00?o0000olha
c_o><Lh02?o><Lh00ol0003o^4NhokQ7^00;okQ7^0;o00002_mbSG800ol0003oKi1_ofn@K`06ofn@
K`03o`000?m>/DkoC[5>00[oC[5>00?o0000oh9mP_n2OH804_n2OH800ol0003o`3o0ol0o`004ol0o
`003o`000?n]DZgo[E:]01Go[E:]00?o0000oiA[U?nDJi@01Ol00005oiUVV@03o`000?o7><OoacS7
00[oacS700?o0000on`Ck?o/4n`03_o/4n`3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m004oo@;m003
o`000?oT6nCoi1_T00Coi1_T00?o0000olhac_o><Lh01oo><Lh00ol0003o^4NhokQ7^00;okQ7^004
o`000?mbSG;oLXebo`0000WoLXeb00?o0000ofn@Kom_T6l01_m_T6l00ol0003oC[5>odjaCP0:odja
CP03o`000?n2OH;oPWf201?oPWf20_l00003ol0o`0Co00005?n]DZd00ol0003oU6^DoiA[U006oiA[
U0Co000000?oVFJIo`000?o7><L02oo7><L00ol0003ok1?/on`Ck00>on`Ck003o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003om0_doo@;m003oo@;m003o`000?oT6nCoi1_T00Goi1_T00?o0000olhac_o>
<Lh01oo><Lh00ol0003o^4NhokQ7^009okQ7^0;o00001?mbSG800ol0003oLXebog:=LP05og:=LP03
o`000?m_T6ooKi1_00OoKi1_00?o0000odjaC_m>/Dh02_m>/Dh00ol0003oPWf2oh9mPP0Eoh9mPP03
o`000?o0?l3o000000CoTVfB0ol0000@ojeB[@03o`000?nDJiCoU6^D00_oU6^D0_l0000<olLha`03
o`000?o/4ncok1?/00cok1?/0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@00_od2o@00ol0003oi1_T
on@Ki006on@Ki003o`000?o><LkocS7>00OocS7>00?o0000okQ7^?nhAkP02?nhAkP00ol0003oLXeb
og:=LP05og:=LP03o`000?mbSG;oLXeb00CoLXeb00?o0000ofn@Kom_T6l01om_T6l00ol0003oC[5>
odjaCP0:odjaCP03o`000?n2OH;oPWf201KoPWf200?o0000oi9]T_nBKI801_nBKI83o`0000co[E:]
00?o0000oiA[U?nDJi@03OnDJi@00ol0003oacS7olLha`09olLha`Go00002Oo/4n`2o`000003onl@
kol0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003oo@;m?l0003oi1_T00Woi1_T00?o0000olhac_o><Lh01_o>
<Lh00ol0003o^4NhokQ7^007okQ7^003o`000?mbSG;oLXeb00OoLXeb00?o0000og:=L_mbSG800_mb
SG800ol0003oKi1_ofn@K`08ofn@K`03o`000?m>/DkoC[5>00WoC[5>00?o0000oh9mP_n2OH805on2
OH800ol0003oTVfBoi9]TP09oi9]TP?o00002On]DZd00ol0003oU6^DoiA[U00>oiA[U0Ko00001?o7
><L00ol0003od2o@om0_d003om0_d0Go00000_o/4n`2o`0000Coka3_00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?oZ5N[ojQGZonXEj_l000002ooT6n@00ol0003ocS7>olhacP06olhacP03o`000?nh
AkSo^4Nh00Go^4Nh0_l0000;og:=LP04o`000?mbSG;oLXebo`0000_oKi1_00?o0000odjaC_m>/Dh0
2Om>/Dh00ol0003oPWf2oh9mPP0Foh9mPP03o`000?nBKI;oTVfB00goTVfB0ol00005ojeB[@03o`00
0?nDJiCoU6^D00ooU6^D00?o0000ojQGZ?nXEjP00onXEjP4o`0000_od2o@0_l00006onl@k`03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ojQGZonXEjP02onXEjPko00001_o><Lh00ol0003o^4NhokQ7
^005okQ7^003o`000?mbSG;oLXeb00coLXeb00?o0000og:=L_l000002om_T6l00ol0003oC[5>odja
CP07odjaCP?o00006?n2OH800ol0003oTVfBoi9]TP0@oi9]TP?o000000?o[E:]o`000?nDJi@04?nD
Ji@00ol0003oZ5NXojQGZ007ojQGZ003o`000?o@;m3od2o@00[od2o@00?o0000onl@koo_4>l01Oo_
4>l00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005onXEjP03o`000?o3?<?o`cc300_o`cc30_l00004
olhacP03o`000?nhAkSo^4Nh00?o^4Nh0_l0000@og:=LP03o`000?m_T6ooKi1_00[oKi1_00?o0000
odjaC_m>/Dh00om>/Dh4o`0000;o</db00?o0000oh9mP_n2OH805On2OH800ol0003oTVfBoi9]TP0D
oi9]TP03o`000?nDJiCoU6^D013oU6^D00?o0000ojQGZ?nXEjP01onXEjP00ol0003od2o@om0_d00:
om0_d003o`000?o_4>ooka3_00Goka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oZ5N[ojQGZ
00GojQGZ00?o0000ol<l`oo3?<<03Oo3?<<6o`0000?o^4Nh00?o0000og:=L_mbSG804?mbSG800ol0
003oKi1_ofn@K`0:ofn@K`03o`000?m>/Dko000000?o00001olbcC800ol0003oPWf2oh9mPP0Doh9m
PP03o`000?nBKI;oTVfB01CoTVfB00?o0000oiA[U?nDJi@03onDJi@00ol0003oZ5NXojQGZ008ojQG
Z003o`000?o@;m3od2o@00[od2o@00?o0000onl@koo_4>l01Oo_4>l00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onXEj_oZ5NX01_oZ5NX00ol0003o`cc3ol<l``0=ol<l``03o`000?n/Djco[5>/00?o
[5>/00?o0000okQ7^?l000004ombSG84o`0000WoKi1_0_l0000<oc;=<P03o`000?n2OH;oPWf201?o
PWf200?o0000oi9]T_nBKI805OnBKI800ol0003oU6^DoiA[U00>oiA[U003o`000?nXEjSoZ5NX00So
Z5NX00?o0000om0_d?o@;m002Oo@;m000ol0003oka3_onl@k`07onl@k`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?oZ5N[ojQGZ00SojQGZ00?o0000ol<l`oo3?<<02oo3?<<00ol0003o[5>/ojaC[005ojaC[003o`00
0?mbSG;oLXeb01;oLXeb00Co0000oco0?olo`3oo?l0o1Ol00003ofn@K`03o`000?lbcC;o</db00go
</db0ol0000@oh9mPP;o00006?nBKI800ol0003oU6^DoiA[U00=oiA[U003o`000?nXEjSoZ5NX00Wo
Z5NX00?o0000om0_d?o@;m002Oo@;m000ol0003oka3_onl@k`07onl@k`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ojQGZ00?o0000ol<l`oo3?<<02_o3?<<00ol0003o[5>/ojaC[006ojaC[003o`00
0?mbSG;oLXeb017oLXeb00?o0000oco0?olo`3l01olo`3l3o`00013o</db00?o0000obCK9?lTfb@0
1Ol00009oh9mPP;o000000?o?L8mo`000?nBKI805onBKI800ol0003oU6^DoiA[U00=oiA[U003o`00
0?nXEjSoZ5NX00WoZ5NX00?o0000om0_d?o@;m002?o@;m02o`0000[oka3_00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?oe2_Gom@[e00;om@[e00?o0000onXEj_oZ5NX02OoZ5NX00ol0003o`cc3ol<l
``0:ol<l``03o`000?n/Djco[5>/00Oo[5>/00?o0000og:=L_mbSG803ombSG800ol0003o?l0ooco0
?`0:oco0?`03o`000?lbcC;o</db00go</db00?o0000obCK9?lTfb@01_lTfb@4o`0000CoPWf200?o
0000ocg2?Olm`Sd00_lm`Sd00ol0003oTVfBoi9]TP0Foi9]TP03o`000?nDJiCoU6^D00_oU6^D00?o
0000ojQGZ?nXEjP02onXEjP00ol0003od2o@om0_d006om0_d003o`000?oR7N;o000000[oka3_00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?oe2_Gom@[e00?om@[e00?o0000onXEj_oZ5NX02?oZ5NX=
o`0000[o[5>/00?o0000og:=L_mbSG803ombSG800ol0003o?l0ooco0?`0;oco0?`03o`000?lbcC;o
</db00co</db00?o0000obCK9?lTfb@02_lTfb@4o`0000Go?L8m00?o0000oi9]T_nBKI805_nBKI80
0ol0003oU6^DoiA[U00:oiA[U003o`000?nXEjSoZ5NX00coZ5NX00?o0000om0_d?o@;m001?o@;m02
o`0000?ohQgR00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ooD:
mOoe2_D00ooe2_D00ol0003ojQGZonXEjP07onXEjP03o`000?o1?/7o`Ck100Wo`Ck100?o0000ojaC
[?n/Dj`02On/Dj`00ol0003oLXebog:=LP0=og:=LP03o`000?lo`3oo?l0o00co?l0o00?o0000oc;=
<_lbcC803?lbcC800ol0003o9=/TobCK900;obCK9003o`000?l?l0oo000000Ko?L8m00?o0000oi9]
T_nBKI805_nBKI800ol0003oU6^DoiA[U009oiA[U003o`000?nXEjSoZ5NX00coZ5NX00?o0000om0_
d?o@;m000oo@;m000ol0003ohQgRon8MhP03on8MhP03o`000?o_4>ooka3_00Soka3_00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?oe2_Gom@[e00Com@[e00?o0000onXEj_oZ5NX01_oZ5NX00ol0003o
`Ck1ol4n`@08ol4n`@03o`000?n/Djco[5>/00_o[5>/00?o0000og:=L_mbSG802?mbSG84o`0000oo
?l0o00?o0000oc;=<_lbcC802olbcC800ol0003o9=/TobCK900;obCK9004o`000?l?l0oo3o0?o`00
00Oo?L8m00?o0000oi9]T_nBKI805OnBKI800ol0003oU6^DoiA[U008oiA[U003o`000?nXEjSoZ5NX
00goZ5NX00?o0000om0_d?o@;m000_o@;m000ol0003ohQgRon8MhP05on8MhP03o`000?o_4>ooka3_
00Ooka3_00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?oe2_Gom@[e00Gom@[e00?o0000onXEj_oZ
5NX01OoZ5NX00ol0003o`Ck1ol4n`@08ol4n`@03o`000?n/Djco[5>/00_o[5>/00?o0000og:=L_mb
SG800ombSG85o`0000?o@;m000?o0000oco0?olo`3l03_lo`3l00ol0003o</dboc;=<P0:oc;=<P03
o`000?lTfbCo9=/T00[o9=/T00Go0000o`o`3ol?l0oo3o0?o`000007ocg2?@03o`000?nBKI;oTVfB
01GoTVfB00?o0000oiA[U?nDJi@02?nDJi@00ol0003oZ5NXojQGZ00=ojQGZ003o`000?o@;m3od2o@
00;o00002?oR7N800ol0003oka3_onl@k`08onl@k`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oZ5N[ojQGZ00Go
jQGZ00?o0000ol4n`Oo1?/402?o1?/400ol0003o[5>/ojaC[00<ojaC[0Go00002Om0_d000ol0003o
?l0ooco0?`0<oco0?`;o00003?lbcC800ol0003o9=/TobCK900:obCK9005o`000?l?l0oo3o0?o`o`
3ol000002?lm`Sd00ol0003oTVfBoi9]TP0Doi9]TP?o00001onDJi@00ol0003oZ5NXojQGZ00>ojQG
Z003o`000?o@;m3o000000_ohQgR00?o0000onl@koo_4>l01_o_4>l00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000ooD:mOoe2_D01Ooe2_D00ol0003ojQGZonXEjP04onXEjP03o`000?o1?/7o`Ck100Oo
`Ck100?o0000ojaC[?n/Dj`03?n/Dj`01?l0003oLXebog:=L_l0000;od2o@003o`000?lo`3oo?l0o
00_o?l0o00Co0000o`[e2_l:m@[o00002_lbcC800ol0003o9=/TobCK900:obCK9003o`000?l?l0oo
3o0?00;o3o0?00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003oTVfBoi9]TP0Aoi9]TP?o00000omQWV40
0ol0003oU6^DoiA[U004oiA[U003o`000?nXEjSoZ5NX00goZ5NX1?l0000;on8MhP03o`000?o_4>oo
ka3_00Goka3_00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oe2_Gom@[e00Kom@[e00Co0000onXE
j_oZ5N[ojQGZ1?l00008ol4n`@03o`000?n/Djco[5>/00_o[5>/00?o0000og:=L_mbSG800_mbSG80
0ol0003o@;m0od2o@008od2o@003o`000?lo`3oo?l0o00[o?l0o00?o0000o`[e2_l:m@X00_l:m@X0
0ol0003o</dboc;=<P03oc;=<PGo00002olTfb@00ol0003o3o0?o`o`3`03o`o`3`03o`000?lm`Sgo
?L8m00Oo?L8m00?o0000oi9]T_nBKI803_nBKI82o`0000OoHIiQ00?o0000oiA[U?nDJi@00_nDJi@0
0ol0003oZ5NXojQGZ00=ojQGZ003o`000?o=</gocC;=00;ocC;=00?o0000on8Mh_oR7N802OoR7N80
0ol0003oka3_onl@k`03onl@k`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003om@[eooD:m@07ooD:
m@?o00001?oG:=L00ol0003o`Ck1ol4n`@05ol4n`@03o`000?n/Djco[5>/00[o[5>/00?o0000og:=
L_mbSG800ombSG800ol0003o@;m0od2o@009od2o@003o`000?lo`3oo?l0o00So?l0o00?o0000o`[e
2_l:m@X01?l:m@X5o`0000Co0?l000?o0000obCK9?lTfb@02OlTfb@00ol0003o3o0?o`o`3`03o`o`
3`03o`000?lm`Sgo?L8m00So?L8m00?o0000oi9]T_nBKI802_nBKI83o`0000[oHIiQ00Go0000oiA[
U?nDJiCoU6^Do`00000>ojQGZ003o`000?o=</gocC;=00CocC;=0_l00009on8MhP03o`000?o_4>oo
ka3_00;oka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?oe2_Gom@[e00Oom@[e00?o0000omLX
eooG:=L01OoG:=L00ol0003o`Ck1ol4n`@03ol4n`@03o`000?n/Djco[5>/00[o[5>/00?o0000og:=
L_mbSG801?mbSG800ol0003o@;m0od2o@009od2o@003o`000?lo`3oo?l0o00Oo?l0o00?o0000o`[e
2_l:m@X01Ol:m@X00ol0003o0?l0o`3o0007o`3o0003o`000?lTfbCo9=/T00Oo9=/T00?o0000o`o`
3ol?l0l01?l?l0l00ol0003o?L8mocg2?@08ocg2?@03o`000?nBKI;oTVfB00SoTVfB0_l0000>of6N
H@Co00003?nXEjP2o`0000WocC;=00?o0000on8Mh_oR7N801ooR7N801?l0003oka3_onl@kol0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oebSGomLXe`07omLXe`;o00000oo1?/400ol0
003o[5>/ojaC[009ojaC[003o`000?mbSG;oLXeb00KoLXeb00?o0000od2o@?m0_d002Om0_d000ol0
003o?l0ooco0?`05oco0?`03o`000?l:m@[o2_D:00Ko2_D:00?o0000o`3o0?l0o`002?l0o`000ol0
003o9=/TobCK9006obCK9003o`000?l?l0oo3o0?00Co3o0?00?o0000ocg2?Olm`Sd02Olm`Sd4o`00
00?oTVfB0ol0000@of6NH@05o`000?nn@Kko_T6noki1__l000002_nXEjP00ol0003ocC;=oldbc@0:
oldbc@Ko00000ooR7N800ol0003oka3_o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000ooD:mOoe2_D01?oe2_D00ol0
003oebSGomLXe`0:omLXe`04o`000?o1?/7o`Ck1o`0000[o[5>/00?o0000og:=L_mbSG801ombSG80
0ol0003o@;m0od2o@009od2o@003o`000?lo`3oo?l0o00Co?l0o00?o0000o`[e2_l:m@X01ol:m@X0
0ol0003o0?l0o`3o0008o`3o00;o00001_lTfb@00ol0003o3o0?o`o`3`05o`o`3`03o`000?lm`Sgo
?L8m00Wo?L8m00Co0000oc3?<?l`cc3o<<l`0ol0000Bof6NH@03o`000?nn@Kko_T6n00?o_T6n0_l0
0006ojQGZ0;o00003Oo=</d00ol0003ol`ccoo<<l`03oo<<l`Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000ooD:mOoe2_D00ooe2_D0
0ol0003oebSGomLXe`0<omLXe`;o00002_n/Dj`00ol0003oLXebog:=LP08og:=LP03o`000?m0_d3o
@;m000[o@;m000?o0000oco0?olo`3l00_lo`3l00ol0003o2_D:o`[e2P08o`[e2P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`Gj1@03o`000?lTfbCo9=/T00;o9=/T00?o0000o`o`3ol?l0l01_l?l0l0
0ol0003o?L8mocg2?@08ocg2?@03o`000?l`cc3o<<l`00Co<<l`00?o0000of6NHOmQWV403omQWV40
0ol0003o_T6noki1_P06oki1_P;o00000onXEjP00ol0003ocC;=oldbc@0=oldbc@03o`000?oc3??o
l`cc00Ool`cc0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003om@[eooD:m@02ooD:m@03o`000?oG:=OoebSG
00koebSG00?o0000ojaC[?n/Dj`01on/Dj`00ol0003oLXebog:=LP0:og:=LP03o`000?m0_d3o@;m0
00Wo@;m000Go0000oco0?olo`3oo?l0oo`00000;o`[e2P03o`000?l0o`3o0?l000Co0?l00_l00005
o`Gj1@05o`000?lTfbCo9=/TobCK9?l000002?l?l0l00ol0003o?L8mocg2?@08ocg2?@03o`000?l`
cc3o<<l`00Go<<l`00?o0000of6NHOmQWV403_mQWV400ol0003o_T6noki1_P08oki1_P03o`000?nX
EjSo000000oocC;=00?o0000oo<<looc3?<02?oc3?<01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?oe2_Gom@[eo`00017oebSG00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003oLXeb
og:=LP0;og:=LP03o`000?m0_d3o@;m000Wo@;m000Co0000oco0?olo`3oo00003?l:m@X00ol0003o
0?l0o`3o0002o`3o00;o00002?l5nPD00ol0003o9=/To`000009o`o`3`03o`000?lm`Sgo?L8m00So
?L8m00?o0000oc3?<?l`cc001Ol`cc000ol0003oHIiQof6NH@0=of6NH@03o`000?nn@Kko_T6n00[o
_T6n00?o0000oldbcOo=</d03_o=</d00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000BomLXe`03o`00
0?n/Djco[5>/00Co[5>/00?o0000og:=L_mbSG803?mbSG800ol0003o@;m0od2o@00:od2o@0?o0000
3?l:m@X00ol0003o0?l0o`3o0002o`0000_o1OX500?o0000o`o`3ol?l0l02?l?l0l00ol0003o?L8m
ocg2?@07ocg2?@03o`000?l`cc3o<<l`00Oo<<l`00?o0000of6NHOmQWV403?mQWV400ol0003o_T6n
oki1_P0;oki1_P;o00003_o=</d00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003oebSGomLXe`0?omLXe`?o00000on/
Dj`00ol0003oLXebog:=LP0>og:=LP03o`000?m0_d3o@;m000So@;m000Co0000oa;]4_lBkA;o4^dB
0_l0000:o`[e2P?o00003Ol5nPD00ol0003o3o0?o`o`3`08o`o`3`03o`000?lm`Sgo?L8m00Oo?L8m
00?o0000oc3?<?l`cc001ol`cc000ol0003oHIiQof6NH@0;of6NH@03o`000?nn@Kko_T6n00co_T6n
00?o0000onHIi_l000000_l0000:oldbc@03o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003ol`ccoo<<l`04oo<<l`03o`000?oG:=OoebSG00coebSG0_l0
0003ol4n`@03o`000?n/Djco0000017oLXeb00?o0000od2o@?m0_d001om0_d000ol0003o4^dBoa;]
4P04oa;]4P;o00002?l:m@X00ol0003o1OX5o`Gj1@0>o`Gj1@;o00002?l?l0l00ol0003o?L8mocg2
?@06ocg2?@03o`000?l`cc3o<<l`00Wo<<l`00?o0000of6NHOmQWV402OmQWV400ol0003o_T6noki1
_P0=oki1_P03o`000?oV6NKoiQWV00;oiQWV0ol00007oldbc@03o`000?oc3??ol`cc00Ool`cc00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oG:=Oo
ebSG00WoebSG0_l00006ol4n`@03o`000?mbSG;oLXeb013oLXeb00?o0000od2o@?m0_d001_m0_d00
0ol0003o4^dBoa;]4P07oa;]4P03o`000?l:m@[o2_D:00Co2_D:0ol0000>o`Gj1@03o`000?l0o`3o
0?l000?o00001Ol?l0l00ol0003o?L8mocg2?@06ocg2?@03o`000?l`cc3o<<l`00[o<<l`00?o0000
of6NHOmQWV402?mQWV400ol0003o_T6noki1_P0=oki1_P03o`000?oV6NKoiQWV00GoiQWV0ol00004
oldbc@03o`000?oc3??ol`cc00Ool`cc00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ol`ccoo<<l`06oo<<l`03o`000?oG:=OoebSG00GoebSG0ol00008ol4n`@03o`000?mbSG;oLXeb
017oLXeb00Co0000od2o@?m0_d3o@;m01?l0000;oa;]4P;o000000Co2_D:o`000?l0003o00000olI
iQT2o`0000_o1OX500?o0000o`3o0?l0o`001?l0o`02o`0000?o3o0?00?o0000ocg2?Olm`Sd01_lm
`Sd00ol0003o<<l`oc3?<00:oc3?<003o`000?mQWV7oHIiQ00OoHIiQ00?o0000oki1__nn@Kh03_nn
@Kh00ol0003oiQWVonHIiP08onHIiPCo00002_oc3?<00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003ol`ccoo<<l`07oo<<l`03o`000?oG:=OoebSG00;oebSG0_l0000<ol4n`@03o`000?mbSG;o
LXeb013oLXeb1?l00003oc?<<`03o`000?lBkA;o4^dB00_o4^dB00?o0000oaWV6OlIiQT01_lIiQT0
0ol0003o1OX5o`Gj1@07o`Gj1@03o`000?l0o`3o0?l000Oo0?l03?l0000>oc3?<003o`000?mQWV7o
HIiQ00KoHIiQ00?o0000oki1__nn@Kh03_nn@Kh00ol0003oiQWVonHIiP0;onHIiP03o`000?oc3??o
l`cc00Ool`cc00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00Wol`cc00Co0000omLX
eol0003o00003_o1?/400ol0003oLXebog:=LP0?og:=LP03o`000?lcc3?o<l`c00Ko<l`c00?o0000
oa;]4_lBkA802_lBkA800ol0003o6NHIoaWV6@07oaWV6@;o00001_l5nPD00ol0003o0?l0o`3o0008
o`3o0003o`000?m3_4?o@ka300So@ka300?o0000oc3?<?l`cc003?l`cc000ol0003oHIiQof6NH@05
of6NH@03o`000?nn@Kko_T6n00oo_T6n0_l0000=onHIiP03o`000?oc3??ol`cc00Kol`cc00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00[ol`cc00?o0000ol4n`Oo1?/403_o1?/400ol0
003oLXebog:=LP0>og:=LP03o`000?lcc3?o<l`c00Oo<l`c00?o0000oa;]4_lBkA802_lBkA800ol0
003o6NHIoaWV6@09oaWV6@;o00000ol5nPD00ol0003o0?l0o`3o0009o`3o0003o`000?m3_4?o@ka3
00Wo@ka300?o0000oc3?<?l`cc002_l`cc04o`0000CoHIiQ00?o0000oki1__nn@Kh04?nn@Kh01?l0
003ohacSo`000?l0000<onHIiP03o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oc3??ol`cc00[ol`cc00?o0000ol4n`Oo1?/403oo1?/4@o`0000[o<l`c00?o0000oa;]
4_lBkA802OlBkA800ol0003o0?l0o`00000<oaWV6@05o`000?l5nPGo0000o`3o0?l000002_l0o`00
0ol0003o@ka3od>l@`09od>l@`03o`000?l`cc3o<<l`00Oo<<l`0ol00004ofFJI@?o000000?oHIiQ
o`000?nn@Kh04Onn@Kh01?l0003ohacSon<LhooS7><2o`0000_oiQWV00?o0000oo<<looc3?<00ooc
3?<00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003o`Ck1ol4n`@0?
ol4n`@03o`000?mdRgCoM8]d00coM8]d00?o0000oc?<<olcc3<02Olcc3<00ol0003o4^dBoa;]4P07
oa;]4P04o`000?l0o`3o0?l0o`0000go6NHI00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m3_4?o@ka300[o@ka300?o0000oc3?<?l`cc000ol`cc03o`0000[oIIYU00?o0000oki1__nn@Kh0
4?nn@Kh00ol0003ohacSon<Lh`04on<Lh`;o00002_oV6NH00ol0003ol`ccoo<<l`04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000col`cc00?o0000ol4n`Oo1?/403oo1?/400ol0003oM8]dogB;M00<ogB;M003o`000?lc
c3?o<l`c00Wo<l`c00?o0000oa;]4_lBkA801_lBkA800ol0003o0?l0o`3o0002o`3o0003o`000?lI
iQWo6NHI00[o6NHI00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m3
_4?o@ka300[o@ka300?o0000oc3?<?l`cc000ol0000=ofFJI@03o`000?nn@Kko_T6n013o_T6n00?o
0000on<LhooS7><01_oS7><2o`0000WoiQWV0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003o`Ck1ol4n`@0=ol4n`@?o00003omdRg@0
0ol0003o<l`coc?<<`08oc?<<`03o`000?lBkA;o4^dB00Go4^dB00?o0000o`3o0?l0o`000ol0o`00
0ol0003o6NHIoaWV6@0:oaWV6@03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o@ka3od>l@`0;od>l@`;o00004OmUVVD00ol0003o_T6noki1_P0?oki1_P03o`000?oS7>?o
hacS00SohacS0_l00007onHIiP03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo<<looc3?<02?oc3?<00ol0003o`Ck1ol4n`@09ol4n`@Go00000_n@Ki000ol0
003oM8]dogB;M00=ogB;M003o`000?lcc3?o<l`c00Wo<l`c00?o0000oa;]4_lBkA801?lBkA800ol0
003o0?l0o`3o0004o`3o0003o`000?lIiQWo6NHI00So6NHI00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m3_4?o@ka300_o@ka300?o0000ofFJIOmUVVD04?mUVVD00ol0
003o_T6noki1_P0?oki1_P03o`000?oS7>?ohacS00[ohacS0_l00004onHIiP03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003ol`ccoo<<l`07oo<<l`03o`000?o1?/7o`Ck100Co`Ck11Ol00007oi1_T003
o`000?mdRgCoM8]d00goM8]d00?o0000oc?<<olcc3<02Olcc3<00ol0003o4^dBoa;]4P03oa;]4P03
o`000?l0o`3o0?l000Go0?l000?o0000oaWV6OlIiQT02?lIiQT00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000od>l@om3_4<02om3_4<00ol0003oIIYUofFJI@0@ofFJI@03
o`000?nn@Kko_T6n00oo_T6n00?o0000on<LhooS7><03?oS7><2o`000003onHIi_l0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000ol4n`Ol00000
1?l0000<oi1_T003o`000?mdRgCoM8]d00koM8]d00?o0000oc?<<olcc3<02?lcc3<00ol0003o4^dB
oa;]4P02oa;]4P03o`000?l0o`3o0?l000Oo0?l000?o0000oaWV6OlIiQT01olIiQT00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000od>l@om3_4<02om3_4<00ol0003oIIYU
ofFJI@0AofFJI@03o`000?nn@Kko_T6n00go_T6n00?o0000on<LhooS7><03ooS7><00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo<<looc3?<01Ooc3?<3o`00017oT6n@00?o0000ogB;M?mdRg@03_md
Rg@00ol0003o<l`coc?<<`09oc?<<`04o`000?lBkA;o4^dBo`0000[o0?l000?o0000oaWV6OlIiQT0
1olIiQT00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om3_4<00ol0003o
IIYUofFJI@0AofFJI@?o00003Onn@Kh00ol0003ohacSon<Lh`0?on<Lh`03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_oc3?<2o`0000;ofRGJ00?o0000oi1_T?n@Ki003on@Ki000ol0003o
M8]dogB;M00>ogB;M003o`000?lcc3?o<l`c00So<l`c1Ol0000;o`3o0003o`000?lIiQWo6NHI00Ko
6NHI00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=od>l@`03o`000?mUVVGoIIYU
017oIIYU00?o0000of6NHOmQWV400ol0000:oki1_PCo00003OoS7><00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000ooD:mOoe2_Gom@[e0_l00005omXUfP03o`000?n@Ki3oT6n@00koT6n@00?o0000ogB;
M?mdRg@03_mdRg@00ol0003o<l`coc?<<`07oc?<<`03o`000?lRgB;o8]dR00?o8]dR00?o0000o`3o
0?l0o`002?l0o`000ol0003o6NHIoaWV6@05oaWV6@03o`000?l0o`3o0?l000[o0?l01Ol0000<od>l
@`03o`000?mUVVGoIIYU013oIIYU00?o0000of6NHOmQWV401?mQWV43o`0000Ko_T6n00?o0000omlO
gooO7ml00_oO7ml5o`0000SohacS00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oe2_Gom@[e00?o
m@[e00?o0000omXUf_oJ9MX01?oJ9MX00ol0003oT6n@oi1_T00=oi1_T003o`000?mdRgCoM8]d00oo
M8]d00?o0000oc?<<olcc3<01?lcc3<2o`0000Oo8]dR00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0Oh100?o0000od>l@om3_4<02?m3_4<3o`00013oIIYU00?o0000of6NHOmQWV402?mQWV43o`0000;o
_T6n00?o0000omlOgooO7ml02?oO7ml5o`0000?ohacS00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?oe2_Gom@[e00Com@[e00?o0000omXUf_oJ9MX01OoJ9MX00ol0003oT6n@oi1_T00;oi1_T0Co0000
3omdRg@00ol0003o<l`coc?<<`03oc?<<`03o`000?lRgB;o8]dR00So8]dR00?o0000o`3o0?l0o`00
1?l0o`02o`0000So7^4N00?o0000o`ka3_l>l@h02?l>l@h00ol0003o0Oh1o`7n0@05o`7n0@;o0000
1_m3_4<2o`0000?o>/Dj00?o0000ofFJIOmUVVD03?mUVVD00ol0003oHIiQof6NH@0<of6NH@;o0000
4?oO7ml3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oJ9M[ofRGJ00KofRGJ00?o
0000oi1_T?n@Ki002On@Ki000ol0003oWV6No`000002oe^TF`?o00003?mdRg@01?l0003o<l`coc?<
<olcc3<2o`0000co8]dR00?o0000o`3o0?l0o`000_l0o`000ol0003o7^4NoakQ7P08oakQ7P03o`00
0?l>l@ko3_4>00So3_4>00?o0000o`7n0Ol1oP401ol1oP400ol0003o@ka3od>l@`02od>l@`03o`00
0?ljaC[o>/Dj00Co>/Dj0_l0000;ofFJI@03o`000?mQWV7oHIiQ00coHIiQ00?o0000ojMHYol00000
4_oO7ml00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003om@[eooD:m@06ooD:m@03o`000?oJ9M[ofRGJ00OofRGJ00?o
0000oi1_T?n@Ki001_n@Ki02o`0000;oWV6N00?o0000oe^TFomKY5/00omKY5/3o`0000[oM8]d00?o
0000oc?<<ol000003olRgB801?l0003o0?l0o`000?l0000;oakQ7P03o`000?l>l@ko3_4>00So3_4>
00?o0000o`7n0Ol1oP402?l1oP401?l0003o@ka3o`000?l00009oc[5>P03o`000?mUVVGoIIYU00Oo
IIYU00?o0000of6NHOmQWV403?mQWV401?l0003oYeRWojMHYol0000ComlOg`03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000ooD:mOoe2_D01ooe2_D00ol0003ofRGJomXUfP08omXUfP03o`000?n@Ki3oT6n@00Co
T6n@00?o0000oiiQW_nNHIh00onNHIh00ol0003oFjAKoe^TF`05oe^TF`?o00001_mdRg@4o`00013o
8]dR00?o0000oakQ7_lNhAh03?lNhAh00ol0003o3_4>o`ka3P07o`ka3P03o`000?l1oP7o0Oh100Wo
0Oh100?o0000oc[5>_ljaCX02_ljaCX2o`0000KoIIYU00?o0000of6NHOmQWV403?mQWV400ol0003o
YeRWojMHY`02ojMHY`03o`000?oO7moogaoO00oogaoO00?o0000oo8=l_l000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003om@[eooD:m@08ooD:m@03o`000?oJ9M[ofRGJ00WofRGJ00Co0000oi1_T?n@Ki3o
T6n@0_l00006oiiQWP03o`000?mKY5_oFjAK00SoFjAK0ol000000omdRgCo0000o`000004ocW6>@03
o`000?lRgB;o8]dR00go8]dR00?o0000oakQ7_lNhAh03?lNhAh00ol0003o3_4>o`ka3P07o`ka3P03
o`000?l1oP7o0Oh100Wo0Oh100?o0000oc[5>_ljaCX03?ljaCX00ol0003oIIYUofFJI@03o`0000ko
HIiQ00?o0000ojMHYonWF:L00onWF:L00ol0003ogaoOomlOg`0>omlOg`05o`000?ob3O;olPgboo8=
l_l000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003om@[eooD:m@09ooD:m@03o`000?oJ9M[ofRGJ00[o
fRGJ00?o0000oi1_T?l000002?nNHIh00ol0003oFjAKoe^TF`0;oe^TF`03o`000?liaSWo>LHi00Go
>LHi00?o0000ob;M8_lRgB803?lRgB800ol0003o7^4NoakQ7P0<oakQ7P03o`000?l>l@ko3_4>00Oo
3_4>00?o0000o`7n0Ol1oP402?l1oP42o`0000oo>/Dj0_l00002ofNHI`03o`000?mQWV7oHIiQ00_o
HIiQ00?o0000ojMHYonWF:L01?nWF:L00ol0003ogaoOomlOg`0=omlOg`03o`000?ob3O;olPgb00?o
lPgb00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooD:m@03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000oiiQW_nNHIh0
1onNHIh00ol0003oFjAKoe^TF`0;oe^TF`03o`000?liaSWo>LHi00Ko>LHi00?o0000ob;M8_lRgB80
2olRgB82o`0000go7^4N00?o0000o`ka3_l>l@h01ol>l@h00ol0003o0Oh1o`7n0@07o`7n0@04o`00
0?l>l@ko3_4>o`0000ko>/Dj00?o0000ofNHIomWV6L00_mWV6L00ol0003oHIiQof6NH@09of6NH@03
o`000?nWF:OoYeRW00KoYeRW00?o0000omlOgooO7ml02ooO7ml00ol0003olPgboo8=lP05oo8=lP04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Som@[e00?o0000omXUf_oJ9MX02_oJ9MX2o`0000Wo
WV6N00?o0000oe^TFomKY5/02omKY5/00ol0003o>LHiocW6>@07ocW6>@03o`000?lRgB;o8]dR00Wo
8]dR00Co0000o`3o0?l0o`3o00003?lNhAh00ol0003o3_4>o`ka3P07o`ka3P03o`000?l1oP7o0Oh1
00Ko0Oh100Go0000o`ka3_l>l@ko3_4>o`00000>oc[5>P03o`000?mWV6OoIiQW00?oIiQW00?o0000
of6NHOmQWV401omQWV400ol0003oYeRWojMHY`07ojMHY`03o`000?oO7moogaoO00[ogaoO00?o0000
oo8=l_ob3O801oob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooD:m@03o`000?oJ9M[ofRGJ
00WofRGJ00Co0000oll`coo?<<oo00002OnNHIh00ol0003oFjAKoe^TF`09oe^TF`03o`000?liaSWo
>LHi00Wo>LHi00?o0000ob;M8_lRgB801olRgB800ol0003o0?l0o`3o0002o`3o0003o`000?lNhAko
7^4N00Wo7^4N00?o0000o`ka3_l>l@h01ol>l@h00ol0003o0Oh1o`7n0@05o`7n0@03o`000?l>l@ko
3_4>00?o3_4>00?o0000oc[5>_ljaCX02_ljaCX00ol0003oIiQWofNHI`05ofNHI`03o`000?mQWV7o
HIiQ00GoHIiQ00?o0000ojMHYonWF:L02?nWF:L00ol0003ogaoOomlOg`09omlOg`03o`000?ob3O;o
lPgb00SolPgb00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oe2_D3o`0000WofRGJ00?o0000oll`
coo?<<l00_o?<<l00ol0003oWV6NoiiQWP06oiiQWP03o`000?mKY5_oFjAK00WoFjAK00?o0000ocW6
>OliaST02_liaST00ol0003o8]dRob;M8P05ob;M8P03o`000?l0o`3o0?l000Co0?l000?o0000oakQ
7_lNhAh02?lNhAh00ol0003o3_4>o`ka3P07o`ka3P03o`000?l1oP7o0Oh100Co0Oh100?o0000o`ka
3_l>l@h01?l>l@h00ol0003o>/Djoc[5>P0:oc[5>P03o`000?mWV6OoIiQW00KoIiQW00?o0000of6N
HOmQWV400omQWV400ol0003oYeRWojMHY`09ojMHY`03o`000?oO7moogaoO00SogaoO00?o0000oo8=
l_ob3O802Oob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onhAkP?o00001OoJ9MX00ol0003o
cc3?oll`c`03oll`c`03o`000?nNHIkoWV6N00KoWV6N00?o0000oe^TFomKY5/02OmKY5/00ol0003o
>LHiocW6>@0;ocW6>@03o`000?lRgB;o8]dR00?o8]dR00?o0000o`3o0?l0o`001_l0o`000ol0003o
7^4NoakQ7P08oakQ7P03o`000?l>l@ko3_4>00Ko3_4>00?o0000o`7n0Ol1oP400_l1oP42o`0000So
3_4>00?o0000oc[5>_ljaCX02OljaCX00ol0003oIiQWofNHI`07ofNHI`05o`000?mQWV7oHIiQof6N
HOl000003OnWF:L00ol0003ogaoOomlOg`06omlOg`03o`000?ob3O;olPgb00[olPgb00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o^4NkokQ7^00GokQ7^0ol000000ooJ9M[o0000oll`c`06oll`c`03
o`000?nNHIkoWV6N00GoWV6N00?o0000oe^TFomKY5/02OmKY5/00ol0003o>LHiocW6>@0<ocW6>@05
o`000?lRgB;o8]dRob;M8_l000002_l0o`000ol0003o7^4NoakQ7P07oakQ7P03o`000?l>l@ko3_4>
00Ko3_4>00?o0000o`7n0Ol000000_l000000oljaC[o0000o`ka3P07o`ka3P03o`000?ljaC[o>/Dj
00So>/Dj00?o0000ofNHIomWV6L02OmWV6L00ol0003oHIiQo`00000=ojMHY`Co00001OoO7ml00ol0
003olPgboo8=lP0;oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^onhAkP08onhAkP03
o`000?o?<<oocc3?00Oocc3?00?o0000oiiQW_nNHIh01?nNHIh00ol0003oFjAKoe^TF`09oe^TF`03
o`000?liaSWo>LHi00go>LHi00?o0000ob;M8_l000003?l0o`0:o`0000Oo3_4>0ol00005oc[5>P03
o`000?l>l@ko3_4>00Ko3_4>00?o0000oc[5>_ljaCX01oljaCX00ol0003oIiQWofNHI`0:ofNHI`03
o`000?nWF:OoYeRW00_oYeRW00?o0000om`Sg?oL8m`00_oL8m`3o`000003omlOgol0003olPgb00_o
lPgb0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003occ3?oll`c`07oll`c`03o`00
0?nNHIkoWV6N00GoWV6N00?o0000oe^TFomKY5/01omKY5/00ol0003o>LHiocW6>@0?ocW6>@;o0000
2ol0o`000ol0003o;M8]obgB;@07obgB;@03o`000?l>l@ko3_4>00;o3_4>0ol00008oc[5>P03o`00
0?l>l@ko3_4>00Ko3_4>00?o0000oc[5>_ljaCX01oljaCX00ol0003oIiQWofNHI`0:ofNHI`03o`00
0?nWF:OoYeRW00[oYeRW00?o0000om`Sg?oL8m`01_oL8m`00ol0003olPgboo8=lP08oo8=lP?o0000
0_oe2_D00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003occ3?oll`
c`08oll`c`03o`000?nNHIkoWV6N00CoWV6N00?o0000oe^TFomKY5/01omKY5/00ol0003o>LHiocW6
>@0>ocW6>@04o`000?l9mPWo2OH9o`0000Wo0?l000?o0000obgB;Ol]dRd02Ol]dRd01?l0003o3_4>
o`000?l0000<oc[5>P03o`000?l>l@ko3_4>00Ko3_4>00?o0000oc[5>_ljaCX01_ljaCX00ol0003o
IiQWofNHI`0;ofNHI`03o`000?nWF:OoYeRW00OoYeRW0_l00009om`Sg003o`000?ob3O;olPgb00Co
lPgb1?l00006ooD:m@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003okQ7^onhAkP09onhAkP03o`00
0?o?<<oocc3?00Socc3?00?o0000oiiQW_nNHIh00onNHIh>o`0000go>LHi00?o0000o`Wf2Ol9mPT0
0_l9mPT00ol0003o0?l0o`3o0005o`3o0003o`000?l]dRgo;M8]00_o;M8]00?o0000oc[5>_ljaCX0
3?ljaCX00ol0003o3_4>o`ka3P06o`ka3P03o`000?ljaC[o>/Dj00Go>/Dj00?o0000ofNHIomWV6L0
3?mWV6L00ol0003oYeRWojMHY`06ojMHY`03o`000?oL8mcog2?L00[og2?L00?o0000oo8=l_ob3O80
0ol0000:ooD:m@?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000oll`coo?<<l02?o?
<<l01Ol0003oWV6NoiiQW_nNHIko000000_oJYEZ00?o0000o`cc3?l<l``00ol00009ocW6>@03o`00
0?l9mPWo2OH900Co2OH900?o0000o`3o0?l0o`000ol0o`000ol0003o;M8]obgB;@0<obgB;@03o`00
0?ljaC[o>/Dj00go>/Dj00?o0000o`ka3_l>l@h01_l>l@h00ol0003o>/Djoc[5>P03oc[5>P?o0000
3OmWV6L00ol0003oYeRWojMHY`05ojMHY`03o`000?oL8mcog2?L00cog2?L0_l0000=ooD:m@03o`00
0?om0_goo@;m00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000oll`coo?<<l02?o?
<<l4o`0000coJYEZ00?o0000o`cc3?l<l``00ol<l``3o`0000Go>LHi00?o0000o`Wf2Ol9mPT01_l9
mPT01Ol0003o0?l0o`3o0?l0o`3o000000oo;M8]00?o0000oc[5>_ljaCX03OljaCX00ol0003o3_4>
o`ka3P06o`ka3P03o`000?ljaC[o>/Dj00?o00000olUfRD00ol0003oIiQWofNHI`0;ofNHI`03o`00
0?nWF:OoYeRW00?oYeRW00?o0000om`Sg?oL8m`03OoL8m`00ol0003om@[eooD:m@0;ooD:m@03o`00
0?om0_goo@;m00Coo@;m0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onhAk_o^4Nh02_o^4Nh3o`0000Kocc3?0ol0
0003oka3_003o`000?mZUF[oJYEZ00[oJYEZ00?o0000o`cc3?l<l``01_l<l``3o`000003ocW6>Ol0
003o2OH900Wo2OH900?o0000o`3o0?l000004?l]dRd00ol0003o>/Djoc[5>P0=oc[5>P03o`000?l>
l@ko3_4>00Oo3_4>0_l00007obGJ9@03o`000?mWV6OoIiQW00[oIiQW00Co0000ojMHYonWF:OoYeRW
0ol0000?om`Sg003o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d01oom0_d4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02_o^
4Nh01?l0003oi1_Ton@Ki?oT6n@2o`000004oll`col0003o0000o`0000Ko_4>l00?o0000ofZEJ_mZ
UFX02_mZUFX00ol0003o3?<<o`cc3009o`cc3003o`000?l9mPWo2OH900[o2OH900?o0000obgB;Ol]
dRd03ol]dRd00ol0003o>/Djoc[5>P0>oc[5>P03o`000?l>l@ko3_4>00Ko3_4>00?o0000obGJ9OlU
fRD01olUfRD4o`0000SoIiQW00Co0000ojMHYonWF:Oo00000onjAKX2o`0000gog2?L00?o0000ooD:
mOoe2_D02_oe2_D00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003o
i1_Ton@Ki004on@Ki003o`000?nl@kco_4>l00Oo_4>l00?o0000ofZEJ_mZUFX02OmZUFX00ol0003o
3?<<o`cc300:o`cc3003o`000?l9mPWo2OH900[o2OH900?o0000obgB;Ol]dRd03ol]dRd00ol0003o
>/Djoc[5>P0>oc[5>P03o`000?l>l@ko3_4>00Go3_4>00?o0000obGJ9OlUfRD02?lUfRD01?l0003o
GZ5NoejQG_mNXEh7o`0000;oIiQW0_l00006okY5^P;o00003?oL8m`00ol0003om@[eooD:m@09ooD:
m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003okQ7^onhAkP08onhAkP03o`000?oT6nCoi1_T00Go
i1_T00?o0000oka3_?nl@k`02?nl@k`00ol0003oJYEZofZEJP08ofZEJP03o`000?l<l`co3?<<00[o
3?<<00?o0000o`Wf2Ol9mPT02ol9mPT00ol0003o;M8]obgB;@0>obgB;@03o`000?ljaC[o>/Dj00ko
>/Dj1Ol00002o`ka3P03o`000?lUfRGo9MXU00Wo9MXU00?o0000oejQG_mNXEh02?mNXEh3o`0000Wo
^TFj0_l0000:om`Sg003o`000?oe2_Gom@[e00Som@[e00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o^4NkokQ7^00SokQ7^00?o0000on@Ki?oT6n@01ooT6n@00ol0003o_4>loka3_007oka3_003o`00
0?mZUF[oJYEZ00SoJYEZ00?o0000o`cc3?l<l``02_l<l``00ol0003o2OH9o`Wf2@0:o`Wf2@;o0000
3_l]dRd3o`0000go>/Dj0ol00005odFjA@;o00002olUfRD00ol0003oGZ5NoejQGP0;oejQGP;o0000
2_njAKX2o`0000Oog2?L0ol00009ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:on@Ki003o`00
0?nl@kco_4>l00Oo_4>l00?o0000ofZEJ_mZUFX02?mZUFX>o`0000Wo2OH90ol000000ol0o`3o0000
obgB;@0:obgB;@?o00000_m6^DH00ol0003o>/Djoc[5>P09oc[5>P;o00002Om5^TD00ol0003o9MXU
obGJ9@09obGJ9@03o`000?mNXEkoGZ5N00_oGZ5N00?o0000ohQgR?l000002onjAKX2o`0000Cog2?L
00Co0000on`Ck?o/4ncok1?/0_l00007ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003oi1_T
on@Ki009on@Ki003o`000?nl@kco_4>l00Ko_4>l00?o0000ofZEJ_mZUFX02?mZUFX00ol0003o4n`C
oa?/4`0:oa?/4`03o`000?l9mPWo2OH900Co2OH90ol00005o`3o0003o`000?l]dRgo;M8]00Co;M8]
1?l00006odJiAP03o`000?ljaC[o>/Dj00Ko>/Dj0_l0000;odFjA@03o`000?lUfRGo9MXU00Wo9MXU
00?o0000oejQG_mNXEh02_mNXEh01Ol0003oR7N8ohQgR?n8MhSo000000co^TFj0_l000000ooL8mco
0000on`Ck005on`Ck003o`000?oe2_Gom@[e00?om@[e00?o0000ood2oOom0_d02oom0_d00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oT6nCoi1_T00Soi1_T00?o0000oka3_?nl@k`01_nl@k`00ol0003oJYEZofZEJP07ofZEJP03o`00
0?lCk1?o4n`C00_o4n`C00?o0000o`Wf2Ol9mPT00_l9mPT2o`0000Wo0?l000?o0000obgB;Ol]dRd0
0ol0000;odJiAP03o`000?ljaC[o>/Dj00;o>/Dj0ol0000>odFjA@03o`000?lUfRGo9MXU00Oo9MXU
00?o0000oejQG_mNXEh02omNXEh00ol0003oR7N8ohQgR002ohQgR003o`000?njAK[o^TFj00_o^TFj
00?o0000on`Ck?o/4n`01_o/4n`2o`0000?om@[e00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oT
6nCoi1_T00Ooi1_T00?o0000oka3_?nl@k`01onl@k`00ol0003oJYEZofZEJP05ofZEJP?o00003OlC
k1<4o`0000_o0?l00ol0000?odJiAP04o`000?ljaC[o0000o`00017oAKY500?o0000obGJ9OlUfRD0
1olUfRD00ol0003oGZ5NoejQGP0:oejQGP03o`000?n8MhSoR7N800CoR7N800?o0000okY5^_njAKX0
1onjAKX3o`0000_ok1?/1?l0000=ood2o@03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on@Ki?oT6n@02?oT6n@00ol0003o_4>loka3
_006oka3_003o`000?mZUF[oJYEZ00;oJYEZ0ol00003odNhA`03o`000?lCk1?o4n`C00[o4n`C00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AodJiAP03o`000?m5^TGoAKY5017oAKY500?o
0000obGJ9OlUfRD01olUfRD00ol0003oGZ5NoejQGP0:oejQGP03o`000?n8MhSoR7N800GoR7N800Co
0000okY5^_njAK[o^TFj1Ol00002ol@ka003o`000?o/4ncok1?/00Wok1?/00Co0000ood2oOom0_go
o@;m0ol00009ood2o@03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000on@Ki?oT6n@01ooT6n@00ol0003o_4>loka3_005oka3_0?o0000
00?oJYEZo`000?l000001om7^4L00ol0003o4n`Coa?/4`08oa?/4`?o00002_l0o`02o`0000;o0?l0
00?o0000odJiA_m6^DH03om6^DH00ol0003oAKY5odFjA@0AodFjA@03o`000?lUfRGo9MXU00Oo9MXU
00?o0000oejQG_mNXEh02OmNXEh00ol0003oR7N8ohQgR007ohQgR0?o00001oo4>l@00ol0003ok1?/
on`Ck009on`Ck003o`000?om0_goo@;m00Coo@;m0_l00007ood2o@03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000on@Ki?oT6n@01ooT
6n@4o`0000;o_4>l0_l00003ok1?/003o`000?m7^4OoAkQ700SoAkQ70_l00006oa?/4`;o00000olB
kA800ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000odJiA_m6^DH03_m6
^DH00ol0003oAKY5odFjA@0BodFjA@03o`000?lUfRGo9MXU00Go9MXU00?o0000oejQG_mNXEh02OmN
XEh00ol0003oR7N8ohQgR008ohQgR003o`000?o4>lCoa3_400Ooa3_400?o0000on`Ck?o/4n`02?o/
4n`00ol0003oo@;mood2o@07ood2o@;o00001Oom0_d00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oT6nCoi1_T00Coi1_T0_l00004
onHIiP;o00001On`Ck000ol0003oAkQ7odNhA`0:odNhA`03o`000?lCk1?o4n`C00;o4n`C00?o0000
oa;]4_lBkA801?lBkA800ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
odJiA_m6^DH03_m6^DH00ol0003oAKY5odFjA@0BodFjA@[o00002_mNXEh00ol0003oR7N8ohQgR008
ohQgR003o`000?o4>lCoa3_400Ooa3_400?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@09
ood2o@?o000000?oo@;mo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003oi1_Ton@Ki?oT6n@2o`0000OoiQWV00?o0000ok1?/?n`Ck001?n`Ck00
0ol0003oAkQ7odNhA`0:odNhA`04o`000?lCk1?o0000o`0000So4^dB00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?m6^DKoA[U600koA[U600?o0000odFjAOm5^TD04_m5^TD00ol0003o@;m0
od2o@007od2o@003o`000?mNXEkoGZ5N00KoGZ5N00?o0000ohQgR?n8MhP02_n8MhP00ol0003oa3_4
ol@ka006ol@ka003o`000?o/4ncok1?/00Sok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oT
6nCo0000o`0000WoiQWV00?o0000ok1?/?n`Ck001?n`Ck000ol0003oAkQ7odNhA`0;odNhA`03o`00
0?lBkA;o4^dB00Wo4^dB00?o0000o`3o0?l000002Ol0o`000ol0003oA[U6odJiAP0>odJiAP;o0000
4_m5^TD00ol0003o@;m0od2o@009od2o@0;o00001_mNXEh00ol0003oR7N8ohQgR00:ohQgR003o`00
0?o4>lCoa3_400Koa3_400?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onHIi_oV6NH02OoV6NH00ol0003o/4n`ok1?/005ok1?/003o`000?m7^4OoAkQ700[oAkQ700?o
0000oa;]4_lBkA802_lBkA82o`0000Wo0?l000?o0000odJiA_m6^DH03_m6^DH00ol0003o<<l`o`00
0002o`0000ooAKY500?o0000od2o@?m0_d002om0_d000ol0003oGZ5NoejQGP03o`0000goR7N800?o
0000ol@ka?o4>l@01_o4>l@00ol0003ok1?/on`Ck007on`Ck003o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oiQWVonHIiP09onHIiP03o`000?n`Ck3o/4n`00Go/4n`00?o0000odNhAom7^4L02Om7^4L2
o`0000_o4^dB0_l0000;o`3o0003o`000?m6^DKoA[U600coA[U600?o0000oc3?<?l`cc000ol`cc03
o`0000coAKY500?o0000od2o@?m0_d003?m0_d02o`0000;oO8=l00?o0000ohQgR?n8MhP03?n8MhP0
0ol0003oa3_4ol@ka005ol@ka003o`000?o/4ncok1?/00Ook1?/00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oV6NKoiQWV00[oiQWV00?o0000ok1?/?n`Ck001_n`Ck000ol0003oAkQ7odNhA`07odNh
A`03o`000?m8]dSo000000[o4^dB00Co0000o`Oh1ol7n0Oo00002_l0o`000ol0003oA[U6odJiAP0<
odJiAP03o`000?l`cc3o<<l`00Ko<<l`0_l00008odFjA@;o00003om0_d000ol0003oO8=logb3O002
ogb3O003o`000?n8MhSoR7N800_oR7N800?o0000ol@ka?o4>l@01Oo4>l@00ol0003ok1?/on`Ck007
on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oiQWVonHIiP0:onHIiP03o`000?n`Ck3o/4n`
00Ko/4n`00?o0000odNhAom7^4L01_m7^4L01Ol0003oB;M8odRgB?m8]dSo000000So4^dB00?o0000
o`Oh1ol7n0L00_l7n0L00ol0003o0?l0o`3o0006o`3o00Co00003?m6^DH00ol0003o<<l`oc3?<008
oc3?<0?o00000_m5^TD3o`000003oc?<<ol0003o@;m000go@;m000?o0000ogb3O?mlPg`01?mlPg`0
0ol0003oR7N8ohQgR00:ohQgR003o`000?o4>lCoa3_400Goa3_400?o0000on`Ck?o/4n`01_o/4n`0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onHIi_oV6NH02ooV6NH00ol0003o/4n`ok1?/007ok1?
/003o`000?m7^4OoAkQ700?oAkQ70_l00005odRgB003o`000?lBkA;o4^dB00Co4^dB00?o0000o`Oh
1ol7n0L00ol7n0L00ol0003o0?l0o`3o0005o`3o0003o`000?l?l0oo3o0?00;o3o0?0ol00007odJi
AP;o00003_l`cc02o`0000Go<l`c00?o0000od2o@?m0_d002_m0_d000ol0003oO8=logb3O005ogb3
O003o`000?n8MhSoR7N800_oR7N800?o0000ol@ka?o4>l@01?o4>l@00ol0003ok1?/on`Ck006on`C
k003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiQWVonHIiP0;onHIiP03o`000?n`Ck3o/4n`00Oo
/4n`00?o0000odNhAom7^4L00_m7^4L00ol0003oB;M8odRgB006odRgB003o`000?lBkA;o4^dB00;o
4^dB00?o0000o`Oh1ol7n0L01Ol7n0L00ol0003o0?l0o`3o0002o`3o00;o00002?l?l0l3o`0000;o
A[U60_l000000olFjAKo0000oc3?<00=oc3?<003o`000?lcc3?o<l`c00Go<l`c00?o0000od2o@?m0
_d002?m0_d000ol0003oO8=logb3O007ogb3O003o`000?n8MhSoR7N800[oR7N800?o0000ol@ka?o4
>l@01?o4>l@00ol0003ok1?/on`Ck006on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWV
onHIiP0<onHIiP03o`000?n`Ck3o/4n`00So/4n`00Co0000odNhAom7^4Oo00002Om8]dP01Ol0003o
4^dBoa;]4_lBkA;o000000So1oP700Go0000o`3o0?l0o`3o0?l0o`00000=o`o`3`;o00001?lFjAH0
0ol0003o<<l`oc3?<00;oc3?<003o`000?lcc3?o<l`c00Ko<l`c00?o0000od2o@?m0_d001om0_d00
0ol0003oO8=logb3O008ogb3O0Co00002?n8MhP00ol0003oa3_4ol@ka004ol@ka003o`000?o/4nco
k1?/00Kok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oV6NKoiQWV00_oiQWV0ol00009ok1?
/003o`000?m7^4Oo000000_oB;M800?o0000oa;]4_l000002_l7n0L00ol0003o0?l0o`00000?o`o`
3`03o`000?lFjAKo5^TF00;o5^TF00?o0000oc3?<?l`cc002ol`cc000ol0003o<l`coc?<<`06oc?<
<`03o`000?m0_d3o@;m000Ko@;m000?o0000ogb3O?mlPg`02OmlPg`01?l0003o[U6^ojiA[_n^DJh7
o`0000;oR7N800?o0000ol@ka?o4>l@00oo4>l@00ol0003ok1?/on`Ck005on`Ck003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oV6NKoiQWV00SoiQWV0ol00003on0Oh003o`000?n`Ck3o/4n`00Oo/4n`00?o0000odRg
B?m8]dP02om8]dP00ol0003o1oP7o`Oh1`0:o`Oh1`03o`000?l?l0oo3o0?00go3o0?00?o0000oaKY
5_lFjAH01?lFjAH00ol0003o<<l`oc3?<009oc3?<003o`000?lcc3?o<l`c00So<l`c00?o0000od2o
@?m0_d000om0_d02o`0000coO8=l00?o0000ojiA[_n^DJh02?n^DJh<o`0000?ok1?/0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onHIi_oV6NH01_oV6NH3o`0000Ooh1oP00?o0000ok1?/?n`Ck001_n`Ck000ol0003o
B;M8odRgB00;odRgB003o`000?l7n0Oo1oP700Wo1oP70_l0000>o`o`3`03o`000?lFjAKo5^TF00Go
5^TF00?o0000oc3?<?l`cc002Ol`cc000ol0003o<l`coc?<<`09oc?<<`03o`000?m0_d3o000000;o
00000_maSW400ol0003oO8=logb3O008ogb3O003o`000?n^DJko[U6^00co[U6^00?o0000onLHiooW
6>L01_oW6>L3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oiQWVonHIiP03onHIiP?o00002ooP7n000ol0003o/4n`
ok1?/004ok1?/003o`000?m8]dSoB;M800_oB;M80ol00007o`Oh1`?o000000?o3_4>o`000?l?l0l0
3Ol?l0l00ol0003o5^TFoaKY5P06oaKY5P03o`000?l`cc3o<<l`00So<<l`00?o0000oc?<<olcc3<0
2_lcc3<00ol0003oLHiaog6>L@04og6>L@03o`000?mlPgcoO8=l00OoO8=l00?o0000ojiA[_n^DJh0
2on^DJh00ol0003oiaSWonLHi`08onLHi`03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onHIi_l0
003o0000o`0000ooh1oP00?o0000ok1?/?n`Ck000on`Ck0>o`0000?o=/Tf0_l00002o`Oh1`?o0000
1Ol>l@h00ol0003o3o0?o`o`3`0:o`o`3`03o`000?lFjAKo5^TF00Oo5^TF00?o0000oc3?<?l`cc00
2?l`cc000ol0003o<l`coc?<<`0:oc?<<`03o`000?maSW7oLHia00GoLHia00?o0000ogb3O?mlPg`0
1_mlPg`00ol0003o[U6^ojiA[P0;ojiA[P03o`000?oW6>OoiaSW00SoiaSW00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ok1?/2o`0001;oh1oP00?o0000ok1?/?n`Ck000_n`Ck000ol0003oTVfBoi9]
TP0:oi9]TP03o`000?lfbCKo=/Tf00?o=/Tf0_l00009o`ka3P03o`000?l?l0oo3o0?00Wo3o0?00?o
0000oaKY5_lFjAH02?lFjAH2o`0000So<<l`00?o0000oc?<<olcc3<02Olcc3<00ol0003oLHiaog6>
L@07og6>L@03o`000?mlPgcoO8=l00CoO8=l00?o0000ojiA[_n^DJh02on^DJh00ol0003oiaSWonLH
i`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003oh1oPon0Oh00?on0Oh0?o000000?o/4n`
o`000?nBKI802onBKI800ol0003o=/TfocK9=P04ocK9=P03o`000?l>l@ko3_4>00Wo3_4>00?o0000
o`o`3ol?l0l01ol?l0l00ol0003o5^TFoaKY5P09oaKY5P04o`000?lIiQWo0000o`0000Ko<<l`00?o
0000oc?<<olcc3<02Olcc3<00ol0003oLHiaog6>L@08og6>L@03o`000?mlPgcoO8=l00?oO8=l00?o
0000ojiA[_n^DJh02on^DJh00ol0003oiaSWonLHi`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003oh1oPon0Oh00<on0Oh0;o00000ooM8]d2o`0000coTVfB00?o0000ocK9=_lfbCH01?lfbCH0
0ol0003o3_4>o`ka3P0:o`ka3PWo00002olFjAH00ol0003o6NHIoaWV6@02oaWV6@?o00000_l`cc00
0ol0003o<l`coc?<<`0:oc?<<`03o`000?maSW7oLHia00WoLHia00?o0000ogb3O?mlPg`00_mlPg`0
0ol0003o[U6^ojiA[P0:ojiA[P03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oP7n02o`0000GogB;M00?o0000ok1?/?l000002_nBKI800ol0003o=/TfocK9=P06ocK9
=P03o`000?l>l@ko3_4>00Wo3_4>00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o5^TFoaKY5P09oaKY
5P03o`000?lIiQWo6NHI00Go6NHI0ol00009oc?<<`?o00003OmaSW401Ol0003oO8=logb3O?mlPgco
000000co[U6^00?o0000onLHiooW6>L02OoW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on0O
h?oP7n001OoP7n02o`0000OogB;M00Co0000ok1?/?n`Ck3o00002OnBKI800ol0003o=/TfocK9=P06
ocK9=P03o`000?l>l@ko3_4>00So3_4>00?o0000o`Ki1_l6n@H01ol6n@H00ol0003o5^TFoaKY5P07
oaKY5P03o`000?lIiQWo6NHI00So6NHI0ol00002oc?<<`Go00000_m=/Td00ol0003oLHiaog6>L@0<
og6>L@03o`000?mlPgco000000co[U6^00?o0000onLHiooW6>L02_oW6>L00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000on0Oh?oP7n000_oP7n02o`0000SogB;M00?o0000ok1?/?n`Ck000_n`Ck05o`00
00CoTVfB00?o0000ocK9=_lfbCH01_lfbCH00ol0003o3_4>o`ka3P08o`ka3P03o`000?l6n@Ko1_T6
00Oo1_T600?o0000oaKY5_lFjAH01olFjAH00ol0003o6NHIoaWV6@08oaWV6@03o`000?lQgR7o8MhQ
00;o00002?m=/Td00ol0003oLHiaog6>L@0<og6>L@Co00002_n^DJh00ol0003oiaSWonLHi`0:onLH
i`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003oh1oPo`000?l0000:omdRg@03o`000?n`Ck3o/4n`
00;o/4n`00?o0000ofbCK?m/Tf`00_m/Tf`4o`0000Wo=/Tf00?o0000o`ka3_l>l@h02?l>l@h00ol0
003o1_T6o`Ki1P08o`Ki1P03o`000?lFjAKo5^TF00Go5^TF00?o0000oaWV6OlIiQT02?lIiQT01Ol0
003o8MhQob7N8OlQgR7o000000[oCK9=0ol0000;og6>L@04o`000?oF:MKoeRWFomHYePCo00001On^
DJh00ol0003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ogB;MomdRg@0:
omdRg@03o`000?n`Ck3o/4n`00?o/4n`00?o0000ofbCK?m/Tf`01?m/Tf`00ol0003o=/TfocK9=P07
ocK9=P03o`000?l>l@ko3_4>00Ko3_4>0_l0000;o`Ki1P03o`000?lFjAKo5^TF00Go5^TF00?o0000
oaWV6OlIiQT02?lIiQT00ol0003o8MhQob7N8@02ob7N8@03o`000?m=/TgoCK9=00OoCK9=00?o0000
oiiQW_nNHIh01?l00006og6>L@03o`000?oF:MKoeRWF00KoeRWF0ol00002ojiA[P03o`000?oW6>Oo
iaSW00_oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oM8]gogB;M00WogB;M00?o0000ok1?
/?n`Ck001?n`Ck000ol0003oK9=/ofbCK005ofbCK003o`000?lfbCKo=/Tf00Oo=/Tf00?o0000o`ka
3_l>l@h00_l>l@h3o`000003oacS7?l0003o1_T600[o1_T600?o0000oaKY5_lFjAH01OlFjAH00ol0
003o6NHIoaWV6@07oaWV6@03o`000?lQgR7o8MhQ00?o8MhQ00?o0000odfbCOm=/Td01om=/Td00ol0
003oWV6NoiiQWP04oiiQWP?o00000_maSW400ol0003oeRWFomHYeP0:omHYeP;o00003_oW6>L00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omdRgOoM8]d02OoM8]d00ol0003o/4n`ok1?/004ok1?/003
o`000?m/TfcoK9=/00KoK9=/0_l00007ocK9=P03o`000?l>l@ko000000;o00001OlLha`00ol0003o
1_T6o`Ki1P08o`Ki1P?o00001?lFjAH00ol0003o6NHIoaWV6@08oaWV6@03o`000?lQgR7o8MhQ00Co
8MhQ00?o0000odfbCOm=/Td01_m=/Td00ol0003oWV6NoiiQWP07oiiQWP;o00003_oF:MH00ol0003o
iaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ogB;MomdRg@08omdRg@03o`00
0?n`Ck3o/4n`00Go/4n`00?o0000ofbCK?m/Tf`01?m/Tf`00ol0003oJ9MXofRGJ003o`0000Co=/Tf
0_l00008oacS7003o`000?l6n@Ko1_T600Oo1_T600Co0000ocK9=_lfbCKo=/Tf0ol000000olFjAKo
0000oaWV6@09oaWV6@03o`000?lQgR7o8MhQ00Co8MhQ00?o0000odfbCOm=/Td01Om=/Td00ol0003o
WV6NoiiQWP09oiiQWP03o`000?oF:MKoeRWF00goeRWF00?o0000onLHiooW6>L02_oW6>L00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omdRgOoM8]d01ooM8]d00ol0003o/4n`ok1?/006ok1?/003o`00
0?m/TfcoK9=/00?oK9=/00?o0000ofRGJ?mXUfP01?mXUfP2o`000003ocK9=_l0003o7><L00[o7><L
00?o0000o`Ki1_l6n@H01Ol6n@H00ol0003o=/TfocK9=P05ocK9=P03o`000?lIiQWo6NHI00Oo6NHI
0ol00007ob7N8@03o`000?m=/TgoCK9=00CoCK9=00?o0000oiiQW_nNHIh02OnNHIh00ol0003oeRWF
omHYeP0=omHYeP03o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oM
8]gogB;M00GogB;M0ol00009ok1?/005o`000?m/TfcoK9=/ofbCK?l000002OmXUfP00ol0003o7><L
oacS700;oacS7003o`000?l6n@Ko1_T600?o1_T600?o0000ocK9=_lfbCH01_lfbCH00ol0003o6NHI
oaWV6@06oaWV6@05o`000?lbcC;o</dboc;=<_l000001olQgR400ol0003oCK9=odfbC@03odfbC@03
o`000?nNHIkoWV6N00WoWV6N00?o0000omHYe_oF:MH03_oF:MH00ol0003oiaSWonLHi`09onLHi`03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ogB;Mo`000004o`0000;ojAKY00?o0000ok1?/?n`Ck00
1on`Ck001?l0003oK9=/ofbCK?l00009ofRGJ0;o00003OlLha`00ol0003o1_T6o`Ki1P02o`Ki1P03
o`000?lfbCKo=/Tf00So=/Tf00?o0000oaWV6OlIiQT00olIiQT2o`0000Go</db00?o0000ob7N8OlQ
gR401?lQgR400ol0003oCK9=odfbC@03odfbC@03o`000?nNHIkoWV6N00WoWV6N00?o0000omHYe_oF
:MH03_oF:MH00ol0003oiaSWonLHi`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SojAKY
00?o0000ok1?/?n`Ck001_n`Ck000ol0003oK9=/o`000009ofRGJ004o`000?m?/4ooCk1?o`0000go
7><L00Co0000o`Ki1_l6n@Ko00003?lfbCH01Ol0003o6NHIoaWV6OlIiQWo000000So</db0_l00005
ob7N8@03o`000?m=/TgoCK9=00;oCK9=00?o0000oiiQW_nNHIh02OnNHIh00ol0003oeRWFomHYeP0>
omHYeP03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oY5^WojAKY
00OojAKY00?o0000ok1?/?n`Ck001on`Ck000ol0003oJ9MXofRGJ007ofRGJ003o`000?m?/4ooCk1?
00;oCk1?00?o0000oacS7?lLha`02_lLha`00ol0003o1_T6o`00000>ocK9=P03o`000?lIiQWo0000
00_o</db00?o0000ob7N8OlQgR400_lQgR401Ol0003oCK9=odfbCOm=/Tgo000000coWV6N00?o0000
omHYe_oF:MH03_oF:MH3o`0000WoiaSW00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oY5^WojAKY
00WojAKY00?o0000ok1?/?n`Ck001_n`Ck000ol0003oJ9MXofRGJ006ofRGJ003o`000?m?/4ooCk1?
00?oCk1?00?o0000oacS7?lLha`02olLha`00ol0003o=/TfocK9=P0>ocK9=P03o`000?lbcC;o</db
00_o</db0_l00003ob7N8@04o`000?m=/TgoCK9=o`0000[oWV6N0ol0000>omHYeP;o00000ool0o`2
o`0000OoiaSW00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oY5^WojAKY00[ojAKY00?o0000ok1?
/?n`Ck001?n`Ck000ol0003oJ9MXofRGJ006ofRGJ003o`000?m?/4ooCk1?00GoCk1?00?o0000oacS
7?lLha`01olLha`3o`00017o=/Tf00?o0000oc;=<_lbcC803OlbcC801Ol0003o8MhQob7N8Ol0003o
CK9=00Co00000onNHIh5o`0000;ohAkQ00?o0000omHYe_oF:MH02_oF:MH2o`0000Ooo0?l0_l00004
onLHi`03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ojAKYonTFj@0;onTFj@03o`000?n`Ck3o/4n`
00Co/4n`00?o0000ofRGJ?mXUfP01OmXUfP00ol0003oCk1?odn`C`06odn`C`03o`000?lLhaco7><L
00Co7><L0ol00002obCK9003o`000?lfbCKo=/Tf00oo=/Tf0_l0000?oc;=<P04o`000?lQgR7o0000
o`0000CoRGJ90ol00008on4Nh@03o`000?oF:MKoeRWF00OoeRWF0_l0000;oo`3o0;o00000_oW6>L0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onTFjOoY5^T03?oY5^T6o`0000OoJ9MX00?o0000odn`
Com?/4l02?m?/4l00ol0003o7><LoacS7003o`0000Ko9=/T00?o0000ocK9=_lfbCH03OlfbCH01?l0
003o@;m0od2o@?l0000?oc;=<P03o`000?n9MXWoRGJ900GoRGJ900?o0000on4NhOoQ7^402?oQ7^40
0ol0003oeRWFomHYeP05omHYeP03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oY5^T00ol0003o]dRgokM8]`04okM8
]`03o`000?mXUfSoJ9MX00?oJ9MX00?o0000odn`Com?/4l02_m?/4l2o`0000[o9=/T00?o0000ocK9
=_lfbCH02olfbCH00ol0003o@;m0od2o@002od2o@003o`000?lbcC;o</db00_o</db0_l00007ohUf
R@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000omHYe_oF:MH00_oF:MH2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onTFjOoY5^T02ooY5^T00ol0003o]dRgokM8]`06okM8]`05o`000?mXUfSoJ9MXofRG
J?l000003Om?/4l00ol0003o9=/TobCK900:obCK9003o`000?lfbCKo=/Tf00Wo=/Tf00?o0000od2o
@?m0_d001?m0_d000ol0003o</dboc;=<P08oc;=<P;o000000?o>l@ko`000?n9MXT01on9MXT00ol0
003ohAkQon4Nh@09on4Nh@04o`000?oF:MKo0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oY5^WojAKY
00WojAKY00?o0000okM8]ongB;L02?ngB;L00ol0003oJ9MXo`00000=odn`C`03o`000?lTfbCo9=/T
00_o9=/T00?o0000ocK9=_lfbCH02?lfbCH00ol0003o@;m0od2o@006od2o@003o`000?lbcC;o</db
00Go</db0_l00003oc_4>`03o`000?n9MXWoRGJ900KoRGJ900?o0000on4NhOoQ7^402_oQ7^400ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ojAKYonTFj@07onTFj@03o`000?ngB;Oo]dRg00[o]dRg00?o0000odn`Com?
/4l03?m?/4l00ol0003o9=/TobCK900<obCK9003o`000?lfbCKo=/Tf00Ko=/Tf00?o0000od2o@?m0
_d002?m0_d000ol0003o</dboc;=<P02oc;=<P;o00001_lka3/00ol0003oRGJ9ohUfR@05ohUfR@03
o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oY5^WojAKY00GojAKY
00?o0000okM8]ongB;L03?ngB;L2o`0000coCk1?00?o0000obCK9?lTfb@03OlTfb@00ol0003o=/Tf
ocK9=P04ocK9=P03o`000?m0_d3o@;m000[o@;m000Co0000oc;=<_l0003o00002?lka3/00ol0003o
RGJ9ohUfR@06ohUfR@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oY5^T00ol0003o]dRgokM8]`0=okM8]`03o`000?m[U6_o000000;o00002?m?/4l00ol0003o9=/T
obCK900?obCK90Ko00003_m0_d000ol0003o>l@koc_4>`08oc_4>`03o`000?n9MXWoRGJ900KoRGJ9
00?o0000on4NhOoQ7^402OoQ7^400ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000on`Ck?o/4ncok1?/
0_l0000?okM8]`03o`000?m[U6_oJiA[00?oJiA[0ol00005odn`C`;o00004?lTfb@01_l0003o5nPG
oaOX5ol0003o2?L8o`0000ko@;m000?o0000oc_4>olka3/02Olka3/00ol0003oRGJ9ohUfR@05ohUf
R@03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000on`Ck?o/4n`00oo/4n`00ol0003o
]dRgokM8]`0=okM8]`03o`000?m[U6_oJiA[00KoJiA[0ol000001?m?/4oo0000ob_D:ol[e2/3o`00
00co9=/T00Go0000oaOX5olGj1Oo5nPGo`000002o`Sg2003o`000?m0_d3o@;m000_o@;m000?o0000
oc_4>olka3/02Olka3/00ol0003oRGJ9ohUfR@06ohUfR@03o`000?oQ7^7ohAkQ00SohAkQ0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003ok1?/on`Ck004on`Ck0oo00003?m[U6/00ol0003o:m@[ob_D:`04ob_D
:`?o00002?lTfb@00ol0003o5nPGoaOX5`02oaOX5`05o`000?l8m`So2?L8o`Sg2?l000003?m0_d00
0ol0003o>l@koc_4>`09oc_4>`03o`000?n9MXWoRGJ900GoRGJ93?l00002oo8=lP;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003ok1?/on`Ck005on`Ck003o`000?nfBKKo]TVf00_o]TVf00?o0000of^D
Jom[U6/02_m[U6/00ol0003o:m@[ob_D:`07ob_D:`;o00001OlTfb@00ol0003o5nPGoaOX5`03oaOX
5`03o`000?l8m`So2?L800;o2?L800?o0000od2o@?m0_d002Om0_d000ol0003o>l@koc_4>`0:oc_4
>`03o`000?n9MXWoRGJ900?oRGJ900?o0000om8]d_oB;M802OoB;M800ol0003olPgboo8=lP02oo8=
lP;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ok1?/on`Ck006on`Ck003o`000?nfBKKo]TVf00[o
]TVf00?o0000of^DJom[U6/02om[U6/00ol0003o:m@[ob_D:`09ob_D:`?o000000?o9=/To`000?lG
j1L01OlGj1L00ol0003o2?L8o`Sg2003o`Sg2003o`000?m0_d3o@;m000So@;m03_l00003ohUfR@;o
00002ooB;M800ol0003olPgboo8=lP05oo8=lP03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000on`Ck?o/4n`01Oo/4n`00ol0003o`cc3o`00000;okI9]P03o`000?m[U6_oJiA[00[oJiA[
0_l0000>ob_D:`03o`000?lGj1Oo5nPG00Go5nPG00?o0000o`Sg2?l8m`P00ol8m`P00ol0003o@;m0
od2o@008od2o@003o`000?n5NXGoQGZ500_oQGZ500?o0000ohUfROl000003OoB;M800ol0003olPgb
oo8=lP06oo8=lP;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o/4ncok1?/00Kok1?/00Co
0000ol<l`oo3?<?o00002_nfBKH00ol0003oJiA[of^DJ`09of^DJ`03o`000?m5^TGo000000ko:m@[
00?o0000oaOX5olGj1L01OlGj1L00ol0003o2?L8o`Sg2004o`Sg2003o`000?m0_d3o@;m000Ko@;m0
00?o0000ohEjQOn5NXD03On5NXD00ol0003odRgBom8]dP0<om8]dP03o`000?ob3O;olPgb00SolPgb
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o/4ncok1?/00Gok1?/00?o0000ol<l`oo3?<<00_o3
?<<00ol0003o]TVfokI9]P06okI9]P03o`000?m[U6_oJiA[00SoJiA[0_l00003odFjA@03o`000?l[
e2_o:m@[00_o:m@[00?o0000oaOX5olGj1L01OlGj1L00ol0003o2?L8o`Sg2005o`Sg2003o`000?m0
_d3o@;m000Go@;m000?o0000ohEjQOn5NXD03On5NXD00ol0003odRgBom8]dP0;om8]dP03o`000?ob
3O;olPgb00WolPgb00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o/4ncok1?/00Kok1?/00?o0000
ol<l`oo3?<<00oo3?<<00ol0003o]TVfokI9]P05okI9]P03o`000?m[U6_oJiA[00OoJiA[00?o0000
odFjAOm5^TD00om5^TD00ol0003o:m@[ob_D:`0:ob_D:`03o`000?lGj1Oo5nPG00Ko5nPG00?o0000
o`Sg2?l8m`P01_l8m`P00ol0003o@;m0od2o@004od2o@003o`000?n5NXGoQGZ500goQGZ53ol0000;
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o/4ncok1?/00Kok1?/00?o0000ol<l`oo3?<<01Oo3?<<00ol0
003o]TVfokI9]P04okI9]P03o`000?m[U6_oJiA[00GoJiA[0_l00006odFjA@03o`000?l[e2_o:m@[
00Wo:m@[0_l00008oaOX5`03o`000?l8m`So2?L800Ko2?L81Ol000000om0_d3o0000ohEjQ@0?ohEj
Q@03o`000?oD:mCoe2_D00_oe2_D00?o0000oo8=l_ob3O802Oob3O800ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o/4ncok1?/00Kok1?/00?o0000ol<l`oo3?<<01_o3?<<00ol0003o
]TVfokI9]P04o`0000KoJiA[00?o0000odFjAOm5^TD01om5^TD00ol0003o:m@[ob_D:`05ob_D:`?o
000000?o5nPGo`000?lGj1L01olGj1L00ol0003o2?L8o`Sg2005o`Sg2003o`000?m;]4_oBkA;00?o
BkA;0_l0000?ohEjQ@;o00003OoD:m@00ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000Wok1?/00?o0000ol<l`oo3?<<01oo3?<<2o`0000CoWV6N00Co0000of^DJom[U6_o
JiA[0_l0000:odFjA@03o`000?l[e2_o:m@[00;o:m@[0ol00005oaOX5`03o`000?lGj1Oo5nPG00Go
5nPG00?o0000o`Sg2?l8m`P01?l8m`P00ol0003oBkA;od^dB`06od^dB`03o`000?n5NXGoQGZ500[o
QGZ50_l00002ok1?/003o`000?oD:mCoe2_D00[oe2_D00?o0000oo8=l_ob3O802?ob3O800ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000on`Ck?o/4n`01_o/4n`00ol0003o`cc3ol<l``08ol<l``03o`00
0?nNHIkoWV6N00CoWV6N00?o0000of^DJol000003?m5^TD00ol0003o:m@[o`000002o`0000Wo5nPG
00?o0000oaOX5olGj1L01?lGj1L00ol0003o2?L8o`Sg2003o`Sg2003o`000?m;]4_oBkA;00SoBkA;
1_l00004ohEjQ@;o00001On`Ck000ol0003oe2_Dom@[e009om@[e003o`000?ob3O;olPgb00SolPgb
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o/4ncok1?/00Gok1?/00?o0000ol<l`oo3?<<01oo3
?<<00ol0003oWV6NoiiQWP06oiiQWP03o`000?m5^TGoAKY500coAKY500?o0000oaOX5olGj1L02_lG
j1L00ol0003o5nPGoaOX5`04oaOX5`04o`000?l8m`So2?L8o`Sg20;o00002om;]4/00ol0003oS7><
ohacS003ohacS0Co00002?n`Ck000ol0003oe2_Dom@[e008om@[e003o`000?ob3O;olPgb00OolPgb
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000on`Ck?o/4n`00oo/4n`00ol0003o`cc3ol<l``07ol<l``03o`000?nN
HIkoWV6N00OoWV6N00?o0000odFjAOm5^TD03?m5^TD00ol0003o5nPGoaOX5`0;oaOX5`03o`000?lG
j1Oo5nPG00?o5nPG00Co0000o`Sg2?l8m`So00003Om;]4/00ol0003oS7><ohacS006ohacS003o`00
0?n`Ck3o/4n`00Oo/4n`00?o0000om@[e?oD:m@01ooD:m@00ol0003olPgboo8=lP06oo8=lP04o`00
0?om0_goo@;mood2o@;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o/4ncok1?/00;ok1?/00?o0000ol<l`oo3?<<0
1_o3?<<00ol0003oWV6NoiiQWP09oiiQWP03o`000?m5^TGoAKY500WoAKY50_l0000>oaOX5`?o0000
0olGj1L00ol0003o2?L8o`00000=od^dB`03o`000?n<LhcoS7><00OoS7><00?o0000ok1?/?n`Ck00
2?n`Ck0:o`0000KolPgb0_l00006ood2o@03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Oo`cc300?o
0000oiiQW_nNHIh02_nNHIh00ol0003oAKY5odFjA@06odFjA@;o000000?o?L8mo`000?lGj1L02olG
j1L2o`0000?o?L8m1Ol0000>od^dB`03o`000?n<LhcoS7><00OoS7><00?o0000ok1?/?n`Ck002?n`
Ck000ol0003ogb3OomlPg`06omlPg`03o`000?ob3O;olPgb00?olPgb00?o0000ood2oOom0_d01oom
0_d2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ohAkQon4Nh@03on4Nh@Co00000_o3?<<00ol0003oWV6NoiiQWP0;
oiiQWP03o`000?m5^TGoAKY500?oAKY50ol00004ocg2?@03o`000?lGj1Oo5nPG00Oo5nPG0_l00008
ocg2?@03o`000?m;]4_oBkA;00goBkA;00?o0000ohacS?n<Lh`02?n<Lh`00ol0003o/4n`ok1?/007
ok1?/003o`000?oO8=oogb3O00Oogb3O0ol000000oob3O;o0000ood2o@0;ood2o@;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oQ7^7ohAkQ00OohAkQ0_l0000?oiiQWP03o`000?m5^TGoAKY500;o00002?lm`Sd00ol0
003o5nPGoaOX5`05oaOX5`03o`000?lm`Sgo?L8m00So?L8m00?o0000od^dBom;]4/03Om;]4/00ol0
003oS7><ohacS008ohacS003o`000?n`Ck3o/4n`00Ko/4n`00?o0000omlPgooO8=l02?oO8=l01?l0
003ol`ccoo<<lol0000?ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ohAkQon4Nh@09on4N
h@03o`000?nNHIkoWV6N00koWV6N0_l0000;ocg2?@03o`000?lGj1Oo5nPG00;o5nPG0_l0000;ocg2
?@03o`000?m;]4_oBkA;00goBkA;00?o0000ohacS?n<Lh`02?n<Lh`00ol0003o/4n`ok1?/006ok1?
/003o`000?oO8=oogb3O00Oogb3O00Go0000oo<<looc3??ol`cco`00000@ood2o@;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ohAkQon4Nh@0:on4Nh@03o`000?nNHIkoWV6N00goWV6N0_l0000<ocg2?@04o`000?lGj1Oo0000
o`0000go?L8m00?o0000od^dBom;]4/03?m;]4/00ol0003oS7><ohacS009ohacS003o`000?n`Ck3o
/4n`00Ko/4n`00?o0000omlPgooO8=l01_oO8=l00ol0003ol`ccoo<<l`03oo<<l`03o`000?om0_go
o@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ohAkQon4Nh@0:on4Nh@03o`000?nNHIkoWV6N00coWV6N00Co0000ogF:
MOmeRWGo00003?lm`Sd00ol0003o?L8mocg2?@0>ocg2?@03o`000?m;]4_oBkA;00SoBkA;1?l0000;
ohacS003o`000?n`Ck3o/4n`00Ko/4n`00?o0000omlPgooO8=l01OoO8=l00ol0003ol`ccoo<<l`04
oo<<l`03o`000?om0_goo@;m00ooo@;m00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ohAkQon4Nh@0;on4Nh@03o`000?nNHIkoWV6N
00_oWV6N00?o0000ogF:MOmeRWD00_meRWD00ol0003o?L8mocg2?@09ocg2?@03o`000?lm`Sgo?L8m
00ko?L8m00Co0000od^dBom;]4_oBkA;1ol00003of2OH003o`000?n<LhcoS7><00WoS7><00?o0000
ok1?/?n`Ck001_n`Ck000ol0003ogb3OomlPg`04omlPg`03o`000?oc3??ol`cc00Kol`cc00?o0000
ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oQ7^7ohAkQ00cohAkQ00?o0000oiiQW_nNHIh02_nNHIh00ol0
003oMHYeogF:M@03ogF:M@03o`000?lm`Sgo?L8m00So?L8m00?o0000ocg2?Olm`Sd03_lm`Sd4o`00
00_oH9mP00?o0000ohacS?n<Lh`02?n<Lh`00ol0003o/4n`ok1?/005ok1?/003o`000?oO8=oogb3O
00Gogb3O00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on4NhOoQ
7^403?oQ7^47o`0000GoWV6N00?o0000ogF:MOmeRWD01OmeRWD00ol0003o?L8mocg2?@07ocg2?@03
o`000?lm`Sgo?L8m00ko?L8m00?o0000of2OH?mPWf003OmPWf000ol0003oS7><ohacS008ohacS003
o`000?n`Ck3o/4n`00Co/4n`00?o0000omlPgooO8=l01?oO8=l00ol0003ol`ccoo<<l`07oo<<l`03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohAkQon4Nh@0=on4Nh@03o`000?nn@Kko_T6n00Co_T6n
1Ol00009ogF:M@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000ocg2?Olm`Sd03_lm`Sd00ol0003oH9mP
of2OH00=of2OH003o`000?n<LhcoS7><00SoS7><00Co0000ok1?/?n`Ck3o/4n`1Ol00004omlPg`03
o`000?oc3??ol`cc00Wol`cc1?l0000:ood2o@03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=on4Nh@03o`000?nn@Kko_T6n00Wo_T6n
0_l00009ogF:M@03o`000?lm`Sgo?L8m00Ko?L8m00?o0000ocg2?Olm`Sd03?lm`Sd00ol0003oH9mP
of2OH00?of2OH0Ko00001?n<Lh`4o`0000GofbCK0_l000000ooO8=oo0000oo<<l`0;oo<<l`04o`00
0?om0_goo@;mood2o@Oo00000oom0_d00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o^4NkokQ7^onhAkP?o00002_oQ7^400ol0003o
_T6noki1_P09oki1_P03o`000?n:MH[o000000;o00001omeRWD00ol0003o?L8mocg2?@05ocg2?@03
o`000?lm`Sgo?L8m00So?L8m1Ol0000Aof2OH003o`000?nLHicoW6>L00?oW6>L1?l0000;om/Tf`03
o`000?oc3??ol`cc00[ol`cc00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000onhAk_o^4Nh01Oo^4Nh2o`0000OohAkQ
00?o0000oki1__nn@Kh02_nn@Kh00ol0003oRWF:ohYeRP02ohYeRP?o00001OmeRWD00ol0003o?L8m
ocg2?@04ocg2?@04o`000?lm`Sgo?L8mocg2?@Oo00001?m;]4/00ol0003oH9mPof2OH00>of2OH003
o`000?nLHicoW6>L00OoW6>L00?o0000om/TfooK9=/02OoK9=/00ol0003ol`ccoo<<l`09oo<<l`03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003okQ7^onhAkP08onhAkP;o00001?oQ7^400ol0003o_T6n
oki1_P0;oki1_P03o`000?n:MH[oRWF:00GoRWF:0ol00003ogF:M@04o`000?lm`Sgo?L8mocg2?@Ko
00003?m;]4/00ol0003oH9mPof2OH00=of2OH003o`000?nLHicoW6>L00OoW6>L00?o0000om/TfooK
9=/02_oK9=/00ol0003ol`ccoo<<l`08oo<<l`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onhAkP?o000000?ohAkQo`000?nn@Kh0
3?nn@Kh00ol0003oRWF:ohYeRP08ohYeRP?o000000CoMHYeo`000?l0003o00000_n@Ki000ol0003o
BkA;od^dB`0=od^dB`03o`000?mPWf3oH9mP00coH9mP00?o0000oiaSW?nLHi`02?nLHi`00ol0003o
fbCKom/Tf`0;om/Tf`03o`000?oc3??ol`cc00Kol`cc00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
kQ7^00?o0000oki1__nn@Kh03?nn@Kh00ol0003oRWF:ohYeRP0;ohYeRP03o`000?n@Ki3oT6n@00?o
T6n@00?o0000od^dBom;]4/03?m;]4/00ol0003oBkA;o`00000=of2OH003o`000?nLHicoW6>L00So
W6>L00?o0000om/TfooK9=/03?oK9=/3o`0000Gol`cc00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o^4NkokQ7^00cokQ7^00?o0000oki1__nn@Kh03?nn@Kh00ol0003oRWF:ohYeRP0:ohYeRP03o`00
0?n@Ki3oT6n@00GoT6n@00?o0000od^dBom;]4/02_m;]4/01?l0003oBkA;od^dBom;]4/2o`0000[o
H9mP00?o0000oiaSW?nLHi`02OnLHi`00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oe2_Gom@[e00?o
000000?ol`cco`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000oki1__nn@Kh0
3?nn@Kh00ol0003oRWF:ohYeRP09ohYeRP03o`000?n@Ki3oT6n@00KoT6n@00?o0000od^dBom;]4/0
2Om;]4/00ol0003oBkA;od^dB`02od^dB`03o`000?nAKY7o000000;o00001omPWf000ol0003oW6>L
oiaSW009oiaSW003o`000?oK9=_ofbCK00_ofbCK00?o0000ooD:mOoe2_D01?oe2_D00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02oo^4Nh00ol0003o_T6noki1_P0;oki1_P03o`000?n:
MH[oRWF:00SoRWF:00?o0000oi1_T?n@Ki001on@Ki000ol0003oBkA;od^dB`08od^dB`03o`000?m;
]4_oBkA;00?oBkA;00?o0000oi5^TOnAKY400_nAKY42o`0000CoH9mP00?o0000oiaSW?nLHi`02_nL
Hi`00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o^4NkokQ7^00[okQ7^0ol0000;oki1_PKo00001?n:MHX00ol0003oT6n@oi1_T008
oi1_T003o`000?m;]4_oBkA;00OoBkA;00?o0000od^dBom;]4/00om;]4/00ol0003oTFjAoi5^T@05
oi5^T@?o000000?oH9mPo`000?nLHi`02onLHi`00ol0003ofbCKom/Tf`09om/Tf`03o`000?oe2_Go
m@[e00Oom@[e00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o^4NkokQ7^00WokQ7^00?o0000omXU
f_oJ9MX01?l00006oki1_P03o`000?nl@kco_4>l00Co_4>l1?l0000<oi1_T003o`000?m;]4_oBkA;
00GoBkA;00?o0000od^dBom;]4/01?m;]4/00ol0003oTFjAoi5^T@08oi5^T@03o`000?nLHicoW6>L
00_oW6>L00?o0000om/TfooK9=/02?oK9=/00ol0003om@[eooD:m@08ooD:m@Go00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o^4NkokQ7^00OokQ7^00?o0000omXUf_oJ9MX01OoJ9MX3o`0000;o_T6n00?o0000oka3_?nl
@k`02?nl@k`00ol0003oT6n@oi1_T00:oi1_T003o`000?m;]4_oBkA;00CoBkA;00?o0000od^dBom;
]4/01Om;]4/00ol0003oTFjAoi5^T@08oi5^T@03o`000?nLHicoW6>L00WoW6>L1?l00008om/Tf`03
o`000?oe2_Gom@[e00Wom@[e00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^
onhAkP05onhAkP03o`000?oJ9M[ofRGJ00WofRGJ0_l0000<oka3_003o`000?n@Ki3oT6n@00WoT6n@
00?o0000od^dBom;]4/00om;]4/00ol0003oBkA;od^dB`05od^dB`03o`000?nAKY7oTFjA00[oTFjA
00?o0000oiaSW?nLHi`01?nLHi`4o`0000CodRgB00?o0000om/TfooK9=/01?oK9=/00ol0003om@[e
ooD:m@0:ooD:m@03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o^4NkokQ7^00?okQ7^00?o0000omXUf_oJ9MX02ooJ
9MX00ol0003o_4>loka3_00:oka3_003o`000?n@Ki3oT6n@00WoT6n@00?o0000od^dBom;]4/00_m;
]4/00ol0003oBkA;od^dB`06od^dB`03o`000?nAKY7oTFjA00[oTFjA00?o0000oiaSW?nLHi`01?l0
0009om8]dPKo00003?oe2_D00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000onhAk_o^4NkokQ7^0_l0
000=omXUfP03o`000?nl@kco_4>l00[o_4>l00?o0000oi1_T?n@Ki002On@Ki001Ol0003oBkA;od^d
Bom;]4_o000000WoBkA;00?o0000oi5^TOnAKY402onAKY42o`0000godRgB00?o0000oo8=l_ob3O80
0_ob3O800ol0003om@[eooD:m@0:ooD:m@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003okQ7^o`00
0002ooH9mP;o00002ooJ9MX00ol0003o_4>loka3_00;oka3_003o`000?n@Ki3oT6n@00WoT6n@00?o
0000od^dBol000002Om;]4/00ol0003oTFjAoi5^T@0<oi5^T@03o`000?oB;M;odRgB00codRgB00?o
0000oo8=l_ob3O800oob3O800ol0003om@[eooD:m@09ooD:m@03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003omPWfooH9mP03ooH9mP;o00002_oJ9MX00ol0003o_4>loka3_00:oka3_003o`000?n@Ki3o
T6n@00SoT6n@1Ol00008od^dB`03o`000?nAKY7oTFjA00coTFjA00?o0000om8]d_oB;M802ooB;M80
0ol0003olPgboo8=lP05oo8=lP03o`000?oe2_Gom@[e00Som@[e00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001oof2OH2o`0000SofRGJ00?o0000oka3_?nl@k`02_nl@k`00ol0003oT6n@oi1_T007oi1_
T003o`000?n>LHkoSW6>00?oSW6>0ol00005od^dB`03o`000?nAKY7oTFjA00_oTFjA00?o0000om8]
d_oB;M803?oB;M800ol0003olPgboo8=lP06oo8=lP03o`000?oe2_Gom@[e00Oom@[e00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000WomPWf00?o0000omXUf_oJ9MX01OoJ9MX2o`0000co
_4>l00?o0000oi1_T?n@Ki001On@Ki000ol0003oSW6>ohiaSP07ohiaSP?o000000?oBkA;o`000?nA
KY403OnAKY400ol0003odRgBom8]dP0<om8]dP03o`000?ob3O;olPgb00KolPgb00?o0000ooD:mOoe
2_D01_oe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?of2OKomPWf00OomPWf
0_l00004omXUfP03o`000?oS7>?ohacS00;o00002_nl@k`00ol0003oT6n@oi1_T003oi1_T0;o0000
3On>LHh2o`0000goTFjA0ol0000=om8]dP03o`000?ob3O;olPgb00OolPgb00?o0000ooD:mOoe2_D0
1Ooe2_D00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?of2OKomPWf00SomPWf0_l0
00000ooJ9M[o0000on<Lh`04on<Lh`03o`000?nl@kco_4>l00Oo_4>l00Co0000oi1_T?n@Ki3oT6n@
0_l00002oki1_P03o`000?n>LHkoSW6>00coSW6>3Ol00003oldbc@03o`000?oB;M;odRgB00[odRgB
00?o0000oo8=l_ob3O802?ob3O801?l0003om@[eooD:mOoe2_D4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003omPWf
ooH9mP09ooH9mP03o`000?oS7>?ohacS00GohacS0_l00008oka3_003o`000?n@Ki3o000000Go_T6n
00?o0000ohiaS_n>LHh02on>LHh00ol0003oWF:MoieRW@09oieRW@03o`000?o=</gocC;=00;ocC;=
0_l00009om8]dP03o`000?ob3O;olPgb00[olPgb0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?of2OKomPWf00SomPWf00?o0000on<LhooS7><01ooS7><4o`0000?o_4>l0ol0
0007oki1_P03o`000?n>LHkoSW6>00[oSW6>00?o0000oieRWOnMHYd02OnMHYd00ol0003ocC;=oldb
c@04oldbc@;o00001ooB;M800ol0003olPgboo8=lP0:oo8=lP03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?of2OKomPWf00OomPWf00?o0000on<LhooS7><02?oS7><0
1?l0003ohQgRon8Mh_oR7N83o`0000;oeB[E00?o0000oki1__nn@Kh01_nn@Kh00ol0003oSW6>ohia
SP08ohiaSP03o`000?nMHYgoWF:M00[oWF:M00?o0000oldbcOo=</d01_o=</d00ol0003odRgBom8]
dP04om8]dP03o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003ohacSon<Lh`08on<Lh`03o`000?oR7N;o
hQgR00CohQgR00Go0000omDZeOoE:]GoeB[Eo`000008oki1_P03o`000?n>LHkoSW6>00OoSW6>00?o
0000oieRWOnMHYd02_nMHYd00ol0003ocC;=oldbc@07oldbc@;o00001?oB;M800ol0003olPgboo8=
lP08oo8=lP03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooH9m_of2OH00oof2OH0
0ol0003ohacSon<Lh`08on<Lh`03o`000?oR7N;ohQgR00CohQgR00?o0000omDZeOoE:]D00_oE:]D0
0ol0003o_T6noki1_P07oki1_P03o`000?n>LHkoSW6>00KoSW6>00?o0000oieRWOnMHYd02_nMHYd0
0ol0003ocC;=oldbc@09oldbc@05o`000?oB;M;odRgBom8]d_l000002Oob3O800ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_ohacS00?o0000on8Mh_oR7N801?oR7N800ol0003oeB[EomDZe@03
omDZe@03o`000?nn@Kko_T6n00Oo_T6n00?o0000ohiaS_n>LHh01On>LHh00ol0003oWF:MoieRW@0:
oieRW@03o`000?o=</gocC;=00WocC;=1?l00009oo8=lP03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?og2?Oom`Sg
ooL8mol000002_oS7><00ol0003ohQgRon8MhP05on8MhP03o`000?oE:]GoeB[E00?oeB[E00?o0000
oki1__nn@Kh02?nn@Kh00ol0003oSW6>ohiaSP04ohiaSP03o`000?nMHYgoWF:M00WoWF:M00?o0000
oldbcOo=</d02?o=</d2o`0000?olPgb00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L00oog2?L00ol0003ohacSon<Lh`06on<Lh`03o`000?oR7N;ohQgR
00GohQgR00?o0000omDZeOoE:]D01?oE:]D00ol0003o_T6noki1_P09oki1_P03o`000?n>LHkoSW6>
00;oSW6>00?o0000oieRWOnMHYd02_nMHYd00ol0003ocC;=oldbc@06oldbc@;o00001_ob3O88o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oS7>?ohacS00GohacS00?o0000on8Mh_oR
7N801OoR7N800ol0003oeB[EomDZe@05omDZe@03o`000?nn@Kko_T6n00Wo_T6n00Go0000ohiaS_n>
LHkoSW6>o`00000<oieRW@03o`000?o=</gocC;=00CocC;=0_l00008oo8=lP03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on<LhooS
7><00ooS7><00ol0003ohQgRon8MhP06on8MhP03o`000?oE:]GoeB[E00GoeB[E00?o0000oki1__nn
@Kh02_nn@Kh00ol0003oSW6>o`000004o`0000WoWF:M00?o0000oldbcOo=</d00_o=</d2o`0000[o
lPgb00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om`SgooL8m`07ooL8m`03o`00
0?oS7>?ohacS00;ohacS00?o0000on8Mh_oR7N801_oR7N800ol0003oeB[EomDZe@07omDZe@;o0000
2onn@Kh00ol0003ofRGJomXUfP03omXUfPOo00000_nMHYd00ol0003ocC;=oldbc@02o`0000_olPgb
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooL8moog2?L02Oog
2?L01Ol0003ohacSon<LhooS7>?o000000SohQgR00?o0000omDZeOoE:]D01ooE:]D00ol0003ojaC[
o`000002o`0000So_T6n00?o0000omXUf_oJ9MX02_oJ9MX5o`0000golPgb00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooL8m`03o`000?oS7>?o000000WohQgR00?o
0000omDZeOoE:]D01_oE:]D00ol0003ojaC[on/Dj`03on/Dj`?o00001?nn@Kh00ol0003ofRGJomXU
fP0=omXUfP03o`000?ob3O;olPgb00golPgb00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_om`Sg00?o0000on8Mh_oR7N801ooR7N800ol0003oeB[EomDZe@07
omDZe@03o`000?o[5>_ojaC[00KojaC[0ol000000onn@Kko0000omXUfP0>omXUfP03o`000?ob3O;o
lPgb00colPgb00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooL8
m`03o`000?oR7N;ohQgR00;ohQgR1_l00008omDZe@03o`000?o[5>_ojaC[00[ojaC[00?o0000omXU
f_oJ9MX03ooJ9MX00ol0003olPgboo8=lP0:oo8=lP;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooL8m`Go00001_oc3?<00ol0003oeB[EomDZe@05omDZe@03o`000?o[5>_ojaC[00[o
jaC[00?o0000omXUf_oJ9MX03ooJ9MX00ol0003olPgboo8=lP07oo8=lP?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooL8m`03o`000?oc3??ol`cc00Wol`cc00?o0000omDZeOoE
:]D00ooE:]D00ol0003ojaC[on/Dj`0;on/Dj`03o`000?oJ9M[ofRGJ00oofRGJ00?o0000oo8=l_ob
3O801Oob3O82o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?om`Sgo`000?l00000
3Ooc3?<00ol0003oeB[EomDZe@02omDZe@03o`000?o[5>_ojaC[00_ojaC[5?l00004oo8=lP;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo<<l`04o`000?oE:]GoeB[Eo`0000kojaC[
00?o0000ooD:mOoe2_D04?oe2_D00ol0003olPgbo`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_oc3?<00ol0003oeB[Eo`00000>on/Dj`03o`00
0?oe2_Gom@[e017om@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`0=oo<<l`03o`000?o[5>_ojaC[00WojaC[1Ol0
000BooD:m@;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?o[5>_ojaC[00;ojaC[1ol00004ood2o@03o`000?oe2_Go
m@[e00oom@[e00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?oc3??ol`cc00col`cc1?l0000<ood2o@03o`000?oe2_Gom@[e00com@[e0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo<<looc3?<03?oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?oe2_Gom@[e00_o
m@[e00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003ol`ccoo<<l`0:oo<<l`03o`000?om0_goo@;m00koo@;m00?o0000ooD:mOoe
2_D02Ooe2_D2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo<<looc3?<02_oc3?<00ol0003oo@;m
ood2o@0?ood2o@03o`000?oe2_Gom@[e00Kom@[e0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aood2o@?o00001_oe2_D00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooe2_D2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooD:mOl000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02_l00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`07o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`06o`00o`;oool0Iol0
0?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool01?l00?l2oooo00?o003o00?oool0
o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool000co003o0_ooo`05o`00o`;oool01?l00?l2
oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o
00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00;o003o0_ooo`05o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003
o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01_l00?l4oooo0003o`00ooooo`3oool000go
003o0_ooo`04o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l00_l00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00
ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool0
3Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
3?l00?l3oooo00?o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2ol00?l3oooo00Co003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
0008o`00o`Goool01Ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3
oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`0:o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00
o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00_o003o0_ooo`05o`00
o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So
003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool03?l00?l2oooo00Co
003o0_ooo`06o`00o`04oooo0?l00?oo003oo`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00
o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Go
003o00?oool0o`00ool00?l01?l00?l2oooo00Go003o0_ooo`04o`00o`;oool01?l00?l2oooo00Co
003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo
0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o
0_ooo`05o`00o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00?o003o0_ooo`03o`00o`;oool01ol00?l2oooo00;o003o0_ooo`06o`00o`;oool00_l0
0?l2oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03
o`00o`Goool08?l00?l4oooo00Wo003o1?ooo`08o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00
o`7ooooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(310) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.992 .008 .992 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.992 .008 .992 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.992 .008 .992 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.991 .009 .991 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.96 .04 .96 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.99 .01 .99 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.961 .039 .961 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.955 .045 .955 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.933 .067 .933 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.985 .015 .985 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.92 .08 .92 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.991 .009 .991 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.847 .153 .847 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.86 .14 .86 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.762 .238 .762 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.899 .101 .899 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.984 .016 .984 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.987 .013 .987 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.957 .043 .957 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.578 .422 .578 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.899 .101 .899 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.778 .222 .778 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.769 .231 .769 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.82 .18 .82 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.902 .098 .902 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.936 .064 .936 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.749 .251 .749 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.882 .118 .882 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.635 .365 .635 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.926 .074 .926 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.884 .116 .884 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.813 .187 .813 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.873 .127 .873 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.681 .319 .681 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.915 .085 .915 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.777 .223 .777 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.994 .006 .994 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.938 .062 .938 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.7 .3 .7 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.364 .636 .364 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.427 .573 .427 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.966 .034 .966 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.968 .032 .968 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.863 .137 .863 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.992 .008 .992 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.729 .271 .729 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.726 .274 .726 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.451 .549 .451 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.458 .542 .458 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.286 .714 .286 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.701 .299 .701 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.752 .248 .752 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.992 .008 .992 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.729 .271 .729 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.629 .371 .629 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.95 .05 .95 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.444 .556 .444 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.896 .104 .896 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.837 .163 .837 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.449 .551 .449 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.294 .706 .294 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.588 .412 .588 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.053 .947 .053 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.082 .918 .082 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.248 .752 .248 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.423 .577 .423 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.431 .569 .431 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.891 .109 .891 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.196 .804 .196 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.22 .78 .22 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.746 .254 .746 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.954 .046 .954 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.991 .009 .991 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.223 .777 .223 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.282 .718 .282 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.562 .438 .562 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.99 .01 .99 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.696 .304 .696 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.316 .684 .316 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.482 .518 .482 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.073 .927 .073 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.457 .543 .457 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.25 .75 .25 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.955 .045 .955 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.125 .875 .125 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.033 .967 .033 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.841 .159 .841 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.067 .933 .067 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.033 .967 .033 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.576 .424 .576 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.906 .094 .906 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.243 .757 .243 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.053 .947 .053 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.443 .557 .443 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.107 .893 .107 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.173 .827 .173 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.923 .077 .923 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.035 .965 .035 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.989 .011 .989 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.139 .861 .139 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.097 .903 .097 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.754 .246 .754 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.237 .763 .237 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.306 .694 .306 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.087 .913 .087 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.108 .892 .108 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.163 .837 .163 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.052 .948 .052 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.02 .98 .02 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.303 .697 .303 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.572 .428 .572 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.99 .01 .99 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.784 .216 .784 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.192 .808 .192 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.261 .739 .261 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.313 .687 .313 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.957 .043 .957 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.089 .911 .089 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.011 .989 .011 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.204 .796 .204 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.62 .38 .62 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.033 .967 .033 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.991 .009 .991 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.079 .921 .079 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.862 .138 .862 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.961 .039 .961 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.579 .421 .579 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.629 .371 .629 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.133 .867 .133 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.894 .106 .894 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.044 .956 .044 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.295 .705 .295 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.504 .496 .504 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.092 .908 .092 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.248 .752 .248 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.383 .617 .383 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.99 .01 .99 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.99 .01 .99 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.932 .068 .932 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.214 .786 .214 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.18 .82 .18 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.052 .948 .052 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.813 .187 .813 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.198 .802 .198 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.951 .049 .951 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.231 .769 .231 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.251 .749 .251 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.26 .74 .26 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.624 .376 .624 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.754 .246 .754 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.561 .439 .561 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.048 .952 .048 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.139 .861 .139 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.246 .754 .246 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.534 .466 .534 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.828 .172 .828 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.991 .009 .991 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.944 .056 .944 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.201 .799 .201 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.318 .682 .318 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.219 .781 .219 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.827 .173 .827 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.704 .296 .704 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.99 .01 .99 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.549 .451 .549 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.862 .138 .862 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.949 .051 .949 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.144 .856 .144 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.253 .747 .253 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.936 .064 .936 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.185 .815 .185 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.634 .366 .634 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.568 .432 .568 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.457 .543 .457 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.391 .609 .391 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.887 .113 .887 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.832 .168 .832 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.84 .16 .84 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.879 .121 .879 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.379 .621 .379 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.961 .039 .961 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.796 .204 .796 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.378 .622 .378 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.407 .593 .407 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.991 .009 .991 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.68 .32 .68 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.5 .5 .5 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.99 .01 .99 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.954 .046 .954 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.842 .158 .842 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.95 .05 .95 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.39 .61 .39 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.927 .073 .927 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.777 .223 .777 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.69 .31 .69 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.992 .008 .992 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.664 .336 .664 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.543 .457 .543 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.992 .008 .992 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.747 .253 .747 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.986 .014 .986 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.993 .007 .993 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.582 .418 .582 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.989 .011 .989 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.611 .389 .611 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.99 .01 .99 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.741 .259 .741 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.868 .132 .868 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.778 .222 .778 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.905 .095 .905 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.925 .075 .925 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.801 .199 .801 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.663 .337 .663 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.787 .213 .787 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.879 .121 .879 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.924 .076 .924 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.895 .105 .895 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.907 .093 .907 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.987 .013 .987 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.812 .188 .812 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.951 .049 .951 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.989 .011 .989 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.962 .038 .962 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.942 .058 .942 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.823 .177 .823 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.953 .047 .953 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.926 .074 .926 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.891 .109 .891 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.989 .011 .989 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.94 .06 .94 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.991 .009 .991 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.989 .011 .989 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.99 .01 .99 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.989 .011 .989 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.991 .009 .991 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003ol@kaoo4>lOl0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo4>lOoa3_400_oa3_400ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00?ol@ka00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo4>lOoa3_401Ooa3_400ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol@kaoo4>l@06oo4>l@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo4>lOoa3_402?oa3_400ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?od2oCo0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000col@ka00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003oo@;m003o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003okQ7^onhAkP05onhAkP03o`000?oa
3_7ol@ka00_ol@ka0ol00003onl@k`03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
oo@;m?od2o@00ood2o@00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003okQ7^onhAkP06
onhAkP03o`000?oa3_7ol@ka00[ol@ka00?o0000onl@koo_4>l01?o_4>l00ol0003oo@;mood2o@0:
ood2o@04o`000?o]4^gokA;]ondBk@;o00002_om0_d2o`000003on`Ck?l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m005oo@;m003o`000?om0_go
o@;m00Woo@;m00?o0000oo@;m?l000002oom0_d00ol0003okQ7^onhAkP06onhAkP03o`000?oa3_7o
l@ka00Wol@ka00?o0000onl@koo_4>l01_o_4>l00ol0003oo@;mood2o@08ood2o@03o`000?o]4^go
kA;]00CokA;]0_l00005ood2o@?o00001?o/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008oo@;m003o`000?om0_goo@;m00Ooo@;m0_l00003oo@;
m003o`000?om0_goo@;m00Ooo@;m00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ol@kaoo4>l@09oo4>
l@03o`000?o_4>ooka3_00Ooka3_00?o0000ood2oOom0_d01Oom0_d2o`0000WokA;]0_l000000oom
0_go0000o`000007on`Ck003o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000oo@;m?od
2o@02?od2o@00ol0003oo@;mood2o@06ood2o@03o`000?od2oCom0_d00?om0_d00?o0000ood2oOom
0_d01oom0_d00ol0003okQ7^onhAkP08onhAkP03o`000?oa3_7ol@ka00Ool@ka00?o0000onl@koo_
4>l02Oo_4>l00ol0003oo@;mood2o@03ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000on`Ck?o/
4n`01oo/4n`00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ol`cco`000005ood2o@;o00002ood2o@2o`0000Koo@;m
00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@06ood2o@03o`000?o^4NkokQ7^00SokQ7^
00?o0000oo4>lOoa3_401_oa3_400ol0003oka3_onl@k`0;onl@k`05o`000?om0_goo@;mood2oOl0
00003_o]4^d00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?oc3??ol`ccoo<<lol0
00000oom0_d00ol0003om0_doo@;m00:oo@;m004o`000?oW6>OoiaSWo`0000?oo@;m0_l00008oo@;
m003o`000?om0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003ol@kaoo4>l@05oo4>
l@03o`000?o_4>ooka3_00coka3_00?o0000ood2oOl000003oo]4^d00ol0003ok1?/on`Ck008on`C
k003o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<l`03oo<<l`03o`000?om0_go000000_o
m0_d0_l00004onLHi`03o`000?om0_go000000_om0_d00?o0000ood2oOom0_d01Oom0_d00ol0003o
kQ7^onhAkP09onhAkP03o`000?oa3_7ol@ka00Col@ka00?o0000onl@koo_4>l03_o_4>l00ol0003o
kA;]ondBk@0>ondBk@03o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo<<looc3?<0
1?oc3?<00ol0003om0_doo@;m009oo@;m003o`000?oW6>OoiaSW00GoiaSW00?o0000oo@;m?od2o@0
2_od2o@00ol0003oo@;mood2o@05ood2o@03o`000?o^4NkokQ7^00[okQ7^00?o0000oo4>lOoa3_40
0ooa3_400ol0003oka3_onl@k`0>onl@k`03o`000?o]4^gokA;]00gokA;]00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<
l`05oo<<l`03o`000?od2oCom0_d00Oom0_d0_l00008onLHi`03o`000?od2oCom0_d00_om0_d00?o
0000ood2oOom0_d01?om0_d00ol0003okQ7^onhAkP0:onhAkP04o`000?oa3_7ol@kaoo4>l@?o0000
3oo_4>l00ol0003okA;]ondBk@0>ondBk@03o`000?o/4ncok1?/00[ok1?/00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000oo@;m?od2o@01?od2o@2o`0000_oiaSW1?l0
0009oo@;m003o`000?om0_goo@;m00?oo@;m00?o0000onhAk_o^4Nh02oo^4Nh01?l0003ol@kao`00
0?l00003om</d`;o00003?o_4>l2o`00013okA;]00?o0000on`Ck?o/4n`02oo/4n`00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ol`cc
oo<<l`07oo<<l`03o`000?od2oCom0_d00?om0_d00?o0000onLHiooW6>L02ooW6>L01?l0003ob3O8
olPgb?o8=lP5o`0000Gom0_d00?o0000ood2oOom0_d00_om0_d00ol0003okQ7^onhAkP0<onhAkP03
o`000?oC;=?odbcC00GodbcC0_l00008onl@k`;o00000_o;=</00ol0003okA;]ondBk@0=ondBk@03
o`000?o/4ncok1?/00_ok1?/00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ol`ccoo<<l`09oo<<l`03o`000?od2oCom0_d00;o0000
3OoW6>L00ol0003ob3O8olPgb007olPgb0Ko00000_om0_d4o`0000gokQ7^00?o0000om</dooC;=<0
1ooC;=<2o`0000Goka3_00?o0000ol/dboo;=</00oo;=</00ol0003okA;]ondBk@0<ondBk@03o`00
0?o/4ncok1?/00cok1?/00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?oc3??ol`cc00Wol`cc00?o
0000oo@;m?l000003ooW6>L00ol0003ob3O8olPgb00<olPgb0?o00001?oT6n@3o`0000WokQ7^00?o
0000om</dooC;=<02_oC;=<2o`000003onl@kol0003o000000OobcC;00?o0000ondBkOo]4^d02oo]
4^d00ol0003ok1?/on`Ck00<on`Ck003o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?oc3??ol`cc00_ol`cc00?o0000
onLHiooW6>L03_oW6>L00ol0003ob3O8olPgb00=olPgb003o`000?oT6nCoi1_T00Koi1_T0ol00005
onhAkP03o`000?oC;=?odbcC00godbcC00?o0000ol/dboo;=</02?o;=</00ol0003okA;]ondBk@09
ondBk@03o`000?o/4ncok1?/00gok1?/00Co0000ood2oOom0_goo@;m1Ol00003oo4>l@03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo<<looc3?<02ooc3?<2o`0000ooiaSW00?o0000olPgb?o8=lP03Oo8=lP00ol0003oi1_Ton@Ki00:
on@Ki0?o000000?okQ7^o`000?oC;=<03ooC;=<00ol0003obcC;ol/db`09ol/db`03o`000?o]4^go
kA;]00SokA;]00?o0000on`Ck?o/4n`03_o/4n`3o`0000Sol@ka00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?oc3??ol`cc00Sol`cc0ol000000ooF
:MKo0000onLHi`0>onLHi`03o`000?o8=lSob3O800gob3O800?o0000on@Ki?oT6n@03OoT6n@00ol0
003odbcCom</d`0?om</d`03o`000?o;=<_obcC;00[obcC;2ol0000;on`Ck0Go00003?oa3_400ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02_om0_d01Ol0003ol0o`o`000?om0_go0000
00Sol`cc0ol00005omHYeP03o`000?oW6>OoiaSW00coiaSW00?o0000olPgb?o8=lP03Oo8=lP00ol0
003oi1_Ton@Ki00=on@Ki0;o00004?oC;=<00ol0003obcC;ol/db`0:ol/db`03o`000?o6>LKoaSW6
00OoaSW600?o0000on`Ck?o/4n`00_o/4n`7o`0000CocC;=00?o0000oo4>lOoa3_402_oa3_400ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d01?l0003ol0o`oo0?l?o`3o02o`00
00Gol`cc0ol00009omHYeP;o00002ooW6>L00ol0003ob3O8olPgb00=olPgb003o`000?oT6nCoi1_T
00goi1_T00Co0000ol4n`Oo1?/7o00003ooC;=<00ol0003obcC;ol/db`09ol/db`03o`000?o6>LKo
aSW600WoaSW61?l0000;oldbc@03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?om0_goo@;m00Soo@;m00?o0000oo0?l?o`3o001?o`3o000ol0003ol`cco`000002o`00
00coeRWF00Co0000ok9=/_l0003o00002OoW6>L00ol0003ob3O8olPgb00=olPgb003o`000?oT6nCo
i1_T00goi1_T00Go0000ol4n`Oo1?/7o`Ck1o`00000=om</d`03o`000?o;=<_obcC;00[obcC;00?o
0000olHia_o6>LH02Oo6>LH00ol0003ocC;=oldbc@0<oldbc@03o`000?oa3_7ol@ka00[ol@ka00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00Ooo@;m00?o0000oo0?l?o`3o001_o`3o00
0ol0003oeRWFomHYeP0<omHYeP03o`000?nbCK;o/Tfb00;o/Tfb0_l00007onLHi`03o`000?o8=lSo
b3O800cob3O800?o0000on@Ki?oT6n@03OoT6n@00ol0003o`Ck1ol4n`@03ol4n`@03o`000?oC;=?o
dbcC00[odbcC00?o0000ol/dboo;=</02_o;=</00ol0003oaSW6olHiaP09olHiaP03o`000?o=</go
cC;=00cocC;=00?o0000oo4>lOoa3_402ooa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2
oOom0_d01_om0_d00ol0003ol0o`oo0?l006oo0?l003o`000?oF:MKoeRWF00_oeRWF00?o0000ok9=
/_nbCK801OnbCK800ol0003oiaSWonLHi`03onLHi`03o`000?o8=lSob3O800gob3O800?o0000on@K
i?oT6n@03OoT6n@00ol0003o`Ck1ol4n`@04ol4n`@03o`000?oC;=?odbcC00WodbcC00?o0000ol/d
boo;=</02Oo;=</00ol0003oaSW6olHiaP0:olHiaP03o`000?o=</gocC;=00cocC;=00?o0000oo4>
lOoa3_402ooa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d01Oom0_d00ol0003o
l0o`oo0?l007oo0?l003o`000?oF:MKoeRWF00_oeRWF00?o0000ok9=/_nbCK801_nbCK82o`0000?o
iaSW00?o0000olPgb?o8=lP03Oo8=lP00ol0003oi1_Ton@Ki00<on@Ki003o`000?o1?/7o`Ck100Ko
`Ck100?o0000om</dooC;=<02?oC;=<00ol0003obcC;ol/db`09ol/db`03o`000?o6>LKoaSW600[o
aSW600?o0000oldbcOo=</d03?o=</d00ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?om0_goo@;m00Coo@;m00?o0000oo0?l?o`3o002?o`3o000ol0003oeRWFomHYeP0:omHYeP03o`00
0?nbCK;o/Tfb00Wo/Tfb0_l000000ooW6>Oo0000olPgb00<olPgb0?o00003_oT6n@00ol0003o`Ck1
ol4n`@07ol4n`@03o`000?oC;=?odbcC00OodbcC00?o0000ol/dboo;=</02Oo;=</00ol0003oaSW6
olHiaP0;olHiaP03o`000?o=</gocC;=00cocC;=00?o0000oo4>lOoa3_402_oa3_400ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003oeRWFomHY
eP09omHYeP03o`000?nbCK;o/Tfb00_o/Tfb00?o0000olPgb?o8=lP02_o8=lP2o`0000?oWV6N00?o
0000on@Ki?oT6n@02_oT6n@00ol0003o`Ck1ol4n`@09ol4n`@03o`000?oC;=?odbcC00KodbcC00?o
0000ol/dboo;=</02?o;=</00ol0003oaSW6olHiaP0<olHiaP03o`000?o=</gocC;=00cocC;=00?o
0000oo4>lOoa3_402_oa3_400ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003oo@;mood2o@02ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omHYe_oF:MH02?oF:MH0
0ol0003o/Tfbok9=/P0<ok9=/P03o`000?o8=lSob3O800Sob3O80_l00006oiiQWP;o00002_oT6n@0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?oC;=?odbcC00GodbcC00?o0000ol/dboo;=</02?o;=</0
0ol0003oaSW6olHiaP0<olHiaP03o`000?o=</gocC;=00cocC;=00?o0000oo4>lOoa3_402ooa3_40
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ood2oOom0_goo@;mo`00000=
oo0?l003o`000?oF:MKoeRWF00OoeRWF00?o0000ok9=/_nbCK803_nbCK800ol0003ob3O8olPgb004
olPgb0?o00002_nNHIh00ol0003oi1_Ton@Ki007on@Ki003o`000?o1?/7o`Ck100_o`Ck100?o0000
om</dooC;=<00ooC;=<00ol0003obcC;ol/db`09ol/db`03o`000?o6>LKoaSW600coaSW600?o0000
oldbcOo=</d03?o=</d00ol0003ol@kaoo4>l@0;oo4>l@;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003ol0o`oo0?l00<oo0?l003o`000?oF:MKoeRWF00OoeRWF00?o0000ok9=/_nbCK803onbCK801?l0
003ob3O8olPgb?o8=lP2o`0000koWV6N0_l00006on@Ki003o`000?o1?/7o`Ck100go`Ck100?o0000
om</dooC;=<00_oC;=<00ol0003obcC;ol/db`08ol/db`03o`000?o6>LKoaSW600coaSW60ol0000=
oldbc@03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ool0o`00?o0000omHYe_oF:MH01_oF:MH00ol0003o/Tfbok9=/P0@ok9=/PCo00004_nNHIh00ol0
003oi1_Ton@Ki003on@Ki003o`000?o1?/7o`Ck100ko`Ck100Go0000om</dooC;=?odbcCo`000005
ol/db`Oo00003?o6>LH01Ol0003oW6>LoiaSW?nLHico000000cocC;=00?o0000oo4>lOoa3_402?oa
3_43o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ool0o`00?o0000omHYe_oF:MH01_oF:MH00ol0003o/Tfbok9=/P0=
ok9=/P?o000000CoM8]do`000?l0003o00004onNHIh2o`0000;oi1_T00?o0000ol4n`Oo1?/404?o1
?/400ol0003odbcCo`000006o`0000Oo[U6^00?o0000olHia_o6>LH02?o6>LH00ol0003oW6>LoiaS
W003oiaSW0;o00002?o=</d3o`0000Kol@ka1?l00002ondBk@03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003om0_do`000?o@;m03o`0000gol0o`00?o0000omHYe_oF:MH01?oF:MH00ol0003o/Tfbok9=
/P0;ok9=/P?o00000omdRg@01Ol0003oLHiao`000?m>/Dko000001CoWV6N00?o0000on@Ki?l00000
4oo1?/400ol0003o[U6^ojiA[P0=ojiA[P03o`000?o6>LKoaSW600GoaSW60_l00008oiaSW003o`00
0?o=</gocC;=00Go00000oo9=/T00ol0003ol@kaoo4>l@03o`0000OokA;]00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?od2oCom0_do`0000Cod2o@0ol0000:oo0?l003o`000?oF:MKoeRWF00?oeRWF
00?o0000ok9=/_nbCK802OnbCK83o`0000GoM8]d00Co0000og6>LOmaSW7o00000_m>/Dh00ol0003o
WV6NoiiQWP0BoiiQWP03o`000?o1?/7o`Ck101;o`Ck100?o0000ojiA[_n^DJh03_n^DJh00ol0003o
aSW6olHiaP03olHiaP03o`000?nLHicoW6>L00WoW6>L0_l00009olTfb@;o00002_o]4^d00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000oo@;m?od2oCom0_do`000007om0_d0;o00001oo`3o05o`0000;o
eRWF00?o0000ok9=/_nbCK801_nbCK83o`0000SoM8]d00Co0000og6>LOmaSW7o00000om>/Dh00ol0
003oWV6NoiiQWP0AoiiQWP03o`000?o1?/7o`Ck1017o`Ck100?o0000ojiA[_n^DJh04?n^DJh01Ol0
003oaSW6olHia_o6>LKo000000coW6>L00?o0000olTfbOo9=/T02?o9=/T00ol0003okA;]ondBk@0:
ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Com0_d00?o0000om0_d?o@;m001oo@;m03o`00
0004oo0?l?l0003o0000o`0000Go^TFj0_l00006ok9=/P?o00002_mdRg@01Ol0003oLHiaog6>LOma
SW7o000000CoC[5>00?o0000oiiQW_nNHIh04?nNHIh00ol0003o`Ck1ol4n`@0Aol4n`@03o`000?n^
DJko[U6^017o[U6^00?o0000olHia_l000003OnLHi`00ol0003obCK9olTfb@08olTfb@03o`000?o]
4^gokA;]00[okA;]00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Com0_d00?o0000
om0_d?o@;m002_o@;m000ol0003o^TFjokY5^P08okY5^P03o`000?nbCK;o/Tfb00?o00003OmdRg@0
1Ol0003oLHiaog6>LOmaSW7o000000GoC[5>00?o0000oiiQW_nNHIh03onNHIh00ol0003o`Ck1ol4n
`@0Aol4n`@03o`000?n^DJko[U6^01;o[U6^00?o0000oiaSW?nLHi`03?nLHi`00ol0003obCK9olTf
b@08olTfb@03o`000?o]4^gokA;]00_okA;]00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000oo@;m?od2o@01Ood2o@0
0ol0003od2o@om0_d00:om0_d003o`000?njAK[o^TFj00Wo^TFj0_l0000?ogB;M003o`000?maSW7o
LHia00;oLHia00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oWV6NoiiQWP0=oiiQWP?o00004Oo1?/40
0ol0003o[U6^ojiA[P0CojiA[P03o`000?nLHicoW6>L00_oW6>L00?o0000olTfbOo9=/T02Oo9=/T0
0ol0003okA;]ondBk@0;ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?od2o@0
0ol0003od2o@om0_d00:om0_d003o`000?njAK[o^TFj00Wo^TFj00?o0000ogB;M?mdRg@03OmdRg@0
0ol0003oLHiaog6>L@03og6>L@03o`000?m>/DkoC[5>00GoC[5>00?o0000oiiQW_nNHIh02_nNHIh2
o`0000?oPGj100?o0000ol4n`Oo1?/403_o1?/400ol0003o[U6^ojiA[P0CojiA[P03o`000?nLHico
W6>L00_oW6>L00?o0000olTfbOo9=/T02Oo9=/T00ol0003okA;]ondBk@0;ondBk@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000oo@;m?od2o@01ood2o@2o`0000_od2o@00?o0000okY5
^_njAKX02onjAKX00ol0003oM8]dogB;M00<ogB;M003o`000?maSW7oLHia00?oLHia00?o0000odja
C_m>/Dh01_m>/Dh00ol0003oWV6NoiiQWP07oiiQWP;o00001_n1OX42o`0000ko`Ck100?o0000ojiA
[_n^DJh04on^DJh00ol0003oW6>LoiaSW00;oiaSW003o`000?o9=/WobCK900WobCK900?o0000ondB
kOo]4^d03?o]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009oo@;
m003o`000?oV6NKo000000_od2o@00?o0000okY5^_njAKX02onjAKX00ol0003oM8]dogB;M00;ogB;
M003o`000?maSW7oLHia00CoLHia00?o0000odjaC_m>/Dh01om>/Dh00ol0003oWV6NoiiQWP05oiiQ
WP03o`000?n1OX7oPGj100SoPGj100?o0000ol4n`Oo1?/402_o1?/400ol0003o[U6^ojiA[P0DojiA
[P03o`000?nLHicoW6>L00_oW6>L00?o0000olTfbOo9=/T02Oo9=/T00ol0003okA;]ondBk@0<ondB
k@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009oo@;m004o`000?oV6NKoiQWVo`00
00_od2o@00?o0000okY5^_njAKX02onjAKX00ol0003oM8]dogB;M00;ogB;M003o`000?maSW7oLHia
00CoLHia00?o0000odjaC_m>/Dh02?m>/Dh00ol0003oWV6NoiiQWP02oiiQWP;o00003?n1OX42o`00
00[o`Ck100?o0000ojiA[_n^DJh05?n^DJh00ol0003oW6>LoiaSW00;oiaSW003o`000?o9=/WobCK9
00WobCK900?o0000ondBkOo]4^d03Oo]4^d00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m007oo@;m003
o`000?oV6NKoiQWV00;oiQWV00?o0000om0_d?o@;m002?o@;m000ol0003o^TFjokY5^P0<okY5^P03
o`000?mdRgCoM8]d00WoM8]d00?o0000og6>LOmaSW401OmaSW400ol0003oC[5>odjaCP09odjaCP04
o`000?nNHIko0000o`00013oPGj10_l00008ol4n`@03o`000?n^DJko[U6^01Co[U6^0ol0000;oiaS
W003o`000?o9=/WobCK900WobCK900?o0000ondBkOo]4^d03Oo]4^d01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003om0_doo@;m006oo@;m003o`000?oV6NKoiQWV00?oiQWV00?o0000om0_
d?o@;m002?o@;m000ol0003o^TFjokY5^P0;okY5^P;o00002_mdRg@00ol0003oLHiaog6>L@06og6>
L@03o`000?m>/DkoC[5>00[oC[5>00?o0000oh5nPOn1OX404_n1OX400ol0003o`Ck1ol4n`@04ol4n
`@03o`000?n^DJko[U6^01Go[U6^00?o0000oiA[U?nDJi@01Ol00005oiaSW003o`000?o9=/WobCK9
00[obCK900?o0000ondBkOo]4^d03_o]4^d3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m004oo@;m003
o`000?oV6NKoiQWV00CoiQWV00?o0000om0_d?o@;m001oo@;m000ol0003o^TFjokY5^P0;okY5^P04
o`000?mbSG;oLXebo`0000WoM8]d00?o0000og6>LOmaSW401_maSW400ol0003oC[5>odjaCP0:odja
CP03o`000?n1OX7oPGj101?oPGj10_l00003ol4n`@Co00005?n^DJh00ol0003oU6^DoiA[U006oiA[
U0Co000000?oW6>Lo`000?o9=/T02oo9=/T00ol0003okA;]ondBk@0>ondBk@03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003om0_doo@;m003oo@;m003o`000?oV6NKoiQWV00GoiQWV00?o0000om0_d?o@
;m001oo@;m000ol0003o^TFjokY5^P09okY5^P;o00001?mbSG800ol0003oM8]dogB;M005ogB;M003
o`000?maSW7oLHia00OoLHia00?o0000odjaC_m>/Dh02_m>/Dh00ol0003oPGj1oh5nP@0Eoh5nP@03
o`000?o1?/7o000000CoTFjA0ol0000@ojiA[P03o`000?nDJiCoU6^D00_oU6^D0_l0000<olTfb@03
o`000?o]4^gokA;]00cokA;]0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@00_od2o@00ol0003oiQWV
onHIiP06onHIiP03o`000?o@;m3od2o@00Ood2o@00?o0000okY5^_njAKX02?njAKX00ol0003oLXeb
og:=LP05og:=LP03o`000?mdRgCoM8]d00CoM8]d00?o0000og6>LOmaSW401omaSW400ol0003oC[5>
odjaCP0:odjaCP03o`000?n1OX7oPGj101KoPGj100?o0000oi5^TOnAKY401_nAKY43o`0000co[U6^
00?o0000oiA[U?nDJi@03OnDJi@00ol0003obCK9olTfb@09olTfb@Go00002Oo]4^d2o`000003oo0?
l?l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003oo@;m?l0003oiQWV00WoiQWV00?o0000om0_d?o@;m001_o@
;m000ol0003o^TFjokY5^P07okY5^P03o`000?mbSG;oLXeb00OoLXeb00?o0000ogB;M?mdRg@00_md
Rg@00ol0003oLHiaog6>L@08og6>L@03o`000?m>/DkoC[5>00WoC[5>00?o0000oh5nPOn1OX405on1
OX400ol0003oTFjAoi5^T@09oi5^T@?o00002On^DJh00ol0003oU6^DoiA[U00>oiA[U0Ko00001?o9
=/T00ol0003odRgBom8]dP03om8]dPGo00000_o]4^d2o`0000Col0o`00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o[5>_ojaC[on/Djol000002ooV6NH00ol0003od2o@om0_d006om0_d003o`000?nj
AK[o^TFj00Go^TFj0_l0000;og:=LP04o`000?mdRgCoM8]do`0000_oLHia00?o0000odjaC_m>/Dh0
2Om>/Dh00ol0003oPGj1oh5nP@0Foh5nP@03o`000?nAKY7oTFjA00goTFjA0ol00005ojiA[P03o`00
0?nDJiCoU6^D00ooU6^D00?o0000ojUFZOnYEZT00onYEZT4o`0000_odRgB0_l00006oo0?l003o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ojaC[on/Dj`02on/Dj`ko00001_o@;m000ol0003o^TFjokY5
^P05okY5^P03o`000?mbSG;oLXeb00coLXeb00?o0000ogB;M?l000002omaSW400ol0003oC[5>odja
CP07odjaCP?o00006?n1OX400ol0003oTFjAoi5^T@0@oi5^T@?o000000?o[U6^o`000?nDJi@04?nD
Ji@00ol0003oZEJYojUFZ@07ojUFZ@03o`000?oB;M;odRgB00[odRgB00?o0000oo0?l?o`3o001Oo`
3o000ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005on/Dj`03o`000?o7><OoacS700_oacS70_l00004
om0_d003o`000?njAK[o^TFj00?o^TFj0_l0000@og:=LP03o`000?maSW7oLHia00[oLHia00?o0000
odjaC_m>/Dh00om>/Dh4o`0000;o<Lha00?o0000oh5nPOn1OX405On1OX400ol0003oTFjAoi5^T@0D
oi5^T@03o`000?nDJiCoU6^D013oU6^D00?o0000ojUFZOnYEZT01onYEZT00ol0003odRgBom8]dP0:
om8]dP03o`000?o`3o3ol0o`00Gol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o[5>_ojaC[
00GojaC[00?o0000olLhaoo7><L03Oo7><L6o`0000?o^TFj00?o0000og:=L_mbSG804?mbSG800ol0
003oLHiaog6>L@0:og6>L@03o`000?m>/Dko000000?o00001olacS400ol0003oPGj1oh5nP@0Doh5n
P@03o`000?nAKY7oTFjA01CoTFjA00?o0000oiA[U?nDJi@03onDJi@00ol0003oZEJYojUFZ@08ojUF
Z@03o`000?oB;M;odRgB00[odRgB00?o0000oo0?l?o`3o001Oo`3o000ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000on/Djoo[5>/01_o[5>/00ol0003oacS7olLha`0=olLha`03o`000?n^DJko[U6^00?o
[U6^00?o0000okY5^_l000004ombSG84o`0000WoLHia0_l0000<oc7><@03o`000?n1OX7oPGj101?o
PGj100?o0000oi5^TOnAKY405OnAKY400ol0003oU6^DoiA[U00>oiA[U003o`000?nYEZWoZEJY00So
ZEJY00?o0000om8]d_oB;M802OoB;M800ol0003ol0o`oo0?l007oo0?l003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o[5>_ojaC[00SojaC[00?o0000olLhaoo7><L02oo7><L00ol0003o[U6^ojiA[P05ojiA[P03o`00
0?mbSG;oLXeb01;oLXeb00Co0000ock1?_ln`Cko?/4n1Ol00003og6>L@03o`000?lacS7o<Lha00go
<Lha0ol0000@oh5nP@;o00006?nAKY400ol0003oU6^DoiA[U00=oiA[U003o`000?nYEZWoZEJY00Wo
ZEJY00?o0000om8]d_oB;M802OoB;M800ol0003ol0o`oo0?l007oo0?l003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ood2oOom0_d0
0_om0_d6o`0000_ojaC[00?o0000olLhaoo7><L02_o7><L00ol0003o[U6^ojiA[P06ojiA[P03o`00
0?mbSG;oLXeb017oLXeb00?o0000ock1?_ln`Ch01oln`Ch3o`00013o<Lha00?o0000ob;M8_lRgB80
1Ol00009oh5nP@;o000000?o>l@ko`000?nAKY405onAKY400ol0003oU6^DoiA[U00=oiA[U003o`00
0?nYEZWoZEJY00WoZEJY00?o0000om8]d_oB;M802?oB;M82o`0000[ol0o`00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo@;mood2
o@03ood2o@03o`000?of2OKomPWf00;omPWf00?o0000on/Djoo[5>/02Oo[5>/00ol0003oacS7olLh
a`0:olLha`03o`000?n^DJko[U6^00Oo[U6^00?o0000og:=L_mbSG803ombSG800ol0003o?/4nock1
?P0:ock1?P03o`000?lacS7o<Lha00go<Lha00?o0000ob;M8_lRgB801_lRgB84o`0000CoPGj100?o
0000oc_4>olka3/00_lka3/00ol0003oTFjAoi5^T@0Foi5^T@03o`000?nDJiCoU6^D00_oU6^D00?o
0000ojUFZOnYEZT02onYEZT00ol0003odRgBom8]dP06om8]dP03o`000?oT6nCo000000[ol0o`00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo@;mood2o@04ood2o@03o`000?of2OKomPWf00?omPWf00?o0000on/Djoo[5>/02?o[5>/=
o`0000[o[U6^00?o0000og:=L_mbSG803ombSG800ol0003o?/4nock1?P0;ock1?P03o`000?lacS7o
<Lha00co<Lha00?o0000ob;M8_lRgB802_lRgB84o`0000Go>l@k00?o0000oi5^TOnAKY405_nAKY40
0ol0003oU6^DoiA[U00:oiA[U003o`000?nYEZWoZEJY00coZEJY00?o0000om8]d_oB;M801?oB;M82
o`0000?oi1_T00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m00?o0000ooH9
m_of2OH00oof2OH00ol0003ojaC[on/Dj`07on/Dj`03o`000?o4>lCoa3_400Woa3_400?o0000ojiA
[_n^DJh02On^DJh00ol0003oLXebog:=LP0=og:=LP03o`000?ln`Cko?/4n00co?/4n00?o0000oc7>
<OlacS403?lacS400ol0003o8]dRob;M8P0;ob;M8P03o`000?l=lPgo000000Ko>l@k00?o0000oi5^
TOnAKY405_nAKY400ol0003oU6^DoiA[U009oiA[U003o`000?nYEZWoZEJY00coZEJY00?o0000om8]
d_oB;M800ooB;M800ol0003oi1_Ton@Ki003on@Ki003o`000?o`3o3ol0o`00Sol0o`00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o@;mood2o@06ood2o@03o`000?of2OKomPWf00ComPWf00?o0000on/Djoo[5>/01_o[5>/00ol0003o
a3_4ol@ka008ol@ka003o`000?n^DJko[U6^00_o[U6^00?o0000og:=L_mbSG802?mbSG84o`0000oo
?/4n00?o0000oc7><OlacS402olacS400ol0003o8]dRob;M8P0;ob;M8P04o`000?l=lPgo3O8=o`00
00Oo>l@k00?o0000oi5^TOnAKY405OnAKY400ol0003oU6^DoiA[U008oiA[U003o`000?nYEZWoZEJY
00goZEJY00?o0000om8]d_oB;M800_oB;M800ol0003oi1_Ton@Ki005on@Ki003o`000?o`3o3ol0o`
00Ool0o`00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00GomPWf00?o0000on/Djoo[
5>/01Oo[5>/00ol0003oa3_4ol@ka008ol@ka003o`000?n^DJko[U6^00_o[U6^00?o0000og:=L_mb
SG800ombSG85o`0000?o?l0o00?o0000ock1?_ln`Ch03_ln`Ch00ol0003o<Lhaoc7><@0:oc7><@03
o`000?lRgB;o8]dR00[o8]dR00Go0000o`gb3Ol=lPgo3O8=o`000007oc_4>`03o`000?nAKY7oTFjA
01GoTFjA00?o0000oiA[U?nDJi@02?nDJi@00ol0003oZEJYojUFZ@0=ojUFZ@03o`000?oB;M;odRgB
00;o00002?oT6n@00ol0003ol0o`oo0?l008oo0?l0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ood2oOom0_d01oom0_d00ol0003omPWfooH9mP05ooH9mP03o`000?o[5>_ojaC[00Go
jaC[00?o0000ol@ka?o4>l@02?o4>l@00ol0003o[U6^ojiA[P0<ojiA[PGo00002Olo`3l00ol0003o
?/4nock1?P0<ock1?P;o00003?lacS400ol0003o8]dRob;M8P0:ob;M8P05o`000?l=lPgo3O8=o`gb
3Ol000002?lka3/00ol0003oTFjAoi5^T@0Doi5^T@?o00001onDJi@00ol0003oZEJYojUFZ@0>ojUF
Z@03o`000?oB;M;o000000_oi1_T00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00So
o@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003ojaC[on/Dj`04on/Dj`03o`000?o4>lCoa3_400Oo
a3_400?o0000ojiA[_n^DJh03?n^DJh01?l0003oLhacog><Lol0000;oco0?`03o`000?ln`Cko?/4n
00_o?/4n00Co0000o`Sg2?l8m`So00002_lacS400ol0003o8]dRob;M8P0:ob;M8P03o`000?l=lPgo
3O8=00;o3O8=00?o0000oc_4>olka3/01_lka3/00ol0003oTFjAoi5^T@0Aoi5^T@?o00000omPWf00
0ol0003oU6^DoiA[U004oiA[U003o`000?nYEZWoZEJY00goZEJY1?l0000;on@Ki003o`000?o`3o3o
l0o`00Gol0o`00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo@;mood2o@08ood2o@03o`000?of2OKomPWf00KomPWf00Co0000on/D
joo[5>_ojaC[1?l00008ol@ka003o`000?n^DJko[U6^00_o[U6^00?o0000og><LomcS7<00_mcS7<0
0ol0003o?l0ooco0?`08oco0?`03o`000?ln`Cko?/4n00[o?/4n00?o0000o`Sg2?l8m`P00_l8m`P0
0ol0003o<Lhaoc7><@03oc7><@Go00002olRgB800ol0003o3O8=o`gb3@03o`gb3@03o`000?lka3_o
>l@k00Oo>l@k00?o0000oi5^TOnAKY403_nAKY42o`0000OoH9mP00?o0000oiA[U?nDJi@00_nDJi@0
0ol0003oZEJYojUFZ@0=ojUFZ@03o`000?o?<<oocc3?00;occ3?00?o0000on@Ki?oT6n@02OoT6n@0
0ol0003ol0o`oo0?l003oo0?l003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ood2oOom0_d02Oom0_d00ol0003omPWfooH9mP07ooH9
mP?o00001?oH9mP00ol0003oa3_4ol@ka005ol@ka003o`000?n^DJko[U6^00[o[U6^00?o0000og><
LomcS7<00omcS7<00ol0003o?l0ooco0?`09oco0?`03o`000?ln`Cko?/4n00So?/4n00?o0000o`Sg
2?l8m`P01?l8m`P5o`0000Co0?l000?o0000ob;M8_lRgB802OlRgB800ol0003o3O8=o`gb3@03o`gb
3@03o`000?lka3_o>l@k00So>l@k00?o0000oi5^TOnAKY402_nAKY43o`0000[oH9mP00Go0000oiA[
U?nDJiCoU6^Do`00000>ojUFZ@03o`000?o?<<oocc3?00Cocc3?0_l00009on@Ki003o`000?o`3o3o
l0o`00;ol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo@;mood2o@09ood2o@03o`000?of2OKomPWf00OomPWf00?o0000omPW
f?oH9mP01OoH9mP00ol0003oa3_4ol@ka003ol@ka003o`000?n^DJko[U6^00[o[U6^00?o0000og><
LomcS7<01?mcS7<00ol0003o?l0ooco0?`09oco0?`03o`000?ln`Cko?/4n00Oo?/4n00?o0000o`Sg
2?l8m`P01Ol8m`P00ol0003o0?l0o`3o0007o`3o0003o`000?lRgB;o8]dR00Oo8]dR00?o0000o`gb
3Ol=lPd01?l=lPd00ol0003o>l@koc_4>`08oc_4>`03o`000?nAKY7oTFjA00SoTFjA0_l0000>of2O
H0Co00003?nYEZT2o`0000Wocc3?00?o0000on@Ki?oT6n@01ooT6n@01?l0003ol0o`oo0?l?l0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?om0_goo@;m
00[oo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003of2OHomPWf007omPWf0;o00000oo4>l@00ol0
003o[U6^ojiA[P09ojiA[P03o`000?mcS7?oLhac00KoLhac00?o0000oco0?olo`3l02Olo`3l00ol0
003o?/4nock1?P05ock1?P03o`000?l8m`So2?L800Ko2?L800?o0000o`3o0?l0o`002?l0o`000ol0
003o8]dRob;M8P06ob;M8P03o`000?l=lPgo3O8=00Co3O8=00?o0000oc_4>olka3/02Olka3/4o`00
00?oTFjA0ol0000@of2OH005o`000?no@;oo_d2ookm0_ol000002_nYEZT00ol0003occ3?oll`c`0:
oll`c`Ko00000ooT6n@00ol0003ol0o`o`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH01?of2OH00ol0
003of2OHomPWf00:omPWf004o`000?o4>lCoa3_4o`0000[o[U6^00?o0000og><LomcS7<01omcS7<0
0ol0003o?l0ooco0?`09oco0?`03o`000?ln`Cko?/4n00Co?/4n00?o0000o`Sg2?l8m`P01ol8m`P0
0ol0003o0?l0o`3o0008o`3o00;o00001_lRgB800ol0003o3O8=o`gb3@05o`gb3@03o`000?lka3_o
>l@k00Wo>l@k00Co0000obo@;ol_d2oo;m0_0ol0000Bof2OH003o`000?no@;oo_d2o00?o_d2o0_l0
0006ojUFZ@;o00003Oo?<<l00ol0003ol`ccoo<<l`03oo<<l`Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo@;m00?o0000ooH9m_of2OH00oof2OH0
0ol0003of2OHomPWf00<omPWf0;o00002_n^DJh00ol0003oLhacog><L`08og><L`03o`000?lo`3oo
?l0o00[o?l0o00?o0000ock1?_ln`Ch00_ln`Ch00ol0003o2?L8o`Sg2008o`Sg2003o`000?l0o`3o
0?l000Ko0?l00_l00002o`;m0P03o`000?lRgB;o8]dR00;o8]dR00?o0000o`gb3Ol=lPd01_l=lPd0
0ol0003o>l@koc_4>`08oc_4>`03o`000?l_d2oo;m0_00Co;m0_00?o0000of2OH?mPWf003omPWf00
0ol0003o_d2ookm0_`06okm0_`;o00000onYEZT00ol0003occ3?oll`c`0=oll`c`03o`000?oc3??o
l`cc00Ool`cc0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oom0_d00ol0003omPWfooH9mP02ooH9mP03o`000?oH9mSof2OH
00kof2OH00?o0000ojiA[_n^DJh01on^DJh00ol0003oLhacog><L`0:og><L`03o`000?lo`3oo?l0o
00Wo?l0o00Go0000ock1?_ln`Cko?/4no`00000;o`Sg2003o`000?l0o`3o0?l000Co0?l00_l00005
o`;m0P05o`000?lRgB;o8]dRob;M8_l000002?l=lPd00ol0003o>l@koc_4>`08oc_4>`03o`000?l_
d2oo;m0_00Go;m0_00?o0000of2OH?mPWf003_mPWf000ol0003o_d2ookm0_`08okm0_`03o`000?nY
EZWo000000oocc3?00?o0000oo<<looc3?<02?oc3?<01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ood2o@04o`000?of2OKomPWfo`00017of2OH00?o0000ojiA[_n^DJh01_n^DJh00ol0003oLhac
og><L`0;og><L`03o`000?lo`3oo?l0o00Wo?l0o00Co0000ock1?_ln`Cko00003?l8m`P00ol0003o
0?l0o`3o0002o`3o00;o00002?l2o@800ol0003o8]dRo`000009o`gb3@03o`000?lka3_o>l@k00So
>l@k00?o0000obo@;ol_d2l01Ol_d2l00ol0003oH9mPof2OH00=of2OH003o`000?no@;oo_d2o00[o
_d2o00?o0000oll`coo?<<l03_o?<<l00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?oo@;mo`000?l000000ol0000BomPWf003o`00
0?n^DJko[U6^00Co[U6^00?o0000og><LomcS7<03?mcS7<00ol0003o?l0ooco0?`0:oco0?`?o0000
3?l8m`P00ol0003o0?l0o`3o0002o`0000_o0_d200?o0000o`gb3Ol=lPd02?l=lPd00ol0003o>l@k
oc_4>`07oc_4>`03o`000?l_d2oo;m0_00Oo;m0_00?o0000of2OH?mPWf003?mPWf000ol0003o_d2o
okm0_`0;okm0_`;o00003_o?<<l00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003of2OHomPWf00?omPWf0?o00000on^
DJh00ol0003oLhacog><L`0>og><L`03o`000?lo`3oo?l0o00So?l0o00Co0000oa7^4OlAkQ7o4NhA
0_l0000:o`Sg20?o00003Ol2o@800ol0003o3O8=o`gb3@08o`gb3@03o`000?lka3_o>l@k00Oo>l@k
00?o0000obo@;ol_d2l01ol_d2l00ol0003oH9mPof2OH00;of2OH003o`000?no@;oo_d2o00co_d2o
00?o0000onPGj?l000000_l0000:oll`c`03o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m004oo@;m003o`000?oH9mSof2OH00cof2OH0_l0
0003ol<l``03o`000?n^DJko0000017oLhac00?o0000oco0?olo`3l01olo`3l00ol0003o4NhAoa7^
4@04oa7^4@;o00002?l8m`P00ol0003o0_d2o`;m0P0>o`;m0P;o00002?l=lPd00ol0003o>l@koc_4
>`06oc_4>`03o`000?l_d2oo;m0_00Wo;m0_00?o0000of2OH?mPWf002OmPWf000ol0003o_d2ookm0
_`0=okm0_`03o`000?oX5nSoj1OX00;oj1OX0ol00007oll`c`03o`000?oc3??ol`cc00Ool`cc00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m005oo@;m003o`000?oH9mSo
f2OH00Wof2OH0_l00006ol<l``03o`000?mcS7?oLhac013oLhac00?o0000oco0?olo`3l01_lo`3l0
0ol0003o4NhAoa7^4@07oa7^4@03o`000?l8m`So2?L800Co2?L80ol0000>o`;m0P03o`000?l0o`3o
0?l000?o00001Ol=lPd00ol0003o>l@koc_4>`06oc_4>`03o`000?l_d2oo;m0_00[o;m0_00?o0000
of2OH?mPWf002?mPWf000ol0003o_d2ookm0_`0=okm0_`03o`000?oX5nSoj1OX00Goj1OX0ol00004
oll`c`03o`000?oc3??ol`cc00Ool`cc00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003om0_doo@;m006oo@;m003o`000?oH9mSof2OH00Gof2OH0ol00008ol<l``03o`000?mcS7?oLhac
017oLhac00Co0000oco0?olo`3oo?l0o1?l0000;oa7^4@;o000000Co2?L8o`000?l0003o00000olF
jAH2o`0000_o0_d200?o0000o`3o0?l0o`001?l0o`02o`0000?o3O8=00?o0000oc_4>olka3/01_lk
a3/00ol0003o;m0_obo@;`0:obo@;`03o`000?mPWf3oH9mP00OoH9mP00?o0000okm0_ono@;l03_no
@;l00ol0003oj1OXonPGj008onPGj0Co00002_oc3?<00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om0_doo@;m007oo@;m003o`000?oH9mSof2OH00;of2OH0_l0000<ol<l``03o`000?mcS7?o
Lhac013oLhac1?l00003oc;=<P03o`000?lAkQ7o4NhA00_o4NhA00?o0000oaKY5_lFjAH01_lFjAH0
0ol0003o0_d2o`;m0P07o`;m0P03o`000?l0o`3o0?l000Oo0?l03?l0000>obo@;`03o`000?mPWf3o
H9mP00KoH9mP00?o0000okm0_ono@;l03_no@;l00ol0003oj1OXonPGj00;onPGj003o`000?oc3??o
l`cc00Ool`cc00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00Wom0_d00Co0000omPW
f?l0003o00003_o3?<<00ol0003oLhacog><L`0?og><L`03o`000?lbcC;o</db00Ko</db00?o0000
oa7^4OlAkQ402_lAkQ400ol0003o5^TFoaKY5P07oaKY5P;o00001_l2o@800ol0003o0?l0o`3o0008
o`3o0003o`000?m0_d3o@;m000So@;m000?o0000obo@;ol_d2l03?l_d2l00ol0003oH9mPof2OH005
of2OH003o`000?no@;oo_d2o00oo_d2o0_l0000=onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00[om0_d00?o0000ol<l`oo3?<<03_o3?<<00ol0
003oLhacog><L`0>og><L`03o`000?lbcC;o</db00Oo</db00?o0000oa7^4OlAkQ402_lAkQ400ol0
003o5^TFoaKY5P09oaKY5P;o00000ol2o@800ol0003o0?l0o`3o0009o`3o0003o`000?m0_d3o@;m0
00Wo@;m000?o0000obo@;ol_d2l02_l_d2l4o`0000CoH9mP00?o0000okm0_ono@;l04?no@;l01?l0
003oiA[Uo`000?l0000<onPGj003o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?od2oCom0_d00[om0_d00?o0000ol<l`oo3?<<03oo3?<<@o`0000[o</db00?o0000oa7^
4OlAkQ402OlAkQ400ol0003o0?l0o`00000<oaKY5P05o`000?l2o@;o0000o`3o0?l000002_l0o`00
0ol0003o@;m0od2o@009od2o@003o`000?l_d2oo;m0_00Oo;m0_0ol00004ofBKI0?o000000?oH9mP
o`000?no@;l04Ono@;l01?l0003oiA[UonDJiOoU6^D2o`0000_oj1OX00?o0000oo<<looc3?<00ooc
3?<00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@02_od2o@00ol0003o`cc3ol<l``0?
ol<l``03o`000?meRWGoMHYe00coMHYe00?o0000oc;=<_lbcC802OlbcC800ol0003o4NhAoa7^4@07
oa7^4@04o`000?l0o`3o0?l0o`0000go5^TF00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?m0_d3o@;m000[o@;m000?o0000obo@;ol_d2l00ol_d2l3o`0000[oI9]T00?o0000okm0_ono@;l0
4?no@;l00ol0003oiA[UonDJi@04onDJi@;o00002_oX5nP00ol0003ol`ccoo<<l`04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000com0_d00?o0000ol<l`oo3?<<03oo3?<<00ol0003oMHYeogF:M@0<ogF:M@03o`000?lb
cC;o</db00Wo</db00?o0000oa7^4OlAkQ401_lAkQ400ol0003o0?l0o`3o0002o`3o0003o`000?lF
jAKo5^TF00[o5^TF00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?m0
_d3o@;m000[o@;m000?o0000obo@;ol_d2l00ol0000=ofBKI003o`000?no@;oo_d2o013o_d2o00?o
0000onDJiOoU6^D01_oU6^D2o`0000Woj1OX0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;oo@;m00?o0000oo@;m?od2o@02_od2o@00ol0003o`cc3ol<l``0=ol<l``?o00003omeRWD0
0ol0003o</dboc;=<P08oc;=<P03o`000?lAkQ7o4NhA00Go4NhA00?o0000o`3o0?l0o`000ol0o`00
0ol0003o5^TFoaKY5P0:oaKY5P03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o@;m0od2o@00;od2o@0;o00004OmTVf@00ol0003o_d2ookm0_`0?okm0_`03o`000?oU6^Go
iA[U00SoiA[U0_l00007onPGj003o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00Ooo@;m00?o0000oo@;m?od2o@02?od2o@00ol0003o`cc3ol<l``09ol<l``Go00000_nCK9<00ol0
003oMHYeogF:M@0=ogF:M@03o`000?lbcC;o</db00Wo</db00?o0000oa7^4OlAkQ401?lAkQ400ol0
003o0?l0o`3o0004o`3o0003o`000?lFjAKo5^TF00So5^TF00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?m0_d3o@;m000_o@;m000?o0000ofBKI?mTVf@04?mTVf@00ol0
003o_d2ookm0_`0?okm0_`03o`000?oU6^GoiA[U00[oiA[U0_l00004onPGj003o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?om0_d00ol0003om0_doo@;m007oo@;m003o`000?o3?<?o`cc300Co`cc31Ol00007oi=/T`03
o`000?meRWGoMHYe00goMHYe00?o0000oc;=<_lbcC802OlbcC800ol0003o4NhAoa7^4@03oa7^4@03
o`000?l0o`3o0?l000Go0?l000?o0000oaKY5_lFjAH02?lFjAH00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000od2o@?m0_d002om0_d000ol0003oI9]TofBKI00@ofBKI003
o`000?no@;oo_d2o00oo_d2o00?o0000onDJiOoU6^D03?oU6^D2o`000003onPGj?l0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Oom0_d00?o0000ol<l`ol00000
1?l0000<oi=/T`03o`000?meRWGoMHYe00koMHYe00?o0000oc;=<_lbcC802?lbcC800ol0003o4NhA
oa7^4@02oa7^4@03o`000?l0o`3o0?l000Oo0?l000?o0000oaKY5_lFjAH01olFjAH00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000od2o@?m0_d002om0_d000ol0003oI9]T
ofBKI00AofBKI003o`000?no@;oo_d2o00go_d2o00?o0000onDJiOoU6^D03ooU6^D00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo@;m?od2o@01Ood2o@3o`00017oTfbC00?o0000ogF:MOmeRWD03_me
RWD00ol0003o</dboc;=<P09oc;=<P04o`000?lAkQ7o4NhAo`0000[o0?l000?o0000oaKY5_lFjAH0
1olFjAH00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Om0_d000ol0003o
I9]TofBKI00AofBKI0?o00003Ono@;l00ol0003oiA[UonDJi@0?onDJi@03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o@;mood2o@0=ood2o@?o00000_od2o@2o`0000;og2?L00?o0000oi=/TonCK9<03onCK9<00ol0003o
MHYeogF:M@0>ogF:M@03o`000?lbcC;o</db00So</db1Ol0000;o`3o0003o`000?lFjAKo5^TF00Ko
5^TF00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=od2o@003o`000?mTVfCoI9]T
017oI9]T00?o0000of>LHomSW6<00ol0000:okm0_`Co00003OoU6^D00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00co
o@;m00Co0000ooD:mOoe2_Gom@[e0_l00005om`Sg003o`000?nCK9?oTfbC00koTfbC00?o0000ogF:
MOmeRWD03_meRWD00ol0003o</dboc;=<P07oc;=<P03o`000?lOgaoo7mlO00?o7mlO00?o0000o`3o
0?l0o`002?l0o`000ol0003o5^TFoaKY5P05oaKY5P03o`000?l0o`3o0?l000[o0?l01Ol0000<od2o
@003o`000?mTVfCoI9]T013oI9]T00?o0000of>LHomSW6<01?mSW6<3o`0000Ko_d2o00?o0000on4N
hOoQ7^400_oQ7^45o`0000SoiA[U00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oe2_Gom@[e00?o
m@[e00?o0000om`Sg?oL8m`01?oL8m`00ol0003oTfbCoi=/T`0=oi=/T`03o`000?meRWGoMHYe00oo
MHYe00?o0000oc;=<_lbcC801?lbcC82o`0000Oo7mlO00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000od2o@?m0_d002?m0_d03o`00013oI9]T00?o0000of>LHomSW6<02?mSW6<3o`0000;o
_d2o00?o0000on4NhOoQ7^402?oQ7^45o`0000?oiA[U00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo@;mood2o@0:ood2o@03o`00
0?oe2_Gom@[e00Com@[e00?o0000om`Sg?oL8m`01OoL8m`00ol0003oTfbCoi=/T`0;oi=/T`Co0000
3omeRWD00ol0003o</dboc;=<P03oc;=<P03o`000?lOgaoo7mlO00So7mlO00?o0000o`3o0?l0o`00
1?l0o`02o`0000So6n@K00?o0000o`_d2ol;m0/02?l;m0/00ol0003o0?l0o`3o0005o`3o00;o0000
1_m0_d02o`0000?o><Lh00?o0000ofBKI?mTVf@03?mTVf@00ol0003oHiaSof>LH`0<of>LH`;o0000
4?oQ7^43o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02Oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oL8mcog2?L00Kog2?L00?o
0000oi=/TonCK9<02OnCK9<00ol0003oXUfRo`000002oefRG@?o00003?meRWD01?l0003o</dboc;=
<_lbcC82o`0000co7mlO00?o0000o`3o0?l0o`000_l0o`000ol0003o6n@Koa_T6`08oa_T6`03o`00
0?l;m0_o2o@;00So2o@;00?o0000o`3o0?l0o`001ol0o`000ol0003o@;m0od2o@002od2o@003o`00
0?lhacSo><Lh00Co><Lh0_l0000;ofBKI003o`000?mSW6?oHiaS00coHiaS00?o0000ojUFZOl00000
4_oQ7^400ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ood2oOom0_d02?om0_d00ol0003om@[eooD:m@06ooD:m@03o`000?oL8mcog2?L00Oog2?L00?o
0000oi=/TonCK9<01_nCK9<2o`0000;oXUfR00?o0000oefRGOmMXUd00omMXUd3o`0000[oMHYe00?o
0000oc;=<_l000003olOgal01?l0003o0?l0o`000?l0000;oa_T6`03o`000?l;m0_o2o@;00So2o@;
00?o0000o`3o0?l0o`002?l0o`001?l0003o@;m0o`000?l00009ocS7>003o`000?mTVfCoI9]T00Oo
I9]T00?o0000of>LHomSW6<03?mSW6<01?l0003oZEJYojUFZOl0000Con4Nh@03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o@;m00?o0000ooD:mOoe2_D01ooe2_D00ol0003og2?Lom`Sg008om`Sg003o`000?nCK9?oTfbC00Co
TfbC00?o0000oj9MX_nRGJ800onRGJ800ol0003oGJ9MoefRG@05oefRG@?o00001_meRWD4o`00013o
7mlO00?o0000oa_T6olKi1/03?lKi1/00ol0003o2o@;o`_d2`07o`_d2`03o`000?l0o`3o0?l000Wo
0?l000?o0000ocS7>?lhacP02_lhacP2o`0000KoI9]T00?o0000of>LHomSW6<03?mSW6<00ol0003o
ZEJYojUFZ@02ojUFZ@03o`000?oQ7^7ohAkQ00oohAkQ00?o0000oo<<lol000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ood2oOom0_d0
1?om0_d00ol0003om@[eooD:m@08ooD:m@03o`000?oL8mcog2?L00Wog2?L00Co0000oi=/TonCK9?o
TfbC0_l00006oj9MXP03o`000?mMXUgoGJ9M00SoGJ9M0ol000000omeRWGo0000o`000004ocS7>003
o`000?lOgaoo7mlO00go7mlO00?o0000oa_T6olKi1/03?lKi1/00ol0003o2o@;o`_d2`07o`_d2`03
o`000?l0o`3o0?l000Wo0?l000?o0000ocS7>?lhacP03?lhacP00ol0003oI9]TofBKI003o`0000ko
HiaS00?o0000ojUFZOnYEZT00onYEZT00ol0003ohAkQon4Nh@0>on4Nh@05o`000?oc3??ol`ccoo<<
lol000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ood2oOom0_d00_om0_d00ol0003om@[eooD:m@09ooD:m@03o`000?oL8mcog2?L00[o
g2?L00?o0000oi=/Tol000002?nRGJ800ol0003oGJ9MoefRG@0;oefRG@03o`000?lhacSo><Lh00Go
><Lh00?o0000oaoO7olOgal03?lOgal00ol0003o6n@Koa_T6`0<oa_T6`03o`000?l;m0_o2o@;00Oo
2o@;00?o0000o`3o0?l0o`002?l0o`02o`0000oo><Lh0_l00002ofRGJ003o`000?mSW6?oHiaS00_o
HiaS00?o0000ojUFZOnYEZT01?nYEZT00ol0003ohAkQon4Nh@0=on4Nh@03o`000?oc3??ol`cc00?o
l`cc00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooD:m@03o`000?oL8mcog2?L00_og2?L00?o0000oj9MX_nRGJ80
1onRGJ800ol0003oGJ9MoefRG@0;oefRG@03o`000?lhacSo><Lh00Ko><Lh00?o0000oaoO7olOgal0
2olOgal2o`0000go6n@K00?o0000o`_d2ol;m0/01ol;m0/00ol0003o0?l0o`3o0007o`3o0004o`00
0?l<l`co3?<<o`0000ko><Lh00?o0000ofRGJ?mXUfP00_mXUfP00ol0003oHiaSof>LH`09of>LH`03
o`000?nYEZWoZEJY00KoZEJY00?o0000on4NhOoQ7^402ooQ7^400ol0003ol`ccoo<<l`05oo<<l`04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Som@[e00?o0000om`Sg?oL8m`02_oL8m`2o`0000Wo
XUfR00?o0000oefRGOmMXUd02omMXUd00ol0003o><LhocS7>007ocS7>003o`000?lOgaoo7mlO00Wo
7mlO00Co0000o`3o0?l0o`3o00003?lKi1/00ol0003o2o@;o`_d2`07o`_d2`03o`000?l0o`3o0?l0
00Ko0?l000Go0000o`cc3?l<l`co3?<<o`00000>ocS7>003o`000?mXUfSoJ9MX00?oJ9MX00?o0000
of>LHomSW6<01omSW6<00ol0003oZEJYojUFZ@07ojUFZ@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000
oo<<looc3?<01ooc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooD:m@03o`000?oL8mcog2?L
00Wog2?L00Co0000om4^dOoA;]7o00002OnRGJ800ol0003oGJ9MoefRG@09oefRG@03o`000?lhacSo
><Lh00Wo><Lh00?o0000oaoO7olOgal01olOgal00ol0003o0?l0o`3o0002o`3o0003o`000?lKi1_o
6n@K00Wo6n@K00?o0000o`_d2ol;m0/01ol;m0/00ol0003o0?l0o`3o0005o`3o0003o`000?l<l`co
3?<<00?o3?<<00?o0000ocS7>?lhacP02_lhacP00ol0003oJ9MXofRGJ005ofRGJ003o`000?mSW6?o
HiaS00GoHiaS00?o0000ojUFZOnYEZT02?nYEZT00ol0003ohAkQon4Nh@09on4Nh@03o`000?oc3??o
l`cc00Sol`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oe2_D3o`0000Wog2?L00?o0000om4^
dOoA;]400_oA;]400ol0003oXUfRoj9MXP06oj9MXP03o`000?mMXUgoGJ9M00WoGJ9M00?o0000ocS7
>?lhacP02_lhacP00ol0003o7mlOoaoO7`05oaoO7`03o`000?l0o`3o0?l000Co0?l000?o0000oa_T
6olKi1/02?lKi1/00ol0003o2o@;o`_d2`07o`_d2`03o`000?l0o`3o0?l000Co0?l000?o0000o`cc
3?l<l``01?l<l``00ol0003o><LhocS7>00:ocS7>003o`000?mXUfSoJ9MX00KoJ9MX00?o0000of>L
HomSW6<00omSW6<00ol0003oZEJYojUFZ@09ojUFZ@03o`000?oQ7^7ohAkQ00SohAkQ00?o0000oo<<
looc3?<02Ooc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onhAkP?o00001OoL8m`00ol0003o
dBkAom4^d@03om4^d@03o`000?nRGJ;oXUfR00KoXUfR00?o0000oefRGOmMXUd02OmMXUd00ol0003o
><LhocS7>00;ocS7>003o`000?lOgaoo7mlO00?o7mlO00?o0000o`3o0?l0o`001_l0o`000ol0003o
6n@Koa_T6`08oa_T6`03o`000?l;m0_o2o@;00Ko2o@;00?o0000o`3o0?l0o`000_l0o`02o`0000So
3?<<00?o0000ocS7>?lhacP02OlhacP00ol0003oJ9MXofRGJ007ofRGJ005o`000?mSW6?oHiaSof>L
Hol000003OnYEZT00ol0003ohAkQon4Nh@06on4Nh@03o`000?oc3??ol`cc00[ol`cc00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o^4NkokQ7^00GokQ7^0ol000000ooL8mco0000om4^d@06om4^d@03
o`000?nRGJ;oXUfR00GoXUfR00?o0000oefRGOmMXUd02OmMXUd00ol0003o><LhocS7>00<ocS7>005
o`000?lOgaoo7mlOoaoO7ol000002_l0o`000ol0003o6n@Koa_T6`07oa_T6`03o`000?l;m0_o2o@;
00Ko2o@;00?o0000o`3o0?l000000_l000000olfbCKo0000o`cc3007o`cc3003o`000?lhacSo><Lh
00So><Lh00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oHiaSo`00000=ojUFZ@Co00001OoQ7^400ol0
003ol`ccoo<<l`0;oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003okQ7^onhAkP08onhAkP03
o`000?oA;]7odBkA00OodBkA00?o0000oj9MX_nRGJ801?nRGJ800ol0003oGJ9MoefRG@09oefRG@03
o`000?lhacSo><Lh00go><Lh00?o0000oaoO7ol000003?l0o`0:o`0000Oo2o@;0ol00005ocK9=P03
o`000?l<l`co3?<<00Ko3?<<00?o0000ocS7>?lhacP01olhacP00ol0003oJ9MXofRGJ00:ofRGJ003
o`000?nYEZWoZEJY00_oZEJY00?o0000omhQg_oN8Mh00_oN8Mh3o`000003on4NhOl0003ol`cc00_o
l`cc0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003odBkAom4^d@07om4^d@03o`00
0?nRGJ;oXUfR00GoXUfR00?o0000oefRGOmMXUd01omMXUd00ol0003o><LhocS7>00?ocS7>0;o0000
2ol0o`000ol0003o:MHYobWF:@07obWF:@03o`000?l;m0_o2o@;00;o2o@;0ol00008ocK9=P03o`00
0?l<l`co3?<<00Ko3?<<00?o0000ocS7>?lhacP01olhacP00ol0003oJ9MXofRGJ00:ofRGJ003o`00
0?nYEZWoZEJY00[oZEJY00?o0000omhQg_oN8Mh01_oN8Mh00ol0003ol`ccoo<<l`08oo<<l`?o0000
0_of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003odBkAom4^
d@08om4^d@03o`000?nRGJ;oXUfR00CoXUfR00?o0000oefRGOmMXUd01omMXUd00ol0003o><LhocS7
>00>ocS7>004o`000?l8m`So2?L8o`0000Wo0?l000?o0000obWF:OlYeRT02OlYeRT01?l0003o2o@;
o`000?l0000<ocK9=P03o`000?l<l`co3?<<00Ko3?<<00?o0000ocS7>?lhacP01_lhacP00ol0003o
J9MXofRGJ00;ofRGJ003o`000?nYEZWoZEJY00OoZEJY0_l00009omhQgP03o`000?oc3??ol`cc00Co
l`cc1?l00006ooH9mP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003okQ7^onhAkP09onhAkP03o`00
0?oA;]7odBkA00SodBkA00?o0000oj9MX_nRGJ800onRGJ8>o`0000go><Lh00?o0000o`Sg2?l8m`P0
0_l8m`P00ol0003o0?l0o`3o0005o`3o0003o`000?lYeRWo:MHY00_o:MHY00?o0000ocK9=_lfbCH0
3?lfbCH00ol0003o3?<<o`cc3006o`cc3003o`000?lhacSo><Lh00Go><Lh00?o0000ofRGJ?mXUfP0
3?mXUfP00ol0003oZEJYojUFZ@06ojUFZ@03o`000?oN8MkogR7N00[ogR7N00?o0000oo<<looc3?<0
0ol0000:ooH9mP?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000om4^dOoA;]402?oA
;]401Ol0003oXUfRoj9MX_nRGJ;o000000_oKI9]00?o0000o`gb3Ol=lPd00ol00009ocS7>003o`00
0?l8m`So2?L800Co2?L800?o0000o`3o0?l0o`000ol0o`000ol0003o:MHYobWF:@0<obWF:@03o`00
0?lfbCKo=/Tf00go=/Tf00?o0000o`cc3?l<l``01_l<l``00ol0003o><LhocS7>003ocS7>0?o0000
3OmXUfP00ol0003oZEJYojUFZ@05ojUFZ@03o`000?oN8MkogR7N00cogR7N0_l0000=ooH9mP03o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000om4^dOoA;]402?oA
;]44o`0000coKI9]00?o0000o`gb3Ol=lPd00ol=lPd3o`0000Go><Lh00?o0000o`Sg2?l8m`P01_l8
m`P01Ol0003o0?l0o`3o0?l0o`3o000000oo:MHY00?o0000ocK9=_lfbCH03OlfbCH00ol0003o3?<<
o`cc3006o`cc3003o`000?lhacSo><Lh00?o00000olTfb@00ol0003oJ9MXofRGJ00;ofRGJ003o`00
0?nYEZWoZEJY00?oZEJY00?o0000omhQg_oN8Mh03OoN8Mh00ol0003omPWfooH9mP0;ooH9mP03o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onhAk_o^4Nh02_o^4Nh3o`0000KodBkA0ol0
0003okm0_`03o`000?m]TVgoKI9]00[oKI9]00?o0000o`gb3Ol=lPd01_l=lPd3o`000003ocS7>?l0
003o2?L800Wo2?L800?o0000o`3o0?l000004?lYeRT00ol0003o=/TfocK9=P0=ocK9=P03o`000?l<
l`co3?<<00Oo3?<<0_l00007obCK9003o`000?mXUfSoJ9MX00[oJ9MX00Co0000ojUFZOnYEZWoZEJY
0ol0000?omhQgP03o`000?of2OKomPWf00_omPWf00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onhAk_o^4Nh02_o^
4Nh01?l0003oiQWVonHIi_oV6NH2o`000004om4^dOl0003o0000o`0000Ko_d2o00?o0000offBKOm]
TVd02_m]TVd00ol0003o3O8=o`gb3@09o`gb3@03o`000?l8m`So2?L800[o2?L800?o0000obWF:OlY
eRT03olYeRT00ol0003o=/TfocK9=P0>ocK9=P03o`000?l<l`co3?<<00Ko3?<<00?o0000obCK9?lT
fb@01olTfb@4o`0000SoJ9MX00Co0000ojUFZOnYEZWo00000onm@[d2o`0000gogR7N00?o0000ooH9
m_of2OH02_of2OH00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003o
iQWVonHIiP04onHIiP03o`000?no@;oo_d2o00Oo_d2o00?o0000offBKOm]TVd02Om]TVd00ol0003o
3O8=o`gb3@0:o`gb3@03o`000?l8m`So2?L800[o2?L800?o0000obWF:OlYeRT03olYeRT00ol0003o
=/TfocK9=P0>ocK9=P03o`000?l<l`co3?<<00Go3?<<00?o0000obCK9?lTfb@02?lTfb@01?l0003o
HIiQof6NHOmQWV47o`0000;oJ9MX0_l00006oke2_@;o00003?oN8Mh00ol0003omPWfooH9mP09ooH9
mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003okQ7^onhAkP08onhAkP03o`000?oV6NKoiQWV00Go
iQWV00?o0000okm0_ono@;l02?no@;l00ol0003oKI9]offBK@08offBK@03o`000?l=lPgo3O8=00[o
3O8=00?o0000o`Sg2?l8m`P02ol8m`P00ol0003o:MHYobWF:@0>obWF:@03o`000?lfbCKo=/Tf00ko
=/Tf1Ol00002o`cc3003o`000?lTfbCo9=/T00Wo9=/T00?o0000of6NHOmQWV402?mQWV43o`0000Wo
_D:m0_l0000:omhQgP03o`000?of2OKomPWf00SomPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o^4NkokQ7^00SokQ7^00?o0000onHIi_oV6NH01ooV6NH00ol0003o_d2ookm0_`07okm0_`03o`00
0?m]TVgoKI9]00SoKI9]00?o0000o`gb3Ol=lPd02_l=lPd00ol0003o2?L8o`Sg200:o`Sg20;o0000
3_lYeRT3o`0000go=/Tf0ol00005od:m@P;o00002olTfb@00ol0003oHIiQof6NH@0;of6NH@;o0000
2_nm@[d2o`0000OogR7N0ol00009ooH9mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:onHIiP03o`00
0?no@;oo_d2o00Oo_d2o00?o0000offBKOm]TVd02?m]TVd>o`0000Wo2?L80ol000000ol0o`3o0000
obWF:@0:obWF:@?o00000_m2_D800ol0003o=/TfocK9=P09ocK9=P;o00002Om2_D800ol0003o9=/T
obCK9009obCK9003o`000?mQWV7oHIiQ00_oHIiQ00?o0000oh]dRol000002onm@[d2o`0000CogR7N
00Co0000on`Ck?o/4ncok1?/0_l00007ooH9mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003oiQWV
onHIiP09onHIiP03o`000?no@;oo_d2o00Ko_d2o00?o0000offBKOm]TVd02?m]TVd00ol0003o5>/D
oaC[500:oaC[5003o`000?l8m`So2?L800Co2?L80ol00005o`3o0003o`000?lYeRWo:MHY00Co:MHY
1?l00006od:m@P03o`000?lfbCKo=/Tf00Ko=/Tf0_l0000;od:m@P03o`000?lTfbCo9=/T00Wo9=/T
00?o0000of6NHOmQWV402_mQWV401Ol0003oRgB;oh]dRon;M8_o000000co_D:m0_l000000ooN8Mko
0000on`Ck005on`Ck003o`000?of2OKomPWf00?omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oV6NKoiQWV00SoiQWV00?o0000okm0_ono@;l01_no@;l00ol0003oKI9]offBK@07offBK@03o`00
0?lDjaCo5>/D00_o5>/D00?o0000o`Sg2?l8m`P00_l8m`P2o`0000Wo0?l000?o0000obWF:OlYeRT0
0ol0000;od:m@P03o`000?lfbCKo=/Tf00;o=/Tf0ol0000>od:m@P03o`000?lTfbCo9=/T00Oo9=/T
00?o0000of6NHOmQWV402omQWV400ol0003oRgB;oh]dR`02oh]dR`03o`000?nm@[go_D:m00_o_D:m
00?o0000on`Ck?o/4n`01_o/4n`2o`0000?omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oV
6NKoiQWV00OoiQWV00?o0000okm0_ono@;l01ono@;l00ol0003oKI9]offBK@05offBK@?o00003OlD
ja@4o`0000_o0?l00ol0000?od:m@P04o`000?lfbCKo0000o`00017o@[e200?o0000obCK9?lTfb@0
1olTfb@00ol0003oHIiQof6NH@0:of6NH@03o`000?n;M8_oRgB;00CoRgB;00?o0000oke2_Onm@[d0
1onm@[d3o`0000_ok1?/1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onHIi_oV6NH02?oV6NH00ol0003o_d2ookm0
_`06okm0_`03o`000?m]TVgoKI9]00;oKI9]0ol00003odVfB@03o`000?lDjaCo5>/D00[o5>/D00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aod:m@P03o`000?m2_D;o@[e2017o@[e200?o
0000obCK9?lTfb@01olTfb@00ol0003oHIiQof6NH@0:of6NH@03o`000?n;M8_oRgB;00GoRgB;00Co
0000oke2_Onm@[go_D:m1Ol00002olLha`03o`000?o/4ncok1?/00Wok1?/00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onHIi_oV6NH01ooV6NH00ol0003o_d2ookm0_`05okm0_`?o0000
00?oKI9]o`000?l000001om9]TT00ol0003o5>/DoaC[5008oaC[50?o00002_l0o`02o`0000;o0?l0
00?o0000od:m@_m2_D803om2_D800ol0003o@[e2od:m@P0Aod:m@P03o`000?lTfbCo9=/T00Oo9=/T
00?o0000of6NHOmQWV402OmQWV400ol0003oRgB;oh]dR`07oh]dR`?o00001oo7><L00ol0003ok1?/
on`Ck009on`Ck003o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onHIi_oV6NH01ooV
6NH4o`0000;o_d2o0_l00003ok=</`03o`000?m9]TWoBKI900SoBKI90_l00006oaC[50;o00000olB
kA800ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000od:m@_m2_D803_m2
_D800ol0003o@[e2od:m@P0Bod:m@P03o`000?lTfbCo9=/T00Go9=/T00?o0000of6NHOmQWV402OmQ
WV400ol0003oRgB;oh]dR`08oh]dR`03o`000?o7><OoacS700OoacS700?o0000on`Ck?o/4n`02?o/
4n`00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oV6NKoiQWV00CoiQWV0_l00004
onHIiP;o00001OncC;<00ol0003oBKI9odVfB@0:odVfB@03o`000?lDjaCo5>/D00;o5>/D00?o0000
oa;]4_lBkA801?lBkA800ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
od:m@_m2_D803_m2_D800ol0003o@[e2od:m@P0Bod:m@P[o00002_mQWV400ol0003oRgB;oh]dR`08
oh]dR`03o`000?o7><OoacS700OoacS700?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003oiQWVonHIi_oV6NH2o`0000OoiQWV00?o0000ok=</oncC;<01?ncC;<0
0ol0003oBKI9odVfB@0:odVfB@04o`000?lDjaCo0000o`0000So4^dB00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?m2_D;o@[e200ko@[e200?o0000od:m@_m2_D804_m2_D800ol0003o@;m0
od2o@007od2o@003o`000?mQWV7oHIiQ00KoHIiQ00?o0000oh]dRon;M8/02_n;M8/00ol0003oacS7
olLha`06olLha`03o`000?o/4ncok1?/00Sok1?/00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oV
6NKo0000o`0000WoiQWV00?o0000ok=</oncC;<01?ncC;<00ol0003oBKI9odVfB@0;odVfB@03o`00
0?lBkA;o4^dB00Wo4^dB00?o0000o`3o0?l000002Ol0o`000ol0003o@[e2od:m@P0>od:m@P;o0000
4_m2_D800ol0003o@;m0od2o@009od2o@0;o00001_mQWV400ol0003oRgB;oh]dR`0:oh]dR`03o`00
0?o7><OoacS700KoacS700?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onHIi_oV6NH02OoV6NH00ol0003o/dbcok=</`05ok=</`03o`000?m9]TWoBKI900[oBKI900?o
0000oa;]4_lBkA802_lBkA82o`0000Wo0?l000?o0000od:m@_m2_D803_m2_D800ol0003o;]4^o`00
0002o`0000oo@[e200?o0000od2o@?m0_d002om0_d000ol0003oHIiQof6NH@03o`0000goRgB;00?o
0000olLhaoo7><L01_o7><L00ol0003ok1?/on`Ck007on`Ck003o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oiQWVonHIiP09onHIiP03o`000?ncC;?o/dbc00Go/dbc00?o0000odVfBOm9]TT02Om9]TT2
o`0000_o4^dB0_l0000;o`3o0003o`000?m2_D;o@[e200co@[e200?o0000obkA;_l^dBh00ol^dBh3
o`0000co@[e200?o0000od2o@?m0_d003?m0_d02o`0000;oOgmo00?o0000oh]dRon;M8/03?n;M8/0
0ol0003oacS7olLha`05olLha`03o`000?o/4ncok1?/00Ook1?/00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oV6NKoiQWV00[oiQWV00?o0000ok=</oncC;<01_ncC;<00ol0003oBKI9odVfB@07odVf
B@03o`000?m;]4_o000000[o4^dB00Co0000o`Sg2?l8m`So00002_l0o`000ol0003o@[e2od:m@P0<
od:m@P03o`000?l^dBko;]4^00Ko;]4^0_l00008od:m@P;o00003om0_d000ol0003oOgmoogmoO`02
ogmoO`03o`000?n;M8_oRgB;00_oRgB;00?o0000olLhaoo7><L01Oo7><L00ol0003ok1?/on`Ck007
on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oiQWVonHIiP0:onHIiP03o`000?ncC;?o/dbc
00Ko/dbc00?o0000odVfBOm9]TT01_m9]TT01Ol0003oBkA;od^dBom;]4_o000000So4^dB00?o0000
o`Sg2?l8m`P00_l8m`P00ol0003o0?l0o`3o0006o`3o00Co00003?m2_D800ol0003o;]4^obkA;P08
obkA;P?o00000_m2_D83o`000003oc?<<ol0003o@;m000go@;m000?o0000ogmoOomoOgl01?moOgl0
0ol0003oRgB;oh]dR`0:oh]dR`03o`000?o7><OoacS700GoacS700?o0000on`Ck?o/4n`01_o/4n`0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onHIi_oV6NH02ooV6NH00ol0003o/dbcok=</`07ok=<
/`03o`000?m9]TWoBKI900?oBKI90_l00005od^dB`03o`000?lBkA;o4^dB00Co4^dB00?o0000o`Sg
2?l8m`P00ol8m`P00ol0003o0?l0o`3o0005o`3o0003o`000?l=lPgo3O8=00;o3O8=0ol00007od:m
@P;o00003_l^dBh2o`0000Go<l`c00?o0000od2o@?m0_d002_m0_d000ol0003oOgmoogmoO`05ogmo
O`03o`000?n;M8_oRgB;00_oRgB;00?o0000olLhaoo7><L01?o7><L00ol0003ok1?/on`Ck006on`C
k003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiQWVonHIiP0;onHIiP03o`000?ncC;?o/dbc00Oo
/dbc00?o0000odVfBOm9]TT00_m9]TT00ol0003oBkA;od^dB`06od^dB`03o`000?lBkA;o4^dB00;o
4^dB00?o0000o`Sg2?l8m`P01Ol8m`P00ol0003o0?l0o`3o0002o`3o00;o00002?l=lPd3o`0000;o
@[e20_l000000olDjaCo0000obkA;P0=obkA;P03o`000?lcc3?o<l`c00Go<l`c00?o0000od2o@?m0
_d002?m0_d000ol0003oOgmoogmoO`07ogmoO`03o`000?n;M8_oRgB;00[oRgB;00?o0000olLhaoo7
><L01?o7><L00ol0003ok1?/on`Ck006on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiQWV
onHIiP0<onHIiP03o`000?ncC;?o/dbc00So/dbc00Co0000odVfBOm9]TWo00002Om;]4/01Ol0003o
4^dBoa;]4_lBkA;o000000So2?L800Go0000o`3o0?l0o`3o0?l0o`00000=o`gb3@;o00001?lDja@0
0ol0003o;]4^obkA;P0;obkA;P03o`000?lcc3?o<l`c00Ko<l`c00?o0000od2o@?m0_d001om0_d00
0ol0003oOgmoogmoO`08ogmoO`Co00002?n;M8/00ol0003oacS7olLha`04olLha`03o`000?o/4nco
k1?/00Kok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oV6NKoiQWV00_oiQWV0ol00009ok=<
/`03o`000?m9]TWo000000_oBkA;00?o0000oa;]4_l000002_l8m`P00ol0003o0?l0o`00000?o`gb
3@03o`000?lDjaCo5>/D00;o5>/D00?o0000obkA;_l^dBh02ol^dBh00ol0003o<l`coc?<<`06oc?<
<`03o`000?m0_d3o@;m000Ko@;m000?o0000ogmoOomoOgl02OmoOgl01?l0003o/4n`ok1?/?n`Ck07
o`0000;oRgB;00?o0000olLhaoo7><L00oo7><L00ol0003ok1?/on`Ck005on`Ck003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oV6NKoiQWV00SoiQWV0ol00003on4Nh@03o`000?ncC;?o/dbc00Oo/dbc00?o0000od^d
Bom;]4/02om;]4/00ol0003o2?L8o`Sg200:o`Sg2003o`000?l=lPgo3O8=00go3O8=00?o0000oaC[
5?lDja@01?lDja@00ol0003o;]4^obkA;P09obkA;P03o`000?lcc3?o<l`c00So<l`c00?o0000od2o
@?m0_d000om0_d02o`0000coOgmo00?o0000ok1?/?n`Ck002?n`Ck0<o`0000?ok1?/0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onHIi_oV6NH01_oV6NH3o`0000OohAkQ00?o0000ok=</oncC;<01_ncC;<00ol0003o
BkA;od^dB`0;od^dB`03o`000?l8m`So2?L800Wo2?L80_l0000>o`gb3@03o`000?lDjaCo5>/D00Go
5>/D00?o0000obkA;_l^dBh02Ol^dBh00ol0003o<l`coc?<<`09oc?<<`03o`000?m0_d3o000000;o
00000_mdRg@00ol0003oOgmoogmoO`08ogmoO`03o`000?n`Ck3o/4n`00co/4n`00?o0000onLHiooW
6>L01_oW6>L3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oiQWVonHIiP03onHIiP?o00002ooQ7^400ol0003o/dbc
ok=</`04ok=</`03o`000?m;]4_oBkA;00_oBkA;0ol00007o`Sg20?o000000?o3O8=o`000?l=lPd0
3Ol=lPd00ol0003o5>/DoaC[5006oaC[5003o`000?l^dBko;]4^00So;]4^00?o0000oc?<<olcc3<0
2_lcc3<00ol0003oM8]dogB;M004ogB;M003o`000?moOgooOgmo00OoOgmo00?o0000ok1?/?n`Ck00
2on`Ck000ol0003oiaSWonLHi`08onLHi`03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onHIi_l0
003o0000o`0000oohAkQ00?o0000ok=</oncC;<00oncC;<>o`0000?o>LHi0_l00002o`Sg20?o0000
1Ol=lPd00ol0003o3O8=o`gb3@0:o`gb3@03o`000?lDjaCo5>/D00Oo5>/D00?o0000obkA;_l^dBh0
2?l^dBh00ol0003o<l`coc?<<`0:oc?<<`03o`000?mdRgCoM8]d00GoM8]d00?o0000ogmoOomoOgl0
1_moOgl00ol0003o/4n`ok1?/00;ok1?/003o`000?oW6>OoiaSW00SoiaSW00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ok1?/2o`0001;ohAkQ00?o0000ok=</oncC;<00_ncC;<00ol0003oUVVFoiIY
UP0:oiIYUP03o`000?liaSWo>LHi00?o>LHi0_l00009o`gb3@03o`000?l=lPgo3O8=00Wo3O8=00?o
0000oaC[5?lDja@02?lDja@2o`0000So;]4^00?o0000oc?<<olcc3<02Olcc3<00ol0003oM8]dogB;
M007ogB;M003o`000?moOgooOgmo00CoOgmo00?o0000ok1?/?n`Ck002on`Ck000ol0003oiaSWonLH
i`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ohAkQon4Nh@0?on4Nh@?o000000?o/dbc
o`000?nFJIH02onFJIH00ol0003o>LHiocW6>@04ocW6>@03o`000?l=lPgo3O8=00Wo3O8=00?o0000
o`gb3Ol=lPd01ol=lPd00ol0003o5>/DoaC[5009oaC[5004o`000?lGj1Oo0000o`0000Ko;]4^00?o
0000oc?<<olcc3<02Olcc3<00ol0003oM8]dogB;M008ogB;M003o`000?moOgooOgmo00?oOgmo00?o
0000ok1?/?n`Ck002on`Ck000ol0003oiaSWonLHi`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ohAkQon4Nh@0<on4Nh@;o00000ooO8=l2o`0000coUVVF00?o0000ocW6>OliaST01?liaST0
0ol0003o3O8=o`gb3@0:o`gb3@Wo00002olDja@00ol0003o5nPGoaOX5`02oaOX5`?o00000_l^dBh0
0ol0003o<l`coc?<<`0:oc?<<`03o`000?mdRgCoM8]d00WoM8]d00?o0000ogmoOomoOgl00_moOgl0
0ol0003o/4n`ok1?/00:ok1?/003o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oQ7^42o`0000Gogb3O00?o0000ok=</ol000002_nFJIH00ol0003o>LHiocW6>@06ocW6
>@03o`000?l=lPgo3O8=00Wo3O8=00?o0000o`Gj1Ol5nPD01Ol5nPD00ol0003o5>/DoaC[5009oaC[
5003o`000?lGj1Oo5nPG00Go5nPG0ol00009oc?<<`?o00003OmdRg@01Ol0003oOgmoogmoOomoOgoo
000000co/4n`00?o0000onLHiooW6>L02OoW6>L00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on4N
hOoQ7^401OoQ7^42o`0000Oogb3O00Co0000ok=</oncC;?o00002OnFJIH00ol0003o>LHiocW6>@06
ocW6>@03o`000?l=lPgo3O8=00So3O8=00?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o5>/DoaC[5007
oaC[5003o`000?lGj1Oo5nPG00So5nPG0ol00002oc?<<`Go00000_mA[U400ol0003oM8]dogB;M00<
ogB;M003o`000?moOgoo000000co/4n`00?o0000onLHiooW6>L02_oW6>L00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000on4NhOoQ7^400_oQ7^42o`0000Sogb3O00?o0000ok=</oncC;<00_ncC;<5o`00
00CoUVVF00?o0000ocW6>OliaST01_liaST00ol0003o3O8=o`gb3@08o`gb3@03o`000?l5nPGo1OX5
00Oo1OX500?o0000oaC[5?lDja@01olDja@00ol0003o5nPGoaOX5`08oaOX5`03o`000?lSg2?o8m`S
00;o00002?mA[U400ol0003oM8]dogB;M00<ogB;M0Co00002_n`Ck000ol0003oiaSWonLHi`0:onLH
i`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ohAkQo`000?l0000:omlPg`03o`000?ncC;?o/dbc
00;o/dbc00?o0000og6>LOmaSW400_maSW44o`0000Wo>LHi00?o0000o`gb3Ol=lPd02?l=lPd00ol0
003o1OX5o`Gj1@08o`Gj1@03o`000?lDjaCo5>/D00Go5>/D00?o0000oaOX5olGj1L02?lGj1L01Ol0
003o8m`Sob?L8olSg2?o000000[oDJiA0ol0000;ogB;M004o`000?oG:=OoebSGomLXe`Co00001On`
Ck000ol0003oiaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ogb3OomlPg`0:
omlPg`03o`000?ncC;?o/dbc00?o/dbc00?o0000og6>LOmaSW401?maSW400ol0003o>LHiocW6>@07
ocW6>@03o`000?l=lPgo3O8=00Ko3O8=0_l0000;o`Gj1@03o`000?lDjaCo5>/D00Go5>/D00?o0000
oaOX5olGj1L02?lGj1L00ol0003o8m`Sob?L8`02ob?L8`03o`000?mA[U7oDJiA00OoDJiA00?o0000
oj9MX_nRGJ801?l00006ogB;M003o`000?oG:=OoebSG00KoebSG0ol00002ok1?/003o`000?oW6>Oo
iaSW00_oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oO8=oogb3O00Wogb3O00?o0000ok=<
/oncC;<01?ncC;<00ol0003oLHiaog6>L@05og6>L@03o`000?liaSWo>LHi00Oo>LHi00?o0000o`gb
3Ol=lPd00_l=lPd3o`000003oa_T6ol0003o1OX500[o1OX500?o0000oaC[5?lDja@01OlDja@00ol0
003o5nPGoaOX5`07oaOX5`03o`000?lSg2?o8m`S00?o8m`S00?o0000oe6^DOmA[U401omA[U400ol0
003oXUfRoj9MXP04oj9MXP?o00000_mdRg@00ol0003oebSGomLXe`0:omLXe`;o00003_oW6>L00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000omlPgooO8=l02OoO8=l00ol0003o/dbcok=</`04ok=</`03
o`000?maSW7oLHia00KoLHia0_l00007ocW6>@03o`000?l=lPgo000000;o00001OlKi1/00ol0003o
1OX5o`Gj1@08o`Gj1@?o00001?lDja@00ol0003o5nPGoaOX5`08oaOX5`03o`000?lSg2?o8m`S00Co
8m`S00?o0000oe6^DOmA[U401_mA[U400ol0003oXUfRoj9MXP07oj9MXP;o00003_oG:=L00ol0003o
iaSWonLHi`0;onLHi`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ogb3OomlPg`08omlPg`03o`00
0?ncC;?o/dbc00Go/dbc00?o0000og6>LOmaSW401?maSW400ol0003oK9=/ofbCK003o`0000Co>LHi
0_l00008oa_T6`03o`000?l5nPGo1OX500Oo1OX500Co0000ocC;=?ldbcCo=</d0ol000000olDjaCo
0000oaOX5`09oaOX5`03o`000?lSg2?o8m`S00Co8m`S00?o0000oe6^DOmA[U401OmA[U400ol0003o
XUfRoj9MXP09oj9MXP03o`000?oG:=OoebSG00goebSG00?o0000onLHiooW6>L02_oW6>L00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000omlPgooO8=l01ooO8=l00ol0003o/dbcok=</`06ok=</`03o`00
0?maSW7oLHia00?oLHia00?o0000ofbCK?m/Tf`01?m/Tf`2o`000003ocW6>Ol0003o6n@K00[o6n@K
00?o0000o`Gj1Ol5nPD01Ol5nPD00ol0003o=</docC;=005ocC;=003o`000?lGj1Oo5nPG00Oo5nPG
0ol00007ob?L8`03o`000?mA[U7oDJiA00CoDJiA00?o0000oj9MX_nRGJ802OnRGJ800ol0003oebSG
omLXe`0=omLXe`03o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oO
8=oogb3O00Gogb3O0ol00009ok=</`05o`000?maSW7oLHiaog6>LOl000002Om/Tf`00ol0003o6n@K
oa_T6`0;oa_T6`03o`000?l5nPGo1OX500?o1OX500?o0000ocC;=?ldbc@01_ldbc@00ol0003o5nPG
oaOX5`06oaOX5`05o`000?lbcC;o</dboc;=<_l000001olSg2<00ol0003oDJiAoe6^D@03oe6^D@03
o`000?nRGJ;oXUfR00WoXUfR00?o0000omLXeooG:=L03_oG:=L00ol0003oiaSWonLHi`09onLHi`03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ogb3Oo`000004o`0000;ojQGZ00?o0000ok=</oncC;<0
1oncC;<01?l0003oLHiaog6>LOl00009ofbCK0;o00003OlKi1/00ol0003o1OX5o`Gj1@02o`Gj1@03
o`000?ldbcCo=</d00So=</d00?o0000oaOX5olGj1L00olGj1L2o`0000Go</db00?o0000ob?L8olS
g2<01?lSg2<00ol0003oDJiAoe6^D@03oe6^D@03o`000?nRGJ;oXUfR00WoXUfR00?o0000omLXeooG
:=L03_oG:=L00ol0003oiaSWonLHi`09onLHi`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SojQGZ
00?o0000ok=</oncC;<01_ncC;<00ol0003oLHiao`000009ofbCK004o`000?m@[e3oD:m@o`0000go
6n@K00Co0000o`Gj1Ol5nPGo00003?ldbc@01Ol0003o5nPGoaOX5olGj1Oo000000So</db0_l00005
ob?L8`03o`000?mA[U7oDJiA00;oDJiA00?o0000oj9MX_nRGJ802OnRGJ800ol0003oebSGomLXe`0>
omLXe`03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oZ5N[ojQGZ
00OojQGZ00?o0000ok=</oncC;<01oncC;<00ol0003oK9=/ofbCK007ofbCK003o`000?m@[e3oD:m@
00;oD:m@00?o0000oa_T6olKi1/02_lKi1/00ol0003o1OX5o`00000>ocC;=003o`000?lGj1Oo0000
00_o</db00?o0000ob?L8olSg2<00_lSg2<01Ol0003oDJiAoe6^DOmA[U7o000000coXUfR00?o0000
omLXeooG:=L03_oG:=L3o`0000WoiaSW00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oZ5N[ojQGZ
00WojQGZ00?o0000ok=</oncC;<01_ncC;<00ol0003oK9=/ofbCK006ofbCK003o`000?m@[e3oD:m@
00?oD:m@00?o0000oa_T6olKi1/02olKi1/00ol0003o=</docC;=00>ocC;=003o`000?lbcC;o</db
00_o</db0_l00003ob?L8`04o`000?mA[U7oDJiAo`0000[oXUfR0ol0000>omLXe`;o00000ool0o`2
o`0000OoiaSW00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ok=<
/oncC;<01?ncC;<00ol0003oK9=/ofbCK006ofbCK003o`000?m@[e3oD:m@00GoD:m@00?o0000oa_T
6olKi1/01olKi1/3o`00017o=</d00?o0000oc;=<_lbcC803OlbcC801Ol0003o8m`Sob?L8ol0003o
DJiA00Co00000onRGJ85o`0000;ohacS00?o0000omLXeooG:=L02_oG:=L2o`0000Ooo0?l0_l00004
onLHi`03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ojQGZonXEjP0;onXEjP03o`000?ncC;?o/dbc
00Co/dbc00?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oD:m@oe2_D006oe2_D003o`000?lKi1_o6n@K
00Co6n@K0ol00002ob?L8`03o`000?ldbcCo=</d00oo=</d0_l0000?oc;=<P04o`000?lSg2?o0000
o`0000CoS7><0ol00008on<Lh`03o`000?oG:=OoebSG00OoebSG0_l0000;oo`3o0;o00000_oW6>L0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000onXEj_oZ5NX03?oZ5NX6o`0000OoK9=/00?o0000oe2_
D?m@[e002?m@[e000ol0003o6n@Koa_T6`03o`0000Ko8m`S00?o0000ocC;=?ldbc@03Oldbc@01?l0
003o?l0ooco0?ol0000?oc;=<P03o`000?n<LhcoS7><00GoS7><00?o0000on<LhooS7><02?oS7><0
0ol0003oebSGomLXe`05omLXe`03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oZ5NX00ol0003o^TFjokY5^P04okY5
^P03o`000?m/TfcoK9=/00?oK9=/00?o0000oe2_D?m@[e002_m@[e02o`0000[o8m`S00?o0000ocC;
=?ldbc@02oldbc@00ol0003o?l0ooco0?`02oco0?`03o`000?lbcC;o</db00_o</db0_l00007ohac
S003o`000?oS7>?ohacS00WohacS00?o0000omLXeooG:=L00_oG:=L2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onXEj_oZ5NX02ooZ5NX00ol0003o^TFjokY5^P06okY5^P05o`000?m/TfcoK9=/ofbC
K?l000003Om@[e000ol0003o8m`Sob?L8`0:ob?L8`03o`000?ldbcCo=</d00Wo=</d00?o0000oco0
?olo`3l01?lo`3l00ol0003o</dboc;=<P08oc;=<P;o000000?o?/4no`000?n<Lh`01on<Lh`00ol0
003ohacSon<Lh`09on<Lh`04o`000?oG:=Oo0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?oZ5N[ojQGZ
00WojQGZ00?o0000okY5^_njAKX02?njAKX00ol0003oK9=/o`00000=oe2_D003o`000?lSg2?o8m`S
00_o8m`S00?o0000ocC;=?ldbc@02?ldbc@00ol0003o?l0ooco0?`06oco0?`03o`000?lbcC;o</db
00Go</db0_l00003ock1?P03o`000?n<LhcoS7><00KoS7><00?o0000on<LhooS7><02_oS7><00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ojQGZonXEjP07onXEjP03o`000?njAK[o^TFj00[o^TFj00?o0000oe2_D?m@
[e003?m@[e000ol0003o8m`Sob?L8`0<ob?L8`03o`000?ldbcCo=</d00Ko=</d00?o0000oco0?olo
`3l02?lo`3l00ol0003o</dboc;=<P02oc;=<P;o00001_ln`Ch00ol0003oS7><ohacS005ohacS003
o`000?oS7>?ohacS00[ohacS00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oZ5N[ojQGZ00GojQGZ
00?o0000okY5^_njAKX03?njAKX2o`0000coD:m@00?o0000ob?L8olSg2<03OlSg2<00ol0003o=</d
ocC;=004ocC;=003o`000?lo`3oo?l0o00[o?l0o00Co0000oc;=<_l0003o00002?ln`Ch00ol0003o
S7><ohacS006ohacS003o`000?oS7>?ohacS00WohacS00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_oZ5NX00ol0003o^TFjokY5^P0=okY5^P03o`000?m^TFko000000;o00002?m@[e000ol0003o8m`S
ob?L8`0?ob?L8`Ko00003_lo`3l00ol0003o?/4nock1?P08ock1?P03o`000?n<LhcoS7><00KoS7><
00?o0000on<LhooS7><02OoS7><00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000ondBkOo]4^gokA;]
0_l0000?okY5^P03o`000?m^TFkoKY5^00?oKY5^0ol00005oe2_D0;o00004?lSg2<01_l0003o5^TF
oaKY5_l0003o2?L8o`0000ko?l0o00?o0000ock1?_ln`Ch02Oln`Ch00ol0003oS7><ohacS005ohac
S003o`000?oS7>?ohacS00WohacS00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003o
^TFjokY5^P0=okY5^P03o`000?m^TFkoKY5^00KoKY5^0ol000001?m@[e3o0000obcC;?l/db`3o`00
00co8m`S00Go0000oaKY5_lFjAKo5^TFo`000002o`Sg2003o`000?lo`3oo?l0o00_o?l0o00?o0000
ock1?_ln`Ch02Oln`Ch00ol0003oS7><ohacS006ohacS003o`000?oS7>?ohacS00SohacS0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003okA;]ondBk@04ondBk@oo00003?m^TFh00ol0003o;=</obcC;004obcC
;0?o00002?lSg2<00ol0003o5^TFoaKY5P02oaKY5P05o`000?l8m`So2?L8o`Sg2?l000003?lo`3l0
0ol0003o?/4nock1?P09ock1?P03o`000?n<LhcoS7><00GoS7><3?l00002oo<<l`;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003okA;]ondBk@05ondBk@03o`000?niA[Wo^DJi00_o^DJi00?o0000ofjA
K_m^TFh02_m^TFh00ol0003o;=</obcC;007obcC;0;o00001OlSg2<00ol0003o5^TFoaKY5P03oaKY
5P03o`000?l8m`So2?L800;o2?L800?o0000oco0?olo`3l02Olo`3l00ol0003o?/4nock1?P0:ock1
?P03o`000?n<LhcoS7><00?oS7><00?o0000om@[e?oD:m@02OoD:m@00ol0003ol`ccoo<<l`02oo<<
l`;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@06ondBk@03o`000?niA[Wo^DJi00[o
^DJi00?o0000ofjAK_m^TFh02om^TFh00ol0003o;=</obcC;009obcC;0?o000000?o8m`So`000?lF
jAH01OlFjAH00ol0003o2?L8o`Sg2003o`Sg2003o`000?lo`3oo?l0o00So?l0o3_l00003ohacS0;o
00002ooD:m@00ol0003ol`ccoo<<l`05oo<<l`03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000ondBkOo]4^d01Oo]4^d00ol0003oaSW6o`00000;okU6^@03o`000?m^TFkoKY5^00[oKY5^
0_l0000>obcC;003o`000?lFjAKo5^TF00Go5^TF00?o0000o`Sg2?l8m`P00ol8m`P00ol0003o?l0o
oco0?`08oco0?`03o`000?n8MhSoR7N800_oR7N800?o0000ohacS?l000003OoD:m@00ol0003ol`cc
oo<<l`06oo<<l`;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00KokA;]00Co
0000olHia_o6>LKo00002_niA[T00ol0003oKY5^ofjAKP09ofjAKP03o`000?m8]dSo000000ko;=</
00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2?L8o`Sg2004o`Sg2003o`000?lo`3oo?l0o00Ko?l0o
00?o0000ohQgR?n8MhP03On8MhP00ol0003oe2_Dom@[e00<om@[e003o`000?oc3??ol`cc00Sol`cc
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00GokA;]00?o0000olHia_o6>LH00_o6
>LH00ol0003o^DJiokU6^@06okU6^@03o`000?m^TFkoKY5^00SoKY5^0_l00003odRgB003o`000?l/
dbco;=</00_o;=</00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2?L8o`Sg2005o`Sg2003o`000?lo
`3oo?l0o00Go?l0o00?o0000ohQgR?n8MhP03On8MhP00ol0003oe2_Dom@[e00;om@[e003o`000?oc
3??ol`cc00Wol`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000
olHia_o6>LH00oo6>LH00ol0003o^DJiokU6^@05okU6^@03o`000?m^TFkoKY5^00OoKY5^00?o0000
odRgB?m8]dP00om8]dP00ol0003o;=</obcC;00:obcC;003o`000?lFjAKo5^TF00Ko5^TF00?o0000
o`Sg2?l8m`P01_l8m`P00ol0003o?l0ooco0?`04oco0?`03o`000?n8MhSoR7N800goR7N83ol0000;
oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000olHia_o6>LH01Oo6>LH00ol0
003o^DJiokU6^@04okU6^@03o`000?m^TFkoKY5^00GoKY5^0_l00006odRgB003o`000?l/dbco;=</
00Wo;=</0_l00008oaKY5P03o`000?l8m`So2?L800Ko2?L81Ol000000olo`3oo0000ohQgR00?ohQg
R003o`000?oG:=OoebSG00_oebSG00?o0000oo<<looc3?<02Ooc3?<00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000olHia_o6>LH01_o6>LH00ol0003o
^DJiokU6^@04o`0000KoKY5^00?o0000odRgB?m8]dP01om8]dP00ol0003o;=</obcC;005obcC;0?o
000000?o6>LHo`000?lFjAH01olFjAH00ol0003o2?L8o`Sg2005o`Sg2003o`000?m;]4_oBkA;00?o
BkA;0_l0000?ohQgR0;o00003OoG:=L00ol0003ol`ccoo<<l`08oo<<l`03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WokA;]00?o0000olHia_o6>LH01oo6>LH2o`0000CoXEjQ00Co0000ofjAK_m^TFko
KY5^0_l0000:odRgB003o`000?l/dbco;=</00;o;=</0ol00005oaSW6003o`000?lFjAKo5^TF00Go
5^TF00?o0000o`Sg2?l8m`P01?l8m`P00ol0003oBkA;od^dB`06od^dB`03o`000?n8MhSoR7N800[o
R7N80_l00002okA;]003o`000?oG:=OoebSG00[oebSG00?o0000oo<<looc3?<02?oc3?<00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000ondBkOo]4^d01_o]4^d00ol0003oaSW6olHiaP08olHiaP03o`00
0?nQGZ7oXEjQ00CoXEjQ00?o0000ofjAK_l000003?m8]dP00ol0003o;=</o`000002o`0000Wo6>LH
00?o0000oaKY5_lFjAH01?lFjAH00ol0003o2?L8o`Sg2003o`Sg2003o`000?m;]4_oBkA;00SoBkA;
1_l00004ohQgR0;o00001OndBk@00ol0003oebSGomLXe`09omLXe`03o`000?oc3??ol`cc00Sol`cc
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00GokA;]00?o0000olHia_o6>LH01oo6
>LH00ol0003oXEjQoj5NX@06oj5NX@03o`000?m8]dSoB;M800coB;M800?o0000oaSW6?lHiaP02_lH
iaP00ol0003o5^TFoaKY5P04oaKY5P04o`000?l8m`So2?L8o`Sg20;o00002om;]4/00ol0003oSg2?
ohm`S`03ohm`S`Co00002?ndBk@00ol0003oebSGomLXe`08omLXe`03o`000?oc3??ol`cc00Ool`cc
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003oaSW6olHiaP07olHiaP03o`000?nQ
GZ7oXEjQ00OoXEjQ00?o0000odRgB?m8]dP03?m8]dP00ol0003o6>LHoaSW600;oaSW6003o`000?lF
jAKo5^TF00?o5^TF00Co0000o`Sg2?l8m`So00003Om;]4/00ol0003oSg2?ohm`S`06ohm`S`03o`00
0?ndBkCo]4^d00Oo]4^d00?o0000omLXeooG:=L01ooG:=L00ol0003ol`ccoo<<l`06oo<<l`04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00;okA;]00?o0000olHia_o6>LH0
1_o6>LH00ol0003oXEjQoj5NX@09oj5NX@03o`000?m8]dSoB;M800WoB;M80_l0000>oaSW60?o0000
0olFjAH00ol0003o2?L8o`00000=od^dB`03o`000?n?L8ooSg2?00OoSg2?00?o0000okA;]?ndBk@0
2?ndBk@:o`0000Kol`cc0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000OoaSW600?o
0000oj5NXOnQGZ402_nQGZ400ol0003oB;M8odRgB006odRgB0;o000000?o?kloo`000?lHiaP02olH
iaP2o`0000?o?<<l1Ol0000>od^dB`03o`000?n?L8ooSg2?00OoSg2?00?o0000okA;]?ndBk@02?nd
Bk@00ol0003ohAkQon4Nh@06on4Nh@03o`000?oc3??ol`cc00?ol`cc00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ohQgRon8MhP03on8MhPCo00000_o6>LH00ol0003oXEjQoj5NX@0;
oj5NX@03o`000?m8]dSoB;M800?oB;M80ol00004ocno?`03o`000?lHiaSo6>LH00Oo6>LH0_l00008
occ3?003o`000?m;]4_oBkA;00goBkA;00?o0000ohm`Son?L8l02?n?L8l00ol0003o]4^dokA;]007
okA;]003o`000?oQ7^7ohAkQ00OohAkQ0ol000000ooc3??o0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oR7N;ohQgR00OohQgR0_l0000?oj5NX@03o`000?m8]dSoB;M800;o00002?lo_cl00ol0
003o6>LHoaSW6005oaSW6003o`000?ll`cco?<<l00So?<<l00?o0000od^dBom;]4/03Om;]4/00ol0
003oSg2?ohm`S`08ohm`S`03o`000?ndBkCo]4^d00Ko]4^d00?o0000on4NhOoQ7^402?oQ7^401?l0
003om0_doo@;m?l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ohQgRon8MhP09on8M
hP03o`000?nQGZ7oXEjQ00koXEjQ0_l0000;ocno?`03o`000?lHiaSo6>LH00;o6>LH0_l0000;occ3
?003o`000?m;]4_oBkA;00goBkA;00?o0000ohm`Son?L8l02?n?L8l00ol0003o]4^dokA;]006okA;
]003o`000?oQ7^7ohAkQ00OohAkQ00Go0000oo@;m?od2oCom0_do`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ohQgRon8MhP0:on8MhP03o`000?nQGZ7oXEjQ00goXEjQ0_l0000<ocno?`04o`000?lHiaSo0000
o`0000go?<<l00?o0000od^dBom;]4/03?m;]4/00ol0003oSg2?ohm`S`09ohm`S`03o`000?ndBkCo
]4^d00Ko]4^d00?o0000on4NhOoQ7^401_oQ7^400ol0003om0_doo@;m003oo@;m003o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ohQgRon8MhP0:on8MhP03o`000?nQGZ7oXEjQ00coXEjQ00Co0000og^4
NomkQ7_o00003?lo_cl00ol0003o?<<locc3?00>occ3?003o`000?m;]4_oBkA;00SoBkA;1?l0000;
ohm`S`03o`000?ndBkCo]4^d00Ko]4^d00?o0000on4NhOoQ7^401OoQ7^400ol0003om0_doo@;m004
oo@;m003o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ohQgRon8MhP0;on8MhP03o`000?nQGZ7oXEjQ
00_oXEjQ00?o0000og^4NomkQ7/00_mkQ7/00ol0003o?kloocno?`09ocno?`03o`000?ll`cco?<<l
00ko?<<l00Co0000od^dBom;]4_oBkA;1ol00003of:MHP03o`000?n?L8ooSg2?00WoSg2?00?o0000
okA;]?ndBk@01_ndBk@00ol0003ohAkQon4Nh@04on4Nh@03o`000?od2oCom0_d00Kom0_d00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oR7N;ohQgR00cohQgR00?o0000oj5NXOnQGZ402_nQGZ400ol0
003oNhAkog^4N`03og^4N`03o`000?lo_coo?klo00So?klo00?o0000occ3??ll`c`03_ll`c`4o`00
00_oHYeR00?o0000ohm`Son?L8l02?n?L8l00ol0003o]4^dokA;]005okA;]003o`000?oQ7^7ohAkQ
00GohAkQ00?o0000oo@;m?od2o@01_od2o@00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on8Mh_oR
7N803?oR7N87o`0000GoXEjQ00?o0000og^4NomkQ7/01OmkQ7/00ol0003o?kloocno?`07ocno?`03
o`000?ll`cco?<<l00ko?<<l00?o0000of:MH_mRWF803OmRWF800ol0003oSg2?ohm`S`08ohm`S`03
o`000?ndBkCo]4^d00Co]4^d00?o0000on4NhOoQ7^401?oQ7^400ol0003om0_doo@;m007oo@;m003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohQgRon8MhP0=on8MhP03o`000?o0?l3o`3o000Co`3o0
1Ol00009og^4N`03o`000?lo_coo?klo00Ko?klo00?o0000occ3??ll`c`03_ll`c`00ol0003oHYeR
of:MHP0=of:MHP03o`000?n?L8ooSg2?00SoSg2?00Co0000okA;]?ndBkCo]4^d1Ol00004on4Nh@03
o`000?od2oCom0_d00Wom0_d1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=on8MhP03o`000?o0?l3o`3o000Wo`3o0
0_l00009og^4N`03o`000?lo_coo?klo00Ko?klo00?o0000occ3??ll`c`03?ll`c`00ol0003oHYeR
of:MHP0?of:MHPKo00001?n?L8l4o`0000Gog2?L0_l000000ooQ7^7o0000oo@;m00;oo@;m004o`00
0?om0_goo@;mood2o@Oo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o_4>ooka3_onl@k`?o00002_oR7N800ol0003o
`3o0ol0o`009ol0o`003o`000?n?L8oo000000;o00001omkQ7/00ol0003o?kloocno?`05ocno?`03
o`000?ll`cco?<<l00So?<<l1Ol0000Aof:MHP03o`000?nOH9ooWf2O00?oWf2O1?l0000;om`Sg003
o`000?od2oCom0_d00[om0_d00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000onl@koo_4>l01Oo_4>l2o`0000OohQgR
00?o0000ol0o`?o0?l002_o0?l000ol0003oSg2?ohm`S`02ohm`S`?o00001OmkQ7/00ol0003o?klo
ocno?`04ocno?`04o`000?ll`cco?<<locc3?0Oo00001?m=/Td00ol0003oHYeRof:MHP0>of:MHP03
o`000?nOH9ooWf2O00OoWf2O00?o0000om`Sg?oL8m`02OoL8m`00ol0003om0_doo@;m009oo@;m003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003oka3_onl@k`08onl@k`;o00001?oR7N800ol0003o`3o0
ol0o`00;ol0o`003o`000?n?L8ooSg2?00GoSg2?0ol00003og^4N`04o`000?lo_coo?kloocno?`Ko
00003?m=/Td00ol0003oHYeRof:MHP0=of:MHP03o`000?nOH9ooWf2O00OoWf2O00?o0000om`Sg?oL
8m`02_oL8m`00ol0003om0_doo@;m008oo@;m003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=onl@k`?o000000?ohQgRo`000?o0?l00
3?o0?l000ol0003oSg2?ohm`S`08ohm`S`?o000000CoNhAko`000?l0003o00000_nCK9<00ol0003o
CK9=odfbC@0=odfbC@03o`000?mRWF;oHYeR00coHYeR00?o0000oimPWonOH9l02?nOH9l00ol0003o
g2?Lom`Sg00;om`Sg003o`000?od2oCom0_d00Kom0_d00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
ka3_00?o0000ol0o`?o0?l003?o0?l000ol0003oSg2?ohm`S`0;ohm`S`03o`000?nCK9?oTfbC00?o
TfbC00?o0000odfbCOm=/Td03?m=/Td00ol0003oD:m@o`00000=of:MHP03o`000?nOH9ooWf2O00So
Wf2O00?o0000om`Sg?oL8m`03?oL8m`3o`0000Gom0_d00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o_4>ooka3_00coka3_00?o0000ol0o`?o0?l003?o0?l000ol0003oSg2?ohm`S`0:ohm`S`03o`00
0?nCK9?oTfbC00GoTfbC00?o0000odfbCOm=/Td02_m=/Td01?l0003oD:m@oe2_D?m@[e02o`0000[o
HYeR00?o0000oimPWonOH9l02OnOH9l00ol0003og2?Lom`Sg00<om`Sg003o`000?of2OKomPWf00?o
000000?om0_do`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000ol0o`?o0?l00
3?o0?l000ol0003oSg2?ohm`S`09ohm`S`03o`000?nCK9?oTfbC00KoTfbC00?o0000odfbCOm=/Td0
2Om=/Td00ol0003oD:m@oe2_D002oe2_D003o`000?nDJiCo000000;o00001omRWF800ol0003oWf2O
oimPW`09oimPW`03o`000?oL8mcog2?L00_og2?L00?o0000ooH9m_of2OH01?of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000onl@koo_4>l02oo_4>l00ol0003o`3o0ol0o`00;ol0o`003o`000?n?
L8ooSg2?00SoSg2?00?o0000oi=/TonCK9<01onCK9<00ol0003oCK9=odfbC@08odfbC@03o`000?m@
[e3oD:m@00?oD:m@00?o0000oiA[U?nDJi@00_nDJi@2o`0000CoHYeR00?o0000oimPWonOH9l02_nO
H9l00ol0003og2?Lom`Sg00:om`Sg003o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o_4>ooka3_00[oka3_0ol0000;ol0o`0Ko00001?n?L8l00ol0003oTfbCoi=/T`08
oi=/T`03o`000?m=/TgoCK9=00OoCK9=00?o0000oe2_D?m@[e000om@[e000ol0003oU6^DoiA[U005
oiA[U0?o000000?oHYeRo`000?nOH9l02onOH9l00ol0003og2?Lom`Sg009om`Sg003o`000?of2OKo
mPWf00OomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o_4>ooka3_00Woka3_00?o0000om`S
g?oL8m`01?l00006ol0o`003o`000?nn@Kko_T6n00Co_T6n1?l0000<oi=/T`03o`000?m=/TgoCK9=
00GoCK9=00?o0000oe2_D?m@[e001?m@[e000ol0003oU6^DoiA[U008oiA[U003o`000?nOH9ooWf2O
00_oWf2O00?o0000om`Sg?oL8m`02?oL8m`00ol0003omPWfooH9mP08ooH9mPGo00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o_4>ooka3_00Ooka3_00?o0000om`Sg?oL8m`01OoL8m`3o`0000;o`3o000?o0000oki1__nn
@Kh02?nn@Kh00ol0003oTfbCoi=/T`0:oi=/T`03o`000?m=/TgoCK9=00CoCK9=00?o0000oe2_D?m@
[e001Om@[e000ol0003oU6^DoiA[U008oiA[U003o`000?nOH9ooWf2O00WoWf2O1?l00008om`Sg003
o`000?of2OKomPWf00WomPWf00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003oka3_
onl@k`05onl@k`03o`000?oL8mcog2?L00Wog2?L0_l0000<oki1_P03o`000?nCK9?oTfbC00WoTfbC
00?o0000odfbCOm=/Td00om=/Td00ol0003oD:m@oe2_D005oe2_D003o`000?nDJiCoU6^D00[oU6^D
00?o0000oimPWonOH9l01?nOH9l4o`0000CodbcC00?o0000om`Sg?oL8m`01?oL8m`00ol0003omPWf
ooH9mP0:ooH9mP03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o_4>ooka3_00?oka3_00?o0000om`Sg?oL8m`02ooL
8m`00ol0003o_T6noki1_P0:oki1_P03o`000?nCK9?oTfbC00WoTfbC00?o0000odfbCOm=/Td00_m=
/Td00ol0003oD:m@oe2_D006oe2_D003o`000?nDJiCoU6^D00[oU6^D00?o0000oimPWonOH9l01?l0
0009om</d`Ko00003?of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000onl@koo_4>ooka3_0_l0
000=om`Sg003o`000?nn@Kko_T6n00[o_T6n00?o0000oi=/TonCK9<02OnCK9<01Ol0003oCK9=odfb
COm=/Tgo000000WoD:m@00?o0000oiA[U?nDJi@02onDJi@2o`0000godbcC00?o0000oo8=l_ob3O80
0_ob3O800ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003oka3_o`00
0002ooL8m`;o00002ooL8m`00ol0003o_T6noki1_P0;oki1_P03o`000?nCK9?oTfbC00WoTfbC00?o
0000odfbCOl000002Om@[e000ol0003oU6^DoiA[U00<oiA[U003o`000?oC;=?odbcC00codbcC00?o
0000oo8=l_ob3O800oob3O800ol0003omPWfooH9mP09ooH9mP03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om`SgooL8m`03ooL8m`;o00002_oL8m`00ol0003o_T6noki1_P0:oki1_P03o`000?nCK9?o
TfbC00SoTfbC1Ol00008oe2_D003o`000?nDJiCoU6^D00coU6^D00?o0000om</dooC;=<02ooC;=<0
0ol0003olPgboo8=lP05oo8=lP03o`000?of2OKomPWf00SomPWf00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001oog2?L2o`0000Sog2?L00?o0000oki1__nn@Kh02_nn@Kh00ol0003oTfbCoi=/T`07oi=/
T`03o`000?nBKI;oTVfB00?oTVfB0ol00005oe2_D003o`000?nDJiCoU6^D00_oU6^D00?o0000om</
dooC;=<03?oC;=<00ol0003olPgboo8=lP06oo8=lP03o`000?of2OKomPWf00OomPWf00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Wom`Sg00?o0000om`Sg?oL8m`01OoL8m`2o`0000co
_T6n00?o0000oi=/TonCK9<01OnCK9<00ol0003oTVfBoi9]TP07oi9]TP?o000000?oD:m@o`000?nD
Ji@03OnDJi@00ol0003odbcCom</d`0<om</d`03o`000?ob3O;olPgb00KolPgb00?o0000ooH9m_of
2OH01_of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?og2?Oom`Sg00Oom`Sg
0_l00004om`Sg003o`000?oU6^GoiA[U00;o00002_nn@Kh00ol0003oTfbCoi=/T`03oi=/T`;o0000
3OnBKI82o`0000goU6^D0ol0000=om</d`03o`000?ob3O;olPgb00OolPgb00?o0000ooH9m_of2OH0
1Oof2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?og2?Oom`Sg00Som`Sg0_l0
00000ooL8mco0000onDJi@04onDJi@03o`000?nn@Kko_T6n00Oo_T6n00Co0000oi=/TonCK9?oTfbC
0_l00002ol4n`@03o`000?nBKI;oTVfB00coTVfB3Ol00003om0_d003o`000?oC;=?odbcC00[odbcC
00?o0000oo8=l_ob3O802?ob3O801?l0003omPWfooH9m_of2OH4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003om`Sg
ooL8m`09ooL8m`03o`000?oU6^GoiA[U00GoiA[U0_l00008oki1_P03o`000?nCK9?o000000Go`Ck1
00?o0000oi9]T_nBKI802onBKI800ol0003oXEjQoj5NX@09oj5NX@03o`000?o@;m3od2o@00;od2o@
0_l00009om</d`03o`000?ob3O;olPgb00[olPgb0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000onDJiOoU6^D01ooU6^D4o`0000?o_T6n0ol0
0007ol4n`@03o`000?nBKI;oTVfB00[oTVfB00?o0000oj5NXOnQGZ402OnQGZ400ol0003od2o@om0_
d004om0_d0;o00001ooC;=<00ol0003olPgboo8=lP0:oo8=lP03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU6^D02?oU6^D0
1?l0003oi1_Ton@Ki?oT6n@3o`0000;oebSG00?o0000ol4n`Oo1?/401_o1?/400ol0003oTVfBoi9]
TP08oi9]TP03o`000?nQGZ7oXEjQ00[oXEjQ00?o0000om0_d?o@;m001_o@;m000ol0003odbcCom</
d`04om</d`03o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooL8moog2?L01Oog2?L00ol0003oiA[UonDJi@08onDJi@03o`000?oT6nCo
i1_T00Coi1_T00Go0000omLXeooG:=OoebSGo`000008ol4n`@03o`000?nBKI;oTVfB00OoTVfB00?o
0000oj5NXOnQGZ402_nQGZ400ol0003od2o@om0_d007om0_d0;o00001?oC;=<00ol0003olPgboo8=
lP08oo8=lP03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L00oog2?L0
0ol0003oiA[UonDJi@08onDJi@03o`000?oT6nCoi1_T00Coi1_T00?o0000omLXeooG:=L00_oG:=L0
0ol0003o`Ck1ol4n`@07ol4n`@03o`000?nBKI;oTVfB00KoTVfB00?o0000oj5NXOnQGZ402_nQGZ40
0ol0003od2o@om0_d009om0_d005o`000?oC;=?odbcCom</dol000002Oob3O800ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oiA[U00?o0000on@Ki?oT6n@01?oT6n@00ol0003oebSGomLXe`03
omLXe`03o`000?o1?/7o`Ck100Oo`Ck100?o0000oi9]T_nBKI801OnBKI800ol0003oXEjQoj5NX@0:
oj5NX@03o`000?o@;m3od2o@00Wod2o@1?l00009oo8=lP03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?og2?Oom`Sg
ooL8mol000002_oU6^D00ol0003oi1_Ton@Ki005on@Ki003o`000?oG:=OoebSG00?oebSG00?o0000
ol4n`Oo1?/402?o1?/400ol0003oTVfBoi9]TP04oi9]TP03o`000?nQGZ7oXEjQ00WoXEjQ00?o0000
om0_d?o@;m002?o@;m02o`0000?ol`cc00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L00oog2?L00ol0003oiA[UonDJi@06onDJi@03o`000?oT6nCoi1_T
00Goi1_T00?o0000omLXeooG:=L01?oG:=L00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nBKI;oTVfB
00;oTVfB00?o0000oj5NXOnQGZ402_nQGZ400ol0003od2o@om0_d006om0_d0;o00001_oc3?<8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oU6^GoiA[U00GoiA[U00?o0000on@Ki?oT
6n@01OoT6n@00ol0003oebSGomLXe`05omLXe`03o`000?o1?/7o`Ck100Wo`Ck100Go0000oi9]T_nB
KI;oTVfBo`00000<oj5NX@03o`000?o@;m3od2o@00Cod2o@0_l00008oo<<l`03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU
6^D00ooU6^D00ol0003oi1_Ton@Ki006on@Ki003o`000?oG:=OoebSG00GoebSG00?o0000ol4n`Oo1
?/402_o1?/400ol0003oTVfBo`000004o`0000WoXEjQ00?o0000om0_d?o@;m000_o@;m02o`0000[o
l`cc00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003om`SgooL8m`07ooL8m`03o`00
0?oU6^GoiA[U00;oiA[U00?o0000on@Ki?oT6n@01_oT6n@00ol0003oebSGomLXe`07omLXe`;o0000
2oo1?/400ol0003og2?Lom`Sg003om`Sg0Oo00000_nQGZ400ol0003od2o@om0_d002o`0000_ol`cc
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooL8moog2?L02Oog
2?L01Ol0003oiA[UonDJiOoU6^Go000000Soi1_T00?o0000omLXeooG:=L01ooG:=L00ol0003ok1?/
o`000002o`0000So`Ck100?o0000om`Sg?oL8m`02_oL8m`5o`0000gol`cc00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooL8m`03o`000?oU6^Go000000Woi1_T00?o
0000omLXeooG:=L01_oG:=L00ol0003ok1?/on`Ck003on`Ck0?o00001?o1?/400ol0003og2?Lom`S
g00=om`Sg003o`000?oc3??ol`cc00gol`cc00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_om`Sg00?o0000on@Ki?oT6n@01ooT6n@00ol0003oebSGomLXe`07
omLXe`03o`000?o/4ncok1?/00Kok1?/0ol000000oo1?/7o0000om`Sg00>om`Sg003o`000?oc3??o
l`cc00col`cc00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooL8
m`03o`000?oT6nCoi1_T00;oi1_T1_l00008omLXe`03o`000?o/4ncok1?/00[ok1?/00?o0000om`S
g?oL8m`03ooL8m`00ol0003ol`ccoo<<l`0:oo<<l`;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooL8m`Go00001_od2o@00ol0003oebSGomLXe`05omLXe`03o`000?o/4ncok1?/00[o
k1?/00?o0000om`Sg?oL8m`03ooL8m`00ol0003ol`ccoo<<l`07oo<<l`?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooL8m`03o`000?od2oCom0_d00Wom0_d00?o0000omLXeooG
:=L00ooG:=L00ol0003ok1?/on`Ck00;on`Ck003o`000?oL8mcog2?L00oog2?L00?o0000oo<<looc
3?<01Ooc3?<2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?om`Sgo`000?l00000
3Ood2o@00ol0003oebSGomLXe`02omLXe`03o`000?o/4ncok1?/00_ok1?/5?l00004oo<<l`;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo@;m004o`000?oG:=OoebSGo`0000kok1?/
00?o0000ooH9m_of2OH04?of2OH00ol0003ol`cco`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_od2o@00ol0003oebSGo`00000>on`Ck003o`00
0?of2OKomPWf017omPWf00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003om0_doo@;m00=oo@;m003o`000?o/4ncok1?/00Wok1?/1Ol0
000BooH9mP;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003om0_doo@;m00<oo@;m003o`000?o/4ncok1?/00;ok1?/1ol00004ood2o@03o`000?of2OKo
mPWf00oomPWf00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?od2oCom0_d00com0_d1?l0000<ood2o@03o`000?of2OKomPWf00comPWf0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003oo@;mood2o@0=ood2o@03o`000?of2OKomPWf00_o
mPWf00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00koo@;m00?o0000ooH9m_of
2OH02Oof2OH2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo@;m?od2o@02_od2o@00ol0003oo@;m
ood2o@0?ood2o@03o`000?of2OKomPWf00KomPWf0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aood2o@?o00001_of2OH00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000oof2OH2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooH9m_l000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02Ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`09o`00o`;oool02?l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool02?l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000=o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`07o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000=o`00o`;oool01ol00?l2oooo00Oo003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
3Ol00?l2oooo00Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00Oo003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0<o`00o`?oool01ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00_o003o0oooo`08o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
0008o`00o`Goool02Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3
oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`0:o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0;o`00o`;oool02Ol00?l2oooo00Ko003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool03?l00?l2oooo00So003o0_ooo`06o`00o`;oool01_l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
6?l00?l2oooo00Go003o00?oool0o`00ool00?l01?l00?l2oooo00So003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?o
ool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00;o003o00?oool0o`00ool00?l01?l0
0?l2oooo00So003o0_ooo`07o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol0
0?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`03
o`00o`;oool00ol00?l2oooo00Oo003o1?ooo`08o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1W
o`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08?l00?l4oooo
00[o003o0_ooo`09o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(320) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.992 .008 .992 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.993 .007 .993 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.993 .007 .993 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.991 .009 .991 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.963 .037 .963 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.99 .01 .99 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.963 .037 .963 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.957 .043 .957 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.936 .064 .936 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.986 .014 .986 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.924 .076 .924 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.992 .008 .992 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.853 .147 .853 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.866 .134 .866 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.987 .013 .987 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.77 .23 .77 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.903 .097 .903 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.984 .016 .984 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.987 .013 .987 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.959 .041 .959 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.589 .411 .589 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.907 .093 .907 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.79 .21 .79 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.782 .218 .782 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.829 .171 .829 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.906 .094 .906 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.938 .062 .938 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.992 .008 .992 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.761 .239 .761 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.887 .113 .887 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.65 .35 .65 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.929 .071 .929 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.888 .112 .888 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.819 .181 .819 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.879 .121 .879 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.687 .313 .687 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.919 .081 .919 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.787 .213 .787 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.994 .006 .994 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.94 .06 .94 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.71 .29 .71 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.37 .63 .37 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.437 .563 .437 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.969 .031 .969 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.97 .03 .97 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.871 .129 .871 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.992 .008 .992 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.739 .261 .739 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.739 .261 .739 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.454 .546 .454 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.459 .541 .459 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.295 .705 .295 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.713 .287 .713 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.76 .24 .76 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.992 .008 .992 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.737 .263 .737 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.638 .362 .638 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.952 .048 .952 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.464 .536 .464 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.902 .098 .902 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.843 .157 .843 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.453 .547 .453 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.306 .694 .306 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.605 .395 .605 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.06 .94 .06 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.087 .913 .087 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.243 .757 .243 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.439 .561 .439 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.443 .557 .443 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.897 .103 .897 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.192 .808 .192 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.215 .785 .215 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.756 .244 .756 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.956 .044 .956 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.991 .009 .991 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.233 .767 .233 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.293 .707 .293 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.583 .417 .583 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.991 .009 .991 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.703 .297 .703 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.321 .679 .321 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.504 .496 .504 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.076 .924 .076 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.466 .534 .466 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.26 .74 .26 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.958 .042 .958 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.115 .885 .115 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.037 .963 .037 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.849 .151 .849 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.06 .94 .06 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.028 .972 .028 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.587 .413 .587 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.909 .091 .909 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.239 .761 .239 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.05 .95 .05 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.45 .55 .45 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.104 .896 .104 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.175 .825 .175 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.927 .073 .927 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.029 .971 .029 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.135 .865 .135 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.102 .898 .102 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.765 .235 .765 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.236 .764 .236 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.305 .695 .305 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.076 .924 .076 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.096 .904 .096 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.151 .849 .151 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.044 .956 .044 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.014 .986 .014 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.314 .686 .314 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.586 .414 .586 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.991 .009 .991 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.789 .211 .789 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.187 .813 .187 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.249 .751 .249 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.33 .67 .33 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.96 .04 .96 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.088 .912 .088 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.003 .997 .003 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.196 .804 .196 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.625 .375 .625 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.036 .964 .036 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.991 .009 .991 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.07 .93 .07 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.869 .131 .869 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.963 .037 .963 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.59 .41 .59 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.643 .357 .643 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.125 .875 .125 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.897 .103 .897 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.033 .967 .033 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.297 .703 .297 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.498 .502 .498 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.087 .913 .087 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.247 .753 .247 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.39 .61 .39 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.991 .009 .991 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.991 .009 .991 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.935 .065 .935 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.202 .798 .202 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.171 .829 .171 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.046 .954 .046 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.823 .177 .823 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.199 .801 .199 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.953 .047 .953 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.222 .778 .222 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.24 .76 .24 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.25 .75 .25 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.636 .364 .636 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.757 .243 .757 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.573 .427 .573 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.042 .958 .042 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.147 .853 .147 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.26 .74 .26 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.546 .454 .546 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.835 .165 .835 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.991 .009 .991 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.946 .054 .946 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.201 .799 .201 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.334 .666 .334 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.212 .788 .212 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.832 .168 .832 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.716 .284 .716 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.991 .009 .991 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.562 .438 .562 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.868 .132 .868 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.952 .048 .952 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.145 .855 .145 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.256 .744 .256 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.938 .062 .938 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.18 .82 .18 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.646 .354 .646 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.564 .436 .564 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.469 .531 .469 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.388 .612 .388 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.892 .108 .892 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.841 .159 .841 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.85 .15 .85 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.886 .114 .886 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.387 .613 .387 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.962 .038 .962 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.803 .197 .803 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.378 .622 .378 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.411 .589 .411 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.991 .009 .991 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.683 .317 .683 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.513 .487 .513 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.99 .01 .99 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.956 .044 .956 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.846 .154 .846 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.952 .048 .952 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.399 .601 .399 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.929 .071 .929 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.784 .216 .784 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.7 .3 .7 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.992 .008 .992 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.674 .326 .674 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.553 .447 .553 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.992 .008 .992 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.75 .25 .75 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.987 .013 .987 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.993 .007 .993 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.586 .414 .586 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.989 .011 .989 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.623 .377 .623 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.99 .01 .99 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.754 .246 .754 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.874 .126 .874 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.789 .211 .789 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.907 .093 .907 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.927 .073 .927 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.808 .192 .808 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.668 .332 .668 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.794 .206 .794 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.883 .117 .883 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.927 .073 .927 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.899 .101 .899 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.911 .089 .911 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.987 .013 .987 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.82 .18 .82 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.953 .047 .953 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.989 .011 .989 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.964 .036 .964 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.944 .056 .944 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.831 .169 .831 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.956 .044 .956 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.929 .071 .929 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.898 .102 .898 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.943 .057 .943 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.991 .009 .991 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.99 .01 .99 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.99 .01 .99 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.989 .011 .989 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.991 .009 .991 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003olPgboo8=l_l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo8=l_ob3O800_ob3O800ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00?olPgb00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo8=l_ob3O801Oob3O800ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003olPgboo8=lP06oo8=lP03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oe2_Go0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000colPgb00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooD:m@03o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oka3_onl@k`05onl@k`03o`000?ob
3O;olPgb00_olPgb0ol00003oo0?l003o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooD:mOoe2_D00ooe2_D00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003oka3_onl@k`06
onl@k`03o`000?ob3O;olPgb00[olPgb00?o0000oo0?l?o`3o001?o`3o000ol0003oo@;mood2o@0:
ood2o@04o`000?o]4^gokA;]ondBk@;o00002_om0_d2o`000003ondBkOl0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?om0_go
o@;m00Woo@;m00?o0000ooD:mOl000002oom0_d00ol0003oka3_onl@k`06onl@k`03o`000?ob3O;o
lPgb00WolPgb00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@08ood2o@03o`000?o]4^go
kA;]00CokA;]0_l00005ood2o@?o00001?o]4^d00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008ooD:m@03o`000?om0_goo@;m00Ooo@;m0_l00003ooD:
m@03o`000?om0_goo@;m00Ooo@;m00?o0000onl@koo_4>l01oo_4>l00ol0003olPgboo8=lP09oo8=
lP03o`000?o`3o3ol0o`00Ool0o`00?o0000ood2oOom0_d01Oom0_d2o`0000WokA;]0_l000000oom
0_go0000o`000007ondBk@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000ooD:mOoe
2_D02?oe2_D00ol0003oo@;mood2o@06ood2o@03o`000?oe2_Gom@[e00?om@[e00?o0000ood2oOom
0_d01oom0_d00ol0003oka3_onl@k`08onl@k`03o`000?ob3O;olPgb00OolPgb00?o0000oo0?l?o`
3o002Oo`3o000ol0003oo@;mood2o@03ood2o@03o`000?o]4^gokA;]00_okA;]00?o0000ondBkOo]
4^d01oo]4^d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003ol`cco`000005ood2o@;o00002ooe2_D2o`0000Koo@;m
00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oo@;mood2o@06ood2o@03o`000?o_4>ooka3_00Soka3_
00?o0000oo8=l_ob3O801_ob3O800ol0003ol0o`oo0?l00;oo0?l005o`000?om0_goo@;mood2oOl0
00003_o]4^d00ol0003okA;]ondBk@08ondBk@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?oc3??ol`ccoo<<lol0
00000oom0_d00ol0003om@[eooD:m@0:ooD:m@04o`000?oX5nSoj1OXo`0000?oo@;m0_l00008ooD:
m@03o`000?om0_goo@;m00Koo@;m00?o0000onl@koo_4>l02Oo_4>l00ol0003olPgboo8=lP05oo8=
lP03o`000?o`3o3ol0o`00col0o`00?o0000ood2oOl000003oo]4^d00ol0003okA;]ondBk@08ondB
k@03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<l`03oo<<l`03o`000?om0_go000000_o
m@[e0_l00004onPGj003o`000?om0_go000000_om@[e00?o0000ood2oOom0_d01Oom0_d00ol0003o
ka3_onl@k`09onl@k`03o`000?ob3O;olPgb00ColPgb00?o0000oo0?l?o`3o003_o`3o000ol0003o
kA;]ondBk@0>ondBk@03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo<<looc3?<0
1?oc3?<00ol0003om@[eooD:m@09ooD:m@03o`000?oX5nSoj1OX00Goj1OX00?o0000ooD:mOoe2_D0
2_oe2_D00ol0003oo@;mood2o@05ood2o@03o`000?o_4>ooka3_00[oka3_00?o0000oo8=l_ob3O80
0oob3O800ol0003ol0o`oo0?l00>oo0?l003o`000?o]4^gokA;]00gokA;]00?o0000ondBkOo]4^d0
2_o]4^d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ol`ccoo<<
l`05oo<<l`03o`000?oe2_Gom@[e00Oom@[e0_l00008onPGj003o`000?oe2_Gom@[e00_om@[e00?o
0000ood2oOom0_d01?om0_d00ol0003oka3_onl@k`0:onl@k`04o`000?ob3O;olPgboo8=lP?o0000
3oo`3o000ol0003okA;]ondBk@0>ondBk@03o`000?o]4^gokA;]00[okA;]00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_om0_d00ol0003oo@;mood2
o@09ood2o@03o`000?oc3??ol`cc00Ool`cc00?o0000ooD:mOoe2_D01?oe2_D2o`0000_oj1OX1?l0
0009ooD:m@03o`000?om0_goo@;m00?oo@;m00?o0000onl@koo_4>l02oo_4>l01?l0003olPgbo`00
0?l00003om@[e0;o00003?o`3o02o`00013okA;]00?o0000ondBkOo]4^d02oo]4^d00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d02?om0_d00ol0003ol`cc
oo<<l`07oo<<l`03o`000?oe2_Gom@[e00?om@[e00?o0000onPGj?oX5nP02ooX5nP01?l0003obCK9
olTfbOo9=/T5o`0000Gom@[e00?o0000ood2oOom0_d00_om0_d00ol0003oka3_onl@k`0<onl@k`03
o`000?oD:mCoe2_D00Goe2_D0_l00008oo0?l0;o00000_o=</d00ol0003okA;]ondBk@0=ondBk@03
o`000?o]4^gokA;]00_okA;]00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[oo@;m
00?o0000ood2oOom0_d01oom0_d00ol0003ol`ccoo<<l`09oo<<l`03o`000?oe2_Gom@[e00;o0000
3OoX5nP00ol0003obCK9olTfb@07olTfb@Ko00000_om0_d4o`0000goka3_00?o0000om@[e?oD:m@0
1ooD:m@2o`0000Gol0o`00?o0000oldbcOo=</d00oo=</d00ol0003okA;]ondBk@0<ondBk@03o`00
0?o]4^gokA;]00cokA;]00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?oc3??ol`cc00Wol`cc00?o
0000ooD:mOl000003ooX5nP00ol0003obCK9olTfb@0<olTfb@?o00001?oU6^D3o`0000Woka3_00?o
0000om@[e?oD:m@02_oD:m@2o`000003oo0?l?l0003o000000OocC;=00?o0000ondBkOo]4^d02oo]
4^d00ol0003okA;]ondBk@0<ondBk@03o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?oc3??ol`cc00_ol`cc00?o0000
onPGj?oX5nP03_oX5nP00ol0003obCK9olTfb@0=olTfb@03o`000?oU6^GoiA[U00KoiA[U0ol00005
onl@k`03o`000?oD:mCoe2_D00goe2_D00?o0000oldbcOo=</d02?o=</d00ol0003okA;]ondBk@09
ondBk@03o`000?o]4^gokA;]00gokA;]00Co0000ood2oOom0_goo@;m1Ol00003oo4>l@03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000
oo<<looc3?<02ooc3?<2o`0000ooj1OX00?o0000olTfbOo9=/T03Oo9=/T00ol0003oiA[UonDJi@0:
onDJi@?o000000?oka3_o`000?oD:m@03ooD:m@00ol0003ocC;=oldbc@09oldbc@03o`000?o]4^go
kA;]00SokA;]00?o0000ondBkOo]4^d03_o]4^d3o`0000Sol@ka00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00[oo@;m0_l00003ood2o@03o`000?oc3??ol`cc00Sol`cc0ol000000ooG
:=Oo0000onPGj00>onPGj003o`000?o9=/WobCK900gobCK900?o0000onDJiOoU6^D03OoU6^D00ol0
003oe2_Dom@[e00?om@[e003o`000?o=</gocC;=00[ocC;=2ol0000;ondBk@Go00003?oa3_400ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02_om0_d01Ol0003ol0o`o`000?om0_go0000
00Sol`cc0ol00005omLXe`03o`000?oX5nSoj1OX00coj1OX00?o0000olTfbOo9=/T03Oo9=/T00ol0
003oiA[UonDJi@0=onDJi@;o00004?oD:m@00ol0003ocC;=oldbc@0:oldbc@03o`000?o8=lSob3O8
00Oob3O800?o0000ondBkOo]4^d00_o]4^d7o`0000CocS7>00?o0000oo4>lOoa3_402_oa3_400ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d01?l0003ol0o`oo0?l?o`3o02o`00
00Gol`cc0ol00009omLXe`;o00002ooX5nP00ol0003obCK9olTfb@0=olTfb@03o`000?oU6^GoiA[U
00goiA[U00Co0000ol4n`Oo1?/7o00003ooD:m@00ol0003ocC;=oldbc@09oldbc@03o`000?o8=lSo
b3O800Wob3O81?l0000;olhacP03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?om0_goo@;m00Soo@;m00?o0000oo0?l?o`3o001?o`3o000ol0003ol`cco`000002o`00
00coebSG00Co0000ok=</ol0003o00002OoX5nP00ol0003obCK9olTfb@0=olTfb@03o`000?oU6^Go
iA[U00goiA[U00Go0000ol4n`Oo1?/7o`Ck1o`00000=om@[e003o`000?o=</gocC;=00[ocC;=00?o
0000olPgb?o8=lP02Oo8=lP00ol0003ocS7>olhacP0<olhacP03o`000?oa3_7ol@ka00[ol@ka00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00Ooo@;m00?o0000oo0?l?o`3o001_o`3o00
0ol0003oebSGomLXe`0<omLXe`03o`000?ncC;?o/dbc00;o/dbc0_l00007onPGj003o`000?o9=/Wo
bCK900cobCK900?o0000onDJiOoU6^D03OoU6^D00ol0003o`Ck1ol4n`@03ol4n`@03o`000?oD:mCo
e2_D00[oe2_D00?o0000oldbcOo=</d02_o=</d00ol0003ob3O8olPgb009olPgb003o`000?o><Lko
cS7>00cocS7>00?o0000oo4>lOoa3_402ooa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2
oOom0_d01_om0_d00ol0003ol0o`oo0?l006oo0?l003o`000?oG:=OoebSG00_oebSG00?o0000ok=<
/oncC;<01OncC;<00ol0003oj1OXonPGj003onPGj003o`000?o9=/WobCK900gobCK900?o0000onDJ
iOoU6^D03OoU6^D00ol0003o`Ck1ol4n`@04ol4n`@03o`000?oD:mCoe2_D00Woe2_D00?o0000oldb
cOo=</d02Oo=</d00ol0003ob3O8olPgb00:olPgb003o`000?o><LkocS7>00cocS7>00?o0000oo4>
lOoa3_402ooa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d01Oom0_d00ol0003o
l0o`oo0?l007oo0?l003o`000?oG:=OoebSG00_oebSG00?o0000ok=</oncC;<01_ncC;<2o`0000?o
j1OX00?o0000olTfbOo9=/T03Oo9=/T00ol0003oiA[UonDJi@0<onDJi@03o`000?o1?/7o`Ck100Ko
`Ck100?o0000om@[e?oD:m@02?oD:m@00ol0003ocC;=oldbc@09oldbc@03o`000?o8=lSob3O800[o
b3O800?o0000olhac_o><Lh03?o><Lh00ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?om0_goo@;m00Coo@;m00?o0000oo0?l?o`3o002?o`3o000ol0003oebSGomLXe`0:omLXe`03o`00
0?ncC;?o/dbc00Wo/dbc0_l000000ooX5nSo0000olTfb@0<olTfb@?o00003_oU6^D00ol0003o`Ck1
ol4n`@07ol4n`@03o`000?oD:mCoe2_D00Ooe2_D00?o0000oldbcOo=</d02Oo=</d00ol0003ob3O8
olPgb00;olPgb003o`000?o><LkocS7>00cocS7>00?o0000oo4>lOoa3_402_oa3_400ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000oo0?l?o`3o002_o`3o000ol0003oebSGomLX
e`09omLXe`03o`000?ncC;?o/dbc00_o/dbc00?o0000olTfbOo9=/T02_o9=/T2o`0000?oWenO00?o
0000onDJiOoU6^D02_oU6^D00ol0003o`Ck1ol4n`@09ol4n`@03o`000?oD:mCoe2_D00Koe2_D00?o
0000oldbcOo=</d02?o=</d00ol0003ob3O8olPgb00<olPgb003o`000?o><LkocS7>00cocS7>00?o
0000oo4>lOoa3_402_oa3_400ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003oo@;mood2o@02ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omLXeooG:=L02?oG:=L0
0ol0003o/dbcok=</`0<ok=</`03o`000?o9=/WobCK900SobCK90_l00006oimOW`;o00002_oU6^D0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?oD:mCoe2_D00Goe2_D00?o0000oldbcOo=</d02?o=</d0
0ol0003ob3O8olPgb00<olPgb003o`000?o><LkocS7>00cocS7>00?o0000oo4>lOoa3_402ooa3_40
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ood2oOom0_goo@;mo`00000=
oo0?l003o`000?oG:=OoebSG00OoebSG00?o0000ok=</oncC;<03_ncC;<00ol0003obCK9olTfb@04
olTfb@?o00002_nOGil00ol0003oiA[UonDJi@07onDJi@03o`000?o1?/7o`Ck100_o`Ck100?o0000
om@[e?oD:m@00ooD:m@00ol0003ocC;=oldbc@09oldbc@03o`000?o8=lSob3O800cob3O800?o0000
olhac_o><Lh03?o><Lh00ol0003ol@kaoo4>l@0;oo4>l@;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_om0_d00ol0
003ol0o`oo0?l00<oo0?l003o`000?oG:=OoebSG00OoebSG00?o0000ok=</oncC;<03oncC;<01?l0
003obCK9olTfbOo9=/T2o`0000koWenO0_l00006onDJi@03o`000?o1?/7o`Ck100go`Ck100?o0000
om@[e?oD:m@00_oD:m@00ol0003ocC;=oldbc@08oldbc@03o`000?o8=lSob3O800cob3O80ol0000=
olhacP03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?om0_go0000
00ool0o`00?o0000omLXeooG:=L01_oG:=L00ol0003o/dbcok=</`0@ok=</`Co00004_nOGil00ol0
003oiA[UonDJi@03onDJi@03o`000?o1?/7o`Ck100ko`Ck100Go0000om@[e?oD:mCoe2_Do`000005
oldbc@Oo00003?o8=lP01Ol0003oWf2OoimPWonOH9oo000000cocS7>00?o0000oo4>lOoa3_402?oa
3_43o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ool0o`00?o0000omLXeooG:=L01_oG:=L00ol0003o/dbcok=</`0=
ok=</`?o000000CoMhQgo`000?l0003o00004onOGil2o`0000;oiA[U00?o0000ol4n`Oo1?/404?o1
?/400ol0003oe2_Do`000006o`0000Oo[U6^00?o0000olPgb?o8=lP02?o8=lP00ol0003oWf2OoimP
W`03oimPW`;o00002?o><Lh3o`0000Kol@ka1?l00002ondBk@03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003om@[eo`000?oA;]43o`0000gol0o`00?o0000omLXeooG:=L01?oG:=L00ol0003o/dbcok=<
/`0;ok=</`?o00000omgR7L01Ol0003oLhaco`000?m>/Dko000001CoWenO00?o0000onDJiOl00000
4oo1?/400ol0003o[U6^ojiA[P0=ojiA[P03o`000?o8=lSob3O800Gob3O80_l00008oimPW`03o`00
0?o><LkocS7>00Go00000oo;=</00ol0003ol@kaoo4>l@03o`0000OokA;]00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?oe2_Gom@[eo`0000CodBkA0ol0000:oo0?l003o`000?oG:=OoebSG00?oebSG
00?o0000ok=</oncC;<02OncC;<3o`0000GoMhQg00Co0000og><LomcS7?o00000_m>/Dh00ol0003o
WenOoimOW`0BoimOW`03o`000?o1?/7o`Ck101;o`Ck100?o0000ojiA[_n^DJh03_n^DJh00ol0003o
b3O8olPgb003olPgb003o`000?nOH9ooWf2O00WoWf2O0_l00009ol/db`;o00002_o]4^d00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000ooD:mOoe2_Gom@[eo`000007om4^d@;o00001oo`3o05o`0000;o
ebSG00?o0000ok=</oncC;<01_ncC;<3o`0000SoMhQg00Co0000og><LomcS7?o00000om>/Dh00ol0
003oWenOoimOW`0AoimOW`03o`000?o1?/7o`Ck1017o`Ck100?o0000ojiA[_n^DJh04?n^DJh01Ol0
003ob3O8olPgb?o8=lSo000000coWf2O00?o0000ol/dboo;=</02?o;=</00ol0003okA;]ondBk@0:
ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Com@[e00?o0000om4^dOoA;]401ooA;]43o`00
0004oo0?l?l0003o0000o`0000Go_4>l0_l00006ok=</`?o00002_mgR7L01Ol0003oLhacog><Lomc
S7?o000000CoC[5>00?o0000oimOWonOGil04?nOGil00ol0003o`Ck1ol4n`@0Aol4n`@03o`000?n^
DJko[U6^017o[U6^00?o0000olPgb?l000003OnOH9l00ol0003obcC;ol/db`08ol/db`03o`000?o]
4^gokA;]00[okA;]00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?oe2_Gom@[e00Com@[e00?o0000
om4^dOoA;]402_oA;]400ol0003o_4>loka3_008oka3_003o`000?ncC;?o/dbc00?o00003OmgR7L0
1Ol0003oLhacog><LomcS7?o000000GoC[5>00?o0000oimOWonOGil03onOGil00ol0003o`Ck1ol4n
`@0Aol4n`@03o`000?n^DJko[U6^01;o[U6^00?o0000oimPWonOH9l03?nOH9l00ol0003obcC;ol/d
b`08ol/db`03o`000?o]4^gokA;]00_okA;]00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000ooD:mOoe2_D01Ooe2_D0
0ol0003odBkAom4^d@0:om4^d@03o`000?nl@kco_4>l00Wo_4>l0_l0000?ogN8M`03o`000?mcS7?o
Lhac00;oLhac00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oWenOoimOW`0=oimOW`?o00004Oo1?/40
0ol0003o[U6^ojiA[P0CojiA[P03o`000?nOH9ooWf2O00_oWf2O00?o0000ol/dboo;=</02Oo;=</0
0ol0003okA;]ondBk@0;ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?oe2_D0
0ol0003odBkAom4^d@0:om4^d@03o`000?nl@kco_4>l00Wo_4>l00?o0000ogN8MomgR7L03OmgR7L0
0ol0003oLhacog><L`03og><L`03o`000?m>/DkoC[5>00GoC[5>00?o0000oimOWonOGil02_nOGil2
o`0000?oOh1o00?o0000ol4n`Oo1?/403_o1?/400ol0003o[U6^ojiA[P0CojiA[P03o`000?nOH9oo
Wf2O00_oWf2O00?o0000ol/dboo;=</02Oo;=</00ol0003okA;]ondBk@0;ondBk@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000ooD:mOoe2_D01ooe2_D2o`0000_odBkA00?o0000oka3
_?nl@k`02onl@k`00ol0003oMhQgogN8M`0<ogN8M`03o`000?mcS7?oLhac00?oLhac00?o0000odja
C_m>/Dh01_m>/Dh00ol0003oWenOoimOW`07oimOW`;o00001_moP7l2o`0000ko`Ck100?o0000ojiA
[_n^DJh04on^DJh00ol0003oWf2OoimPW`0;oimPW`03o`000?o;=<_obcC;00WobcC;00?o0000ondB
kOo]4^d03?o]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009ooD:
m@03o`000?oX5nSo000000_odBkA00?o0000oka3_?nl@k`02onl@k`00ol0003oMhQgogN8M`0;ogN8
M`03o`000?mcS7?oLhac00CoLhac00?o0000odjaC_m>/Dh01om>/Dh00ol0003oWenOoimOW`05oimO
W`03o`000?moP7ooOh1o00SoOh1o00?o0000ol4n`Oo1?/402_o1?/400ol0003o[U6^ojiA[P0DojiA
[P03o`000?nOH9ooWf2O00_oWf2O00?o0000ol/dboo;=</02Oo;=</00ol0003okA;]ondBk@0<ondB
k@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009ooD:m@04o`000?oX5nSoj1OXo`00
00_odBkA00?o0000oka3_?nl@k`02onl@k`00ol0003oMhQgogN8M`0;ogN8M`03o`000?mcS7?oLhac
00CoLhac00?o0000odjaC_m>/Dh02?m>/Dh00ol0003oWenOoimOW`02oimOW`;o00003?moP7l2o`00
00[o`Ck100?o0000ojiA[_n^DJh05?n^DJh00ol0003oWf2OoimPW`0;oimPW`03o`000?o;=<_obcC;
00WobcC;00?o0000ondBkOo]4^d03Oo]4^d00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003om@[eooD:m@07ooD:m@03
o`000?oX5nSoj1OX00;oj1OX00?o0000om4^dOoA;]402?oA;]400ol0003o_4>loka3_00<oka3_003
o`000?mgR7OoMhQg00WoMhQg00?o0000og><LomcS7<01OmcS7<00ol0003oC[5>odjaCP09odjaCP04
o`000?nOGioo0000o`00013oOh1o0_l00008ol4n`@03o`000?n^DJko[U6^01Co[U6^0ol0000;oimP
W`03o`000?o;=<_obcC;00WobcC;00?o0000ondBkOo]4^d03Oo]4^d01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003om@[eooD:m@06ooD:m@03o`000?oX5nSoj1OX00?oj1OX00?o0000om4^
dOoA;]402?oA;]400ol0003o_4>loka3_00;oka3_0;o00002_mgR7L00ol0003oLhacog><L`06og><
L`03o`000?m>/DkoC[5>00[oC[5>00?o0000ogn0OomoP7l04_moP7l00ol0003o`Ck1ol4n`@04ol4n
`@03o`000?n^DJko[U6^01Go[U6^00?o0000oiIYU_nFJIH01Ol00005oimPW`03o`000?o;=<_obcC;
00[obcC;00?o0000ondBkOo]4^d03_o]4^d3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@04ooD:m@03
o`000?oX5nSoj1OX00Coj1OX00?o0000om4^dOoA;]401ooA;]400ol0003o_4>loka3_00;oka3_004
o`000?mcS7?oLhaco`0000WoMhQg00?o0000og><LomcS7<01_mcS7<00ol0003oC[5>odjaCP0:odja
CP03o`000?moP7ooOh1o01?oOh1o0_l00003ol4n`@Co00005?n^DJh00ol0003oUVVFoiIYUP06oiIY
UPCo000000?oWf2Oo`000?o;=</02oo;=</00ol0003okA;]ondBk@0>ondBk@03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003om@[eooD:m@03ooD:m@03o`000?oX5nSoj1OX00Goj1OX00?o0000om4^dOoA
;]401ooA;]400ol0003o_4>loka3_009oka3_0;o00001?mcS7<00ol0003oMhQgogN8M`05ogN8M`03
o`000?mcS7?oLhac00OoLhac00?o0000odjaC_m>/Dh02_m>/Dh00ol0003oOh1oogn0O`0Eogn0O`03
o`000?o1?/7o000000CoT6n@0ol0000@ojiA[P03o`000?nFJIKoUVVF00_oUVVF0_l0000<ol/db`03
o`000?o]4^gokA;]00cokA;]0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D00_oe2_D00ol0003oj1OX
onPGj006onPGj003o`000?oA;]7odBkA00OodBkA00?o0000oka3_?nl@k`02?nl@k`00ol0003oLhac
og><L`05og><L`03o`000?mgR7OoMhQg00CoMhQg00?o0000og><LomcS7<01omcS7<00ol0003oC[5>
odjaCP0:odjaCP03o`000?moP7ooOh1o01KoOh1o00?o0000oi1_T?n@Ki001_n@Ki03o`0000co[U6^
00?o0000oiIYU_nFJIH03OnFJIH00ol0003obcC;ol/db`09ol/db`Go00002Oo]4^d2o`000003oo4>
lOl0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooD:mOl0003oj1OX00Woj1OX00?o0000om4^dOoA;]401_oA
;]400ol0003o_4>loka3_007oka3_003o`000?mcS7?oLhac00OoLhac00?o0000ogN8MomgR7L00_mg
R7L00ol0003oLhacog><L`08og><L`03o`000?m>/DkoC[5>00WoC[5>00?o0000ogn0OomoP7l05omo
P7l00ol0003oT6n@oi1_T009oi1_T0?o00002On^DJh00ol0003oUVVFoiIYUP0>oiIYUPKo00001?o;
=</00ol0003oe2_Dom@[e003om@[e0Go00000_o]4^d2o`0000Col@ka00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o/4ncok1?/on`Ck?l000002ooX5nP00ol0003odBkAom4^d@06om4^d@03o`000?nl
@kco_4>l00Go_4>l0_l0000;og><L`04o`000?mgR7OoMhQgo`0000_oLhac00?o0000odjaC_m>/Dh0
2Om>/Dh00ol0003oOh1oogn0O`0Fogn0O`03o`000?n@Ki3oT6n@00goT6n@0ol00005ojiA[P03o`00
0?nFJIKoUVVF00ooUVVF00?o0000oj]DZon[E:/00on[E:/4o`0000_oe2_D0_l00006oo4>l@03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ok1?/on`Ck002on`Ck0ko00001_oA;]400ol0003o_4>loka3
_005oka3_003o`000?mcS7?oLhac00coLhac00?o0000ogN8Mol000002omcS7<00ol0003oC[5>odja
CP07odjaCP?o00006?moP7l00ol0003oT6n@oi1_T00@oi1_T0?o000000?o[U6^o`000?nFJIH04?nF
JIH00ol0003oZeB[oj]DZ`07oj]DZ`03o`000?oD:mCoe2_D00[oe2_D00?o0000oo4>lOoa3_401Ooa
3_400ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005on`Ck003o`000?o:=L[obSG:00_obSG:0_l00004
om4^d@03o`000?nl@kco_4>l00?o_4>l0_l0000@og><L`03o`000?mcS7?oLhac00[oLhac00?o0000
odjaC_m>/Dh00om>/Dh4o`0000;o;m0_00?o0000ogn0OomoP7l05OmoP7l00ol0003oT6n@oi1_T00D
oi1_T003o`000?nFJIKoUVVF013oUVVF00?o0000oj]DZon[E:/01on[E:/00ol0003oe2_Dom@[e00:
om@[e003o`000?oa3_7ol@ka00Gol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o/4ncok1?/
00Gok1?/00?o0000olXeb_o:=LX03Oo:=LX6o`0000?o_4>l00?o0000og><LomcS7<04?mcS7<00ol0
003oLhacog><L`0:og><L`03o`000?m>/Dko000000?o00001ol_d2l00ol0003oOh1oogn0O`0Dogn0
O`03o`000?n@Ki3oT6n@01CoT6n@00?o0000oiIYU_nFJIH03onFJIH00ol0003oZeB[oj]DZ`08oj]D
Z`03o`000?oD:mCoe2_D00[oe2_D00?o0000oo4>lOoa3_401Ooa3_400ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000on`Ck?o/4n`01_o/4n`00ol0003obSG:olXebP0=olXebP03o`000?n_D:oo[e2_00?o
[e2_00?o0000oka3_?l000004omcS7<4o`0000WoLhac0_l0000<obo@;`03o`000?moP7ooOh1o01?o
Oh1o00?o0000oi1_T?n@Ki005On@Ki000ol0003oUVVFoiIYUP0>oiIYUP03o`000?n[E:_oZeB[00So
ZeB[00?o0000om@[e?oD:m@02OoD:m@00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o/4ncok1?/00Sok1?/00?o0000olXeb_o:=LX02oo:=LX00ol0003o[e2_ojm@[`05ojm@[`03o`00
0?mcS7?oLhac01;oLhac00Co0000ocg2?Olm`Sgo?L8m1Ol00003og><L`03o`000?l_d2oo;m0_00go
;m0_0ol0000@ogn0O`;o00006?n@Ki000ol0003oUVVFoiIYUP0=oiIYUP03o`000?n[E:_oZeB[00Wo
ZeB[00?o0000om@[e?oD:m@02OoD:m@00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ok1?/00?o0000olXeb_o:=LX02_o:=LX00ol0003o[e2_ojm@[`06ojm@[`03o`00
0?mcS7?oLhac017oLhac00?o0000ocg2?Olm`Sd01olm`Sd3o`00013o;m0_00?o0000oaoO7olOgal0
1Ol00009ogn0O`;o000000?o><Lho`000?n@Ki005on@Ki000ol0003oUVVFoiIYUP0=oiIYUP03o`00
0?n[E:_oZeB[00WoZeB[00?o0000om@[e?oD:m@02?oD:m@2o`0000[ol@ka00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?of2OKomPWf00;omPWf00?o0000on`Ck?o/4n`02Oo/4n`00ol0003obSG:olXe
bP0:olXebP03o`000?n_D:oo[e2_00Oo[e2_00?o0000og><LomcS7<03omcS7<00ol0003o?L8mocg2
?@0:ocg2?@03o`000?l_d2oo;m0_00go;m0_00?o0000oaoO7olOgal01_lOgal4o`0000CoOh1o00?o
0000ocS7>?lhacP00_lhacP00ol0003oT6n@oi1_T00Foi1_T003o`000?nFJIKoUVVF00_oUVVF00?o
0000oj]DZon[E:/02on[E:/00ol0003oe2_Dom@[e006om@[e003o`000?oU6^Go000000[ol@ka00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?of2OKomPWf00?omPWf00?o0000on`Ck?o/4n`02?o/4n`=
o`0000[o[e2_00?o0000og><LomcS7<03omcS7<00ol0003o?L8mocg2?@0;ocg2?@03o`000?l_d2oo
;m0_00co;m0_00?o0000oaoO7olOgal02_lOgal4o`0000Go><Lh00?o0000oi1_T?n@Ki005_n@Ki00
0ol0003oUVVFoiIYUP0:oiIYUP03o`000?n[E:_oZeB[00coZeB[00?o0000om@[e?oD:m@01?oD:m@2
o`0000?oiA[U00?o0000oo4>lOoa3_402?oa3_400ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooH9
m_of2OH00oof2OH00ol0003ok1?/on`Ck007on`Ck003o`000?o8=lSob3O800Wob3O800?o0000ojm@
[on_D:l02On_D:l00ol0003oLhacog><L`0=og><L`03o`000?lm`Sgo?L8m00co?L8m00?o0000obo@
;ol_d2l03?l_d2l00ol0003o7mlOoaoO7`0;oaoO7`03o`000?l;m0_o000000Ko><Lh00?o0000oi1_
T?n@Ki005_n@Ki000ol0003oUVVFoiIYUP09oiIYUP03o`000?n[E:_oZeB[00coZeB[00?o0000om@[
e?oD:m@00ooD:m@00ol0003oiA[UonDJi@03onDJi@03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?of2OKomPWf00ComPWf00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
b3O8olPgb008olPgb003o`000?n_D:oo[e2_00_o[e2_00?o0000og><LomcS7<02?mcS7<4o`0000oo
?L8m00?o0000obo@;ol_d2l02ol_d2l00ol0003o7mlOoaoO7`0;oaoO7`04o`000?l;m0_o2o@;o`00
00Oo><Lh00?o0000oi1_T?n@Ki005On@Ki000ol0003oUVVFoiIYUP08oiIYUP03o`000?n[E:_oZeB[
00goZeB[00?o0000om@[e?oD:m@00_oD:m@00ol0003oiA[UonDJi@05onDJi@03o`000?oa3_7ol@ka
00Ool@ka00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?of2OKomPWf00GomPWf00?o0000on`Ck?o/
4n`01Oo/4n`00ol0003ob3O8olPgb008olPgb003o`000?n_D:oo[e2_00_o[e2_00?o0000og><Lomc
S7<00omcS7<5o`0000?o?/4n00?o0000ocg2?Olm`Sd03_lm`Sd00ol0003o;m0_obo@;`0:obo@;`03
o`000?lOgaoo7mlO00[o7mlO00Go0000o`_d2ol;m0_o2o@;o`000007ocS7>003o`000?n@Ki3oT6n@
01GoT6n@00?o0000oiIYU_nFJIH02?nFJIH00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?oD:mCoe2_D
00;o00002?oU6^D00ol0003ol@kaoo4>l@08oo4>l@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`000?o/4ncok1?/00Go
k1?/00?o0000olPgb?o8=lP02?o8=lP00ol0003o[e2_ojm@[`0<ojm@[`Go00002Oln`Ch00ol0003o
?L8mocg2?@0<ocg2?@;o00003?l_d2l00ol0003o7mlOoaoO7`0:oaoO7`05o`000?l;m0_o2o@;o`_d
2ol000002?lhacP00ol0003oT6n@oi1_T00Doi1_T0?o00001onFJIH00ol0003oZeB[oj]DZ`0>oj]D
Z`03o`000?oD:mCo000000_oiA[U00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooH9m_of2OH01Oof2OH00ol0003ok1?/on`Ck004on`Ck003o`000?o8=lSob3O800Oo
b3O800?o0000ojm@[on_D:l03?n_D:l01?l0003oM8]dogB;M?l0000;ock1?P03o`000?lm`Sgo?L8m
00_o?L8m00Co0000o`Oh1ol7n0Oo00002_l_d2l00ol0003o7mlOoaoO7`0:oaoO7`03o`000?l;m0_o
2o@;00;o2o@;00?o0000ocS7>?lhacP01_lhacP00ol0003oT6n@oi1_T00Aoi1_T0?o00000omPWf00
0ol0003oUVVFoiIYUP04oiIYUP03o`000?n[E:_oZeB[00goZeB[1?l0000;onDJi@03o`000?oa3_7o
l@ka00Gol@ka00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?of2OKomPWf00KomPWf00Co0000on`C
k?o/4ncok1?/1?l00008olPgb003o`000?n_D:oo[e2_00_o[e2_00?o0000ogB;M?mdRg@00_mdRg@0
0ol0003o?/4nock1?P08ock1?P03o`000?lm`Sgo?L8m00[o?L8m00?o0000o`Oh1ol7n0L00_l7n0L0
0ol0003o;m0_obo@;`03obo@;`Go00002olOgal00ol0003o2o@;o`_d2`03o`_d2`03o`000?lhacSo
><Lh00Oo><Lh00?o0000oi1_T?n@Ki003_n@Ki02o`0000OoH9mP00?o0000oiIYU_nFJIH00_nFJIH0
0ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?oA;]7odBkA00;odBkA00?o0000onDJiOoU6^D02OoU6^D0
0ol0003ol@kaoo4>l@03oo4>l@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003omPWfooH9mP07ooH9
mP?o00001?oJ9MX00ol0003ob3O8olPgb005olPgb003o`000?n_D:oo[e2_00[o[e2_00?o0000ogB;
M?mdRg@00omdRg@00ol0003o?/4nock1?P09ock1?P03o`000?lm`Sgo?L8m00So?L8m00?o0000o`Oh
1ol7n0L01?l7n0L5o`0000Co0?l000?o0000oaoO7olOgal02OlOgal00ol0003o2o@;o`_d2`03o`_d
2`03o`000?lhacSo><Lh00So><Lh00?o0000oi1_T?n@Ki002_n@Ki03o`0000[oH9mP00Go0000oiIY
U_nFJIKoUVVFo`00000>oj]DZ`03o`000?oA;]7odBkA00CodBkA0_l00009onDJi@03o`000?oa3_7o
l@ka00;ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000omXU
f_oJ9MX01OoJ9MX00ol0003ob3O8olPgb003olPgb003o`000?n_D:oo[e2_00[o[e2_00?o0000ogB;
M?mdRg@01?mdRg@00ol0003o?/4nock1?P09ock1?P03o`000?lm`Sgo?L8m00Oo?L8m00?o0000o`Oh
1ol7n0L01Ol7n0L00ol0003o0?l0o`3o0007o`3o0003o`000?lOgaoo7mlO00Oo7mlO00?o0000o`_d
2ol;m0/01?l;m0/00ol0003o><LhocS7>008ocS7>003o`000?n@Ki3oT6n@00SoT6n@0_l0000>of2O
H0Co00003?n[E:/2o`0000WodBkA00?o0000onDJiOoU6^D01ooU6^D01?l0003ol@kaoo4>lOl0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooH9m_of2OH01Oof2OH00ol0003ofRGJomXUfP07omXUfP;o00000oo8=lP00ol0
003o[e2_ojm@[`09ojm@[`03o`000?mdRgCoM8]d00KoM8]d00?o0000ock1?_ln`Ch02Oln`Ch00ol0
003o?L8mocg2?@05ocg2?@03o`000?l7n0Oo1oP700Ko1oP700?o0000o`3o0?l0o`002?l0o`000ol0
003o7mlOoaoO7`06oaoO7`03o`000?l;m0_o2o@;00Co2o@;00?o0000ocS7>?lhacP02OlhacP4o`00
00?oT6n@0ol0000@of2OH005o`000?no?koo_cnooklo_ol000002_n[E:/00ol0003odBkAom4^d@0:
om4^d@Ko00000ooU6^D00ol0003ol@kao`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooH9m_of2OH01?of2OH00ol0
003ofRGJomXUfP0:omXUfP04o`000?o8=lSob3O8o`0000[o[e2_00?o0000ogB;M?mdRg@01omdRg@0
0ol0003o?/4nock1?P09ock1?P03o`000?lm`Sgo?L8m00Co?L8m00?o0000o`Oh1ol7n0L01ol7n0L0
0ol0003o0?l0o`3o0008o`3o00;o00001_lOgal00ol0003o2o@;o`_d2`05o`_d2`03o`000?lhacSo
><Lh00Wo><Lh00Co0000obkA;_l^dBko;]4^0ol0000Bof2OH003o`000?no?koo_cno00?o_cno0_l0
0006oj]DZ`;o00003OoA;]400ol0003om0_doo@;m003oo@;m0Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooH9m_of2OH00oof2OH0
0ol0003ofRGJomXUfP0<omXUfP;o00002_n_D:l00ol0003oM8]dogB;M008ogB;M003o`000?ln`Cko
?/4n00[o?/4n00?o0000ocg2?Olm`Sd00_lm`Sd00ol0003o1oP7o`Oh1`08o`Oh1`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lOgaoo7mlO00;o7mlO00?o0000o`_d2ol;m0/01_l;m0/0
0ol0003o><LhocS7>008ocS7>003o`000?l^dBko;]4^00Co;]4^00?o0000of2OH?mPWf003omPWf00
0ol0003o_cnooklo_`06oklo_`;o00000on[E:/00ol0003odBkAom4^d@0=om4^d@03o`000?od2oCo
m0_d00Oom0_d0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oon0Oh00ol0003omPWfooH9mP02ooH9mP03o`000?oJ9M[ofRGJ
00kofRGJ00?o0000ojm@[on_D:l01on_D:l00ol0003oM8]dogB;M00:ogB;M003o`000?ln`Cko?/4n
00Wo?/4n00Go0000ocg2?Olm`Sgo?L8mo`00000;o`Oh1`03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lOgaoo7mlOoaoO7ol000002?l;m0/00ol0003o><LhocS7>008ocS7>003o`000?l^
dBko;]4^00Go;]4^00?o0000of2OH?mPWf003_mPWf000ol0003o_cnooklo_`08oklo_`03o`000?n[
E:_o000000oodBkA00?o0000oo@;m?od2o@02?od2o@01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ooh1oP04o`000?of2OKomPWfo`00017ofRGJ00?o0000ojm@[on_D:l01_n_D:l00ol0003oM8]d
ogB;M00;ogB;M003o`000?ln`Cko?/4n00Wo?/4n00Co0000ocg2?Olm`Sgo00003?l7n0L00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o7mlOo`000009o`_d2`03o`000?lhacSo><Lh00So
><Lh00?o0000obkA;_l^dBh01Ol^dBh00ol0003oH9mPof2OH00=of2OH003o`000?no?koo_cno00[o
_cno00?o0000om4^dOoA;]403_oA;]400ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?ooP7no`000?l000000ol0000BomXUfP03o`00
0?n_D:oo[e2_00Co[e2_00?o0000ogB;M?mdRg@03?mdRg@00ol0003o?/4nock1?P0:ock1?P?o0000
3?l7n0L00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`_d2ol;m0/02?l;m0/00ol0003o><Lh
ocS7>007ocS7>003o`000?l^dBko;]4^00Oo;]4^00?o0000of2OH?mPWf003?mPWf000ol0003o_cno
oklo_`0;oklo_`;o00003_oA;]400ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003ofRGJomXUfP0?omXUfP?o00000on_
D:l00ol0003oM8]dogB;M00>ogB;M003o`000?ln`Cko?/4n00So?/4n00Co0000o`o`3ol?l0oo3o0?
0_l0000:o`Oh1`?o00003Ol0o`000ol0003o2o@;o`_d2`08o`_d2`03o`000?lhacSo><Lh00Oo><Lh
00?o0000obkA;_l^dBh01ol^dBh00ol0003oH9mPof2OH00;of2OH003o`000?no?koo_cno00co_cno
00?o0000onTFjOl000000_l0000:om4^d@03o`000?od2oCom0_d00Som0_d00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m004oo@;m003o`000?oJ9M[ofRGJ00cofRGJ0_l0
0003olDja@03o`000?n_D:oo0000017oM8]d00?o0000ock1?_ln`Ch01oln`Ch00ol0003o3o0?o`o`
3`04o`o`3`;o00002?l7n0L00ol0003o0?l0o`3o000>o`3o00;o00002?l;m0/00ol0003o><LhocS7
>006ocS7>003o`000?l^dBko;]4^00Wo;]4^00?o0000of2OH?mPWf002OmPWf000ol0003o_cnooklo
_`0=oklo_`03o`000?oY5^WojAKY00;ojAKY0ol00007om4^d@03o`000?od2oCom0_d00Oom0_d00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m005oo@;m003o`000?oJ9M[o
fRGJ00WofRGJ0_l00006olDja@03o`000?mdRgCoM8]d013oM8]d00?o0000ock1?_ln`Ch01_ln`Ch0
0ol0003o3o0?o`o`3`07o`o`3`03o`000?l7n0Oo1oP700Co1oP70ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol;m0/00ol0003o><LhocS7>006ocS7>003o`000?l^dBko;]4^00[o;]4^00?o0000
of2OH?mPWf002?mPWf000ol0003o_cnooklo_`0=oklo_`03o`000?oY5^WojAKY00GojAKY0ol00004
om4^d@03o`000?od2oCom0_d00Oom0_d00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003om0_doo@;m006oo@;m003o`000?oJ9M[ofRGJ00GofRGJ0ol00008olDja@03o`000?mdRgCoM8]d
017oM8]d00Co0000ock1?_ln`Cko?/4n1?l0000;o`o`3`;o000000Co1oP7o`000?l0003o00000olC
k1<2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2o@;00?o0000ocS7>?lhacP01_lh
acP00ol0003o;]4^obkA;P0:obkA;P03o`000?mPWf3oH9mP00OoH9mP00?o0000oklo_ono?kl03_no
?kl00ol0003ojAKYonTFj@08onTFj@Co00002_od2o@00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om0_doo@;m007oo@;m003o`000?oJ9M[ofRGJ00;ofRGJ0_l0000<olDja@03o`000?mdRgCo
M8]d013oM8]d1?l00003oc7><@03o`000?l?l0oo3o0?00_o3o0?00?o0000oa?/4olCk1<01_lCk1<0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obkA;P03o`000?mPWf3o
H9mP00KoH9mP00?o0000oklo_ono?kl03_no?kl00ol0003ojAKYonTFj@0;onTFj@03o`000?od2oCo
m0_d00Oom0_d00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00Wom0_d00Co0000omXU
f_l0003o00003_o5>/D00ol0003oM8]dogB;M00?ogB;M003o`000?lacS7o<Lha00Ko<Lha00?o0000
o`o`3ol?l0l02_l?l0l00ol0003o4n`Coa?/4`07oa?/4`;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lm`Sgo?L8m00So?L8m00?o0000obkA;_l^dBh03?l^dBh00ol0003oH9mPof2OH005
of2OH003o`000?no?koo_cno00oo_cno0_l0000=onTFj@03o`000?od2oCom0_d00Kom0_d00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00[om0_d00?o0000olDjaOo5>/D03_o5>/D00ol0
003oM8]dogB;M00>ogB;M003o`000?lacS7o<Lha00Oo<Lha00?o0000o`o`3ol?l0l02_l?l0l00ol0
003o4n`Coa?/4`09oa?/4`;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lm`Sgo?L8m
00Wo?L8m00?o0000obkA;_l^dBh02_l^dBh4o`0000CoH9mP00?o0000oklo_ono?kl04?no?kl01?l0
003oiQWVo`000?l0000<onTFj@03o`000?od2oCom0_d00Gom0_d00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?od2oCom0_d00[om0_d00?o0000olDjaOo5>/D03oo5>/D@o`0000[o<Lha00?o0000o`o`
3ol?l0l02Ol?l0l00ol0003o0?l0o`00000<oa?/4`05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o?L8mocg2?@09ocg2?@03o`000?l^dBko;]4^00Oo;]4^0ol00004of>LH`?o000000?oH9mP
o`000?no?kl04Ono?kl01?l0003oiQWVonHIi_oV6NH2o`0000_ojAKY00?o0000oo@;m?od2o@00ood
2o@00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@02_od2o@00ol0003oaC[5olDja@0?
olDja@03o`000?meRWGoMHYe00coMHYe00?o0000oc7><OlacS402OlacS400ol0003o3o0?o`o`3`07
o`o`3`04o`000?l0o`3o0?l0o`0000go4n`C00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lm`Sgo?L8m00[o?L8m00?o0000obkA;_l^dBh00ol^dBh3o`0000[oHiaS00?o0000oklo_ono?kl0
4?no?kl00ol0003oiQWVonHIiP04onHIiP;o00002_oY5^T00ol0003om0_doo@;m004o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000com0_d00?o0000olDjaOo5>/D03oo5>/D00ol0003oMHYeogF:M@0<ogF:M@03o`000?la
cS7o<Lha00Wo<Lha00?o0000o`o`3ol?l0l01_l?l0l00ol0003o0?l0o`3o0002o`3o0003o`000?lC
k1?o4n`C00[o4n`C00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?lm
`Sgo?L8m00[o?L8m00?o0000obkA;_l^dBh00ol0000=of>LH`03o`000?no?koo_cno013o_cno00?o
0000onHIi_oV6NH01_oV6NH2o`0000WojAKY0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;ooP7n00?o0000oo@;m?od2o@02_od2o@00ol0003oaC[5olDja@0=olDja@?o00003omeRWD0
0ol0003o<Lhaoc7><@08oc7><@03o`000?l?l0oo3o0?00Go3o0?00?o0000o`3o0?l0o`000ol0o`00
0ol0003o4n`Coa?/4`0:oa?/4`03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o?L8mocg2?@0;ocg2?@;o00004OmSW6<00ol0003o_cnooklo_`0?oklo_`03o`000?oV6NKo
iQWV00SoiQWV0_l00007onTFj@03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00OooP7n00?o0000oo@;m?od2o@02?od2o@00ol0003oaC[5olDja@09olDja@Go00000_nFJIH00ol0
003oMHYeogF:M@0=ogF:M@03o`000?lacS7o<Lha00Wo<Lha00?o0000o`o`3ol?l0l01?l?l0l00ol0
003o0?l0o`3o0004o`3o0003o`000?lCk1?o4n`C00So4n`C00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lm`Sgo?L8m00_o?L8m00?o0000of>LHomSW6<04?mSW6<00ol0
003o_cnooklo_`0?oklo_`03o`000?oV6NKoiQWV00[oiQWV0_l00004onTFj@03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om0_doo@;m007oo@;m003o`000?o5>/GoaC[500CoaC[51Ol00007oiIYUP03
o`000?meRWGoMHYe00goMHYe00?o0000oc7><OlacS402OlacS400ol0003o3o0?o`o`3`03o`o`3`03
o`000?l0o`3o0?l000Go0?l000?o0000oa?/4olCk1<02?lCk1<00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ocg2?Olm`Sd02olm`Sd00ol0003oHiaSof>LH`0@of>LH`03
o`000?no?koo_cno00oo_cno00?o0000onHIi_oV6NH03?oV6NH2o`000003onTFjOl0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?od2oCom0_d00Oom0_d00?o0000olDjaOl00000
1?l0000<oiIYUP03o`000?meRWGoMHYe00koMHYe00?o0000oc7><OlacS402?lacS400ol0003o3o0?
o`o`3`02o`o`3`03o`000?l0o`3o0?l000Oo0?l000?o0000oa?/4olCk1<01olCk1<00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ocg2?Olm`Sd02olm`Sd00ol0003oHiaS
of>LH`0Aof>LH`03o`000?no?koo_cno00go_cno00?o0000onHIi_oV6NH03ooV6NH00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000oo@;m?od2o@01Ood2o@3o`00017oUVVF00?o0000ogF:MOmeRWD03_me
RWD00ol0003o<Lhaoc7><@09oc7><@04o`000?l?l0oo3o0?o`0000[o0?l000?o0000oa?/4olCk1<0
1olCk1<00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Olm`Sd00ol0003o
HiaSof>LH`0Aof>LH`?o00003Ono?kl00ol0003oiQWVonHIiP0?onHIiP03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_od2o@2o`0000;ogB;M00?o0000oiIYU_nFJIH03onFJIH00ol0003o
MHYeogF:M@0>ogF:M@03o`000?lacS7o<Lha00So<Lha1Ol0000;o`3o0003o`000?lCk1?o4n`C00Ko
4n`C00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ocg2?@03o`000?mSW6?oHiaS
017oHiaS00?o0000ofJII_mVVFH00ol0000:oklo_`Co00003OoV6NH00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooH9m_of2OKomPWf0_l00005omdRg@03o`000?nFJIKoUVVF00koUVVF00?o0000ogF:
MOmeRWD03_meRWD00ol0003o<Lhaoc7><@07oc7><@03o`000?lMhQgo7N8M00?o7N8M00?o0000o`3o
0?l0o`002?l0o`000ol0003o4n`Coa?/4`05oa?/4`03o`000?l0o`3o0?l000[o0?l01Ol0000<ocg2
?@03o`000?mSW6?oHiaS013oHiaS00?o0000ofJII_mVVFH01?mVVFH3o`0000Ko_cno00?o0000on8M
h_oR7N800_oR7N85o`0000SoiQWV00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?of2OKomPWf00?o
mPWf00?o0000omdRgOoM8]d01?oM8]d00ol0003oUVVFoiIYUP0=oiIYUP03o`000?meRWGoMHYe00oo
MHYe00?o0000oc7><OlacS401?lacS42o`0000Oo7N8M00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ocg2?Olm`Sd02?lm`Sd3o`00013oHiaS00?o0000ofJII_mVVFH02?mVVFH3o`0000;o
_cno00?o0000on8Mh_oR7N802?oR7N85o`0000?oiQWV00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?of2OKomPWf00ComPWf00?o0000omdRgOoM8]d01OoM8]d00ol0003oUVVFoiIYUP0;oiIYUPCo0000
3omeRWD00ol0003o<Lhaoc7><@03oc7><@03o`000?lMhQgo7N8M00So7N8M00?o0000o`3o0?l0o`00
1?l0o`02o`0000So6>LH00?o0000o`Sg2?l8m`P02?l8m`P00ol0003o0?l0o`3o0005o`3o00;o0000
1_lm`Sd2o`0000?o=/Tf00?o0000of>LHomSW6<03?mSW6<00ol0003oIYUVofJIIP0<ofJIIP;o0000
4?oR7N83o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`000?oM8]gogB;M00KogB;M00?o
0000oiIYU_nFJIH02OnFJIH00ol0003oYUVVo`000002oejQGP?o00003?meRWD01?l0003o<Lhaoc7>
<OlacS42o`0000co7N8M00?o0000o`3o0?l0o`000_l0o`000ol0003o6>LHoaSW6008oaSW6003o`00
0?l8m`So2?L800So2?L800?o0000o`3o0?l0o`001ol0o`000ol0003o?L8mocg2?@02ocg2?@03o`00
0?lfbCKo=/Tf00Co=/Tf0_l0000;of>LH`03o`000?mVVFKoIYUV00coIYUV00?o0000ojaC[?l00000
4_oR7N800ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003omPWfooH9mP06ooH9mP03o`000?oM8]gogB;M00OogB;M00?o
0000oiIYU_nFJIH01_nFJIH2o`0000;oYUVV00?o0000oejQG_mNXEh00omNXEh3o`0000[oMHYe00?o
0000oc7><Ol000003olMhQd01?l0003o0?l0o`000?l0000;oaSW6003o`000?l8m`So2?L800So2?L8
00?o0000o`3o0?l0o`002?l0o`001?l0003o?L8mo`000?l00009ocK9=P03o`000?mSW6?oHiaS00Oo
HiaS00?o0000ofJII_mVVFH03?mVVFH01?l0003o[5>/ojaC[?l0000Con8MhP03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooH9m_of2OH01oof2OH00ol0003ogB;MomdRg@08omdRg@03o`000?nFJIKoUVVF00Co
UVVF00?o0000ojIIY_nVFJH00onVFJH00ol0003oGZ5NoejQGP05oejQGP?o00001_meRWD4o`00013o
7N8M00?o0000oaSW6?lHiaP03?lHiaP00ol0003o2?L8o`Sg2007o`Sg2003o`000?l0o`3o0?l000Wo
0?l000?o0000ocK9=_lfbCH02_lfbCH2o`0000KoHiaS00?o0000ofJII_mVVFH03?mVVFH00ol0003o
[5>/ojaC[002ojaC[003o`000?oR7N;ohQgR00oohQgR00?o0000oo<<lol000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003omPWfooH9mP08ooH9mP03o`000?oM8]gogB;M00WogB;M00Co0000oiIYU_nFJIKo
UVVF0_l00006ojIIYP03o`000?mNXEkoGZ5N00SoGZ5N0ol000000omeRWGo0000o`000004ocO8=`03
o`000?lMhQgo7N8M00go7N8M00?o0000oaSW6?lHiaP03?lHiaP00ol0003o2?L8o`Sg2007o`Sg2003
o`000?l0o`3o0?l000Wo0?l000?o0000ocK9=_lfbCH03?lfbCH00ol0003oHiaSof>LH`03o`0000ko
IYUV00?o0000ojaC[?n/Dj`00on/Dj`00ol0003ohQgRon8MhP0>on8MhP05o`000?oc3??ol`ccoo<<
lol000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003omPWfooH9mP09ooH9mP03o`000?oM8]gogB;M00[o
gB;M00?o0000oiIYU_l000002?nVFJH00ol0003oGZ5NoejQGP0;oejQGP03o`000?lgb3Oo=lPg00Go
=lPg00?o0000oagR7OlMhQd03?lMhQd00ol0003o6>LHoaSW600<oaSW6003o`000?l8m`So2?L800Oo
2?L800?o0000o`3o0?l0o`002?l0o`02o`0000oo=/Tf0_l00002ofVFJ@03o`000?mVVFKoIYUV00_o
IYUV00?o0000ojaC[?n/Dj`01?n/Dj`00ol0003ohQgRon8MhP0=on8MhP03o`000?oc3??ol`cc00?o
l`cc00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooH9mP03o`000?oM8]gogB;M00_ogB;M00?o0000ojIIY_nVFJH0
1onVFJH00ol0003oGZ5NoejQGP0;oejQGP03o`000?lgb3Oo=lPg00Ko=lPg00?o0000oagR7OlMhQd0
2olMhQd2o`0000go6>LH00?o0000o`Sg2?l8m`P01ol8m`P00ol0003o0?l0o`3o0007o`3o0004o`00
0?l:m@[o2_D:o`0000ko=/Tf00?o0000ofVFJOmYUVT00_mYUVT00ol0003oIYUVofJIIP09ofJIIP03
o`000?n/Djco[5>/00Ko[5>/00?o0000on8Mh_oR7N802ooR7N800ol0003ol`ccoo<<l`05oo<<l`04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000SomPWf00?o0000omdRgOoM8]d02_oM8]d2o`0000Wo
YUVV00?o0000oejQG_mNXEh02omNXEh00ol0003o=lPgocO8=`07ocO8=`03o`000?lMhQgo7N8M00Wo
7N8M00Co0000o`3o0?l0o`3o00003?lHiaP00ol0003o2?L8o`Sg2007o`Sg2003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`[e2_l:m@[o2_D:o`00000>ocK9=P03o`000?mYUVWoJIIY00?oJIIY00?o0000
ofJII_mVVFH01omVVFH00ol0003o[5>/ojaC[007ojaC[003o`000?oR7N;ohQgR00[ohQgR00?o0000
oo<<looc3?<01ooc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooH9mP03o`000?oM8]gogB;M
00WogB;M00Co0000om@[e?oD:mCo00002OnVFJH00ol0003oGZ5NoejQGP09oejQGP03o`000?lgb3Oo
=lPg00Wo=lPg00?o0000oagR7OlMhQd01olMhQd00ol0003o0?l0o`3o0002o`3o0003o`000?lHiaSo
6>LH00Wo6>LH00?o0000o`Sg2?l8m`P01ol8m`P00ol0003o0?l0o`3o0005o`3o0003o`000?l:m@[o
2_D:00?o2_D:00?o0000ocK9=_lfbCH02_lfbCH00ol0003oJIIYofVFJ@05ofVFJ@03o`000?mVVFKo
IYUV00GoIYUV00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003ohQgRon8MhP09on8MhP03o`000?oc3??o
l`cc00Sol`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_of2OH3o`0000WogB;M00?o0000om@[
e?oD:m@00_oD:m@00ol0003oYUVVojIIYP06ojIIYP03o`000?mNXEkoGZ5N00WoGZ5N00?o0000ocO8
=olgb3L02_lgb3L00ol0003o7N8MoagR7@05oagR7@03o`000?l0o`3o0?l000Co0?l000?o0000oaSW
6?lHiaP02?lHiaP00ol0003o2?L8o`Sg2007o`Sg2003o`000?l0o`3o0?l000Co0?l000?o0000o`[e
2_l:m@X01?l:m@X00ol0003o=/TfocK9=P0:ocK9=P03o`000?mYUVWoJIIY00KoJIIY00?o0000ofJI
I_mVVFH00omVVFH00ol0003o[5>/ojaC[009ojaC[003o`000?oR7N;ohQgR00SohQgR00?o0000oo<<
looc3?<02Ooc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003onl@k`?o00001OoM8]d00ol0003o
e2_Dom@[e003om@[e003o`000?nVFJKoYUVV00KoYUVV00?o0000oejQG_mNXEh02OmNXEh00ol0003o
=lPgocO8=`0;ocO8=`03o`000?lMhQgo7N8M00?o7N8M00?o0000o`3o0?l0o`001_l0o`000ol0003o
6>LHoaSW6008oaSW6003o`000?l8m`So2?L800Ko2?L800?o0000o`3o0?l0o`000_l0o`02o`0000So
2_D:00?o0000ocK9=_lfbCH02OlfbCH00ol0003oJIIYofVFJ@07ofVFJ@05o`000?mVVFKoIYUVofJI
I_l000003On/Dj`00ol0003ohQgRon8MhP06on8MhP03o`000?oc3??ol`cc00[ol`cc00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o_4>ooka3_00Goka3_0ol000000ooM8]go0000om@[e006om@[e003
o`000?nVFJKoYUVV00GoYUVV00?o0000oejQG_mNXEh02OmNXEh00ol0003o=lPgocO8=`0<ocO8=`05
o`000?lMhQgo7N8MoagR7Ol000002_l0o`000ol0003o6>LHoaSW6007oaSW6003o`000?l8m`So2?L8
00Ko2?L800?o0000o`3o0?l000000_l000000olcc3?o0000o`[e2P07o`[e2P03o`000?lfbCKo=/Tf
00So=/Tf00?o0000ofVFJOmYUVT02OmYUVT00ol0003oIYUVo`00000=ojaC[0Co00001OoR7N800ol0
003ol`ccoo<<l`0;oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003oka3_onl@k`08onl@k`03
o`000?oD:mCoe2_D00Ooe2_D00?o0000ojIIY_nVFJH01?nVFJH00ol0003oGZ5NoejQGP09oejQGP03
o`000?lgb3Oo=lPg00go=lPg00?o0000oagR7Ol000003?l0o`0:o`0000Oo2?L80ol00005oc?<<`03
o`000?l:m@[o2_D:00Ko2_D:00?o0000ocK9=_lfbCH01olfbCH00ol0003oJIIYofVFJ@0:ofVFJ@03
o`000?n/Djco[5>/00_o[5>/00?o0000omlPgooO8=l00_oO8=l3o`000003on8Mh_l0003ol`cc00_o
l`cc0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000onl@koo_4>l02Oo_4>l00ol0003oe2_Dom@[e007om@[e003o`00
0?nVFJKoYUVV00GoYUVV00?o0000oejQG_mNXEh01omNXEh00ol0003o=lPgocO8=`0?ocO8=`;o0000
2ol0o`000ol0003o9]TVobKI9P07obKI9P03o`000?l8m`So2?L800;o2?L80ol00008oc?<<`03o`00
0?l:m@[o2_D:00Ko2_D:00?o0000ocK9=_lfbCH01olfbCH00ol0003oJIIYofVFJ@0:ofVFJ@03o`00
0?n/Djco[5>/00[o[5>/00?o0000omlPgooO8=l01_oO8=l00ol0003ol`ccoo<<l`08oo<<l`?o0000
0_of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000onl@koo_4>l02Oo_4>l00ol0003oe2_Dom@[
e008om@[e003o`000?nVFJKoYUVV00CoYUVV00?o0000oejQG_mNXEh01omNXEh00ol0003o=lPgocO8
=`0>ocO8=`04o`000?l7n0Oo1oP7o`0000Wo0?l000?o0000obKI9_lVfBH02OlVfBH01?l0003o2?L8
o`000?l0000<oc?<<`03o`000?l:m@[o2_D:00Ko2_D:00?o0000ocK9=_lfbCH01_lfbCH00ol0003o
JIIYofVFJ@0;ofVFJ@03o`000?n/Djco[5>/00Oo[5>/0_l00009omlPg`03o`000?oc3??ol`cc00Co
l`cc1?l00006ooH9mP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003oka3_onl@k`09onl@k`03o`00
0?oD:mCoe2_D00Soe2_D00?o0000ojIIY_nVFJH00onVFJH>o`0000go=lPg00?o0000o`Oh1ol7n0L0
0_l7n0L00ol0003o0?l0o`3o0005o`3o0003o`000?lVfBKo9]TV00_o9]TV00?o0000oc?<<olcc3<0
3?lcc3<00ol0003o2_D:o`[e2P06o`[e2P03o`000?lfbCKo=/Tf00Go=/Tf00?o0000ofVFJOmYUVT0
3?mYUVT00ol0003o[5>/ojaC[006ojaC[003o`000?oO8=oogb3O00[ogb3O00?o0000oo<<looc3?<0
0ol0000:ooH9mP?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000om@[e?oD:m@02?oD
:m@01Ol0003oYUVVojIIY_nVFJKo000000_oKi1_00?o0000o`o`3ol?l0l00ol00009ocO8=`03o`00
0?l7n0Oo1oP700Co1oP700?o0000o`3o0?l0o`000ol0o`000ol0003o9]TVobKI9P0<obKI9P03o`00
0?lcc3?o<l`c00go<l`c00?o0000o`[e2_l:m@X01_l:m@X00ol0003o=/TfocK9=P03ocK9=P?o0000
3OmYUVT00ol0003o[5>/ojaC[005ojaC[003o`000?oO8=oogb3O00cogb3O0_l0000=ooH9mP03o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000om@[e?oD:m@02?oD
:m@4o`0000coKi1_00?o0000o`o`3ol?l0l00ol?l0l3o`0000Go=lPg00?o0000o`Oh1ol7n0L01_l7
n0L01Ol0003o0?l0o`3o0?l0o`3o000000oo9]TV00?o0000oc?<<olcc3<03Olcc3<00ol0003o2_D:
o`[e2P06o`[e2P03o`000?lfbCKo=/Tf00?o00000olUfRD00ol0003oJIIYofVFJ@0;ofVFJ@03o`00
0?n/Djco[5>/00?o[5>/00?o0000omlPgooO8=l03OoO8=l00ol0003omPWfooH9mP0;ooH9mP03o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000onl@koo_4>l02_o_4>l3o`0000Koe2_D0ol0
0003ol8m`P03o`000?m_T6ooKi1_00[oKi1_00?o0000o`o`3ol?l0l01_l?l0l3o`000003ocO8=ol0
003o1oP700Wo1oP700?o0000o`3o0?l000004?lVfBH00ol0003o<l`coc?<<`0=oc?<<`03o`000?l:
m@[o2_D:00Oo2_D:0_l00007obGJ9@03o`000?mYUVWoJIIY00[oJIIY00Co0000ojaC[?n/Djco[5>/
0ol0000?omlPg`03o`000?of2OKomPWf00_omPWf00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000onl@koo_4>l02_o_
4>l01?l0003oiaSWonLHiooW6>L2o`000004om@[e?l0003o0000o`0000Ko`Sg200?o0000ofn@Kom_
T6l02_m_T6l00ol0003o3o0?o`o`3`09o`o`3`03o`000?l7n0Oo1oP700[o1oP700?o0000obKI9_lV
fBH03olVfBH00ol0003o<l`coc?<<`0>oc?<<`03o`000?l:m@[o2_D:00Ko2_D:00?o0000obGJ9OlU
fRD01olUfRD4o`0000SoJIIY00Co0000ojaC[?n/Djco00000oo1?/42o`0000gogb3O00?o0000ooH9
m_of2OH02_of2OH00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000onl@koo_4>l02Oo_4>l00ol0003o
iaSWonLHi`04onLHi`03o`000?o2?L;o`Sg200Oo`Sg200?o0000ofn@Kom_T6l02Om_T6l00ol0003o
3o0?o`o`3`0:o`o`3`03o`000?l7n0Oo1oP700[o1oP700?o0000obKI9_lVfBH03olVfBH00ol0003o
<l`coc?<<`0>oc?<<`03o`000?l:m@[o2_D:00Go2_D:00?o0000obGJ9OlUfRD02?lUfRD01?l0003o
HiaSof>LHomSW6<7o`0000;oJIIY0_l00006ol4n`@;o00003?oO8=l00ol0003omPWfooH9mP09ooH9
mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003oka3_onl@k`08onl@k`03o`000?oW6>OoiaSW00Go
iaSW00?o0000ol8m`_o2?L802?o2?L800ol0003oKi1_ofn@K`08ofn@K`03o`000?l?l0oo3o0?00[o
3o0?00?o0000o`Oh1ol7n0L02ol7n0L00ol0003o9]TVobKI9P0>obKI9P03o`000?lcc3?o<l`c00ko
<l`c1Ol00002o`[e2P03o`000?lUfRGo9MXU00Wo9MXU00?o0000of>LHomSW6<02?mSW6<3o`0000Wo
`Ck10_l0000:omlPg`03o`000?of2OKomPWf00SomPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o_4>ooka3_00Soka3_00?o0000onLHiooW6>L01ooW6>L00ol0003o`Sg2ol8m`P07ol8m`P03o`00
0?m_T6ooKi1_00SoKi1_00?o0000o`o`3ol?l0l02_l?l0l00ol0003o1oP7o`Oh1`0:o`Oh1`;o0000
3_lVfBH3o`0000go<l`c0ol00005ocno?`;o00002olUfRD00ol0003oHiaSof>LH`0;of>LH`;o0000
2_o1?/42o`0000Oogb3O0ol00009ooH9mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:onLHi`03o`00
0?o2?L;o`Sg200Oo`Sg200?o0000ofn@Kom_T6l02?m_T6l>o`0000Wo1oP70ol000000ol0o`3o0000
obKI9P0:obKI9P?o00000_lo`3l00ol0003o<l`coc?<<`09oc?<<`;o00002Olo_cl00ol0003o9MXU
obGJ9@09obGJ9@03o`000?mSW6?oHiaS00_oHiaS00?o0000ohebSOl000002oo1?/42o`0000Cogb3O
00Co0000ondBkOo]4^gokA;]0_l00007ooH9mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003oiaSW
onLHi`09onLHi`03o`000?o2?L;o`Sg200Ko`Sg200?o0000ofn@Kom_T6l02?m_T6l00ol0003o5^TF
oaKY5P0:oaKY5P03o`000?l7n0Oo1oP700Co1oP70ol00005o`3o0003o`000?lVfBKo9]TV00Co9]TV
1?l00006oco0?`03o`000?lcc3?o<l`c00Ko<l`c0_l0000;ocno?`03o`000?lUfRGo9MXU00Wo9MXU
00?o0000of>LHomSW6<02_mSW6<01Ol0003oSG:=ohebSOn=LXgo000000co`Ck10_l000000ooO8=oo
0000ondBk@05ondBk@03o`000?of2OKomPWf00?omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oW6>OoiaSW00SoiaSW00?o0000ol8m`_o2?L801_o2?L800ol0003oKi1_ofn@K`07ofn@K`03o`00
0?lFjAKo5^TF00_o5^TF00?o0000o`Oh1ol7n0L00_l7n0L2o`0000Wo0?l000?o0000obKI9_lVfBH0
0ol0000;oco0?`03o`000?lcc3?o<l`c00;o<l`c0ol0000>ocno?`03o`000?lUfRGo9MXU00Oo9MXU
00?o0000of>LHomSW6<02omSW6<00ol0003oSG:=ohebS@02ohebS@03o`000?o1?/7o`Ck100_o`Ck1
00?o0000ondBkOo]4^d01_o]4^d2o`0000?omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oW
6>OoiaSW00OoiaSW00?o0000ol8m`_o2?L801oo2?L800ol0003oKi1_ofn@K`05ofn@K`?o00003OlF
jAH4o`0000_o0?l00ol0000?oco0?`04o`000?lcc3?o0000o`00017o?klo00?o0000obGJ9OlUfRD0
1olUfRD00ol0003oHiaSof>LH`0:of>LH`03o`000?n=LXgoSG:=00CoSG:=00?o0000ol4n`Oo1?/40
1oo1?/43o`0000_okA;]1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onLHiooW6>L02?oW6>L00ol0003o`Sg2ol8m
`P06ol8m`P03o`000?m_T6ooKi1_00;oKi1_0ol00003od^dB`03o`000?lFjAKo5^TF00[o5^TF00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aoco0?`03o`000?lo_coo?klo017o?klo00?o
0000obGJ9OlUfRD01olUfRD00ol0003oHiaSof>LH`0:of>LH`03o`000?n=LXgoSG:=00GoSG:=00Co
0000ol4n`Oo1?/7o`Ck11Ol00002olTfb@03o`000?o]4^gokA;]00WokA;]00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onLHiooW6>L01ooW6>L00ol0003o`Sg2ol8m`P05ol8m`P?o0000
00?oKi1_o`000?l000001om;]4/00ol0003o5^TFoaKY5P08oaKY5P?o00002_l0o`02o`0000;o0?l0
00?o0000oco0?olo`3l03olo`3l00ol0003o?kloocno?`0Aocno?`03o`000?lUfRGo9MXU00Oo9MXU
00?o0000of>LHomSW6<02OmSW6<00ol0003oSG:=ohebS@07ohebS@?o00001oo9=/T00ol0003okA;]
ondBk@09ondBk@03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onLHiooW6>L01ooW
6>L4o`0000;o`Sg20_l00003okE:]@03o`000?m;]4_oBkA;00SoBkA;0_l00006oaKY5P;o00000olC
k1<00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000oco0?olo`3l03_lo
`3l00ol0003o?kloocno?`0Bocno?`03o`000?lUfRGo9MXU00Go9MXU00?o0000of>LHomSW6<02OmS
W6<00ol0003oSG:=ohebS@08ohebS@03o`000?o9=/WobCK900OobCK900?o0000ondBkOo]4^d02?o]
4^d00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oW6>OoiaSW00CoiaSW0_l00004
onLHi`;o00001OneB[D00ol0003oBkA;od^dB`0:od^dB`03o`000?lFjAKo5^TF00;o5^TF00?o0000
oa?/4olCk1<01?lCk1<00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
oco0?olo`3l03_lo`3l00ol0003o?kloocno?`0Bocno?`[o00002_mSW6<00ol0003oSG:=ohebS@08
ohebS@03o`000?o9=/WobCK900OobCK900?o0000ondBkOo]4^d02?o]4^d00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003oiaSWonLHiooW6>L2o`0000OoiaSW00?o0000okE:]OneB[D01?neB[D0
0ol0003oBkA;od^dB`0:od^dB`04o`000?lFjAKo0000o`0000So4n`C00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lo`3oo?l0o00ko?l0o00?o0000ocno?olo_cl04_lo_cl00ol0003o@Ki1
od6n@@07od6n@@03o`000?mSW6?oHiaS00KoHiaS00?o0000ohebSOn=LXd02_n=LXd00ol0003obCK9
olTfb@06olTfb@03o`000?o]4^gokA;]00SokA;]00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oW
6>Oo0000o`0000WoiaSW00?o0000okE:]OneB[D01?neB[D00ol0003oBkA;od^dB`0;od^dB`03o`00
0?lCk1?o4n`C00Wo4n`C00?o0000o`3o0?l000002Ol0o`000ol0003o?l0ooco0?`0>oco0?`;o0000
4_lo_cl00ol0003o@Ki1od6n@@09od6n@@;o00001_mSW6<00ol0003oSG:=ohebS@0:ohebS@03o`00
0?o9=/WobCK900KobCK900?o0000ondBkOo]4^d02?o]4^d00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onLHiooW6>L02OoW6>L00ol0003o]DZeokE:]@05okE:]@03o`000?m;]4_oBkA;00[oBkA;00?o
0000oa?/4olCk1<02_lCk1<2o`0000Wo0?l000?o0000oco0?olo`3l03_lo`3l00ol0003o:m@[o`00
0002o`0000oo?klo00?o0000od6n@Om1_T402om1_T400ol0003oHiaSof>LH`03o`0000goSG:=00?o
0000olTfbOo9=/T01_o9=/T00ol0003okA;]ondBk@07ondBk@03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oiaSWonLHi`09onLHi`03o`000?neB[Go]DZe00Go]DZe00?o0000od^dBom;]4/02Om;]4/2
o`0000_o4n`C0_l0000;o`3o0003o`000?lo`3oo?l0o00co?l0o00?o0000ob_D:ol[e2/00ol[e2/3
o`0000co?klo00?o0000od6n@Om1_T403?m1_T42o`0000;oPgb300?o0000ohebSOn=LXd03?n=LXd0
0ol0003obCK9olTfb@05olTfb@03o`000?o]4^gokA;]00OokA;]00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oW6>OoiaSW00[oiaSW00?o0000okE:]OneB[D01_neB[D00ol0003oBkA;od^dB`07od^d
B`03o`000?m>/Dko000000[o4n`C00Co0000o`Wf2Ol9mPWo00002_l0o`000ol0003o?l0ooco0?`0<
oco0?`03o`000?l[e2_o:m@[00Ko:m@[0_l00008ocno?`;o00003om1_T400ol0003oPgb3oh=lP`02
oh=lP`03o`000?n=LXgoSG:=00_oSG:=00?o0000olTfbOo9=/T01Oo9=/T00ol0003okA;]ondBk@07
ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oiaSWonLHi`0:onLHi`03o`000?neB[Go]DZe
00Ko]DZe00?o0000od^dBom;]4/01_m;]4/01Ol0003oC[5>odjaC_m>/Dko000000So4n`C00?o0000
o`Wf2Ol9mPT00_l9mPT00ol0003o0?l0o`3o0006o`3o00Co00003?lo`3l00ol0003o:m@[ob_D:`08
ob_D:`?o00000_lo_cl3o`000003oc?<<ol0003o@Ki100go@Ki100?o0000oh=lPon3O8<01?n3O8<0
0ol0003oSG:=ohebS@0:ohebS@03o`000?o9=/WobCK900GobCK900?o0000ondBkOo]4^d01_o]4^d0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onLHiooW6>L02ooW6>L00ol0003o]DZeokE:]@07okE:
]@03o`000?m;]4_oBkA;00?oBkA;0_l00005odjaCP03o`000?lCk1?o4n`C00Co4n`C00?o0000o`Wf
2Ol9mPT00ol9mPT00ol0003o0?l0o`3o0005o`3o0003o`000?l;m0_o2o@;00;o2o@;0ol00007oco0
?`;o00003_l[e2/2o`0000Go<l`c00?o0000od6n@Om1_T402_m1_T400ol0003oPgb3oh=lP`05oh=l
P`03o`000?n=LXgoSG:=00_oSG:=00?o0000olTfbOo9=/T01?o9=/T00ol0003okA;]ondBk@06ondB
k@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiaSWonLHi`0;onLHi`03o`000?neB[Go]DZe00Oo
]DZe00?o0000od^dBom;]4/00_m;]4/00ol0003oC[5>odjaCP06odjaCP03o`000?lCk1?o4n`C00;o
4n`C00?o0000o`Wf2Ol9mPT01Ol9mPT00ol0003o0?l0o`3o0002o`3o00;o00002?l;m0/3o`0000;o
?l0o0_l000000olAkQ7o0000ob_D:`0=ob_D:`03o`000?lcc3?o<l`c00Go<l`c00?o0000od6n@Om1
_T402?m1_T400ol0003oPgb3oh=lP`07oh=lP`03o`000?n=LXgoSG:=00[oSG:=00?o0000olTfbOo9
=/T01?o9=/T00ol0003okA;]ondBk@06ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oiaSW
onLHi`0<onLHi`03o`000?neB[Go]DZe00So]DZe00Co0000od^dBom;]4_o00002Om>/Dh01Ol0003o
4n`Coa?/4olCk1?o000000So2OH900Go0000o`3o0?l0o`3o0?l0o`00000=o`_d2`;o00001?lAkQ40
0ol0003o:m@[ob_D:`0;ob_D:`03o`000?lcc3?o<l`c00Ko<l`c00?o0000od6n@Om1_T401om1_T40
0ol0003oPgb3oh=lP`08oh=lP`Co00002?n=LXd00ol0003obCK9olTfb@04olTfb@03o`000?o]4^go
kA;]00KokA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oW6>OoiaSW00_oiaSW0ol00009okE:
]@03o`000?m;]4_o000000_oC[5>00?o0000oa?/4ol000002_l9mPT00ol0003o0?l0o`00000?o`_d
2`03o`000?lAkQ7o4NhA00;o4NhA00?o0000ob_D:ol[e2/02ol[e2/00ol0003o<l`coc?<<`06oc?<
<`03o`000?m1_T7o@Ki100Ko@Ki100?o0000oh=lPon3O8<02On3O8<01?l0003o/dbcok=</oncC;<7
o`0000;oSG:=00?o0000olTfbOo9=/T00oo9=/T00ol0003okA;]ondBk@05ondBk@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oW6>OoiaSW00SoiaSW0ol00003on<Lh`03o`000?neB[Go]DZe00Oo]DZe00?o0000odja
C_m>/Dh02om>/Dh00ol0003o2OH9o`Wf2@0:o`Wf2@03o`000?l;m0_o2o@;00go2o@;00?o0000oa7^
4OlAkQ401?lAkQ400ol0003o:m@[ob_D:`09ob_D:`03o`000?lcc3?o<l`c00So<l`c00?o0000od6n
@Om1_T400om1_T42o`0000coPgb300?o0000ok=</oncC;<02?ncC;<<o`0000?okA;]0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onLHiooW6>L01_oW6>L3o`0000OohacS00?o0000okE:]OneB[D01_neB[D00ol0003o
C[5>odjaCP0;odjaCP03o`000?l9mPWo2OH900Wo2OH90_l0000>o`_d2`03o`000?lAkQ7o4NhA00Go
4NhA00?o0000ob_D:ol[e2/02Ol[e2/00ol0003o<l`coc?<<`09oc?<<`03o`000?m1_T7o000000;o
00000_mhQgP00ol0003oPgb3oh=lP`08oh=lP`03o`000?ncC;?o/dbc00co/dbc00?o0000onPGj?oX
5nP01_oX5nP3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oiaSWonLHi`03onLHi`?o00002ooS7><00ol0003o]DZe
okE:]@04okE:]@03o`000?m>/DkoC[5>00_oC[5>0ol00007o`Wf2@?o000000?o3?<<o`000?l;m0/0
3Ol;m0/00ol0003o4NhAoa7^4@06oa7^4@03o`000?l[e2_o:m@[00So:m@[00?o0000oc?<<olcc3<0
2_lcc3<00ol0003oN8MhogR7N004ogR7N003o`000?n3O8?oPgb300OoPgb300?o0000ok=</oncC;<0
2oncC;<00ol0003oj1OXonPGj008onPGj003o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onLHiol0
003o0000o`0000oohacS00?o0000okE:]OneB[D00oneB[D>o`0000?o>l@k0_l00002o`Wf2@?o0000
1Ol<l``00ol0003o2o@;o`_d2`0:o`_d2`03o`000?lAkQ7o4NhA00Oo4NhA00?o0000ob_D:ol[e2/0
2?l[e2/00ol0003o<l`coc?<<`0:oc?<<`03o`000?mhQgSoN8Mh00GoN8Mh00?o0000oh=lPon3O8<0
1_n3O8<00ol0003o/dbcok=</`0;ok=</`03o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ok1?/2o`0001;ohacS00?o0000okE:]OneB[D00_neB[D00ol0003oVVFJoiYU
VP0:oiYUVP03o`000?lka3_o>l@k00?o>l@k0_l00009o`cc3003o`000?l;m0_o2o@;00Wo2o@;00?o
0000oa7^4OlAkQ402?lAkQ42o`0000So:m@[00?o0000oc?<<olcc3<02Olcc3<00ol0003oN8MhogR7
N007ogR7N003o`000?n3O8?oPgb300CoPgb300?o0000ok=</oncC;<02oncC;<00ol0003oj1OXonPG
j009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo/4nook1?/01ook1?/00ol0003ohacSon<Lh`0?on<Lh`?o000000?o]DZe
o`000?nJIIX02onJIIX00ol0003o>l@koc_4>`04oc_4>`03o`000?l<l`co3?<<00Wo3?<<00?o0000
o`_d2ol;m0/01ol;m0/00ol0003o4NhAoa7^4@09oa7^4@04o`000?lFjAKo0000o`0000Ko:m@[00?o
0000oc?<<olcc3<02Olcc3<00ol0003oN8MhogR7N008ogR7N003o`000?n3O8?oPgb300?oPgb300?o
0000ok=</oncC;<02oncC;<00ol0003oj1OXonPGj009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo/4nook1?/02?ok1?/0
0ol0003ohacSon<Lh`0<on<Lh`;o00000ooQ7^42o`0000coVVFJ00?o0000oc_4>olka3/01?lka3/0
0ol0003o3?<<o`cc300:o`cc30Wo00002olAkQ400ol0003o5^TFoaKY5P02oaKY5P?o00000_l[e2/0
0ol0003o<l`coc?<<`0:oc?<<`03o`000?mhQgSoN8Mh00WoN8Mh00?o0000oh=lPon3O8<00_n3O8<0
0ol0003o/dbcok=</`0:ok=</`03o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`09oo/4
n`;o00002_oS7><2o`0000GohAkQ00?o0000okI9]_l000002_nJIIX00ol0003o>l@koc_4>`06oc_4
>`03o`000?l<l`co3?<<00Wo3?<<00?o0000o`?l0ol3o0<01Ol3o0<00ol0003o4NhAoa7^4@09oa7^
4@03o`000?lFjAKo5^TF00Go5^TF0ol00009oc?<<`?o00003OmhQgP01Ol0003oPgb3oh=lPon3O8?o
000000co/dbc00?o0000onPGj?oX5nP02OoX5nP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck00con`Ck00?o0000on<L
hooS7><01OoS7><2o`0000OohAkQ00Co0000okI9]_nfBKKo00002OnJIIX00ol0003o>l@koc_4>`06
oc_4>`03o`000?l<l`co3?<<00So3?<<00?o0000o`?l0ol3o0<01ol3o0<00ol0003o4NhAoa7^4@07
oa7^4@03o`000?lFjAKo5^TF00So5^TF0ol00002oc?<<`Go00000_mEZUD00ol0003oN8MhogR7N00<
ogR7N003o`000?n3O8?o000000co/dbc00?o0000onPGj?oX5nP02_oX5nP00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ok1?_on`Ck
00gon`Ck00?o0000on<LhooS7><00_oS7><2o`0000SohAkQ00?o0000okI9]_nfBKH00_nfBKH5o`00
00CoVVFJ00?o0000oc_4>olka3/01_lka3/00ol0003o3?<<o`cc3008o`cc3003o`000?l3o0?o0o`3
00Oo0o`300?o0000oa7^4OlAkQ401olAkQ400ol0003o5^TFoaKY5P08oaKY5P03o`000?lUfRGo9MXU
00;o00002?mEZUD00ol0003oN8MhogR7N00<ogR7N0Co00002_ncC;<00ol0003oj1OXonPGj00:onPG
j003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo/4nook1?/03_ok1?/01?l0003ohacSo`000?l0000:on4Nh@03o`000?nfBKKo]TVf
00;o]TVf00?o0000ogJ9M_mfRGH00_mfRGH4o`0000Wo>l@k00?o0000o`cc3?l<l``02?l<l``00ol0
003o0o`3o`?l0`08o`?l0`03o`000?lAkQ7o4NhA00Go4NhA00?o0000oaKY5_lFjAH02?lFjAH01Ol0
003o9MXUobGJ9OlUfRGo000000[oEJYE0ol0000;ogR7N004o`000?oH9mSof2OHomPWf0Co00001Onc
C;<00ol0003oj1OXonPGj00;onPGj003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo/4nook1?/03ook1?/00ol0003ohAkQon4Nh@0:
on4Nh@03o`000?nfBKKo]TVf00?o]TVf00?o0000ogJ9M_mfRGH01?mfRGH00ol0003o>l@koc_4>`07
oc_4>`03o`000?l<l`co3?<<00Ko3?<<0_l0000;o`?l0`03o`000?lAkQ7o4NhA00Go4NhA00?o0000
oaKY5_lFjAH02?lFjAH00ol0003o9MXUobGJ9@02obGJ9@03o`000?mEZUGoEJYE00OoEJYE00?o0000
ojEJYOnUFZD01?l00006ogR7N003o`000?oH9mSof2OH00Kof2OH0ol00002ok=</`03o`000?oX5nSo
j1OX00_oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000okI9
]_nfBKH01?nfBKH00ol0003oMXUfogJ9MP05ogJ9MP03o`000?lka3_o>l@k00Oo>l@k00?o0000o`cc
3?l<l``00_l<l``3o`000003oa[U6_l0003o0o`300[o0o`300?o0000oa7^4OlAkQ401OlAkQ400ol0
003o5^TFoaKY5P07oaKY5P03o`000?lUfRGo9MXU00?o9MXU00?o0000oeFZEOmEZUD01omEZUD00ol0
003oYEZUojEJY@04ojEJY@?o00000_mhQgP00ol0003of2OHomPWf00:omPWf0;o00003_oX5nP00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ok1?_on`Ck013on`Ck00?o0000on4NhOoQ7^402OoQ7^400ol0003o]TVfokI9]P04okI9]P03
o`000?mfRGKoMXUf00KoMXUf0_l00007oc_4>`03o`000?l<l`co000000;o00001OlJiAX00ol0003o
0o`3o`?l0`08o`?l0`?o00001?lAkQ400ol0003o5^TFoaKY5P08oaKY5P03o`000?lUfRGo9MXU00Co
9MXU00?o0000oeFZEOmEZUD01_mEZUD00ol0003oYEZUojEJY@07ojEJY@;o00003_oH9mP00ol0003o
j1OXonPGj00;onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo/4nook1?/04Ook1?/00ol0003ohAkQon4Nh@08on4Nh@03o`00
0?nfBKKo]TVf00Go]TVf00?o0000ogJ9M_mfRGH01?mfRGH00ol0003oL8m`og2?L003o`0000Co>l@k
0_l00008oa[U6P03o`000?l3o0?o0o`300Oo0o`300Co0000oc;=<_lbcC;o</db0ol000000olAkQ7o
0000oaKY5P09oaKY5P03o`000?lUfRGo9MXU00Co9MXU00?o0000oeFZEOmEZUD01OmEZUD00ol0003o
YEZUojEJY@09ojEJY@03o`000?oH9mSof2OH00gof2OH00?o0000onPGj?oX5nP02_oX5nP00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ok1?_on`Ck017on`Ck00?o0000on4NhOoQ7^401ooQ7^400ol0003o]TVfokI9]P06okI9]P03o`00
0?mfRGKoMXUf00?oMXUf00?o0000og2?L?m`Sg001?m`Sg02o`000003oc_4>ol0003o6^DJ00[o6^DJ
00?o0000o`?l0ol3o0<01Ol3o0<00ol0003o</dboc;=<P05oc;=<P03o`000?lFjAKo5^TF00Oo5^TF
0ol00007obGJ9@03o`000?mEZUGoEJYE00CoEJYE00?o0000ojEJYOnUFZD02OnUFZD00ol0003of2OH
omPWf00=omPWf003o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oQ
7^7ohAkQ00GohAkQ0ol00009okI9]P05o`000?mfRGKoMXUfogJ9M_l000002Om`Sg000ol0003o6^DJ
oa[U6P0;oa[U6P03o`000?l3o0?o0o`300?o0o`300?o0000oc;=<_lbcC801_lbcC800ol0003o5^TF
oaKY5P06oaKY5P05o`000?lbcC;o</dboc;=<_l000001olUfRD00ol0003oEJYEoeFZE@03oeFZE@03
o`000?nUFZGoYEZU00WoYEZU00?o0000omPWf?oH9mP03_oH9mP00ol0003oj1OXonPGj009onPGj003
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo/4nook1?/04Ook1?/00ol0003ohAkQo`000004o`0000;ojaC[00?o0000okI9]_nfBKH0
1onfBKH01?l0003oMXUfogJ9M_l00009og2?L0;o00003OlJiAX00ol0003o0o`3o`?l0`02o`?l0`03
o`000?lbcC;o</db00So</db00?o0000oaKY5_lFjAH00olFjAH2o`0000Go</db00?o0000obGJ9OlU
fRD01?lUfRD00ol0003oEJYEoeFZE@03oeFZE@03o`000?nUFZGoYEZU00WoYEZU00?o0000omPWf?oH
9mP03_oH9mP00ol0003oj1OXonPGj009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo/4nook1?/04Ook1?/2o`0000SojaC[
00?o0000okI9]_nfBKH01_nfBKH00ol0003oMXUfo`000009og2?L004o`000?mB[E;oDZeBo`0000go
6^DJ00Co0000o`?l0ol3o0?o00003?lbcC801Ol0003o5^TFoaKY5_lFjAKo000000So</db0_l00005
obGJ9@03o`000?mEZUGoEJYE00;oEJYE00?o0000ojEJYOnUFZD02OnUFZD00ol0003of2OHomPWf00>
omPWf003o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o[5>_ojaC[
00OojaC[00?o0000okI9]_nfBKH01onfBKH00ol0003oL8m`og2?L007og2?L003o`000?mB[E;oDZeB
00;oDZeB00?o0000oa[U6_lJiAX02_lJiAX00ol0003o0o`3o`00000>oc;=<P03o`000?lFjAKo0000
00_o</db00?o0000obGJ9OlUfRD00_lUfRD01Ol0003oEJYEoeFZEOmEZUGo000000coYEZU00?o0000
omPWf?oH9mP03_oH9mP3o`0000Woj1OX00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o[5>_ojaC[
00WojaC[00?o0000okI9]_nfBKH01_nfBKH00ol0003oL8m`og2?L006og2?L003o`000?mB[E;oDZeB
00?oDZeB00?o0000oa[U6_lJiAX02olJiAX00ol0003o</dboc;=<P0>oc;=<P03o`000?lbcC;o</db
00_o</db0_l00003obGJ9@04o`000?mEZUGoEJYEo`0000[oYEZU0ol0000>omPWf0;o00000ool0o`2
o`0000Ooj1OX00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o[5>_ojaC[00[ojaC[00?o0000okI9
]_nfBKH01?nfBKH00ol0003oL8m`og2?L006og2?L003o`000?mB[E;oDZeB00GoDZeB00?o0000oa[U
6_lJiAX01olJiAX3o`00017o</db00?o0000oc;=<_lbcC803OlbcC801Ol0003o9MXUobGJ9Ol0003o
EJYE00Co00000onUFZD5o`0000;oi1_T00?o0000omPWf?oH9mP02_oH9mP2o`0000Ooo0?l0_l00004
onPGj003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo/4nook1?/03_ok1?/00ol0003ojaC[on/Dj`0;on/Dj`03o`000?nfBKKo]TVf
00Co]TVf00?o0000og2?L?m`Sg001Om`Sg000ol0003oDZeBoe:]DP06oe:]DP03o`000?lJiA[o6^DJ
00Co6^DJ0ol00002ob;M8P03o`000?lbcC;o</db00oo</db0_l0000?oc;=<P04o`000?lUfRGo0000
o`0000CoSg2?0ol00008on@Ki003o`000?oH9mSof2OH00Oof2OH0_l0000;oo`3o0;o00000_oX5nP0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ok1?_on`Ck00gon`Ck00?o0000on/Djoo[5>/03?o[5>/6o`0000OoL8m`00?o0000oe:]
D_mB[E802?mB[E800ol0003o6^DJoa[U6P03o`0000Ko8]dR00?o0000oc;=<_lbcC803OlbcC801?l0
003o?l0ooco0?ol0000?oc;=<P03o`000?n?L8ooSg2?00GoSg2?00?o0000on@Ki?oT6n@02?oT6n@0
0ol0003of2OHomPWf005omPWf003o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o[5>/00ol0003o_D:moke2_@04oke2
_@03o`000?m`Sg3oL8m`00?oL8m`00?o0000oe:]D_mB[E802_mB[E82o`0000[o8]dR00?o0000oc;=
<_lbcC802olbcC800ol0003o?l0ooco0?`02oco0?`03o`000?lbcC;o</db00_o</db0_l00007ohm`
S`03o`000?oT6nCoi1_T00Woi1_T00?o0000omPWf?oH9mP00_oH9mP2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000on/Djoo[5>/02oo[5>/00ol0003o_D:moke2_@06oke2_@05o`000?m`Sg3oL8m`og2?
L?l000003OmB[E800ol0003o8]dRob;M8P0:ob;M8P03o`000?lbcC;o</db00Wo</db00?o0000oco0
?olo`3l01?lo`3l00ol0003o</dboc;=<P08oc;=<P;o000000?o@[e2o`000?n?L8l01on?L8l00ol0
003oi1_Ton@Ki009on@Ki004o`000?oH9mSo0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?o[5>_ojaC[
00WojaC[00?o0000oke2_Onm@[d02?nm@[d00ol0003oL8m`o`00000=oe:]DP03o`000?lRgB;o8]dR
00_o8]dR00?o0000oc;=<_lbcC802?lbcC800ol0003o?l0ooco0?`06oco0?`03o`000?lbcC;o</db
00Go</db0_l00003od:m@P03o`000?n?L8ooSg2?00KoSg2?00?o0000on@Ki?oT6n@02_oT6n@00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ojaC[on/Dj`07on/Dj`03o`000?nm@[go_D:m00[o_D:m00?o0000oe:]D_mB
[E803?mB[E800ol0003o8]dRob;M8P0<ob;M8P03o`000?lbcC;o</db00Ko</db00?o0000oco0?olo
`3l02?lo`3l00ol0003o</dboc;=<P02oc;=<P;o00001_m2_D800ol0003oSg2?ohm`S`05ohm`S`03
o`000?oT6nCoi1_T00[oi1_T00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o[5>_ojaC[00GojaC[
00?o0000oke2_Onm@[d03?nm@[d2o`0000coDZeB00?o0000ob;M8_lRgB803OlRgB800ol0003o</db
oc;=<P04oc;=<P03o`000?lo`3oo?l0o00[o?l0o00Co0000oc;=<_l0003o00002?m2_D800ol0003o
Sg2?ohm`S`06ohm`S`03o`000?oT6nCoi1_T00Woi1_T00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_o[5>/00ol0003o_D:moke2_@0=oke2_@03o`000?maSW7o000000;o00002?mB[E800ol0003o8]dR
ob;M8P0?ob;M8PKo00003_lo`3l00ol0003o@[e2od:m@P08od:m@P03o`000?n?L8ooSg2?00KoSg2?
00?o0000on@Ki?oT6n@02OoT6n@00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000ondBkOo]4^gokA;]
0_l0000?oke2_@03o`000?maSW7oLHia00?oLHia0ol00005oe:]DP;o00004?lRgB801_l0003o5^TF
oaKY5_l0003o2OH9o`0000ko?l0o00?o0000od:m@_m2_D802Om2_D800ol0003oSg2?ohm`S`05ohm`
S`03o`000?oT6nCoi1_T00Woi1_T00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003o
_D:moke2_@0=oke2_@03o`000?maSW7oLHia00KoLHia0ol000001?mB[E;o0000obcC;?l/db`3o`00
00co8]dR00Go0000oaKY5_lFjAKo5^TFo`000002o`Wf2@03o`000?lo`3oo?l0o00_o?l0o00?o0000
od:m@_m2_D802Om2_D800ol0003oSg2?ohm`S`06ohm`S`03o`000?oT6nCoi1_T00Soi1_T0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003okA;]ondBk@04ondBk@oo00003?maSW400ol0003o;=</obcC;004obcC
;0?o00002?lRgB800ol0003o5^TFoaKY5P02oaKY5P05o`000?l9mPWo2OH9o`Wf2Ol000003?lo`3l0
0ol0003o@[e2od:m@P09od:m@P03o`000?n?L8ooSg2?00GoSg2?3?l00002oo<<l`;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003okA;]ondBk@05ondBk@03o`000?nm@[go_D:m00_o_D:m00?o0000og6>
LOmaSW402_maSW400ol0003o;=</obcC;007obcC;0;o00001OlRgB800ol0003o5^TFoaKY5P03oaKY
5P03o`000?l9mPWo2OH900;o2OH900?o0000oco0?olo`3l02Olo`3l00ol0003o@[e2od:m@P0:od:m
@P03o`000?n?L8ooSg2?00?oSg2?00?o0000omLXeooG:=L02OoG:=L00ol0003ol`ccoo<<l`02oo<<
l`;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okA;]ondBk@06ondBk@03o`000?nm@[go_D:m00[o
_D:m00?o0000og6>LOmaSW402omaSW400ol0003o;=</obcC;009obcC;0?o000000?o8]dRo`000?lF
jAH01OlFjAH00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?lo`3oo?l0o00So?l0o3_l00003ohm`S`;o
00002ooG:=L00ol0003ol`ccoo<<l`05oo<<l`03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000ondBkOo]4^d01Oo]4^d00ol0003obCK9o`00000;oke2_@03o`000?maSW7oLHia00[oLHia
0_l0000>obcC;003o`000?lFjAKo5^TF00Go5^TF00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o?l0o
oco0?`08oco0?`03o`000?n;M8_oRgB;00_oRgB;00?o0000ohm`Sol000003OoG:=L00ol0003ol`cc
oo<<l`06oo<<l`;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00KokA;]00Co
0000olTfbOo9=/Wo00002_nm@[d00ol0003oLHiaog6>L@09og6>L@03o`000?m;]4_o000000ko;=</
00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2OH9o`Wf2@04o`Wf2@03o`000?lo`3oo?l0o00Ko?l0o
00?o0000oh]dRon;M8/03On;M8/00ol0003oebSGomLXe`0<omLXe`03o`000?oc3??ol`cc00Sol`cc
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]00GokA;]00?o0000olTfbOo9=/T00_o9
=/T00ol0003o_D:moke2_@06oke2_@03o`000?maSW7oLHia00SoLHia0_l00003od^dB`03o`000?l/
dbco;=</00_o;=</00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?lo
`3oo?l0o00Go?l0o00?o0000oh]dRon;M8/03On;M8/00ol0003oebSGomLXe`0;omLXe`03o`000?oc
3??ol`cc00Wol`cc00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000
olTfbOo9=/T00oo9=/T00ol0003o_D:moke2_@05oke2_@03o`000?maSW7oLHia00OoLHia00?o0000
od^dBom;]4/00om;]4/00ol0003o;=</obcC;00:obcC;003o`000?lFjAKo5^TF00Ko5^TF00?o0000
o`Wf2Ol9mPT01_l9mPT00ol0003o?l0ooco0?`04oco0?`03o`000?n;M8_oRgB;00goRgB;3ol0000;
oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000olTfbOo9=/T01Oo9=/T00ol0
003o_D:moke2_@04oke2_@03o`000?maSW7oLHia00GoLHia0_l00006od^dB`03o`000?l/dbco;=</
00Wo;=</0_l00008oaKY5P03o`000?l9mPWo2OH900Ko2OH91Ol000000olo`3oo0000oh]dR`0?oh]d
R`03o`000?oI9]WofBKI00_ofBKI00?o0000oo<<looc3?<02Ooc3?<00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o]4^gokA;]00KokA;]00?o0000olTfbOo9=/T01_o9=/T00ol0003o
_D:moke2_@04o`0000KoLHia00?o0000od^dBom;]4/01om;]4/00ol0003o;=</obcC;005obcC;0?o
000000?o6^DJo`000?lFjAH01olFjAH00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?m</dcoC;=<00?o
C;=<0_l0000?oh]dR`;o00003OoI9]T00ol0003ol`ccoo<<l`08oo<<l`03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WokA;]00?o0000olTfbOo9=/T01oo9=/T2o`0000CoXebS00Co0000og6>LOmaSW7o
LHia0_l0000:od^dB`03o`000?l/dbco;=</00;o;=</0ol00005oa[U6P03o`000?lFjAKo5^TF00Go
5^TF00?o0000o`Wf2Ol9mPT01?l9mPT00ol0003oC;=<odbcC006odbcC003o`000?n;M8_oRgB;00[o
RgB;0_l00002okM8]`03o`000?oI9]WofBKI00[ofBKI00?o0000oo<<looc3?<02?oc3?<00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000ondBkOo]4^d01_o]4^d00ol0003obCK9olTfb@08olTfb@03o`00
0?nSG:?oXebS00CoXebS00?o0000og6>LOl000003?m;]4/00ol0003o;=</o`000002o`0000Wo6^DJ
00?o0000oaKY5_lFjAH01?lFjAH00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?m</dcoC;=<00SoC;=<
1_l00004oh]dR`;o00001OngB;L00ol0003ofBKIomTVf@09omTVf@03o`000?oc3??ol`cc00Sol`cc
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00GokA;]00?o0000olTfbOo9=/T01oo9
=/T00ol0003oXebSoj=LX`06oj=LX`03o`000?m;]4_oBkA;00coBkA;00?o0000oa[U6_lJiAX02_lJ
iAX00ol0003o5^TFoaKY5P04oaKY5P04o`000?l9mPWo2OH9o`Wf2@;o00002om</d`00ol0003oTVfB
oi9]TP03oi9]TPCo00002?ngB;L00ol0003ofBKIomTVf@08omTVf@03o`000?oc3??ol`cc00Ool`cc
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000ondBkOo]4^d00oo]4^d00ol0003obCK9olTfb@07olTfb@03o`000?nS
G:?oXebS00OoXebS00?o0000od^dBom;]4/03?m;]4/00ol0003o6^DJoa[U6P0;oa[U6P03o`000?lF
jAKo5^TF00?o5^TF00Co0000o`Wf2Ol9mPWo00003Om</d`00ol0003oTVfBoi9]TP06oi9]TP03o`00
0?ngB;Oo]dRg00Oo]dRg00?o0000omTVfOoI9]T01ooI9]T00ol0003ol`ccoo<<l`06oo<<l`04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]4^gokA;]00;okA;]00?o0000olTfbOo9=/T0
1_o9=/T00ol0003oXebSoj=LX`09oj=LX`03o`000?m;]4_oBkA;00WoBkA;0_l0000>oa[U6P?o0000
0olFjAH00ol0003o2OH9o`00000=odbcC003o`000?nBKI;oTVfB00OoTVfB00?o0000okM8]ongB;L0
2?ngB;L:o`0000Kol`cc0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000OobCK900?o
0000oj=LXonSG:<02_nSG:<00ol0003oBkA;od^dB`06od^dB`;o000000?o@[e2o`000?lJiAX02olJ
iAX2o`0000?o?<<l1Ol0000>odbcC003o`000?nBKI;oTVfB00OoTVfB00?o0000okM8]ongB;L02?ng
B;L00ol0003ohQgRon8MhP06on8MhP03o`000?oc3??ol`cc00?ol`cc00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003ohacSon<Lh`03on<Lh`Co00000_o9=/T00ol0003oXebSoj=LX`0;
oj=LX`03o`000?m;]4_oBkA;00?oBkA;0ol00004od:m@P03o`000?lJiA[o6^DJ00Oo6^DJ0_l00008
occ3?003o`000?m</dcoC;=<00goC;=<00?o0000oi9]T_nBKI802?nBKI800ol0003o]dRgokM8]`07
okM8]`03o`000?oR7N;ohQgR00OohQgR0ol000000ooc3??o0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oS7>?ohacS00OohacS0_l0000?oj=LX`03o`000?m;]4_oBkA;00;o00002?m2_D800ol0
003o6^DJoa[U6P05oa[U6P03o`000?ll`cco?<<l00So?<<l00?o0000odbcC?m</d`03Om</d`00ol0
003oTVfBoi9]TP08oi9]TP03o`000?ngB;Oo]dRg00Ko]dRg00?o0000on8Mh_oR7N802?oR7N801?l0
003om0_doo@;m?l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ohacSon<Lh`09on<L
h`03o`000?nSG:?oXebS00koXebS0_l0000;od:m@P03o`000?lJiA[o6^DJ00;o6^DJ0_l0000;occ3
?003o`000?m</dcoC;=<00goC;=<00?o0000oi9]T_nBKI802?nBKI800ol0003o]dRgokM8]`06okM8
]`03o`000?oR7N;ohQgR00OohQgR00Go0000oo@;m?od2oCom0_do`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003ohacSon<Lh`0:on<Lh`03o`000?nSG:?oXebS00goXebS0_l0000<od:m@P04o`000?lJiA[o0000
o`0000go?<<l00?o0000odbcC?m</d`03?m</d`00ol0003oTVfBoi9]TP09oi9]TP03o`000?ngB;Oo
]dRg00Ko]dRg00?o0000on8Mh_oR7N801_oR7N800ol0003om0_doo@;m003oo@;m003o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003ohacSon<Lh`0:on<Lh`03o`000?nSG:?oXebS00coXebS00Co0000oh5n
POn1OX7o00003?m2_D800ol0003o?<<locc3?00>occ3?003o`000?m</dcoC;=<00SoC;=<1?l0000;
oi9]TP03o`000?ngB;Oo]dRg00Ko]dRg00?o0000on8Mh_oR7N801OoR7N800ol0003om0_doo@;m004
oo@;m003o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ohacSon<Lh`0;on<Lh`03o`000?nSG:?oXebS
00_oXebS00?o0000oh5nPOn1OX400_n1OX400ol0003o@[e2od:m@P09od:m@P03o`000?ll`cco?<<l
00ko?<<l00Co0000odbcC?m</dcoC;=<1ol00003of>LH`03o`000?nBKI;oTVfB00WoTVfB00?o0000
okM8]ongB;L01_ngB;L00ol0003ohQgRon8MhP04on8MhP03o`000?od2oCom0_d00Kom0_d00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oS7>?ohacS00cohacS00?o0000oj=LXonSG:<02_nSG:<00ol0
003oPGj1oh5nP@03oh5nP@03o`000?m2_D;o@[e200So@[e200?o0000occ3??ll`c`03_ll`c`4o`00
00_oHiaS00?o0000oi9]T_nBKI802?nBKI800ol0003o]dRgokM8]`05okM8]`03o`000?oR7N;ohQgR
00GohQgR00?o0000oo@;m?od2o@01_od2o@00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on<LhooS
7><03?oS7><7o`0000GoXebS00?o0000oh5nPOn1OX401On1OX400ol0003o@[e2od:m@P07od:m@P03
o`000?ll`cco?<<l00ko?<<l00?o0000of>LHomSW6<03OmSW6<00ol0003oTVfBoi9]TP08oi9]TP03
o`000?ngB;Oo]dRg00Co]dRg00?o0000on8Mh_oR7N801?oR7N800ol0003om0_doo@;m007oo@;m003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003ohacSon<Lh`0=on<Lh`03o`000?o2?L;o`Sg200Co`Sg2
1Ol00009oh5nP@03o`000?m2_D;o@[e200Ko@[e200?o0000occ3??ll`c`03_ll`c`00ol0003oHiaS
of>LH`0=of>LH`03o`000?nBKI;oTVfB00SoTVfB00Co0000okM8]ongB;Oo]dRg1Ol00004on8MhP03
o`000?od2oCom0_d00Wom0_d1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=on<Lh`03o`000?o2?L;o`Sg200Wo`Sg2
0_l00009oh5nP@03o`000?m2_D;o@[e200Ko@[e200?o0000occ3??ll`c`03?ll`c`00ol0003oHiaS
of>LH`0?of>LH`Ko00001?nBKI84o`0000GogR7N0_l000000ooR7N;o0000oo@;m00;oo@;m004o`00
0?om0_goo@;mood2o@Oo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o`3o3ol0o`oo0?l0?o00002_oS7><00ol0003o
`Sg2ol8m`P09ol8m`P03o`000?nEJYGo000000;o00001on1OX400ol0003o@[e2od:m@P05od:m@P03
o`000?ll`cco?<<l00So?<<l1Ol0000Aof>LH`03o`000?nRGJ;oXUfR00?oXUfR1?l0000;omhQgP03
o`000?od2oCom0_d00[om0_d00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000oo0?l?o`3o001Oo`3o02o`0000OohacS
00?o0000ol8m`_o2?L802_o2?L800ol0003oUFZEoiEZU@02oiEZU@?o00001On1OX400ol0003o@[e2
od:m@P04od:m@P04o`000?ll`cco?<<locc3?0Oo00001?m@[e000ol0003oHiaSof>LH`0>of>LH`03
o`000?nRGJ;oXUfR00OoXUfR00?o0000omhQg_oN8Mh02OoN8Mh00ol0003om0_doo@;m009oo@;m003
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ol0o`oo0?l008oo0?l0;o00001?oS7><00ol0003o`Sg2
ol8m`P0;ol8m`P03o`000?nEJYGoUFZE00GoUFZE0ol00003oh5nP@04o`000?m2_D;o@[e2od:m@PKo
00003?m@[e000ol0003oHiaSof>LH`0=of>LH`03o`000?nRGJ;oXUfR00OoXUfR00?o0000omhQg_oN
8Mh02_oN8Mh00ol0003om0_doo@;m008oo@;m003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo0?l0?o000000?ohacSo`000?o2?L80
3?o2?L800ol0003oUFZEoiEZU@08oiEZU@?o000000CoPGj1o`000?l0003o00000_nFJIH00ol0003o
D:m@oe2_D00=oe2_D003o`000?mSW6?oHiaS00coHiaS00?o0000oj9MX_nRGJ802?nRGJ800ol0003o
gR7NomhQgP0;omhQgP03o`000?od2oCom0_d00Kom0_d00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
l0o`00?o0000ol8m`_o2?L803?o2?L800ol0003oUFZEoiEZU@0;oiEZU@03o`000?nFJIKoUVVF00?o
UVVF00?o0000oe2_D?m@[e003?m@[e000ol0003oE:]Do`00000=of>LH`03o`000?nRGJ;oXUfR00So
XUfR00?o0000omhQg_oN8Mh03?oN8Mh3o`0000Gom0_d00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o`3o3ol0o`00col0o`00?o0000ol8m`_o2?L803?o2?L800ol0003oUFZEoiEZU@0:oiEZU@03o`00
0?nFJIKoUVVF00GoUVVF00?o0000oe2_D?m@[e002_m@[e001?l0003oE:]DoeB[E?mDZe@2o`0000[o
HiaS00?o0000oj9MX_nRGJ802OnRGJ800ol0003ogR7NomhQgP0<omhQgP03o`000?of2OKomPWf00?o
000000?om0_do`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000ol8m`_o2?L80
3?o2?L800ol0003oUFZEoiEZU@09oiEZU@03o`000?nFJIKoUVVF00KoUVVF00?o0000oe2_D?m@[e00
2Om@[e000ol0003oE:]DoeB[E002oeB[E003o`000?nGJ9Oo000000;o00001omSW6<00ol0003oXUfR
oj9MXP09oj9MXP03o`000?oN8MkogR7N00_ogR7N00?o0000ooH9m_of2OH01?of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002oo`3o000ol0003o`Sg2ol8m`P0;ol8m`P03o`000?nE
JYGoUFZE00SoUFZE00?o0000oiIYU_nFJIH01onFJIH00ol0003oD:m@oe2_D008oe2_D003o`000?mD
ZeCoE:]D00?oE:]D00?o0000oiMXUonGJ9L00_nGJ9L2o`0000CoHiaS00?o0000oj9MX_nRGJ802_nR
GJ800ol0003ogR7NomhQgP0:omhQgP03o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o`3o3ol0o`00[ol0o`0ol0000;ol8m`PKo00001?nEJYD00ol0003oUVVFoiIYUP08
oiIYUP03o`000?m@[e3oD:m@00OoD:m@00?o0000oeB[E?mDZe@00omDZe@00ol0003oUfRGoiMXU`05
oiMXU`?o000000?oHiaSo`000?nRGJ802onRGJ800ol0003ogR7NomhQgP09omhQgP03o`000?of2OKo
mPWf00OomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o`3o3ol0o`00Wol0o`00?o0000omhQ
g_oN8Mh01?l00006ol8m`P03o`000?o1?/7o`Ck100Co`Ck11?l0000<oiIYUP03o`000?m@[e3oD:m@
00GoD:m@00?o0000oeB[E?mDZe@01?mDZe@00ol0003oUfRGoiMXU`08oiMXU`03o`000?nRGJ;oXUfR
00_oXUfR00?o0000omhQg_oN8Mh02?oN8Mh00ol0003omPWfooH9mP08ooH9mPGo00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o`3o3ol0o`00Ool0o`00?o0000omhQg_oN8Mh01OoN8Mh3o`0000;o`Sg200?o0000ol4n`Oo1
?/402?o1?/400ol0003oUVVFoiIYUP0:oiIYUP03o`000?m@[e3oD:m@00CoD:m@00?o0000oeB[E?mD
Ze@01OmDZe@00ol0003oUfRGoiMXU`08oiMXU`03o`000?nRGJ;oXUfR00WoXUfR1?l00008omhQgP03
o`000?of2OKomPWf00WomPWf00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`
oo0?l005oo0?l003o`000?oN8MkogR7N00WogR7N0_l0000<ol4n`@03o`000?nFJIKoUVVF00WoUVVF
00?o0000oe2_D?m@[e000om@[e000ol0003oE:]DoeB[E005oeB[E003o`000?nGJ9OoUfRG00[oUfRG
00?o0000oj9MX_nRGJ801?nRGJ84o`0000CoeB[E00?o0000omhQg_oN8Mh01?oN8Mh00ol0003omPWf
ooH9mP0:ooH9mP03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o`3o3ol0o`00?ol0o`00?o0000omhQg_oN8Mh02ooN
8Mh00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?nFJIKoUVVF00WoUVVF00?o0000oe2_D?m@[e000_m@
[e000ol0003oE:]DoeB[E006oeB[E003o`000?nGJ9OoUfRG00[oUfRG00?o0000oj9MX_nRGJ801?l0
0009omDZe@Ko00003?of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo0?l?o`3o3ol0o`0_l0
000=omhQgP03o`000?o1?/7o`Ck100[o`Ck100?o0000oiIYU_nFJIH02OnFJIH01Ol0003oD:m@oe2_
D?m@[e3o000000WoE:]D00?o0000oiMXUonGJ9L02onGJ9L2o`0000goeB[E00?o0000oo<<looc3?<0
0_oc3?<00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol0o`o`00
0002ooP7n0;o00002ooN8Mh00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?nFJIKoUVVF00WoUVVF00?o
0000oe2_D?l000002OmDZe@00ol0003oUfRGoiMXU`0<oiMXU`03o`000?oE:]GoeB[E00coeB[E00?o
0000oo<<looc3?<00ooc3?<00ol0003omPWfooH9mP09ooH9mP03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on0OhooP7n003ooP7n0;o00002_oN8Mh00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?nFJIKo
UVVF00SoUVVF1Ol00008oeB[E003o`000?nGJ9OoUfRG00coUfRG00?o0000omDZeOoE:]D02ooE:]D0
0ol0003ol`ccoo<<l`05oo<<l`03o`000?of2OKomPWf00SomPWf00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooh1oP2o`0000SogR7N00?o0000ol4n`Oo1?/402_o1?/400ol0003oUVVFoiIYUP07oiIY
UP03o`000?nFJIKoUVVF00?oUVVF0ol00005oeB[E003o`000?nGJ9OoUfRG00_oUfRG00?o0000omDZ
eOoE:]D03?oE:]D00ol0003ol`ccoo<<l`06oo<<l`03o`000?of2OKomPWf00OomPWf00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Won0Oh00?o0000omhQg_oN8Mh01OoN8Mh2o`0000co
`Ck100?o0000oiIYU_nFJIH01OnFJIH00ol0003oUVVFoiIYUP07oiIYUP?o000000?oE:]Do`000?nG
J9L03OnGJ9L00ol0003oeB[EomDZe@0<omDZe@03o`000?oc3??ol`cc00Kol`cc00?o0000ooH9m_of
2OH01_of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?oh1oSon0Oh00Oon0Oh
0_l00004omhQgP03o`000?oV6NKoiQWV00;o00002_o1?/400ol0003oUVVFoiIYUP03oiIYUP;o0000
3OnFJIH2o`0000goUfRG0ol0000=omDZe@03o`000?oc3??ol`cc00Ool`cc00?o0000ooH9m_of2OH0
1Oof2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Son0Oh0_l0
00000ooN8Mko0000onHIiP04onHIiP03o`000?o1?/7o`Ck100Oo`Ck100Co0000oiIYU_nFJIKoUVVF
0_l00002ol<l``03o`000?nFJIKoUVVF00coUVVF3Ol00003om8]dP03o`000?oE:]GoeB[E00[oeB[E
00?o0000oo<<looc3?<02?oc3?<01?l0003omPWfooH9m_of2OH4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003on0Oh
ooP7n009ooP7n003o`000?oV6NKoiQWV00GoiQWV0_l00008ol4n`@03o`000?nFJIKo000000Go`cc3
00?o0000oiIYU_nFJIH02onFJIH00ol0003oY5^TojAKY009ojAKY003o`000?oB;M;odRgB00;odRgB
0_l00009omDZe@03o`000?oc3??ol`cc00[ol`cc0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?oh1oSon0Oh00Son0Oh00?o0000onHIi_oV6NH01ooV6NH4o`0000?o`Ck10ol0
0007ol<l``03o`000?nFJIKoUVVF00[oUVVF00?o0000ojAKY?nTFj@02OnTFj@00ol0003odRgBom8]
dP04om8]dP;o00001ooE:]D00ol0003ol`ccoo<<l`0:oo<<l`03o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oh1oSon0Oh00Oon0Oh00?o0000onHIi_oV6NH02?oV6NH0
1?l0003oiA[UonDJiOoU6^D3o`0000;ofBKI00?o0000ol<l`oo3?<<01_o3?<<00ol0003oUVVFoiIY
UP08oiIYUP03o`000?nTFjCoY5^T00[oY5^T00?o0000om8]d_oB;M801_oB;M800ol0003oeB[EomDZ
e@04omDZe@03o`000?oc3??ol`cc00Wol`cc00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oiQWVonHIiP08onHIiP03o`000?oU6^Go
iA[U00CoiA[U00Go0000omTVfOoI9]WofBKIo`000008ol<l``03o`000?nFJIKoUVVF00OoUVVF00?o
0000ojAKY?nTFj@02_nTFj@00ol0003odRgBom8]dP07om8]dP;o00001?oE:]D00ol0003ol`ccoo<<
l`08oo<<l`03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7n?oh1oP00ooh1oP0
0ol0003oiQWVonHIiP08onHIiP03o`000?oU6^GoiA[U00CoiA[U00?o0000omTVfOoI9]T00_oI9]T0
0ol0003o`cc3ol<l``07ol<l``03o`000?nFJIKoUVVF00KoUVVF00?o0000ojAKY?nTFj@02_nTFj@0
0ol0003odRgBom8]dP09om8]dP05o`000?oE:]GoeB[EomDZeOl000002Ooc3?<00ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oiQWV00?o0000onDJiOoU6^D01?oU6^D00ol0003ofBKIomTVf@03
omTVf@03o`000?o3?<?o`cc300Oo`cc300?o0000oiIYU_nFJIH01OnFJIH00ol0003oY5^TojAKY00:
ojAKY003o`000?oB;M;odRgB00WodRgB1?l00009oo<<l`03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oh1oSon0Oh
ooP7n?l000002_oV6NH00ol0003oiA[UonDJi@05onDJi@03o`000?oI9]WofBKI00?ofBKI00?o0000
ol<l`oo3?<<02?o3?<<00ol0003oUVVFoiIYUP04oiIYUP03o`000?nTFjCoY5^T00WoY5^T00?o0000
om8]d_oB;M802?oB;M82o`0000?ol`cc00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooP7n?oh1oP00ooh1oP00ol0003oiQWVonHIiP06onHIiP03o`000?oU6^GoiA[U
00GoiA[U00?o0000omTVfOoI9]T01?oI9]T00ol0003o`cc3ol<l``09ol<l``03o`000?nFJIKoUVVF
00;oUVVF00?o0000ojAKY?nTFj@02_nTFj@00ol0003odRgBom8]dP06om8]dP;o00001_oc3?<8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003on0OhooP7n005ooP7n003o`000?oV6NKoiQWV00GoiQWV00?o0000onDJiOoU
6^D01OoU6^D00ol0003ofBKIomTVf@05omTVf@03o`000?o3?<?o`cc300Wo`cc300Go0000oiIYU_nF
JIKoUVVFo`00000<ojAKY003o`000?oB;M;odRgB00CodRgB0_l00008oo<<l`03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oh1oSon0Oh00Oon0Oh00?o0000onHIi_oV
6NH00ooV6NH00ol0003oiA[UonDJi@06onDJi@03o`000?oI9]WofBKI00GofBKI00?o0000ol<l`oo3
?<<02_o3?<<00ol0003oUVVFo`000004o`0000WoY5^T00?o0000om8]d_oB;M800_oB;M82o`0000[o
l`cc00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003on0OhooP7n007ooP7n003o`00
0?oV6NKoiQWV00;oiQWV00?o0000onDJiOoU6^D01_oU6^D00ol0003ofBKIomTVf@07omTVf@;o0000
2oo3?<<00ol0003ogR7NomhQgP03omhQgPOo00000_nTFj@00ol0003odRgBom8]dP02o`0000_ol`cc
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooP7n?oh1oP02Ooh
1oP01Ol0003oiQWVonHIi_oV6NKo000000SoiA[U00?o0000omTVfOoI9]T01ooI9]T00ol0003okA;]
o`000002o`0000So`cc300?o0000omhQg_oN8Mh02_oN8Mh5o`0000gol`cc00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooP7n003o`000?oV6NKo000000WoiA[U00?o
0000omTVfOoI9]T01_oI9]T00ol0003okA;]ondBk@03ondBk@?o00001?o3?<<00ol0003ogR7NomhQ
gP0=omhQgP03o`000?oc3??ol`cc00gol`cc00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_on0Oh00?o0000onDJiOoU6^D01ooU6^D00ol0003ofBKIomTVf@07
omTVf@03o`000?o]4^gokA;]00KokA;]0ol000000oo3?<?o0000omhQgP0>omhQgP03o`000?oc3??o
l`cc00col`cc00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooP7
n003o`000?oU6^GoiA[U00;oiA[U1_l00008omTVf@03o`000?o]4^gokA;]00[okA;]00?o0000omhQ
g_oN8Mh03ooN8Mh00ol0003ol`ccoo<<l`0:oo<<l`;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooP7n0Go00001_od2o@00ol0003ofBKIomTVf@05omTVf@03o`000?o]4^gokA;]00[o
kA;]00?o0000omhQg_oN8Mh03ooN8Mh00ol0003ol`ccoo<<l`07oo<<l`?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooP7n003o`000?od2oCom0_d00Wom0_d00?o0000omTVfOoI
9]T00ooI9]T00ol0003okA;]ondBk@0;ondBk@03o`000?oN8MkogR7N00oogR7N00?o0000oo<<looc
3?<01Ooc3?<2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on0Oho`000?l00000
3Ood2o@00ol0003ofBKIomTVf@02omTVf@03o`000?o]4^gokA;]00_okA;]5?l00004oo<<l`;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003oo@;mo`00000>oo@;m004o`000?oI9]WofBKIo`0000kokA;]
00?o0000ooH9m_of2OH04?of2OH00ol0003ol`cco`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?om0_goo@;mood2oOl000003_od2o@00ol0003ofBKIo`00000>ondBk@03o`00
0?of2OKomPWf017omPWf00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ood2oOom0_d00_om0_d00ol0003om0_doo@;m00=oo@;m003o`000?o]4^gokA;]00WokA;]1Ol0
000BooH9mP;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d0
0ol0003om0_doo@;m00<oo@;m003o`000?o]4^gokA;]00;okA;]1ol00004ood2o@03o`000?of2OKo
mPWf00oomPWf00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo@;mood2o@06ood2
o@03o`000?od2oCom0_d00com0_d1?l0000<ood2o@03o`000?of2OKomPWf00comPWf0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003oo@;mood2o@0=ood2o@03o`000?of2OKomPWf00_o
mPWf00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00koo@;m00?o0000ooH9m_of
2OH02Oof2OH2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000oo@;m?od2o@02_od2o@00ol0003oo@;m
ood2o@0?ood2o@03o`000?of2OKomPWf00KomPWf0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003oo@;m00goo@;m3?l0
000Aood2o@?o00001_of2OH00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000oof2OH2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?om0_go
o@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooH9m_l000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?om0_goo@;m00[o
o@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ood2
o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool01ol00?l9oooo00Ko003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`06o`00o`Soool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool01_l00?l00oooo`3o003oo`00o`03o`00o`;oool00ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000go003o00?oool0o`00ool00?l01Ol00?l00ooo
o`3o003oo`00o`03o`00o`04oooo0?l00?oo003oo`00o`;oool01Ol00?l00oooo`3o003oo`00o`05
o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol0
0?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo000=o`00
o`;oool01_l00?l2oooo00So003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00
o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?oo
ool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool03Ol00?l2oooo00Oo
003o00?oool0o`00ool00?l01Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00
J_l00?l2oooo00;o003o00Coool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co
003o0_ooo`04o`00o`?oool01?l00?l2oooo00go003o0_ooo`08o`00o`03oooo0?l00?oo003o00Co
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo
0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o0oooo`09o`00o`03oooo0?l00?oo003o00?o
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo
0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`04o`00o`04oooo0?l00?ooool0oooo00_o003o0oooo`0:o`00o`;oool01?l00?l2oooo00Ko
003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`00
0_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o
0_ooo`000ol00?ooool0oooo0008o`00o`Goool03?l00?l00oooo`3o003oo`00o`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?o
ool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_oo
o`0:o`00o`;oool03Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02ol00?l2
oooo00co003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00
o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00co003o0_ooo`04o`00
o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00
o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Go
003o00?oool0o`00ool00?l01?l00?l2oooo00Co003o0_ooo`05o`00o`;oool01?l00?l2oooo00Co
003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo
0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o
0_ooo`05o`00o`;oool00ol00?l3oooo00Co003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00?o003o0_ooo`03o`00o`;oool01ol00?l6oooo00Ko003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0P
o`00o`Coool02Ol00?l4oooo00So003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(330) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.992 .008 .992 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.993 .007 .993 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.993 .007 .993 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.992 .008 .992 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.965 .035 .965 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.99 .01 .99 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.965 .035 .965 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.958 .042 .958 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.939 .061 .939 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.986 .014 .986 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.927 .073 .927 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.992 .008 .992 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.858 .142 .858 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.872 .128 .872 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.777 .223 .777 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.908 .092 .908 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.985 .015 .985 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.987 .013 .987 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.962 .038 .962 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.601 .399 .601 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.913 .087 .913 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.801 .199 .801 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.793 .207 .793 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.838 .162 .838 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.909 .091 .909 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.941 .059 .941 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.772 .228 .772 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.892 .108 .892 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.664 .336 .664 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.933 .067 .933 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.892 .108 .892 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.825 .175 .825 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.885 .115 .885 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.694 .306 .694 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.922 .078 .922 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.798 .202 .798 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.994 .006 .994 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.942 .058 .942 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.719 .281 .719 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.378 .622 .378 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.447 .553 .447 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.971 .029 .971 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.972 .028 .972 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.878 .122 .878 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.992 .008 .992 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.75 .25 .75 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.751 .249 .751 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.458 .542 .458 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.461 .539 .461 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.305 .695 .305 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.724 .276 .724 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.768 .232 .768 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.993 .007 .993 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.744 .256 .744 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.647 .353 .647 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.954 .046 .954 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.483 .517 .483 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.908 .092 .908 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.849 .151 .849 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.458 .542 .458 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.319 .681 .319 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.621 .379 .621 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.068 .932 .068 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.093 .907 .093 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.239 .761 .239 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.454 .546 .454 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.455 .545 .455 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.903 .097 .903 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.189 .811 .189 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.21 .79 .21 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.765 .235 .765 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.957 .043 .957 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.991 .009 .991 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.243 .757 .243 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.303 .697 .303 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.602 .398 .602 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.991 .009 .991 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.711 .289 .711 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.327 .673 .327 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.526 .474 .526 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.079 .921 .079 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.475 .525 .475 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.271 .729 .271 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.96 .04 .96 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.106 .894 .106 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.042 .958 .042 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.857 .143 .857 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.054 .946 .054 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.025 .975 .025 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.597 .403 .597 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.912 .088 .912 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.235 .765 .235 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.048 .952 .048 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.458 .542 .458 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.102 .898 .102 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.178 .822 .178 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.93 .07 .93 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.023 .977 .023 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.132 .868 .132 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.107 .893 .107 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.775 .225 .775 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.236 .764 .236 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.305 .695 .305 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.066 .934 .066 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.085 .915 .085 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.139 .861 .139 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.038 .962 .038 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.01 .99 .01 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.325 .675 .325 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.599 .401 .599 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.991 .009 .991 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.794 .206 .794 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.184 .816 .184 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.237 .763 .237 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.348 .652 .348 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.962 .038 .962 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.089 .911 .089 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.188 .812 .188 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.63 .37 .63 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.039 .961 .039 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.992 .008 .992 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.062 .938 .062 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.875 .125 .875 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.965 .035 .965 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.601 .399 .601 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.656 .344 .656 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.117 .883 .117 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.9 .1 .9 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.023 .977 .023 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.3 .7 .3 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.493 .507 .493 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.083 .917 .083 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.247 .753 .247 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.397 .603 .397 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.991 .009 .991 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.991 .009 .991 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.937 .063 .937 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.19 .81 .19 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.163 .837 .163 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.04 .96 .04 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.833 .167 .833 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.2 .8 .2 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.956 .044 .956 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.215 .785 .215 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.231 .769 .231 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.241 .759 .241 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.647 .353 .647 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.76 .24 .76 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.584 .416 .584 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.036 .964 .036 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.156 .844 .156 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.273 .727 .273 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.559 .441 .559 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.841 .159 .841 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.992 .008 .992 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.949 .051 .949 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.202 .798 .202 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.349 .651 .349 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.206 .794 .206 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.837 .163 .837 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.728 .272 .728 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.991 .009 .991 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.575 .425 .575 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.873 .127 .873 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.954 .046 .954 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.146 .854 .146 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.259 .741 .259 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.94 .06 .94 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.177 .823 .177 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.658 .342 .658 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.561 .439 .561 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.481 .519 .481 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.386 .614 .386 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.897 .103 .897 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.85 .15 .85 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.859 .141 .859 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.893 .107 .893 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.397 .603 .397 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.964 .036 .964 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.809 .191 .809 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.38 .62 .38 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.416 .584 .416 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.992 .008 .992 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.687 .313 .687 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.526 .474 .526 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.991 .009 .991 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.958 .042 .958 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.851 .149 .851 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.954 .046 .954 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.408 .592 .408 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.932 .068 .932 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.791 .209 .791 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.709 .291 .709 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.992 .008 .992 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.683 .317 .683 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.563 .437 .563 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.992 .008 .992 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.753 .247 .753 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.987 .013 .987 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.993 .007 .993 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.59 .41 .59 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.989 .011 .989 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.635 .365 .635 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.99 .01 .99 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.767 .233 .767 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.88 .12 .88 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.799 .201 .799 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.91 .09 .91 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.93 .07 .93 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.815 .185 .815 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.675 .325 .675 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.801 .199 .801 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.887 .113 .887 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.93 .07 .93 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.904 .096 .904 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.915 .085 .915 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.987 .013 .987 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.828 .172 .828 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.956 .044 .956 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.99 .01 .99 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.965 .035 .965 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.946 .054 .946 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.838 .162 .838 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.958 .042 .958 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.931 .069 .931 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.904 .096 .904 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.945 .055 .945 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.991 .009 .991 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.99 .01 .99 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.991 .009 .991 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.99 .01 .99 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.991 .009 .991 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003olPgboo8=l_l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo8=l_ob3O800_ob3O800ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00?olPgb00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo8=l_ob3O801Oob3O800ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003olPgboo8=lP06oo8=lP03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oe2_Go0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000colPgb00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooD:m@03o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oka3_onl@k`05onl@k`03o`000?ob
3O;olPgb00_olPgb0ol00003oo0?l003o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooD:mOoe2_D00ooe2_D00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003oka3_onl@k`06
onl@k`03o`000?ob3O;olPgb00[olPgb00?o0000oo0?l?o`3o001?o`3o000ol0003oo@;mood2o@0:
ood2o@04o`000?o^4NkokQ7^onhAkP;o00002_om0_d2o`000003onhAk_l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?om0_go
o@;m00Ooo@;m00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?om0_go
o@;m00Woo@;m00?o0000ooH9m_l000002oom0_d00ol0003oka3_onl@k`06onl@k`03o`000?ob3O;o
lPgb00WolPgb00?o0000oo0?l?o`3o001_o`3o000ol0003oo@;mood2o@08ood2o@03o`000?o^4Nko
kQ7^00CokQ7^0_l00005ood2o@?o00001?o^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Soo@;m0_l00008ooD:m@03o`000?om0_goo@;m00Ooo@;m0_l00003ooH9
mP03o`000?om0_goo@;m00Ooo@;m00?o0000onl@koo_4>l01oo_4>l00ol0003olPgboo8=lP09oo8=
lP03o`000?o`3o3ol0o`00Ool0o`00?o0000ood2oOom0_d01Oom0_d2o`0000WokQ7^0_l000000oom
0_go0000o`000007onhAkP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ood2oOom0_d02_om0_d2o`0000Soo@;m00?o0000ooD:mOoe
2_D02?oe2_D00ol0003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00?omPWf00?o0000ood2oOom
0_d01oom0_d00ol0003oka3_onl@k`08onl@k`03o`000?ob3O;olPgb00OolPgb00?o0000oo0?l?o`
3o002Oo`3o000ol0003oo@;mood2o@03ood2o@03o`000?o^4NkokQ7^00_okQ7^00?o0000onhAk_o^
4Nh01oo^4Nh00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ood2oOom0_d02oom0_d00ol0003om0_do`000005ood2o@;o00002ooe2_D2o`0000Koo@;m
00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@06ood2o@03o`000?o_4>ooka3_00Soka3_
00?o0000oo8=l_ob3O801_ob3O800ol0003ol0o`oo0?l00;oo0?l005o`000?om0_goo@;mood2oOl0
00003_o^4Nh00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo@;mood2o@0;ood2o@05o`000?od2oCom0_doo@;m?l0
00000oom0_d00ol0003om@[eooD:m@0:ooD:m@04o`000?oY5^WojAKYo`0000?oo@;m0_l00008ooH9
mP03o`000?om0_goo@;m00Koo@;m00?o0000onl@koo_4>l02Oo_4>l00ol0003olPgboo8=lP05oo8=
lP03o`000?o`3o3ol0o`00col0o`00?o0000ood2oOl000003oo^4Nh00ol0003okQ7^onhAkP08onhA
kP03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m003oo@;m003o`000?om0_go000000_o
m@[e0_l00004onTFj@03o`000?om0_go000000_omPWf00?o0000ood2oOom0_d01Oom0_d00ol0003o
ka3_onl@k`09onl@k`03o`000?ob3O;olPgb00ColPgb00?o0000oo0?l?o`3o003_o`3o000ol0003o
kQ7^onhAkP0>onhAkP03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo@;m00?o0000oo@;m?od2o@0
1?od2o@00ol0003om@[eooD:m@09ooD:m@03o`000?oY5^WojAKY00GojAKY00?o0000ooH9m_of2OH0
2_of2OH00ol0003oo@;mood2o@05ood2o@03o`000?o_4>ooka3_00[oka3_00?o0000oo8=l_ob3O80
0oob3O800ol0003ol0o`oo0?l00>oo0?l003o`000?o^4NkokQ7^00gokQ7^00?o0000onhAk_o^4Nh0
2_o^4Nh00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;
m005oo@;m003o`000?oe2_Gom@[e00Oom@[e0_l00008onTFj@03o`000?of2OKomPWf00_omPWf00?o
0000ood2oOom0_d01?om0_d00ol0003oka3_onl@k`0:onl@k`04o`000?ob3O;olPgboo8=lP?o0000
3oo`3o000ol0003okQ7^onhAkP0>onhAkP03o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003oo@;mood2
o@09ood2o@03o`000?od2oCom0_d00Oom0_d00?o0000ooD:mOoe2_D01?oe2_D2o`0000_ojAKY1?l0
0009ooH9mP03o`000?om0_goo@;m00?oo@;m00?o0000onl@koo_4>l02oo_4>l01?l0003olPgbo`00
0?l00003omHYeP;o00003?o`3o02o`00013okQ7^00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d02?om0_d00ol0003om0_d
oo@;m007oo@;m003o`000?oe2_Gom@[e00?om@[e00?o0000onTFjOoY5^T02ooY5^T01?l0003obcC;
ol/dboo;=</5o`0000GomPWf00?o0000ood2oOom0_d00_om0_d00ol0003oka3_onl@k`0<onl@k`03
o`000?oF:MKoeRWF00GoeRWF0_l00008oo0?l0;o00000_o?<<l00ol0003okQ7^onhAkP0=onhAkP03
o`000?o^4NkokQ7^00_okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ood2oOom0_d01oom0_d00ol0003om0_doo@;m009oo@;m003o`000?oe2_Gom@[e00;o0000
3OoY5^T00ol0003obcC;ol/db`07ol/db`Ko00000_om0_d4o`0000goka3_00?o0000omHYe_oF:MH0
1ooF:MH2o`0000Gol0o`00?o0000oll`coo?<<l00oo?<<l00ol0003okQ7^onhAkP0<onhAkP03o`00
0?o^4NkokQ7^00cokQ7^00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?od2oCom0_d00Wom0_d00?o
0000ooD:mOl000003ooY5^T00ol0003obcC;ol/db`0<ol/db`?o00001?oV6NH3o`0000Woka3_00?o
0000omHYe_oF:MH02_oF:MH2o`000003oo0?l?l0003o000000Oocc3?00?o0000onhAk_o^4Nh02oo^
4Nh00ol0003okQ7^onhAkP0<onhAkP03o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@05ood2o@03o`000?od2oCom0_d00_om0_d00?o0000
onTFjOoY5^T03_oY5^T00ol0003obcC;ol/db`0=ol/db`03o`000?oV6NKoiQWV00KoiQWV0ol00005
onl@k`03o`000?oF:MKoeRWF00goeRWF00?o0000oll`coo?<<l02?o?<<l00ol0003okQ7^onhAkP09
onhAkP03o`000?o^4NkokQ7^00gokQ7^00Co0000ood2oOom0_goo@;m1Ol00003oo8=lP03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000
oo@;m?od2o@02ood2o@2o`0000oojAKY00?o0000ol/dboo;=</03Oo;=</00ol0003oiQWVonHIiP0:
onHIiP?o000000?oka3_o`000?oF:MH03ooF:MH00ol0003occ3?oll`c`09oll`c`03o`000?o^4Nko
kQ7^00SokQ7^00?o0000onhAk_o^4Nh03_o^4Nh3o`0000SolPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ood2o@03o`000?od2oCom0_d00Som0_d0ol000000ooI
9]Wo0000onTFj@0>onTFj@03o`000?o;=<_obcC;00gobcC;00?o0000onHIi_oV6NH03OoV6NH00ol0
003oeRWFomHYeP0?omHYeP03o`000?o?<<oocc3?00[occ3?2ol0000;onhAkPGo00003?ob3O800ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003ol@kao`000?om0_go0000
00Som0_d0ol00005omTVf@03o`000?oY5^WojAKY00cojAKY00?o0000ol/dboo;=</03Oo;=</00ol0
003oiQWVonHIiP0=onHIiP;o00004?oF:MH00ol0003occ3?oll`c`0:oll`c`03o`000?o:=L[obSG:
00OobSG:00?o0000onhAk_o^4Nh00_o^4Nh7o`0000Cod2o@00?o0000oo8=l_ob3O802_ob3O800ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003ol@kaoo4>lOoa3_42o`00
00Gom0_d0ol00009omTVf@;o00002ooY5^T00ol0003obcC;ol/db`0=ol/db`03o`000?oV6NKoiQWV
00goiQWV00Co0000ol8m`_o2?L;o00003ooF:MH00ol0003occ3?oll`c`09oll`c`03o`000?o:=L[o
bSG:00WobSG:1?l0000;om0_d003o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo4>lOoa3_401?oa3_400ol0003om0_do`000002o`00
00cofBKI00Co0000okI9]_l0003o00002OoY5^T00ol0003obcC;ol/db`0=ol/db`03o`000?oV6NKo
iQWV00goiQWV00Go0000ol8m`_o2?L;o`Sg2o`00000=omHYeP03o`000?o?<<oocc3?00[occ3?00?o
0000olXeb_o:=LX02Oo:=LX00ol0003od2o@om0_d00<om0_d003o`000?ob3O;olPgb00[olPgb00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo4>lOoa3_401_oa3_40
0ol0003ofBKIomTVf@0<omTVf@03o`000?nfBKKo]TVf00;o]TVf0_l00007onTFj@03o`000?o;=<_o
bcC;00cobcC;00?o0000onHIi_oV6NH03OoV6NH00ol0003o`Sg2ol8m`P03ol8m`P03o`000?oF:MKo
eRWF00[oeRWF00?o0000oll`coo?<<l02_o?<<l00ol0003obSG:olXebP09olXebP03o`000?o@;m3o
d2o@00cod2o@00?o0000oo8=l_ob3O802oob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003ol@kaoo4>l@06oo4>l@03o`000?oI9]WofBKI00_ofBKI00?o0000okI9
]_nfBKH01OnfBKH00ol0003ojAKYonTFj@03onTFj@03o`000?o;=<_obcC;00gobcC;00?o0000onHI
i_oV6NH03OoV6NH00ol0003o`Sg2ol8m`P04ol8m`P03o`000?oF:MKoeRWF00WoeRWF00?o0000oll`
coo?<<l02Oo?<<l00ol0003obSG:olXebP0:olXebP03o`000?o@;m3od2o@00cod2o@00?o0000oo8=
l_ob3O802oob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l@kaoo4>l@07oo4>l@03o`000?oI9]WofBKI00_ofBKI00?o0000okI9]_nfBKH01_nfBKH2o`0000?o
jAKY00?o0000ol/dboo;=</03Oo;=</00ol0003oiQWVonHIiP0<onHIiP03o`000?o2?L;o`Sg200Ko
`Sg200?o0000omHYe_oF:MH02?oF:MH00ol0003occ3?oll`c`09oll`c`03o`000?o:=L[obSG:00[o
bSG:00?o0000om0_d?o@;m003?o@;m000ol0003olPgboo8=lP0;oo8=lP03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo4>lOoa3_402?oa3_400ol0003ofBKIomTVf@0:omTVf@03o`00
0?nfBKKo]TVf00Wo]TVf0_l000000ooY5^Wo0000ol/db`0<ol/db`?o00003_oV6NH00ol0003o`Sg2
ol8m`P07ol8m`P03o`000?oF:MKoeRWF00OoeRWF00?o0000oll`coo?<<l02Oo?<<l00ol0003obSG:
olXebP0;olXebP03o`000?o@;m3od2o@00cod2o@00?o0000oo8=l_ob3O802_ob3O800ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo4>lOoa3_402_oa3_400ol0003ofBKIomTV
f@09omTVf@03o`000?nfBKKo]TVf00_o]TVf00?o0000ol/dboo;=</02_o;=</2o`0000?oXEjQ00?o
0000onHIi_oV6NH02_oV6NH00ol0003o`Sg2ol8m`P09ol8m`P03o`000?oF:MKoeRWF00KoeRWF00?o
0000oll`coo?<<l02?o?<<l00ol0003obSG:olXebP0<olXebP03o`000?o@;m3od2o@00cod2o@00?o
0000oo8=l_ob3O802_ob3O800ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oa3_7ol@ka00_ol@ka00?o0000omTVfOoI9]T02?oI9]T0
0ol0003o]TVfokI9]P0<okI9]P03o`000?o;=<_obcC;00SobcC;0_l00006oj5NX@;o00002_oV6NH0
0ol0003o`Sg2ol8m`P0:ol8m`P03o`000?oF:MKoeRWF00GoeRWF00?o0000oll`coo?<<l02?o?<<l0
0ol0003obSG:olXebP0<olXebP03o`000?o@;m3od2o@00cod2o@00?o0000oo8=l_ob3O802oob3O80
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo4>l@03o`000?oI9]WofBKI00OofBKI00?o0000okI9]_nfBKH03_nfBKH00ol0003obcC;ol/db`04
ol/db`?o00002_nQGZ400ol0003oiQWVonHIiP07onHIiP03o`000?o2?L;o`Sg200_o`Sg200?o0000
omHYe_oF:MH00ooF:MH00ol0003occ3?oll`c`09oll`c`03o`000?o:=L[obSG:00cobSG:00?o0000
om0_d?o@;m003?o@;m000ol0003olPgboo8=lP0;oo8=lP;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_on0Oh00ol0
003ol@kaoo4>l@0<oo4>l@03o`000?oI9]WofBKI00OofBKI00?o0000okI9]_nfBKH03onfBKH01?l0
003obcC;ol/dboo;=</2o`0000koXEjQ0_l00006onHIiP03o`000?o2?L;o`Sg200go`Sg200?o0000
omHYe_oF:MH00_oF:MH00ol0003occ3?oll`c`08oll`c`03o`000?o:=L[obSG:00cobSG:0ol0000=
om0_d003o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?on0Oko0000
00ool@ka00?o0000omTVfOoI9]T01_oI9]T00ol0003o]TVfokI9]P0@okI9]PCo00004_nQGZ400ol0
003oiQWVonHIiP03onHIiP03o`000?o2?L;o`Sg200ko`Sg200Go0000omHYe_oF:MKoeRWFo`000005
oll`c`Oo00003?o:=LX01Ol0003oXUfRoj9MX_nRGJ;o000000cod2o@00?o0000oo8=l_ob3O802?ob
3O83o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ool@ka00?o0000omTVfOoI9]T01_oI9]T00ol0003o]TVfokI9]P0=
okI9]P?o000000CoNHIio`000?l0003o00004onQGZ42o`0000;oiQWV00?o0000ol8m`_o2?L804?o2
?L800ol0003oeRWFo`000006o`0000Oo[e2_00?o0000olXeb_o:=LX02?o:=LX00ol0003oXUfRoj9M
XP03oj9MXP;o00002?o@;m03o`0000KolPgb1?l00002onhAkP03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003omPWfo`000?oC;=<3o`0000gol@ka00?o0000omTVfOoI9]T01?oI9]T00ol0003o]TVfokI9
]P0;okI9]P?o00000omiQWT01Ol0003oMHYeo`000?m>/Dko000001CoXEjQ00?o0000onHIi_l00000
4oo2?L800ol0003o[e2_ojm@[`0=ojm@[`03o`000?o:=L[obSG:00GobSG:0_l00008oj9MXP03o`00
0?o@;m3od2o@00Go00000oo=</d00ol0003olPgboo8=lP03o`0000OokQ7^00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?of2OKomPWfo`0000CodbcC0ol0000:oo4>l@03o`000?oI9]WofBKI00?ofBKI
00?o0000okI9]_nfBKH02OnfBKH3o`0000GoNHIi00Co0000ogF:MOmeRWGo00000_m>/Dh00ol0003o
XEjQoj5NX@0Boj5NX@03o`000?o2?L;o`Sg201;o`Sg200?o0000ojm@[on_D:l03_n_D:l00ol0003o
bSG:olXebP03olXebP03o`000?nRGJ;oXUfR00WoXUfR0_l00009oldbc@;o00002_o^4Nh00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000ooH9m_of2OKomPWfo`000007om</d`;o00001ooa3_45o`0000;o
fBKI00?o0000okI9]_nfBKH01_nfBKH3o`0000SoNHIi00Co0000ogF:MOmeRWGo00000om>/Dh00ol0
003oXEjQoj5NX@0Aoj5NX@03o`000?o2?L;o`Sg2017o`Sg200?o0000ojm@[on_D:l04?n_D:l01Ol0
003obSG:olXeb_o:=L[o000000coXUfR00?o0000oldbcOo=</d02?o=</d00ol0003okQ7^onhAkP0:
onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000ComPWf00?o0000om</dooC;=<01ooC;=<3o`00
0004oo4>lOl0003o0000o`0000Go_T6n0_l00006okI9]P?o00002_miQWT01Ol0003oMHYeogF:MOme
RWGo000000CoC[5>00?o0000oj5NXOnQGZ404?nQGZ400ol0003o`Sg2ol8m`P0Aol8m`P03o`000?n_
D:oo[e2_017o[e2_00?o0000olXeb_l000003OnRGJ800ol0003ocC;=oldbc@08oldbc@03o`000?o^
4NkokQ7^00[okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00ComPWf00?o0000
om</dooC;=<02_oC;=<00ol0003o_T6noki1_P08oki1_P03o`000?nfBKKo]TVf00?o00003OmiQWT0
1Ol0003oMHYeogF:MOmeRWGo000000GoC[5>00?o0000oj5NXOnQGZ403onQGZ400ol0003o`Sg2ol8m
`P0Aol8m`P03o`000?n_D:oo[e2_01;o[e2_00?o0000oj9MX_nRGJ803?nRGJ800ol0003ocC;=oldb
c@08oldbc@03o`000?o^4NkokQ7^00_okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000ooH9m_of2OH01Oof2OH0
0ol0003odbcCom</d`0:om</d`03o`000?nn@Kko_T6n00Wo_T6n0_l0000?ogV6N@03o`000?meRWGo
MHYe00;oMHYe00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oXEjQoj5NX@0=oj5NX@?o00004Oo2?L80
0ol0003o[e2_ojm@[`0Cojm@[`03o`000?nRGJ;oXUfR00_oXUfR00?o0000oldbcOo=</d02Oo=</d0
0ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?of2OH0
0ol0003odbcCom</d`0:om</d`03o`000?nn@Kko_T6n00Wo_T6n00?o0000ogV6NOmiQWT03OmiQWT0
0ol0003oMHYeogF:M@03ogF:M@03o`000?m>/DkoC[5>00GoC[5>00?o0000oj5NXOnQGZ402_nQGZ42
o`0000?oOX5n00?o0000ol8m`_o2?L803_o2?L800ol0003o[e2_ojm@[`0Cojm@[`03o`000?nRGJ;o
XUfR00_oXUfR00?o0000oldbcOo=</d02Oo=</d00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000ooH9m_of2OH01oof2OH2o`0000_odbcC00?o0000oki1
__nn@Kh02onn@Kh00ol0003oNHIiogV6N@0<ogV6N@03o`000?meRWGoMHYe00?oMHYe00?o0000odja
C_m>/Dh01_m>/Dh00ol0003oXEjQoj5NX@07oj5NX@;o00001_mnPGh2o`0000ko`Sg200?o0000ojm@
[on_D:l04on_D:l00ol0003oXUfRoj9MXP0;oj9MXP03o`000?o=</gocC;=00WocC;=00?o0000onhA
k_o^4Nh03?o^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009ooH9
mP03o`000?oY5^Wo000000_odbcC00?o0000oki1__nn@Kh02onn@Kh00ol0003oNHIiogV6N@0;ogV6
N@03o`000?meRWGoMHYe00CoMHYe00?o0000odjaC_m>/Dh01om>/Dh00ol0003oXEjQoj5NX@05oj5N
X@03o`000?mnPGkoOX5n00SoOX5n00?o0000ol8m`_o2?L802_o2?L800ol0003o[e2_ojm@[`0Dojm@
[`03o`000?nRGJ;oXUfR00_oXUfR00?o0000oldbcOo=</d02Oo=</d00ol0003okQ7^onhAkP0<onhA
kP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009ooH9mP04o`000?oY5^WojAKYo`00
00_odbcC00?o0000oki1__nn@Kh02onn@Kh00ol0003oNHIiogV6N@0;ogV6N@03o`000?meRWGoMHYe
00CoMHYe00?o0000odjaC_m>/Dh02?m>/Dh00ol0003oXEjQoj5NX@02oj5NX@;o00003?mnPGh2o`00
00[o`Sg200?o0000ojm@[on_D:l05?n_D:l00ol0003oXUfRoj9MXP0;oj9MXP03o`000?o=</gocC;=
00WocC;=00?o0000onhAk_o^4Nh03Oo^4Nh00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003omPWfooH9mP07ooH9mP03
o`000?oY5^WojAKY00;ojAKY00?o0000om</dooC;=<02?oC;=<00ol0003o_T6noki1_P0<oki1_P03
o`000?miQWWoNHIi00WoNHIi00?o0000ogF:MOmeRWD01OmeRWD00ol0003oC[5>odjaCP09odjaCP04
o`000?nQGZ7o0000o`00013oOX5n0_l00008ol8m`P03o`000?n_D:oo[e2_01Co[e2_0ol0000;oj9M
XP03o`000?o=</gocC;=00WocC;=00?o0000onhAk_o^4Nh03Oo^4Nh01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003omPWfooH9mP06ooH9mP03o`000?oY5^WojAKY00?ojAKY00?o0000om</
dooC;=<02?oC;=<00ol0003o_T6noki1_P0;oki1_P;o00002_miQWT00ol0003oMHYeogF:M@06ogF:
M@03o`000?m>/DkoC[5>00[oC[5>00?o0000ogj1O_mnPGh04_mnPGh00ol0003o`Sg2ol8m`P04ol8m
`P03o`000?n_D:oo[e2_01Go[e2_00?o0000oiMXUonGJ9L01Ol00005oj9MXP03o`000?o=</gocC;=
00[ocC;=00?o0000onhAk_o^4Nh03_o^4Nh3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003omPWfooH9mP04ooH9mP03
o`000?oY5^WojAKY00CojAKY00?o0000om</dooC;=<01ooC;=<00ol0003o_T6noki1_P0;oki1_P04
o`000?meRWGoMHYeo`0000WoNHIi00?o0000ogF:MOmeRWD01_meRWD00ol0003oC[5>odjaCP0:odja
CP03o`000?mnPGkoOX5n01?oOX5n0_l00003ol8m`PCo00005?n_D:l00ol0003oUfRGoiMXU`06oiMX
U`Co000000?oXUfRo`000?o=</d02oo=</d00ol0003okQ7^onhAkP0>onhAkP03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003omPWfooH9mP03ooH9mP03o`000?oY5^WojAKY00GojAKY00?o0000om</dooC
;=<01ooC;=<00ol0003o_T6noki1_P09oki1_P;o00001?meRWD00ol0003oNHIiogV6N@05ogV6N@03
o`000?meRWGoMHYe00OoMHYe00?o0000odjaC_m>/Dh02_m>/Dh00ol0003oOX5nogj1OP0Eogj1OP03
o`000?o2?L;o000000CoSg2?0ol0000@ojm@[`03o`000?nGJ9OoUfRG00_oUfRG0_l0000<oldbc@03
o`000?o^4NkokQ7^00cokQ7^0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooH9m_of2OH00_of2OH00ol0003ojAKY
onTFj@06onTFj@03o`000?oC;=?odbcC00OodbcC00?o0000oki1__nn@Kh02?nn@Kh00ol0003oMHYe
ogF:M@05ogF:M@03o`000?miQWWoNHIi00CoNHIi00?o0000ogF:MOmeRWD01omeRWD00ol0003oC[5>
odjaCP0:odjaCP03o`000?mnPGkoOX5n01KoOX5n00?o0000ohm`Son?L8l01_n?L8l3o`0000co[e2_
00?o0000oiMXUonGJ9L03OnGJ9L00ol0003ocC;=oldbc@09oldbc@Go00002Oo^4Nh2o`000003oo4>
lOl0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooH9m_l0003ojAKY00WojAKY00?o0000om</dooC;=<01_oC
;=<00ol0003o_T6noki1_P07oki1_P03o`000?meRWGoMHYe00OoMHYe00?o0000ogV6NOmiQWT00_mi
QWT00ol0003oMHYeogF:M@08ogF:M@03o`000?m>/DkoC[5>00WoC[5>00?o0000ogj1O_mnPGh05omn
PGh00ol0003oSg2?ohm`S`09ohm`S`?o00002On_D:l00ol0003oUfRGoiMXU`0>oiMXU`Ko00001?o=
</d00ol0003oeRWFomHYeP03omHYePGo00000_o^4Nh2o`0000Col@ka00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o]4^gokA;]ondBkOl000002ooY5^T00ol0003odbcCom</d`06om</d`03o`000?nn
@Kko_T6n00Go_T6n0_l0000;ogF:M@04o`000?miQWWoNHIio`0000_oMHYe00?o0000odjaC_m>/Dh0
2Om>/Dh00ol0003oOX5nogj1OP0Fogj1OP03o`000?n?L8ooSg2?00goSg2?0ol00005ojm@[`03o`00
0?nGJ9OoUfRG00ooUfRG00?o0000ojaC[?n/Dj`00on/Dj`4o`0000_oeRWF0_l00006oo4>l@03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003okA;]ondBk@02ondBk@ko00001_oC;=<00ol0003o_T6noki1
_P05oki1_P03o`000?meRWGoMHYe00coMHYe00?o0000ogV6NOl000002omeRWD00ol0003oC[5>odja
CP07odjaCP?o00006?mnPGh00ol0003oSg2?ohm`S`0@ohm`S`?o000000?o[e2_o`000?nGJ9L04?nG
J9L00ol0003o[5>/ojaC[007ojaC[003o`000?oF:MKoeRWF00[oeRWF00?o0000oo4>lOoa3_401Ooa
3_400ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005ondBk@03o`000?o=</gocC;=00_ocC;=0_l00004
om</d`03o`000?nn@Kko_T6n00?o_T6n0_l0000@ogF:M@03o`000?meRWGoMHYe00[oMHYe00?o0000
odjaC_m>/Dh00om>/Dh4o`0000;o;m0_00?o0000ogj1O_mnPGh05OmnPGh00ol0003oSg2?ohm`S`0D
ohm`S`03o`000?nGJ9OoUfRG013oUfRG00?o0000ojaC[?n/Dj`01on/Dj`00ol0003oeRWFomHYeP0:
omHYeP03o`000?oa3_7ol@ka00Gol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o]4^gokA;]
00GokA;]00?o0000oldbcOo=</d03Oo=</d6o`0000?o_T6n00?o0000ogF:MOmeRWD04?meRWD00ol0
003oMHYeogF:M@0:ogF:M@03o`000?m>/Dko000000?o00001ol_d2l00ol0003oOX5nogj1OP0Dogj1
OP03o`000?n?L8ooSg2?01CoSg2?00?o0000oiMXUonGJ9L03onGJ9L00ol0003o[5>/ojaC[008ojaC
[003o`000?oF:MKoeRWF00[oeRWF00?o0000oo4>lOoa3_401Ooa3_400ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000ondBkOo]4^d01_o]4^d00ol0003ocC;=oldbc@0=oldbc@03o`000?naC[7o/Dja00?o
/Dja00?o0000oki1__l000004omeRWD4o`0000WoMHYe0_l0000<obo@;`03o`000?mnPGkoOX5n01?o
OX5n00?o0000ohm`Son?L8l05On?L8l00ol0003oUfRGoiMXU`0>oiMXU`03o`000?n/Djco[5>/00So
[5>/00?o0000omHYe_oF:MH02OoF:MH00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o]4^gokA;]00SokA;]00?o0000oldbcOo=</d02oo=</d00ol0003o/Djaok5>/@05ok5>/@03o`00
0?meRWGoMHYe01;oMHYe00Co0000occ3??ll`cco?<<l1Ol00003ogF:M@03o`000?l_d2oo;m0_00go
;m0_0ol0000@ogj1OP;o00006?n?L8l00ol0003oUfRGoiMXU`0=oiMXU`03o`000?n/Djco[5>/00Wo
[5>/00?o0000omHYe_oF:MH02OoF:MH00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_okA;]00?o0000oldbcOo=</d02_o=</d00ol0003o/Djaok5>/@06ok5>/@03o`00
0?meRWGoMHYe017oMHYe00?o0000occ3??ll`c`01oll`c`3o`00013o;m0_00?o0000oagR7OlMhQd0
1Ol00009ogj1OP;o000000?o=lPgo`000?n?L8l05on?L8l00ol0003oUfRGoiMXU`0=oiMXU`03o`00
0?n/Djco[5>/00Wo[5>/00?o0000omHYe_oF:MH02?oF:MH2o`0000[ol@ka00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?og2?Oom`Sg00;om`Sg00?o0000ondBkOo]4^d02Oo]4^d00ol0003ocC;=oldb
c@0:oldbc@03o`000?naC[7o/Dja00Oo/Dja00?o0000ogF:MOmeRWD03omeRWD00ol0003o?<<locc3
?00:occ3?003o`000?l_d2oo;m0_00go;m0_00?o0000oagR7OlMhQd01_lMhQd4o`0000CoOX5n00?o
0000ocO8=olgb3L00_lgb3L00ol0003oSg2?ohm`S`0Fohm`S`03o`000?nGJ9OoUfRG00_oUfRG00?o
0000ojaC[?n/Dj`02on/Dj`00ol0003oeRWFomHYeP06omHYeP03o`000?oW6>Oo000000[ol@ka00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000ondBkOo]4^d02?o]4^d=
o`0000[o/Dja00?o0000ogF:MOmeRWD03omeRWD00ol0003o?<<locc3?00;occ3?003o`000?l_d2oo
;m0_00co;m0_00?o0000oagR7OlMhQd02_lMhQd4o`0000Go=lPg00?o0000ohm`Son?L8l05_n?L8l0
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?n/Djco[5>/00co[5>/00?o0000omHYe_oF:MH01?oF:MH2
o`0000?oiaSW00?o0000oo4>lOoa3_402?oa3_400ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooL8
moog2?L00oog2?L00ol0003okA;]ondBk@07ondBk@03o`000?o;=<_obcC;00WobcC;00?o0000ok5>
/OnaC[402OnaC[400ol0003oMHYeogF:M@0=ogF:M@03o`000?ll`cco?<<l00co?<<l00?o0000obo@
;ol_d2l03?l_d2l00ol0003o7N8MoagR7@0;oagR7@03o`000?l:m@[o000000Ko=lPg00?o0000ohm`
Son?L8l05_n?L8l00ol0003oUfRGoiMXU`09oiMXU`03o`000?n/Djco[5>/00co[5>/00?o0000omHY
e_oF:MH00ooF:MH00ol0003oiaSWonLHi`03onLHi`03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Com`Sg00?o0000ondBkOo]4^d01_o]4^d00ol0003o
bcC;ol/db`08ol/db`03o`000?naC[7o/Dja00_o/Dja00?o0000ogF:MOmeRWD02?meRWD4o`0000oo
?<<l00?o0000obo@;ol_d2l02ol_d2l00ol0003o7N8MoagR7@0;oagR7@04o`000?l:m@[o2_D:o`00
00Oo=lPg00?o0000ohm`Son?L8l05On?L8l00ol0003oUfRGoiMXU`08oiMXU`03o`000?n/Djco[5>/
00go[5>/00?o0000omHYe_oF:MH00_oF:MH00ol0003oiaSWonLHi`05onLHi`03o`000?oa3_7ol@ka
00Ool@ka00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Gom`Sg00?o0000ondBkOo]
4^d01Oo]4^d00ol0003obcC;ol/db`08ol/db`03o`000?naC[7o/Dja00_o/Dja00?o0000ogF:MOme
RWD00omeRWD5o`0000?o?L8m00?o0000occ3??ll`c`03_ll`c`00ol0003o;m0_obo@;`0:obo@;`03
o`000?lMhQgo7N8M00[o7N8M00Go0000o`[e2_l:m@[o2_D:o`000007ocO8=`03o`000?n?L8ooSg2?
01GoSg2?00?o0000oiMXUonGJ9L02?nGJ9L00ol0003o[5>/ojaC[00=ojaC[003o`000?oF:MKoeRWF
00;o00002?oW6>L00ol0003ol@kaoo4>l@08oo4>l@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?o]4^gokA;]00Go
kA;]00?o0000ol/dboo;=</02?o;=</00ol0003o/Djaok5>/@0<ok5>/@Go00002Olm`Sd00ol0003o
?<<locc3?00<occ3?0;o00003?l_d2l00ol0003o7N8MoagR7@0:oagR7@05o`000?l:m@[o2_D:o`[e
2_l000002?lgb3L00ol0003oSg2?ohm`S`0Dohm`S`?o00001onGJ9L00ol0003o[5>/ojaC[00>ojaC
[003o`000?oF:MKo000000_oiaSW00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooL8moog2?L01Oog2?L00ol0003okA;]ondBk@04ondBk@03o`000?o;=<_obcC;00Oo
bcC;00?o0000ok5>/OnaC[403?naC[401?l0003oMHYeogF:MOl0000;ocg2?@03o`000?ll`cco?<<l
00_o?<<l00Co0000o`Gj1Ol5nPGo00002_l_d2l00ol0003o7N8MoagR7@0:oagR7@03o`000?l:m@[o
2_D:00;o2_D:00?o0000ocO8=olgb3L01_lgb3L00ol0003oSg2?ohm`S`0Aohm`S`?o00000omQWV40
0ol0003oUfRGoiMXU`04oiMXU`03o`000?n/Djco[5>/00go[5>/1?l0000;onLHi`03o`000?oa3_7o
l@ka00Gol@ka00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00Co0000ondB
kOo]4^gokA;]1?l00008ol/db`03o`000?naC[7o/Dja00_o/Dja00?o0000ogF:MOmeRWD00_meRWD0
0ol0003o?L8mocg2?@08ocg2?@03o`000?ll`cco?<<l00[o?<<l00?o0000o`Gj1Ol5nPD00_l5nPD0
0ol0003o;m0_obo@;`03obo@;`Go00002olMhQd00ol0003o2_D:o`[e2P03o`[e2P03o`000?lgb3Oo
=lPg00Oo=lPg00?o0000ohm`Son?L8l03_n?L8l2o`0000OoHIiQ00?o0000oiMXUonGJ9L00_nGJ9L0
0ol0003o[5>/ojaC[00=ojaC[003o`000?oC;=?odbcC00;odbcC00?o0000onLHiooW6>L02OoW6>L0
0ol0003ol@kaoo4>l@03oo4>l@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`07ooL8
m`?o00001?oK9=/00ol0003obcC;ol/db`05ol/db`03o`000?naC[7o/Dja00[o/Dja00?o0000ogF:
MOmeRWD00omeRWD00ol0003o?L8mocg2?@09ocg2?@03o`000?ll`cco?<<l00So?<<l00?o0000o`Gj
1Ol5nPD01?l5nPD5o`0000Co0?l000?o0000oagR7OlMhQd02OlMhQd00ol0003o2_D:o`[e2P03o`[e
2P03o`000?lgb3Oo=lPg00So=lPg00?o0000ohm`Son?L8l02_n?L8l3o`0000[oHIiQ00Go0000oiMX
UonGJ9OoUfRGo`00000>ojaC[003o`000?oC;=?odbcC00CodbcC0_l00009onLHi`03o`000?oa3_7o
l@ka00;ol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000om/T
fooK9=/01OoK9=/00ol0003obcC;ol/db`03ol/db`03o`000?naC[7o/Dja00[o/Dja00?o0000ogF:
MOmeRWD01?meRWD00ol0003o?L8mocg2?@09ocg2?@03o`000?ll`cco?<<l00Oo?<<l00?o0000o`Gj
1Ol5nPD01Ol5nPD00ol0003o0?l0o`3o0007o`3o0003o`000?lMhQgo7N8M00Oo7N8M00?o0000o`[e
2_l:m@X01?l:m@X00ol0003o=lPgocO8=`08ocO8=`03o`000?n?L8ooSg2?00SoSg2?0_l0000>of6N
H@Co00003?n/Dj`2o`0000WodbcC00?o0000onLHiooW6>L01ooW6>L01?l0003ol@kaoo4>lOl0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooL8moog2?L01Oog2?L00ol0003ofbCKom/Tf`07om/Tf`;o00000oo;=</00ol0
003o/Djaok5>/@09ok5>/@03o`000?meRWGoMHYe00KoMHYe00?o0000ocg2?Olm`Sd02Olm`Sd00ol0
003o?<<locc3?005occ3?003o`000?l5nPGo1OX500Ko1OX500?o0000o`3o0?l0o`002?l0o`000ol0
003o7N8MoagR7@06oagR7@03o`000?l:m@[o2_D:00Co2_D:00?o0000ocO8=olgb3L02Olgb3L4o`00
00?oSg2?0ol0000@of6NH@05o`000?o0?l3o`3o0ol0o`?l000002_n/Dj`00ol0003odbcCom</d`0:
om</d`Ko00000ooW6>L00ol0003ol@kao`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooL8moog2?L01?og2?L00ol0
003ofbCKom/Tf`0:om/Tf`04o`000?o;=<_obcC;o`0000[o/Dja00?o0000ogF:MOmeRWD01omeRWD0
0ol0003o?L8mocg2?@09ocg2?@03o`000?ll`cco?<<l00Co?<<l00?o0000o`Gj1Ol5nPD01ol5nPD0
0ol0003o0?l0o`3o0008o`3o00;o00001_lMhQd00ol0003o2_D:o`[e2P05o`[e2P03o`000?lgb3Oo
=lPg00Wo=lPg00Co0000obgB;Ol]dRgo;M8]0ol0000Bof6NH@03o`000?o0?l3o`3o000?o`3o00_l0
0006ojaC[0;o00003OoC;=<00ol0003om@[eooD:m@03ooD:m@Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooL8moog2?L00oog2?L0
0ol0003ofbCKom/Tf`0<om/Tf`;o00002_naC[400ol0003oMHYeogF:M@08ogF:M@03o`000?lm`Sgo
?L8m00[o?L8m00?o0000occ3??ll`c`00_ll`c`00ol0003o1OX5o`Gj1@08o`Gj1@03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lMhQgo7N8M00;o7N8M00?o0000o`[e2_l:m@X01_l:m@X0
0ol0003o=lPgocO8=`08ocO8=`03o`000?l]dRgo;M8]00Co;M8]00?o0000of6NHOmQWV403omQWV40
0ol0003o`3o0ol0o`006ol0o`0;o00000on/Dj`00ol0003odbcCom</d`0=om</d`03o`000?oe2_Go
m@[e00Oom@[e0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?om0_goo@;m00?o00001oon0Oh00ol0003om`SgooL8m`02ooL8m`03o`000?oK9=_ofbCK
00kofbCK00?o0000ok5>/OnaC[401onaC[400ol0003oMHYeogF:M@0:ogF:M@03o`000?lm`Sgo?L8m
00Wo?L8m00Go0000occ3??ll`cco?<<lo`00000;o`Gj1@03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lMhQgo7N8MoagR7Ol000002?l:m@X00ol0003o=lPgocO8=`08ocO8=`03o`000?l]
dRgo;M8]00Go;M8]00?o0000of6NHOmQWV403_mQWV400ol0003o`3o0ol0o`008ol0o`003o`000?n/
Djco000000oodbcC00?o0000ooD:mOoe2_D02?oe2_D01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?om0_goo@;m00Coo@;m0ol0
0005ooh1oP04o`000?og2?Oom`Sgo`00017ofbCK00?o0000ok5>/OnaC[401_naC[400ol0003oMHYe
ogF:M@0;ogF:M@03o`000?lm`Sgo?L8m00Wo?L8m00Co0000occ3??ll`cco00003?l5nPD00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o7N8Mo`000009o`[e2P03o`000?lgb3Oo=lPg00So
=lPg00?o0000obgB;Ol]dRd01Ol]dRd00ol0003oHIiQof6NH@0=of6NH@03o`000?o0?l3o`3o000[o
`3o000?o0000om</dooC;=<03_oC;=<00ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo@;mood2o@08ood2o@?o000000?ooP7no`000?l000000ol0000Bom/Tf`03o`00
0?naC[7o/Dja00Co/Dja00?o0000ogF:MOmeRWD03?meRWD00ol0003o?L8mocg2?@0:ocg2?@?o0000
3?l5nPD00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`[e2_l:m@X02?l:m@X00ol0003o=lPg
ocO8=`07ocO8=`03o`000?l]dRgo;M8]00Oo;M8]00?o0000of6NHOmQWV403?mQWV400ol0003o`3o0
ol0o`00;ol0o`0;o00003_oC;=<00ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?om
0_goo@;m00coo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003ofbCKom/Tf`0?om/Tf`?o00000ona
C[400ol0003oMHYeogF:M@0>ogF:M@03o`000?lm`Sgo?L8m00So?L8m00Co0000o`gb3Ol=lPgo3O8=
0_l0000:o`Gj1@?o00003Ol0o`000ol0003o2_D:o`[e2P08o`[e2P03o`000?lgb3Oo=lPg00Oo=lPg
00?o0000obgB;Ol]dRd01ol]dRd00ol0003oHIiQof6NH@0;of6NH@03o`000?o0?l3o`3o000co`3o0
00?o0000onXEj_l000000_l0000:om</d`03o`000?oe2_Gom@[e00Som@[e00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ood2oOom0_d03Oom0_d00ol0003om@[eooD:m@04ooD:m@03o`000?oK9=_ofbCK00cofbCK0_l0
0003olHiaP03o`000?naC[7o0000017oMHYe00?o0000ocg2?Olm`Sd01olm`Sd00ol0003o3O8=o`gb
3@04o`gb3@;o00002?l5nPD00ol0003o0?l0o`3o000>o`3o00;o00002?l:m@X00ol0003o=lPgocO8
=`06ocO8=`03o`000?l]dRgo;M8]00Wo;M8]00?o0000of6NHOmQWV402OmQWV400ol0003o`3o0ol0o
`00=ol0o`003o`000?oZ5N[ojQGZ00;ojQGZ0ol00007om</d`03o`000?oe2_Gom@[e00Oom@[e00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oK9=_o
fbCK00WofbCK0_l00006olHiaP03o`000?meRWGoMHYe013oMHYe00?o0000ocg2?Olm`Sd01_lm`Sd0
0ol0003o3O8=o`gb3@07o`gb3@03o`000?l5nPGo1OX500Co1OX50ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol:m@X00ol0003o=lPgocO8=`06ocO8=`03o`000?l]dRgo;M8]00[o;M8]00?o0000
of6NHOmQWV402?mQWV400ol0003o`3o0ol0o`00=ol0o`003o`000?oZ5N[ojQGZ00GojQGZ0ol00004
om</d`03o`000?oe2_Gom@[e00Oom@[e00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d00ol0
003om@[eooD:m@06ooD:m@03o`000?oK9=_ofbCK00GofbCK0ol00008olHiaP03o`000?meRWGoMHYe
017oMHYe00Co0000ocg2?Olm`Sgo?L8m1?l0000;o`gb3@;o000000Co1OX5o`000?l0003o00000ol@
ka02o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2_D:00?o0000ocO8=olgb3L01_lg
b3L00ol0003o;M8]obgB;@0:obgB;@03o`000?mQWV7oHIiQ00OoHIiQ00?o0000ol0o`?o0?l003_o0
?l000ol0003ojQGZonXEjP08onXEjPCo00002_oe2_D00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003om@[eooD:m@07ooD:m@03o`000?oK9=_ofbCK00;ofbCK0_l0000<olHiaP03o`000?meRWGo
MHYe013oMHYe1?l00003oc3?<003o`000?l=lPgo3O8=00_o3O8=00?o0000oa3_4?l@ka001_l@ka00
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obgB;@03o`000?mQWV7o
HIiQ00KoHIiQ00?o0000ol0o`?o0?l003_o0?l000ol0003ojQGZonXEjP0;onXEjP03o`000?oe2_Go
m@[e00Oom@[e00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oe2_Gom@[e00Wom@[e00Co0000om/T
fol0003o00003_o6>LH00ol0003oMHYeogF:M@0?ogF:M@03o`000?l`cc3o<<l`00Ko<<l`00?o0000
o`gb3Ol=lPd02_l=lPd00ol0003o4>l@oa3_4007oa3_40;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lka3_o>l@k00So>l@k00?o0000obgB;Ol]dRd03?l]dRd00ol0003oHIiQof6NH@05
of6NH@03o`000?o0?l3o`3o000oo`3o00_l0000=onXEjP03o`000?oe2_Gom@[e00Kom@[e00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oe2_Gom@[e00[om@[e00?o0000olHia_o6>LH03_o6>LH00ol0
003oMHYeogF:M@0>ogF:M@03o`000?l`cc3o<<l`00Oo<<l`00?o0000o`gb3Ol=lPd02_l=lPd00ol0
003o4>l@oa3_4009oa3_40;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lka3_o>l@k
00Wo>l@k00?o0000obgB;Ol]dRd02_l]dRd4o`0000CoHIiQ00?o0000ol0o`?o0?l004?o0?l001?l0
003oiaSWo`000?l0000<onXEjP03o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oe2_Gom@[e00[om@[e00?o0000olHia_o6>LH03oo6>LH@o`0000[o<<l`00?o0000o`gb
3Ol=lPd02Ol=lPd00ol0003o0?l0o`00000<oa3_4005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o>l@koc_4>`09oc_4>`03o`000?l]dRgo;M8]00Oo;M8]0ol00004of:MHP?o000000?oHIiQ
o`000?o0?l004Oo0?l001?l0003oiaSWonLHiooW6>L2o`0000_ojQGZ00?o0000ooD:mOoe2_D00ooe
2_D00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D02_oe2_D00ol0003oaSW6olHiaP0?
olHiaP03o`000?mfRGKoMXUf00coMXUf00?o0000oc3?<?l`cc002Ol`cc000ol0003o3O8=o`gb3@07
o`gb3@04o`000?l0o`3o0?l0o`0000go4>l@00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lka3_o>l@k00[o>l@k00?o0000obgB;Ol]dRd00ol]dRd3o`0000[oHYeR00?o0000ol0o`?o0?l00
4?o0?l000ol0003oiaSWonLHi`04onLHi`;o00002_oZ5NX00ol0003om@[eooD:m@04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ood2oOom0_d02_om
0_d3o`0000com@[e00?o0000olHia_o6>LH03oo6>LH00ol0003oMXUfogJ9MP0<ogJ9MP03o`000?l`
cc3o<<l`00Wo<<l`00?o0000o`gb3Ol=lPd01_l=lPd00ol0003o0?l0o`3o0002o`3o0003o`000?l@
ka3o4>l@00[o4>l@00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?lk
a3_o>l@k00[o>l@k00?o0000obgB;Ol]dRd00ol0000=of:MHP03o`000?o0?l3o`3o0013o`3o000?o
0000onLHiooW6>L01_oW6>L2o`0000WojQGZ0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ood2oOom0_d01Oom0_d4
o`0000;ooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003oaSW6olHiaP0=olHiaP?o00003omfRGH0
0ol0003o<<l`oc3?<008oc3?<003o`000?l=lPgo3O8=00Go3O8=00?o0000o`3o0?l0o`000ol0o`00
0ol0003o4>l@oa3_400:oa3_4003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o>l@koc_4>`0;oc_4>`;o00004OmRWF800ol0003o`3o0ol0o`00?ol0o`003o`000?oW6>Oo
iaSW00SoiaSW0_l00007onXEjP03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo@;mood2o@04o`00
00OooP7n00?o0000ooD:mOoe2_D02?oe2_D00ol0003oaSW6olHiaP09olHiaPGo00000_nIIYT00ol0
003oMXUfogJ9MP0=ogJ9MP03o`000?l`cc3o<<l`00Wo<<l`00?o0000o`gb3Ol=lPd01?l=lPd00ol0
003o0?l0o`3o0004o`3o0003o`000?l@ka3o4>l@00So4>l@00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lka3_o>l@k00_o>l@k00?o0000of:MH_mRWF804?mRWF800ol0
003o`3o0ol0o`00?ol0o`003o`000?oW6>OoiaSW00[oiaSW0_l00004onXEjP03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om@[eooD:m@07ooD:m@03o`000?o6>LKoaSW600CoaSW61Ol00007oiUVV@03
o`000?mfRGKoMXUf00goMXUf00?o0000oc3?<?l`cc002Ol`cc000ol0003o3O8=o`gb3@03o`gb3@03
o`000?l0o`3o0?l000Go0?l000?o0000oa3_4?l@ka002?l@ka000ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000oc_4>olka3/02olka3/00ol0003oHYeRof:MHP0@of:MHP03
o`000?o0?l3o`3o000oo`3o000?o0000onLHiooW6>L03?oW6>L2o`000003onXEj_l0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oe2_Gom@[e00Oom@[e00?o0000olHia_l00000
1?l0000<oiUVV@03o`000?mfRGKoMXUf00koMXUf00?o0000oc3?<?l`cc002?l`cc000ol0003o3O8=
o`gb3@02o`gb3@03o`000?l0o`3o0?l000Oo0?l000?o0000oa3_4?l@ka001ol@ka000ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000oc_4>olka3/02olka3/00ol0003oHYeR
of:MHP0Aof:MHP03o`000?o0?l3o`3o000go`3o000?o0000onLHiooW6>L03ooW6>L00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooD:mOoe2_D01Ooe2_D3o`00017oVFJI00?o0000ogJ9M_mfRGH03_mf
RGH00ol0003o<<l`oc3?<009oc3?<004o`000?l=lPgo3O8=o`0000[o0?l000?o0000oa3_4?l@ka00
1ol@ka000ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Olka3/00ol0003o
HYeRof:MHP0Aof:MHP?o00003Oo0?l000ol0003oiaSWonLHi`0?onLHi`03o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oe2_D2o`0000;ogb3O00?o0000oiUVVOnIIYT03onIIYT00ol0003o
MXUfogJ9MP0>ogJ9MP03o`000?l`cc3o<<l`00So<<l`1Ol0000;o`3o0003o`000?l@ka3o4>l@00Ko
4>l@00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=oc_4>`03o`000?mRWF;oHYeR
017oHYeR00?o0000ofRGJ?mXUfP00ol0000:ol0o`0Co00003OoW6>L00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooL8moog2?Oom`Sg0_l00005omlPg`03o`000?nIIYWoVFJI00koVFJI00?o0000ogJ9
M_mfRGH03_mfRGH00ol0003o<<l`oc3?<007oc3?<003o`000?lKi1_o6n@K00?o6n@K00?o0000o`3o
0?l0o`002?l0o`000ol0003o4>l@oa3_4005oa3_4003o`000?l0o`3o0?l000[o0?l01Ol0000<oc_4
>`03o`000?mRWF;oHYeR013oHYeR00?o0000ofRGJ?mXUfP01?mXUfP3o`0000Ko`3o000?o0000on<L
hooS7><00_oS7><5o`0000SoiaSW00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00?o
m`Sg00?o0000omlPgooO8=l01?oO8=l00ol0003oVFJIoiUVV@0=oiUVV@03o`000?mfRGKoMXUf00oo
MXUf00?o0000oc3?<?l`cc001?l`cc02o`0000Oo6n@K00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000oc_4>olka3/02?lka3/3o`00013oHYeR00?o0000ofRGJ?mXUfP02?mXUfP3o`0000;o
`3o000?o0000on<LhooS7><02?oS7><5o`0000?oiaSW00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?og2?Oom`Sg00Com`Sg00?o0000omlPgooO8=l01OoO8=l00ol0003oVFJIoiUVV@0;oiUVV@Co0000
3omfRGH00ol0003o<<l`oc3?<003oc3?<003o`000?lKi1_o6n@K00So6n@K00?o0000o`3o0?l0o`00
1?l0o`02o`0000So5NXE00?o0000o`Gj1Ol5nPD02?l5nPD00ol0003o0?l0o`3o0005o`3o00;o0000
1_lka3/2o`0000?o=</d00?o0000of:MH_mRWF803?mRWF800ol0003oJ9MXofRGJ00<ofRGJ0;o0000
4?oS7><3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?oO8=oogb3O00Kogb3O00?o
0000oiUVVOnIIYT02OnIIYT00ol0003oZEJYo`000002of2OH0?o00003?mfRGH01?l0003o<<l`oc3?
<?l`cc02o`0000co6n@K00?o0000o`3o0?l0o`000_l0o`000ol0003o5NXEoaGZ5@08oaGZ5@03o`00
0?l5nPGo1OX500So1OX500?o0000o`3o0?l0o`001ol0o`000ol0003o>l@koc_4>`02oc_4>`03o`00
0?ldbcCo=</d00Co=</d0_l0000;of:MHP03o`000?mXUfSoJ9MX00coJ9MX00?o0000ojiA[_l00000
4_oS7><00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003om`SgooL8m`06ooL8m`03o`000?oO8=oogb3O00Oogb3O00?o
0000oiUVVOnIIYT01_nIIYT2o`0000;oZEJY00?o0000of2OH?mPWf000omPWf03o`0000[oMXUf00?o
0000oc3?<?l000003olKi1/01?l0003o0?l0o`000?l0000;oaGZ5@03o`000?l5nPGo1OX500So1OX5
00?o0000o`3o0?l0o`002?l0o`001?l0003o>l@ko`000?l00009ocC;=003o`000?mRWF;oHYeR00Oo
HYeR00?o0000ofRGJ?mXUfP03?mXUfP01?l0003o[U6^ojiA[_l0000Con<Lh`03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooL8moog2?L01oog2?L00ol0003ogb3OomlPg`08omlPg`03o`000?nIIYWoVFJI00Co
VFJI00?o0000ojUFZOnYEZT00onYEZT00ol0003oH9mPof2OH005of2OH0?o00001_mfRGH4o`00013o
6n@K00?o0000oaGZ5OlEjQD03?lEjQD00ol0003o1OX5o`Gj1@07o`Gj1@03o`000?l0o`3o0?l000Wo
0?l000?o0000ocC;=?ldbc@02_ldbc@2o`0000KoHYeR00?o0000ofRGJ?mXUfP03?mXUfP00ol0003o
[U6^ojiA[P02ojiA[P03o`000?oS7>?ohacS00oohacS00?o0000oo@;m?l000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003om`SgooL8m`08ooL8m`03o`000?oO8=oogb3O00Wogb3O00Co0000oiUVVOnIIYWo
VFJI0_l00006ojUFZ@03o`000?mPWf3oH9mP00SoH9mP0ol000000omfRGKo0000o`000004ocG:=@03
o`000?lKi1_o6n@K00go6n@K00?o0000oaGZ5OlEjQD03?lEjQD00ol0003o1OX5o`Gj1@07o`Gj1@03
o`000?l0o`3o0?l000Wo0?l000?o0000ocC;=?ldbc@03?ldbc@00ol0003oHYeRof:MHP03o`0000ko
J9MX00?o0000ojiA[_n^DJh00on^DJh00ol0003ohacSon<Lh`0>on<Lh`05o`000?od2oCom0_doo@;
m?l000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003om`SgooL8m`09ooL8m`03o`000?oO8=oogb3O00[o
gb3O00?o0000oiUVVOl000002?nYEZT00ol0003oH9mPof2OH00;of2OH003o`000?lebSGo=LXe00Go
=LXe00?o0000oa_T6olKi1/03?lKi1/00ol0003o5NXEoaGZ5@0<oaGZ5@03o`000?l5nPGo1OX500Oo
1OX500?o0000o`3o0?l0o`002?l0o`02o`0000oo=</d0_l00002ofZEJP03o`000?mXUfSoJ9MX00_o
J9MX00?o0000ojiA[_n^DJh01?n^DJh00ol0003ohacSon<Lh`0=on<Lh`03o`000?od2oCom0_d00?o
m0_d00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooL8m`03o`000?oO8=oogb3O00_ogb3O00?o0000ojUFZOnYEZT0
1onYEZT00ol0003oH9mPof2OH00;of2OH003o`000?lebSGo=LXe00Ko=LXe00?o0000oa_T6olKi1/0
2olKi1/2o`0000go5NXE00?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o0?l0o`3o0007o`3o0004o`00
0?l9mPWo2OH9o`0000ko=</d00?o0000ofZEJ_mZUFX00_mZUFX00ol0003oJ9MXofRGJ009ofRGJ003
o`000?n^DJko[U6^00Ko[U6^00?o0000on<LhooS7><02ooS7><00ol0003om0_doo@;m005oo@;m004
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Som`Sg00?o0000omlPgooO8=l02_oO8=l2o`0000Wo
ZEJY00?o0000of2OH?mPWf002omPWf000ol0003o=LXeocG:=@07ocG:=@03o`000?lKi1_o6n@K00Wo
6n@K00Co0000o`3o0?l0o`3o00003?lEjQD00ol0003o1OX5o`Gj1@07o`Gj1@03o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Wf2Ol9mPWo2OH9o`00000>ocC;=003o`000?mZUF[oJYEZ00?oJYEZ00?o0000
ofRGJ?mXUfP01omXUfP00ol0003o[U6^ojiA[P07ojiA[P03o`000?oS7>?ohacS00[ohacS00?o0000
oo@;m?od2o@01ood2o@00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooL8m`03o`000?oO8=oogb3O
00Wogb3O00Co0000omHYe_oF:MKo00002OnYEZT00ol0003oH9mPof2OH009of2OH003o`000?lebSGo
=LXe00Wo=LXe00?o0000oa_T6olKi1/01olKi1/00ol0003o0?l0o`3o0002o`3o0003o`000?lEjQGo
5NXE00Wo5NXE00?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?l9mPWo
2OH900?o2OH900?o0000ocC;=?ldbc@02_ldbc@00ol0003oJYEZofZEJP05ofZEJP03o`000?mXUfSo
J9MX00GoJ9MX00?o0000ojiA[_n^DJh02?n^DJh00ol0003ohacSon<Lh`09on<Lh`03o`000?od2oCo
m0_d00Som0_d00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_og2?L3o`0000Wogb3O00?o0000omHY
e_oF:MH00_oF:MH00ol0003oZEJYojUFZ@06ojUFZ@03o`000?mPWf3oH9mP00WoH9mP00?o0000ocG:
=OlebSD02_lebSD00ol0003o6n@Koa_T6`05oa_T6`03o`000?l0o`3o0?l000Co0?l000?o0000oaGZ
5OlEjQD02?lEjQD00ol0003o1OX5o`Gj1@07o`Gj1@03o`000?l0o`3o0?l000Co0?l000?o0000o`Wf
2Ol9mPT01?l9mPT00ol0003o=</docC;=00:ocC;=003o`000?mZUF[oJYEZ00KoJYEZ00?o0000ofRG
J?mXUfP00omXUfP00ol0003o[U6^ojiA[P09ojiA[P03o`000?oS7>?ohacS00SohacS00?o0000oo@;
m?od2o@02Ood2o@00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003oo0?l0?o00001OoO8=l00ol0003o
eRWFomHYeP03omHYeP03o`000?nYEZWoZEJY00KoZEJY00?o0000of2OH?mPWf002OmPWf000ol0003o
=LXeocG:=@0;ocG:=@03o`000?lKi1_o6n@K00?o6n@K00?o0000o`3o0?l0o`001_l0o`000ol0003o
5NXEoaGZ5@08oaGZ5@03o`000?l5nPGo1OX500Ko1OX500?o0000o`3o0?l0o`000_l0o`02o`0000So
2OH900?o0000ocC;=?ldbc@02Oldbc@00ol0003oJYEZofZEJP07ofZEJP05o`000?mXUfSoJ9MXofRG
J?l000003On^DJh00ol0003ohacSon<Lh`06on<Lh`03o`000?od2oCom0_d00[om0_d00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o`3o3ol0o`00Gol0o`0ol000000ooO8=oo0000omHYeP06omHYeP03
o`000?nYEZWoZEJY00GoZEJY00?o0000of2OH?mPWf002OmPWf000ol0003o=LXeocG:=@0<ocG:=@05
o`000?lKi1_o6n@Koa_T6ol000002_l0o`000ol0003o5NXEoaGZ5@07oaGZ5@03o`000?l5nPGo1OX5
00Ko1OX500?o0000o`3o0?l000000_l000000ol`cc3o0000o`Wf2@07o`Wf2@03o`000?ldbcCo=</d
00So=</d00?o0000ofZEJ_mZUFX02OmZUFX00ol0003oJ9MXo`00000=ojiA[PCo00001OoS7><00ol0
003om0_doo@;m00;oo@;m003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l008oo0?l003
o`000?oF:MKoeRWF00OoeRWF00?o0000ojUFZOnYEZT01?nYEZT00ol0003oH9mPof2OH009of2OH003
o`000?lebSGo=LXe00go=LXe00?o0000oa_T6ol000003?l0o`0:o`0000Oo1OX50ol00005oc3?<003
o`000?l9mPWo2OH900Ko2OH900?o0000ocC;=?ldbc@01oldbc@00ol0003oJYEZofZEJP0:ofZEJP03
o`000?n^DJko[U6^00_o[U6^00?o0000on4NhOoQ7^400_oQ7^43o`000003on<Lhol0003om0_d00_o
m0_d0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003oeRWFomHYeP07omHYeP03o`00
0?nYEZWoZEJY00GoZEJY00?o0000of2OH?mPWf001omPWf000ol0003o=LXeocG:=@0?ocG:=@;o0000
2ol0o`000ol0003o8m`Sob?L8`07ob?L8`03o`000?l5nPGo1OX500;o1OX50ol00008oc3?<003o`00
0?l9mPWo2OH900Ko2OH900?o0000ocC;=?ldbc@01oldbc@00ol0003oJYEZofZEJP0:ofZEJP03o`00
0?n^DJko[U6^00[o[U6^00?o0000on4NhOoQ7^401_oQ7^400ol0003om0_doo@;m008oo@;m0?o0000
0_og2?L00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003oeRWFomHY
eP08omHYeP03o`000?nYEZWoZEJY00CoZEJY00?o0000of2OH?mPWf001omPWf000ol0003o=LXeocG:
=@0>ocG:=@04o`000?l6n@Ko1_T6o`0000Wo0?l000?o0000ob?L8olSg2<02OlSg2<01?l0003o1OX5
o`000?l0000<oc3?<003o`000?l9mPWo2OH900Ko2OH900?o0000ocC;=?ldbc@01_ldbc@00ol0003o
JYEZofZEJP0;ofZEJP03o`000?n^DJko[U6^00Oo[U6^0_l00009on4Nh@03o`000?od2oCom0_d00Co
m0_d1?l00006ooL8m`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ol0o`oo0?l009oo0?l003o`00
0?oF:MKoeRWF00SoeRWF00?o0000ojUFZOnYEZT00onYEZT>o`0000go=LXe00?o0000o`Ki1_l6n@H0
0_l6n@H00ol0003o0?l0o`3o0005o`3o0003o`000?lSg2?o8m`S00_o8m`S00?o0000oc3?<?l`cc00
3?l`cc000ol0003o2OH9o`Wf2@06o`Wf2@03o`000?ldbcCo=</d00Go=</d00?o0000ofZEJ_mZUFX0
3?mZUFX00ol0003o[U6^ojiA[P06ojiA[P03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo@;m?od2o@0
0ol0000:ooL8m`?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omHYe_oF:MH02?oF
:MH01Ol0003oZEJYojUFZOnYEZWo000000_oLXeb00?o0000oa7^4OlAkQ400ol00009ocG:=@03o`00
0?l6n@Ko1_T600Co1_T600?o0000o`3o0?l0o`000ol0o`000ol0003o8m`Sob?L8`0<ob?L8`03o`00
0?l`cc3o<<l`00go<<l`00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o=</docC;=003ocC;=0?o0000
3OmZUFX00ol0003o[U6^ojiA[P05ojiA[P03o`000?oQ7^7ohAkQ00cohAkQ0_l0000=ooL8m`03o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omHYe_oF:MH02?oF
:MH4o`0000coLXeb00?o0000oa7^4OlAkQ400olAkQ43o`0000Go=LXe00?o0000o`Ki1_l6n@H01_l6
n@H01Ol0003o0?l0o`3o0?l0o`3o000000oo8m`S00?o0000oc3?<?l`cc003Ol`cc000ol0003o2OH9
o`Wf2@06o`Wf2@03o`000?ldbcCo=</d00?o00000olUfRD00ol0003oJYEZofZEJP0;ofZEJP03o`00
0?n^DJko[U6^00?o[U6^00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000oo0?l?o`3o002_o`3o03o`0000KoeRWF0ol0
0003olDja@03o`000?mbSG;oLXeb00[oLXeb00?o0000oa7^4OlAkQ401_lAkQ43o`000003ocG:=Ol0
003o1_T600Wo1_T600?o0000o`3o0?l000004?lSg2<00ol0003o<<l`oc3?<00=oc3?<003o`000?l9
mPWo2OH900Oo2OH90_l00007obGJ9@03o`000?mZUF[oJYEZ00[oJYEZ00Co0000ojiA[_n^DJko[U6^
0ol0000?on4Nh@03o`000?og2?Oom`Sg00_om`Sg00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002_o`
3o001?l0003oj1OXonPGj?oX5nP2o`000004omHYe_l0003o0000o`0000KoaC[500?o0000og:=L_mb
SG802_mbSG800ol0003o4NhAoa7^4@09oa7^4@03o`000?l6n@Ko1_T600[o1_T600?o0000ob?L8olS
g2<03olSg2<00ol0003o<<l`oc3?<00>oc3?<003o`000?l9mPWo2OH900Ko2OH900?o0000obGJ9OlU
fRD01olUfRD4o`0000SoJYEZ00Co0000ojiA[_n^DJko00000oo4>l@2o`0000gohAkQ00?o0000ooL8
moog2?L02_og2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003o
j1OXonPGj004onPGj003o`000?o5>/GoaC[500OoaC[500?o0000og:=L_mbSG802OmbSG800ol0003o
4NhAoa7^4@0:oa7^4@03o`000?l6n@Ko1_T600[o1_T600?o0000ob?L8olSg2<03olSg2<00ol0003o
<<l`oc3?<00>oc3?<003o`000?l9mPWo2OH900Go2OH900?o0000obGJ9OlUfRD02?lUfRD01?l0003o
IIYUofFJIOmUVVD7o`0000;oJYEZ0_l00006ol@ka0;o00003?oQ7^400ol0003om`SgooL8m`09ooL8
m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ol0o`oo0?l008oo0?l003o`000?oX5nSoj1OX00Go
j1OX00?o0000olDjaOo5>/D02?o5>/D00ol0003oLXebog:=LP08og:=LP03o`000?lAkQ7o4NhA00[o
4NhA00?o0000o`Ki1_l6n@H02ol6n@H00ol0003o8m`Sob?L8`0>ob?L8`03o`000?l`cc3o<<l`00ko
<<l`1Ol00002o`Wf2@03o`000?lUfRGo9MXU00Wo9MXU00?o0000ofFJIOmUVVD02?mUVVD3o`0000Wo
a3_40_l0000:on4Nh@03o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o`3o3ol0o`00Sol0o`00?o0000onPGj?oX5nP01ooX5nP00ol0003oaC[5olDja@07olDja@03o`00
0?mbSG;oLXeb00SoLXeb00?o0000oa7^4OlAkQ402_lAkQ400ol0003o1_T6o`Ki1P0:o`Ki1P;o0000
3_lSg2<3o`0000go<<l`0ol00005ocg2?@;o00002olUfRD00ol0003oIIYUofFJI@0;ofFJI@;o0000
2_o4>l@2o`0000OohAkQ0ol00009ooL8m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:onPGj003o`00
0?o5>/GoaC[500OoaC[500?o0000og:=L_mbSG802?mbSG8>o`0000Wo1_T60ol000000ol0o`3o0000
ob?L8`0:ob?L8`?o00000_ll`c`00ol0003o<<l`oc3?<009oc3?<0;o00002Olm`Sd00ol0003o9MXU
obGJ9@09obGJ9@03o`000?mUVVGoIIYU00_oIIYU00?o0000oi1_T?l000002oo4>l@2o`0000CohAkQ
00Co0000onhAk_o^4NkokQ7^0_l00007ooL8m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003oj1OX
onPGj009onPGj003o`000?o5>/GoaC[500KoaC[500?o0000og:=L_mbSG802?mbSG800ol0003o5nPG
oaOX5`0:oaOX5`03o`000?l6n@Ko1_T600Co1_T60ol00005o`3o0003o`000?lSg2?o8m`S00Co8m`S
1?l00006occ3?003o`000?l`cc3o<<l`00Ko<<l`0_l0000;ocg2?@03o`000?lUfRGo9MXU00Wo9MXU
00?o0000ofFJIOmUVVD02_mUVVD01Ol0003oT6n@oi1_T?n@Ki3o000000coa3_40_l000000ooQ7^7o
0000onhAkP05onhAkP03o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oX5nSoj1OX00Soj1OX00?o0000olDjaOo5>/D01_o5>/D00ol0003oLXebog:=LP07og:=LP03o`00
0?lGj1Oo5nPG00_o5nPG00?o0000o`Ki1_l6n@H00_l6n@H2o`0000Wo0?l000?o0000ob?L8olSg2<0
0ol0000;occ3?003o`000?l`cc3o<<l`00;o<<l`0ol0000>ocg2?@03o`000?lUfRGo9MXU00Oo9MXU
00?o0000ofFJIOmUVVD02omUVVD00ol0003oT6n@oi1_T002oi1_T003o`000?o4>lCoa3_400_oa3_4
00?o0000onhAk_o^4Nh01_o^4Nh2o`0000?om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oX
5nSoj1OX00Ooj1OX00?o0000olDjaOo5>/D01oo5>/D00ol0003oLXebog:=LP05og:=LP?o00003OlG
j1L4o`0000_o0?l00ol0000?occ3?004o`000?l`cc3o0000o`00017o?L8m00?o0000obGJ9OlUfRD0
1olUfRD00ol0003oIIYUofFJI@0:ofFJI@03o`000?n@Ki3oT6n@00CoT6n@00?o0000ol@ka?o4>l@0
1oo4>l@3o`0000_okQ7^1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onPGj?oX5nP02?oX5nP00ol0003oaC[5olDj
a@06olDja@03o`000?mbSG;oLXeb00;oLXeb0ol00003odjaCP03o`000?lGj1Oo5nPG00[o5nPG00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aocc3?003o`000?lm`Sgo?L8m017o?L8m00?o
0000obGJ9OlUfRD01olUfRD00ol0003oIIYUofFJI@0:ofFJI@03o`000?n@Ki3oT6n@00GoT6n@00Co
0000ol@ka?o4>lCoa3_41Ol00002ol`cc003o`000?o^4NkokQ7^00WokQ7^00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onPGj?oX5nP01ooX5nP00ol0003oaC[5olDja@05olDja@?o0000
00?oLXebo`000?l000001om>/Dh00ol0003o5nPGoaOX5`08oaOX5`?o00002_l0o`02o`0000;o0?l0
00?o0000occ3??ll`c`03oll`c`00ol0003o?L8mocg2?@0Aocg2?@03o`000?lUfRGo9MXU00Oo9MXU
00?o0000ofFJIOmUVVD02OmUVVD00ol0003oT6n@oi1_T007oi1_T0?o00001oo<<l`00ol0003okQ7^
onhAkP09onhAkP03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onPGj?oX5nP01ooX
5nP4o`0000;oaC[50_l00003okQ7^003o`000?m>/DkoC[5>00SoC[5>0_l00006oaOX5`;o00000olD
ja@00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000occ3??ll`c`03_ll
`c`00ol0003o?L8mocg2?@0Bocg2?@03o`000?lUfRGo9MXU00Go9MXU00?o0000ofFJIOmUVVD02OmU
VVD00ol0003oT6n@oi1_T008oi1_T003o`000?o<<lcoc3?<00Ooc3?<00?o0000onhAk_o^4Nh02?o^
4Nh00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oX5nSoj1OX00Coj1OX0_l00004
onPGj0;o00001OnhAkP00ol0003oC[5>odjaCP0:odjaCP03o`000?lGj1Oo5nPG00;o5nPG00?o0000
oaC[5?lDja@01?lDja@00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
occ3??ll`c`03_ll`c`00ol0003o?L8mocg2?@0Bocg2?@[o00002_mUVVD00ol0003oT6n@oi1_T008
oi1_T003o`000?o<<lcoc3?<00Ooc3?<00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003oj1OXonPGj?oX5nP2o`0000Ooj1OX00?o0000okQ7^?nhAkP01?nhAkP0
0ol0003oC[5>odjaCP0:odjaCP04o`000?lGj1Oo0000o`0000So5>/D00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?ll`cco?<<l00ko?<<l00?o0000ocg2?Olm`Sd04_lm`Sd00ol0003o@[e2
od:m@P07od:m@P03o`000?mUVVGoIIYU00KoIIYU00?o0000oi1_T?n@Ki002_n@Ki000ol0003oc3?<
ol`cc006ol`cc003o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oX
5nSo0000o`0000Woj1OX00?o0000okQ7^?nhAkP01?nhAkP00ol0003oC[5>odjaCP0;odjaCP03o`00
0?lDjaCo5>/D00Wo5>/D00?o0000o`3o0?l000002Ol0o`000ol0003o?<<locc3?00>occ3?0;o0000
4_lm`Sd00ol0003o@[e2od:m@P09od:m@P;o00001_mUVVD00ol0003oT6n@oi1_T00:oi1_T003o`00
0?o<<lcoc3?<00Koc3?<00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onPGj?oX5nP02OoX5nP00ol0003o^4NhokQ7^005okQ7^003o`000?m>/DkoC[5>00[oC[5>00?o
0000oaC[5?lDja@02_lDja@2o`0000Wo0?l000?o0000occ3??ll`c`03_ll`c`00ol0003o:MHYo`00
0002o`0000oo?L8m00?o0000od:m@_m2_D802om2_D800ol0003oIIYUofFJI@03o`0000goT6n@00?o
0000ol`cc?o<<l`01_o<<l`00ol0003okQ7^onhAkP07onhAkP03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003oj1OXonPGj009onPGj003o`000?nhAkSo^4Nh00Go^4Nh00?o0000odjaC_m>/Dh02Om>/Dh2
o`0000_o5>/D0_l0000;o`3o0003o`000?ll`cco?<<l00co?<<l00?o0000obWF:OlYeRT00olYeRT3
o`0000co?L8m00?o0000od:m@_m2_D803?m2_D82o`0000;oQWV600?o0000oi1_T?n@Ki003?n@Ki00
0ol0003oc3?<ol`cc005ol`cc003o`000?o^4NkokQ7^00OokQ7^00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oX5nSoj1OX00[oj1OX00?o0000okQ7^?nhAkP01_nhAkP00ol0003oC[5>odjaCP07odja
CP03o`000?mA[U7o000000[o5>/D00Co0000o`[e2_l:m@[o00002_l0o`000ol0003o?<<locc3?00<
occ3?003o`000?lYeRWo:MHY00Ko:MHY0_l00008ocg2?@;o00003om2_D800ol0003oQWV6ohIiQP02
ohIiQP03o`000?n@Ki3oT6n@00_oT6n@00?o0000ol`cc?o<<l`01Oo<<l`00ol0003okQ7^onhAkP07
onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oj1OXonPGj00:onPGj003o`000?nhAkSo^4Nh
00Ko^4Nh00?o0000odjaC_m>/Dh01_m>/Dh01Ol0003oDJiAoe6^DOmA[U7o000000So5>/D00?o0000
o`[e2_l:m@X00_l:m@X00ol0003o0?l0o`3o0006o`3o00Co00003?ll`c`00ol0003o:MHYobWF:@08
obWF:@?o00000_lm`Sd3o`000003oc?<<ol0003o@[e200go@[e200?o0000ohIiQ_n6NHH01?n6NHH0
0ol0003oT6n@oi1_T00:oi1_T003o`000?o<<lcoc3?<00Goc3?<00?o0000onhAk_o^4Nh01_o^4Nh0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onPGj?oX5nP02ooX5nP00ol0003o^4NhokQ7^007okQ7
^003o`000?m>/DkoC[5>00?oC[5>0_l00005oe6^D@03o`000?lDjaCo5>/D00Co5>/D00?o0000o`[e
2_l:m@X00ol:m@X00ol0003o0?l0o`3o0005o`3o0003o`000?l9mPWo2OH900;o2OH90ol00007occ3
?0;o00003_lYeRT2o`0000Go<l`c00?o0000od:m@_m2_D802_m2_D800ol0003oQWV6ohIiQP05ohIi
QP03o`000?n@Ki3oT6n@00_oT6n@00?o0000ol`cc?o<<l`01?o<<l`00ol0003okQ7^onhAkP06onhA
kP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oj1OXonPGj00;onPGj003o`000?nhAkSo^4Nh00Oo
^4Nh00?o0000odjaC_m>/Dh00_m>/Dh00ol0003oDJiAoe6^D@06oe6^D@03o`000?lDjaCo5>/D00;o
5>/D00?o0000o`[e2_l:m@X01Ol:m@X00ol0003o0?l0o`3o0002o`3o00;o00002?l9mPT3o`0000;o
?<<l0_l000000ol?l0oo0000obWF:@0=obWF:@03o`000?lcc3?o<l`c00Go<l`c00?o0000od:m@_m2
_D802?m2_D800ol0003oQWV6ohIiQP07ohIiQP03o`000?n@Ki3oT6n@00[oT6n@00?o0000ol`cc?o<
<l`01?o<<l`00ol0003okQ7^onhAkP06onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003oj1OX
onPGj00<onPGj003o`000?nhAkSo^4Nh00So^4Nh00Co0000odjaC_m>/Dko00002OmA[U401Ol0003o
5>/DoaC[5?lDjaCo000000So2_D:00Go0000o`3o0?l0o`3o0?l0o`00000=o`Wf2@;o00001?l?l0l0
0ol0003o:MHYobWF:@0;obWF:@03o`000?lcc3?o<l`c00Ko<l`c00?o0000od:m@_m2_D801om2_D80
0ol0003oQWV6ohIiQP08ohIiQPCo00002?n@Ki000ol0003oc3?<ol`cc004ol`cc003o`000?o^4Nko
kQ7^00KokQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oX5nSoj1OX00_oj1OX0ol00009okQ7
^003o`000?m>/Dko000000_oDJiA00?o0000oaC[5?l000002_l:m@X00ol0003o0?l0o`00000?o`Wf
2@03o`000?l?l0oo3o0?00;o3o0?00?o0000obWF:OlYeRT02olYeRT00ol0003o<l`coc?<<`06oc?<
<`03o`000?m2_D;o@[e200Ko@[e200?o0000ohIiQ_n6NHH02On6NHH01?l0003o]DZeokE:]OneB[D7
o`0000;oT6n@00?o0000ol`cc?o<<l`00oo<<l`00ol0003okQ7^onhAkP05onhAkP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oX5nSoj1OX00Soj1OX0ol00003on@Ki003o`000?nhAkSo^4Nh00Oo^4Nh00?o0000oe6^
DOmA[U402omA[U400ol0003o2_D:o`[e2P0:o`[e2P03o`000?l9mPWo2OH900go2OH900?o0000o`o`
3ol?l0l01?l?l0l00ol0003o:MHYobWF:@09obWF:@03o`000?lcc3?o<l`c00So<l`c00?o0000od:m
@_m2_D800om2_D82o`0000coQWV600?o0000okE:]OneB[D02?neB[D<o`0000?okQ7^0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onPGj?oX5nP01_oX5nP3o`0000Ooi1_T00?o0000okQ7^?nhAkP01_nhAkP00ol0003o
DJiAoe6^D@0;oe6^D@03o`000?l:m@[o2_D:00Wo2_D:0_l0000>o`Wf2@03o`000?l?l0oo3o0?00Go
3o0?00?o0000obWF:OlYeRT02OlYeRT00ol0003o<l`coc?<<`09oc?<<`03o`000?m2_D;o000000;o
00000_mkQ7/00ol0003oQWV6ohIiQP08ohIiQP03o`000?neB[Go]DZe00co]DZe00?o0000onPGj?oX
5nP01_oX5nP3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003oj1OXonPGj003onPGj0?o00002ooT6n@00ol0003o^4Nh
okQ7^004okQ7^003o`000?mA[U7oDJiA00_oDJiA0ol00007o`[e2P?o000000?o3?<<o`000?l9mPT0
3Ol9mPT00ol0003o3o0?o`o`3`06o`o`3`03o`000?lYeRWo:MHY00So:MHY00?o0000oc?<<olcc3<0
2_lcc3<00ol0003oNhAkog^4N`04og^4N`03o`000?n6NHKoQWV600OoQWV600?o0000okE:]OneB[D0
2oneB[D00ol0003oj1OXonPGj008onPGj003o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onPGj?l0
003o0000o`0000ooi1_T00?o0000okQ7^?nhAkP00onhAkP>o`0000?o?/4n0_l00002o`[e2P?o0000
1Ol<l``00ol0003o2OH9o`Wf2@0:o`Wf2@03o`000?l?l0oo3o0?00Oo3o0?00?o0000obWF:OlYeRT0
2?lYeRT00ol0003o<l`coc?<<`0:oc?<<`03o`000?mkQ7_oNhAk00GoNhAk00?o0000ohIiQ_n6NHH0
1_n6NHH00ol0003o]DZeokE:]@0;okE:]@03o`000?oX5nSoj1OX00Soj1OX00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;oi1_T00?o0000okQ7^?nhAkP00_nhAkP00ol0003oWV6NoiiQ
WP0:oiiQWP03o`000?ln`Cko?/4n00?o?/4n0_l00009o`cc3003o`000?l9mPWo2OH900Wo2OH900?o
0000o`o`3ol?l0l02?l?l0l2o`0000So:MHY00?o0000oc?<<olcc3<02Olcc3<00ol0003oNhAkog^4
N`07og^4N`03o`000?n6NHKoQWV600CoQWV600?o0000okE:]OneB[D02oneB[D00ol0003oj1OXonPG
j009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oi1_Ton@Ki00?on@Ki0?o000000?o^4Nh
o`000?nNHIh02onNHIh00ol0003o?/4nock1?P04ock1?P03o`000?l<l`co3?<<00Wo3?<<00?o0000
o`Wf2Ol9mPT01ol9mPT00ol0003o3o0?o`o`3`09o`o`3`04o`000?lEjQGo0000o`0000Ko:MHY00?o
0000oc?<<olcc3<02Olcc3<00ol0003oNhAkog^4N`08og^4N`03o`000?n6NHKoQWV600?oQWV600?o
0000okE:]OneB[D02oneB[D00ol0003oj1OXonPGj009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oi1_Ton@Ki00<on@Ki0;o00000ooR7N82o`0000coWV6N00?o0000ock1?_ln`Ch01?ln`Ch0
0ol0003o3?<<o`cc300:o`cc30Wo00002ol?l0l00ol0003o5NXEoaGZ5@02oaGZ5@?o00000_lYeRT0
0ol0003o<l`coc?<<`0:oc?<<`03o`000?mkQ7_oNhAk00WoNhAk00?o0000ohIiQ_n6NHH00_n6NHH0
0ol0003o]DZeokE:]@0:okE:]@03o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oT6n@2o`0000GohQgR00?o0000okU6^Ol000002_nNHIh00ol0003o?/4nock1?P06ock1
?P03o`000?l<l`co3?<<00Wo3?<<00?o0000o`;m0_l2o@801Ol2o@800ol0003o3o0?o`o`3`09o`o`
3`03o`000?lEjQGo5NXE00Go5NXE0ol00009oc?<<`?o00003OmkQ7/01Ol0003oQWV6ohIiQ_n6NHKo
000000co]DZe00?o0000onPGj?oX5nP02OoX5nP00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on@K
i?oT6n@01OoT6n@2o`0000OohQgR00Co0000okU6^OniA[Wo00002OnNHIh00ol0003o?/4nock1?P06
ock1?P03o`000?l<l`co3?<<00So3?<<00?o0000o`;m0_l2o@801ol2o@800ol0003o3o0?o`o`3`07
o`o`3`03o`000?lEjQGo5NXE00So5NXE0ol00002oc?<<`Go00000_mIYUT00ol0003oNhAkog^4N`0<
og^4N`03o`000?n6NHKo000000co]DZe00?o0000onPGj?oX5nP02_oX5nP00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000on@Ki?oT6n@00_oT6n@2o`0000SohQgR00?o0000okU6^OniA[T00_niA[T5o`00
00CoWV6N00?o0000ock1?_ln`Ch01_ln`Ch00ol0003o3?<<o`cc3008o`cc3003o`000?l2o@;o0_d2
00Oo0_d200?o0000o`o`3ol?l0l01ol?l0l00ol0003o5NXEoaGZ5@08oaGZ5@03o`000?lWf2Oo9mPW
00;o00002?mIYUT00ol0003oNhAkog^4N`0<og^4N`Co00002_neB[D00ol0003oj1OXonPGj00:onPG
j003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oi1_To`000?l0000:on8MhP03o`000?niA[Wo^DJi
00;o^DJi00?o0000og^4NomkQ7/00_mkQ7/4o`0000Wo?/4n00?o0000o`cc3?l<l``02?l<l``00ol0
003o0_d2o`;m0P08o`;m0P03o`000?l?l0oo3o0?00Go3o0?00?o0000oaGZ5OlEjQD02?lEjQD01Ol0
003o9mPWobOH9olWf2Oo000000[oFJII0ol0000;og^4N`04o`000?oI9]WofBKIomTVf@Co00001One
B[D00ol0003oj1OXonPGj00;onPGj003o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ohQgRon8MhP0:
on8MhP03o`000?niA[Wo^DJi00?o^DJi00?o0000og^4NomkQ7/01?mkQ7/00ol0003o?/4nock1?P07
ock1?P03o`000?l<l`co3?<<00Ko3?<<0_l0000;o`;m0P03o`000?l?l0oo3o0?00Go3o0?00?o0000
oaGZ5OlEjQD02?lEjQD00ol0003o9mPWobOH9`02obOH9`03o`000?mIYUWoFJII00OoFJII00?o0000
ojQGZ?nXEjP01?l00006og^4N`03o`000?oI9]WofBKI00KofBKI0ol00002okE:]@03o`000?oX5nSo
j1OX00_oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oR7N;ohQgR00WohQgR00?o0000okU6
^OniA[T01?niA[T00ol0003oNhAkog^4N`05og^4N`03o`000?ln`Cko?/4n00Oo?/4n00?o0000o`cc
3?l<l``00_l<l``3o`000003oa[U6_l0003o0_d200[o0_d200?o0000o`o`3ol?l0l01Ol?l0l00ol0
003o5NXEoaGZ5@07oaGZ5@03o`000?lWf2Oo9mPW00?o9mPW00?o0000oeVVFOmIYUT01omIYUT00ol0
003oZ5NXojQGZ004ojQGZ0?o00000_mkQ7/00ol0003ofBKIomTVf@0:omTVf@;o00003_oX5nP00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000on8Mh_oR7N802OoR7N800ol0003o^DJiokU6^@04okU6^@03
o`000?mkQ7_oNhAk00KoNhAk0_l00007ock1?P03o`000?l<l`co000000;o00001OlJiAX00ol0003o
0_d2o`;m0P08o`;m0P?o00001?l?l0l00ol0003o5NXEoaGZ5@08oaGZ5@03o`000?lWf2Oo9mPW00Co
9mPW00?o0000oeVVFOmIYUT01_mIYUT00ol0003oZ5NXojQGZ007ojQGZ0;o00003_oI9]T00ol0003o
j1OXonPGj00;onPGj003o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ohQgRon8MhP08on8MhP03o`00
0?niA[Wo^DJi00Go^DJi00?o0000og^4NomkQ7/01?mkQ7/00ol0003oM8]dogB;M003o`0000Co?/4n
0_l00008oa[U6P03o`000?l2o@;o0_d200Oo0_d200Co0000oc3?<?l`cc3o<<l`0ol000000ol?l0oo
0000oaGZ5@09oaGZ5@03o`000?lWf2Oo9mPW00Co9mPW00?o0000oeVVFOmIYUT01OmIYUT00ol0003o
Z5NXojQGZ009ojQGZ003o`000?oI9]WofBKI00gofBKI00?o0000onPGj?oX5nP02_oX5nP00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000on8Mh_oR7N801ooR7N800ol0003o^DJiokU6^@06okU6^@03o`00
0?mkQ7_oNhAk00?oNhAk00?o0000ogB;M?mdRg@01?mdRg@2o`000003ock1?_l0003o6^DJ00[o6^DJ
00?o0000o`;m0_l2o@801Ol2o@800ol0003o<<l`oc3?<005oc3?<003o`000?lEjQGo5NXE00Oo5NXE
0ol00007obOH9`03o`000?mIYUWoFJII00CoFJII00?o0000ojQGZ?nXEjP02OnXEjP00ol0003ofBKI
omTVf@0=omTVf@03o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oR
7N;ohQgR00GohQgR0ol00009okU6^@05o`000?mkQ7_oNhAkog^4Nol000002OmdRg@00ol0003o6^DJ
oa[U6P0;oa[U6P03o`000?l2o@;o0_d200?o0_d200?o0000oc3?<?l`cc001_l`cc000ol0003o5NXE
oaGZ5@06oaGZ5@05o`000?lcc3?o<l`coc?<<ol000001olWf2L00ol0003oFJIIoeVVF@03oeVVF@03
o`000?nXEjSoZ5NX00WoZ5NX00?o0000omTVfOoI9]T03_oI9]T00ol0003oj1OXonPGj009onPGj003
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ohQgRo`000004o`0000;ok1?/00?o0000okU6^OniA[T0
1oniA[T01?l0003oNhAkog^4Nol00009ogB;M0;o00003OlJiAX00ol0003o0_d2o`;m0P02o`;m0P03
o`000?l`cc3o<<l`00So<<l`00?o0000oaGZ5OlEjQD00olEjQD2o`0000Go<l`c00?o0000obOH9olW
f2L01?lWf2L00ol0003oFJIIoeVVF@03oeVVF@03o`000?nXEjSoZ5NX00WoZ5NX00?o0000omTVfOoI
9]T03_oI9]T00ol0003oj1OXonPGj009onPGj003o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sok1?/
00?o0000okU6^OniA[T01_niA[T00ol0003oNhAko`000009ogB;M004o`000?mC[5?oDjaCo`0000go
6^DJ00Co0000o`;m0_l2o@;o00003?l`cc001Ol0003o5NXEoaGZ5OlEjQGo000000So<l`c0_l00005
obOH9`03o`000?mIYUWoFJII00;oFJII00?o0000ojQGZ?nXEjP02OnXEjP00ol0003ofBKIomTVf@0>
omTVf@03o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/4ncok1?/
00Ook1?/00?o0000okU6^OniA[T01oniA[T00ol0003oM8]dogB;M007ogB;M003o`000?mC[5?oDjaC
00;oDjaC00?o0000oa[U6_lJiAX02_lJiAX00ol0003o0_d2o`00000>oc3?<003o`000?lEjQGo0000
00_o<l`c00?o0000obOH9olWf2L00_lWf2L01Ol0003oFJIIoeVVFOmIYUWo000000coZ5NX00?o0000
omTVfOoI9]T03_oI9]T3o`0000Woj1OX00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o/4ncok1?/
00Wok1?/00?o0000okU6^OniA[T01_niA[T00ol0003oM8]dogB;M006ogB;M003o`000?mC[5?oDjaC
00?oDjaC00?o0000oa[U6_lJiAX02olJiAX00ol0003o<<l`oc3?<00>oc3?<003o`000?lcc3?o<l`c
00_o<l`c0_l00003obOH9`04o`000?mIYUWoFJIIo`0000[oZ5NX0ol0000>omTVf@;o00000ool0o`2
o`0000Ooj1OX00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o/4ncok1?/00[ok1?/00?o0000okU6
^OniA[T01?niA[T00ol0003oM8]dogB;M006ogB;M003o`000?mC[5?oDjaC00GoDjaC00?o0000oa[U
6_lJiAX01olJiAX3o`00017o<<l`00?o0000oc?<<olcc3<03Olcc3<01Ol0003o9mPWobOH9ol0003o
FJII00Co00000onXEjP5o`0000;oiA[U00?o0000omTVfOoI9]T02_oI9]T2o`0000Ooo0?l0_l00004
onPGj003o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ok1?/on`Ck00;on`Ck003o`000?niA[Wo^DJi
00Co^DJi00?o0000ogB;M?mdRg@01OmdRg@00ol0003oDjaCoe>/D`06oe>/D`03o`000?lJiA[o6^DJ
00Co6^DJ0ol00002ob7N8@03o`000?l`cc3o<<l`00oo<<l`0_l0000?oc?<<`04o`000?lWf2Oo0000
o`0000CoTfbC0ol00008onDJi@03o`000?oI9]WofBKI00OofBKI0_l0000;oo`3o0;o00000_oX5nP0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000on`Ck?o/4n`03?o/4n`6o`0000OoM8]d00?o0000oe>/
DomC[5<02?mC[5<00ol0003o6^DJoa[U6P03o`0000Ko8MhQ00?o0000oc3?<?l`cc003Ol`cc001?l0
003o?l0ooco0?ol0000?oc?<<`03o`000?nCK9?oTfbC00GoTfbC00?o0000onDJiOoU6^D02?oU6^D0
0ol0003ofBKIomTVf@05omTVf@03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o/4n`00ol0003o_cnooklo_`04oklo
_`03o`000?mdRgCoM8]d00?oM8]d00?o0000oe>/DomC[5<02_mC[5<2o`0000[o8MhQ00?o0000oc3?
<?l`cc002ol`cc000ol0003o?l0ooco0?`02oco0?`03o`000?lcc3?o<l`c00_o<l`c0_l00007oi=/
T`03o`000?oU6^GoiA[U00WoiA[U00?o0000omTVfOoI9]T00_oI9]T2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000on`Ck?o/4n`02oo/4n`00ol0003o_cnooklo_`06oklo_`05o`000?mdRgCoM8]dogB;
M?l000003OmC[5<00ol0003o8MhQob7N8@0:ob7N8@03o`000?l`cc3o<<l`00Wo<<l`00?o0000oco0
?olo`3l01?lo`3l00ol0003o<l`coc?<<`08oc?<<`;o000000?oAKY5o`000?nCK9<01onCK9<00ol0
003oiA[UonDJi@09onDJi@04o`000?oI9]Wo0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?o/4ncok1?/
00Wok1?/00?o0000oklo_ono?kl02?no?kl00ol0003oM8]do`00000=oe>/D`03o`000?lQgR7o8MhQ
00_o8MhQ00?o0000oc3?<?l`cc002?l`cc000ol0003o?l0ooco0?`06oco0?`03o`000?lcc3?o<l`c
00Go<l`c0_l00003odFjA@03o`000?nCK9?oTfbC00KoTfbC00?o0000onDJiOoU6^D02_oU6^D00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ok1?/on`Ck007on`Ck003o`000?no?koo_cno00[o_cno00?o0000oe>/DomC
[5<03?mC[5<00ol0003o8MhQob7N8@0<ob7N8@03o`000?l`cc3o<<l`00Ko<<l`00?o0000oco0?olo
`3l02?lo`3l00ol0003o<l`coc?<<`02oc?<<`;o00001_m5^TD00ol0003oTfbCoi=/T`05oi=/T`03
o`000?oU6^GoiA[U00[oiA[U00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/4ncok1?/00Gok1?/
00?o0000oklo_ono?kl03?no?kl2o`0000coDjaC00?o0000ob7N8OlQgR403OlQgR400ol0003o<<l`
oc3?<004oc3?<003o`000?lo`3oo?l0o00[o?l0o00Co0000oc?<<ol0003o00002?m5^TD00ol0003o
TfbCoi=/T`06oi=/T`03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_o/4n`00ol0003o_cnooklo_`0=oklo_`03o`000?mdRgCo000000;o00002?mC[5<00ol0003o8MhQ
ob7N8@0?ob7N8@Ko00003_lo`3l00ol0003oAKY5odFjA@08odFjA@03o`000?nCK9?oTfbC00KoTfbC
00?o0000onDJiOoU6^D02OoU6^D00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onhAk_o^4NkokQ7^
0_l0000?oklo_`03o`000?mdRgCoM8]d00?oM8]d0ol00005oe>/D`;o00004?lQgR401_l0003o5^TF
oaKY5_l0003o2OH9o`0000ko?l0o00?o0000odFjAOm5^TD02Om5^TD00ol0003oTfbCoi=/T`05oi=/
T`03o`000?oU6^GoiA[U00WoiA[U00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onhAk_o^4Nh00oo^4Nh00ol0003o
_cnooklo_`0=oklo_`03o`000?mdRgCoM8]d00KoM8]d0ol000001?mC[5?o0000obgB;Ol]dRd3o`00
00co8MhQ00Go0000oaKY5_lFjAKo5^TFo`000002o`Wf2@03o`000?lo`3oo?l0o00_o?l0o00?o0000
odFjAOm5^TD02Om5^TD00ol0003oTfbCoi=/T`06oi=/T`03o`000?oU6^GoiA[U00SoiA[U0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003okQ7^onhAkP04onhAkPoo00003?mdRg@00ol0003o;M8]obgB;@04obgB
;@?o00002?lQgR400ol0003o5^TFoaKY5P02oaKY5P05o`000?l9mPWo2OH9o`Wf2Ol000003?lo`3l0
0ol0003oAKY5odFjA@09odFjA@03o`000?nCK9?oTfbC00GoTfbC3?l00002oo@;m0;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003okQ7^onhAkP05onhAkP03o`000?o0?l3o`3o000_o`3o000?o0000ogB;
M?mdRg@02_mdRg@00ol0003o;M8]obgB;@07obgB;@;o00001OlQgR400ol0003o5^TFoaKY5P03oaKY
5P03o`000?l9mPWo2OH900;o2OH900?o0000oco0?olo`3l02Olo`3l00ol0003oAKY5odFjA@0:odFj
A@03o`000?nCK9?oTfbC00?oTfbC00?o0000omTVfOoI9]T02OoI9]T00ol0003om0_doo@;m002oo@;
m0;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003okQ7^onhAkP06onhAkP03o`000?o0?l3o`3o000[o
`3o000?o0000ogB;M?mdRg@02omdRg@00ol0003o;M8]obgB;@09obgB;@?o000000?o8MhQo`000?lF
jAH01OlFjAH00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?lo`3oo?l0o00So?l0o3_l00003oi=/T`;o
00002ooI9]T00ol0003om0_doo@;m005oo@;m003o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003oc3?<o`00000;ol0o`003o`000?mdRgCoM8]d00[oM8]d
0_l0000>obgB;@03o`000?lFjAKo5^TF00Go5^TF00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o?l0o
oco0?`08oco0?`03o`000?n?L8ooSg2?00_oSg2?00?o0000oi=/Tol000003OoI9]T00ol0003om0_d
oo@;m006oo@;m0;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o^4NkokQ7^00KokQ7^00Co
0000ol`cc?o<<lco00002_o0?l000ol0003oM8]dogB;M009ogB;M003o`000?m=/Tgo000000ko;M8]
00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2OH9o`Wf2@04o`Wf2@03o`000?lo`3oo?l0o00Ko?l0o
00?o0000ohm`Son?L8l03On?L8l00ol0003ofBKIomTVf@0<omTVf@03o`000?od2oCom0_d00Som0_d
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^00GokQ7^00?o0000ol`cc?o<<l`00_o<
<l`00ol0003o`3o0ol0o`006ol0o`003o`000?mdRgCoM8]d00SoM8]d0_l00003odfbC@03o`000?l]
dRgo;M8]00_o;M8]00?o0000oaKY5_lFjAH01OlFjAH00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?lo
`3oo?l0o00Go?l0o00?o0000ohm`Son?L8l03On?L8l00ol0003ofBKIomTVf@0;omTVf@03o`000?od
2oCom0_d00Wom0_d00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o^4NkokQ7^00KokQ7^00?o0000
ol`cc?o<<l`00oo<<l`00ol0003o`3o0ol0o`005ol0o`003o`000?mdRgCoM8]d00OoM8]d00?o0000
odfbCOm=/Td00om=/Td00ol0003o;M8]obgB;@0:obgB;@03o`000?lFjAKo5^TF00Ko5^TF00?o0000
o`Wf2Ol9mPT01_l9mPT00ol0003o?l0ooco0?`04oco0?`03o`000?n?L8ooSg2?00goSg2?3ol0000;
oo@;m003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o^4NkokQ7^00KokQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0
003o`3o0ol0o`004ol0o`003o`000?mdRgCoM8]d00GoM8]d0_l00006odfbC@03o`000?l]dRgo;M8]
00Wo;M8]0_l00008oaKY5P03o`000?l9mPWo2OH900Ko2OH91Ol000000olo`3oo0000ohm`S`0?ohm`
S`03o`000?oK9=_ofbCK00_ofbCK00?o0000oo@;m?od2o@02Ood2o@00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o^4NkokQ7^00KokQ7^00?o0000ol`cc?o<<l`01_o<<l`00ol0003o
`3o0ol0o`004o`0000KoM8]d00?o0000odfbCOm=/Td01om=/Td00ol0003o;M8]obgB;@05obgB;@?o
000000?o6n@Ko`000?lFjAH01olFjAH00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?m</dcoC;=<00?o
C;=<0_l0000?ohm`S`;o00003OoK9=/00ol0003om0_doo@;m008oo@;m003o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000WokQ7^00?o0000ol`cc?o<<l`01oo<<l`2o`0000CoYEZU00Co0000ogB;M?mdRgCo
M8]d0_l0000:odfbC@03o`000?l]dRgo;M8]00;o;M8]0ol00005oa_T6`03o`000?lFjAKo5^TF00Go
5^TF00?o0000o`Wf2Ol9mPT01?l9mPT00ol0003oC;=<odbcC006odbcC003o`000?n?L8ooSg2?00[o
Sg2?0_l00002okY5^P03o`000?oK9=_ofbCK00[ofbCK00?o0000oo@;m?od2o@02?od2o@00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oc3?<ol`cc008ol`cc003o`00
0?nUFZGoYEZU00CoYEZU00?o0000ogB;M?l000003?m=/Td00ol0003o;M8]o`000002o`0000Wo6n@K
00?o0000oaKY5_lFjAH01?lFjAH00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?m</dcoC;=<00SoC;=<
1_l00004ohm`S`;o00001OnjAKX00ol0003ofbCKom/Tf`09om/Tf`03o`000?od2oCom0_d00Som0_d
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o^4NkokQ7^00GokQ7^00?o0000ol`cc?o<<l`01oo<
<l`00ol0003oYEZUojEJY@06ojEJY@03o`000?m=/TgoCK9=00coCK9=00?o0000oa_T6olKi1/02_lK
i1/00ol0003o5^TFoaKY5P04oaKY5P04o`000?l9mPWo2OH9o`Wf2@;o00002om</d`00ol0003oUFZE
oiEZU@03oiEZU@Co00002?njAKX00ol0003ofbCKom/Tf`08om/Tf`03o`000?od2oCom0_d00Oom0_d
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oc3?<ol`cc007ol`cc003o`000?nU
FZGoYEZU00OoYEZU00?o0000odfbCOm=/Td03?m=/Td00ol0003o6n@Koa_T6`0;oa_T6`03o`000?lF
jAKo5^TF00?o5^TF00Co0000o`Wf2Ol9mPWo00003Om</d`00ol0003oUFZEoiEZU@06oiEZU@03o`00
0?njAK[o^TFj00Oo^TFj00?o0000om/TfooK9=/01ooK9=/00ol0003om0_doo@;m006oo@;m004o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o^4NkokQ7^00;okQ7^00?o0000ol`cc?o<<l`0
1_o<<l`00ol0003oYEZUojEJY@09ojEJY@03o`000?m=/TgoCK9=00WoCK9=0_l0000>oa_T6`?o0000
0olFjAH00ol0003o2OH9o`00000=odbcC003o`000?nEJYGoUFZE00OoUFZE00?o0000okY5^_njAKX0
2?njAKX:o`0000Kom0_d0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000Ooc3?<00?o
0000ojEJYOnUFZD02_nUFZD00ol0003oCK9=odfbC@06odfbC@;o000000?oAKY5o`000?lKi1/02olK
i1/2o`0000?o?<<l1Ol0000>odbcC003o`000?nEJYGoUFZE00OoUFZE00?o0000okY5^_njAKX02?nj
AKX00ol0003oi1_Ton@Ki006on@Ki003o`000?od2oCom0_d00?om0_d00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003oi1_Ton@Ki003on@Ki0Co00000_o<<l`00ol0003oYEZUojEJY@0;
ojEJY@03o`000?m=/TgoCK9=00?oCK9=0ol00004odFjA@03o`000?lKi1_o6n@K00Oo6n@K0_l00008
occ3?003o`000?m</dcoC;=<00goC;=<00?o0000oiEZUOnEJYD02?nEJYD00ol0003o^TFjokY5^P07
okY5^P03o`000?oT6nCoi1_T00Ooi1_T0ol000000ood2oCo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oT6nCoi1_T00Ooi1_T0_l0000?ojEJY@03o`000?m=/TgoCK9=00;o00002?m5^TD00ol0
003o6n@Koa_T6`05oa_T6`03o`000?ll`cco?<<l00So?<<l00?o0000odbcC?m</d`03Om</d`00ol0
003oUFZEoiEZU@08oiEZU@03o`000?njAK[o^TFj00Ko^TFj00?o0000on@Ki?oT6n@02?oT6n@01?l0
003om@[eooD:mOl0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oi1_Ton@Ki009on@K
i003o`000?nUFZGoYEZU00koYEZU0_l0000;odFjA@03o`000?lKi1_o6n@K00;o6n@K0_l0000;occ3
?003o`000?m</dcoC;=<00goC;=<00?o0000oiEZUOnEJYD02?nEJYD00ol0003o^TFjokY5^P06okY5
^P03o`000?oT6nCoi1_T00Ooi1_T00Go0000ooD:mOoe2_Gom@[eo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003oi1_Ton@Ki00:on@Ki003o`000?nUFZGoYEZU00goYEZU0_l0000<odFjA@04o`000?lKi1_o0000
o`0000go?<<l00?o0000odbcC?m</d`03?m</d`00ol0003oUFZEoiEZU@09oiEZU@03o`000?njAK[o
^TFj00Ko^TFj00?o0000on@Ki?oT6n@01_oT6n@00ol0003om@[eooD:m@03ooD:m@03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003oi1_Ton@Ki00:on@Ki003o`000?nUFZGoYEZU00coYEZU00Co0000ohIi
Q_n6NHKo00003?m5^TD00ol0003o?<<locc3?00>occ3?003o`000?m</dcoC;=<00SoC;=<1?l0000;
oiEZU@03o`000?njAK[o^TFj00Ko^TFj00?o0000on@Ki?oT6n@01OoT6n@00ol0003om@[eooD:m@04
ooD:m@03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oi1_Ton@Ki00;on@Ki003o`000?nUFZGoYEZU
00_oYEZU00?o0000ohIiQ_n6NHH00_n6NHH00ol0003oAKY5odFjA@09odFjA@03o`000?ll`cco?<<l
00ko?<<l00Co0000odbcC?m</dcoC;=<1ol00003ofFJI@03o`000?nEJYGoUFZE00WoUFZE00?o0000
okY5^_njAKX01_njAKX00ol0003oi1_Ton@Ki004on@Ki003o`000?oe2_Gom@[e00Kom@[e00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oT6nCoi1_T00coi1_T00?o0000ojEJYOnUFZD02_nUFZD00ol0
003oQWV6ohIiQP03ohIiQP03o`000?m5^TGoAKY500SoAKY500?o0000occ3??ll`c`03_ll`c`4o`00
00_oIIYU00?o0000oiEZUOnEJYD02?nEJYD00ol0003o^TFjokY5^P05okY5^P03o`000?oT6nCoi1_T
00Goi1_T00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on@Ki?oT
6n@03?oT6n@7o`0000GoYEZU00?o0000ohIiQ_n6NHH01On6NHH00ol0003oAKY5odFjA@07odFjA@03
o`000?ll`cco?<<l00ko?<<l00?o0000ofFJIOmUVVD03OmUVVD00ol0003oUFZEoiEZU@08oiEZU@03
o`000?njAK[o^TFj00Co^TFj00?o0000on@Ki?oT6n@01?oT6n@00ol0003om@[eooD:m@07ooD:m@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003oi1_Ton@Ki00=on@Ki003o`000?o4>lCoa3_400Coa3_4
1Ol00009ohIiQP03o`000?m5^TGoAKY500KoAKY500?o0000occ3??ll`c`03_ll`c`00ol0003oIIYU
ofFJI@0=ofFJI@03o`000?nEJYGoUFZE00SoUFZE00Co0000okY5^_njAK[o^TFj1Ol00004on@Ki003
o`000?oe2_Gom@[e00Wom@[e1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=on@Ki003o`000?o4>lCoa3_400Woa3_4
0_l00009ohIiQP03o`000?m5^TGoAKY500KoAKY500?o0000occ3??ll`c`03?ll`c`00ol0003oIIYU
ofFJI@0?ofFJI@Ko00001?nEJYD4o`0000Gogb3O0_l000000ooT6nCo0000ooD:m@0;ooD:m@04o`00
0?om0_goo@;mood2o@Oo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?o`3o3ol0o`oo0?l0?o00002_oT6n@00ol0003o
a3_4ol@ka009ol@ka003o`000?nJII[o000000;o00001on6NHH00ol0003oAKY5odFjA@05odFjA@03
o`000?ll`cco?<<l00So?<<l1Ol0000AofFJI@03o`000?nUFZGoYEZU00?oYEZU1?l0000;omlPg`03
o`000?oe2_Gom@[e00[om@[e00?o0000ood2oOom0_d02Oom0_d3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000oo0?l?o`3o001Oo`3o02o`0000Ooi1_T
00?o0000ol@ka?o4>l@02_o4>l@00ol0003oVVFJoiYUVP02oiYUVP?o00001On6NHH00ol0003oAKY5
odFjA@04odFjA@04o`000?ll`cco?<<locc3?0Oo00001?mC[5<00ol0003oIIYUofFJI@0>ofFJI@03
o`000?nUFZGoYEZU00OoYEZU00?o0000omlPgooO8=l02OoO8=l00ol0003om@[eooD:m@09ooD:m@03
o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ol0o`oo0?l008oo0?l0;o00001?oT6n@00ol0003oa3_4
ol@ka00;ol@ka003o`000?nJII[oVVFJ00GoVVFJ0ol00003ohIiQP04o`000?m5^TGoAKY5odFjA@Ko
00003?mC[5<00ol0003oIIYUofFJI@0=ofFJI@03o`000?nUFZGoYEZU00OoYEZU00?o0000omlPgooO
8=l02_oO8=l00ol0003om@[eooD:m@08ooD:m@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo0?l0?o000000?oi1_To`000?o4>l@0
3?o4>l@00ol0003oVVFJoiYUVP08oiYUVP?o000000CoQWV6o`000?l0003o00000_nHIiP00ol0003o
DjaCoe>/D`0=oe>/D`03o`000?mUVVGoIIYU00coIIYU00?o0000ojEJYOnUFZD02?nUFZD00ol0003o
gb3OomlPg`0;omlPg`03o`000?oe2_Gom@[e00Kom@[e00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
l0o`00?o0000ol@ka?o4>l@03?o4>l@00ol0003oVVFJoiYUVP0;oiYUVP03o`000?nHIiSoV6NH00?o
V6NH00?o0000oe>/DomC[5<03?mC[5<00ol0003oFJIIo`00000=ofFJI@03o`000?nUFZGoYEZU00So
YEZU00?o0000omlPgooO8=l03?oO8=l3o`0000Gom@[e00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o`3o3ol0o`00col0o`00?o0000ol@ka?o4>l@03?o4>l@00ol0003oVVFJoiYUVP0:oiYUVP03o`00
0?nHIiSoV6NH00GoV6NH00?o0000oe>/DomC[5<02_mC[5<01?l0003oFJIIoeVVFOmIYUT2o`0000[o
IIYU00?o0000ojEJYOnUFZD02OnUFZD00ol0003ogb3OomlPg`0<omlPg`03o`000?of2OKomPWf00?o
000000?om@[eo`000?om0_d03oom0_d00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000ol@ka?o4>l@0
3?o4>l@00ol0003oVVFJoiYUVP09oiYUVP03o`000?nHIiSoV6NH00KoV6NH00?o0000oe>/DomC[5<0
2OmC[5<00ol0003oFJIIoeVVF@02oeVVF@03o`000?nIIYWo000000;o00001omUVVD00ol0003oYEZU
ojEJY@09ojEJY@03o`000?oO8=oogb3O00_ogb3O00?o0000ooH9m_of2OH01?of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002oo`3o000ol0003oa3_4ol@ka00;ol@ka003o`000?nJ
II[oVVFJ00SoVVFJ00?o0000oiQWV?nHIiP01onHIiP00ol0003oDjaCoe>/D`08oe>/D`03o`000?mI
YUWoFJII00?oFJII00?o0000oiUVVOnIIYT00_nIIYT2o`0000CoIIYU00?o0000ojEJYOnUFZD02_nU
FZD00ol0003ogb3OomlPg`0:omlPg`03o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?o`3o3ol0o`00[ol0o`0ol0000;ol@ka0Ko00001?nJIIX00ol0003oV6NHoiQWV008
oiQWV003o`000?mC[5?oDjaC00OoDjaC00?o0000oeVVFOmIYUT00omIYUT00ol0003oVFJIoiUVV@05
oiUVV@?o000000?oIIYUo`000?nUFZD02onUFZD00ol0003ogb3OomlPg`09omlPg`03o`000?of2OKo
mPWf00OomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?o`3o3ol0o`00Wol0o`00?o0000on0O
h?oP7n001?l00006ol@ka003o`000?o3?<?o`cc300Co`cc31?l0000<oiQWV003o`000?mC[5?oDjaC
00GoDjaC00?o0000oeVVFOmIYUT01?mIYUT00ol0003oVFJIoiUVV@08oiUVV@03o`000?nUFZGoYEZU
00_oYEZU00?o0000omlPgooO8=l02?oO8=l00ol0003omPWfooH9mP08ooH9mPGo00002_om0_d00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?o`3o3ol0o`00Ool0o`00?o0000on0Oh?oP7n001OoP7n03o`0000;oa3_400?o0000ol<l`oo3
?<<02?o3?<<00ol0003oV6NHoiQWV00:oiQWV003o`000?mC[5?oDjaC00CoDjaC00?o0000oeVVFOmI
YUT01OmIYUT00ol0003oVFJIoiUVV@08oiUVV@03o`000?nUFZGoYEZU00WoYEZU1?l00008omlPg`03
o`000?of2OKomPWf00WomPWf00?o0000ood2oOom0_d00_om0_d7o`0000?oo@;m00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`
oo0?l005oo0?l003o`000?oP7n3oh1oP00Woh1oP0_l0000<ol<l``03o`000?nHIiSoV6NH00WoV6NH
00?o0000oe>/DomC[5<00omC[5<00ol0003oFJIIoeVVF@05oeVVF@03o`000?nIIYWoVFJI00[oVFJI
00?o0000ojEJYOnUFZD01?nUFZD4o`0000CoebSG00?o0000omlPgooO8=l01?oO8=l00ol0003omPWf
ooH9mP0:ooH9mP03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?o`3o3ol0o`00?ol0o`00?o0000on0Oh?oP7n002ooP
7n000ol0003o`cc3ol<l``0:ol<l``03o`000?nHIiSoV6NH00WoV6NH00?o0000oe>/DomC[5<00_mC
[5<00ol0003oFJIIoeVVF@06oeVVF@03o`000?nIIYWoVFJI00[oVFJI00?o0000ojEJYOnUFZD01?l0
0009omLXe`Ko00003?of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo0?l?o`3o3ol0o`0_l0
000=on0Oh003o`000?o3?<?o`cc300[o`cc300?o0000oiQWV?nHIiP02OnHIiP01Ol0003oDjaCoe>/
DomC[5?o000000WoFJII00?o0000oiUVVOnIIYT02onIIYT2o`0000goebSG00?o0000oo@;m?od2o@0
0_od2o@00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol0o`o`00
0002ooP7n0;o00002ooP7n000ol0003o`cc3ol<l``0;ol<l``03o`000?nHIiSoV6NH00WoV6NH00?o
0000oe>/Dol000002OmIYUT00ol0003oVFJIoiUVV@0<oiUVV@03o`000?oG:=OoebSG00coebSG00?o
0000oo@;m?od2o@00ood2o@00ol0003omPWfooH9mP09ooH9mP03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on0OhooP7n003ooP7n0;o00002_oP7n000ol0003o`cc3ol<l``0:ol<l``03o`000?nHIiSo
V6NH00SoV6NH1Ol00008oeVVF@03o`000?nIIYWoVFJI00coVFJI00?o0000omLXeooG:=L02ooG:=L0
0ol0003om0_doo@;m005oo@;m003o`000?of2OKomPWf00SomPWf00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooh1oP2o`0000Soh1oP00?o0000ol<l`oo3?<<02_o3?<<00ol0003oV6NHoiQWV007oiQW
V003o`000?nIIYWoVFJI00?oVFJI0ol00005oeVVF@03o`000?nIIYWoVFJI00_oVFJI00?o0000omLX
eooG:=L03?oG:=L00ol0003om0_doo@;m006oo@;m003o`000?of2OKomPWf00OomPWf00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Won0Oh00?o0000on0Oh?oP7n001OoP7n02o`0000co
`cc300?o0000oiQWV?nHIiP01OnHIiP00ol0003oVFJIoiUVV@07oiUVV@?o000000?oFJIIo`000?nI
IYT03OnIIYT00ol0003oebSGomLXe`0<omLXe`03o`000?od2oCom0_d00Kom0_d00?o0000ooH9m_of
2OH01_of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?oh1oSon0Oh00Oon0Oh
0_l00004on0Oh003o`000?oX5nSoj1OX00;o00002_o3?<<00ol0003oV6NHoiQWV003oiQWV0;o0000
3OnIIYT2o`0000goVFJI0ol0000=omLXe`03o`000?od2oCom0_d00Oom0_d00?o0000ooH9m_of2OH0
1Oof2OH00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Son0Oh0_l0
00000ooP7n3o0000onPGj004onPGj003o`000?o3?<?o`cc300Oo`cc300Co0000oiQWV?nHIiSoV6NH
0_l00002olHiaP03o`000?nIIYWoVFJI00coVFJI3Ol00003omDZe@03o`000?oG:=OoebSG00[oebSG
00?o0000oo@;m?od2o@02?od2o@01?l0003omPWfooH9m_of2OH4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003on0Oh
ooP7n009ooP7n003o`000?oX5nSoj1OX00Goj1OX0_l00008ol<l``03o`000?nHIiSo000000GoaSW6
00?o0000oiUVVOnIIYT02onIIYT00ol0003oYeRWojMHY`09ojMHY`03o`000?oE:]GoeB[E00;oeB[E
0_l00009omLXe`03o`000?od2oCom0_d00[om0_d0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?oh1oSon0Oh00Son0Oh00?o0000onPGj?oX5nP01ooX5nP4o`0000?o`cc30ol0
0007olHiaP03o`000?nIIYWoVFJI00[oVFJI00?o0000ojMHYonWF:L02OnWF:L00ol0003oeB[EomDZ
e@04omDZe@;o00001ooG:=L00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oh1oSon0Oh00Oon0Oh00?o0000onPGj?oX5nP02?oX5nP0
1?l0003oiaSWonLHiooW6>L3o`0000;ofbCK00?o0000olHia_o6>LH01_o6>LH00ol0003oVFJIoiUV
V@08oiUVV@03o`000?nWF:OoYeRW00[oYeRW00?o0000omDZeOoE:]D01_oE:]D00ol0003oebSGomLX
e`04omLXe`03o`000?od2oCom0_d00Wom0_d00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oj1OXonPGj008onPGj003o`000?oW6>Oo
iaSW00CoiaSW00Go0000om/TfooK9=_ofbCKo`000008olHiaP03o`000?nIIYWoVFJI00OoVFJI00?o
0000ojMHYonWF:L02_nWF:L00ol0003oeB[EomDZe@07omDZe@;o00001?oG:=L00ol0003om0_doo@;
m008oo@;m003o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7n?oh1oP00ooh1oP0
0ol0003oj1OXonPGj008onPGj003o`000?oW6>OoiaSW00CoiaSW00?o0000om/TfooK9=/00_oK9=/0
0ol0003oaSW6olHiaP07olHiaP03o`000?nIIYWoVFJI00KoVFJI00?o0000ojMHYonWF:L02_nWF:L0
0ol0003oeB[EomDZe@09omDZe@05o`000?oG:=OoebSGomLXeol000002Ood2o@00ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_oj1OX00?o0000onLHiooW6>L01?oW6>L00ol0003ofbCKom/Tf`03
om/Tf`03o`000?o6>LKoaSW600OoaSW600?o0000oiUVVOnIIYT01OnIIYT00ol0003oYeRWojMHY`0:
ojMHY`03o`000?oE:]GoeB[E00WoeB[E1?l00009oo@;m003o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oh1oSon0Oh
ooP7n?l000002_oX5nP00ol0003oiaSWonLHi`05onLHi`03o`000?oK9=_ofbCK00?ofbCK00?o0000
olHia_o6>LH02?o6>LH00ol0003oVFJIoiUVV@04oiUVV@03o`000?nWF:OoYeRW00WoYeRW00?o0000
omDZeOoE:]D02?oE:]D2o`0000?om0_d00?o0000oo@;m?od2o@01_od2o@00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooP7n?oh1oP00ooh1oP00ol0003oj1OXonPGj006onPGj003o`000?oW6>OoiaSW
00GoiaSW00?o0000om/TfooK9=/01?oK9=/00ol0003oaSW6olHiaP09olHiaP03o`000?nIIYWoVFJI
00;oVFJI00?o0000ojMHYonWF:L02_nWF:L00ol0003oeB[EomDZe@06omDZe@;o00001_od2o@8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003on0OhooP7n005ooP7n003o`000?oX5nSoj1OX00Goj1OX00?o0000onLHiooW
6>L01OoW6>L00ol0003ofbCKom/Tf`05om/Tf`03o`000?o6>LKoaSW600WoaSW600Go0000oiUVVOnI
IYWoVFJIo`00000<ojMHY`03o`000?oE:]GoeB[E00CoeB[E0_l00008oo@;m003o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oh1oSon0Oh00Oon0Oh00?o0000onPGj?oX
5nP00ooX5nP00ol0003oiaSWonLHi`06onLHi`03o`000?oK9=_ofbCK00GofbCK00?o0000olHia_o6
>LH02_o6>LH00ol0003oVFJIo`000004o`0000WoYeRW00?o0000omDZeOoE:]D00_oE:]D2o`0000[o
m0_d00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003on0OhooP7n007ooP7n003o`00
0?oX5nSoj1OX00;oj1OX00?o0000onLHiooW6>L01_oW6>L00ol0003ofbCKom/Tf`07om/Tf`;o0000
2oo6>LH00ol0003ogaoOomlOg`03omlOg`Oo00000_nWF:L00ol0003oeB[EomDZe@02o`0000_om0_d
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooP7n?oh1oP02Ooh
1oP01Ol0003oj1OXonPGj?oX5nSo000000SoiaSW00?o0000om/TfooK9=/01ooK9=/00ol0003okQ7^
o`000002o`0000SoaSW600?o0000omlOgooO7ml02_oO7ml5o`0000gom0_d00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooP7n003o`000?oX5nSo000000WoiaSW00?o
0000om/TfooK9=/01_oK9=/00ol0003okQ7^onhAkP03onhAkP?o00001?o6>LH00ol0003ogaoOomlO
g`0=omlOg`03o`000?od2oCom0_d00gom0_d00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_on0Oh00?o0000onLHiooW6>L01ooW6>L00ol0003ofbCKom/Tf`07
om/Tf`03o`000?o^4NkokQ7^00KokQ7^0ol000000oo6>LKo0000omlOg`0>omlOg`03o`000?od2oCo
m0_d00com0_d00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooP7
n003o`000?oW6>OoiaSW00;oiaSW1_l00008om/Tf`03o`000?o^4NkokQ7^00[okQ7^00?o0000omlO
gooO7ml03ooO7ml00ol0003om0_doo@;m00:oo@;m0;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooP7n0Go00001_od2o@00ol0003ofbCKom/Tf`05om/Tf`03o`000?o^4NkokQ7^00[o
kQ7^00?o0000omlOgooO7ml03ooO7ml00ol0003om0_doo@;m007oo@;m0?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooP7n003o`000?od2oCom0_d00Wom0_d00?o0000om/TfooK
9=/00ooK9=/00ol0003okQ7^onhAkP0;onhAkP03o`000?oO7moogaoO00oogaoO00?o0000oo@;m?od
2o@01Ood2o@2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on0Oho`000?l00000
3Ood2o@00ol0003ofbCKom/Tf`02om/Tf`03o`000?o^4NkokQ7^00_okQ7^5?l00004oo@;m0;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>oo@;m004o`000?oK9=_ofbCKo`0000kokQ7^
00?o0000ooL8moog2?L04?og2?L00ol0003om0_do`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_od2o@00ol0003ofbCKo`00000>onhAkP03o`00
0?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003om0_doo@;m00=oo@;m003o`000?o^4NkokQ7^00WokQ7^1Ol0
000BooL8m`;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003om0_doo@;m00<oo@;m003o`000?o^4NkokQ7^00;okQ7^1ol00004ood2o@03o`000?og2?Oo
m`Sg00oom`Sg00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?od2oCom0_d00com0_d1?l0000<ood2o@03o`000?og2?Oom`Sg00com`Sg0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000oo@;m?od2o@03?od2o@00ol0003oo@;mood2o@0=ood2o@03o`000?og2?Oom`Sg00_o
m`Sg00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L02Oog2?L2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@02_od2o@00ol0003oo@;m
ood2o@0?ood2o@03o`000?og2?Oom`Sg00Kom`Sg0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_og2?L00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000oog2?L2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooL8mol000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool01_l00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`04o`00o`?oool00ol0
0?l2oooo00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00[o003o0_ooo`05o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`09o`00o`03oooo0?l00?oo003o
00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000go003o0_ooo`0:o`00o`;oool01?l00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool02_l00?l2oooo00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo0?l00?oo003oo`00o`;oool0
0_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co003o0_ooo`0=o`00o`;oool0
2_l00?l2oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o0oooo`09o`00o`?oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02ol00?l3oooo00Wo003o0oooo`04o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000So003o1Oooo`07o`00o`Goool01Ol00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02_l00?l2
oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00
o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00_o003o0_ooo`0:o`00
o`;oool01Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo00Go
003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0<o`00o`;oool02_l00?l2oooo00Co
003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool0
0ol00?l00oooo`3o003oo`00o`04o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0
Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_oo
o`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`05o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol0
0?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`03
o`00o`;oool00ol00?l2oooo00Go003o0_ooo`03o`00o`;oool01ol00?l2oooo00;o003o0_ooo`05
o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
023o003o1?ooo`08o`00o`Coool02Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(340) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.993 .007 .993 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.993 .007 .993 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.993 .007 .993 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.992 .008 .992 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.967 .033 .967 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.991 .009 .991 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.967 .033 .967 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.96 .04 .96 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.941 .059 .941 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.986 .014 .986 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.931 .069 .931 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.992 .008 .992 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.863 .137 .863 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.878 .122 .878 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.784 .216 .784 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.913 .087 .913 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.985 .015 .985 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.988 .012 .988 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.964 .036 .964 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.612 .388 .612 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.92 .08 .92 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.812 .188 .812 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.804 .196 .804 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.847 .153 .847 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.912 .088 .912 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.944 .056 .944 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.782 .218 .782 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.897 .103 .897 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.678 .322 .678 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.936 .064 .936 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.896 .104 .896 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.831 .169 .831 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.89 .11 .89 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.7 .3 .7 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.925 .075 .925 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.808 .192 .808 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.995 .005 .995 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.944 .056 .944 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.729 .271 .729 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.386 .614 .386 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.458 .542 .458 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.972 .028 .972 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.973 .027 .973 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.884 .116 .884 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.993 .007 .993 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.76 .24 .76 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.763 .237 .763 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.463 .537 .463 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.464 .536 .464 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.315 .685 .315 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.734 .266 .734 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.776 .224 .776 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.993 .007 .993 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.751 .249 .751 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.655 .345 .655 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.957 .043 .957 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.501 .499 .501 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.913 .087 .913 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.855 .145 .855 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.463 .537 .463 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.332 .668 .332 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.636 .364 .636 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.077 .923 .077 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.1 .9 .1 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.237 .763 .237 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.469 .531 .469 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.468 .532 .468 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.908 .092 .908 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.187 .813 .187 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.207 .793 .207 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.774 .226 .774 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.959 .041 .959 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.991 .009 .991 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.254 .746 .254 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.315 .685 .315 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.621 .379 .621 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.991 .009 .991 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.718 .282 .718 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.333 .667 .333 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.547 .453 .547 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.083 .917 .083 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.485 .515 .485 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.282 .718 .282 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.962 .038 .962 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.098 .902 .098 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.048 .952 .048 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.864 .136 .864 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.049 .951 .049 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.022 .978 .022 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.607 .393 .607 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.915 .085 .915 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.232 .768 .232 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.046 .954 .046 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.466 .534 .466 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.101 .899 .101 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.183 .817 .183 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.934 .066 .934 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.019 .981 .019 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.13 .87 .13 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.114 .886 .114 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.785 .215 .785 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.236 .764 .236 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.307 .693 .307 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.056 .944 .056 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.075 .925 .075 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.128 .872 .128 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.032 .968 .032 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.006 .994 .006 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.337 .663 .337 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.612 .388 .612 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.991 .009 .991 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.8 .2 .8 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.181 .819 .181 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.226 .774 .226 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.366 .634 .366 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.964 .036 .964 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.09 .91 .09 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.182 .818 .182 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.635 .365 .635 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.043 .957 .043 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.992 .008 .992 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.055 .945 .055 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.881 .119 .881 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.966 .034 .966 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.612 .388 .612 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.669 .331 .669 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.11 .89 .11 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.903 .097 .903 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.014 .986 .014 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.303 .697 .303 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.489 .511 .489 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.079 .921 .079 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.247 .753 .247 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.405 .595 .405 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.991 .009 .991 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.991 .009 .991 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.939 .061 .939 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.178 .822 .178 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.156 .844 .156 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.036 .964 .036 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.842 .158 .842 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.203 .797 .203 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.958 .042 .958 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.208 .792 .208 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.222 .778 .222 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.232 .768 .232 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.659 .341 .659 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.763 .237 .763 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.596 .404 .596 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.031 .969 .031 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.166 .834 .166 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.287 .713 .287 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.572 .428 .572 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.848 .152 .848 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.992 .008 .992 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.951 .049 .951 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.204 .796 .204 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.365 .635 .365 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.2 .8 .2 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.842 .158 .842 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.739 .261 .739 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.991 .009 .991 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.588 .412 .588 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.878 .122 .878 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.956 .044 .956 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.148 .852 .148 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.264 .736 .264 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.943 .057 .943 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.174 .826 .174 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.67 .33 .67 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.558 .442 .558 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.494 .506 .494 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.385 .615 .385 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.901 .099 .901 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.858 .142 .858 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.867 .133 .867 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.899 .101 .899 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.406 .594 .406 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.966 .034 .966 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.816 .184 .816 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.382 .618 .382 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.422 .578 .422 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.992 .008 .992 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.69 .31 .69 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.538 .462 .538 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.991 .009 .991 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.96 .04 .96 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.855 .145 .855 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.956 .044 .956 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.419 .581 .419 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.934 .066 .934 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.797 .203 .797 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.719 .281 .719 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.992 .008 .992 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.692 .308 .692 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.573 .427 .573 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.993 .007 .993 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.756 .244 .756 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.987 .013 .987 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.994 .006 .994 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.594 .406 .594 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.989 .011 .989 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.647 .353 .647 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.991 .009 .991 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.778 .222 .778 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.885 .115 .885 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.809 .191 .809 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.912 .088 .912 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.932 .068 .932 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.821 .179 .821 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.681 .319 .681 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.807 .193 .807 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.89 .11 .89 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.932 .068 .932 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.908 .092 .908 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.919 .081 .919 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.988 .012 .988 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.835 .165 .835 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.958 .042 .958 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.99 .01 .99 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.967 .033 .967 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.948 .052 .948 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.845 .155 .845 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.96 .04 .96 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.933 .067 .933 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.911 .089 .911 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.947 .053 .947 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.992 .008 .992 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.99 .01 .99 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.991 .009 .991 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.99 .01 .99 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.992 .008 .992 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003ol`ccoo<<lol0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo<<looc3?<00_oc3?<00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`06oo<<l`03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?of2OKo0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000col`cc00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooH9mP03o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l005oo0?l003o`000?oc
3??ol`cc00_ol`cc0ol00003oo4>l@03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooH9m_of2OH00oof2OH00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003ol0o`oo0?l006
oo0?l003o`000?oc3??ol`cc00[ol`cc00?o0000oo4>lOoa3_401?oa3_400ol0003oo@;mood2o@0:
ood2o@04o`000?o_4>ooka3_onl@k`;o00002_om0_d2o`000003onhAk_l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003omPWfooH9mP05ooH9mP03o`000?om0_go
o@;m00Woo@;m00?o0000ooH9m_l000002oom0_d00ol0003ol0o`oo0?l006oo0?l003o`000?oc3??o
l`cc00Wol`cc00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@08ood2o@03o`000?o_4>oo
ka3_00Coka3_0_l00005ood2o@?o00001?o^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooH9mP03o`000?om0_goo@;m00Ooo@;m0_l00003ooH9
mP03o`000?om0_goo@;m00Ooo@;m00?o0000oo0?l?o`3o001oo`3o000ol0003ol`ccoo<<l`09oo<<
l`03o`000?oa3_7ol@ka00Ool@ka00?o0000ood2oOom0_d01Oom0_d2o`0000Woka3_0_l000000oom
0_go0000o`000007onhAkP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooH9m_of
2OH02?of2OH00ol0003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00?omPWf00?o0000ood2oOom
0_d01oom0_d00ol0003ol0o`oo0?l008oo0?l003o`000?oc3??ol`cc00Ool`cc00?o0000oo4>lOoa
3_402Ooa3_400ol0003oo@;mood2o@03ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000onhAk_o^
4Nh01oo^4Nh00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003om0_do`000005ood2o@;o00002oof2OH2o`0000Koo@;m
00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Sol0o`
00?o0000oo<<looc3?<01_oc3?<00ol0003ol@kaoo4>l@0;oo4>l@05o`000?om0_goo@;mood2oOl0
00003_o_4>l00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?od2oCom0_doo@;m?l0
00000oom0_d00ol0003omPWfooH9mP0:ooH9mP04o`000?oZ5N[ojQGZo`0000?oo@;m0_l00008ooH9
mP03o`000?om0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003ol`ccoo<<l`05oo<<
l`03o`000?oa3_7ol@ka00col@ka00?o0000ood2oOl000003oo_4>l00ol0003okQ7^onhAkP08onhA
kP03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om0_doo@;m003oo@;m003o`000?om0_go000000_o
mPWf0_l00004onXEjP03o`000?om0_go000000_omPWf00?o0000ood2oOom0_d01Oom0_d00ol0003o
l0o`oo0?l009oo0?l003o`000?oc3??ol`cc00Col`cc00?o0000oo4>lOoa3_403_oa3_400ol0003o
ka3_onl@k`0>onl@k`03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000oo@;m?od2o@0
1?od2o@00ol0003omPWfooH9mP09ooH9mP03o`000?oZ5N[ojQGZ00GojQGZ00?o0000ooH9m_of2OH0
2_of2OH00ol0003oo@;mood2o@05ood2o@03o`000?o`3o3ol0o`00[ol0o`00?o0000oo<<looc3?<0
0ooc3?<00ol0003ol@kaoo4>l@0>oo4>l@03o`000?o_4>ooka3_00goka3_00?o0000onhAk_o^4Nh0
2_o^4Nh00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003om0_doo@;
m005oo@;m003o`000?of2OKomPWf00OomPWf0_l00008onXEjP03o`000?of2OKomPWf00_omPWf00?o
0000ood2oOom0_d01?om0_d00ol0003ol0o`oo0?l00:oo0?l004o`000?oc3??ol`ccoo<<l`?o0000
3ooa3_400ol0003oka3_onl@k`0>onl@k`03o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?od2oCom0_d00Oom0_d00?o0000ooH9m_of2OH01?of2OH2o`0000_ojQGZ1?l0
0009ooH9mP03o`000?om0_goo@;m00?oo@;m00?o0000oo0?l?o`3o002oo`3o001?l0003ol`cco`00
0?l00003omLXe`;o00003?oa3_42o`00013oka3_00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_d
oo@;m007oo@;m003o`000?of2OKomPWf00?omPWf00?o0000onXEj_oZ5NX02ooZ5NX01?l0003oc3?<
ol`cc?o<<l`5o`0000GomPWf00?o0000ood2oOom0_d00_om0_d00ol0003ol0o`oo0?l00<oo0?l003
o`000?oG:=OoebSG00GoebSG0_l00008oo4>l@;o00000_o@;m000ol0003oka3_onl@k`0=onl@k`03
o`000?o^4NkokQ7^00_okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003om0_doo@;m009oo@;m003o`000?of2OKomPWf00;o0000
3OoZ5NX00ol0003oc3?<ol`cc007ol`cc0Ko00000_om0_d4o`0000gol0o`00?o0000omLXeooG:=L0
1ooG:=L2o`0000Gol@ka00?o0000om0_d?o@;m000oo@;m000ol0003oka3_onl@k`0<onl@k`03o`00
0?o^4NkokQ7^00cokQ7^00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?od2oCom0_d00Wom0_d00?o
0000ooH9m_l000003ooZ5NX00ol0003oc3?<ol`cc00<ol`cc0?o00001?oW6>L3o`0000Wol0o`00?o
0000omLXeooG:=L02_oG:=L2o`000003oo4>lOl0003o000000Ood2o@00?o0000onl@koo_4>l02oo_
4>l00ol0003okQ7^onhAkP0<onhAkP03o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000
onXEj_oZ5NX03_oZ5NX00ol0003oc3?<ol`cc00=ol`cc003o`000?oW6>OoiaSW00KoiaSW0ol00005
oo0?l003o`000?oG:=OoebSG00goebSG00?o0000om0_d?o@;m002?o@;m000ol0003oka3_onl@k`09
onl@k`03o`000?o^4NkokQ7^00gokQ7^00Co0000ood2oOom0_goo@;m1Ol00003oo8=lP03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
oo@;m?od2o@02ood2o@2o`0000oojQGZ00?o0000ol`cc?o<<l`03Oo<<l`00ol0003oiaSWonLHi`0:
onLHi`?o000000?ol0o`o`000?oG:=L03ooG:=L00ol0003od2o@om0_d009om0_d003o`000?o_4>oo
ka3_00Soka3_00?o0000onhAk_o^4Nh03_o^4Nh3o`0000SolPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?od2oCom0_d00Som0_d0ol000000ooJ
9M[o0000onXEjP0>onXEjP03o`000?o<<lcoc3?<00goc3?<00?o0000onLHiooW6>L03OoW6>L00ol0
003oebSGomLXe`0?omLXe`03o`000?o@;m3od2o@00[od2o@2ol0000;onhAkPGo00003?ob3O800ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003ol@kao`000?on0Oko0000
00Som0_d0ol00005omXUfP03o`000?oZ5N[ojQGZ00cojQGZ00?o0000ol`cc?o<<l`03Oo<<l`00ol0
003oiaSWonLHi`0=onLHi`;o00004?oG:=L00ol0003od2o@om0_d00:om0_d003o`000?o<<lcoc3?<
00Ooc3?<00?o0000onhAk_o^4Nh00_o^4Nh7o`0000CodRgB00?o0000oo8=l_ob3O802_ob3O800ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003ol@kaoo4>lOoa3_42o`00
00Gom0_d0ol00009omXUfP;o00002ooZ5NX00ol0003oc3?<ol`cc00=ol`cc003o`000?oW6>OoiaSW
00goiaSW00Co0000ol<l`oo3?<?o00003ooG:=L00ol0003od2o@om0_d009om0_d003o`000?o<<lco
c3?<00Woc3?<1?l0000;om8]dP03o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo4>lOoa3_401?oa3_400ol0003om0_do`000002o`00
00cofRGJ00Co0000okM8]ol0003o00002OoZ5NX00ol0003oc3?<ol`cc00=ol`cc003o`000?oW6>Oo
iaSW00goiaSW00Go0000ol<l`oo3?<?o`cc3o`00000=omLXe`03o`000?o@;m3od2o@00[od2o@00?o
0000ol`cc?o<<l`02Oo<<l`00ol0003odRgBom8]dP0<om8]dP03o`000?ob3O;olPgb00[olPgb00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo4>lOoa3_401_oa3_40
0ol0003ofRGJomXUfP0<omXUfP03o`000?ngB;Oo]dRg00;o]dRg0_l00007onXEjP03o`000?o<<lco
c3?<00coc3?<00?o0000onLHiooW6>L03OoW6>L00ol0003o`cc3ol<l``03ol<l``03o`000?oG:=Oo
ebSG00[oebSG00?o0000om0_d?o@;m002_o@;m000ol0003oc3?<ol`cc009ol`cc003o`000?oB;M;o
dRgB00codRgB00?o0000oo8=l_ob3O802oob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003ol@kaoo4>l@06oo4>l@03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000okM8
]ongB;L01OngB;L00ol0003ojQGZonXEjP03onXEjP03o`000?o<<lcoc3?<00goc3?<00?o0000onLH
iooW6>L03OoW6>L00ol0003o`cc3ol<l``04ol<l``03o`000?oG:=OoebSG00WoebSG00?o0000om0_
d?o@;m002Oo@;m000ol0003oc3?<ol`cc00:ol`cc003o`000?oB;M;odRgB00codRgB00?o0000oo8=
l_ob3O802oob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l@kaoo4>l@07oo4>l@03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000okM8]ongB;L01_ngB;L2o`0000?o
jQGZ00?o0000ol`cc?o<<l`03Oo<<l`00ol0003oiaSWonLHi`0<onLHi`03o`000?o3?<?o`cc300Ko
`cc300?o0000omLXeooG:=L02?oG:=L00ol0003od2o@om0_d009om0_d003o`000?o<<lcoc3?<00[o
c3?<00?o0000om8]d_oB;M803?oB;M800ol0003olPgboo8=lP0;oo8=lP03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo4>lOoa3_402?oa3_400ol0003ofRGJomXUfP0:omXUfP03o`00
0?ngB;Oo]dRg00Wo]dRg0_l000000ooZ5N[o0000ol`cc00<ol`cc0?o00003_oW6>L00ol0003o`cc3
ol<l``07ol<l``03o`000?oG:=OoebSG00OoebSG00?o0000om0_d?o@;m002Oo@;m000ol0003oc3?<
ol`cc00;ol`cc003o`000?oB;M;odRgB00codRgB00?o0000oo8=l_ob3O802_ob3O800ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo4>lOoa3_402_oa3_400ol0003ofRGJomXU
fP09omXUfP03o`000?ngB;Oo]dRg00_o]dRg00?o0000ol`cc?o<<l`02_o<<l`2o`0000?oXUfR00?o
0000onLHiooW6>L02_oW6>L00ol0003o`cc3ol<l``09ol<l``03o`000?oG:=OoebSG00KoebSG00?o
0000om0_d?o@;m002?o@;m000ol0003oc3?<ol`cc00<ol`cc003o`000?oB;M;odRgB00codRgB00?o
0000oo8=l_ob3O802_ob3O800ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oa3_7ol@ka00_ol@ka00?o0000omXUf_oJ9MX02?oJ9MX0
0ol0003o]dRgokM8]`0<okM8]`03o`000?o<<lcoc3?<00Soc3?<0_l00006oj9MXP;o00002_oW6>L0
0ol0003o`cc3ol<l``0:ol<l``03o`000?oG:=OoebSG00GoebSG00?o0000om0_d?o@;m002?o@;m00
0ol0003oc3?<ol`cc00<ol`cc003o`000?oB;M;odRgB00codRgB00?o0000oo8=l_ob3O802oob3O80
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo4>l@03o`000?oJ9M[ofRGJ00OofRGJ00?o0000okM8]ongB;L03_ngB;L00ol0003oc3?<ol`cc004
ol`cc0?o00002_nRGJ800ol0003oiaSWonLHi`07onLHi`03o`000?o3?<?o`cc300_o`cc300?o0000
omLXeooG:=L00ooG:=L00ol0003od2o@om0_d009om0_d003o`000?o<<lcoc3?<00coc3?<00?o0000
om8]d_oB;M803?oB;M800ol0003olPgboo8=lP0;oo8=lP;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_on0Oh00ol0
003ol@kaoo4>l@0<oo4>l@03o`000?oJ9M[ofRGJ00OofRGJ00?o0000okM8]ongB;L03ongB;L01?l0
003oc3?<ol`cc?o<<l`2o`0000koXUfR0_l00006onLHi`03o`000?o3?<?o`cc300go`cc300?o0000
omLXeooG:=L00_oG:=L00ol0003od2o@om0_d008om0_d003o`000?o<<lcoc3?<00coc3?<0ol0000=
om8]dP03o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?on0Oko0000
00ool@ka00?o0000omXUf_oJ9MX01_oJ9MX00ol0003o]dRgokM8]`0@okM8]`Co00004_nRGJ800ol0
003oiaSWonLHi`03onLHi`03o`000?o3?<?o`cc300ko`cc300Go0000omLXeooG:=OoebSGo`000005
om0_d0Oo00003?o<<l`01Ol0003oYEZUojEJYOnUFZGo000000codRgB00?o0000oo8=l_ob3O802?ob
3O83o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000ool@ka00?o0000omXUf_oJ9MX01_oJ9MX00ol0003o]dRgokM8]`0=
okM8]`?o000000CoO8=lo`000?l0003o00004onRGJ82o`0000;oiaSW00?o0000ol<l`oo3?<<04?o3
?<<00ol0003oebSGo`000006o`0000Oo/4n`00?o0000ol`cc?o<<l`02?o<<l`00ol0003oYEZUojEJ
Y@03ojEJY@;o00002?oB;M83o`0000KolPgb1?l00002onhAkP03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003omPWfo`000?oD:m@3o`0000gol@ka00?o0000omXUf_oJ9MX01?oJ9MX00ol0003o]dRgokM8
]`0;okM8]`?o00000omlPg`01Ol0003oMhQgo`000?m>/Dko000001CoXUfR00?o0000onLHiol00000
4oo3?<<00ol0003o/4n`ok1?/00=ok1?/003o`000?o<<lcoc3?<00Goc3?<0_l00008ojEJY@03o`00
0?oB;M;odRgB00Go00000oo><Lh00ol0003olPgboo8=lP03o`0000OokQ7^00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?of2OKomPWfo`0000Coe2_D0ol0000:oo4>l@03o`000?oJ9M[ofRGJ00?ofRGJ
00?o0000okM8]ongB;L02OngB;L3o`0000GoO8=l00Co0000ogN8MomgR7Oo00000_m>/Dh00ol0003o
XUfRoj9MXP0Boj9MXP03o`000?o3?<?o`cc301;o`cc300?o0000ok1?/?n`Ck003_n`Ck000ol0003o
c3?<ol`cc003ol`cc003o`000?nUFZGoYEZU00WoYEZU0_l00009olhacP;o00002_o^4Nh00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000ooH9m_of2OKomPWfo`000007om@[e0;o00001ooa3_45o`0000;o
fRGJ00?o0000okM8]ongB;L01_ngB;L3o`0000SoO8=l00Co0000ogN8MomgR7Oo00000om>/Dh00ol0
003oXUfRoj9MXP0Aoj9MXP03o`000?o3?<?o`cc3017o`cc300?o0000ok1?/?n`Ck004?n`Ck001Ol0
003oc3?<ol`cc?o<<lco000000coYEZU00?o0000olhac_o><Lh02?o><Lh00ol0003okQ7^onhAkP0:
onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000ComPWf00?o0000om@[e?oD:m@01ooD:m@3o`00
0004oo4>lOl0003o0000o`0000Go`3o00_l00006okM8]`?o00002_mlPg`01Ol0003oMhQgogN8Momg
R7Oo000000CoC[5>00?o0000oj9MX_nRGJ804?nRGJ800ol0003o`cc3ol<l``0Aol<l``03o`000?n`
Ck3o/4n`017o/4n`00?o0000ol`cc?l000003OnUFZD00ol0003ocS7>olhacP08olhacP03o`000?o^
4NkokQ7^00[okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00ComPWf00?o0000
om@[e?oD:m@02_oD:m@00ol0003o`3o0ol0o`008ol0o`003o`000?ngB;Oo]dRg00?o00003OmlPg`0
1Ol0003oMhQgogN8MomgR7Oo000000GoC[5>00?o0000oj9MX_nRGJ803onRGJ800ol0003o`cc3ol<l
``0Aol<l``03o`000?n`Ck3o/4n`01;o/4n`00?o0000ojEJYOnUFZD03?nUFZD00ol0003ocS7>olha
cP08olhacP03o`000?o^4NkokQ7^00_okQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000ooH9m_of2OH01Oof2OH0
0ol0003oe2_Dom@[e00:om@[e003o`000?o0?l3o`3o000Wo`3o00_l0000?ogb3O003o`000?mgR7Oo
MhQg00;oMhQg00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oXUfRoj9MXP0=oj9MXP?o00004Oo3?<<0
0ol0003o/4n`ok1?/00Cok1?/003o`000?nUFZGoYEZU00_oYEZU00?o0000olhac_o><Lh02Oo><Lh0
0ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?of2OH0
0ol0003oe2_Dom@[e00:om@[e003o`000?o0?l3o`3o000Wo`3o000?o0000ogb3O?mlPg`03OmlPg`0
0ol0003oMhQgogN8M`03ogN8M`03o`000?m>/DkoC[5>00GoC[5>00?o0000oj9MX_nRGJ802_nRGJ82
o`0000?oOH9m00?o0000ol<l`oo3?<<03_o3?<<00ol0003o/4n`ok1?/00Cok1?/003o`000?nUFZGo
YEZU00_oYEZU00?o0000olhac_o><Lh02Oo><Lh00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000ooH9m_of2OH01oof2OH2o`0000_oe2_D00?o0000ol0o
`?o0?l002oo0?l000ol0003oO8=logb3O00<ogb3O003o`000?mgR7OoMhQg00?oMhQg00?o0000odja
C_m>/Dh01_m>/Dh00ol0003oXUfRoj9MXP07oj9MXP;o00001_mmPWd2o`0000ko`cc300?o0000ok1?
/?n`Ck004on`Ck000ol0003oYEZUojEJY@0;ojEJY@03o`000?o><LkocS7>00WocS7>00?o0000onhA
k_o^4Nh03?o^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009ooH9
mP03o`000?o[5>_o000000_oe2_D00?o0000ol0o`?o0?l002oo0?l000ol0003oO8=logb3O00;ogb3
O003o`000?mgR7OoMhQg00CoMhQg00?o0000odjaC_m>/Dh01om>/Dh00ol0003oXUfRoj9MXP05oj9M
XP03o`000?mmPWgoOH9m00SoOH9m00?o0000ol<l`oo3?<<02_o3?<<00ol0003o/4n`ok1?/00Dok1?
/003o`000?nUFZGoYEZU00_oYEZU00?o0000olhac_o><Lh02Oo><Lh00ol0003okQ7^onhAkP0<onhA
kP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009ooH9mP04o`000?o[5>_ojaC[o`00
00_oe2_D00?o0000ol0o`?o0?l002oo0?l000ol0003oO8=logb3O00;ogb3O003o`000?mgR7OoMhQg
00CoMhQg00?o0000odjaC_m>/Dh02?m>/Dh00ol0003oXUfRoj9MXP02oj9MXP;o00003?mmPWd2o`00
00[o`cc300?o0000ok1?/?n`Ck005?n`Ck000ol0003oYEZUojEJY@0;ojEJY@03o`000?o><LkocS7>
00WocS7>00?o0000onhAk_o^4Nh03Oo^4Nh00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003omPWfooH9mP07ooH9mP03
o`000?o[5>_ojaC[00;ojaC[00?o0000om@[e?oD:m@02?oD:m@00ol0003o`3o0ol0o`00<ol0o`003
o`000?mlPgcoO8=l00WoO8=l00?o0000ogN8MomgR7L01OmgR7L00ol0003oC[5>odjaCP09odjaCP04
o`000?nRGJ;o0000o`00013oOH9m0_l00008ol<l``03o`000?n`Ck3o/4n`01Co/4n`0ol0000;ojEJ
Y@03o`000?o><LkocS7>00WocS7>00?o0000onhAk_o^4Nh03Oo^4Nh01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003omPWfooH9mP06ooH9mP03o`000?o[5>_ojaC[00?ojaC[00?o0000om@[
e?oD:m@02?oD:m@00ol0003o`3o0ol0o`00;ol0o`0;o00002_mlPg`00ol0003oMhQgogN8M`06ogN8
M`03o`000?m>/DkoC[5>00[oC[5>00?o0000ogf2OOmmPWd04_mmPWd00ol0003o`cc3ol<l``04ol<l
``03o`000?n`Ck3o/4n`01Go/4n`00?o0000oiQWV?nHIiP01Ol00005ojEJY@03o`000?o><LkocS7>
00[ocS7>00?o0000onhAk_o^4Nh03_o^4Nh3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003omPWfooH9mP04ooH9mP03
o`000?o[5>_ojaC[00CojaC[00?o0000om@[e?oD:m@01ooD:m@00ol0003o`3o0ol0o`00;ol0o`004
o`000?mfRGKoMXUfo`0000WoO8=l00?o0000ogN8MomgR7L01_mgR7L00ol0003oC[5>odjaCP0:odja
CP03o`000?mmPWgoOH9m01?oOH9m0_l00003ol<l``Co00005?n`Ck000ol0003oV6NHoiQWV006oiQW
V0Co000000?oYEZUo`000?o><Lh02oo><Lh00ol0003okQ7^onhAkP0>onhAkP03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003omPWfooH9mP03ooH9mP03o`000?o[5>_ojaC[00GojaC[00?o0000om@[e?oD
:m@01ooD:m@00ol0003o`3o0ol0o`009ol0o`0;o00001?mfRGH00ol0003oO8=logb3O005ogb3O003
o`000?mgR7OoMhQg00OoMhQg00?o0000odjaC_m>/Dh02_m>/Dh00ol0003oOH9mogf2O@0Eogf2O@03
o`000?o3?<?o000000CoSW6>0ol0000@ok1?/003o`000?nHIiSoV6NH00_oV6NH0_l0000<olhacP03
o`000?o^4NkokQ7^00cokQ7^0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooH9m_of2OH00_of2OH00ol0003ojaC[
on/Dj`06on/Dj`03o`000?oD:mCoe2_D00Ooe2_D00?o0000ol0o`?o0?l002?o0?l000ol0003oMXUf
ogJ9MP05ogJ9MP03o`000?mlPgcoO8=l00CoO8=l00?o0000ogN8MomgR7L01omgR7L00ol0003oC[5>
odjaCP0:odjaCP03o`000?mmPWgoOH9m01KoOH9m00?o0000ohiaS_n>LHh01_n>LHh3o`0000co/4n`
00?o0000oiQWV?nHIiP03OnHIiP00ol0003ocS7>olhacP09olhacPGo00002Oo^4Nh2o`000003oo8=
l_l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooH9m_l0003ojaC[00WojaC[00?o0000om@[e?oD:m@01_oD
:m@00ol0003o`3o0ol0o`007ol0o`003o`000?mfRGKoMXUf00OoMXUf00?o0000ogb3O?mlPg`00_ml
Pg`00ol0003oMhQgogN8M`08ogN8M`03o`000?m>/DkoC[5>00WoC[5>00?o0000ogf2OOmmPWd05omm
PWd00ol0003oSW6>ohiaSP09ohiaSP?o00002On`Ck000ol0003oV6NHoiQWV00>oiQWV0Ko00001?o>
<Lh00ol0003of2OHomPWf003omPWf0Go00000_o^4Nh2o`0000ColPgb00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o^4NkokQ7^onhAk_l000002oo[5>/00ol0003oe2_Dom@[e006om@[e003o`000?o0
?l3o`3o000Go`3o00_l0000;ogJ9MP04o`000?mlPgcoO8=lo`0000_oMhQg00?o0000odjaC_m>/Dh0
2Om>/Dh00ol0003oOH9mogf2O@0Fogf2O@03o`000?n>LHkoSW6>00goSW6>0ol00005ok1?/003o`00
0?nHIiSoV6NH00ooV6NH00?o0000ojiA[_n^DJh00on^DJh4o`0000_of2OH0_l00006oo8=lP03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003okQ7^onhAkP02onhAkPko00001_oD:m@00ol0003o`3o0ol0o
`005ol0o`003o`000?mfRGKoMXUf00coMXUf00?o0000ogb3O?l000002omgR7L00ol0003oC[5>odja
CP07odjaCP?o00006?mmPWd00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o/4n`o`000?nHIiP04?nH
IiP00ol0003o[U6^ojiA[P07ojiA[P03o`000?oH9mSof2OH00[of2OH00?o0000oo8=l_ob3O801Oob
3O800ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005onhAkP03o`000?o?<<oocc3?00_occ3?0_l00004
om@[e003o`000?o0?l3o`3o000?o`3o00_l0000@ogJ9MP03o`000?mgR7OoMhQg00[oMhQg00?o0000
odjaC_m>/Dh00om>/Dh4o`0000;o;]4^00?o0000ogf2OOmmPWd05OmmPWd00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nHIiSoV6NH013oV6NH00?o0000ojiA[_n^DJh01on^DJh00ol0003of2OHomPWf00:
omPWf003o`000?ob3O;olPgb00GolPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o^4NkokQ7^
00GokQ7^00?o0000oll`coo?<<l03Oo?<<l6o`0000?o`3o000?o0000ogJ9M_mfRGH04?mfRGH00ol0
003oMhQgogN8M`0:ogN8M`03o`000?m>/Dko000000?o00001ol^dBh00ol0003oOH9mogf2O@0Dogf2
O@03o`000?n>LHkoSW6>01CoSW6>00?o0000oiQWV?nHIiP03onHIiP00ol0003o[U6^ojiA[P08ojiA
[P03o`000?oH9mSof2OH00[of2OH00?o0000oo8=l_ob3O801Oob3O800ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onhAk_o^4Nh01_o^4Nh00ol0003occ3?oll`c`0=oll`c`03o`000?ncC;?o/dbc00?o
/dbc00?o0000ol0o`?l000004omfRGH4o`0000WoMhQg0_l0000<obkA;P03o`000?mmPWgoOH9m01?o
OH9m00?o0000ohiaS_n>LHh05On>LHh00ol0003oV6NHoiQWV00>oiQWV003o`000?n^DJko[U6^00So
[U6^00?o0000omPWf?oH9mP02OoH9mP00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o^4NkokQ7^00SokQ7^00?o0000oll`coo?<<l02oo?<<l00ol0003o/dbcok=</`05ok=</`03o`00
0?mfRGKoMXUf01;oMXUf00Co0000oc_4>olka3_o>l@k1Ol00003ogN8M`03o`000?l^dBko;]4^00go
;]4^0ol0000@ogf2O@;o00006?n>LHh00ol0003oV6NHoiQWV00=oiQWV003o`000?n^DJko[U6^00Wo
[U6^00?o0000omPWf?oH9mP02OoH9mP00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_okQ7^00?o0000oll`coo?<<l02_o?<<l00ol0003o/dbcok=</`06ok=</`03o`00
0?mfRGKoMXUf017oMXUf00?o0000oc_4>olka3/01olka3/3o`00013o;]4^00?o0000oacS7?lLha`0
1Ol00009ogf2O@;o000000?o=LXeo`000?n>LHh05on>LHh00ol0003oV6NHoiQWV00=oiQWV003o`00
0?n^DJko[U6^00Wo[U6^00?o0000omPWf?oH9mP02?oH9mP2o`0000[olPgb00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?og2?Oom`Sg00;om`Sg00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003occ3?oll`
c`0:oll`c`03o`000?ncC;?o/dbc00Oo/dbc00?o0000ogJ9M_mfRGH03omfRGH00ol0003o>l@koc_4
>`0:oc_4>`03o`000?l^dBko;]4^00go;]4^00?o0000oacS7?lLha`01_lLha`4o`0000CoOH9m00?o
0000ocG:=OlebSD00_lebSD00ol0003oSW6>ohiaSP0FohiaSP03o`000?nHIiSoV6NH00_oV6NH00?o
0000ojiA[_n^DJh02on^DJh00ol0003of2OHomPWf006omPWf003o`000?oY5^Wo000000[olPgb00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000onhAk_o^4Nh02?o^4Nh=
o`0000[o/dbc00?o0000ogJ9M_mfRGH03omfRGH00ol0003o>l@koc_4>`0;oc_4>`03o`000?l^dBko
;]4^00co;]4^00?o0000oacS7?lLha`02_lLha`4o`0000Go=LXe00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oV6NHoiQWV00:oiQWV003o`000?n^DJko[U6^00co[U6^00?o0000omPWf?oH9mP01?oH9mP2
o`0000?ojAKY00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooL8
moog2?L00oog2?L00ol0003okQ7^onhAkP07onhAkP03o`000?o=</gocC;=00WocC;=00?o0000ok=<
/oncC;<02OncC;<00ol0003oMXUfogJ9MP0=ogJ9MP03o`000?lka3_o>l@k00co>l@k00?o0000obkA
;_l^dBh03?l^dBh00ol0003o7><LoacS700;oacS7003o`000?l9mPWo000000Ko=LXe00?o0000ohia
S_n>LHh05_n>LHh00ol0003oV6NHoiQWV009oiQWV003o`000?n^DJko[U6^00co[U6^00?o0000omPW
f?oH9mP00ooH9mP00ol0003ojAKYonTFj@03onTFj@03o`000?ob3O;olPgb00SolPgb00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Com`Sg00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o
cC;=oldbc@08oldbc@03o`000?ncC;?o/dbc00_o/dbc00?o0000ogJ9M_mfRGH02?mfRGH4o`0000oo
>l@k00?o0000obkA;_l^dBh02ol^dBh00ol0003o7><LoacS700;oacS7004o`000?l9mPWo2OH9o`00
00Oo=LXe00?o0000ohiaS_n>LHh05On>LHh00ol0003oV6NHoiQWV008oiQWV003o`000?n^DJko[U6^
00go[U6^00?o0000omPWf?oH9mP00_oH9mP00ol0003ojAKYonTFj@05onTFj@03o`000?ob3O;olPgb
00OolPgb00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Gom`Sg00?o0000onhAk_o^
4Nh01Oo^4Nh00ol0003ocC;=oldbc@08oldbc@03o`000?ncC;?o/dbc00_o/dbc00?o0000ogJ9M_mf
RGH00omfRGH5o`0000?o?<<l00?o0000oc_4>olka3/03_lka3/00ol0003o;]4^obkA;P0:obkA;P03
o`000?lLhaco7><L00[o7><L00Go0000o`Wf2Ol9mPWo2OH9o`000007ocG:=@03o`000?n>LHkoSW6>
01GoSW6>00?o0000oiQWV?nHIiP02?nHIiP00ol0003o[U6^ojiA[P0=ojiA[P03o`000?oH9mSof2OH
00;o00002?oY5^T00ol0003olPgboo8=lP08oo8=lPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?o^4NkokQ7^00Go
kQ7^00?o0000oldbcOo=</d02?o=</d00ol0003o/dbcok=</`0<ok=</`Go00002Oll`c`00ol0003o
>l@koc_4>`0<oc_4>`;o00003?l^dBh00ol0003o7><LoacS700:oacS7005o`000?l9mPWo2OH9o`Wf
2Ol000002?lebSD00ol0003oSW6>ohiaSP0DohiaSP?o00001onHIiP00ol0003o[U6^ojiA[P0>ojiA
[P03o`000?oH9mSo000000_ojAKY00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooL8moog2?L01Oog2?L00ol0003okQ7^onhAkP04onhAkP03o`000?o=</gocC;=00Oo
cC;=00?o0000ok=</oncC;<03?ncC;<01?l0003oMXUfogJ9M_l0000;occ3?003o`000?lka3_o>l@k
00_o>l@k00Co0000o`Ck1?l4n`Co00002_l^dBh00ol0003o7><LoacS700:oacS7003o`000?l9mPWo
2OH900;o2OH900?o0000ocG:=OlebSD01_lebSD00ol0003oSW6>ohiaSP0AohiaSP?o00000omQWV40
0ol0003oV6NHoiQWV004oiQWV003o`000?n^DJko[U6^00go[U6^1?l0000;onTFj@03o`000?ob3O;o
lPgb00GolPgb00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00Co0000onhA
k_o^4NkokQ7^1?l00008oldbc@03o`000?ncC;?o/dbc00_o/dbc00?o0000ogJ9M_mfRGH00_mfRGH0
0ol0003o?<<locc3?008occ3?003o`000?lka3_o>l@k00[o>l@k00?o0000o`Ck1?l4n`@00_l4n`@0
0ol0003o;]4^obkA;P03obkA;PGo00002olLha`00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?lebSGo
=LXe00Oo=LXe00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoHIiQ00?o0000oiQWV?nHIiP00_nHIiP0
0ol0003o[U6^ojiA[P0=ojiA[P03o`000?oE:]GoeB[E00;oeB[E00?o0000onTFjOoY5^T02OoY5^T0
0ol0003olPgboo8=lP03oo8=lP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`07ooL8
m`?o00001?oL8m`00ol0003ocC;=oldbc@05oldbc@03o`000?ncC;?o/dbc00[o/dbc00?o0000ogJ9
M_mfRGH00omfRGH00ol0003o?<<locc3?009occ3?003o`000?lka3_o>l@k00So>l@k00?o0000o`Ck
1?l4n`@01?l4n`@5o`0000Co0?l000?o0000oacS7?lLha`02OlLha`00ol0003o2OH9o`Wf2@03o`Wf
2@03o`000?lebSGo=LXe00So=LXe00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oHIiQ00Go0000oiQW
V?nHIiSoV6NHo`00000>ojiA[P03o`000?oE:]GoeB[E00CoeB[E0_l00009onTFj@03o`000?ob3O;o
lPgb00;olPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000om`S
g?oL8m`01OoL8m`00ol0003ocC;=oldbc@03oldbc@03o`000?ncC;?o/dbc00[o/dbc00?o0000ogJ9
M_mfRGH01?mfRGH00ol0003o?<<locc3?009occ3?003o`000?lka3_o>l@k00Oo>l@k00?o0000o`Ck
1?l4n`@01Ol4n`@00ol0003o0?l0o`3o0007o`3o0003o`000?lLhaco7><L00Oo7><L00?o0000o`Wf
2Ol9mPT01?l9mPT00ol0003o=LXeocG:=@08ocG:=@03o`000?n>LHkoSW6>00SoSW6>0_l0000>of6N
H@Co00003?n^DJh2o`0000WoeB[E00?o0000onTFjOoY5^T01ooY5^T01?l0003olPgboo8=l_l0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooL8moog2?L01Oog2?L00ol0003og2?Lom`Sg007om`Sg0;o00000oo=</d00ol0
003o/dbcok=</`09ok=</`03o`000?mfRGKoMXUf00KoMXUf00?o0000occ3??ll`c`02Oll`c`00ol0
003o>l@koc_4>`05oc_4>`03o`000?l4n`Co1?/400Ko1?/400?o0000o`3o0?l0o`002?l0o`000ol0
003o7><LoacS7006oacS7003o`000?l9mPWo2OH900Co2OH900?o0000ocG:=OlebSD02OlebSD4o`00
00?oSW6>0ol0000@of6NH@05o`000?o1?/7o`Ck1ol4n`Ol000002_n^DJh00ol0003oeB[EomDZe@0:
omDZe@Ko00000ooY5^T00ol0003olPgbo`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooL8moog2?L01?og2?L00ol0
003og2?Lom`Sg00:om`Sg004o`000?o=</gocC;=o`0000[o/dbc00?o0000ogJ9M_mfRGH01omfRGH0
0ol0003o?<<locc3?009occ3?003o`000?lka3_o>l@k00Co>l@k00?o0000o`Ck1?l4n`@01ol4n`@0
0ol0003o0?l0o`3o0008o`3o00;o00001_lLha`00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?lebSGo
=LXe00Wo=LXe00Co0000obcC;?l/dbco;=</0ol0000Bof6NH@03o`000?o1?/7o`Ck100?o`Ck10_l0
0006ojiA[P;o00003OoE:]D00ol0003om@[eooD:m@03ooD:m@Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooL8moog2?L00oog2?L0
0ol0003og2?Lom`Sg00<om`Sg0;o00002_ncC;<00ol0003oMXUfogJ9MP08ogJ9MP03o`000?ll`cco
?<<l00[o?<<l00?o0000oc_4>olka3/00_lka3/00ol0003o1?/4o`Ck1008o`Ck1003o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lLhaco7><L00;o7><L00?o0000o`Wf2Ol9mPT01_l9mPT0
0ol0003o=LXeocG:=@08ocG:=@03o`000?l/dbco;=</00Co;=</00?o0000of6NHOmQWV403omQWV40
0ol0003o`Ck1ol4n`@06ol4n`@;o00000on^DJh00ol0003oeB[EomDZe@0=omDZe@03o`000?oe2_Go
m@[e00Oom@[e0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003om`SgooL8m`02ooL8m`03o`000?oL8mcog2?L
00kog2?L00?o0000ok=</oncC;<01oncC;<00ol0003oMXUfogJ9MP0:ogJ9MP03o`000?ll`cco?<<l
00Wo?<<l00Go0000oc_4>olka3_o>l@ko`00000;o`Ck1003o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lLhaco7><LoacS7?l000002?l9mPT00ol0003o=LXeocG:=@08ocG:=@03o`000?l/
dbco;=</00Go;=</00?o0000of6NHOmQWV403_mQWV400ol0003o`Ck1ol4n`@08ol4n`@03o`000?n^
DJko000000ooeB[E00?o0000ooD:mOoe2_D02?oe2_D01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?og2?Oom`Sgo`00017og2?L00?o0000ok=</oncC;<01_ncC;<00ol0003oMXUf
ogJ9MP0;ogJ9MP03o`000?ll`cco?<<l00Wo?<<l00Co0000oc_4>olka3_o00003?l4n`@00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o7><Lo`000009o`Wf2@03o`000?lebSGo=LXe00So
=LXe00?o0000obcC;?l/db`01Ol/db`00ol0003oHIiQof6NH@0=of6NH@03o`000?o1?/7o`Ck100[o
`Ck100?o0000omDZeOoE:]D03_oE:]D00ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bom`Sg003o`00
0?ncC;?o/dbc00Co/dbc00?o0000ogJ9M_mfRGH03?mfRGH00ol0003o?<<locc3?00:occ3?0?o0000
3?l4n`@00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Wf2Ol9mPT02?l9mPT00ol0003o=LXe
ocG:=@07ocG:=@03o`000?l/dbco;=</00Oo;=</00?o0000of6NHOmQWV403?mQWV400ol0003o`Ck1
ol4n`@0;ol4n`@;o00003_oE:]D00ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooD:mOoe2_D00ooe2_D00ol0003og2?Lom`Sg00?om`Sg0?o00000onc
C;<00ol0003oMXUfogJ9MP0>ogJ9MP03o`000?ll`cco?<<l00So?<<l00Co0000o`cc3?l<l`co3?<<
0_l0000:o`Ck10?o00003Ol0o`000ol0003o2OH9o`Wf2@08o`Wf2@03o`000?lebSGo=LXe00Oo=LXe
00?o0000obcC;?l/db`01ol/db`00ol0003oHIiQof6NH@0;of6NH@03o`000?o1?/7o`Ck100co`Ck1
00?o0000on/Djol000000_l0000:omDZe@03o`000?oe2_Gom@[e00Som@[e00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003om@[eooD:m@04ooD:m@03o`000?oL8mcog2?L00cog2?L0_l0
0003olPgb003o`000?ncC;?o0000017oMXUf00?o0000occ3??ll`c`01oll`c`00ol0003o3?<<o`cc
3004o`cc30;o00002?l4n`@00ol0003o0?l0o`3o000>o`3o00;o00002?l9mPT00ol0003o=LXeocG:
=@06ocG:=@03o`000?l/dbco;=</00Wo;=</00?o0000of6NHOmQWV402OmQWV400ol0003o`Ck1ol4n
`@0=ol4n`@03o`000?o[5>_ojaC[00;ojaC[0ol00007omDZe@03o`000?oe2_Gom@[e00Oom@[e00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om@[eooD:m@05ooD:m@03o`000?oL8mco
g2?L00Wog2?L0_l00006olPgb003o`000?mfRGKoMXUf013oMXUf00?o0000occ3??ll`c`01_ll`c`0
0ol0003o3?<<o`cc3007o`cc3003o`000?l4n`Co1?/400Co1?/40ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol9mPT00ol0003o=LXeocG:=@06ocG:=@03o`000?l/dbco;=</00[o;=</00?o0000
of6NHOmQWV402?mQWV400ol0003o`Ck1ol4n`@0=ol4n`@03o`000?o[5>_ojaC[00GojaC[0ol00004
omDZe@03o`000?oe2_Gom@[e00Oom@[e00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om@[eooD:m@06ooD:m@03o`000?oL8mcog2?L00Gog2?L0ol00008olPgb003o`000?mfRGKoMXUf
017oMXUf00Co0000occ3??ll`cco?<<l1?l0000;o`cc30;o000000Co1?/4o`000?l0003o00000ol>
l@h2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2OH900?o0000ocG:=OlebSD01_le
bSD00ol0003o;=</obcC;00:obcC;003o`000?mQWV7oHIiQ00OoHIiQ00?o0000ol4n`Oo1?/403_o1
?/400ol0003ojaC[on/Dj`08on/Dj`Co00002_oe2_D00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003om@[eooD:m@07ooD:m@03o`000?oL8mcog2?L00;og2?L0_l0000<olPgb003o`000?mfRGKo
MXUf013oMXUf1?l00003obo@;`03o`000?l<l`co3?<<00_o3?<<00?o0000o`ka3_l>l@h01_l>l@h0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obcC;003o`000?mQWV7o
HIiQ00KoHIiQ00?o0000ol4n`Oo1?/403_o1?/400ol0003ojaC[on/Dj`0;on/Dj`03o`000?oe2_Go
m@[e00Oom@[e00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oe2_Gom@[e00Wom@[e00Co0000om`S
g?l0003o00003_o8=lP00ol0003oMXUfogJ9MP0?ogJ9MP03o`000?l_d2oo;m0_00Ko;m0_00?o0000
o`cc3?l<l``02_l<l``00ol0003o3_4>o`ka3P07o`ka3P;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lhacSo><Lh00So><Lh00?o0000obcC;?l/db`03?l/db`00ol0003oHIiQof6NH@05
of6NH@03o`000?o1?/7o`Ck100oo`Ck10_l0000=on/Dj`03o`000?oe2_Gom@[e00Kom@[e00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oe2_Gom@[e00[om@[e00?o0000olPgb?o8=lP03_o8=lP00ol0
003oMXUfogJ9MP0>ogJ9MP03o`000?l_d2oo;m0_00Oo;m0_00?o0000o`cc3?l<l``02_l<l``00ol0
003o3_4>o`ka3P09o`ka3P;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lhacSo><Lh
00Wo><Lh00?o0000obcC;?l/db`02_l/db`4o`0000CoHIiQ00?o0000ol4n`Oo1?/404?o1?/401?l0
003oj1OXo`000?l0000<on/Dj`03o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oe2_Gom@[e00[om@[e00?o0000olPgb?o8=lP03oo8=lP@o`0000[o;m0_00?o0000o`cc
3?l<l``02Ol<l``00ol0003o0?l0o`00000<o`ka3P05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o><LhocS7>009ocS7>003o`000?l/dbco;=</00Oo;=</0ol00004of:MHP?o000000?oHIiQ
o`000?o1?/404Oo1?/401?l0003oj1OXonPGj?oX5nP2o`0000_ojaC[00?o0000ooD:mOoe2_D00ooe
2_D00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003ob3O8olPgb00?
olPgb003o`000?mfRGKoMXUf00coMXUf00?o0000obo@;ol_d2l02Ol_d2l00ol0003o3?<<o`cc3007
o`cc3004o`000?l0o`3o0?l0o`0000go3_4>00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lhacSo><Lh00[o><Lh00?o0000obcC;?l/db`00ol/db`3o`0000[oHYeR00?o0000ol4n`Oo1?/40
4?o1?/400ol0003oj1OXonPGj004onPGj0;o00002_o[5>/00ol0003om@[eooD:m@04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000com@[e00?o0000olPgb?o8=lP03oo8=lP00ol0003oMXUfogJ9MP0<ogJ9MP03o`000?l_
d2oo;m0_00Wo;m0_00?o0000o`cc3?l<l``01_l<l``00ol0003o0?l0o`3o0002o`3o0003o`000?l>
l@ko3_4>00[o3_4>00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?lh
acSo><Lh00[o><Lh00?o0000obcC;?l/db`00ol0000=of:MHP03o`000?o1?/7o`Ck1013o`Ck100?o
0000onPGj?oX5nP01_oX5nP2o`0000WojaC[0_l00004oo`3o003o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003ob3O8olPgb00=olPgb0?o00003omfRGH0
0ol0003o;m0_obo@;`08obo@;`03o`000?l<l`co3?<<00Go3?<<00?o0000o`3o0?l0o`000ol0o`00
0ol0003o3_4>o`ka3P0:o`ka3P03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o><LhocS7>00;ocS7>0;o00004OmRWF800ol0003o`Ck1ol4n`@0?ol4n`@03o`000?oX5nSo
j1OX00Soj1OX0_l00007on/Dj`03o`000?ol0ocoo0?l00Coo0?l00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooD:mOoe2_D02?oe2_D00ol0003ob3O8olPgb009olPgb0Go00000_nLHi`00ol0
003oMXUfogJ9MP0=ogJ9MP03o`000?l_d2oo;m0_00Wo;m0_00?o0000o`cc3?l<l``01?l<l``00ol0
003o0?l0o`3o0004o`3o0003o`000?l>l@ko3_4>00So3_4>00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lhacSo><Lh00_o><Lh00?o0000of:MH_mRWF804?mRWF800ol0
003o`Ck1ol4n`@0?ol4n`@03o`000?oX5nSoj1OX00[oj1OX0_l00004on/Dj`03o`000?ol0ocoo0?l
00Koo0?l0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om@[eooD:m@07ooD:m@03o`000?o8=lSob3O800Cob3O81Ol00007oiaSW003
o`000?mfRGKoMXUf00goMXUf00?o0000obo@;ol_d2l02Ol_d2l00ol0003o3?<<o`cc3003o`cc3003
o`000?l0o`3o0?l000Go0?l000?o0000o`ka3_l>l@h02?l>l@h00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ocS7>?lhacP02olhacP00ol0003oHYeRof:MHP0@of:MHP03
o`000?o1?/7o`Ck100oo`Ck100?o0000onPGj?oX5nP03?oX5nP2o`000003on/Djol0003oo0?l00[o
o0?l00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oe2_Gom@[e00Oom@[e00?o0000olPgb?l00000
1?l0000<oiaSW003o`000?mfRGKoMXUf00koMXUf00?o0000obo@;ol_d2l02?l_d2l00ol0003o3?<<
o`cc3002o`cc3003o`000?l0o`3o0?l000Oo0?l000?o0000o`ka3_l>l@h01ol>l@h00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ocS7>?lhacP02olhacP00ol0003oHYeR
of:MHP0Aof:MHP03o`000?o1?/7o`Ck100go`Ck100?o0000onPGj?oX5nP03ooX5nP00ol0003oo0?l
oo`3o00;oo`3o0;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooD:mOoe2_D01Ooe2_D3o`00017oW6>L00?o0000ogJ9M_mfRGH03_mf
RGH00ol0003o;m0_obo@;`09obo@;`04o`000?l<l`co3?<<o`0000[o0?l000?o0000o`ka3_l>l@h0
1ol>l@h00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003OlhacP00ol0003o
HYeRof:MHP0Aof:MHP?o00003Oo1?/400ol0003oj1OXonPGj00?onPGj003o`000?ol0ocoo0?l00go
o0?l00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oe2_D2o`0000;oh1oP00?o0000oiaSW?nLHi`03onLHi`00ol0003o
MXUfogJ9MP0>ogJ9MP03o`000?l_d2oo;m0_00So;m0_1Ol0000;o`3o0003o`000?l>l@ko3_4>00Ko
3_4>00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ocS7>003o`000?mRWF;oHYeR
017oHYeR00?o0000of^DJom[U6/00ol0000:ol4n`@Co00003OoX5nP00ol0003oo0?loo`3o00?oo`3
o003o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooL8moog2?Oom`Sg0_l00005on0Oh003o`000?nLHicoW6>L00koW6>L00?o0000ogJ9
M_mfRGH03_mfRGH00ol0003o;m0_obo@;`07obo@;`03o`000?lIiQWo6NHI00?o6NHI00?o0000o`3o
0?l0o`002?l0o`000ol0003o3_4>o`ka3P05o`ka3P03o`000?l0o`3o0?l000[o0?l01Ol0000<ocS7
>003o`000?mRWF;oHYeR013oHYeR00?o0000of^DJom[U6/01?m[U6/3o`0000Ko`Ck100?o0000on<L
hooS7><00_oS7><5o`0000Soj1OX00?o0000oo`3o?ol0o`04?ol0o`00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00?o
m`Sg00?o0000on0Oh?oP7n001?oP7n000ol0003oW6>LoiaSW00=oiaSW003o`000?mfRGKoMXUf00oo
MXUf00?o0000obo@;ol_d2l01?l_d2l2o`0000Oo6NHI00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ocS7>?lhacP02?lhacP3o`00013oHYeR00?o0000of^DJom[U6/02?m[U6/3o`0000;o
`Ck100?o0000on<LhooS7><02?oS7><5o`0000?oj1OX00?o0000oo`3o?ol0o`04?ol0o`00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?og2?Oom`Sg00Com`Sg00?o0000on0Oh?oP7n001OoP7n000ol0003oW6>LoiaSW00;oiaSW0Co0000
3omfRGH00ol0003o;m0_obo@;`03obo@;`03o`000?lIiQWo6NHI00So6NHI00?o0000o`3o0?l0o`00
1?l0o`02o`0000So4n`C00?o0000o`?l0ol3o0<02?l3o0<00ol0003o0?l0o`3o0005o`3o00;o0000
1_lhacP2o`0000?o<l`c00?o0000of:MH_mRWF803?mRWF800ol0003oJiA[of^DJ`0<of^DJ`;o0000
4?oS7><3o`0001?oo0?l00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?oP7n3oh1oP00Koh1oP00?o
0000oiaSW?nLHi`02OnLHi`00ol0003o[E:]o`000002of:MHP?o00003?mfRGH01?l0003o;m0_obo@
;ol_d2l2o`0000co6NHI00?o0000o`3o0?l0o`000_l0o`000ol0003o4n`Coa?/4`08oa?/4`03o`00
0?l3o0?o0o`300So0o`300?o0000o`3o0?l0o`001ol0o`000ol0003o><LhocS7>002ocS7>003o`00
0?lcc3?o<l`c00Co<l`c0_l0000;of:MHP03o`000?m[U6_oJiA[00coJiA[00?o0000ok5>/Ol00000
4_oS7><00ol0003oo0?loo`3o00@oo`3o0;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003om`SgooL8m`06ooL8m`03o`000?oP7n3oh1oP00Ooh1oP00?o
0000oiaSW?nLHi`01_nLHi`2o`0000;o[E:]00?o0000of:MH_mRWF800omRWF83o`0000[oMXUf00?o
0000obo@;ol000003olIiQT01?l0003o0?l0o`000?l0000;oa?/4`03o`000?l3o0?o0o`300So0o`3
00?o0000o`3o0?l0o`002?l0o`001?l0003o><Lho`000?l00009oc?<<`03o`000?mRWF;oHYeR00Oo
HYeR00?o0000of^DJom[U6/03?m[U6/01?l0003o/Djaok5>/Ol0000Con<Lh`03o`000?ol0ocoo0?l
00coo0?l0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooL8moog2?L01oog2?L00ol0003oh1oPon0Oh008on0Oh003o`000?nLHicoW6>L00Co
W6>L00?o0000ojeB[On]DZd00on]DZd00ol0003oHYeRof:MHP05of:MHP?o00001_mfRGH4o`00013o
6NHI00?o0000oa?/4olCk1<03?lCk1<00ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l000Wo
0?l000?o0000oc?<<olcc3<02_lcc3<2o`0000KoHYeR00?o0000of^DJom[U6/03?m[U6/00ol0003o
/Djaok5>/@02ok5>/@03o`000?oS7>?ohacS00oohacS00?o0000ooD:mOl000002ool0o`2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003om`SgooL8m`08ooL8m`03o`000?oP7n3oh1oP00Woh1oP00Co0000oiaSW?nLHico
W6>L0_l00006ojeB[@03o`000?mRWF;oHYeR00SoHYeR0ol000000omfRGKo0000o`000004ocC;=003
o`000?lIiQWo6NHI00go6NHI00?o0000oa?/4olCk1<03?lCk1<00ol0003o0o`3o`?l0`07o`?l0`03
o`000?l0o`3o0?l000Wo0?l000?o0000oc?<<olcc3<03?lcc3<00ol0003oHYeRof:MHP03o`0000ko
JiA[00?o0000ok5>/OnaC[400onaC[400ol0003ohacSon<Lh`0>on<Lh`05o`000?oe2_Gom@[eooD:
mOl000002?ol0o`2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003om`SgooL8m`09ooL8m`03o`000?oP7n3oh1oP00[o
h1oP00?o0000oiaSW?l000002?n]DZd00ol0003oHYeRof:MHP0;of:MHP03o`000?ldbcCo=</d00Go
=</d00?o0000oaWV6OlIiQT03?lIiQT00ol0003o4n`Coa?/4`0<oa?/4`03o`000?l3o0?o0o`300Oo
0o`300?o0000o`3o0?l0o`002?l0o`02o`0000oo<l`c0_l00002ofbCK003o`000?m[U6_oJiA[00_o
JiA[00?o0000ok5>/OnaC[401?naC[400ol0003ohacSon<Lh`0=on<Lh`03o`000?oe2_Gom@[e00?o
m@[e00?o0000oo`3o?ol0o`00_ol0o`3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooL8m`03o`000?oP7n3oh1oP00_oh1oP00?o0000ojeB[On]DZd0
1on]DZd00ol0003oHYeRof:MHP0;of:MHP03o`000?ldbcCo=</d00Ko=</d00?o0000oaWV6OlIiQT0
2olIiQT2o`0000go4n`C00?o0000o`?l0ol3o0<01ol3o0<00ol0003o0?l0o`3o0007o`3o0004o`00
0?l7n0Oo1oP7o`0000ko<l`c00?o0000ofbCK?m/Tf`00_m/Tf`00ol0003oJiA[of^DJ`09of^DJ`03
o`000?naC[7o/Dja00Ko/Dja00?o0000on<LhooS7><02ooS7><00ol0003om@[eooD:m@05ooD:m@04
o`000?ol0oco0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Som`Sg00?o0000on0Oh?oP7n002_oP7n02o`0000Wo
[E:]00?o0000of:MH_mRWF802omRWF800ol0003o=</docC;=007ocC;=003o`000?lIiQWo6NHI00Wo
6NHI00Co0000o`3o0?l0o`3o00003?lCk1<00ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Oh1ol7n0Oo1oP7o`00000>oc?<<`03o`000?m/TfcoK9=/00?oK9=/00?o0000
of^DJom[U6/01om[U6/00ol0003o/Djaok5>/@07ok5>/@03o`000?oS7>?ohacS00[ohacS00?o0000
ooD:mOoe2_D01ooe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooL8m`03o`000?oP7n3oh1oP
00Woh1oP00Co0000omPWf?oH9mSo00002On]DZd00ol0003oHYeRof:MHP09of:MHP03o`000?ldbcCo
=</d00Wo=</d00?o0000oaWV6OlIiQT01olIiQT00ol0003o0?l0o`3o0002o`3o0003o`000?lCk1?o
4n`C00Wo4n`C00?o0000o`?l0ol3o0<01ol3o0<00ol0003o0?l0o`3o0005o`3o0003o`000?l7n0Oo
1oP700?o1oP700?o0000oc?<<olcc3<02_lcc3<00ol0003oK9=/ofbCK005ofbCK003o`000?m[U6_o
JiA[00GoJiA[00?o0000ok5>/OnaC[402?naC[400ol0003ohacSon<Lh`09on<Lh`03o`000?oe2_Go
m@[e00Som@[e00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_og2?L3o`0000Woh1oP00?o0000omPW
f?oH9mP00_oH9mP00ol0003o[E:]ojeB[@06ojeB[@03o`000?mRWF;oHYeR00WoHYeR00?o0000ocC;
=?ldbc@02_ldbc@00ol0003o6NHIoaWV6@05oaWV6@03o`000?l0o`3o0?l000Co0?l000?o0000oa?/
4olCk1<02?lCk1<00ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l000Co0?l000?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o<l`coc?<<`0:oc?<<`03o`000?m/TfcoK9=/00KoK9=/00?o0000of^D
Jom[U6/00om[U6/00ol0003o/Djaok5>/@09ok5>/@03o`000?oS7>?ohacS00SohacS00?o0000ooD:
mOoe2_D02Ooe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003oo0?l0?o00001OoP7n000ol0003o
f2OHomPWf003omPWf003o`000?n]DZgo[E:]00Ko[E:]00?o0000of:MH_mRWF802OmRWF800ol0003o
=</docC;=00;ocC;=003o`000?lIiQWo6NHI00?o6NHI00?o0000o`3o0?l0o`001_l0o`000ol0003o
4n`Coa?/4`08oa?/4`03o`000?l3o0?o0o`300Ko0o`300?o0000o`3o0?l0o`000_l0o`02o`0000So
1oP700?o0000oc?<<olcc3<02Olcc3<00ol0003oK9=/ofbCK007ofbCK005o`000?m[U6_oJiA[of^D
Jol000003OnaC[400ol0003ohacSon<Lh`06on<Lh`03o`000?oe2_Gom@[e00[om@[e00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?o`3o3ol0o`00Gol0o`0ol000000ooP7n3o0000omPWf006omPWf003
o`000?n]DZgo[E:]00Go[E:]00?o0000of:MH_mRWF802OmRWF800ol0003o=</docC;=00<ocC;=005
o`000?lIiQWo6NHIoaWV6Ol000002_l0o`000ol0003o4n`Coa?/4`07oa?/4`03o`000?l3o0?o0o`3
00Ko0o`300?o0000o`3o0?l000000_l000000ol]dRgo0000o`Oh1`07o`Oh1`03o`000?lcc3?o<l`c
00So<l`c00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003oJiA[o`00000=ok5>/@Co00001OoS7><00ol0
003om@[eooD:m@0;ooD:m@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l008oo0?l003
o`000?oH9mSof2OH00Oof2OH00?o0000ojeB[On]DZd01?n]DZd00ol0003oHYeRof:MHP09of:MHP03
o`000?ldbcCo=</d00go=</d00?o0000oaWV6Ol000003?l0o`0:o`0000Oo0o`30ol00005obgB;@03
o`000?l7n0Oo1oP700Ko1oP700?o0000oc?<<olcc3<01olcc3<00ol0003oK9=/ofbCK00:ofbCK003
o`000?naC[7o/Dja00_o/Dja00?o0000on8Mh_oR7N800_oR7N83o`000003on<Lhol0003om@[e00_o
m@[e0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003of2OHomPWf007omPWf003o`00
0?n]DZgo[E:]00Go[E:]00?o0000of:MH_mRWF801omRWF800ol0003o=</docC;=00?ocC;=0;o0000
2ol0o`000ol0003o8=lPob3O8007ob3O8003o`000?l3o0?o0o`300;o0o`30ol00008obgB;@03o`00
0?l7n0Oo1oP700Ko1oP700?o0000oc?<<olcc3<01olcc3<00ol0003oK9=/ofbCK00:ofbCK003o`00
0?naC[7o/Dja00[o/Dja00?o0000on8Mh_oR7N801_oR7N800ol0003om@[eooD:m@08ooD:m@?o0000
0_og2?L00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003of2OHomPW
f008omPWf003o`000?n]DZgo[E:]00Co[E:]00?o0000of:MH_mRWF801omRWF800ol0003o=</docC;
=00>ocC;=004o`000?l5nPGo1OX5o`0000Wo0?l000?o0000ob3O8?lPgb002OlPgb001?l0003o0o`3
o`000?l0000<obgB;@03o`000?l7n0Oo1oP700Ko1oP700?o0000oc?<<olcc3<01_lcc3<00ol0003o
K9=/ofbCK00;ofbCK003o`000?naC[7o/Dja00Oo/Dja0_l00009on8MhP03o`000?oe2_Gom@[e00Co
m@[e1?l00006ooL8m`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ol0o`oo0?l009oo0?l003o`00
0?oH9mSof2OH00Sof2OH00?o0000ojeB[On]DZd00on]DZd>o`0000go=</d00?o0000o`Gj1Ol5nPD0
0_l5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?lPgb3o8=lP00_o8=lP00?o0000obgB;Ol]dRd0
3?l]dRd00ol0003o1oP7o`Oh1`06o`Oh1`03o`000?lcc3?o<l`c00Go<l`c00?o0000ofbCK?m/Tf`0
3?m/Tf`00ol0003o/Djaok5>/@06ok5>/@03o`000?oR7N;ohQgR00[ohQgR00?o0000ooD:mOoe2_D0
0ol0000:ooL8m`?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omPWf?oH9mP02?oH
9mP01Ol0003o[E:]ojeB[On]DZgo000000_oMHYe00?o0000oa?/4olCk1<00ol00009ocC;=003o`00
0?l5nPGo1OX500Co1OX500?o0000o`3o0?l0o`000ol0o`000ol0003o8=lPob3O800<ob3O8003o`00
0?l]dRgo;M8]00go;M8]00?o0000o`Oh1ol7n0L01_l7n0L00ol0003o<l`coc?<<`03oc?<<`?o0000
3Om/Tf`00ol0003o/Djaok5>/@05ok5>/@03o`000?oR7N;ohQgR00cohQgR0_l0000=ooL8m`03o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000omPWf?oH9mP02?oH
9mP4o`0000coMHYe00?o0000oa?/4olCk1<00olCk1<3o`0000Go=</d00?o0000o`Gj1Ol5nPD01_l5
nPD01Ol0003o0?l0o`3o0?l0o`3o000000oo8=lP00?o0000obgB;Ol]dRd03Ol]dRd00ol0003o1oP7
o`Oh1`06o`Oh1`03o`000?lcc3?o<l`c00?o00000olUfRD00ol0003oK9=/ofbCK00;ofbCK003o`00
0?naC[7o/Dja00?o/Dja00?o0000on8Mh_oR7N803OoR7N800ol0003om`SgooL8m`0;ooL8m`03o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000oo0?l?o`3o002_o`3o03o`0000Kof2OH0ol0
0003olPgb003o`000?meRWGoMHYe00[oMHYe00?o0000oa?/4olCk1<01_lCk1<3o`000003ocC;=?l0
003o1OX500Wo1OX500?o0000o`3o0?l000004?lPgb000ol0003o;M8]obgB;@0=obgB;@03o`000?l7
n0Oo1oP700Oo1oP70_l00007obGJ9@03o`000?m/TfcoK9=/00[oK9=/00Co0000ok5>/OnaC[7o/Dja
0ol0000?on8MhP03o`000?og2?Oom`Sg00_om`Sg00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002_o`
3o001?l0003ojAKYonTFjOoY5^T2o`000004omPWf?l0003o0000o`0000Kob3O800?o0000ogF:MOme
RWD02_meRWD00ol0003o4n`Coa?/4`09oa?/4`03o`000?l5nPGo1OX500[o1OX500?o0000ob3O8?lP
gb003olPgb000ol0003o;M8]obgB;@0>obgB;@03o`000?l7n0Oo1oP700Ko1oP700?o0000obGJ9OlU
fRD01olUfRD4o`0000SoK9=/00Co0000ok5>/OnaC[7o00000oo7><L2o`0000gohQgR00?o0000ooL8
moog2?L02_og2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003o
jAKYonTFj@04onTFj@03o`000?o8=lSob3O800Oob3O800?o0000ogF:MOmeRWD02OmeRWD00ol0003o
4n`Coa?/4`0:oa?/4`03o`000?l5nPGo1OX500[o1OX500?o0000ob3O8?lPgb003olPgb000ol0003o
;M8]obgB;@0>obgB;@03o`000?l7n0Oo1oP700Go1oP700?o0000obGJ9OlUfRD02?lUfRD01?l0003o
IiQWofNHIomWV6L7o`0000;oK9=/0_l00006olLha`;o00003?oR7N800ol0003om`SgooL8m`09ooL8
m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ol0o`oo0?l008oo0?l003o`000?oY5^WojAKY00Go
jAKY00?o0000olPgb?o8=lP02?o8=lP00ol0003oMHYeogF:M@08ogF:M@03o`000?lCk1?o4n`C00[o
4n`C00?o0000o`Gj1Ol5nPD02ol5nPD00ol0003o8=lPob3O800>ob3O8003o`000?l]dRgo;M8]00ko
;M8]1Ol00002o`Oh1`03o`000?lUfRGo9MXU00Wo9MXU00?o0000ofNHIomWV6L02?mWV6L3o`0000Wo
acS70_l0000:on8MhP03o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?o`3o3ol0o`00Sol0o`00?o0000onTFjOoY5^T01ooY5^T00ol0003ob3O8olPgb007olPgb003o`00
0?meRWGoMHYe00SoMHYe00?o0000oa?/4olCk1<02_lCk1<00ol0003o1OX5o`Gj1@0:o`Gj1@;o0000
3_lPgb03o`0000go;M8]0ol00005oc_4>`;o00002olUfRD00ol0003oIiQWofNHI`0;ofNHI`;o0000
2_o7><L2o`0000OohQgR0ol00009ooL8m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:onTFj@03o`00
0?o8=lSob3O800Oob3O800?o0000ogF:MOmeRWD02?meRWD>o`0000Wo1OX50ol000000ol0o`3o0000
ob3O800:ob3O80?o00000_liaST00ol0003o;M8]obgB;@09obgB;@;o00002Olka3/00ol0003o9MXU
obGJ9@09obGJ9@03o`000?mWV6OoIiQW00_oIiQW00?o0000oi9]T_l000002oo7><L2o`0000CohQgR
00Co0000onhAk_o^4NkokQ7^0_l00007ooL8m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003ojAKY
onTFj@09onTFj@03o`000?o8=lSob3O800Kob3O800?o0000ogF:MOmeRWD02?meRWD00ol0003o6NHI
oaWV6@0:oaWV6@03o`000?l5nPGo1OX500Co1OX50ol00005o`3o0003o`000?lPgb3o8=lP00Co8=lP
1?l00006ocW6>@03o`000?l]dRgo;M8]00Ko;M8]0_l0000;oc_4>`03o`000?lUfRGo9MXU00Wo9MXU
00?o0000ofNHIomWV6L02_mWV6L01Ol0003oTVfBoi9]T_nBKI;o000000coacS70_l000000ooR7N;o
0000onhAkP05onhAkP03o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oY5^WojAKY00SojAKY00?o0000olPgb?o8=lP01_o8=lP00ol0003oMHYeogF:M@07ogF:M@03o`00
0?lIiQWo6NHI00_o6NHI00?o0000o`Gj1Ol5nPD00_l5nPD2o`0000Wo0?l000?o0000ob3O8?lPgb00
0ol0000;ocW6>@03o`000?l]dRgo;M8]00;o;M8]0ol0000>oc_4>`03o`000?lUfRGo9MXU00Oo9MXU
00?o0000ofNHIomWV6L02omWV6L00ol0003oTVfBoi9]TP02oi9]TP03o`000?o7><OoacS700_oacS7
00?o0000onhAk_o^4Nh01_o^4Nh2o`0000?om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oY
5^WojAKY00OojAKY00?o0000olPgb?o8=lP01oo8=lP00ol0003oMHYeogF:M@05ogF:M@?o00003OlI
iQT4o`0000_o0?l00ol0000?ocW6>@04o`000?l]dRgo0000o`00017o>l@k00?o0000obGJ9OlUfRD0
1olUfRD00ol0003oIiQWofNHI`0:ofNHI`03o`000?nBKI;oTVfB00CoTVfB00?o0000olLhaoo7><L0
1oo7><L3o`0000_okQ7^1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onTFjOoY5^T02?oY5^T00ol0003ob3O8olPg
b006olPgb003o`000?meRWGoMHYe00;oMHYe0ol00003oe2_D003o`000?lIiQWo6NHI00[o6NHI00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AocW6>@03o`000?lka3_o>l@k017o>l@k00?o
0000obGJ9OlUfRD01olUfRD00ol0003oIiQWofNHI`0:ofNHI`03o`000?nBKI;oTVfB00GoTVfB00Co
0000olLhaoo7><OoacS71Ol00002oll`c`03o`000?o^4NkokQ7^00WokQ7^00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onTFjOoY5^T01ooY5^T00ol0003ob3O8olPgb005olPgb0?o0000
00?oMHYeo`000?l000001om@[e000ol0003o6NHIoaWV6@08oaWV6@?o00002_l0o`02o`0000;o0?l0
00?o0000ocW6>OliaST03oliaST00ol0003o>l@koc_4>`0Aoc_4>`03o`000?lUfRGo9MXU00Oo9MXU
00?o0000ofNHIomWV6L02OmWV6L00ol0003oTVfBoi9]TP07oi9]TP?o00001oo?<<l00ol0003okQ7^
onhAkP09onhAkP03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onTFjOoY5^T01ooY
5^T4o`0000;ob3O80_l00003okY5^P03o`000?m@[e3oD:m@00SoD:m@0_l00006oaWV6@;o00000olE
jQD00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000ocW6>OliaST03_li
aST00ol0003o>l@koc_4>`0Boc_4>`03o`000?lUfRGo9MXU00Go9MXU00?o0000ofNHIomWV6L02OmW
V6L00ol0003oTVfBoi9]TP08oi9]TP03o`000?o?<<oocc3?00Oocc3?00?o0000onhAk_o^4Nh02?o^
4Nh00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oY5^WojAKY00CojAKY0_l00004
onTFj@;o00001OnjAKX00ol0003oD:m@oe2_D00:oe2_D003o`000?lIiQWo6NHI00;o6NHI00?o0000
oaGZ5OlEjQD01?lEjQD00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
ocW6>OliaST03_liaST00ol0003o>l@koc_4>`0Boc_4>`[o00002_mWV6L00ol0003oTVfBoi9]TP08
oi9]TP03o`000?o?<<oocc3?00Oocc3?00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ojAKYonTFjOoY5^T2o`0000OojAKY00?o0000okY5^_njAKX01?njAKX0
0ol0003oD:m@oe2_D00:oe2_D004o`000?lIiQWo0000o`0000So5NXE00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?liaSWo>LHi00ko>LHi00?o0000oc_4>olka3/04_lka3/00ol0003o@ka3
od>l@`07od>l@`03o`000?mWV6OoIiQW00KoIiQW00?o0000oi9]T_nBKI802_nBKI800ol0003occ3?
oll`c`06oll`c`03o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oY
5^Wo0000o`0000WojAKY00?o0000okY5^_njAKX01?njAKX00ol0003oD:m@oe2_D00;oe2_D003o`00
0?lEjQGo5NXE00Wo5NXE00?o0000o`3o0?l000002Ol0o`000ol0003o>LHiocW6>@0>ocW6>@;o0000
4_lka3/00ol0003o@ka3od>l@`09od>l@`;o00001_mWV6L00ol0003oTVfBoi9]TP0:oi9]TP03o`00
0?o?<<oocc3?00Kocc3?00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onTFjOoY5^T02OoY5^T00ol0003o^TFjokY5^P05okY5^P03o`000?m@[e3oD:m@00[oD:m@00?o
0000oaGZ5OlEjQD02_lEjQD2o`0000Wo0?l000?o0000ocW6>OliaST03_liaST00ol0003o9mPWo`00
0002o`0000oo>l@k00?o0000od>l@om3_4<02om3_4<00ol0003oIiQWofNHI`03o`0000goTVfB00?o
0000oll`coo?<<l01_o?<<l00ol0003okQ7^onhAkP07onhAkP03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003ojAKYonTFj@09onTFj@03o`000?njAK[o^TFj00Go^TFj00?o0000oe2_D?m@[e002Om@[e02
o`0000_o5NXE0_l0000;o`3o0003o`000?liaSWo>LHi00co>LHi00?o0000obOH9olWf2L00olWf2L3
o`0000co>l@k00?o0000od>l@om3_4<03?m3_4<2o`0000;oRGJ900?o0000oi9]T_nBKI803?nBKI80
0ol0003occ3?oll`c`05oll`c`03o`000?o^4NkokQ7^00OokQ7^00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oY5^WojAKY00[ojAKY00?o0000okY5^_njAKX01_njAKX00ol0003oD:m@oe2_D007oe2_
D003o`000?mDZeCo000000[o5NXE00Co0000o`cc3?l<l`co00002_l0o`000ol0003o>LHiocW6>@0<
ocW6>@03o`000?lWf2Oo9mPW00Ko9mPW0_l00008oc_4>`;o00003om3_4<00ol0003oRGJ9ohUfR@02
ohUfR@03o`000?nBKI;oTVfB00_oTVfB00?o0000oll`coo?<<l01Oo?<<l00ol0003okQ7^onhAkP07
onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ojAKYonTFj@0:onTFj@03o`000?njAK[o^TFj
00Ko^TFj00?o0000oe2_D?m@[e001_m@[e001Ol0003oE:]DoeB[E?mDZeCo000000So5NXE00?o0000
o`cc3?l<l``00_l<l``00ol0003o0?l0o`3o0006o`3o00Co00003?liaST00ol0003o9mPWobOH9`08
obOH9`?o00000_lka3/3o`000003ocC;=?l0003o@ka300go@ka300?o0000ohUfROn9MXT01?n9MXT0
0ol0003oTVfBoi9]TP0:oi9]TP03o`000?o?<<oocc3?00Gocc3?00?o0000onhAk_o^4Nh01_o^4Nh0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onTFjOoY5^T02ooY5^T00ol0003o^TFjokY5^P07okY5
^P03o`000?m@[e3oD:m@00?oD:m@0_l00005oeB[E003o`000?lEjQGo5NXE00Co5NXE00?o0000o`cc
3?l<l``00ol<l``00ol0003o0?l0o`3o0005o`3o0003o`000?l8m`So2?L800;o2?L80ol00007ocW6
>@;o00003_lWf2L2o`0000Go=</d00?o0000od>l@om3_4<02_m3_4<00ol0003oRGJ9ohUfR@05ohUf
R@03o`000?nBKI;oTVfB00_oTVfB00?o0000oll`coo?<<l01?o?<<l00ol0003okQ7^onhAkP06onhA
kP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ojAKYonTFj@0;onTFj@03o`000?njAK[o^TFj00Oo
^TFj00?o0000oe2_D?m@[e000_m@[e000ol0003oE:]DoeB[E006oeB[E003o`000?lEjQGo5NXE00;o
5NXE00?o0000o`cc3?l<l``01Ol<l``00ol0003o0?l0o`3o0002o`3o00;o00002?l8m`P3o`0000;o
>LHi0_l000000ol>l@ko0000obOH9`0=obOH9`03o`000?ldbcCo=</d00Go=</d00?o0000od>l@om3
_4<02?m3_4<00ol0003oRGJ9ohUfR@07ohUfR@03o`000?nBKI;oTVfB00[oTVfB00?o0000oll`coo?
<<l01?o?<<l00ol0003okQ7^onhAkP06onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojAKY
onTFj@0<onTFj@03o`000?njAK[o^TFj00So^TFj00Co0000oe2_D?m@[e3o00002OmDZe@01Ol0003o
5NXEoaGZ5OlEjQGo000000So3?<<00Go0000o`3o0?l0o`3o0?l0o`00000=o`Sg20;o00001?l>l@h0
0ol0003o9mPWobOH9`0;obOH9`03o`000?ldbcCo=</d00Ko=</d00?o0000od>l@om3_4<01om3_4<0
0ol0003oRGJ9ohUfR@08ohUfR@Co00002?nBKI800ol0003occ3?oll`c`04oll`c`03o`000?o^4Nko
kQ7^00KokQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oY5^WojAKY00_ojAKY0ol00009okY5
^P03o`000?m@[e3o000000_oE:]D00?o0000oaGZ5Ol000002_l<l``00ol0003o0?l0o`00000?o`Sg
2003o`000?l>l@ko3_4>00;o3_4>00?o0000obOH9olWf2L02olWf2L00ol0003o=</docC;=006ocC;
=003o`000?m3_4?o@ka300Ko@ka300?o0000ohUfROn9MXT02On9MXT01?l0003o^4NhokQ7^?nhAkP7
o`0000;oTVfB00?o0000oll`coo?<<l00oo?<<l00ol0003okQ7^onhAkP05onhAkP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oY5^WojAKY00SojAKY0ol00003onDJi@03o`000?njAK[o^TFj00Oo^TFj00?o0000oeB[
E?mDZe@02omDZe@00ol0003o3?<<o`cc300:o`cc3003o`000?l8m`So2?L800go2?L800?o0000o`ka
3_l>l@h01?l>l@h00ol0003o9mPWobOH9`09obOH9`03o`000?ldbcCo=</d00So=</d00?o0000od>l
@om3_4<00om3_4<2o`0000coRGJ900?o0000okQ7^?nhAkP02?nhAkP<o`0000?okQ7^0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onTFjOoY5^T01_oY5^T3o`0000OoiA[U00?o0000okY5^_njAKX01_njAKX00ol0003o
E:]DoeB[E00;oeB[E003o`000?l<l`co3?<<00Wo3?<<0_l0000>o`Sg2003o`000?l>l@ko3_4>00Go
3_4>00?o0000obOH9olWf2L02OlWf2L00ol0003o=</docC;=009ocC;=003o`000?m3_4?o000000;o
00000_mnPGh00ol0003oRGJ9ohUfR@08ohUfR@03o`000?nhAkSo^4Nh00co^4Nh00?o0000onTFjOoY
5^T01_oY5^T3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003ojAKYonTFj@03onTFj@?o00002ooU6^D00ol0003o^TFj
okY5^P04okY5^P03o`000?mDZeCoE:]D00_oE:]D0ol00007o`cc30?o000000?o2o@;o`000?l8m`P0
3Ol8m`P00ol0003o3_4>o`ka3P06o`ka3P03o`000?lWf2Oo9mPW00So9mPW00?o0000ocC;=?ldbc@0
2_ldbc@00ol0003oOX5nogj1OP04ogj1OP03o`000?n9MXWoRGJ900OoRGJ900?o0000okQ7^?nhAkP0
2onhAkP00ol0003ojAKYonTFj@08onTFj@03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onTFjOl0
003o0000o`0000ooiA[U00?o0000okY5^_njAKX00onjAKX>o`0000?o@Ki10_l00002o`cc30?o0000
1Ol;m0/00ol0003o2?L8o`Sg200:o`Sg2003o`000?l>l@ko3_4>00Oo3_4>00?o0000obOH9olWf2L0
2?lWf2L00ol0003o=</docC;=00:ocC;=003o`000?mnPGkoOX5n00GoOX5n00?o0000ohUfROn9MXT0
1_n9MXT00ol0003o^4NhokQ7^00;okQ7^003o`000?oY5^WojAKY00SojAKY00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;oiA[U00?o0000okY5^_njAKX00_njAKX00ol0003oXUfRoj9M
XP0:oj9MXP03o`000?m1_T7o@Ki100?o@Ki10_l00009o`_d2`03o`000?l8m`So2?L800Wo2?L800?o
0000o`ka3_l>l@h02?l>l@h2o`0000So9mPW00?o0000ocC;=?ldbc@02Oldbc@00ol0003oOX5nogj1
OP07ogj1OP03o`000?n9MXWoRGJ900CoRGJ900?o0000okQ7^?nhAkP02onhAkP00ol0003ojAKYonTF
j@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oiA[UonDJi@0?onDJi@?o000000?o^TFj
o`000?nRGJ802onRGJ800ol0003o@Ki1od6n@@04od6n@@03o`000?l;m0_o2o@;00Wo2o@;00?o0000
o`Sg2?l8m`P01ol8m`P00ol0003o3_4>o`ka3P09o`ka3P04o`000?lDjaCo0000o`0000Ko9mPW00?o
0000ocC;=?ldbc@02Oldbc@00ol0003oOX5nogj1OP08ogj1OP03o`000?n9MXWoRGJ900?oRGJ900?o
0000okQ7^?nhAkP02onhAkP00ol0003ojAKYonTFj@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oiA[UonDJi@0<onDJi@;o00000ooS7><2o`0000coXUfR00?o0000od6n@Om1_T401?m1_T40
0ol0003o2o@;o`_d2`0:o`_d2`Wo00002ol>l@h00ol0003o5>/DoaC[5002oaC[50?o00000_lWf2L0
0ol0003o=</docC;=00:ocC;=003o`000?mnPGkoOX5n00WoOX5n00?o0000ohUfROn9MXT00_n9MXT0
0ol0003o^4NhokQ7^00:okQ7^003o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oU6^D2o`0000GohacS00?o0000ok]4^ol000002_nRGJ800ol0003o@Ki1od6n@@06od6n
@@03o`000?l;m0_o2o@;00Wo2o@;00?o0000o`7n0Ol1oP401Ol1oP400ol0003o3_4>o`ka3P09o`ka
3P03o`000?lDjaCo5>/D00Go5>/D0ol00009ocC;=0?o00003OmnPGh01Ol0003oRGJ9ohUfROn9MXWo
000000co^4Nh00?o0000onTFjOoY5^T02OoY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onDJ
iOoU6^D01OoU6^D2o`0000OohacS00Co0000ok]4^onkA;_o00002OnRGJ800ol0003o@Ki1od6n@@06
od6n@@03o`000?l;m0_o2o@;00So2o@;00?o0000o`7n0Ol1oP401ol1oP400ol0003o3_4>o`ka3P07
o`ka3P03o`000?lDjaCo5>/D00So5>/D0ol00002ocC;=0Go00000_mMXUd00ol0003oOX5nogj1OP0<
ogj1OP03o`000?n9MXWo000000co^4Nh00?o0000onTFjOoY5^T02_oY5^T00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onDJiOoU6^D00_oU6^D2o`0000SohacS00?o0000ok]4^onkA;/00_nkA;/5o`00
00CoXUfR00?o0000od6n@Om1_T401_m1_T400ol0003o2o@;o`_d2`08o`_d2`03o`000?l1oP7o0Oh1
00Oo0Oh100?o0000o`ka3_l>l@h01ol>l@h00ol0003o5>/DoaC[5008oaC[5003o`000?lZeB[o:]DZ
00;o00002?mMXUd00ol0003oOX5nogj1OP0<ogj1OPCo00002_nhAkP00ol0003ojAKYonTFj@0:onTF
j@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oiA[Uo`000?l0000:on<Lh`03o`000?nkA;_o^dBk
00;o^dBk00?o0000oh1oP?n0Oh000_n0Oh04o`0000Wo@Ki100?o0000o`_d2ol;m0/02?l;m0/00ol0
003o0Oh1o`7n0@08o`7n0@03o`000?l>l@ko3_4>00Go3_4>00?o0000oaC[5?lDja@02?lDja@01Ol0
003o:]DZob[E:_lZeB[o000000[oGJ9M0ol0000;ogj1OP04o`000?oJ9M[ofRGJomXUfPCo00001Onh
AkP00ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ohacSon<Lh`0:
on<Lh`03o`000?nkA;_o^dBk00?o^dBk00?o0000oh1oP?n0Oh001?n0Oh000ol0003o@Ki1od6n@@07
od6n@@03o`000?l;m0_o2o@;00Ko2o@;0_l0000;o`7n0@03o`000?l>l@ko3_4>00Go3_4>00?o0000
oaC[5?lDja@02?lDja@00ol0003o:]DZob[E:P02ob[E:P03o`000?mMXUgoGJ9M00OoGJ9M00?o0000
oj]DZon[E:/01?l00006ogj1OP03o`000?oJ9M[ofRGJ00KofRGJ0ol00002okQ7^003o`000?oY5^Wo
jAKY00_ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oS7>?ohacS00WohacS00?o0000ok]4
^onkA;/01?nkA;/00ol0003oP7n0oh1oP005oh1oP003o`000?m1_T7o@Ki100Oo@Ki100?o0000o`_d
2ol;m0/00_l;m0/3o`000003oaWV6Ol0003o0Oh100[o0Oh100?o0000o`ka3_l>l@h01Ol>l@h00ol0
003o5>/DoaC[5007oaC[5003o`000?lZeB[o:]DZ00?o:]DZ00?o0000oefRGOmMXUd01omMXUd00ol0
003oZeB[oj]DZ`04oj]DZ`?o00000_mnPGh00ol0003ofRGJomXUfP0:omXUfP;o00003_oY5^T00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000on<LhooS7><02OoS7><00ol0003o^dBkok]4^`04ok]4^`03
o`000?n0Oh3oP7n000KoP7n00_l00007od6n@@03o`000?l;m0_o000000;o00001OlIiQT00ol0003o
0Oh1o`7n0@08o`7n0@?o00001?l>l@h00ol0003o5>/DoaC[5008oaC[5003o`000?lZeB[o:]DZ00Co
:]DZ00?o0000oefRGOmMXUd01_mMXUd00ol0003oZeB[oj]DZ`07oj]DZ`;o00003_oJ9MX00ol0003o
jAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ohacSon<Lh`08on<Lh`03o`00
0?nkA;_o^dBk00Go^dBk00?o0000oh1oP?n0Oh001?n0Oh000ol0003oN8MhogR7N003o`0000Co@Ki1
0_l00008oaWV6@03o`000?l1oP7o0Oh100Oo0Oh100Co0000obkA;_l^dBko;]4^0ol000000ol>l@ko
0000oaC[5009oaC[5003o`000?lZeB[o:]DZ00Co:]DZ00?o0000oefRGOmMXUd01OmMXUd00ol0003o
ZeB[oj]DZ`09oj]DZ`03o`000?oJ9M[ofRGJ00gofRGJ00?o0000onTFjOoY5^T02_oY5^T00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000on<LhooS7><01ooS7><00ol0003o^dBkok]4^`06ok]4^`03o`00
0?n0Oh3oP7n000?oP7n000?o0000ogR7N?mhQgP01?mhQgP2o`000003od6n@Ol0003o6NHI00[o6NHI
00?o0000o`7n0Ol1oP401Ol1oP400ol0003o;]4^obkA;P05obkA;P03o`000?lDjaCo5>/D00Oo5>/D
0ol00007ob[E:P03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oj]DZon[E:/02On[E:/00ol0003ofRGJ
omXUfP0=omXUfP03o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oS
7>?ohacS00GohacS0ol00009ok]4^`05o`000?n0Oh3oP7n0oh1oP?l000002OmhQgP00ol0003o6NHI
oaWV6@0;oaWV6@03o`000?l1oP7o0Oh100?o0Oh100?o0000obkA;_l^dBh01_l^dBh00ol0003o5>/D
oaC[5006oaC[5005o`000?lcc3?o<l`coc?<<ol000001olZeBX00ol0003oGJ9MoefRG@03oefRG@03
o`000?n[E:_oZeB[00WoZeB[00?o0000omXUf_oJ9MX03_oJ9MX00ol0003ojAKYonTFj@09onTFj@03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ohacSo`000004o`0000;ok1?/00?o0000ok]4^onkA;/0
1onkA;/01?l0003oP7n0oh1oP?l00009ogR7N0;o00003OlIiQT00ol0003o0Oh1o`7n0@02o`7n0@03
o`000?l^dBko;]4^00So;]4^00?o0000oaC[5?lDja@00olDja@2o`0000Go<l`c00?o0000ob[E:_lZ
eBX01?lZeBX00ol0003oGJ9MoefRG@03oefRG@03o`000?n[E:_oZeB[00WoZeB[00?o0000omXUf_oJ
9MX03_oJ9MX00ol0003ojAKYonTFj@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sok1?/
00?o0000ok]4^onkA;/01_nkA;/00ol0003oP7n0o`000009ogR7N004o`000?mEZUGoEJYEo`0000go
6NHI00Co0000o`7n0Ol1oP7o00003?l^dBh01Ol0003o5>/DoaC[5?lDjaCo000000So<l`c0_l00005
ob[E:P03o`000?mMXUgoGJ9M00;oGJ9M00?o0000oj]DZon[E:/02On[E:/00ol0003ofRGJomXUfP0>
omXUfP03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/4ncok1?/
00Ook1?/00?o0000ok]4^onkA;/01onkA;/00ol0003oN8MhogR7N007ogR7N003o`000?mEZUGoEJYE
00;oEJYE00?o0000oaWV6OlIiQT02_lIiQT00ol0003o0Oh1o`00000>obkA;P03o`000?lDjaCo0000
00_o<l`c00?o0000ob[E:_lZeBX00_lZeBX01Ol0003oGJ9MoefRGOmMXUgo000000coZeB[00?o0000
omXUf_oJ9MX03_oJ9MX3o`0000WojAKY00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o/4ncok1?/
00Wok1?/00?o0000ok]4^onkA;/01_nkA;/00ol0003oN8MhogR7N006ogR7N003o`000?mEZUGoEJYE
00?oEJYE00?o0000oaWV6OlIiQT02olIiQT00ol0003o;]4^obkA;P0>obkA;P03o`000?lcc3?o<l`c
00_o<l`c0_l00003ob[E:P04o`000?mMXUgoGJ9Mo`0000[oZeB[0ol0000>omXUfP;o00000ool0o`2
o`0000OojAKY00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o/4ncok1?/00[ok1?/00?o0000ok]4
^onkA;/01?nkA;/00ol0003oN8MhogR7N006ogR7N003o`000?mEZUGoEJYE00GoEJYE00?o0000oaWV
6OlIiQT01olIiQT3o`00017o;]4^00?o0000oc?<<olcc3<03Olcc3<01Ol0003o:]DZob[E:_l0003o
GJ9M00Co00000on[E:/5o`0000;oiQWV00?o0000omXUf_oJ9MX02_oJ9MX2o`0000Ooo0?l0_l00004
onTFj@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ok1?/on`Ck00;on`Ck003o`000?nkA;_o^dBk
00Co^dBk00?o0000ogR7N?mhQgP01OmhQgP00ol0003oEJYEoeFZE@06oeFZE@03o`000?lIiQWo6NHI
00Co6NHI0ol00002ob7N8@03o`000?l^dBko;]4^00oo;]4^0_l0000?oc?<<`04o`000?lZeB[o0000
o`0000CoUVVF0ol00008onHIiP03o`000?oJ9M[ofRGJ00OofRGJ0_l0000;oo`3o0;o00000_oY5^T0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000on`Ck?o/4n`03?o/4n`6o`0000OoN8Mh00?o0000oeFZ
EOmEZUD02?mEZUD00ol0003o6NHIoaWV6@03o`0000Ko8MhQ00?o0000obkA;_l^dBh03Ol^dBh01?l0
003o?l0ooco0?ol0000?oc?<<`03o`000?nFJIKoUVVF00GoUVVF00?o0000onHIi_oV6NH02?oV6NH0
0ol0003ofRGJomXUfP05omXUfP03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o/4n`00ol0003o`Sg2ol8m`P04ol8m
`P03o`000?mhQgSoN8Mh00?oN8Mh00?o0000oeFZEOmEZUD02_mEZUD2o`0000[o8MhQ00?o0000obkA
;_l^dBh02ol^dBh00ol0003o?l0ooco0?`02oco0?`03o`000?lcc3?o<l`c00_o<l`c0_l00007oiIY
UP03o`000?oV6NKoiQWV00WoiQWV00?o0000omXUf_oJ9MX00_oJ9MX2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000on`Ck?o/4n`02oo/4n`00ol0003o`Sg2ol8m`P06ol8m`P05o`000?mhQgSoN8MhogR7
N?l000003OmEZUD00ol0003o8MhQob7N8@0:ob7N8@03o`000?l^dBko;]4^00Wo;]4^00?o0000oco0
?olo`3l01?lo`3l00ol0003o<l`coc?<<`08oc?<<`;o000000?oBKI9o`000?nFJIH01onFJIH00ol0
003oiQWVonHIiP09onHIiP04o`000?oJ9M[o0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?o/4ncok1?/
00Wok1?/00?o0000ol8m`_o2?L802?o2?L800ol0003oN8Mho`00000=oeFZE@03o`000?lQgR7o8MhQ
00_o8MhQ00?o0000obkA;_l^dBh02?l^dBh00ol0003o?l0ooco0?`06oco0?`03o`000?lcc3?o<l`c
00Go<l`c0_l00003odVfB@03o`000?nFJIKoUVVF00KoUVVF00?o0000onHIi_oV6NH02_oV6NH00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003ok1?/on`Ck007on`Ck003o`000?o2?L;o`Sg200[o`Sg200?o0000oeFZEOmE
ZUD03?mEZUD00ol0003o8MhQob7N8@0<ob7N8@03o`000?l^dBko;]4^00Ko;]4^00?o0000oco0?olo
`3l02?lo`3l00ol0003o<l`coc?<<`02oc?<<`;o00001_m9]TT00ol0003oUVVFoiIYUP05oiIYUP03
o`000?oV6NKoiQWV00[oiQWV00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/4ncok1?/00Gok1?/
00?o0000ol8m`_o2?L803?o2?L82o`0000coEJYE00?o0000ob7N8OlQgR403OlQgR400ol0003o;]4^
obkA;P04obkA;P03o`000?lo`3oo?l0o00[o?l0o00Co0000oc?<<ol0003o00002?m9]TT00ol0003o
UVVFoiIYUP06oiIYUP03o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_o/4n`00ol0003o`Sg2ol8m`P0=ol8m`P03o`000?mgR7Oo000000;o00002?mEZUD00ol0003o8MhQ
ob7N8@0?ob7N8@Ko00003_lo`3l00ol0003oBKI9odVfB@08odVfB@03o`000?nFJIKoUVVF00KoUVVF
00?o0000onHIi_oV6NH02OoV6NH00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000onl@koo_4>ooka3_
0_l0000?ol8m`P03o`000?mgR7OoMhQg00?oMhQg0ol00005oeFZE@;o00004?lQgR401_l0003o5nPG
oaOX5ol0003o2o@;o`0000ko?l0o00?o0000odVfBOm9]TT02Om9]TT00ol0003oUVVFoiIYUP05oiIY
UP03o`000?oV6NKoiQWV00WoiQWV00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000onl@koo_4>l00oo_4>l00ol0003o
`Sg2ol8m`P0=ol8m`P03o`000?mgR7OoMhQg00KoMhQg0ol000001?mEZUGo0000obkA;_l^dBh3o`00
00co8MhQ00Go0000oaOX5olGj1Oo5nPGo`000002o`_d2`03o`000?lo`3oo?l0o00_o?l0o00?o0000
odVfBOm9]TT02Om9]TT00ol0003oUVVFoiIYUP06oiIYUP03o`000?oV6NKoiQWV00SoiQWV0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003oka3_onl@k`04onl@k`oo00003?mgR7L00ol0003o;]4^obkA;P04obkA
;P?o00002?lQgR400ol0003o5nPGoaOX5`02oaOX5`05o`000?l;m0_o2o@;o`_d2ol000003?lo`3l0
0ol0003oBKI9odVfB@09odVfB@03o`000?nFJIKoUVVF00GoUVVF3?l00002oo@;m0;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oka3_onl@k`05onl@k`03o`000?o3?<?o`cc300_o`cc300?o0000ogN8
MomgR7L02_mgR7L00ol0003o;]4^obkA;P07obkA;P;o00001OlQgR400ol0003o5nPGoaOX5`03oaOX
5`03o`000?l;m0_o2o@;00;o2o@;00?o0000oco0?olo`3l02Olo`3l00ol0003oBKI9odVfB@0:odVf
B@03o`000?nFJIKoUVVF00?oUVVF00?o0000om/TfooK9=/02OoK9=/00ol0003om0_doo@;m002oo@;
m0;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oka3_onl@k`06onl@k`03o`000?o3?<?o`cc300[o
`cc300?o0000ogN8MomgR7L02omgR7L00ol0003o;]4^obkA;P09obkA;P?o000000?o8MhQo`000?lG
j1L01OlGj1L00ol0003o2o@;o`_d2`03o`_d2`03o`000?lo`3oo?l0o00So?l0o3_l00003oiIYUP;o
00002ooK9=/00ol0003om0_doo@;m005oo@;m003o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000onl@koo_4>l01Oo_4>l00ol0003ocS7>o`00000;ol<l``03o`000?mgR7OoMhQg00[oMhQg
0_l0000>obkA;P03o`000?lGj1Oo5nPG00Go5nPG00?o0000o`_d2ol;m0/00ol;m0/00ol0003o?l0o
oco0?`08oco0?`03o`000?nBKI;oTVfB00_oTVfB00?o0000oiIYU_l000003OoK9=/00ol0003om0_d
oo@;m006oo@;m0;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o_4>ooka3_00Koka3_00Co
0000olhac_o><Lko00002_o3?<<00ol0003oMhQgogN8M`09ogN8M`03o`000?m@[e3o000000ko;]4^
00?o0000oaOX5olGj1L01OlGj1L00ol0003o2o@;o`_d2`04o`_d2`03o`000?lo`3oo?l0o00Ko?l0o
00?o0000oi9]T_nBKI803OnBKI800ol0003ofbCKom/Tf`0<om/Tf`03o`000?od2oCom0_d00Som0_d
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o_4>ooka3_00Goka3_00?o0000olhac_o><Lh00_o>
<Lh00ol0003o`cc3ol<l``06ol<l``03o`000?mgR7OoMhQg00SoMhQg0_l00003oe2_D003o`000?l^
dBko;]4^00_o;]4^00?o0000oaOX5olGj1L01OlGj1L00ol0003o2o@;o`_d2`05o`_d2`03o`000?lo
`3oo?l0o00Go?l0o00?o0000oi9]T_nBKI803OnBKI800ol0003ofbCKom/Tf`0;om/Tf`03o`000?od
2oCom0_d00Wom0_d00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o_4>ooka3_00Koka3_00?o0000
olhac_o><Lh00oo><Lh00ol0003o`cc3ol<l``05ol<l``03o`000?mgR7OoMhQg00OoMhQg00?o0000
oe2_D?m@[e000om@[e000ol0003o;]4^obkA;P0:obkA;P03o`000?lGj1Oo5nPG00Ko5nPG00?o0000
o`_d2ol;m0/01_l;m0/00ol0003o?l0ooco0?`04oco0?`03o`000?nBKI;oTVfB00goTVfB3ol0000;
oo@;m003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o_4>ooka3_00Koka3_00?o0000olhac_o><Lh01Oo><Lh00ol0
003o`cc3ol<l``04ol<l``03o`000?mgR7OoMhQg00GoMhQg0_l00006oe2_D003o`000?l^dBko;]4^
00Wo;]4^0_l00008oaOX5`03o`000?l;m0_o2o@;00Ko2o@;1Ol000000olo`3oo0000oi9]TP0?oi9]
TP03o`000?oM8]gogB;M00_ogB;M00?o0000oo@;m?od2o@02Ood2o@00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o_4>ooka3_00Koka3_00?o0000olhac_o><Lh01_o><Lh00ol0003o
`cc3ol<l``04o`0000KoMhQg00?o0000oe2_D?m@[e001om@[e000ol0003o;]4^obkA;P05obkA;P?o
000000?o7N8Mo`000?lGj1L01olGj1L00ol0003o2o@;o`_d2`05o`_d2`03o`000?m=/TgoCK9=00?o
CK9=0_l0000?oi9]TP;o00003OoM8]d00ol0003om0_doo@;m008oo@;m003o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000Woka3_00?o0000olhac_o><Lh01oo><Lh2o`0000CoYeRW00Co0000ogN8MomgR7Oo
MhQg0_l0000:oe2_D003o`000?l^dBko;]4^00;o;]4^0ol00005oagR7@03o`000?lGj1Oo5nPG00Go
5nPG00?o0000o`_d2ol;m0/01?l;m0/00ol0003oCK9=odfbC@06odfbC@03o`000?nBKI;oTVfB00[o
TVfB0_l00002oke2_@03o`000?oM8]gogB;M00[ogB;M00?o0000oo@;m?od2o@02?od2o@00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000onl@koo_4>l01_o_4>l00ol0003ocS7>olhacP08olhacP03o`00
0?nWF:OoYeRW00CoYeRW00?o0000ogN8Mol000003?m@[e000ol0003o;]4^o`000002o`0000Wo7N8M
00?o0000oaOX5olGj1L01?lGj1L00ol0003o2o@;o`_d2`03o`_d2`03o`000?m=/TgoCK9=00SoCK9=
1_l00004oi9]TP;o00001Onm@[d00ol0003ogB;MomdRg@09omdRg@03o`000?od2oCom0_d00Som0_d
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o_4>ooka3_00Goka3_00?o0000olhac_o><Lh01oo>
<Lh00ol0003oYeRWojMHY`06ojMHY`03o`000?m@[e3oD:m@00coD:m@00?o0000oagR7OlMhQd02_lM
hQd00ol0003o5nPGoaOX5`04oaOX5`04o`000?l;m0_o2o@;o`_d2`;o00002om=/Td00ol0003oV6NH
oiQWV003oiQWV0Co00002?nm@[d00ol0003ogB;MomdRg@08omdRg@03o`000?od2oCom0_d00Oom0_d
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000onl@koo_4>l00oo_4>l00ol0003ocS7>olhacP07olhacP03o`000?nW
F:OoYeRW00OoYeRW00?o0000oe2_D?m@[e003?m@[e000ol0003o7N8MoagR7@0;oagR7@03o`000?lG
j1Oo5nPG00?o5nPG00Co0000o`_d2ol;m0_o00003Om=/Td00ol0003oV6NHoiQWV006oiQWV003o`00
0?nm@[go_D:m00Oo_D:m00?o0000omdRgOoM8]d01ooM8]d00ol0003om0_doo@;m006oo@;m004o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o_4>ooka3_00;oka3_00?o0000olhac_o><Lh0
1_o><Lh00ol0003oYeRWojMHY`09ojMHY`03o`000?m@[e3oD:m@00WoD:m@0_l0000>oagR7@?o0000
0olGj1L00ol0003o2o@;o`00000=odfbC@03o`000?nHIiSoV6NH00OoV6NH00?o0000oke2_Onm@[d0
2?nm@[d:o`0000Kom0_d0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000OocS7>00?o
0000ojMHYonWF:L02_nWF:L00ol0003oD:m@oe2_D006oe2_D0;o000000?oB;M8o`000?lMhQd02olM
hQd2o`0000?o?<<l1Ol0000>odfbC@03o`000?nHIiSoV6NH00OoV6NH00?o0000oke2_Onm@[d02?nm
@[d00ol0003oiQWVonHIiP06onHIiP03o`000?od2oCom0_d00?om0_d00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003oiA[UonDJi@03onDJi@Co00000_o><Lh00ol0003oYeRWojMHY`0;
ojMHY`03o`000?m@[e3oD:m@00?oD:m@0ol00004odRgB003o`000?lMhQgo7N8M00Oo7N8M0_l00008
occ3?003o`000?m=/TgoCK9=00goCK9=00?o0000oiQWV?nHIiP02?nHIiP00ol0003o_D:moke2_@07
oke2_@03o`000?oV6NKoiQWV00OoiQWV0ol000000ood2oCo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oU6^GoiA[U00OoiA[U0_l0000?ojMHY`03o`000?m@[e3oD:m@00;o00002?m8]dP00ol0
003o7N8MoagR7@05oagR7@03o`000?ll`cco?<<l00So?<<l00?o0000odfbCOm=/Td03Om=/Td00ol0
003oV6NHoiQWV008oiQWV003o`000?nm@[go_D:m00Ko_D:m00?o0000onHIi_oV6NH02?oV6NH01?l0
003om@[eooD:mOl0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiA[UonDJi@09onDJ
i@03o`000?nWF:OoYeRW00koYeRW0_l0000;odRgB003o`000?lMhQgo7N8M00;o7N8M0_l0000;occ3
?003o`000?m=/TgoCK9=00goCK9=00?o0000oiQWV?nHIiP02?nHIiP00ol0003o_D:moke2_@06oke2
_@03o`000?oV6NKoiQWV00OoiQWV00Go0000ooD:mOoe2_Gom@[eo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003oiA[UonDJi@0:onDJi@03o`000?nWF:OoYeRW00goYeRW0_l0000<odRgB004o`000?lMhQgo0000
o`0000go?<<l00?o0000odfbCOm=/Td03?m=/Td00ol0003oV6NHoiQWV009oiQWV003o`000?nm@[go
_D:m00Ko_D:m00?o0000onHIi_oV6NH01_oV6NH00ol0003om@[eooD:m@03ooD:m@03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003oiA[UonDJi@0:onDJi@03o`000?nWF:OoYeRW00coYeRW00Co0000ohac
S?n<Lhco00003?m8]dP00ol0003o?<<locc3?00>occ3?003o`000?m=/TgoCK9=00SoCK9=1?l0000;
oiQWV003o`000?nm@[go_D:m00Ko_D:m00?o0000onHIi_oV6NH01OoV6NH00ol0003om@[eooD:m@04
ooD:m@03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiA[UonDJi@0;onDJi@03o`000?nWF:OoYeRW
00_oYeRW00?o0000ohacS?n<Lh`00_n<Lh`00ol0003oB;M8odRgB009odRgB003o`000?ll`cco?<<l
00ko?<<l00Co0000odfbCOm=/TgoCK9=1ol00003ofNHI`03o`000?nHIiSoV6NH00WoV6NH00?o0000
oke2_Onm@[d01_nm@[d00ol0003oiQWVonHIiP04onHIiP03o`000?oe2_Gom@[e00Kom@[e00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oU6^GoiA[U00coiA[U00?o0000ojMHYonWF:L02_nWF:L00ol0
003oS7><ohacS003ohacS003o`000?m8]dSoB;M800SoB;M800?o0000occ3??ll`c`03_ll`c`4o`00
00_oIiQW00?o0000oiQWV?nHIiP02?nHIiP00ol0003o_D:moke2_@05oke2_@03o`000?oV6NKoiQWV
00GoiQWV00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onDJiOoU
6^D03?oU6^D7o`0000GoYeRW00?o0000ohacS?n<Lh`01On<Lh`00ol0003oB;M8odRgB007odRgB003
o`000?ll`cco?<<l00ko?<<l00?o0000ofNHIomWV6L03OmWV6L00ol0003oV6NHoiQWV008oiQWV003
o`000?nm@[go_D:m00Co_D:m00?o0000onHIi_oV6NH01?oV6NH00ol0003om@[eooD:m@07ooD:m@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003oiA[UonDJi@0=onDJi@03o`000?o6>LKoaSW600CoaSW6
1Ol00009ohacS003o`000?m8]dSoB;M800KoB;M800?o0000occ3??ll`c`03_ll`c`00ol0003oIiQW
ofNHI`0=ofNHI`03o`000?nHIiSoV6NH00SoV6NH00Co0000oke2_Onm@[go_D:m1Ol00004onHIiP03
o`000?oe2_Gom@[e00Wom@[e1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=onDJi@03o`000?o6>LKoaSW600WoaSW6
0_l00009ohacS003o`000?m8]dSoB;M800KoB;M800?o0000occ3??ll`c`03?ll`c`00ol0003oIiQW
ofNHI`0?ofNHI`Ko00001?nHIiP4o`0000Goh1oP0_l000000ooV6NKo0000ooD:m@0;ooD:m@04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?oa3_7ol@kaoo4>l@?o00002_oU6^D00ol0003o
aSW6olHiaP09olHiaP03o`000?nNHIko000000;o00001on<Lh`00ol0003oB;M8odRgB005odRgB003
o`000?ll`cco?<<l00So?<<l1Ol0000AofNHI`03o`000?nXEjSoZ5NX00?oZ5NX1?l0000;on0Oh003
o`000?oe2_Gom@[e00[om@[e00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000oo4>lOoa3_401Ooa3_42o`0000OoiA[U
00?o0000olHia_o6>LH02_o6>LH00ol0003oWV6NoiiQWP02oiiQWP?o00001On<Lh`00ol0003oB;M8
odRgB004odRgB004o`000?ll`cco?<<locc3?0Oo00001?mFZEH00ol0003oIiQWofNHI`0>ofNHI`03
o`000?nXEjSoZ5NX00OoZ5NX00?o0000on0Oh?oP7n002OoP7n000ol0003om@[eooD:m@09ooD:m@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003ol@kaoo4>l@08oo4>l@;o00001?oU6^D00ol0003oaSW6
olHiaP0;olHiaP03o`000?nNHIkoWV6N00GoWV6N0ol00003ohacS004o`000?m8]dSoB;M8odRgB0Ko
00003?mFZEH00ol0003oIiQWofNHI`0=ofNHI`03o`000?nXEjSoZ5NX00OoZ5NX00?o0000on0Oh?oP
7n002_oP7n000ol0003om@[eooD:m@08ooD:m@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo4>l@?o000000?oiA[Uo`000?o6>LH0
3?o6>LH00ol0003oWV6NoiiQWP08oiiQWP?o000000CoS7><o`000?l0003o00000_nKI9/00ol0003o
EZUFoeJYEP0=oeJYEP03o`000?mWV6OoIiQW00coIiQW00?o0000ojQGZ?nXEjP02?nXEjP00ol0003o
h1oPon0Oh00;on0Oh003o`000?oe2_Gom@[e00Kom@[e00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
l@ka00?o0000olHia_o6>LH03?o6>LH00ol0003oWV6NoiiQWP0;oiiQWP03o`000?nKI9_oVfBK00?o
VfBK00?o0000oeJYE_mFZEH03?mFZEH00ol0003oGJ9Mo`00000=ofNHI`03o`000?nXEjSoZ5NX00So
Z5NX00?o0000on0Oh?oP7n003?oP7n03o`0000Gom@[e00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oa3_7ol@ka00col@ka00?o0000olHia_o6>LH03?o6>LH00ol0003oWV6NoiiQWP0:oiiQWP03o`00
0?nKI9_oVfBK00GoVfBK00?o0000oeJYE_mFZEH02_mFZEH01?l0003oGJ9MoefRGOmMXUd2o`0000[o
IiQW00?o0000ojQGZ?nXEjP02OnXEjP00ol0003oh1oPon0Oh00<on0Oh003o`000?og2?Oom`Sg00?o
000000?om@[eo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000olHia_o6>LH0
3?o6>LH00ol0003oWV6NoiiQWP09oiiQWP03o`000?nKI9_oVfBK00KoVfBK00?o0000oeJYE_mFZEH0
2OmFZEH00ol0003oGJ9MoefRG@02oefRG@03o`000?nLHico000000;o00001omWV6L00ol0003oZ5NX
ojQGZ009ojQGZ003o`000?oP7n3oh1oP00_oh1oP00?o0000ooL8moog2?L01?og2?L00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo4>lOoa3_402ooa3_400ol0003oaSW6olHiaP0;olHiaP03o`000?nN
HIkoWV6N00SoWV6N00?o0000oi]TVonKI9/01onKI9/00ol0003oEZUFoeJYEP08oeJYEP03o`000?mM
XUgoGJ9M00?oGJ9M00?o0000oiaSW?nLHi`00_nLHi`2o`0000CoIiQW00?o0000ojQGZ?nXEjP02_nX
EjP00ol0003oh1oPon0Oh00:on0Oh003o`000?og2?Oom`Sg00Gom`Sg00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?oa3_7ol@ka00[ol@ka0ol0000;olHiaPKo00001?nNHIh00ol0003oVfBKoi]TV`08
oi]TV`03o`000?mFZEKoEZUF00OoEZUF00?o0000oefRGOmMXUd00omMXUd00ol0003oW6>LoiaSW005
oiaSW0?o000000?oIiQWo`000?nXEjP02onXEjP00ol0003oh1oPon0Oh009on0Oh003o`000?og2?Oo
m`Sg00Oom`Sg00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?oa3_7ol@ka00Wol@ka00?o0000on8M
h_oR7N801?l00006olHiaP03o`000?o6>LKoaSW600CoaSW61?l0000<oi]TV`03o`000?mFZEKoEZUF
00GoEZUF00?o0000oefRGOmMXUd01?mMXUd00ol0003oW6>LoiaSW008oiaSW003o`000?nXEjSoZ5NX
00_oZ5NX00?o0000on0Oh?oP7n002?oP7n000ol0003om`SgooL8m`08ooL8m`Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?oa3_7ol@ka00Ool@ka00?o0000on8Mh_oR7N801OoR7N83o`0000;oaSW600?o0000olHia_o6
>LH02?o6>LH00ol0003oVfBKoi]TV`0:oi]TV`03o`000?mFZEKoEZUF00CoEZUF00?o0000oefRGOmM
XUd01OmMXUd00ol0003oW6>LoiaSW008oiaSW003o`000?nXEjSoZ5NX00WoZ5NX1?l00008on0Oh003
o`000?og2?Oom`Sg00Wom`Sg00?o0000ood2oOom0_d00_om0_d7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ol@ka
oo4>l@05oo4>l@03o`000?oR7N;ohQgR00WohQgR0_l0000<olHiaP03o`000?nKI9_oVfBK00WoVfBK
00?o0000oeJYE_mFZEH00omFZEH00ol0003oGJ9MoefRG@05oefRG@03o`000?nLHicoW6>L00[oW6>L
00?o0000ojQGZ?nXEjP01?nXEjP4o`0000CofBKI00?o0000on0Oh?oP7n001?oP7n000ol0003om`Sg
ooL8m`0:ooL8m`03o`000?om0_goo@;m00Woo@;m0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00?ol@ka00?o0000on8Mh_oR7N802ooR
7N800ol0003oaSW6olHiaP0:olHiaP03o`000?nKI9_oVfBK00WoVfBK00?o0000oeJYE_mFZEH00_mF
ZEH00ol0003oGJ9MoefRG@06oefRG@03o`000?nLHicoW6>L00[oW6>L00?o0000ojQGZ?nXEjP01?l0
0009omTVf@Ko00003?og2?L00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo4>lOoa3_7ol@ka0_l0
000=on8MhP03o`000?o6>LKoaSW600[oaSW600?o0000oi]TVonKI9/02OnKI9/01Ol0003oEZUFoeJY
E_mFZEKo000000WoGJ9M00?o0000oiaSW?nLHi`02onLHi`2o`0000gofBKI00?o0000oo@;m?od2o@0
0_od2o@00ol0003om`SgooL8m`0:ooL8m`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol@kao`00
0002ooP7n0;o00002ooR7N800ol0003oaSW6olHiaP0;olHiaP03o`000?nKI9_oVfBK00WoVfBK00?o
0000oeJYE_l000002OmMXUd00ol0003oW6>LoiaSW00<oiaSW003o`000?oI9]WofBKI00cofBKI00?o
0000oo@;m?od2o@00ood2o@00ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00goo@;m00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on0OhooP7n003ooP7n0;o00002_oR7N800ol0003oaSW6olHiaP0:olHiaP03o`000?nKI9_o
VfBK00SoVfBK1Ol00008oefRG@03o`000?nLHicoW6>L00coW6>L00?o0000omTVfOoI9]T02ooI9]T0
0ol0003om0_doo@;m005oo@;m003o`000?og2?Oom`Sg00Som`Sg00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooh1oP2o`0000SohQgR00?o0000olHia_o6>LH02_o6>LH00ol0003oVfBKoi]TV`07oi]T
V`03o`000?nLHicoW6>L00?oW6>L0ol00005oefRG@03o`000?nLHicoW6>L00_oW6>L00?o0000omTV
fOoI9]T03?oI9]T00ol0003om0_doo@;m006oo@;m003o`000?og2?Oom`Sg00Oom`Sg00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?om0_go000000Won0Oh00?o0000on8Mh_oR7N801OoR7N82o`0000co
aSW600?o0000oi]TVonKI9/01OnKI9/00ol0003oW6>LoiaSW007oiaSW0?o000000?oGJ9Mo`000?nL
Hi`03OnLHi`00ol0003ofBKIomTVf@0<omTVf@03o`000?od2oCom0_d00Kom0_d00?o0000ooL8moog
2?L01_og2?L00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ood2o@03o`000?oh1oSon0Oh00Oon0Oh
0_l00004on8MhP03o`000?oY5^WojAKY00;o00002_o6>LH00ol0003oVfBKoi]TV`03oi]TV`;o0000
3OnLHi`2o`0000goW6>L0ol0000=omTVf@03o`000?od2oCom0_d00Oom0_d00?o0000ooL8moog2?L0
1Oog2?L00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Son0Oh0_l0
00000ooR7N;o0000onTFj@04onTFj@03o`000?o6>LKoaSW600OoaSW600Co0000oi]TVonKI9_oVfBK
0_l00002olPgb003o`000?nLHicoW6>L00coW6>L3Ol00003omLXe`03o`000?oI9]WofBKI00[ofBKI
00?o0000oo@;m?od2o@02?od2o@01?l0003om`SgooL8moog2?L4o`0000koo@;m00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?om0_d00ol0003on0Oh
ooP7n009ooP7n003o`000?oY5^WojAKY00GojAKY0_l00008olHiaP03o`000?nKI9_o000000Gob3O8
00?o0000oiaSW?nLHi`02onLHi`00ol0003oZeB[oj]DZ`09oj]DZ`03o`000?oG:=OoebSG00;oebSG
0_l00009omTVf@03o`000?od2oCom0_d00[om0_d0ol00004ood2o@03o`000?om0_goo@;m00[oo@;m
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ood2
o@0:ood2o@03o`000?oh1oSon0Oh00Son0Oh00?o0000onTFjOoY5^T01ooY5^T4o`0000?oaSW60ol0
0007olPgb003o`000?nLHicoW6>L00[oW6>L00?o0000oj]DZon[E:/02On[E:/00ol0003oebSGomLX
e`04omLXe`;o00001ooI9]T00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00Goo@;m00?o
0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo@;mood2o@0:ood2o@03o`000?oh1oSon0Oh00Oon0Oh00?o0000onTFjOoY5^T02?oY5^T0
1?l0003oj1OXonPGj?oX5nP3o`0000;ogB;M00?o0000olPgb?o8=lP01_o8=lP00ol0003oW6>LoiaS
W008oiaSW003o`000?n[E:_oZeB[00[oZeB[00?o0000omLXeooG:=L01_oG:=L00ol0003ofBKIomTV
f@04omTVf@03o`000?od2oCom0_d00Wom0_d00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@07ood2o@03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?om0_go
o@;m00_oo@;m00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ojAKYonTFj@08onTFj@03o`000?oX5nSo
j1OX00Coj1OX00Go0000omdRgOoM8]gogB;Mo`000008olPgb003o`000?nLHicoW6>L00OoW6>L00?o
0000oj]DZon[E:/02_n[E:/00ol0003oebSGomLXe`07omLXe`;o00001?oI9]T00ol0003om0_doo@;
m008oo@;m003o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d01?om0_d2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7n?oh1oP00ooh1oP0
0ol0003ojAKYonTFj@08onTFj@03o`000?oX5nSoj1OX00Coj1OX00?o0000omdRgOoM8]d00_oM8]d0
0ol0003ob3O8olPgb007olPgb003o`000?nLHicoW6>L00KoW6>L00?o0000oj]DZon[E:/02_n[E:/0
0ol0003oebSGomLXe`09omLXe`05o`000?oI9]WofBKIomTVfOl000002Ood2o@00ol0003oo@;mood2
o@0;ood2o@03o`000?om0_goo@;m00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ood2oOom0_d03Oom0_d5o`0000_ojAKY00?o0000onPGj?oX5nP01?oX5nP00ol0003ogB;MomdRg@03
omdRg@03o`000?o8=lSob3O800Oob3O800?o0000oiaSW?nLHi`01OnLHi`00ol0003oZeB[oj]DZ`0:
oj]DZ`03o`000?oG:=OoebSG00WoebSG1?l00009oo@;m003o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo@;mood2o@0<ood2o@05o`000?oi1_Won@Ki
ooT6nOl000002_oY5^T00ol0003oj1OXonPGj005onPGj003o`000?oM8]gogB;M00?ogB;M00?o0000
olPgb?o8=lP02?o8=lP00ol0003oW6>LoiaSW004oiaSW003o`000?n[E:_oZeB[00WoZeB[00?o0000
omLXeooG:=L02?oG:=L2o`0000?om@[e00?o0000oo@;m?od2o@01_od2o@00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooT6nOoi1_T00ooi1_T00ol0003ojAKYonTFj@06onTFj@03o`000?oX5nSoj1OX
00Goj1OX00?o0000omdRgOoM8]d01?oM8]d00ol0003ob3O8olPgb009olPgb003o`000?nLHicoW6>L
00;oW6>L00?o0000oj]DZon[E:/02_n[E:/00ol0003oebSGomLXe`06omLXe`;o00001_oe2_D8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ood2oOom
0_d02_om0_d00ol0003on@KiooT6n@05ooT6n@03o`000?oY5^WojAKY00GojAKY00?o0000onPGj?oX
5nP01OoX5nP00ol0003ogB;MomdRg@05omdRg@03o`000?o8=lSob3O800Wob3O800Go0000oiaSW?nL
HicoW6>Lo`00000<oj]DZ`03o`000?oG:=OoebSG00CoebSG0_l00008ooD:m@03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo@;mood2o@09ood2o@03o`000?oi1_Won@Ki00Oon@Ki00?o0000onTFjOoY
5^T00ooY5^T00ol0003oj1OXonPGj006onPGj003o`000?oM8]gogB;M00GogB;M00?o0000olPgb?o8
=lP02_o8=lP00ol0003oW6>Lo`000004o`0000WoZeB[00?o0000omLXeooG:=L00_oG:=L2o`0000[o
m@[e00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ood2oOom0_d02?om0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?oY5^WojAKY00;ojAKY00?o0000onPGj?oX5nP01_oX5nP00ol0003ogB;MomdRg@07omdRg@;o0000
2oo8=lP00ol0003ohAkQon4Nh@03on4Nh@Oo00000_n[E:/00ol0003oebSGomLXe`02o`0000_om@[e
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000ooT6nOoi1_T02Ooi
1_T01Ol0003ojAKYonTFjOoY5^Wo000000Soj1OX00?o0000omdRgOoM8]d01ooM8]d00ol0003oka3_
o`000002o`0000Sob3O800?o0000on4NhOoQ7^402_oQ7^45o`0000gom@[e00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?om0_goo@;m00?oo@;m0ol0000<ooT6n@03o`000?oY5^Wo000000Woj1OX00?o
0000omdRgOoM8]d01_oM8]d00ol0003oka3_onl@k`03onl@k`?o00001?o8=lP00ol0003ohAkQon4N
h@0=on4Nh@03o`000?oe2_Gom@[e00gom@[e00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?om0_go
000000;o00000oon0Oh2o`0000_on@Ki00?o0000onPGj?oX5nP01ooX5nP00ol0003ogB;MomdRg@07
omdRg@03o`000?o_4>ooka3_00Koka3_0ol000000oo8=lSo0000on4Nh@0>on4Nh@03o`000?oe2_Go
m@[e00com@[e00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooT6
n@03o`000?oX5nSoj1OX00;oj1OX1_l00008omdRg@03o`000?o_4>ooka3_00[oka3_00?o0000on4N
hOoQ7^403ooQ7^400ol0003om@[eooD:m@0:ooD:m@;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooT6n@Go00001_oe2_D00ol0003ogB;MomdRg@05omdRg@03o`000?o_4>ooka3_00[o
ka3_00?o0000on4NhOoQ7^403ooQ7^400ol0003om@[eooD:m@07ooD:m@?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooT6n@03o`000?oe2_Gom@[e00Wom@[e00?o0000omdRgOoM
8]d00ooM8]d00ol0003oka3_onl@k`0;onl@k`03o`000?oQ7^7ohAkQ00oohAkQ00?o0000ooD:mOoe
2_D01Ooe2_D2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on@Kio`000?l00000
3Ooe2_D00ol0003ogB;MomdRg@02omdRg@03o`000?o_4>ooka3_00_oka3_5?l00004ooD:m@;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooD:m@04o`000?oM8]gogB;Mo`0000koka3_
00?o0000ooL8moog2?L04?og2?L00ol0003om@[eo`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_oe2_D00ol0003ogB;Mo`00000>onl@k`03o`00
0?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003om@[eooD:m@0=ooD:m@03o`000?o_4>ooka3_00Woka3_1Ol0
000BooL8m`;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003om@[eooD:m@0<ooD:m@03o`000?o_4>ooka3_00;oka3_1ol00004ood2o@03o`000?og2?Oo
m`Sg00oom`Sg00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?oe2_Gom@[e00com@[e1?l0000<ood2o@03o`000?og2?Oom`Sg00com`Sg0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooD:mOoe2_D03?oe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?og2?Oom`Sg00_o
m`Sg00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003om@[eooD:m@0:ooD:m@03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L02Oog2?L2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003oo@;m
ood2o@0?ood2o@03o`000?og2?Oom`Sg00Kom`Sg0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_og2?L00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000oog2?L2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooL8mol000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool03Ol00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`0;o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool02_l00?l2oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000=o`00o`03oooo0?l00?oo003o00So003o0_ooo`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000=o`00o`;oool00_l00?l<oooo00;o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
3Ol00?l2oooo00;o003o3?ooo`000ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`02o`00o`04oooo0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o
0_ooo`04o`00o`;oool01?l00?l3oooo00Co003o0_ooo`0=o`00o`;oool00_l00?l00oooo`3o003o
o`00o`04o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l0
0?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l3oooo00?o003o
00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00_o003o
0oooo`05o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo0002oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol00?l2oooo0003o`00oooo
o`3oool000So003o1Oooo`06o`00o`;oool00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`08
o`00o`04oooo0?l00?oo003oo`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol0
0?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0;
o`00o`;oool02?l00?l00oooo`3o003oo`00o`02oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2
oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00
o`;oool03?l00?l2oooo00So003o00Coool0o`00ooooo`3oool01?l00?l2oooo00Ko003o00?oool0
o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01_l00?l2oooo
01So003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o0_ooo`08o`00o`04oooo0?l00?ooool0
oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00
o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l00_l00?l00ooo
o`3o003oo`00o`04o`00o`;oool02Ol00?l3oooo00Go003o0_ooo`04o`00o`;oool01_l00?l00olb
</coool0oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool0
0?l05_l00?l5oooo00?o003o0_ooo`03o`00o`;oool02ol00?l2oooo00Ko003o0_ooo`02o`00o`;o
ool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o
1Oooo`0Po`00o`Coool03?l00?l2oooo00Oo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Ooo
ool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(350) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.993 .007 .993 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.993 .007 .993 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.993 .007 .993 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.992 .008 .992 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.969 .031 .969 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.991 .009 .991 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.969 .031 .969 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.962 .038 .962 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.944 .056 .944 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.987 .013 .987 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.934 .066 .934 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.992 .008 .992 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.868 .132 .868 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.883 .117 .883 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.988 .012 .988 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.791 .209 .791 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.917 .083 .917 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.985 .015 .985 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.988 .012 .988 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.966 .034 .966 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.623 .377 .623 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.925 .075 .925 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.822 .178 .822 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.815 .185 .815 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.855 .145 .855 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.915 .085 .915 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.946 .054 .946 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.993 .007 .993 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.792 .208 .792 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.902 .098 .902 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.691 .309 .691 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.939 .061 .939 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.9 .1 .9 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.837 .163 .837 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.895 .105 .895 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.707 .293 .707 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.928 .072 .928 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.817 .183 .817 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.995 .005 .995 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.946 .054 .946 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.738 .262 .738 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.394 .606 .394 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.469 .531 .469 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.974 .026 .974 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.975 .025 .975 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.89 .11 .89 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.993 .007 .993 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.769 .231 .769 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.775 .225 .775 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.468 .532 .468 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.467 .533 .467 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.325 .675 .325 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.745 .255 .745 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.783 .217 .783 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.993 .007 .993 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.758 .242 .758 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.664 .336 .664 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.959 .041 .959 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.518 .482 .518 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.918 .082 .918 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.861 .139 .861 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.469 .531 .469 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.345 .655 .345 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.65 .35 .65 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.086 .914 .086 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.107 .893 .107 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.235 .765 .235 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.484 .516 .484 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.48 .52 .48 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.913 .087 .913 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.185 .815 .185 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.205 .795 .205 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.783 .217 .783 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.961 .039 .961 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.992 .008 .992 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.265 .735 .265 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.327 .673 .327 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.639 .361 .639 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.991 .009 .991 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.725 .275 .725 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.339 .661 .339 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.567 .433 .567 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.088 .912 .088 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.495 .505 .495 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.294 .706 .294 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.964 .036 .964 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.09 .91 .09 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.054 .946 .054 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.871 .129 .871 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.046 .954 .046 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.02 .98 .02 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.618 .382 .618 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.918 .082 .918 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.23 .77 .23 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.045 .955 .045 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.474 .526 .474 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.101 .899 .101 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.188 .812 .188 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.937 .063 .937 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.015 .985 .015 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.128 .872 .128 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.122 .878 .122 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.795 .205 .795 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.238 .762 .238 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.309 .691 .309 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.048 .952 .048 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.065 .935 .065 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.118 .882 .118 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.027 .973 .027 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.003 .997 .003 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.35 .65 .35 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.626 .374 .626 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.991 .009 .991 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.805 .195 .805 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.179 .821 .179 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.216 .784 .216 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.385 .615 .385 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.966 .034 .966 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.093 .907 .093 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.176 .824 .176 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.641 .359 .641 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.048 .952 .048 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.992 .008 .992 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.049 .951 .049 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.887 .113 .887 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.968 .032 .968 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.623 .377 .623 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.682 .318 .682 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.104 .896 .104 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.906 .094 .906 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.006 .994 .006 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.308 .692 .308 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.486 .514 .486 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.076 .924 .076 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.249 .751 .249 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.414 .586 .414 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.992 .008 .992 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.991 .009 .991 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.941 .059 .941 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.167 .833 .167 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.149 .851 .149 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.033 .967 .033 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.851 .149 .851 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.206 .794 .206 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.96 .04 .96 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.203 .797 .203 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.214 .786 .214 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.225 .775 .225 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.67 .33 .67 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.766 .234 .766 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.608 .392 .608 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.027 .973 .027 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.176 .824 .176 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.301 .699 .301 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.584 .416 .584 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.854 .146 .854 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.992 .008 .992 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.953 .047 .953 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.206 .794 .206 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.381 .619 .381 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.196 .804 .196 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.847 .153 .847 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.75 .25 .75 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.991 .009 .991 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.6 .4 .6 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.883 .117 .883 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.958 .042 .958 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.151 .849 .151 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.269 .731 .269 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.945 .055 .945 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.173 .827 .173 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.681 .319 .681 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.556 .444 .556 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.506 .494 .506 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.385 .615 .385 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.905 .095 .905 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.866 .134 .866 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.875 .125 .875 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.905 .095 .905 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.416 .584 .416 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.967 .033 .967 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.822 .178 .822 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.384 .616 .384 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.428 .572 .428 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.992 .008 .992 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.694 .306 .694 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.551 .449 .551 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.991 .009 .991 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.962 .038 .962 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.859 .141 .859 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.958 .042 .958 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.429 .571 .429 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.936 .064 .936 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.804 .196 .804 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.728 .272 .728 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.993 .007 .993 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.701 .299 .701 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.583 .417 .583 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.993 .007 .993 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.759 .241 .759 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.987 .013 .987 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.994 .006 .994 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.599 .401 .599 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.99 .01 .99 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.658 .342 .658 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.991 .009 .991 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.789 .211 .789 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.89 .11 .89 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.818 .182 .818 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.914 .086 .914 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.934 .066 .934 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.827 .173 .827 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.687 .313 .687 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.813 .187 .813 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.894 .106 .894 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.935 .065 .935 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.912 .088 .912 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.923 .077 .923 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.988 .012 .988 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.842 .158 .842 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.96 .04 .96 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.99 .01 .99 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.969 .031 .969 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.95 .05 .95 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.852 .148 .852 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.962 .038 .962 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.935 .065 .935 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.916 .084 .916 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.99 .01 .99 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.95 .05 .95 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.992 .008 .992 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.991 .009 .991 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.991 .009 .991 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.99 .01 .99 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.992 .008 .992 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?om0_goo@;mood2oOl000004Oom
0_d01?l0003ol`ccoo<<lol0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003oo@;mood2o@02ood2o@03o`000?om
0_goo@;m00goo@;m00?o0000oo<<looc3?<00_oc3?<00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m
00[oo@;m00?o0000oo<<looc3?<01Ooc3?<00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol`ccoo<<l`06oo<<l`03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?om0_goo@;m00Ooo@;m
00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?of2OKo0000013oo@;m00?o0000ood2oOom0_d02?om
0_d9o`0000col`cc00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooH9mP03o`000?om
0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003ol0o`oo0?l005oo0?l003o`000?oc
3??ol`cc00_ol`cc0ol00003oo4>l@03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooH9m_of2OH00oof2OH00ol0003oo@;mood2o@0;ood2o@;o00002oom0_d00ol0003ol0o`oo0?l006
oo0?l003o`000?oc3??ol`cc00[ol`cc00?o0000oo4>lOoa3_401?oa3_400ol0003oo@;mood2o@0:
ood2o@04o`000?o_4>ooka3_onl@k`;o00002_om0_d2o`000003onl@kol0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003omPWfooH9mP05ooH9mP03o`000?om0_go
o@;m00Woo@;m00?o0000ooL8mol000002oom0_d00ol0003ol0o`oo0?l006oo0?l003o`000?oc3??o
l`cc00Wol`cc00?o0000oo4>lOoa3_401_oa3_400ol0003oo@;mood2o@08ood2o@03o`000?o_4>oo
ka3_00Coka3_0_l00005ood2o@?o00001?o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooH9mP03o`000?om0_goo@;m00Ooo@;m0_l00003ooL8
m`03o`000?om0_goo@;m00Ooo@;m00?o0000oo0?l?o`3o001oo`3o000ol0003ol`ccoo<<l`09oo<<
l`03o`000?oa3_7ol@ka00Ool@ka00?o0000ood2oOom0_d01Oom0_d2o`0000Woka3_0_l000000oom
0_go0000o`000007onl@k`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooH9m_of
2OH02?of2OH00ol0003oo@;mood2o@06ood2o@03o`000?og2?Oom`Sg00?om`Sg00?o0000ood2oOom
0_d01oom0_d00ol0003ol0o`oo0?l008oo0?l003o`000?oc3??ol`cc00Ool`cc00?o0000oo4>lOoa
3_402Ooa3_400ol0003oo@;mood2o@03ood2o@03o`000?o_4>ooka3_00_oka3_00?o0000onl@koo_
4>l01oo_4>l00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[eo`000005ood2o@;o00002oof2OH2o`0000Koo@;m
00?o0000ooL8moog2?L01Oog2?L00ol0003oo@;mood2o@06ood2o@03o`000?o`3o3ol0o`00Sol0o`
00?o0000oo<<looc3?<01_oc3?<00ol0003ol@kaoo4>l@0;oo4>l@05o`000?om0_goo@;mood2oOl0
00003_o_4>l00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oe2_Gom@[eooD:mOl0
00000oom0_d00ol0003omPWfooH9mP0:ooH9mP04o`000?o[5>_ojaC[o`0000?oo@;m0_l00008ooL8
m`03o`000?om0_goo@;m00Koo@;m00?o0000oo0?l?o`3o002Oo`3o000ol0003ol`ccoo<<l`05oo<<
l`03o`000?oa3_7ol@ka00col@ka00?o0000ood2oOl000003oo_4>l00ol0003oka3_onl@k`08onl@
k`03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:m@03ooD:m@03o`000?om0_go000000_o
mPWf0_l00004on/Dj`03o`000?om0_go000000_om`Sg00?o0000ood2oOom0_d01Oom0_d00ol0003o
l0o`oo0?l009oo0?l003o`000?oc3??ol`cc00Col`cc00?o0000oo4>lOoa3_403_oa3_400ol0003o
ka3_onl@k`0>onl@k`03o`000?o_4>ooka3_00Woka3_00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooD:mOoe2_D0
1?oe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?o[5>_ojaC[00GojaC[00?o0000ooL8moog2?L0
2_og2?L00ol0003oo@;mood2o@05ood2o@03o`000?o`3o3ol0o`00[ol0o`00?o0000oo<<looc3?<0
0ooc3?<00ol0003ol@kaoo4>l@0>oo4>l@03o`000?o_4>ooka3_00goka3_00?o0000onl@koo_4>l0
2_o_4>l00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:
m@05ooD:m@03o`000?of2OKomPWf00OomPWf0_l00008on/Dj`03o`000?og2?Oom`Sg00_om`Sg00?o
0000ood2oOom0_d01?om0_d00ol0003ol0o`oo0?l00:oo0?l004o`000?oc3??ol`ccoo<<l`?o0000
3ooa3_400ol0003oka3_onl@k`0>onl@k`03o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oe2_Gom@[e00Oom@[e00?o0000ooH9m_of2OH01?of2OH2o`0000_ojaC[1?l0
0009ooL8m`03o`000?om0_goo@;m00?oo@;m00?o0000oo0?l?o`3o002oo`3o001?l0003ol`cco`00
0?l00003omPWf0;o00003?oa3_42o`00013oka3_00?o0000onl@koo_4>l02oo_4>l00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003om@[e
ooD:m@07ooD:m@03o`000?of2OKomPWf00?omPWf00?o0000on/Djoo[5>/02oo[5>/01?l0003ocS7>
olhac_o><Lh5o`0000Gom`Sg00?o0000ood2oOom0_d00_om0_d00ol0003ol0o`oo0?l00<oo0?l003
o`000?oH9mSof2OH00Gof2OH0_l00008oo4>l@;o00000_oB;M800ol0003oka3_onl@k`0=onl@k`03
o`000?o_4>ooka3_00_oka3_00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003om@[eooD:m@09ooD:m@03o`000?of2OKomPWf00;o0000
3Oo[5>/00ol0003ocS7>olhacP07olhacPKo00000_om0_d4o`0000gol0o`00?o0000omPWf?oH9mP0
1ooH9mP2o`0000Gol@ka00?o0000om8]d_oB;M800ooB;M800ol0003oka3_onl@k`0<onl@k`03o`00
0?o_4>ooka3_00coka3_00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oe2_Gom@[e00Wom@[e00?o
0000ooH9m_l000003oo[5>/00ol0003ocS7>olhacP0<olhacP?o00001?oW6>L3o`0000Wol0o`00?o
0000omPWf?oH9mP02_oH9mP2o`000003oo4>lOl0003o000000OodRgB00?o0000onl@koo_4>l02oo_
4>l00ol0003oka3_onl@k`0<onl@k`03o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000
on/Djoo[5>/03_o[5>/00ol0003ocS7>olhacP0=olhacP03o`000?oW6>OoiaSW00KoiaSW0ol00005
oo0?l003o`000?oH9mSof2OH00gof2OH00?o0000om8]d_oB;M802?oB;M800ol0003oka3_onl@k`09
onl@k`03o`000?o_4>ooka3_00goka3_00Co0000ood2oOom0_goo@;m1Ol00003oo<<l`03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooD:mOoe2_D02ooe2_D2o`0000oojaC[00?o0000olhac_o><Lh03Oo><Lh00ol0003oiaSWonLHi`0:
onLHi`?o000000?ol0o`o`000?oH9mP03ooH9mP00ol0003odRgBom8]dP09om8]dP03o`000?o_4>oo
ka3_00Soka3_00?o0000onl@koo_4>l03_o_4>l3o`0000Sol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oe2_Gom@[e00Som@[e0ol000000ooL
8mco0000on/Dj`0>on/Dj`03o`000?o><LkocS7>00gocS7>00?o0000onLHiooW6>L03OoW6>L00ol0
003of2OHomPWf00?omPWf003o`000?oB;M;odRgB00[odRgB2ol0000;onl@k`Go00003?oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003olPgbo`000?on0Oko0000
00Som@[e0ol00005om`Sg003o`000?o[5>_ojaC[00cojaC[00?o0000olhac_o><Lh03Oo><Lh00ol0
003oiaSWonLHi`0=onLHi`;o00004?oH9mP00ol0003odRgBom8]dP0:om8]dP03o`000?o=</gocC;=
00OocC;=00?o0000onl@koo_4>l00_o_4>l7o`0000CodbcC00?o0000oo<<looc3?<02_oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003olPgboo8=l_ob3O82o`00
00Gom@[e0ol00009om`Sg0;o00002oo[5>/00ol0003ocS7>olhacP0=olhacP03o`000?oW6>OoiaSW
00goiaSW00Co0000ol@ka?o4>lCo00003ooH9mP00ol0003odRgBom8]dP09om8]dP03o`000?o=</go
cC;=00WocC;=1?l0000;om</d`03o`000?oc3??ol`cc00[ol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo8=l_ob3O801?ob3O800ol0003om@[eo`000002o`00
00cog2?L00Co0000okU6^Ol0003o00002Oo[5>/00ol0003ocS7>olhacP0=olhacP03o`000?oW6>Oo
iaSW00goiaSW00Go0000ol@ka?o4>lCoa3_4o`00000=omPWf003o`000?oB;M;odRgB00[odRgB00?o
0000oldbcOo=</d02Oo=</d00ol0003odbcCom</d`0<om</d`03o`000?oc3??ol`cc00[ol`cc00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo8=l_ob3O801_ob3O80
0ol0003og2?Lom`Sg00<om`Sg003o`000?niA[Wo^DJi00;o^DJi0_l00007on/Dj`03o`000?o><Lko
cS7>00cocS7>00?o0000onLHiooW6>L03OoW6>L00ol0003oa3_4ol@ka003ol@ka003o`000?oH9mSo
f2OH00[of2OH00?o0000om8]d_oB;M802_oB;M800ol0003ocC;=oldbc@09oldbc@03o`000?oC;=?o
dbcC00codbcC00?o0000oo<<looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003olPgboo8=lP06oo8=lP03o`000?oL8mcog2?L00_og2?L00?o0000okU6
^OniA[T01OniA[T00ol0003ojaC[on/Dj`03on/Dj`03o`000?o><LkocS7>00gocS7>00?o0000onLH
iooW6>L03OoW6>L00ol0003oa3_4ol@ka004ol@ka003o`000?oH9mSof2OH00Wof2OH00?o0000om8]
d_oB;M802OoB;M800ol0003ocC;=oldbc@0:oldbc@03o`000?oC;=?odbcC00codbcC00?o0000oo<<
looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
lPgboo8=lP07oo8=lP03o`000?oL8mcog2?L00_og2?L00?o0000okU6^OniA[T01_niA[T2o`0000?o
jaC[00?o0000olhac_o><Lh03Oo><Lh00ol0003oiaSWonLHi`0<onLHi`03o`000?o4>lCoa3_400Ko
a3_400?o0000omPWf?oH9mP02?oH9mP00ol0003odRgBom8]dP09om8]dP03o`000?o=</gocC;=00[o
cC;=00?o0000om</dooC;=<03?oC;=<00ol0003ol`ccoo<<l`0;oo<<l`03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo8=l_ob3O802?ob3O800ol0003og2?Lom`Sg00:om`Sg003o`00
0?niA[Wo^DJi00Wo^DJi0_l000000oo[5>_o0000olhacP0<olhacP?o00003_oW6>L00ol0003oa3_4
ol@ka007ol@ka003o`000?oH9mSof2OH00Oof2OH00?o0000om8]d_oB;M802OoB;M800ol0003ocC;=
oldbc@0;oldbc@03o`000?oC;=?odbcC00codbcC00?o0000oo<<looc3?<02_oc3?<00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ood2oOom0_d00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo8=l_ob3O802_ob3O800ol0003og2?Lom`S
g009om`Sg003o`000?niA[Wo^DJi00_o^DJi00?o0000olhac_o><Lh02_o><Lh2o`0000?oY5^T00?o
0000onLHiooW6>L02_oW6>L00ol0003oa3_4ol@ka009ol@ka003o`000?oH9mSof2OH00Kof2OH00?o
0000om8]d_oB;M802?oB;M800ol0003ocC;=oldbc@0<oldbc@03o`000?oC;=?odbcC00codbcC00?o
0000oo<<looc3?<02_oc3?<00ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@04ood2o@?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000om`Sg?oL8m`02?oL8m`0
0ol0003o^DJiokU6^@0<okU6^@03o`000?o><LkocS7>00SocS7>0_l00006ojAKY0;o00002_oW6>L0
0ol0003oa3_4ol@ka00:ol@ka003o`000?oH9mSof2OH00Gof2OH00?o0000om8]d_oB;M802?oB;M80
0ol0003ocC;=oldbc@0<oldbc@03o`000?oC;=?odbcC00codbcC00?o0000oo<<looc3?<02ooc3?<0
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d02?om0_d3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo8=lP03o`000?oL8mcog2?L00Oog2?L00?o0000okU6^OniA[T03_niA[T00ol0003ocS7>olhacP04
olhacP?o00002_nTFj@00ol0003oiaSWonLHi`07onLHi`03o`000?o4>lCoa3_400_oa3_400?o0000
omPWf?oH9mP00ooH9mP00ol0003odRgBom8]dP09om8]dP03o`000?o=</gocC;=00cocC;=00?o0000
om</dooC;=<03?oC;=<00ol0003ol`ccoo<<l`0;oo<<l`;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0<ood2o@Co00000_on0Oh00ol0
003olPgboo8=lP0<oo8=lP03o`000?oL8mcog2?L00Oog2?L00?o0000okU6^OniA[T03oniA[T01?l0
003ocS7>olhac_o><Lh2o`0000koY5^T0_l00006onLHi`03o`000?o4>lCoa3_400goa3_400?o0000
omPWf?oH9mP00_oH9mP00ol0003odRgBom8]dP08om8]dP03o`000?o=</gocC;=00cocC;=0ol0000=
om</d`03o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?on0Oko0000
00oolPgb00?o0000om`Sg?oL8m`01_oL8m`00ol0003o^DJiokU6^@0@okU6^@Co00004_nTFj@00ol0
003oiaSWonLHi`03onLHi`03o`000?o4>lCoa3_400koa3_400Go0000omPWf?oH9mSof2OHo`000005
om8]dPOo00003?o=</d01Ol0003oZ5NXojQGZ?nXEjSo000000codbcC00?o0000oo<<looc3?<02?oc
3?<3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ood2oOom0_d04?om0_d3o`0000oolPgb00?o0000om`Sg?oL8m`01_oL8m`00ol0003o^DJiokU6^@0=
okU6^@?o000000CoOX5no`000?l0003o00004onTFj@2o`0000;oiaSW00?o0000ol@ka?o4>l@04?o4
>l@00ol0003of2OHo`000006o`0000Oo/Dja00?o0000oldbcOo=</d02?o=</d00ol0003oZ5NXojQG
Z003ojQGZ0;o00002?oC;=<3o`0000Kol`cc1?l00002onl@k`03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ood2oOom0_d03oom0_d0
1?l0003om`Sgo`000?oF:MH3o`0000golPgb00?o0000om`Sg?oL8m`01?oL8m`00ol0003o^DJiokU6
^@0;okU6^@?o00000omnPGh01Ol0003oNHIio`000?m?/4oo000001CoY5^T00?o0000onLHiol00000
4oo4>l@00ol0003o/Djaok5>/@0=ok5>/@03o`000?o=</gocC;=00GocC;=0_l00008ojQGZ003o`00
0?oC;=?odbcC00Go00000oo@;m000ol0003ol`ccoo<<l`03o`0000Ooka3_00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo@;mood2
o@0>ood2o@04o`000?og2?Oom`Sgo`0000CoeRWF0ol0000:oo8=lP03o`000?oL8mcog2?L00?og2?L
00?o0000okU6^OniA[T02OniA[T3o`0000GoOX5n00Co0000ogV6NOmiQWWo00000_m?/4l00ol0003o
Y5^TojAKY00BojAKY003o`000?o4>lCoa3_401;oa3_400?o0000ok5>/OnaC[403_naC[400ol0003o
cC;=oldbc@03oldbc@03o`000?nXEjSoZ5NX00WoZ5NX0_l00009om0_d0;o00002_o_4>l00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?om0_goo@;m00koo@;m00Go0000ooL8moog2?Oom`Sgo`000007omHYeP;o00001oob3O85o`0000;o
g2?L00?o0000okU6^OniA[T01_niA[T3o`0000SoOX5n00Co0000ogV6NOmiQWWo00000om?/4l00ol0
003oY5^TojAKY00AojAKY003o`000?o4>lCoa3_4017oa3_400?o0000ok5>/OnaC[404?naC[401Ol0
003ocC;=oldbcOo=</go000000coZ5NX00?o0000om0_d?o@;m002?o@;m000ol0003oka3_onl@k`0:
onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ood2oOom0_d03?om0_d2o`0000Com`Sg00?o0000omHYe_oF:MH01ooF:MH3o`00
0004oo8=l_l0003o0000o`0000Go`Sg20_l00006okU6^@?o00002_mnPGh01Ol0003oNHIiogV6NOmi
QWWo000000CoCk1?00?o0000ojAKY?nTFj@04?nTFj@00ol0003oa3_4ol@ka00Aol@ka003o`000?na
C[7o/Dja017o/Dja00?o0000oldbcOl000003OnXEjP00ol0003od2o@om0_d008om0_d003o`000?o_
4>ooka3_00[oka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo@;mood2o@0;ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000
omHYe_oF:MH02_oF:MH00ol0003o`Sg2ol8m`P08ol8m`P03o`000?niA[Wo^DJi00?o00003OmnPGh0
1Ol0003oNHIiogV6NOmiQWWo000000GoCk1?00?o0000ojAKY?nTFj@03onTFj@00ol0003oa3_4ol@k
a00Aol@ka003o`000?naC[7o/Dja01;o/Dja00?o0000ojQGZ?nXEjP03?nXEjP00ol0003od2o@om0_
d008om0_d003o`000?o_4>ooka3_00_oka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo@;m00?o0000ooL8moog2?L01Oog2?L0
0ol0003oeRWFomHYeP0:omHYeP03o`000?o2?L;o`Sg200Wo`Sg20_l0000?ogj1OP03o`000?miQWWo
NHIi00;oNHIi00?o0000odn`Com?/4l01?m?/4l00ol0003oY5^TojAKY00=ojAKY0?o00004Oo4>l@0
0ol0003o/Djaok5>/@0Cok5>/@03o`000?nXEjSoZ5NX00_oZ5NX00?o0000om0_d?o@;m002Oo@;m00
0ol0003oka3_onl@k`0;onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ood2o@;o00002?og2?L0
0ol0003oeRWFomHYeP0:omHYeP03o`000?o2?L;o`Sg200Wo`Sg200?o0000ogj1O_mnPGh03OmnPGh0
0ol0003oNHIiogV6N@03ogV6N@03o`000?m?/4ooCk1?00GoCk1?00?o0000ojAKY?nTFj@02_nTFj@2
o`0000?oO8=l00?o0000ol@ka?o4>l@03_o4>l@00ol0003o/Djaok5>/@0Cok5>/@03o`000?nXEjSo
Z5NX00_oZ5NX00?o0000om0_d?o@;m002Oo@;m000ol0003oka3_onl@k`0;onl@k`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000Goo@;m00?o0000ooL8moog2?L01oog2?L2o`0000_oeRWF00?o0000ol8m
`_o2?L802oo2?L800ol0003oOX5nogj1OP0<ogj1OP03o`000?miQWWoNHIi00?oNHIi00?o0000odn`
Com?/4l01_m?/4l00ol0003oY5^TojAKY007ojAKY0;o00001_mlPg`2o`0000koa3_400?o0000ok5>
/OnaC[404onaC[400ol0003oZ5NXojQGZ00;ojQGZ003o`000?o@;m3od2o@00Wod2o@00?o0000onl@
koo_4>l03?o_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ood2oOom0_goo@;mo`000009ooL8
m`03o`000?o/4nco000000_oeRWF00?o0000ol8m`_o2?L802oo2?L800ol0003oOX5nogj1OP0;ogj1
OP03o`000?miQWWoNHIi00CoNHIi00?o0000odn`Com?/4l01om?/4l00ol0003oY5^TojAKY005ojAK
Y003o`000?mlPgcoO8=l00SoO8=l00?o0000ol@ka?o4>l@02_o4>l@00ol0003o/Djaok5>/@0Dok5>
/@03o`000?nXEjSoZ5NX00_oZ5NX00?o0000om0_d?o@;m002Oo@;m000ol0003oka3_onl@k`0<onl@
k`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mo`000009ooL8m`04o`000?o/4ncok1?/o`00
00_oeRWF00?o0000ol8m`_o2?L802oo2?L800ol0003oOX5nogj1OP0;ogj1OP03o`000?miQWWoNHIi
00CoNHIi00?o0000odn`Com?/4l02?m?/4l00ol0003oY5^TojAKY002ojAKY0;o00003?mlPg`2o`00
00[oa3_400?o0000ok5>/OnaC[405?naC[400ol0003oZ5NXojQGZ00;ojQGZ003o`000?o@;m3od2o@
00Wod2o@00?o0000onl@koo_4>l03Oo_4>l00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003om`SgooL8m`07ooL8m`03
o`000?o/4ncok1?/00;ok1?/00?o0000omHYe_oF:MH02?oF:MH00ol0003o`Sg2ol8m`P0<ol8m`P03
o`000?mnPGkoOX5n00WoOX5n00?o0000ogV6NOmiQWT01OmiQWT00ol0003oCk1?odn`C`09odn`C`04
o`000?nTFjCo0000o`00013oO8=l0_l00008ol@ka003o`000?naC[7o/Dja01Co/Dja0ol0000;ojQG
Z003o`000?o@;m3od2o@00Wod2o@00?o0000onl@koo_4>l03Oo_4>l01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003om`SgooL8m`06ooL8m`03o`000?o/4ncok1?/00?ok1?/00?o0000omHY
e_oF:MH02?oF:MH00ol0003o`Sg2ol8m`P0;ol8m`P;o00002_mnPGh00ol0003oNHIiogV6N@06ogV6
N@03o`000?m?/4ooCk1?00[oCk1?00?o0000ogb3O?mlPg`04_mlPg`00ol0003oa3_4ol@ka004ol@k
a003o`000?naC[7o/Dja01Go/Dja00?o0000oiUVVOnIIYT01Ol00005ojQGZ003o`000?o@;m3od2o@
00[od2o@00?o0000onl@koo_4>l03_o_4>l3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003om`SgooL8m`04ooL8m`03
o`000?o/4ncok1?/00Cok1?/00?o0000omHYe_oF:MH01ooF:MH00ol0003o`Sg2ol8m`P0;ol8m`P04
o`000?mhQgSoN8Mho`0000WoOX5n00?o0000ogV6NOmiQWT01_miQWT00ol0003oCk1?odn`C`0:odn`
C`03o`000?mlPgcoO8=l01?oO8=l0_l00003ol@ka0Co00005?naC[400ol0003oVFJIoiUVV@06oiUV
V@Co000000?oZ5NXo`000?o@;m002oo@;m000ol0003oka3_onl@k`0>onl@k`03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?o/4ncok1?/00Gok1?/00?o0000omHYe_oF
:MH01ooF:MH00ol0003o`Sg2ol8m`P09ol8m`P;o00001?mhQgP00ol0003oOX5nogj1OP05ogj1OP03
o`000?miQWWoNHIi00OoNHIi00?o0000odn`Com?/4l02_m?/4l00ol0003oO8=logb3O00Eogb3O003
o`000?o4>lCo000000CoSW6>0ol0000@ok5>/@03o`000?nIIYWoVFJI00_oVFJI0_l0000<om0_d003
o`000?o_4>ooka3_00coka3_0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L00_og2?L00ol0003ok1?/
on`Ck006on`Ck003o`000?oF:MKoeRWF00OoeRWF00?o0000ol8m`_o2?L802?o2?L800ol0003oN8Mh
ogR7N005ogR7N003o`000?mnPGkoOX5n00CoOX5n00?o0000ogV6NOmiQWT01omiQWT00ol0003oCk1?
odn`C`0:odn`C`03o`000?mlPgcoO8=l01KoO8=l00?o0000ohiaS_n>LHh01_n>LHh3o`0000co/Dja
00?o0000oiUVVOnIIYT03OnIIYT00ol0003od2o@om0_d009om0_d0Go00002Oo_4>l2o`000003oo<<
lol0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooL8mol0003ok1?/00Wok1?/00?o0000omHYe_oF:MH01_oF
:MH00ol0003o`Sg2ol8m`P07ol8m`P03o`000?mhQgSoN8Mh00OoN8Mh00?o0000ogj1O_mnPGh00_mn
PGh00ol0003oNHIiogV6N@08ogV6N@03o`000?m?/4ooCk1?00WoCk1?00?o0000ogb3O?mlPg`05oml
Pg`00ol0003oSW6>ohiaSP09ohiaSP?o00002OnaC[400ol0003oVFJIoiUVV@0>oiUVV@Ko00001?o@
;m000ol0003ofRGJomXUfP03omXUfPGo00000_o_4>l2o`0000Col`cc00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o_4>ooka3_onl@kol000002oo/4n`00ol0003oeRWFomHYeP06omHYeP03o`000?o2
?L;o`Sg200Go`Sg20_l0000;ogR7N004o`000?mnPGkoOX5no`0000_oNHIi00?o0000odn`Com?/4l0
2Om?/4l00ol0003oO8=logb3O00Fogb3O003o`000?n>LHkoSW6>00goSW6>0ol00005ok5>/@03o`00
0?nIIYWoVFJI00ooVFJI00?o0000ojm@[on_D:l00on_D:l4o`0000_ofRGJ0_l00006oo<<l`03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003oka3_onl@k`02onl@k`ko00001_oF:MH00ol0003o`Sg2ol8m
`P05ol8m`P03o`000?mhQgSoN8Mh00coN8Mh00?o0000ogj1O_l000002omiQWT00ol0003oCk1?odn`
C`07odn`C`?o00006?mlPg`00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o/Djao`000?nIIYT04?nI
IYT00ol0003o[e2_ojm@[`07ojm@[`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oo<<looc3?<01Ooc
3?<00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005onl@k`03o`000?oB;M;odRgB00_odRgB0_l00004
omHYeP03o`000?o2?L;o`Sg200?o`Sg20_l0000@ogR7N003o`000?miQWWoNHIi00[oNHIi00?o0000
odn`Com?/4l00om?/4l4o`0000;o;M8]00?o0000ogb3O?mlPg`05OmlPg`00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nIIYWoVFJI013oVFJI00?o0000ojm@[on_D:l01on_D:l00ol0003ofRGJomXUfP0:
omXUfP03o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o_4>ooka3_
00Goka3_00?o0000om8]d_oB;M803OoB;M86o`0000?o`Sg200?o0000ogR7N?mhQgP04?mhQgP00ol0
003oNHIiogV6N@0:ogV6N@03o`000?m?/4oo000000?o00001ol]dRd00ol0003oO8=logb3O00Dogb3
O003o`000?n>LHkoSW6>01CoSW6>00?o0000oiUVVOnIIYT03onIIYT00ol0003o[e2_ojm@[`08ojm@
[`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oo<<looc3?<01Ooc3?<00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onl@koo_4>l01_o_4>l00ol0003odRgBom8]dP0=om8]dP03o`000?ndBkCo]4^d00?o
]4^d00?o0000ol8m`_l000004omhQgP4o`0000WoNHIi0_l0000<obgB;@03o`000?mlPgcoO8=l01?o
O8=l00?o0000ohiaS_n>LHh05On>LHh00ol0003oVFJIoiUVV@0>oiUVV@03o`000?n_D:oo[e2_00So
[e2_00?o0000omXUf_oJ9MX02OoJ9MX00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o_4>ooka3_00Soka3_00?o0000om8]d_oB;M802ooB;M800ol0003o]4^dokA;]005okA;]003o`00
0?mhQgSoN8Mh01;oN8Mh00Co0000oc[5>_ljaC[o>/Dj1Ol00003ogV6N@03o`000?l]dRgo;M8]00go
;M8]0ol0000@ogb3O0;o00006?n>LHh00ol0003oVFJIoiUVV@0=oiUVV@03o`000?n_D:oo[e2_00Wo
[e2_00?o0000omXUf_oJ9MX02OoJ9MX00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_oka3_00?o0000om8]d_oB;M802_oB;M800ol0003o]4^dokA;]006okA;]003o`00
0?mhQgSoN8Mh017oN8Mh00?o0000oc[5>_ljaCX01oljaCX3o`00013o;M8]00?o0000oa[U6_lJiAX0
1Ol00009ogb3O0;o000000?o<l`co`000?n>LHh05on>LHh00ol0003oVFJIoiUVV@0=oiUVV@03o`00
0?n_D:oo[e2_00Wo[e2_00?o0000omXUf_oJ9MX02?oJ9MX2o`0000[ol`cc00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oh1oSon0Oh00;on0Oh00?o0000onl@koo_4>l02Oo_4>l00ol0003odRgBom8]
dP0:om8]dP03o`000?ndBkCo]4^d00Oo]4^d00?o0000ogR7N?mhQgP03omhQgP00ol0003o>/Djoc[5
>P0:oc[5>P03o`000?l]dRgo;M8]00go;M8]00?o0000oa[U6_lJiAX01_lJiAX4o`0000CoO8=l00?o
0000oc?<<olcc3<00_lcc3<00ol0003oSW6>ohiaSP0FohiaSP03o`000?nIIYWoVFJI00_oVFJI00?o
0000ojm@[on_D:l02on_D:l00ol0003ofRGJomXUfP06omXUfP03o`000?oZ5N[o000000[ol`cc00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oh1oSon0Oh00?on0Oh00?o0000onl@koo_4>l02?o_4>l=
o`0000[o]4^d00?o0000ogR7N?mhQgP03omhQgP00ol0003o>/Djoc[5>P0;oc[5>P03o`000?l]dRgo
;M8]00co;M8]00?o0000oa[U6_lJiAX02_lJiAX4o`0000Go<l`c00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oVFJIoiUVV@0:oiUVV@03o`000?n_D:oo[e2_00co[e2_00?o0000omXUf_oJ9MX01?oJ9MX2
o`0000?ojQGZ00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooP7
n?oh1oP00ooh1oP00ol0003oka3_onl@k`07onl@k`03o`000?o@;m3od2o@00Wod2o@00?o0000okA;
]?ndBk@02OndBk@00ol0003oN8MhogR7N00=ogR7N003o`000?ljaC[o>/Dj00co>/Dj00?o0000obgB
;Ol]dRd03?l]dRd00ol0003o6^DJoa[U6P0;oa[U6P03o`000?l8m`So000000Ko<l`c00?o0000ohia
S_n>LHh05_n>LHh00ol0003oVFJIoiUVV@09oiUVV@03o`000?n_D:oo[e2_00co[e2_00?o0000omXU
f_oJ9MX00ooJ9MX00ol0003ojQGZonXEjP03onXEjP03o`000?oc3??ol`cc00Sol`cc00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Con0Oh00?o0000onl@koo_4>l01_o_4>l00ol0003o
d2o@om0_d008om0_d003o`000?ndBkCo]4^d00_o]4^d00?o0000ogR7N?mhQgP02?mhQgP4o`0000oo
>/Dj00?o0000obgB;Ol]dRd02ol]dRd00ol0003o6^DJoa[U6P0;oa[U6P04o`000?l8m`So2?L8o`00
00Oo<l`c00?o0000ohiaS_n>LHh05On>LHh00ol0003oVFJIoiUVV@08oiUVV@03o`000?n_D:oo[e2_
00go[e2_00?o0000omXUf_oJ9MX00_oJ9MX00ol0003ojQGZonXEjP05onXEjP03o`000?oc3??ol`cc
00Ool`cc00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Gon0Oh00?o0000onl@koo_
4>l01Oo_4>l00ol0003od2o@om0_d008om0_d003o`000?ndBkCo]4^d00_o]4^d00?o0000ogR7N?mh
QgP00omhQgP5o`0000?o?<<l00?o0000oc[5>_ljaCX03_ljaCX00ol0003o;M8]obgB;@0:obgB;@03
o`000?lJiA[o6^DJ00[o6^DJ00Go0000o`Sg2?l8m`So2?L8o`000007oc?<<`03o`000?n>LHkoSW6>
01GoSW6>00?o0000oiUVVOnIIYT02?nIIYT00ol0003o[e2_ojm@[`0=ojm@[`03o`000?oJ9M[ofRGJ
00;o00002?oZ5NX00ol0003ol`ccoo<<l`08oo<<l`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?o_4>ooka3_00Go
ka3_00?o0000om0_d?o@;m002?o@;m000ol0003o]4^dokA;]00<okA;]0Go00002Oll`c`00ol0003o
>/Djoc[5>P0<oc[5>P;o00003?l]dRd00ol0003o6^DJoa[U6P0:oa[U6P05o`000?l8m`So2?L8o`Sg
2?l000002?lcc3<00ol0003oSW6>ohiaSP0DohiaSP?o00001onIIYT00ol0003o[e2_ojm@[`0>ojm@
[`03o`000?oJ9M[o000000_ojQGZ00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oka3_onl@k`04onl@k`03o`000?o@;m3od2o@00Oo
d2o@00?o0000okA;]?ndBk@03?ndBk@01?l0003oMhQgogN8Mol0000;occ3?003o`000?ljaC[o>/Dj
00_o>/Dj00Co0000o`?l0ol3o0?o00002_l]dRd00ol0003o6^DJoa[U6P0:oa[U6P03o`000?l8m`So
2?L800;o2?L800?o0000oc?<<olcc3<01_lcc3<00ol0003oSW6>ohiaSP0AohiaSP?o00000omRWF80
0ol0003oVFJIoiUVV@04oiUVV@03o`000?n_D:oo[e2_00go[e2_1?l0000;onXEjP03o`000?oc3??o
l`cc00Gol`cc00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00Co0000onl@
koo_4>ooka3_1?l00008om0_d003o`000?ndBkCo]4^d00_o]4^d00?o0000ogN8MomgR7L00_mgR7L0
0ol0003o?<<locc3?008occ3?003o`000?ljaC[o>/Dj00[o>/Dj00?o0000o`?l0ol3o0<00_l3o0<0
0ol0003o;M8]obgB;@03obgB;@Go00002olJiAX00ol0003o2?L8o`Sg2003o`Sg2003o`000?lcc3?o
<l`c00Oo<l`c00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoHYeR00?o0000oiUVVOnIIYT00_nIIYT0
0ol0003o[e2_ojm@[`0=ojm@[`03o`000?oG:=OoebSG00;oebSG00?o0000onXEj_oZ5NX02OoZ5NX0
0ol0003ol`ccoo<<l`03oo<<l`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n007ooP7
n0?o00001?oN8Mh00ol0003od2o@om0_d005om0_d003o`000?ndBkCo]4^d00[o]4^d00?o0000ogN8
MomgR7L00omgR7L00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00So>/Dj00?o0000o`?l
0ol3o0<01?l3o0<5o`0000Co0?l000?o0000oa[U6_lJiAX02OlJiAX00ol0003o2?L8o`Sg2003o`Sg
2003o`000?lcc3?o<l`c00So<l`c00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oHYeR00Go0000oiUV
VOnIIYWoVFJIo`00000>ojm@[`03o`000?oG:=OoebSG00CoebSG0_l00009onXEjP03o`000?oc3??o
l`cc00;ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000omhQ
g_oN8Mh01OoN8Mh00ol0003od2o@om0_d003om0_d003o`000?ndBkCo]4^d00[o]4^d00?o0000ogN8
MomgR7L01?mgR7L00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Oo>/Dj00?o0000o`?l
0ol3o0<01Ol3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lJiA[o6^DJ00Oo6^DJ00?o0000o`Sg
2?l8m`P01?l8m`P00ol0003o<l`coc?<<`08oc?<<`03o`000?n>LHkoSW6>00SoSW6>0_l0000>of:M
HPCo00003?n_D:l2o`0000WoebSG00?o0000onXEj_oZ5NX01ooZ5NX01?l0003ol`ccoo<<lol0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ogR7NomhQgP07omhQgP;o00000oo@;m000ol0
003o]4^dokA;]009okA;]003o`000?mgR7OoMhQg00KoMhQg00?o0000occ3??ll`c`02Oll`c`00ol0
003o>/Djoc[5>P05oc[5>P03o`000?l3o0?o0o`300Ko0o`300?o0000o`3o0?l0o`002?l0o`000ol0
003o6^DJoa[U6P06oa[U6P03o`000?l8m`So2?L800Co2?L800?o0000oc?<<olcc3<02Olcc3<4o`00
00?oSW6>0ol0000@of:MHP05o`000?o2?L;o`Sg2ol8m`_l000002_n_D:l00ol0003oebSGomLXe`0:
omLXe`Ko00000ooZ5NX00ol0003ol`cco`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooP7n?oh1oP01?oh1oP00ol0
003ogR7NomhQgP0:omhQgP04o`000?o@;m3od2o@o`0000[o]4^d00?o0000ogN8MomgR7L01omgR7L0
0ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Co>/Dj00?o0000o`?l0ol3o0<01ol3o0<0
0ol0003o0?l0o`3o0008o`3o00;o00001_lJiAX00ol0003o2?L8o`Sg2005o`Sg2003o`000?lcc3?o
<l`c00Wo<l`c00Co0000obcC;?l/dbco;=</0ol0000Bof:MHP03o`000?o2?L;o`Sg200?o`Sg20_l0
0006ojm@[`;o00003OoG:=L00ol0003omPWfooH9mP03ooH9mPGo00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooP7n?oh1oP00ooh1oP0
0ol0003ogR7NomhQgP0<omhQgP;o00002_ndBk@00ol0003oMhQgogN8M`08ogN8M`03o`000?ll`cco
?<<l00[o?<<l00?o0000oc[5>_ljaCX00_ljaCX00ol0003o0o`3o`?l0`08o`?l0`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lJiA[o6^DJ00;o6^DJ00?o0000o`Sg2?l8m`P01_l8m`P0
0ol0003o<l`coc?<<`08oc?<<`03o`000?l/dbco;=</00Co;=</00?o0000of:MH_mRWF803omRWF80
0ol0003o`Sg2ol8m`P06ol8m`P;o00000on_D:l00ol0003oebSGomLXe`0=omLXe`03o`000?of2OKo
mPWf00OomPWf0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on0OhooP7n002ooP7n003o`000?oN8MkogR7N
00kogR7N00?o0000okA;]?ndBk@01ondBk@00ol0003oMhQgogN8M`0:ogN8M`03o`000?ll`cco?<<l
00Wo?<<l00Go0000oc[5>_ljaC[o>/Djo`00000;o`?l0`03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lJiA[o6^DJoa[U6_l000002?l8m`P00ol0003o<l`coc?<<`08oc?<<`03o`000?l/
dbco;=</00Go;=</00?o0000of:MH_mRWF803_mRWF800ol0003o`Sg2ol8m`P08ol8m`P03o`000?n_
D:oo000000ooebSG00?o0000ooH9m_of2OH02?of2OH01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oh1oSon0Oho`00017ogR7N00?o0000okA;]?ndBk@01_ndBk@00ol0003oMhQg
ogN8M`0;ogN8M`03o`000?ll`cco?<<l00Wo?<<l00Co0000oc[5>_ljaC[o00003?l3o0<00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o6^DJo`000009o`Sg2003o`000?lcc3?o<l`c00So
<l`c00?o0000obcC;?l/db`01Ol/db`00ol0003oHYeRof:MHP0=of:MHP03o`000?o2?L;o`Sg200[o
`Sg200?o0000omLXeooG:=L03_oG:=L00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BomhQgP03o`00
0?ndBkCo]4^d00Co]4^d00?o0000ogN8MomgR7L03?mgR7L00ol0003o?<<locc3?00:occ3?0?o0000
3?l3o0<00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Sg2?l8m`P02?l8m`P00ol0003o<l`c
oc?<<`07oc?<<`03o`000?l/dbco;=</00Oo;=</00?o0000of:MH_mRWF803?mRWF800ol0003o`Sg2
ol8m`P0;ol8m`P;o00003_oG:=L00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooH9m_of2OH00oof2OH00ol0003ogR7NomhQgP0?omhQgP?o00000ond
Bk@00ol0003oMhQgogN8M`0>ogN8M`03o`000?ll`cco?<<l00So?<<l00Co0000o`_d2ol;m0_o2o@;
0_l0000:o`?l0`?o00003Ol0o`000ol0003o2?L8o`Sg2008o`Sg2003o`000?lcc3?o<l`c00Oo<l`c
00?o0000obcC;?l/db`01ol/db`00ol0003oHYeRof:MHP0;of:MHP03o`000?o2?L;o`Sg200co`Sg2
00?o0000on`Ck?l000000_l0000:omLXe`03o`000?of2OKomPWf00SomPWf00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP04ooH9mP03o`000?oN8MkogR7N00cogR7N0_l0
0003olXebP03o`000?ndBkCo0000017oMhQg00?o0000occ3??ll`c`01oll`c`00ol0003o2o@;o`_d
2`04o`_d2`;o00002?l3o0<00ol0003o0?l0o`3o000>o`3o00;o00002?l8m`P00ol0003o<l`coc?<
<`06oc?<<`03o`000?l/dbco;=</00Wo;=</00?o0000of:MH_mRWF802OmRWF800ol0003o`Sg2ol8m
`P0=ol8m`P03o`000?o/4ncok1?/00;ok1?/0ol00007omLXe`03o`000?of2OKomPWf00OomPWf00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`000?oN8Mko
gR7N00WogR7N0_l00006olXebP03o`000?mgR7OoMhQg013oMhQg00?o0000occ3??ll`c`01_ll`c`0
0ol0003o2o@;o`_d2`07o`_d2`03o`000?l3o0?o0o`300Co0o`30ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol8m`P00ol0003o<l`coc?<<`06oc?<<`03o`000?l/dbco;=</00[o;=</00?o0000
of:MH_mRWF802?mRWF800ol0003o`Sg2ol8m`P0=ol8m`P03o`000?o/4ncok1?/00Gok1?/0ol00004
omLXe`03o`000?of2OKomPWf00OomPWf00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003omPWfooH9mP06ooH9mP03o`000?oN8MkogR7N00GogR7N0ol00008olXebP03o`000?mgR7OoMhQg
017oMhQg00Co0000occ3??ll`cco?<<l1?l0000;o`_d2`;o000000Co0o`3o`000?l0003o00000ol<
l``2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2?L800?o0000oc?<<olcc3<01_lc
c3<00ol0003o;=</obcC;00:obcC;003o`000?mRWF;oHYeR00OoHYeR00?o0000ol8m`_o2?L803_o2
?L800ol0003ok1?/on`Ck008on`Ck0Co00002_of2OH00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003omPWfooH9mP07ooH9mP03o`000?oN8MkogR7N00;ogR7N0_l0000<olXebP03o`000?mgR7Oo
MhQg013oMhQg1?l00003obo@;`03o`000?l;m0_o2o@;00_o2o@;00?o0000o`cc3?l<l``01_l<l``0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obcC;003o`000?mRWF;o
HYeR00KoHYeR00?o0000ol8m`_o2?L803_o2?L800ol0003ok1?/on`Ck00;on`Ck003o`000?of2OKo
mPWf00OomPWf00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00WomPWf00Co0000omhQ
g_l0003o00003_o:=LX00ol0003oMhQgogN8M`0?ogN8M`03o`000?l_d2oo;m0_00Ko;m0_00?o0000
o`_d2ol;m0/02_l;m0/00ol0003o3?<<o`cc3007o`cc30;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lfbCKo=/Tf00So=/Tf00?o0000obcC;?l/db`03?l/db`00ol0003oHYeRof:MHP05
of:MHP03o`000?o2?L;o`Sg200oo`Sg20_l0000=on`Ck003o`000?of2OKomPWf00KomPWf00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00[omPWf00?o0000olXeb_o:=LX03_o:=LX00ol0
003oMhQgogN8M`0>ogN8M`03o`000?l_d2oo;m0_00Oo;m0_00?o0000o`_d2ol;m0/02_l;m0/00ol0
003o3?<<o`cc3009o`cc30;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lfbCKo=/Tf
00Wo=/Tf00?o0000obcC;?l/db`02_l/db`4o`0000CoHYeR00?o0000ol8m`_o2?L804?o2?L801?l0
003ojAKYo`000?l0000<on`Ck003o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?of2OKomPWf00[omPWf00?o0000olXeb_o:=LX03oo:=LX@o`0000[o;m0_00?o0000o`_d
2ol;m0/02Ol;m0/00ol0003o0?l0o`00000<o`cc3005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o=/TfocK9=P09ocK9=P03o`000?l/dbco;=</00Oo;=</0ol00004of:MHP?o000000?oHYeR
o`000?o2?L804Oo2?L801?l0003ojAKYonTFjOoY5^T2o`0000_ok1?/00?o0000ooH9m_of2OH00oof
2OH00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003obSG:olXebP0?
olXebP03o`000?mgR7OoMhQg00coMhQg00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2o@;o`_d2`07
o`_d2`04o`000?l0o`3o0?l0o`0000go3?<<00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lfbCKo=/Tf00[o=/Tf00?o0000obcC;?l/db`00ol/db`3o`0000[oHYeR00?o0000ol8m`_o2?L80
4?o2?L800ol0003ojAKYonTFj@04onTFj@;o00002_o/4n`00ol0003omPWfooH9mP04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000comPWf00?o0000olXeb_o:=LX03oo:=LX00ol0003oMhQgogN8M`0<ogN8M`03o`000?l_
d2oo;m0_00Wo;m0_00?o0000o`_d2ol;m0/01_l;m0/00ol0003o0?l0o`3o0002o`3o0003o`000?l<
l`co3?<<00[o3?<<00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?lf
bCKo=/Tf00[o=/Tf00?o0000obcC;?l/db`00ol0000=of:MHP03o`000?o2?L;o`Sg2013o`Sg200?o
0000onTFjOoY5^T01_oY5^T2o`0000Wok1?/0_l00004ood2o@03o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003obSG:olXebP0=olXebP?o00003omgR7L0
0ol0003o;m0_obo@;`08obo@;`03o`000?l;m0_o2o@;00Go2o@;00?o0000o`3o0?l0o`000ol0o`00
0ol0003o3?<<o`cc300:o`cc3003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o=/TfocK9=P0;ocK9=P;o00004OmRWF800ol0003o`Sg2ol8m`P0?ol8m`P03o`000?oY5^Wo
jAKY00SojAKY0_l00007on`Ck003o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooH9m_of2OH02?of2OH00ol0003obSG:olXebP09olXebPGo00000_nOH9l00ol0
003oMhQgogN8M`0=ogN8M`03o`000?l_d2oo;m0_00Wo;m0_00?o0000o`_d2ol;m0/01?l;m0/00ol0
003o0?l0o`3o0004o`3o0003o`000?l<l`co3?<<00So3?<<00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lfbCKo=/Tf00_o=/Tf00?o0000of:MH_mRWF804?mRWF800ol0
003o`Sg2ol8m`P0?ol8m`P03o`000?oY5^WojAKY00[ojAKY0_l00004on`Ck003o`000?om0_goo@;m
00Koo@;m0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003omPWfooH9mP07ooH9mP03o`000?o:=L[obSG:00CobSG:1Ol00007oimPW`03
o`000?mgR7OoMhQg00goMhQg00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2o@;o`_d2`03o`_d2`03
o`000?l0o`3o0?l000Go0?l000?o0000o`cc3?l<l``02?l<l``00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ocK9=_lfbCH02olfbCH00ol0003oHYeRof:MHP0@of:MHP03
o`000?o2?L;o`Sg200oo`Sg200?o0000onTFjOoY5^T03?oY5^T2o`000003on`Ck?l0003oo@;m00[o
o@;m00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000olXeb_l00000
1?l0000<oimPW`03o`000?mgR7OoMhQg00koMhQg00?o0000obo@;ol_d2l02?l_d2l00ol0003o2o@;
o`_d2`02o`_d2`03o`000?l0o`3o0?l000Oo0?l000?o0000o`cc3?l<l``01ol<l``00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ocK9=_lfbCH02olfbCH00ol0003oHYeR
of:MHP0Aof:MHP03o`000?o2?L;o`Sg200go`Sg200?o0000onTFjOoY5^T03ooY5^T00ol0003oo@;m
ood2o@0;ood2o@;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooH9m_of2OH01Oof2OH3o`00017oWf2O00?o0000ogN8MomgR7L03_mg
R7L00ol0003o;m0_obo@;`09obo@;`04o`000?l;m0_o2o@;o`0000[o0?l000?o0000o`cc3?l<l``0
1ol<l``00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003OlfbCH00ol0003o
HYeRof:MHP0Aof:MHP?o00003Oo2?L800ol0003ojAKYonTFj@0?onTFj@03o`000?om0_goo@;m00go
o@;m00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_of2OH2o`0000;ohQgR00?o0000oimPWonOH9l03onOH9l00ol0003o
MhQgogN8M`0>ogN8M`03o`000?l_d2oo;m0_00So;m0_1Ol0000;o`3o0003o`000?l<l`co3?<<00Ko
3?<<00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ocK9=P03o`000?mRWF;oHYeR
017oHYeR00?o0000offBKOm]TVd00ol0000:ol8m`PCo00003OoY5^T00ol0003oo@;mood2o@0?ood2
o@03o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooP7n?oh1oSon0Oh0_l00005on8MhP03o`000?nOH9ooWf2O00koWf2O00?o0000ogN8
MomgR7L03_mgR7L00ol0003o;m0_obo@;`07obo@;`03o`000?lGj1Oo5nPG00?o5nPG00?o0000o`3o
0?l0o`002?l0o`000ol0003o3?<<o`cc3005o`cc3003o`000?l0o`3o0?l000[o0?l01Ol0000<ocK9
=P03o`000?mRWF;oHYeR013oHYeR00?o0000offBKOm]TVd01?m]TVd3o`0000Ko`Sg200?o0000on@K
i?oT6n@00_oT6n@5o`0000SojAKY00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00?o
n0Oh00?o0000on8Mh_oR7N801?oR7N800ol0003oWf2OoimPW`0=oimPW`03o`000?mgR7OoMhQg00oo
MhQg00?o0000obo@;ol_d2l01?l_d2l2o`0000Oo5nPG00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ocK9=_lfbCH02?lfbCH3o`00013oHYeR00?o0000offBKOm]TVd02?m]TVd3o`0000;o
`Sg200?o0000on@Ki?oT6n@02?oT6n@5o`0000?ojAKY00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oh1oSon0Oh00Con0Oh00?o0000on8Mh_oR7N801OoR7N800ol0003oWf2OoimPW`0;oimPW`Co0000
3omgR7L00ol0003o;m0_obo@;`03obo@;`03o`000?lGj1Oo5nPG00So5nPG00?o0000o`3o0?l0o`00
1?l0o`02o`0000So4>l@00?o0000o`7n0Ol1oP402?l1oP400ol0003o0?l0o`3o0005o`3o00;o0000
1_lfbCH2o`0000?o</db00?o0000of:MH_mRWF803?mRWF800ol0003oKI9]offBK@0<offBK@;o0000
4?oT6n@3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oR7N;ohQgR00KohQgR00?o
0000oimPWonOH9l02OnOH9l00ol0003o/4n`o`000002ofBKI0?o00003?mgR7L01?l0003o;m0_obo@
;ol_d2l2o`0000co5nPG00?o0000o`3o0?l0o`000_l0o`000ol0003o4>l@oa3_4008oa3_4003o`00
0?l1oP7o0Oh100So0Oh100?o0000o`3o0?l0o`001ol0o`000ol0003o=/TfocK9=P02ocK9=P03o`00
0?lbcC;o</db00Co</db0_l0000;of:MHP03o`000?m]TVgoKI9]00coKI9]00?o0000ok=</ol00000
4_oT6n@00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on0OhooP7n006ooP7n003o`000?oR7N;ohQgR00OohQgR00?o
0000oimPWonOH9l01_nOH9l2o`0000;o/4n`00?o0000ofBKI?mTVf@00omTVf@3o`0000[oMhQg00?o
0000obo@;ol000003olGj1L01?l0003o0?l0o`000?l0000;oa3_4003o`000?l1oP7o0Oh100So0Oh1
00?o0000o`3o0?l0o`002?l0o`001?l0003o=/Tfo`000?l00009oc;=<P03o`000?mRWF;oHYeR00Oo
HYeR00?o0000offBKOm]TVd03?m]TVd01?l0003o/dbcok=</ol0000Con@Ki003o`000?om0_goo@;m
00coo@;m0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ohQgRon8MhP08on8MhP03o`000?nOH9ooWf2O00Co
Wf2O00?o0000ok1?/?n`Ck000on`Ck000ol0003oI9]TofBKI005ofBKI0?o00001_mgR7L4o`00013o
5nPG00?o0000oa3_4?l@ka003?l@ka000ol0003o0Oh1o`7n0@07o`7n0@03o`000?l0o`3o0?l000Wo
0?l000?o0000oc;=<_lbcC802_lbcC82o`0000KoHYeR00?o0000offBKOm]TVd03?m]TVd00ol0003o
/dbcok=</`02ok=</`03o`000?oT6nCoi1_T00ooi1_T00?o0000ooD:mOl000002oom0_d2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on0OhooP7n008ooP7n003o`000?oR7N;ohQgR00WohQgR00Co0000oimPWonOH9oo
Wf2O0_l00006ok1?/003o`000?mTVfCoI9]T00SoI9]T0ol000000omgR7Oo0000o`000004ocC;=003
o`000?lGj1Oo5nPG00go5nPG00?o0000oa3_4?l@ka003?l@ka000ol0003o0Oh1o`7n0@07o`7n0@03
o`000?l0o`3o0?l000Wo0?l000?o0000oc;=<_lbcC803?lbcC800ol0003oHYeRof:MHP03o`0000ko
KI9]00?o0000ok=</oncC;<00oncC;<00ol0003oi1_Ton@Ki00>on@Ki005o`000?oe2_Gom@[eooD:
mOl000002?om0_d2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n009ooP7n003o`000?oR7N;ohQgR00[o
hQgR00?o0000oimPWol000002?n`Ck000ol0003oI9]TofBKI00;ofBKI003o`000?ldbcCo=</d00Go
=</d00?o0000oaOX5olGj1L03?lGj1L00ol0003o4>l@oa3_400<oa3_4003o`000?l1oP7o0Oh100Oo
0Oh100?o0000o`3o0?l0o`002?l0o`02o`0000oo</db0_l00002offBK@03o`000?m]TVgoKI9]00_o
KI9]00?o0000ok=</oncC;<01?ncC;<00ol0003oi1_Ton@Ki00=on@Ki003o`000?oe2_Gom@[e00?o
m@[e00?o0000ood2oOom0_d00_om0_d3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooP7n003o`000?oR7N;ohQgR00_ohQgR00?o0000ok1?/?n`Ck00
1on`Ck000ol0003oI9]TofBKI00;ofBKI003o`000?ldbcCo=</d00Ko=</d00?o0000oaOX5olGj1L0
2olGj1L2o`0000go4>l@00?o0000o`7n0Ol1oP401ol1oP400ol0003o0?l0o`3o0007o`3o0004o`00
0?l6n@Ko1_T6o`0000ko</db00?o0000offBKOm]TVd00_m]TVd00ol0003oKI9]offBK@09offBK@03
o`000?ncC;?o/dbc00Ko/dbc00?o0000on@Ki?oT6n@02ooT6n@00ol0003om@[eooD:m@05ooD:m@04
o`000?om0_go0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ood2oOom0_d00_om0_d3o`0000Son0Oh00?o0000on8Mh_oR7N802_oR7N82o`0000Wo
/4n`00?o0000ofBKI?mTVf@02omTVf@00ol0003o=</docC;=007ocC;=003o`000?lGj1Oo5nPG00Wo
5nPG00Co0000o`3o0?l0o`3o00003?l@ka000ol0003o0Oh1o`7n0@07o`7n0@03o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ki1_l6n@Ko1_T6o`00000>oc;=<P03o`000?m]TVgoKI9]00?oKI9]00?o0000
offBKOm]TVd01om]TVd00ol0003o/dbcok=</`07ok=</`03o`000?oT6nCoi1_T00[oi1_T00?o0000
ooD:mOoe2_D01ooe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?om0_goo@;m00Goo@;m0_l00006ooP7n003o`000?oR7N;ohQgR
00WohQgR00Co0000omXUf_oJ9M[o00002On`Ck000ol0003oI9]TofBKI009ofBKI003o`000?ldbcCo
=</d00Wo=</d00?o0000oaOX5olGj1L01olGj1L00ol0003o0?l0o`3o0002o`3o0003o`000?l@ka3o
4>l@00Wo4>l@00?o0000o`7n0Ol1oP401ol1oP400ol0003o0?l0o`3o0005o`3o0003o`000?l6n@Ko
1_T600?o1_T600?o0000oc;=<_lbcC802_lbcC800ol0003oKI9]offBK@05offBK@03o`000?m]TVgo
KI9]00GoKI9]00?o0000ok=</oncC;<02?ncC;<00ol0003oi1_Ton@Ki009on@Ki003o`000?oe2_Go
m@[e00Som@[e00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo@;mood2o@07ood2o@?o00000_oh1oP3o`0000WohQgR00?o0000omXU
f_oJ9MX00_oJ9MX00ol0003o/4n`ok1?/006ok1?/003o`000?mTVfCoI9]T00WoI9]T00?o0000ocC;
=?ldbc@02_ldbc@00ol0003o5nPGoaOX5`05oaOX5`03o`000?l0o`3o0?l000Co0?l000?o0000oa3_
4?l@ka002?l@ka000ol0003o0Oh1o`7n0@07o`7n0@03o`000?l0o`3o0?l000Co0?l000?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o</dboc;=<P0:oc;=<P03o`000?m]TVgoKI9]00KoKI9]00?o0000offB
KOm]TVd00om]TVd00ol0003o/dbcok=</`09ok=</`03o`000?oT6nCoi1_T00Soi1_T00?o0000ooD:
mOoe2_D02Ooe2_D00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?om0_goo@;m00[oo@;m0_l00003oo4>l@?o00001OoR7N800ol0003o
fRGJomXUfP03omXUfP03o`000?n`Ck3o/4n`00Ko/4n`00?o0000ofBKI?mTVf@02OmTVf@00ol0003o
=</docC;=00;ocC;=003o`000?lGj1Oo5nPG00?o5nPG00?o0000o`3o0?l0o`001_l0o`000ol0003o
4>l@oa3_4008oa3_4003o`000?l1oP7o0Oh100Ko0Oh100?o0000o`3o0?l0o`000_l0o`02o`0000So
1_T600?o0000oc;=<_lbcC802OlbcC800ol0003oKI9]offBK@07offBK@05o`000?m]TVgoKI9]offB
KOl000003OncC;<00ol0003oi1_Ton@Ki006on@Ki003o`000?oe2_Gom@[e00[om@[e00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o@;mood2o@0:ood2o@03o`000?oa3_7ol@ka00Gol@ka0ol000000ooR7N;o0000omXUfP06omXUfP03
o`000?n`Ck3o/4n`00Go/4n`00?o0000ofBKI?mTVf@02OmTVf@00ol0003o=</docC;=00<ocC;=005
o`000?lGj1Oo5nPGoaOX5ol000002_l0o`000ol0003o4>l@oa3_4007oa3_4003o`000?l1oP7o0Oh1
00Ko0Oh100?o0000o`3o0?l000000_l000000olZeB[o0000o`Ki1P07o`Ki1P03o`000?lbcC;o</db
00So</db00?o0000offBKOm]TVd02Om]TVd00ol0003oKI9]o`00000=ok=</`Co00001OoT6n@00ol0
003om@[eooD:m@0;ooD:m@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@08oo4>l@03
o`000?oJ9M[ofRGJ00OofRGJ00?o0000ok1?/?n`Ck001?n`Ck000ol0003oI9]TofBKI009ofBKI003
o`000?ldbcCo=</d00go=</d00?o0000oaOX5ol000003?l0o`0:o`0000Oo0Oh10ol00005ob[E:P03
o`000?l6n@Ko1_T600Ko1_T600?o0000oc;=<_lbcC801olbcC800ol0003oKI9]offBK@0:offBK@03
o`000?ncC;?o/dbc00_o/dbc00?o0000on<LhooS7><00_oS7><3o`000003on@Ki?l0003om@[e00_o
m@[e0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_402Ooa3_400ol0003ofRGJomXUfP07omXUfP03o`00
0?n`Ck3o/4n`00Go/4n`00?o0000ofBKI?mTVf@01omTVf@00ol0003o=</docC;=00?ocC;=0;o0000
2ol0o`000ol0003o7^4NoakQ7P07oakQ7P03o`000?l1oP7o0Oh100;o0Oh10ol00008ob[E:P03o`00
0?l6n@Ko1_T600Ko1_T600?o0000oc;=<_lbcC801olbcC800ol0003oKI9]offBK@0:offBK@03o`00
0?ncC;?o/dbc00[o/dbc00?o0000on<LhooS7><01_oS7><00ol0003om@[eooD:m@08ooD:m@?o0000
0_oh1oP00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_402Ooa3_400ol0003ofRGJomXU
fP08omXUfP03o`000?n`Ck3o/4n`00Co/4n`00?o0000ofBKI?mTVf@01omTVf@00ol0003o=</docC;
=00>ocC;=004o`000?l5nPGo1OX5o`0000Wo0?l000?o0000oakQ7_lNhAh02OlNhAh01?l0003o0Oh1
o`000?l0000<ob[E:P03o`000?l6n@Ko1_T600Ko1_T600?o0000oc;=<_lbcC801_lbcC800ol0003o
KI9]offBK@0;offBK@03o`000?ncC;?o/dbc00Oo/dbc0_l00009on<Lh`03o`000?oe2_Gom@[e00Co
m@[e1?l00006ooP7n003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ood2oOom0_d02_om0_d00ol0003ol@kaoo4>l@09oo4>l@03o`00
0?oJ9M[ofRGJ00SofRGJ00?o0000ok1?/?n`Ck000on`Ck0>o`0000go=</d00?o0000o`Gj1Ol5nPD0
0_l5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?lNhAko7^4N00_o7^4N00?o0000ob[E:_lZeBX0
3?lZeBX00ol0003o1_T6o`Ki1P06o`Ki1P03o`000?lbcC;o</db00Go</db00?o0000offBKOm]TVd0
3?m]TVd00ol0003o/dbcok=</`06ok=</`03o`000?oS7>?ohacS00[ohacS00?o0000ooD:mOoe2_D0
0ol0000:ooP7n0?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000omXUf_oJ9MX02?oJ
9MX01Ol0003o/4n`ok1?/?n`Ck3o000000_oN8Mh00?o0000oaKY5_lFjAH00ol00009ocC;=003o`00
0?l5nPGo1OX500Co1OX500?o0000o`3o0?l0o`000ol0o`000ol0003o7^4NoakQ7P0<oakQ7P03o`00
0?lZeB[o:]DZ00go:]DZ00?o0000o`Ki1_l6n@H01_l6n@H00ol0003o</dboc;=<P03oc;=<P?o0000
3Om]TVd00ol0003o/dbcok=</`05ok=</`03o`000?oS7>?ohacS00cohacS0_l0000=ooP7n003o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo@;mood2o@09ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000omXUf_oJ9MX02?oJ
9MX4o`0000coN8Mh00?o0000oaKY5_lFjAH00olFjAH3o`0000Go=</d00?o0000o`Gj1Ol5nPD01_l5
nPD01Ol0003o0?l0o`3o0?l0o`3o000000oo7^4N00?o0000ob[E:_lZeBX03OlZeBX00ol0003o1_T6
o`Ki1P06o`Ki1P03o`000?lbcC;o</db00?o00000olVfBH00ol0003oKI9]offBK@0;offBK@03o`00
0?ncC;?o/dbc00?o/dbc00?o0000on<LhooS7><03OoS7><00ol0003on0OhooP7n00;ooP7n003o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?om0_goo@;m00Soo@;m00?o0000oo4>lOoa3_402_oa3_43o`0000KofRGJ0ol0
0003olXebP03o`000?mhQgSoN8Mh00[oN8Mh00?o0000oaKY5_lFjAH01_lFjAH3o`000003ocC;=?l0
003o1OX500Wo1OX500?o0000o`3o0?l000004?lNhAh00ol0003o:]DZob[E:P0=ob[E:P03o`000?l6
n@Ko1_T600Oo1_T60_l00007obKI9P03o`000?m]TVgoKI9]00[oKI9]00Co0000ok=</oncC;?o/dbc
0ol0000?on<Lh`03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?om0_goo@;m00Koo@;m00?o0000oo4>lOoa3_402_oa
3_401?l0003ojQGZonXEj_oZ5NX2o`000004omXUf_l0003o0000o`0000KobSG:00?o0000ogR7N?mh
QgP02_mhQgP00ol0003o5^TFoaKY5P09oaKY5P03o`000?l5nPGo1OX500[o1OX500?o0000oakQ7_lN
hAh03olNhAh00ol0003o:]DZob[E:P0>ob[E:P03o`000?l6n@Ko1_T600Ko1_T600?o0000obKI9_lV
fBH01olVfBH4o`0000SoKI9]00Co0000ok=</oncC;?o00000oo9=/T2o`0000gohacS00?o0000ooP7
n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?om0_goo@;m00Goo@;m00?o0000oo4>lOoa3_402Ooa3_400ol0003o
jQGZonXEjP04onXEjP03o`000?o:=L[obSG:00OobSG:00?o0000ogR7N?mhQgP02OmhQgP00ol0003o
5^TFoaKY5P0:oaKY5P03o`000?l5nPGo1OX500[o1OX500?o0000oakQ7_lNhAh03olNhAh00ol0003o
:]DZob[E:P0>ob[E:P03o`000?l6n@Ko1_T600Go1_T600?o0000obKI9_lVfBH02?lVfBH01?l0003o
JYEZofZEJ_mZUFX7o`0000;oKI9]0_l00006olTfb@;o00003?oS7><00ol0003on0OhooP7n009ooP7
n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ood2oOom0_d01?om0_d00ol0003ol@kaoo4>l@08oo4>l@03o`000?oZ5N[ojQGZ00Go
jQGZ00?o0000olXeb_o:=LX02?o:=LX00ol0003oN8MhogR7N008ogR7N003o`000?lFjAKo5^TF00[o
5^TF00?o0000o`Gj1Ol5nPD02ol5nPD00ol0003o7^4NoakQ7P0>oakQ7P03o`000?lZeB[o:]DZ00ko
:]DZ1Ol00002o`Ki1P03o`000?lVfBKo9]TV00Wo9]TV00?o0000ofZEJ_mZUFX02?mZUFX3o`0000Wo
bCK90_l0000:on<Lh`03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oa3_7ol@ka00Sol@ka00?o0000onXEj_oZ5NX01ooZ5NX00ol0003obSG:olXebP07olXebP03o`00
0?mhQgSoN8Mh00SoN8Mh00?o0000oaKY5_lFjAH02_lFjAH00ol0003o1OX5o`Gj1@0:o`Gj1@;o0000
3_lNhAh3o`0000go:]DZ0ol00005ocW6>@;o00002olVfBH00ol0003oJYEZofZEJP0;ofZEJP;o0000
2_o9=/T2o`0000OohacS0ol00009ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ood2oOom0_goo@;m3?l0000:onXEjP03o`00
0?o:=L[obSG:00OobSG:00?o0000ogR7N?mhQgP02?mhQgP>o`0000Wo1OX50ol000000ol0o`3o0000
oakQ7P0:oakQ7P?o00000_lgb3L00ol0003o:]DZob[E:P09ob[E:P;o00002OliaST00ol0003o9]TV
obKI9P09obKI9P03o`000?mZUF[oJYEZ00_oJYEZ00?o0000oiEZUOl000002oo9=/T2o`0000CohacS
00Co0000onl@koo_4>ooka3_0_l00007ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ood2oOl000002ool0o`00ol0003ojQGZ
onXEjP09onXEjP03o`000?o:=L[obSG:00KobSG:00?o0000ogR7N?mhQgP02?mhQgP00ol0003o6n@K
oa_T6`0:oa_T6`03o`000?l5nPGo1OX500Co1OX50ol00005o`3o0003o`000?lNhAko7^4N00Co7^4N
1?l00006ocO8=`03o`000?lZeB[o:]DZ00Ko:]DZ0_l0000;ocW6>@03o`000?lVfBKo9]TV00Wo9]TV
00?o0000ofZEJ_mZUFX02_mZUFX01Ol0003oUFZEoiEZUOnEJYGo000000cobCK90_l000000ooS7>?o
0000onl@k`05onl@k`03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oZ5N[ojQGZ00SojQGZ00?o0000olXeb_o:=LX01_o:=LX00ol0003oN8MhogR7N007ogR7N003o`00
0?lKi1_o6n@K00_o6n@K00?o0000o`Gj1Ol5nPD00_l5nPD2o`0000Wo0?l000?o0000oakQ7_lNhAh0
0ol0000;ocO8=`03o`000?lZeB[o:]DZ00;o:]DZ0ol0000>ocW6>@03o`000?lVfBKo9]TV00Oo9]TV
00?o0000ofZEJ_mZUFX02omZUFX00ol0003oUFZEoiEZU@02oiEZU@03o`000?o9=/WobCK900_obCK9
00?o0000onl@koo_4>l01_o_4>l2o`0000?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oZ
5N[ojQGZ00OojQGZ00?o0000olXeb_o:=LX01oo:=LX00ol0003oN8MhogR7N005ogR7N0?o00003OlK
i1/4o`0000_o0?l00ol0000?ocO8=`04o`000?lZeB[o0000o`00017o>LHi00?o0000obKI9_lVfBH0
1olVfBH00ol0003oJYEZofZEJP0:ofZEJP03o`000?nEJYGoUFZE00CoUFZE00?o0000olTfbOo9=/T0
1oo9=/T3o`0000_oka3_1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX02?oZ5NX00ol0003obSG:olXe
bP06olXebP03o`000?mhQgSoN8Mh00;oN8Mh0ol00003oe>/D`03o`000?lKi1_o6n@K00[o6n@K00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AocO8=`03o`000?liaSWo>LHi017o>LHi00?o
0000obKI9_lVfBH01olVfBH00ol0003oJYEZofZEJP0:ofZEJP03o`000?nEJYGoUFZE00GoUFZE00Co
0000olTfbOo9=/WobCK91Ol00002om4^d@03o`000?o_4>ooka3_00Woka3_00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onXEj_oZ5NX01ooZ5NX00ol0003obSG:olXebP05olXebP?o0000
00?oN8Mho`000?l000001omC[5<00ol0003o6n@Koa_T6`08oa_T6`?o00002_l0o`02o`0000;o0?l0
00?o0000ocO8=olgb3L03olgb3L00ol0003o>LHiocW6>@0AocW6>@03o`000?lVfBKo9]TV00Oo9]TV
00?o0000ofZEJ_mZUFX02OmZUFX00ol0003oUFZEoiEZU@07oiEZU@?o00001ooA;]400ol0003oka3_
onl@k`09onl@k`03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onXEj_oZ5NX01ooZ
5NX4o`0000;obSG:0_l00003oka3_003o`000?mC[5?oDjaC00SoDjaC0_l00006oa_T6`;o00000olF
jAH00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000ocO8=olgb3L03_lg
b3L00ol0003o>LHiocW6>@0BocW6>@03o`000?lVfBKo9]TV00Go9]TV00?o0000ofZEJ_mZUFX02OmZ
UFX00ol0003oUFZEoiEZU@08oiEZU@03o`000?oA;]7odBkA00OodBkA00?o0000onl@koo_4>l02?o_
4>l00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oZ5N[ojQGZ00CojQGZ0_l00004
onXEjP;o00001Onl@k`00ol0003oDjaCoe>/D`0:oe>/D`03o`000?lKi1_o6n@K00;o6n@K00?o0000
oaKY5_lFjAH01?lFjAH00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
ocO8=olgb3L03_lgb3L00ol0003o>LHiocW6>@0BocW6>@[o00002_mZUFX00ol0003oUFZEoiEZU@08
oiEZU@03o`000?oA;]7odBkA00OodBkA00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ojQGZonXEj_oZ5NX2o`0000OojQGZ00?o0000oka3_?nl@k`01?nl@k`0
0ol0003oDjaCoe>/D`0:oe>/D`04o`000?lKi1_o0000o`0000So5^TF00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lgb3Oo=lPg00ko=lPg00?o0000ocW6>OliaST04_liaST00ol0003oA;]4
odBkA007odBkA003o`000?mZUF[oJYEZ00KoJYEZ00?o0000oiEZUOnEJYD02_nEJYD00ol0003odBkA
om4^d@06om4^d@03o`000?o_4>ooka3_00Soka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?oZ
5N[o0000o`0000WojQGZ00?o0000oka3_?nl@k`01?nl@k`00ol0003oDjaCoe>/D`0;oe>/D`03o`00
0?lFjAKo5^TF00Wo5^TF00?o0000o`3o0?l000002Ol0o`000ol0003o=lPgocO8=`0>ocO8=`;o0000
4_liaST00ol0003oA;]4odBkA009odBkA0;o00001_mZUFX00ol0003oUFZEoiEZU@0:oiEZU@03o`00
0?oA;]7odBkA00KodBkA00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onXEj_oZ5NX02OoZ5NX00ol0003o_4>loka3_005oka3_003o`000?mC[5?oDjaC00[oDjaC00?o
0000oaKY5_lFjAH02_lFjAH2o`0000Wo0?l000?o0000ocO8=olgb3L03_lgb3L00ol0003o9]TVo`00
0002o`0000oo>LHi00?o0000odBkA?m4^d@02om4^d@00ol0003oJYEZofZEJP03o`0000goUFZE00?o
0000om4^dOoA;]401_oA;]400ol0003oka3_onl@k`07onl@k`03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003ojQGZonXEjP09onXEjP03o`000?nl@kco_4>l00Go_4>l00?o0000oe>/DomC[5<02OmC[5<2
o`0000_o5^TF0_l0000;o`3o0003o`000?lgb3Oo=lPg00co=lPg00?o0000obKI9_lVfBH00olVfBH3
o`0000co>LHi00?o0000odBkA?m4^d@03?m4^d@2o`0000;oSG:=00?o0000oiEZUOnEJYD03?nEJYD0
0ol0003odBkAom4^d@05om4^d@03o`000?o_4>ooka3_00Ooka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oka3_?nl@k`01_nl@k`00ol0003oDjaCoe>/D`07oe>/
D`03o`000?mHYeSo000000[o5^TF00Co0000o`gb3Ol=lPgo00002_l0o`000ol0003o=lPgocO8=`0<
ocO8=`03o`000?lVfBKo9]TV00Ko9]TV0_l00008ocW6>@;o00003om4^d@00ol0003oSG:=ohebS@02
ohebS@03o`000?nEJYGoUFZE00_oUFZE00?o0000om4^dOoA;]401OoA;]400ol0003oka3_onl@k`07
onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ojQGZonXEjP0:onXEjP03o`000?nl@kco_4>l
00Ko_4>l00?o0000oe>/DomC[5<01_mC[5<01Ol0003oF:MHoeRWF?mHYeSo000000So5^TF00?o0000
o`gb3Ol=lPd00_l=lPd00ol0003o0?l0o`3o0006o`3o00Co00003?lgb3L00ol0003o9]TVobKI9P08
obKI9P?o00000_liaST3o`000003ocC;=?l0003oA;]400goA;]400?o0000ohebSOn=LXd01?n=LXd0
0ol0003oUFZEoiEZU@0:oiEZU@03o`000?oA;]7odBkA00GodBkA00?o0000onl@koo_4>l01_o_4>l0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onXEj_oZ5NX02ooZ5NX00ol0003o_4>loka3_007oka3
_003o`000?mC[5?oDjaC00?oDjaC0_l00005oeRWF003o`000?lFjAKo5^TF00Co5^TF00?o0000o`gb
3Ol=lPd00ol=lPd00ol0003o0?l0o`3o0005o`3o0003o`000?l6n@Ko1_T600;o1_T60ol00007ocO8
=`;o00003_lVfBH2o`0000Go=</d00?o0000odBkA?m4^d@02_m4^d@00ol0003oSG:=ohebS@05oheb
S@03o`000?nEJYGoUFZE00_oUFZE00?o0000om4^dOoA;]401?oA;]400ol0003oka3_onl@k`06onl@
k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ojQGZonXEjP0;onXEjP03o`000?nl@kco_4>l00Oo
_4>l00?o0000oe>/DomC[5<00_mC[5<00ol0003oF:MHoeRWF006oeRWF003o`000?lFjAKo5^TF00;o
5^TF00?o0000o`gb3Ol=lPd01Ol=lPd00ol0003o0?l0o`3o0002o`3o00;o00002?l6n@H3o`0000;o
=lPg0_l000000ol<l`co0000obKI9P0=obKI9P03o`000?ldbcCo=</d00Go=</d00?o0000odBkA?m4
^d@02?m4^d@00ol0003oSG:=ohebS@07ohebS@03o`000?nEJYGoUFZE00[oUFZE00?o0000om4^dOoA
;]401?oA;]400ol0003oka3_onl@k`06onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojQGZ
onXEjP0<onXEjP03o`000?nl@kco_4>l00So_4>l00Co0000oe>/DomC[5?o00002OmHYeP01Ol0003o
5^TFoaKY5_lFjAKo000000So3O8=00Go0000o`3o0?l0o`3o0?l0o`00000=o`Ki1P;o00001?l<l``0
0ol0003o9]TVobKI9P0;obKI9P03o`000?ldbcCo=</d00Ko=</d00?o0000odBkA?m4^d@01om4^d@0
0ol0003oSG:=ohebS@08ohebS@Co00002?nEJYD00ol0003odBkAom4^d@04om4^d@03o`000?o_4>oo
ka3_00Koka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oZ5N[ojQGZ00_ojQGZ0ol00009oka3
_003o`000?mC[5?o000000_oF:MH00?o0000oaKY5_l000002_l=lPd00ol0003o0?l0o`00000?o`Ki
1P03o`000?l<l`co3?<<00;o3?<<00?o0000obKI9_lVfBH02olVfBH00ol0003o=</docC;=006ocC;
=003o`000?m4^dCoA;]400KoA;]400?o0000ohebSOn=LXd02On=LXd01?l0003o^TFjokY5^_njAKX7
o`0000;oUFZE00?o0000om4^dOoA;]400ooA;]400ol0003oka3_onl@k`05onl@k`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?oZ5N[ojQGZ00SojQGZ0ol00003onHIiP03o`000?nl@kco_4>l00Oo_4>l00?o0000oeRW
F?mHYeP02omHYeP00ol0003o3O8=o`gb3@0:o`gb3@03o`000?l6n@Ko1_T600go1_T600?o0000o`cc
3?l<l``01?l<l``00ol0003o9]TVobKI9P09obKI9P03o`000?ldbcCo=</d00So=</d00?o0000odBk
A?m4^d@00om4^d@2o`0000coSG:=00?o0000okY5^_njAKX02?njAKX<o`0000?oka3_0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onXEj_oZ5NX01_oZ5NX3o`0000OoiQWV00?o0000oka3_?nl@k`01_nl@k`00ol0003o
F:MHoeRWF00;oeRWF003o`000?l=lPgo3O8=00Wo3O8=0_l0000>o`Ki1P03o`000?l<l`co3?<<00Go
3?<<00?o0000obKI9_lVfBH02OlVfBH00ol0003o=</docC;=009ocC;=003o`000?m4^dCo000000;o
00000_n1OX400ol0003oSG:=ohebS@08ohebS@03o`000?njAK[o^TFj00co^TFj00?o0000onTFjOoY
5^T01_oY5^T3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003ojQGZonXEjP03onXEjP?o00002ooV6NH00ol0003o_4>l
oka3_004oka3_003o`000?mHYeSoF:MH00_oF:MH0ol00007o`gb3@?o000000?o2o@;o`000?l6n@H0
3Ol6n@H00ol0003o3?<<o`cc3006o`cc3003o`000?lVfBKo9]TV00So9]TV00?o0000ocC;=?ldbc@0
2_ldbc@00ol0003oPGj1oh5nP@04oh5nP@03o`000?n=LXgoSG:=00OoSG:=00?o0000okY5^_njAKX0
2onjAKX00ol0003ojAKYonTFj@08onTFj@03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onXEj_l0
003o0000o`0000ooiQWV00?o0000oka3_?nl@k`00onl@k`>o`0000?o@ka30_l00002o`gb3@?o0000
1Ol;m0/00ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?l<l`co3?<<00Oo3?<<00?o0000obKI9_lVfBH0
2?lVfBH00ol0003o=</docC;=00:ocC;=003o`000?n1OX7oPGj100GoPGj100?o0000ohebSOn=LXd0
1_n=LXd00ol0003o^TFjokY5^P0;okY5^P03o`000?oY5^WojAKY00SojAKY00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;oiQWV00?o0000oka3_?nl@k`00_nl@k`00ol0003oYUVVojII
YP0:ojIIYP03o`000?m3_4?o@ka300?o@ka30_l00009o`_d2`03o`000?l6n@Ko1_T600Wo1_T600?o
0000o`cc3?l<l``02?l<l``2o`0000So9]TV00?o0000ocC;=?ldbc@02Oldbc@00ol0003oPGj1oh5n
P@07oh5nP@03o`000?n=LXgoSG:=00CoSG:=00?o0000okY5^_njAKX02onjAKX00ol0003ojAKYonTF
j@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oiQWVonHIiP0?onHIiP?o000000?o_4>l
o`000?nVFJH02onVFJH00ol0003o@ka3od>l@`04od>l@`03o`000?l;m0_o2o@;00Wo2o@;00?o0000
o`Ki1_l6n@H01ol6n@H00ol0003o3?<<o`cc3009o`cc3004o`000?lCk1?o0000o`0000Ko9]TV00?o
0000ocC;=?ldbc@02Oldbc@00ol0003oPGj1oh5nP@08oh5nP@03o`000?n=LXgoSG:=00?oSG:=00?o
0000okY5^_njAKX02onjAKX00ol0003ojAKYonTFj@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oiQWVonHIiP0<onHIiP;o00000ooU6^D2o`0000coYUVV00?o0000od>l@om3_4<01?m3_4<0
0ol0003o2o@;o`_d2`0:o`_d2`Wo00002ol<l``00ol0003o4n`Coa?/4`02oa?/4`?o00000_lVfBH0
0ol0003o=</docC;=00:ocC;=003o`000?n1OX7oPGj100WoPGj100?o0000ohebSOn=LXd00_n=LXd0
0ol0003o^TFjokY5^P0:okY5^P03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oV6NH2o`0000GoiA[U00?o0000oki1__l000002_nVFJH00ol0003o@ka3od>l@`06od>l
@`03o`000?l;m0_o2o@;00Wo2o@;00?o0000o`3o0?l0o`001Ol0o`000ol0003o3?<<o`cc3009o`cc
3003o`000?lCk1?o4n`C00Go4n`C0ol00009ocC;=0?o00003On1OX401Ol0003oSG:=ohebSOn=LXgo
000000co^TFj00?o0000onTFjOoY5^T02OoY5^T00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onHI
i_oV6NH01OoV6NH2o`0000OoiA[U00Co0000oki1__nn@Kko00002OnVFJH00ol0003o@ka3od>l@`06
od>l@`03o`000?l;m0_o2o@;00So2o@;00?o0000o`3o0?l0o`001ol0o`000ol0003o3?<<o`cc3007
o`cc3003o`000?lCk1?o4n`C00So4n`C0ol00002ocC;=0Go00000_mQWV400ol0003oPGj1oh5nP@0<
oh5nP@03o`000?n=LXgo000000co^TFj00?o0000onTFjOoY5^T02_oY5^T00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onHIi_oV6NH00_oV6NH2o`0000SoiA[U00?o0000oki1__nn@Kh00_nn@Kh5o`00
00CoYUVV00?o0000od>l@om3_4<01_m3_4<00ol0003o2o@;o`_d2`08o`_d2`03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`cc3?l<l``01ol<l``00ol0003o4n`Coa?/4`08oa?/4`03o`000?l]dRgo;M8]
00;o00002?mQWV400ol0003oPGj1oh5nP@0<oh5nP@Co00002_njAKX00ol0003ojAKYonTFj@0:onTF
j@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oiQWVo`000?l0000:onDJi@03o`000?nn@Kko_T6n
00;o_T6n00?o0000ohAkQ?n4Nh@00_n4Nh@4o`0000Wo@ka300?o0000o`_d2ol;m0/02?l;m0/00ol0
003o0?l0o`3o0008o`3o0003o`000?l<l`co3?<<00Go3?<<00?o0000oa?/4olCk1<02?lCk1<01Ol0
003o;M8]obgB;Ol]dRgo000000[oHIiQ0ol0000;oh5nP@04o`000?oK9=_ofbCKom/Tf`Co00001Onj
AKX00ol0003ojAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oiA[UonDJi@0:
onDJi@03o`000?nn@Kko_T6n00?o_T6n00?o0000ohAkQ?n4Nh@01?n4Nh@00ol0003o@ka3od>l@`07
od>l@`03o`000?l;m0_o2o@;00Ko2o@;0_l0000;o`3o0003o`000?l<l`co3?<<00Go3?<<00?o0000
oa?/4olCk1<02?lCk1<00ol0003o;M8]obgB;@02obgB;@03o`000?mQWV7oHIiQ00OoHIiQ00?o0000
ojiA[_n^DJh01?l00006oh5nP@03o`000?oK9=_ofbCK00KofbCK0ol00002okY5^P03o`000?oY5^Wo
jAKY00_ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oU6^GoiA[U00WoiA[U00?o0000oki1
__nn@Kh01?nn@Kh00ol0003oQ7^4ohAkQ005ohAkQ003o`000?m3_4?o@ka300Oo@ka300?o0000o`_d
2ol;m0/00_l;m0/3o`000003oaWV6Ol0003o0?l000[o0?l000?o0000o`cc3?l<l``01Ol<l``00ol0
003o4n`Coa?/4`07oa?/4`03o`000?l]dRgo;M8]00?o;M8]00?o0000of6NHOmQWV401omQWV400ol0
003o[U6^ojiA[P04ojiA[P?o00000_n1OX400ol0003ofbCKom/Tf`0:om/Tf`;o00003_oY5^T00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onDJiOoU6^D02OoU6^D00ol0003o_T6noki1_P04oki1_P03
o`000?n4NhCoQ7^400KoQ7^40_l00007od>l@`03o`000?l;m0_o000000;o00001OlIiQT00ol0003o
0?l0o`3o0008o`3o00?o00001?l<l``00ol0003o4n`Coa?/4`08oa?/4`03o`000?l]dRgo;M8]00Co
;M8]00?o0000of6NHOmQWV401_mQWV400ol0003o[U6^ojiA[P07ojiA[P;o00003_oK9=/00ol0003o
jAKYonTFj@0;onTFj@03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiA[UonDJi@08onDJi@03o`00
0?nn@Kko_T6n00Go_T6n00?o0000ohAkQ?n4Nh@01?n4Nh@00ol0003oNhAkog^4N`03o`0000Co@ka3
0_l00008oaWV6@03o`000?l0o`3o0?l000Oo0?l000Co0000obgB;Ol]dRgo;M8]0ol000000ol<l`co
0000oa?/4`09oa?/4`03o`000?l]dRgo;M8]00Co;M8]00?o0000of6NHOmQWV401OmQWV400ol0003o
[U6^ojiA[P09ojiA[P03o`000?oK9=_ofbCK00gofbCK00?o0000onTFjOoY5^T02_oY5^T00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onDJiOoU6^D01ooU6^D00ol0003o_T6noki1_P06oki1_P03o`00
0?n4NhCoQ7^400?oQ7^400?o0000og^4NomkQ7/01?mkQ7/2o`000003od>l@ol0003o6NHI00[o6NHI
00?o0000o`3o0?l0o`001Ol0o`000ol0003o;M8]obgB;@05obgB;@03o`000?lCk1?o4n`C00Oo4n`C
0ol00007obgB;@03o`000?mQWV7oHIiQ00CoHIiQ00?o0000ojiA[_n^DJh02On^DJh00ol0003ofbCK
om/Tf`0=om/Tf`03o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oU
6^GoiA[U00GoiA[U0ol00009oki1_P05o`000?n4NhCoQ7^4ohAkQ?l000002OmkQ7/00ol0003o6NHI
oaWV6@0;oaWV6@03o`000?l0o`3o0?l000?o0?l000?o0000obgB;Ol]dRd01_l]dRd00ol0003o4n`C
oa?/4`06oa?/4`05o`000?ldbcCo=</docC;=?l000001ol]dRd00ol0003oHIiQof6NH@03of6NH@03
o`000?n^DJko[U6^00Wo[U6^00?o0000om/TfooK9=/03_oK9=/00ol0003ojAKYonTFj@09onTFj@03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiA[Uo`000004o`0000;okA;]00?o0000oki1__nn@Kh0
1onn@Kh01?l0003oQ7^4ohAkQ?l00009og^4N`;o00003OlIiQT00ol0003o0?l0o`3o0002o`3o0003
o`000?l]dRgo;M8]00So;M8]00?o0000oa?/4olCk1<00olCk1<2o`0000Go=</d00?o0000obgB;Ol]
dRd01?l]dRd00ol0003oHIiQof6NH@03of6NH@03o`000?n^DJko[U6^00Wo[U6^00?o0000om/TfooK
9=/03_oK9=/00ol0003ojAKYonTFj@09onTFj@03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000SokA;]
00?o0000oki1__nn@Kh01_nn@Kh00ol0003oQ7^4o`000009og^4N`04o`000?mFZEKoEZUFo`0000go
6NHI00Co0000o`3o0?l0o`3o00003?l]dRd01Ol0003o4n`Coa?/4olCk1?o000000So=</d0_l00005
obgB;@03o`000?mQWV7oHIiQ00;oHIiQ00?o0000ojiA[_n^DJh02On^DJh00ol0003ofbCKom/Tf`0>
om/Tf`03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o]4^gokA;]
00OokA;]00?o0000oki1__nn@Kh01onn@Kh00ol0003oNhAkog^4N`07og^4N`03o`000?mFZEKoEZUF
00;oEZUF00?o0000oaWV6OlIiQT02_lIiQT00ol0003o0?l0o`00000>obgB;@03o`000?lCk1?o0000
00_o=</d00?o0000obgB;Ol]dRd00_l]dRd01Ol0003oHIiQof6NHOmQWV7o000000co[U6^00?o0000
om/TfooK9=/03_oK9=/3o`0000WojAKY00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o]4^gokA;]
00WokA;]00?o0000oki1__nn@Kh01_nn@Kh00ol0003oNhAkog^4N`06og^4N`03o`000?mFZEKoEZUF
00?oEZUF00?o0000oaWV6OlIiQT02olIiQT00ol0003o;M8]obgB;@0>obgB;@03o`000?ldbcCo=</d
00_o=</d0_l00003obgB;@04o`000?mQWV7oHIiQo`0000[o[U6^0ol0000>om/Tf`;o00000ool0o`2
o`0000OojAKY00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o]4^gokA;]00[okA;]00?o0000oki1
__nn@Kh01?nn@Kh00ol0003oNhAkog^4N`06og^4N`03o`000?mFZEKoEZUF00GoEZUF00?o0000oaWV
6OlIiQT01olIiQT3o`00017o;M8]00?o0000ocC;=?ldbc@03Oldbc@01Ol0003o;M8]obgB;Ol0003o
HIiQ00Co00000on^DJh5o`0000;oiaSW00?o0000om/TfooK9=/02_oK9=/2o`0000Ooo0?l0_l00004
onTFj@03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okA;]ondBk@0;ondBk@03o`000?nn@Kko_T6n
00Co_T6n00?o0000og^4NomkQ7/01OmkQ7/00ol0003oEZUFoeJYEP06oeJYEP03o`000?lIiQWo6NHI
00Co6NHI0ol00002ob3O8003o`000?l]dRgo;M8]00oo;M8]0_l0000?ocC;=004o`000?l]dRgo0000
o`0000CoVFJI0ol00008onLHi`03o`000?oK9=_ofbCK00OofbCK0_l0000;oo`3o0;o00000_oY5^T0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000ondBkOo]4^d03?o]4^d6o`0000OoNhAk00?o0000oeJY
E_mFZEH02?mFZEH00ol0003o6NHIoaWV6@03o`0000Ko8=lP00?o0000obgB;Ol]dRd03Ol]dRd01?l0
003o?l0ooco0?ol0000?ocC;=003o`000?nIIYWoVFJI00GoVFJI00?o0000onLHiooW6>L02?oW6>L0
0ol0003ofbCKom/Tf`05om/Tf`03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o]4^d00ol0003oa3_4ol@ka004ol@k
a003o`000?mkQ7_oNhAk00?oNhAk00?o0000oeJYE_mFZEH02_mFZEH2o`0000[o8=lP00?o0000obgB
;Ol]dRd02ol]dRd00ol0003o?l0ooco0?`02oco0?`03o`000?ldbcCo=</d00_o=</d0_l00007oiUV
V@03o`000?oW6>OoiaSW00WoiaSW00?o0000om/TfooK9=/00_oK9=/2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000ondBkOo]4^d02oo]4^d00ol0003oa3_4ol@ka006ol@ka005o`000?mkQ7_oNhAkog^4
Nol000003OmFZEH00ol0003o8=lPob3O800:ob3O8003o`000?l]dRgo;M8]00Wo;M8]00?o0000oco0
?olo`3l01?lo`3l00ol0003o=</docC;=008ocC;=0;o000000?oCK9=o`000?nIIYT01onIIYT00ol0
003oiaSWonLHi`09onLHi`04o`000?oK9=_o0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?o]4^gokA;]
00WokA;]00?o0000ol@ka?o4>l@02?o4>l@00ol0003oNhAko`00000=oeJYEP03o`000?lPgb3o8=lP
00_o8=lP00?o0000obgB;Ol]dRd02?l]dRd00ol0003o?l0ooco0?`06oco0?`03o`000?ldbcCo=</d
00Go=</d0_l00003odfbC@03o`000?nIIYWoVFJI00KoVFJI00?o0000onLHiooW6>L02_oW6>L00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003okA;]ondBk@07ondBk@03o`000?o4>lCoa3_400[oa3_400?o0000oeJYE_mF
ZEH03?mFZEH00ol0003o8=lPob3O800<ob3O8003o`000?l]dRgo;M8]00Ko;M8]00?o0000oco0?olo
`3l02?lo`3l00ol0003o=</docC;=002ocC;=0;o00001_m=/Td00ol0003oVFJIoiUVV@05oiUVV@03
o`000?oW6>OoiaSW00[oiaSW00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o]4^gokA;]00GokA;]
00?o0000ol@ka?o4>l@03?o4>l@2o`0000coEZUF00?o0000ob3O8?lPgb003OlPgb000ol0003o;M8]
obgB;@04obgB;@03o`000?lo`3oo?l0o00[o?l0o00Co0000ocC;=?l0003o00002?m=/Td00ol0003o
VFJIoiUVV@06oiUVV@03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_o]4^d00ol0003oa3_4ol@ka00=ol@ka003o`000?mjQG[o000000;o00002?mFZEH00ol0003o8=lP
ob3O800?ob3O80Ko00003_lo`3l00ol0003oCK9=odfbC@08odfbC@03o`000?nIIYWoVFJI00KoVFJI
00?o0000onLHiooW6>L02OoW6>L00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000oo0?l?o`3o3ol0o`
0_l0000?ol@ka003o`000?mjQG[oNXEj00?oNXEj0ol00005oeJYEP;o00004?lPgb001_l0003o5nPG
oaOX5ol0003o3?<<o`0000ko?l0o00?o0000odfbCOm=/Td02Om=/Td00ol0003oVFJIoiUVV@05oiUV
V@03o`000?oW6>OoiaSW00WoiaSW00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000oo0?l?o`3o000oo`3o000ol0003o
a3_4ol@ka00=ol@ka003o`000?mjQG[oNXEj00KoNXEj0ol000001?mFZEKo0000oc3?<?l`cc03o`00
00co8=lP00Go0000oaOX5olGj1Oo5nPGo`000002o`cc3003o`000?lo`3oo?l0o00_o?l0o00?o0000
odfbCOm=/Td02Om=/Td00ol0003oVFJIoiUVV@06oiUVV@03o`000?oW6>OoiaSW00SoiaSW0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003ol0o`oo0?l004oo0?l0oo00003?mjQGX00ol0003o<<l`oc3?<004oc3?
<0?o00002?lPgb000ol0003o5nPGoaOX5`02oaOX5`05o`000?l<l`co3?<<o`cc3?l000003?lo`3l0
0ol0003oCK9=odfbC@09odfbC@03o`000?nIIYWoVFJI00GoVFJI3?l00002ooD:m@;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003ol0o`oo0?l005oo0?l003o`000?o6>LKoaSW600_oaSW600?o0000ogZ5
N_mjQGX02_mjQGX00ol0003o<<l`oc3?<007oc3?<0;o00001OlPgb000ol0003o5nPGoaOX5`03oaOX
5`03o`000?l<l`co3?<<00;o3?<<00?o0000oco0?olo`3l02Olo`3l00ol0003oCK9=odfbC@0:odfb
C@03o`000?nIIYWoVFJI00?oVFJI00?o0000omdRgOoM8]d02OoM8]d00ol0003om@[eooD:m@02ooD:
m@;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ol0o`oo0?l006oo0?l003o`000?o6>LKoaSW600[o
aSW600?o0000ogZ5N_mjQGX02omjQGX00ol0003o<<l`oc3?<009oc3?<0?o000000?o8=lPo`000?lG
j1L01OlGj1L00ol0003o3?<<o`cc3003o`cc3003o`000?lo`3oo?l0o00So?l0o3_l00003oiUVV@;o
00002ooM8]d00ol0003om@[eooD:m@05ooD:m@03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000oo0?l?o`3o001Oo`3o000ol0003odBkAo`00000;olHiaP03o`000?mjQG[oNXEj00[oNXEj
0_l0000>oc3?<003o`000?lGj1Oo5nPG00Go5nPG00?o0000o`cc3?l<l``00ol<l``00ol0003o?l0o
oco0?`08oco0?`03o`000?nEJYGoUFZE00_oUFZE00?o0000oiUVVOl000003OoM8]d00ol0003om@[e
ooD:m@06ooD:m@;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o`3o3ol0o`00Kol0o`00Co
0000om4^dOoA;]7o00002_o6>LH00ol0003oNXEjogZ5NP09ogZ5NP03o`000?mC[5?o000000ko<<l`
00?o0000oaOX5olGj1L01OlGj1L00ol0003o3?<<o`cc3004o`cc3003o`000?lo`3oo?l0o00Ko?l0o
00?o0000oiEZUOnEJYD03OnEJYD00ol0003ogB;MomdRg@0<omdRg@03o`000?oe2_Gom@[e00Som@[e
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?o`3o3ol0o`00Gol0o`00?o0000om4^dOoA;]400_oA
;]400ol0003oaSW6olHiaP06olHiaP03o`000?mjQG[oNXEj00SoNXEj0_l00003oe>/D`03o`000?l`
cc3o<<l`00_o<<l`00?o0000oaOX5olGj1L01OlGj1L00ol0003o3?<<o`cc3005o`cc3003o`000?lo
`3oo?l0o00Go?l0o00?o0000oiEZUOnEJYD03OnEJYD00ol0003ogB;MomdRg@0;omdRg@03o`000?oe
2_Gom@[e00Wom@[e00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o`3o3ol0o`00Kol0o`00?o0000
om4^dOoA;]400ooA;]400ol0003oaSW6olHiaP05olHiaP03o`000?mjQG[oNXEj00OoNXEj00?o0000
oe>/DomC[5<00omC[5<00ol0003o<<l`oc3?<00:oc3?<003o`000?lGj1Oo5nPG00Ko5nPG00?o0000
o`cc3?l<l``01_l<l``00ol0003o?l0ooco0?`04oco0?`03o`000?nEJYGoUFZE00goUFZE3ol0000;
ooD:m@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?o`3o3ol0o`00Kol0o`00?o0000om4^dOoA;]401OoA;]400ol0
003oaSW6olHiaP04olHiaP03o`000?mjQG[oNXEj00GoNXEj0_l00006oe>/D`03o`000?l`cc3o<<l`
00Wo<<l`0_l00008oaOX5`03o`000?l<l`co3?<<00Ko3?<<1Ol000000olo`3oo0000oiEZU@0?oiEZ
U@03o`000?oO7moogaoO00_ogaoO00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00;o
o0?l1Ol00003oo`3o003o`000?o`3o3ol0o`00Kol0o`00?o0000om4^dOoA;]401_oA;]400ol0003o
aSW6olHiaP04o`0000KoNXEj00?o0000oe>/DomC[5<01omC[5<00ol0003o<<l`oc3?<005oc3?<0?o
000000?o7n0Oo`000?lGj1L01olGj1L00ol0003o3?<<o`cc3005o`cc3003o`000?m>/DkoC[5>00?o
C[5>0_l0000?oiEZU@;o00003OoO7ml00ol0003om@[eooD:m@08ooD:m@03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000oo`3o?ol0o`0
1ool0o`3o`0000Wol0o`00?o0000om4^dOoA;]401ooA;]42o`0000CoZEJY00Co0000ogZ5N_mjQG[o
NXEj0_l0000:oe>/D`03o`000?l`cc3o<<l`00;o<<l`0ol00005oaoP7`03o`000?lGj1Oo5nPG00Go
5nPG00?o0000o`cc3?l<l``01?l<l``00ol0003oC[5>odjaCP06odjaCP03o`000?nEJYGoUFZE00[o
UFZE0_l00002oklo_`03o`000?oO7moogaoO00[ogaoO00?o0000ooD:mOoe2_D02?oe2_D00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?ol0ocoo0?l00Woo0?l00?o0000oo0?l?o`3o001_o`3o000ol0003odBkAom4^d@08om4^d@03o`00
0?nYEZWoZEJY00CoZEJY00?o0000ogZ5N_l000003?mC[5<00ol0003o<<l`o`000002o`0000Wo7n0O
00?o0000oaOX5olGj1L01?lGj1L00ol0003o3?<<o`cc3003o`cc3003o`000?m>/DkoC[5>00SoC[5>
1_l00004oiEZU@;o00001Ono?kl00ol0003ogaoOomlOg`09omlOg`03o`000?oe2_Gom@[e00Som@[e
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo0?loo`3o00:oo`3o003o`000?o`3o3ol0o`00Gol0o`00?o0000om4^dOoA;]401ooA
;]400ol0003oZEJYojUFZ@06ojUFZ@03o`000?mC[5?oDjaC00coDjaC00?o0000oaoP7olOh1l02_lO
h1l00ol0003o5nPGoaOX5`04oaOX5`04o`000?l<l`co3?<<o`cc30;o00002om>/Dh00ol0003oVfBK
oi]TV`03oi]TV`Co00002?no?kl00ol0003ogaoOomlOg`08omlOg`03o`000?oe2_Gom@[e00Oom@[e
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?ol
0ocoo0?l00_oo0?l00?o0000oo0?l?o`3o000oo`3o000ol0003odBkAom4^d@07om4^d@03o`000?nY
EZWoZEJY00OoZEJY00?o0000oe>/DomC[5<03?mC[5<00ol0003o7n0OoaoP7`0;oaoP7`03o`000?lG
j1Oo5nPG00?o5nPG00Co0000o`cc3?l<l`co00003Om>/Dh00ol0003oVfBKoi]TV`06oi]TV`03o`00
0?no?koo_cno00Oo_cno00?o0000omlOgooO7ml01ooO7ml00ol0003om@[eooD:m@06ooD:m@04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o`3o3ol0o`00;ol0o`00?o0000om4^dOoA;]40
1_oA;]400ol0003oZEJYojUFZ@09ojUFZ@03o`000?mC[5?oDjaC00WoDjaC0_l0000>oaoP7`?o0000
0olGj1L00ol0003o3?<<o`00000=odjaCP03o`000?nKI9_oVfBK00OoVfBK00?o0000oklo_ono?kl0
2?no?kl:o`0000Kom@[e0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000oo`3o?ol0o`03Ool0o`6o`0000OodBkA00?o
0000ojUFZOnYEZT02_nYEZT00ol0003oDjaCoe>/D`06oe>/D`;o000000?oBkA;o`000?lOh1l02olO
h1l2o`0000?o?<<l1Ol0000>odjaCP03o`000?nKI9_oVfBK00OoVfBK00?o0000oklo_ono?kl02?no
?kl00ol0003oiaSWonLHi`06onLHi`03o`000?oe2_Gom@[e00?om@[e00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
oo`3o?ol0o`03Ool0o`00ol0003oiQWVonHIiP03onHIiPCo00000_oA;]400ol0003oZEJYojUFZ@0;
ojUFZ@03o`000?mC[5?oDjaC00?oDjaC0ol00004od^dB`03o`000?lOh1oo7n0O00Oo7n0O0_l00008
occ3?003o`000?m>/DkoC[5>00goC[5>00?o0000oi]TVonKI9/02?nKI9/00ol0003o_cnooklo_`07
oklo_`03o`000?oW6>OoiaSW00OoiaSW0ol000000ooe2_Go0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?oV6NKoiQWV00OoiQWV0_l0000?ojUFZ@03o`000?mC[5?oDjaC00;o00002?m;]4/00ol0
003o7n0OoaoP7`05oaoP7`03o`000?ll`cco?<<l00So?<<l00?o0000odjaC_m>/Dh03Om>/Dh00ol0
003oVfBKoi]TV`08oi]TV`03o`000?no?koo_cno00Ko_cno00?o0000onLHiooW6>L02?oW6>L01?l0
003omPWfooH9m_l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003oiQWVonHIiP09onHI
iP03o`000?nYEZWoZEJY00koZEJY0_l0000;od^dB`03o`000?lOh1oo7n0O00;o7n0O0_l0000;occ3
?003o`000?m>/DkoC[5>00goC[5>00?o0000oi]TVonKI9/02?nKI9/00ol0003o_cnooklo_`06oklo
_`03o`000?oW6>OoiaSW00OoiaSW00Go0000ooH9m_of2OKomPWfo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`03Ool0o`00ol0
003oiQWVonHIiP0:onHIiP03o`000?nYEZWoZEJY00goZEJY0_l0000<od^dB`04o`000?lOh1oo0000
o`0000go?<<l00?o0000odjaC_m>/Dh03?m>/Dh00ol0003oVfBKoi]TV`09oi]TV`03o`000?no?koo
_cno00Ko_cno00?o0000onLHiooW6>L01_oW6>L00ol0003omPWfooH9mP03ooH9mP03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000oo`3
o?ol0o`03Ool0o`00ol0003oiQWVonHIiP0:onHIiP03o`000?nYEZWoZEJY00coZEJY00Co0000oi5^
TOnAKY7o00003?m;]4/00ol0003o?<<locc3?00>occ3?003o`000?m>/DkoC[5>00SoC[5>1?l0000;
oi]TV`03o`000?no?koo_cno00Ko_cno00?o0000onLHiooW6>L01OoW6>L00ol0003omPWfooH9mP04
ooH9mP03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003oiQWVonHIiP0;onHIiP03o`000?nYEZWoZEJY
00_oZEJY00?o0000oi5^TOnAKY400_nAKY400ol0003oBkA;od^dB`09od^dB`03o`000?ll`cco?<<l
00ko?<<l00Co0000odjaC_m>/DkoC[5>1ol00003ofVFJ@03o`000?nKI9_oVfBK00WoVfBK00?o0000
oklo_ono?kl01_no?kl00ol0003oiaSWonLHi`04onLHi`03o`000?of2OKomPWf00KomPWf00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oV6NKoiQWV00coiQWV00?o0000ojUFZOnYEZT02_nYEZT00ol0
003oTFjAoi5^T@03oi5^T@03o`000?m;]4_oBkA;00SoBkA;00?o0000occ3??ll`c`03_ll`c`4o`00
00_oJIIY00?o0000oi]TVonKI9/02?nKI9/00ol0003o_cnooklo_`05oklo_`03o`000?oW6>OoiaSW
00GoiaSW00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onHIi_oV
6NH03?oV6NH7o`0000GoZEJY00?o0000oi5^TOnAKY401OnAKY400ol0003oBkA;od^dB`07od^dB`03
o`000?ll`cco?<<l00ko?<<l00?o0000ofVFJOmYUVT03OmYUVT00ol0003oVfBKoi]TV`08oi]TV`03
o`000?no?koo_cno00Co_cno00?o0000onLHiooW6>L01?oW6>L00ol0003omPWfooH9mP07ooH9mP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000oo`3o?ol0o`02_ol0o`00ol0003oiQWVonHIiP0=onHIiP03o`000?o8=lSob3O800Cob3O8
1Ol00009oi5^T@03o`000?m;]4_oBkA;00KoBkA;00?o0000occ3??ll`c`03_ll`c`00ol0003oJIIY
ofVFJ@0=ofVFJ@03o`000?nKI9_oVfBK00SoVfBK00Co0000oklo_ono?koo_cno1Ol00004onLHi`03
o`000?of2OKomPWf00WomPWf1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?ol0ocoo0?l00Soo0?l0ol0000=onHIiP03o`000?o8=lSob3O800Wob3O8
0_l00009oi5^T@03o`000?m;]4_oBkA;00KoBkA;00?o0000occ3??ll`c`03?ll`c`00ol0003oJIIY
ofVFJ@0?ofVFJ@Ko00001?nKI9/4o`0000GohQgR0_l000000ooW6>Oo0000ooH9mP0;ooH9mP04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo0?loo`3o006oo`3o004o`000?ob3O;olPgboo8=lP?o00002_oV6NH00ol0003o
b3O8olPgb009olPgb003o`000?nSG:?o000000;o00001onAKY400ol0003oBkA;od^dB`05od^dB`03
o`000?ll`cco?<<l00So?<<l1Ol0000AofVFJ@03o`000?n[E:_oZeB[00?oZeB[1?l0000;on8MhP03
o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?ol0ocoo0?l00Coo0?l00?o0000oo8=l_ob3O801Oob3O82o`0000OoiQWV
00?o0000olPgb?o8=lP02_o8=lP00ol0003oXebSoj=LX`02oj=LX`?o00001OnAKY400ol0003oBkA;
od^dB`04od^dB`04o`000?ll`cco?<<locc3?0Oo00001?mIYUT00ol0003oJIIYofVFJ@0>ofVFJ@03
o`000?n[E:_oZeB[00OoZeB[00?o0000on8Mh_oR7N802OoR7N800ol0003omPWfooH9mP09ooH9mP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000oo`3o?ol0o`00_ol0o`00ol0003olPgboo8=lP08oo8=lP;o00001?oV6NH00ol0003ob3O8
olPgb00;olPgb003o`000?nSG:?oXebS00GoXebS0ol00003oi5^T@04o`000?m;]4_oBkA;od^dB`Ko
00003?mIYUT00ol0003oJIIYofVFJ@0=ofVFJ@03o`000?n[E:_oZeB[00OoZeB[00?o0000on8Mh_oR
7N802_oR7N800ol0003omPWfooH9mP08ooH9mP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo8=lP?o000000?oiQWVo`000?o8=lP0
3?o8=lP00ol0003oXebSoj=LX`08oj=LX`?o000000CoTFjAo`000?l0003o00000_nNHIh00ol0003o
FJIIoeVVF@0=oeVVF@03o`000?mYUVWoJIIY00coJIIY00?o0000oj]DZon[E:/02?n[E:/00ol0003o
hQgRon8MhP0;on8MhP03o`000?of2OKomPWf00KomPWf00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
lPgb00?o0000olPgb?o8=lP03?o8=lP00ol0003oXebSoj=LX`0;oj=LX`03o`000?nNHIkoWV6N00?o
WV6N00?o0000oeVVFOmIYUT03?mIYUT00ol0003oHYeRo`00000=ofVFJ@03o`000?n[E:_oZeB[00So
ZeB[00?o0000on8Mh_oR7N803?oR7N83o`0000GomPWf00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?ob3O;olPgb00colPgb00?o0000olPgb?o8=lP03?o8=lP00ol0003oXebSoj=LX`0:oj=LX`03o`00
0?nNHIkoWV6N00GoWV6N00?o0000oeVVFOmIYUT02_mIYUT01?l0003oHYeRof:MH_mRWF82o`0000[o
JIIY00?o0000oj]DZon[E:/02On[E:/00ol0003ohQgRon8MhP0<on8MhP03o`000?og2?Oom`Sg00?o
000000?omPWfo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?ob3O;olPgb00_olPgb00?o0000olPgb?o8=lP0
3?o8=lP00ol0003oXebSoj=LX`09oj=LX`03o`000?nNHIkoWV6N00KoWV6N00?o0000oeVVFOmIYUT0
2OmIYUT00ol0003oHYeRof:MHP02of:MHP03o`000?nOH9oo000000;o00001omYUVT00ol0003oZeB[
oj]DZ`09oj]DZ`03o`000?oR7N;ohQgR00_ohQgR00?o0000ooL8moog2?L01?og2?L00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo8=l_ob3O802oob3O800ol0003ob3O8olPgb00;olPgb003o`000?nS
G:?oXebS00SoXebS00?o0000oiiQW_nNHIh01onNHIh00ol0003oFJIIoeVVF@08oeVVF@03o`000?mR
WF;oHYeR00?oHYeR00?o0000oimPWonOH9l00_nOH9l2o`0000CoJIIY00?o0000oj]DZon[E:/02_n[
E:/00ol0003ohQgRon8MhP0:on8MhP03o`000?og2?Oom`Sg00Gom`Sg00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?ob3O;olPgb00[olPgb0ol0000;olPgb0Ko00001?nSG:<00ol0003oWV6NoiiQWP08
oiiQWP03o`000?mIYUWoFJII00OoFJII00?o0000of:MH_mRWF800omRWF800ol0003oWf2OoimPW`05
oimPW`?o000000?oJIIYo`000?n[E:/02on[E:/00ol0003ohQgRon8MhP09on8MhP03o`000?og2?Oo
m`Sg00Oom`Sg00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;olPgb00WolPgb00?o0000on<L
hooS7><01?l00006olPgb003o`000?o8=lSob3O800Cob3O81?l0000<oiiQWP03o`000?mIYUWoFJII
00GoFJII00?o0000of:MH_mRWF801?mRWF800ol0003oWf2OoimPW`08oimPW`03o`000?n[E:_oZeB[
00_oZeB[00?o0000on8Mh_oR7N802?oR7N800ol0003om`SgooL8m`08ooL8m`Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?ob3O;olPgb00OolPgb00?o0000on<LhooS7><01OoS7><3o`0000;ob3O800?o0000olPgb?o8
=lP02?o8=lP00ol0003oWV6NoiiQWP0:oiiQWP03o`000?mIYUWoFJII00CoFJII00?o0000of:MH_mR
WF801OmRWF800ol0003oWf2OoimPW`08oimPW`03o`000?n[E:_oZeB[00WoZeB[1?l00008on8MhP03
o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003olPgb
oo8=lP05oo8=lP03o`000?oS7>?ohacS00WohacS0_l0000<olPgb003o`000?nNHIkoWV6N00WoWV6N
00?o0000oeVVFOmIYUT00omIYUT00ol0003oHYeRof:MHP05of:MHP03o`000?nOH9ooWf2O00[oWf2O
00?o0000oj]DZon[E:/01?n[E:/4o`0000CofRGJ00?o0000on8Mh_oR7N801?oR7N800ol0003om`Sg
ooL8m`0:ooL8m`03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00?olPgb00?o0000on<LhooS7><02ooS
7><00ol0003ob3O8olPgb00:olPgb003o`000?nNHIkoWV6N00WoWV6N00?o0000oeVVFOmIYUT00_mI
YUT00ol0003oHYeRof:MHP06of:MHP03o`000?nOH9ooWf2O00[oWf2O00?o0000oj]DZon[E:/01?l0
0009omXUfPKo00003?og2?L00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo8=l_ob3O;olPgb0_l0
000=on<Lh`03o`000?o8=lSob3O800[ob3O800?o0000oiiQW_nNHIh02OnNHIh01Ol0003oFJIIoeVV
FOmIYUWo000000WoHYeR00?o0000oimPWonOH9l02onOH9l2o`0000gofRGJ00?o0000ooD:mOoe2_D0
0_oe2_D00ol0003om`SgooL8m`0:ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgbo`00
0002ooT6n@;o00002ooS7><00ol0003ob3O8olPgb00;olPgb003o`000?nNHIkoWV6N00WoWV6N00?o
0000oeVVFOl000002OmRWF800ol0003oWf2OoimPW`0<oimPW`03o`000?oJ9M[ofRGJ00cofRGJ00?o
0000ooD:mOoe2_D00ooe2_D00ol0003om`SgooL8m`09ooL8m`03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on@KiooT6n@03ooT6n@;o00002_oS7><00ol0003ob3O8olPgb00:olPgb003o`000?nNHIko
WV6N00SoWV6N1Ol00008of:MHP03o`000?nOH9ooWf2O00coWf2O00?o0000omXUf_oJ9MX02ooJ9MX0
0ol0003om@[eooD:m@05ooD:m@03o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooi1_T2o`0000SohacS00?o0000olPgb?o8=lP02_o8=lP00ol0003oWV6NoiiQWP07oiiQ
WP03o`000?nPGj3oX5nP00?oX5nP0ol00005of:MHP03o`000?nOH9ooWf2O00_oWf2O00?o0000omXU
f_oJ9MX03?oJ9MX00ol0003om@[eooD:m@06ooD:m@03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000Won@Ki00?o0000on<LhooS7><01OoS7><2o`0000co
b3O800?o0000oiiQW_nNHIh01OnNHIh00ol0003oX5nPoj1OX007oj1OX0?o000000?oHYeRo`000?nO
H9l03OnOH9l00ol0003ofRGJomXUfP0<omXUfP03o`000?oe2_Gom@[e00Kom@[e00?o0000ooL8moog
2?L01_og2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?oi1_Won@Ki00Oon@Ki
0_l00004on<Lh`03o`000?o[5>_ojaC[00;o00002_o8=lP00ol0003oWV6NoiiQWP03oiiQWP;o0000
3OnPGj02o`0000goWf2O0ol0000=omXUfP03o`000?oe2_Gom@[e00Oom@[e00?o0000ooL8moog2?L0
1Oog2?L00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00Son@Ki0_l0
00000ooS7>?o0000on/Dj`04on/Dj`03o`000?o8=lSob3O800Oob3O800Co0000oiiQW_nNHIkoWV6N
0_l00002ol/db`03o`000?nPGj3oX5nP00coX5nP3Ol00003omTVf@03o`000?oJ9M[ofRGJ00[ofRGJ
00?o0000ooD:mOoe2_D02?oe2_D01?l0003om`SgooL8moog2?L4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003on@Ki
ooT6n@09ooT6n@03o`000?o[5>_ojaC[00GojaC[0_l00008olPgb003o`000?nNHIko000000GobcC;
00?o0000oj1OX?nPGj002onPGj000ol0003o[U6^ojiA[P09ojiA[P03o`000?oI9]WofBKI00;ofBKI
0_l00009omXUfP03o`000?oe2_Gom@[e00[om@[e0ol00004ood2o@03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?oi1_Won@Ki00Son@Ki00?o0000on/Djoo[5>/01oo[5>/4o`0000?ob3O80ol0
0007ol/db`03o`000?nPGj3oX5nP00[oX5nP00?o0000ojiA[_n^DJh02On^DJh00ol0003ofBKIomTV
f@04omTVf@;o00001ooJ9MX00ol0003om@[eooD:m@0:ooD:m@03o`000?om0_goo@;m00Goo@;m00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[5>/02?o[5>/0
1?l0003ojAKYonTFjOoY5^T3o`0000;ogR7N00?o0000ol/dboo;=</01_o;=</00ol0003oX5nPoj1O
X008oj1OX003o`000?n^DJko[U6^00[o[U6^00?o0000omTVfOoI9]T01_oI9]T00ol0003ofRGJomXU
fP04omXUfP03o`000?oe2_Gom@[e00Wom@[e00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ojaC[on/Dj`08on/Dj`03o`000?oY5^Wo
jAKY00CojAKY00Go0000omhQg_oN8MkogR7No`000008ol/db`03o`000?nPGj3oX5nP00OoX5nP00?o
0000ojiA[_n^DJh02_n^DJh00ol0003ofBKIomTVf@07omTVf@;o00001?oJ9MX00ol0003om@[eooD:
m@08ooD:m@03o`000?om0_goo@;m00Woo@;m00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T00ooi1_T0
0ol0003ojaC[on/Dj`08on/Dj`03o`000?oY5^WojAKY00CojAKY00?o0000omhQg_oN8Mh00_oN8Mh0
0ol0003obcC;ol/db`07ol/db`03o`000?nPGj3oX5nP00KoX5nP00?o0000ojiA[_n^DJh02_n^DJh0
0ol0003ofBKIomTVf@09omTVf@05o`000?oJ9M[ofRGJomXUf_l000002Ooe2_D00ol0003oo@;mood2
o@0;ood2o@03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ojaC[00?o0000onTFjOoY5^T01?oY5^T00ol0003ogR7NomhQgP03
omhQgP03o`000?o;=<_obcC;00OobcC;00?o0000oj1OX?nPGj001OnPGj000ol0003o[U6^ojiA[P0:
ojiA[P03o`000?oI9]WofBKI00WofBKI1?l00009ooD:m@03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?oi1_Won@Ki
ooT6nOl000002_o[5>/00ol0003ojAKYonTFj@05onTFj@03o`000?oN8MkogR7N00?ogR7N00?o0000
ol/dboo;=</02?o;=</00ol0003oX5nPoj1OX004oj1OX003o`000?n^DJko[U6^00Wo[U6^00?o0000
omTVfOoI9]T02?oI9]T2o`0000?om@[e00?o0000ooD:mOoe2_D01_oe2_D00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003ojaC[on/Dj`06on/Dj`03o`000?oY5^WojAKY
00GojAKY00?o0000omhQg_oN8Mh01?oN8Mh00ol0003obcC;ol/db`09ol/db`03o`000?nPGj3oX5nP
00;oX5nP00?o0000ojiA[_n^DJh02_n^DJh00ol0003ofBKIomTVf@06omTVf@;o00001_oe2_D8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?o[5>_ojaC[00GojaC[00?o0000onTFjOoY
5^T01OoY5^T00ol0003ogR7NomhQgP05omhQgP03o`000?o;=<_obcC;00WobcC;00Go0000oj1OX?nP
Gj3oX5nPo`00000<ojiA[P03o`000?oI9]WofBKI00CofBKI0_l00008ooD:m@03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[
5>/00oo[5>/00ol0003ojAKYonTFj@06onTFj@03o`000?oN8MkogR7N00GogR7N00?o0000ol/dboo;
=</02_o;=</00ol0003oX5nPo`000004o`0000Wo[U6^00?o0000omTVfOoI9]T00_oI9]T2o`0000[o
m@[e00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on@KiooT6n@07ooT6n@03o`00
0?o[5>_ojaC[00;ojaC[00?o0000onTFjOoY5^T01_oY5^T00ol0003ogR7NomhQgP07omhQgP;o0000
2oo;=</00ol0003ohacSon<Lh`03on<Lh`Oo00000_n^DJh00ol0003ofBKIomTVf@02o`0000_om@[e
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T02Ooi
1_T01Ol0003ojaC[on/Djoo[5>_o000000SojAKY00?o0000omhQg_oN8Mh01ooN8Mh00ol0003oka3_
o`000002o`0000SobcC;00?o0000on<LhooS7><02_oS7><5o`0000gom@[e00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<ooT6n@03o`000?o[5>_o000000WojAKY00?o
0000omhQg_oN8Mh01_oN8Mh00ol0003oka3_onl@k`03onl@k`?o00001?o;=</00ol0003ohacSon<L
h`0=on<Lh`03o`000?oe2_Gom@[e00gom@[e00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on@Ki00?o0000onTFjOoY5^T01ooY5^T00ol0003ogR7NomhQgP07
omhQgP03o`000?o_4>ooka3_00Koka3_0ol000000oo;=<_o0000on<Lh`0>on<Lh`03o`000?oe2_Go
m@[e00com@[e00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooT6
n@03o`000?oY5^WojAKY00;ojAKY1_l00008omhQgP03o`000?o_4>ooka3_00[oka3_00?o0000on<L
hooS7><03ooS7><00ol0003om@[eooD:m@0:ooD:m@;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooT6n@Go00001_of2OH00ol0003ogR7NomhQgP05omhQgP03o`000?o_4>ooka3_00[o
ka3_00?o0000on<LhooS7><03ooS7><00ol0003om@[eooD:m@07ooD:m@?o000000?oo@;mo`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooT6n@03o`000?of2OKomPWf00WomPWf00?o0000omhQg_oN
8Mh00ooN8Mh00ol0003oka3_onl@k`0;onl@k`03o`000?oS7>?ohacS00oohacS00?o0000ooD:mOoe
2_D01Ooe2_D2o`0000Goo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on@Kio`000?l00000
3Oof2OH00ol0003ogR7NomhQgP02omhQgP03o`000?o_4>ooka3_00_oka3_5?l00004ooD:m@;o0000
2?om0_d00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooH9mP04o`000?oN8MkogR7No`0000koka3_
00?o0000ooL8moog2?L04?og2?L00ol0003om@[eo`000002o`0000[oo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_of2OH00ol0003ogR7No`00000>onl@k`03o`00
0?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003omPWfooH9mP0=ooH9mP03o`000?o_4>ooka3_00Woka3_1Ol0
000BooL8m`;o00003oom0_d00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003omPWfooH9mP0<ooH9mP03o`000?o_4>ooka3_00;oka3_1ol00004ood2o@03o`000?og2?Oo
m`Sg00oom`Sg00?o0000ood2oOl000004?om0_d00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?of2OKomPWf00comPWf1?l0000<ood2o@03o`000?og2?Oom`Sg00com`Sg0_l00003ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?og2?Oom`Sg00_o
m`Sg00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2o@04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L02Oog2?L2o`0000Ooo@;m00?o0000ood2oOom0_d03Oom0_d3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?og2?Oom`Sg00Kom`Sg0_l0000:ood2o@03o`000?om0_goo@;m00_oo@;m
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_og2?L00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Woo@;m0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000oog2?L2o`0000koo@;m00?o
0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooL8mol000004Oom0_d00ol0003oo@;mood2o@04ood2o@;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ood2
oOom0_d00oom0_d00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool01ol00?l6oooo00Wo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`05o`00o`?oool00ol0
0?l2oooo00Ko003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00_o003o0_ooo`04o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`003Ol00?l00oooo`3o003oo`00o`0:o`00o`03oooo0?l00?oo003o
00;o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000go003o0_ooo`0;o`00o`;oool00ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool02ol00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo0?l00?oo003oo`00o`;oool0
0_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co003o0_ooo`0=o`00o`;oool0
2ol00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o0oooo`0:o`00o`?oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02ol00?l3oooo00[o003o0oooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000So003o1Oooo`09o`00o`Goool00ol00?l2oooo00Ko003o0_oo
o`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo
003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02_l00?l2
oooo00Oo003o1_ooo`05o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00
o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00_o003o0_ooo`06o`00
o`Coool01ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo00Go
003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0<o`00o`;oool01_l00?l00oooo`3o
003oo`00o`07o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Go003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l00?l2oooo00Co003o0_ooo`07o`00o`;oool0
Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_oo
o`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o0_ooo`06o`00o`03oooo0?l0
0?oo003o00So003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001Wo`00o`7ooooo001W
o`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00?o003o0_ooo`03
o`00o`;oool02?l00?l6oooo00Go003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool0
06Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Po`00o`Coool02Ol00?l7oooo
00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(360) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.993 .007 .993 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.994 .006 .994 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.994 .006 .994 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.993 .007 .993 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.97 .03 .97 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.991 .009 .991 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.971 .029 .971 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.963 .037 .963 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.946 .054 .946 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.987 .013 .987 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.938 .062 .938 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.993 .007 .993 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.873 .127 .873 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.888 .112 .888 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.798 .202 .798 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.921 .079 .921 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.986 .014 .986 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.988 .012 .988 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.968 .032 .968 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.634 .366 .634 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.93 .07 .93 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.831 .169 .831 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.824 .176 .824 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.862 .138 .862 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.918 .082 .918 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.948 .052 .948 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.802 .198 .802 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.906 .094 .906 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.704 .296 .704 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.942 .058 .942 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.904 .096 .904 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.843 .157 .843 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.9 .1 .9 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.713 .287 .713 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.931 .069 .931 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.826 .174 .826 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.995 .005 .995 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.948 .052 .948 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.746 .254 .746 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.403 .597 .403 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.48 .52 .48 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.976 .024 .976 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.976 .024 .976 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.896 .104 .896 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.993 .007 .993 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.779 .221 .779 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.785 .215 .785 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.474 .526 .474 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.471 .529 .471 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.336 .664 .336 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.754 .246 .754 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.79 .21 .79 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.993 .007 .993 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.765 .235 .765 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.673 .327 .673 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.961 .039 .961 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.535 .465 .535 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.923 .077 .923 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.866 .134 .866 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.475 .525 .475 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.358 .642 .358 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.664 .336 .664 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.095 .905 .095 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.115 .885 .115 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.234 .766 .234 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.499 .501 .499 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.492 .508 .492 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.918 .082 .918 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.185 .815 .185 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.203 .797 .203 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.791 .209 .791 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.963 .037 .963 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.992 .008 .992 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.276 .724 .276 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.339 .661 .339 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.656 .344 .656 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.992 .008 .992 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.732 .268 .732 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.346 .654 .346 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.586 .414 .586 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.093 .907 .093 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.506 .494 .506 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.306 .694 .306 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.966 .034 .966 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.084 .916 .084 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.06 .94 .06 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.878 .122 .878 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.042 .958 .042 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.019 .981 .019 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.628 .372 .628 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.921 .079 .921 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.228 .772 .228 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.045 .955 .045 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.483 .517 .483 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.102 .898 .102 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.194 .806 .194 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.94 .06 .94 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.012 .988 .012 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.127 .873 .127 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.13 .87 .13 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.804 .196 .804 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.241 .759 .241 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.312 .688 .312 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.04 .96 .04 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.056 .944 .056 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.109 .891 .109 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.023 .977 .023 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.363 .637 .363 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.638 .362 .638 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.992 .008 .992 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.809 .191 .809 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.178 .822 .178 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.206 .794 .206 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.403 .597 .403 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.968 .032 .968 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.096 .904 .096 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.171 .829 .171 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.646 .354 .646 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.053 .947 .053 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.993 .007 .993 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.044 .956 .044 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.893 .107 .893 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.969 .031 .969 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.634 .366 .634 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.694 .306 .694 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.099 .901 .099 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.908 .092 .908 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.313 .687 .313 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.483 .517 .483 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.074 .926 .074 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.251 .749 .251 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.423 .577 .423 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.992 .008 .992 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.992 .008 .992 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.943 .057 .943 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.157 .843 .157 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.143 .857 .143 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.03 .97 .03 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.859 .141 .859 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.21 .79 .21 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.962 .038 .962 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.198 .802 .198 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.206 .794 .206 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.218 .782 .218 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.68 .32 .68 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.769 .231 .769 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.619 .381 .619 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.024 .976 .024 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.186 .814 .186 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.316 .684 .316 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.596 .404 .596 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.86 .14 .86 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.993 .007 .993 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.955 .045 .955 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.21 .79 .21 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.396 .604 .396 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.192 .808 .192 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.851 .149 .851 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.761 .239 .761 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.992 .008 .992 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.612 .388 .612 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.888 .112 .888 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.96 .04 .96 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.155 .845 .155 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.275 .725 .275 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.947 .053 .947 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.173 .827 .173 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.692 .308 .692 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.555 .445 .555 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.519 .481 .519 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.385 .615 .385 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.909 .091 .909 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.873 .127 .873 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.882 .118 .882 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.91 .09 .91 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.427 .573 .427 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.969 .031 .969 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.828 .172 .828 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.388 .612 .388 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.435 .565 .435 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.992 .008 .992 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.698 .302 .698 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.564 .436 .564 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.991 .009 .991 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.964 .036 .964 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.863 .137 .863 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.96 .04 .96 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.44 .56 .44 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.938 .062 .938 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.81 .19 .81 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.737 .263 .737 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.993 .007 .993 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.71 .29 .71 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.593 .407 .593 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.993 .007 .993 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.762 .238 .762 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.988 .012 .988 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.994 .006 .994 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.604 .396 .604 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.99 .01 .99 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.67 .33 .67 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.991 .009 .991 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.8 .2 .8 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.895 .105 .895 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.827 .173 .827 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.916 .084 .916 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.936 .064 .936 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.833 .167 .833 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.693 .307 .693 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.82 .18 .82 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.897 .103 .897 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.937 .063 .937 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.916 .084 .916 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.927 .073 .927 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.988 .012 .988 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.849 .151 .849 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.962 .038 .962 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.99 .01 .99 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.97 .03 .97 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.951 .049 .951 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.859 .141 .859 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.963 .037 .963 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.937 .063 .937 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.922 .078 .922 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.952 .048 .952 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.992 .008 .992 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.991 .009 .991 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.992 .008 .992 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.991 .009 .991 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.992 .008 .992 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oom
0_d01?l0003om0_doo@;m?l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?om
0_goo@;m00goo@;m00?o0000oo@;m?od2o@00_od2o@00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00?om0_d00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m
00[oo@;m00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m006oo@;m003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Ooo@;m
00?o0000oo@;m?od2o@02?od2o@00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com0_d00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooL8m`03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ol@kaoo4>l@05oo4>l@03o`000?od
2oCom0_d00_om0_d0ol00003oo8=lP03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooL8moog2?L00oog2?L00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003ol@kaoo4>l@06
oo4>l@03o`000?od2oCom0_d00[om0_d00?o0000oo8=l_ob3O801?ob3O800ol0003oo@;mood2o@0:
ood2o@04o`000?o`3o3ol0o`oo0?l0;o00002_om0_d2o`000003onl@kol0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003om`SgooL8m`05ooL8m`03o`000?om0_go
o@;m00Woo@;m00?o0000ooL8mol000002oon0Oh00ol0003ol@kaoo4>l@06oo4>l@03o`000?od2oCo
m0_d00Wom0_d00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@08ood2o@03o`000?o`3o3o
l0o`00Col0o`0_l00005ood2o@?o00001?o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooL8m`03o`000?om0_goo@;m00Ooo@;m0_l00003ooL8
m`03o`000?on0OkooP7n00OooP7n00?o0000oo4>lOoa3_401ooa3_400ol0003om0_doo@;m009oo@;
m003o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d01Oom0_d2o`0000Wol0o`0_l000000oom
0_go0000o`000007onl@k`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooL8moog
2?L02?og2?L00ol0003oo@;mood2o@06ood2o@03o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on
0Oh01oon0Oh00ol0003ol@kaoo4>l@08oo4>l@03o`000?od2oCom0_d00Oom0_d00?o0000oo8=l_ob
3O802Oob3O800ol0003oo@;mood2o@03ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000onl@koo_
4>l01oo_4>l00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfo`000005ood2o@;o00002oog2?L2o`0000Koo@;m
00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP06ooh1oP03o`000?oa3_7ol@ka00Sol@ka
00?o0000oo@;m?od2o@01_od2o@00ol0003olPgboo8=lP0;oo8=lP05o`000?om0_goo@;mood2oOl0
00003_o`3o000ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?of2OKomPWfooH9m_l0
00000oom0_d00ol0003om`SgooL8m`0:ooL8m`04o`000?o[5>_ojaC[o`0000?oo@;m0_l00008ooL8
m`03o`000?on0OkooP7n00KooP7n00?o0000oo4>lOoa3_402Ooa3_400ol0003om0_doo@;m005oo@;
m003o`000?ob3O;olPgb00colPgb00?o0000ood2oOl000003oo`3o000ol0003oka3_onl@k`08onl@
k`03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9mP03ooH9mP03o`000?om0_go000000_o
m`Sg0_l00004on/Dj`03o`000?om0_go000000_om`Sg00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l@kaoo4>l@09oo4>l@03o`000?od2oCom0_d00Com0_d00?o0000oo8=l_ob3O803_ob3O800ol0003o
l0o`oo0?l00>oo0?l003o`000?o_4>ooka3_00Woka3_00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooH9m_of2OH0
1?of2OH00ol0003om`SgooL8m`09ooL8m`03o`000?o[5>_ojaC[00GojaC[00?o0000ooL8moog2?L0
2_og2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?oa3_7ol@ka00[ol@ka00?o0000oo@;m?od2o@0
0ood2o@00ol0003olPgboo8=lP0>oo8=lP03o`000?o`3o3ol0o`00gol0o`00?o0000onl@koo_4>l0
2_o_4>l00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9
mP05ooH9mP03o`000?og2?Oom`Sg00Oom`Sg0_l00008on/Dj`03o`000?og2?Oom`Sg00_om`Sg00?o
0000ooh1o_on0Oh01?on0Oh00ol0003ol@kaoo4>l@0:oo4>l@04o`000?od2oCom0_doo@;m0?o0000
3oob3O800ol0003ol0o`oo0?l00>oo0?l003o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000ooL8moog2?L01?og2?L2o`0000_ojaC[1?l0
0009ooL8m`03o`000?on0OkooP7n00?ooP7n00?o0000oo4>lOoa3_402ooa3_401?l0003om0_do`00
0?l00003omTVf@;o00003?ob3O82o`00013ol0o`00?o0000onl@koo_4>l02oo_4>l00ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003omPWf
ooH9mP07ooH9mP03o`000?og2?Oom`Sg00?om`Sg00?o0000on/Djoo[5>/02oo[5>/01?l0003occ3?
oll`coo?<<l5o`0000Gom`Sg00?o0000ooh1o_on0Oh00_on0Oh00ol0003ol@kaoo4>l@0<oo4>l@03
o`000?oI9]WofBKI00GofBKI0_l00008oo8=lP;o00000_oC;=<00ol0003ol0o`oo0?l00=oo0?l003
o`000?o_4>ooka3_00_oka3_00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003omPWfooH9mP09ooH9mP03o`000?og2?Oom`Sg00;o0000
3Oo[5>/00ol0003occ3?oll`c`07oll`c`Ko00000_on0Oh4o`0000gol@ka00?o0000omTVfOoI9]T0
1ooI9]T2o`0000GolPgb00?o0000om</dooC;=<00ooC;=<00ol0003ol0o`oo0?l00<oo0?l003o`00
0?o_4>ooka3_00coka3_00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?of2OKomPWf00WomPWf00?o
0000ooL8mol000003oo[5>/00ol0003occ3?oll`c`0<oll`c`?o00001?oX5nP3o`0000Wol@ka00?o
0000omTVfOoI9]T02_oI9]T2o`000003oo8=l_l0003o000000OodbcC00?o0000oo0?l?o`3o002oo`
3o000ol0003oka3_onl@k`0<onl@k`03o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000
on/Djoo[5>/03_o[5>/00ol0003occ3?oll`c`0=oll`c`03o`000?oX5nSoj1OX00Koj1OX0ol00005
oo4>l@03o`000?oI9]WofBKI00gofBKI00?o0000om</dooC;=<02?oC;=<00ol0003ol0o`oo0?l009
oo0?l003o`000?o_4>ooka3_00goka3_00Co0000ood2oOom0_goo@;m1Ol00003oo<<l`03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooH9m_of2OH02oof2OH2o`0000oojaC[00?o0000oll`coo?<<l03Oo?<<l00ol0003oj1OXonPGj00:
onPGj0?o000000?ol@kao`000?oI9]T03ooI9]T00ol0003odbcCom</d`09om</d`03o`000?o`3o3o
l0o`00Sol0o`00?o0000onl@koo_4>l03_o_4>l3o`0000Sol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?of2OKomPWf00SomPWf0ol000000ooM
8]go0000on/Dj`0>on/Dj`03o`000?o?<<oocc3?00gocc3?00?o0000onPGj?oX5nP03OoX5nP00ol0
003ofBKIomTVf@0?omTVf@03o`000?oC;=?odbcC00[odbcC2ol0000;onl@k`Go00003?oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003olPgbo`000?on0Oko0000
00SomPWf0ol00005omdRg@03o`000?o[5>_ojaC[00cojaC[00?o0000oll`coo?<<l03Oo?<<l00ol0
003oj1OXonPGj00=onPGj0;o00004?oI9]T00ol0003odbcCom</d`0:om</d`03o`000?o?<<oocc3?
00Oocc3?00?o0000onl@koo_4>l00_o_4>l7o`0000CoeB[E00?o0000oo<<looc3?<02_oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003olPgboo8=l_ob3O82o`00
00GomPWf0ol00009omdRg@;o00002oo[5>/00ol0003occ3?oll`c`0=oll`c`03o`000?oX5nSoj1OX
00goj1OX00Co0000ol@ka?o4>lCo00003ooI9]T00ol0003odbcCom</d`09om</d`03o`000?o?<<oo
cc3?00Wocc3?1?l0000;omDZe@03o`000?oc3??ol`cc00[ol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo8=l_ob3O801?ob3O800ol0003omPWfo`000002o`00
00cogB;M00Co0000ok]4^ol0003o00002Oo[5>/00ol0003occ3?oll`c`0=oll`c`03o`000?oX5nSo
j1OX00goj1OX00Go0000ol@ka?o4>lCoa3_4o`00000=omTVf@03o`000?oC;=?odbcC00[odbcC00?o
0000oll`coo?<<l02Oo?<<l00ol0003oeB[EomDZe@0<omDZe@03o`000?oc3??ol`cc00[ol`cc00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo8=l_ob3O801_ob3O80
0ol0003ogB;MomdRg@0<omdRg@03o`000?nkA;_o^dBk00;o^dBk0_l00007on/Dj`03o`000?o?<<oo
cc3?00cocc3?00?o0000onPGj?oX5nP03OoX5nP00ol0003oa3_4ol@ka003ol@ka003o`000?oI9]Wo
fBKI00[ofBKI00?o0000om</dooC;=<02_oC;=<00ol0003occ3?oll`c`09oll`c`03o`000?oE:]Go
eB[E00coeB[E00?o0000oo<<looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003olPgboo8=lP06oo8=lP03o`000?oM8]gogB;M00_ogB;M00?o0000ok]4
^onkA;/01OnkA;/00ol0003ojaC[on/Dj`03on/Dj`03o`000?o?<<oocc3?00gocc3?00?o0000onPG
j?oX5nP03OoX5nP00ol0003oa3_4ol@ka004ol@ka003o`000?oI9]WofBKI00WofBKI00?o0000om</
dooC;=<02OoC;=<00ol0003occ3?oll`c`0:oll`c`03o`000?oE:]GoeB[E00coeB[E00?o0000oo<<
looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
lPgboo8=lP07oo8=lP03o`000?oM8]gogB;M00_ogB;M00?o0000ok]4^onkA;/01_nkA;/2o`0000?o
jaC[00?o0000oll`coo?<<l03Oo?<<l00ol0003oj1OXonPGj00<onPGj003o`000?o4>lCoa3_400Ko
a3_400?o0000omTVfOoI9]T02?oI9]T00ol0003odbcCom</d`09om</d`03o`000?o?<<oocc3?00[o
cc3?00?o0000omDZeOoE:]D03?oE:]D00ol0003ol`ccoo<<l`0;oo<<l`03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo8=l_ob3O802?ob3O800ol0003ogB;MomdRg@0:omdRg@03o`00
0?nkA;_o^dBk00Wo^dBk0_l000000oo[5>_o0000oll`c`0<oll`c`?o00003_oX5nP00ol0003oa3_4
ol@ka007ol@ka003o`000?oI9]WofBKI00OofBKI00?o0000om</dooC;=<02OoC;=<00ol0003occ3?
oll`c`0;oll`c`03o`000?oE:]GoeB[E00coeB[E00?o0000oo<<looc3?<02_oc3?<00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo8=l_ob3O802_ob3O800ol0003ogB;MomdR
g@09omdRg@03o`000?nkA;_o^dBk00_o^dBk00?o0000oll`coo?<<l02_o?<<l2o`0000?oYEZU00?o
0000onPGj?oX5nP02_oX5nP00ol0003oa3_4ol@ka009ol@ka003o`000?oI9]WofBKI00KofBKI00?o
0000om</dooC;=<02?oC;=<00ol0003occ3?oll`c`0<oll`c`03o`000?oE:]GoeB[E00coeB[E00?o
0000oo<<looc3?<02_oc3?<00ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000omdRgOoM8]d02?oM8]d0
0ol0003o^dBkok]4^`0<ok]4^`03o`000?o?<<oocc3?00Socc3?0_l00006ojEJY@;o00002_oX5nP0
0ol0003oa3_4ol@ka00:ol@ka003o`000?oI9]WofBKI00GofBKI00?o0000om</dooC;=<02?oC;=<0
0ol0003occ3?oll`c`0<oll`c`03o`000?oE:]GoeB[E00coeB[E00?o0000oo<<looc3?<02ooc3?<0
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo8=lP03o`000?oM8]gogB;M00OogB;M00?o0000ok]4^onkA;/03_nkA;/00ol0003occ3?oll`c`04
oll`c`?o00002_nUFZD00ol0003oj1OXonPGj007onPGj003o`000?o4>lCoa3_400_oa3_400?o0000
omTVfOoI9]T00ooI9]T00ol0003odbcCom</d`09om</d`03o`000?o?<<oocc3?00cocc3?00?o0000
omDZeOoE:]D03?oE:]D00ol0003ol`ccoo<<l`0;oo<<l`;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003olPgboo8=lP0<oo8=lP03o`000?oM8]gogB;M00OogB;M00?o0000ok]4^onkA;/03onkA;/01?l0
003occ3?oll`coo?<<l2o`0000koYEZU0_l00006onPGj003o`000?o4>lCoa3_400goa3_400?o0000
omTVfOoI9]T00_oI9]T00ol0003odbcCom</d`08om</d`03o`000?o?<<oocc3?00cocc3?0ol0000=
omDZe@03o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oolPgb00?o0000omdRgOoM8]d01_oM8]d00ol0003o^dBkok]4^`0@ok]4^`Co00004_nUFZD00ol0
003oj1OXonPGj003onPGj003o`000?o4>lCoa3_400koa3_400Go0000omTVfOoI9]WofBKIo`000005
om</d`Oo00003?o?<<l01Ol0003oZeB[oj]DZon[E:_o000000coeB[E00?o0000oo<<looc3?<02?oc
3?<3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oolPgb00?o0000omdRgOoM8]d01_oM8]d00ol0003o^dBkok]4^`0=
ok]4^`?o000000CoPGj1o`000?l0003o00004onUFZD2o`0000;oj1OX00?o0000ol@ka?o4>l@04?o4
>l@00ol0003ofBKIo`000006o`0000Oo/Tfb00?o0000oll`coo?<<l02?o?<<l00ol0003oZeB[oj]D
Z`03oj]DZ`;o00002?oE:]D3o`0000Kol`cc1?l00002onl@k`03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003om`Sgo`000?oG:=L3o`0000golPgb00?o0000omdRgOoM8]d01?oM8]d00ol0003o^dBkok]4
^`0;ok]4^`?o00000on1OX401Ol0003oNhAko`000?m?/4oo000001CoYEZU00?o0000onPGj?l00000
4oo4>l@00ol0003o/Tfbok9=/P0=ok9=/P03o`000?o?<<oocc3?00Gocc3?0_l00008oj]DZ`03o`00
0?oE:]GoeB[E00Go00000ooA;]400ol0003ol`ccoo<<l`03o`0000Ooka3_00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?og2?Oom`Sgo`0000CoebSG0ol0000:oo8=lP03o`000?oM8]gogB;M00?ogB;M
00?o0000ok]4^onkA;/02OnkA;/3o`0000GoPGj100Co0000og^4NomkQ7_o00000_m?/4l00ol0003o
YEZUojEJY@0BojEJY@03o`000?o4>lCoa3_401;oa3_400?o0000ok9=/_nbCK803_nbCK800ol0003o
cc3?oll`c`03oll`c`03o`000?n[E:_oZeB[00WoZeB[0_l00009om4^d@;o00002_o_4>l00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooL8moog2?Oom`Sgo`000007omLXe`;o00001oob3O85o`0000;o
gB;M00?o0000ok]4^onkA;/01_nkA;/3o`0000SoPGj100Co0000og^4NomkQ7_o00000om?/4l00ol0
003oYEZUojEJY@0AojEJY@03o`000?o4>lCoa3_4017oa3_400?o0000ok9=/_nbCK804?nbCK801Ol0
003occ3?oll`coo?<<oo000000coZeB[00?o0000om4^dOoA;]402?oA;]400ol0003oka3_onl@k`0:
onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Com`Sg00?o0000omLXeooG:=L01ooG:=L3o`00
0004oo8=l_l0003o0000o`0000Go`cc30_l00006ok]4^`?o00002_n1OX401Ol0003oNhAkog^4Nomk
Q7_o000000CoCk1?00?o0000ojEJYOnUFZD04?nUFZD00ol0003oa3_4ol@ka00Aol@ka003o`000?nb
CK;o/Tfb017o/Tfb00?o0000oll`col000003On[E:/00ol0003odBkAom4^d@08om4^d@03o`000?o_
4>ooka3_00[oka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00Com`Sg00?o0000
omLXeooG:=L02_oG:=L00ol0003o`cc3ol<l``08ol<l``03o`000?nkA;_o^dBk00?o00003On1OX40
1Ol0003oNhAkog^4NomkQ7_o000000GoCk1?00?o0000ojEJYOnUFZD03onUFZD00ol0003oa3_4ol@k
a00Aol@ka003o`000?nbCK;o/Tfb01;o/Tfb00?o0000oj]DZon[E:/03?n[E:/00ol0003odBkAom4^
d@08om4^d@03o`000?o_4>ooka3_00_oka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooL8moog2?L01Oog2?L0
0ol0003oebSGomLXe`0:omLXe`03o`000?o3?<?o`cc300Wo`cc30_l0000?oh5nP@03o`000?mkQ7_o
NhAk00;oNhAk00?o0000odn`Com?/4l01?m?/4l00ol0003oYEZUojEJY@0=ojEJY@?o00004Oo4>l@0
0ol0003o/Tfbok9=/P0Cok9=/P03o`000?n[E:_oZeB[00_oZeB[00?o0000om4^dOoA;]402OoA;]40
0ol0003oka3_onl@k`0;onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ooh1oP;o00002?og2?L0
0ol0003oebSGomLXe`0:omLXe`03o`000?o3?<?o`cc300Wo`cc300?o0000oh5nPOn1OX403On1OX40
0ol0003oNhAkog^4N`03og^4N`03o`000?m?/4ooCk1?00GoCk1?00?o0000ojEJYOnUFZD02_nUFZD2
o`0000?oNhAk00?o0000ol@ka?o4>l@03_o4>l@00ol0003o/Tfbok9=/P0Cok9=/P03o`000?n[E:_o
ZeB[00_oZeB[00?o0000om4^dOoA;]402OoA;]400ol0003oka3_onl@k`0;onl@k`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000GooP7n00?o0000ooL8moog2?L01oog2?L2o`0000_oebSG00?o0000ol<l
`oo3?<<02oo3?<<00ol0003oPGj1oh5nP@0<oh5nP@03o`000?mkQ7_oNhAk00?oNhAk00?o0000odn`
Com?/4l01_m?/4l00ol0003oYEZUojEJY@07ojEJY@;o00001_mkQ7/2o`0000koa3_400?o0000ok9=
/_nbCK804onbCK800ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?oA;]7odBkA00WodBkA00?o0000onl@
koo_4>l03?o_4>l00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ooh1o_on0OkooP7no`000009ooL8
m`03o`000?o^4Nko000000_oebSG00?o0000ol<l`oo3?<<02oo3?<<00ol0003oPGj1oh5nP@0;oh5n
P@03o`000?mkQ7_oNhAk00CoNhAk00?o0000odn`Com?/4l01om?/4l00ol0003oYEZUojEJY@05ojEJ
Y@03o`000?mkQ7_oNhAk00SoNhAk00?o0000ol@ka?o4>l@02_o4>l@00ol0003o/Tfbok9=/P0Dok9=
/P03o`000?n[E:_oZeB[00_oZeB[00?o0000om4^dOoA;]402OoA;]400ol0003oka3_onl@k`0<onl@
k`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7no`000009ooL8m`04o`000?o^4NkokQ7^o`00
00_oebSG00?o0000ol<l`oo3?<<02oo3?<<00ol0003oPGj1oh5nP@0;oh5nP@03o`000?mkQ7_oNhAk
00CoNhAk00?o0000odn`Com?/4l02?m?/4l00ol0003oYEZUojEJY@02ojEJY@;o00003?mkQ7/2o`00
00[oa3_400?o0000ok9=/_nbCK805?nbCK800ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?oA;]7odBkA
00WodBkA00?o0000onl@koo_4>l03Oo_4>l00ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003om`SgooL8m`07ooL8m`03
o`000?o^4NkokQ7^00;okQ7^00?o0000omLXeooG:=L02?oG:=L00ol0003o`cc3ol<l``0<ol<l``03
o`000?n1OX7oPGj100WoPGj100?o0000og^4NomkQ7/01OmkQ7/00ol0003oCk1?odn`C`09odn`C`04
o`000?nUFZGo0000o`00013oNhAk0_l00008ol@ka003o`000?nbCK;o/Tfb01Co/Tfb0ol0000;oj]D
Z`03o`000?oA;]7odBkA00WodBkA00?o0000onl@koo_4>l03Oo_4>l01?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003om`SgooL8m`06ooL8m`03o`000?o^4NkokQ7^00?okQ7^00?o0000omLX
eooG:=L02?oG:=L00ol0003o`cc3ol<l``0;ol<l``;o00002_n1OX400ol0003oNhAkog^4N`06og^4
N`03o`000?m?/4ooCk1?00[oCk1?00?o0000og^4NomkQ7/04_mkQ7/00ol0003oa3_4ol@ka004ol@k
a003o`000?nbCK;o/Tfb01Go/Tfb00?o0000oiYUV_nJIIX01Ol00005oj]DZ`03o`000?oA;]7odBkA
00[odBkA00?o0000onl@koo_4>l03_o_4>l3o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003om`SgooL8m`04ooL8m`03
o`000?o^4NkokQ7^00CokQ7^00?o0000omLXeooG:=L01ooG:=L00ol0003o`cc3ol<l``0;ol<l``04
o`000?miQWWoNHIio`0000WoPGj100?o0000og^4NomkQ7/01_mkQ7/00ol0003oCk1?odn`C`0:odn`
C`03o`000?mkQ7_oNhAk01?oNhAk0_l00003ol@ka0Co00005?nbCK800ol0003oVVFJoiYUVP06oiYU
VPCo000000?oZeB[o`000?oA;]402ooA;]400ol0003oka3_onl@k`0>onl@k`03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?o^4NkokQ7^00GokQ7^00?o0000omLXeooG
:=L01ooG:=L00ol0003o`cc3ol<l``09ol<l``;o00001?miQWT00ol0003oPGj1oh5nP@05oh5nP@03
o`000?mkQ7_oNhAk00OoNhAk00?o0000odn`Com?/4l02_m?/4l00ol0003oNhAkog^4N`0Eog^4N`03
o`000?o4>lCo000000CoSW6>0ol0000@ok9=/P03o`000?nJII[oVVFJ00_oVVFJ0_l0000<om4^d@03
o`000?o_4>ooka3_00coka3_0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L00_og2?L00ol0003okQ7^
onhAkP06onhAkP03o`000?oG:=OoebSG00OoebSG00?o0000ol<l`oo3?<<02?o3?<<00ol0003oNHIi
ogV6N@05ogV6N@03o`000?n1OX7oPGj100CoPGj100?o0000og^4NomkQ7/01omkQ7/00ol0003oCk1?
odn`C`0:odn`C`03o`000?mkQ7_oNhAk01KoNhAk00?o0000ohiaS_n>LHh01_n>LHh3o`0000co/Tfb
00?o0000oiYUV_nJIIX03OnJIIX00ol0003odBkAom4^d@09om4^d@Go00002Oo_4>l2o`000003oo<<
lol0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooL8mol0003okQ7^00WokQ7^00?o0000omLXeooG:=L01_oG
:=L00ol0003o`cc3ol<l``07ol<l``03o`000?miQWWoNHIi00OoNHIi00?o0000oh5nPOn1OX400_n1
OX400ol0003oNhAkog^4N`08og^4N`03o`000?m?/4ooCk1?00WoCk1?00?o0000og^4NomkQ7/05omk
Q7/00ol0003oSW6>ohiaSP09ohiaSP?o00002OnbCK800ol0003oVVFJoiYUVP0>oiYUVPKo00001?oA
;]400ol0003ofbCKom/Tf`03om/Tf`Go00000_o_4>l2o`0000Col`cc00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o`3o3ol0o`oo0?l?l000002oo^4Nh00ol0003oebSGomLXe`06omLXe`03o`000?o3
?<?o`cc300Go`cc30_l0000;ogV6N@04o`000?n1OX7oPGj1o`0000_oNhAk00?o0000odn`Com?/4l0
2Om?/4l00ol0003oNhAkog^4N`0Fog^4N`03o`000?n>LHkoSW6>00goSW6>0ol00005ok9=/P03o`00
0?nJII[oVVFJ00ooVVFJ00?o0000ok5>/OnaC[400onaC[44o`0000_ofbCK0_l00006oo<<l`03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l002oo0?l0ko00001_oG:=L00ol0003o`cc3ol<l
``05ol<l``03o`000?miQWWoNHIi00coNHIi00?o0000oh5nPOl000002omkQ7/00ol0003oCk1?odn`
C`07odn`C`?o00006?mkQ7/00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o/Tfbo`000?nJIIX04?nJ
IIX00ol0003o/Djaok5>/@07ok5>/@03o`000?oK9=_ofbCK00[ofbCK00?o0000oo<<looc3?<01Ooc
3?<00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005oo0?l003o`000?oD:mCoe2_D00_oe2_D0_l00004
omLXe`03o`000?o3?<?o`cc300?o`cc30_l0000@ogV6N@03o`000?mkQ7_oNhAk00[oNhAk00?o0000
odn`Com?/4l00om?/4l4o`0000;o;M8]00?o0000og^4NomkQ7/05OmkQ7/00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nJII[oVVFJ013oVVFJ00?o0000ok5>/OnaC[401onaC[400ol0003ofbCKom/Tf`0:
om/Tf`03o`000?oc3??ol`cc00Gol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o`3o3ol0o`
00Gol0o`00?o0000om@[e?oD:m@03OoD:m@6o`0000?o`cc300?o0000ogV6NOmiQWT04?miQWT00ol0
003oNhAkog^4N`0:og^4N`03o`000?m?/4oo000000?o00001ol]dRd00ol0003oNhAkog^4N`0Dog^4
N`03o`000?n>LHkoSW6>01CoSW6>00?o0000oiYUV_nJIIX03onJIIX00ol0003o/Djaok5>/@08ok5>
/@03o`000?oK9=_ofbCK00[ofbCK00?o0000oo<<looc3?<01Ooc3?<00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o001_o`3o000ol0003oe2_Dom@[e00=om@[e003o`000?nfBKKo]TVf00?o
]TVf00?o0000ol<l`ol000004omiQWT4o`0000WoNhAk0_l0000<obgB;@03o`000?mkQ7_oNhAk01?o
NhAk00?o0000ohiaS_n>LHh05On>LHh00ol0003oVVFJoiYUVP0>oiYUVP03o`000?naC[7o/Dja00So
/Dja00?o0000om/TfooK9=/02OoK9=/00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o`3o3ol0o`00Sol0o`00?o0000om@[e?oD:m@02ooD:m@00ol0003o]TVfokI9]P05okI9]P03o`00
0?miQWWoNHIi01;oNHIi00Co0000oc[5>_ljaC[o>/Dj1Ol00003og^4N`03o`000?l]dRgo;M8]00go
;M8]0ol0000@og^4N`;o00006?n>LHh00ol0003oVVFJoiYUVP0=oiYUVP03o`000?naC[7o/Dja00Wo
/Dja00?o0000om/TfooK9=/02OoK9=/00ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ol0o`00?o0000om@[e?oD:m@02_oD:m@00ol0003o]TVfokI9]P06okI9]P03o`00
0?miQWWoNHIi017oNHIi00?o0000oc[5>_ljaCX01oljaCX3o`00013o;M8]00?o0000oaWV6OlIiQT0
1Ol00009og^4N`;o000000?o</dbo`000?n>LHh05on>LHh00ol0003oVVFJoiYUVP0=oiYUVP03o`00
0?naC[7o/Dja00Wo/Dja00?o0000om/TfooK9=/02?oK9=/2o`0000[ol`cc00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oh1oSon0Oh00;on0Oh00?o0000oo0?l?o`3o002Oo`3o000ol0003oe2_Dom@[
e00:om@[e003o`000?nfBKKo]TVf00Oo]TVf00?o0000ogV6NOmiQWT03omiQWT00ol0003o>/Djoc[5
>P0:oc[5>P03o`000?l]dRgo;M8]00go;M8]00?o0000oaWV6OlIiQT01_lIiQT4o`0000CoNhAk00?o
0000oc;=<_lbcC800_lbcC800ol0003oSW6>ohiaSP0FohiaSP03o`000?nJII[oVVFJ00_oVVFJ00?o
0000ok5>/OnaC[402onaC[400ol0003ofbCKom/Tf`06om/Tf`03o`000?o/4nco000000[ol`cc00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oh1oSon0Oh00?on0Oh00?o0000oo0?l?o`3o002?o`3o0=
o`0000[o]TVf00?o0000ogV6NOmiQWT03omiQWT00ol0003o>/Djoc[5>P0;oc[5>P03o`000?l]dRgo
;M8]00co;M8]00?o0000oaWV6OlIiQT02_lIiQT4o`0000Go</db00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oVVFJoiYUVP0:oiYUVP03o`000?naC[7o/Dja00co/Dja00?o0000om/TfooK9=/01?oK9=/2
o`0000?ok1?/00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooP7
n?oh1oP00ooh1oP00ol0003ol0o`oo0?l007oo0?l003o`000?oB;M;odRgB00WodRgB00?o0000okI9
]_nfBKH02OnfBKH00ol0003oNHIiogV6N@0=ogV6N@03o`000?ljaC[o>/Dj00co>/Dj00?o0000obgB
;Ol]dRd03?l]dRd00ol0003o6NHIoaWV6@0;oaWV6@03o`000?l7n0Oo000000Ko</db00?o0000ohia
S_n>LHh05_n>LHh00ol0003oVVFJoiYUVP09oiYUVP03o`000?naC[7o/Dja00co/Dja00?o0000om/T
fooK9=/00ooK9=/00ol0003ok1?/on`Ck003on`Ck003o`000?oc3??ol`cc00Sol`cc00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Con0Oh00?o0000oo0?l?o`3o001_o`3o000ol0003o
dRgBom8]dP08om8]dP03o`000?nfBKKo]TVf00_o]TVf00?o0000ogV6NOmiQWT02?miQWT4o`0000oo
>/Dj00?o0000obgB;Ol]dRd02ol]dRd00ol0003o6NHIoaWV6@0;oaWV6@04o`000?l7n0Oo1oP7o`00
00Oo</db00?o0000ohiaS_n>LHh05On>LHh00ol0003oVVFJoiYUVP08oiYUVP03o`000?naC[7o/Dja
00go/Dja00?o0000om/TfooK9=/00_oK9=/00ol0003ok1?/on`Ck005on`Ck003o`000?oc3??ol`cc
00Ool`cc00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Gon0Oh00?o0000oo0?l?o`
3o001Oo`3o000ol0003odRgBom8]dP08om8]dP03o`000?nfBKKo]TVf00_o]TVf00?o0000ogV6NOmi
QWT00omiQWT5o`0000?o>l@k00?o0000oc[5>_ljaCX03_ljaCX00ol0003o;M8]obgB;@0:obgB;@03
o`000?lIiQWo6NHI00[o6NHI00Go0000o`Oh1ol7n0Oo1oP7o`000007oc;=<P03o`000?n>LHkoSW6>
01GoSW6>00?o0000oiYUV_nJIIX02?nJIIX00ol0003o/Djaok5>/@0=ok5>/@03o`000?oK9=_ofbCK
00;o00002?o/4n`00ol0003ol`ccoo<<l`08oo<<l`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?o`3o3ol0o`00Go
l0o`00?o0000om8]d_oB;M802?oB;M800ol0003o]TVfokI9]P0<okI9]PGo00002Olka3/00ol0003o
>/Djoc[5>P0<oc[5>P;o00003?l]dRd00ol0003o6NHIoaWV6@0:oaWV6@05o`000?l7n0Oo1oP7o`Oh
1ol000002?lbcC800ol0003oSW6>ohiaSP0DohiaSP?o00001onJIIX00ol0003o/Djaok5>/@0>ok5>
/@03o`000?oK9=_o000000_ok1?/00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ol0o`oo0?l004oo0?l003o`000?oB;M;odRgB00Oo
dRgB00?o0000okI9]_nfBKH03?nfBKH01?l0003oNHIiogV6NOl0000;oc_4>`03o`000?ljaC[o>/Dj
00_o>/Dj00Co0000o`?l0ol3o0?o00002_l]dRd00ol0003o6NHIoaWV6@0:oaWV6@03o`000?l7n0Oo
1oP700;o1oP700?o0000oc;=<_lbcC801_lbcC800ol0003oSW6>ohiaSP0AohiaSP?o00000omSW6<0
0ol0003oVVFJoiYUVP04oiYUVP03o`000?naC[7o/Dja00go/Dja1?l0000;on`Ck003o`000?oc3??o
l`cc00Gol`cc00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00Co0000oo0?
l?o`3o3ol0o`1?l00008om8]dP03o`000?nfBKKo]TVf00_o]TVf00?o0000ogV6NOmiQWT00_miQWT0
0ol0003o>l@koc_4>`08oc_4>`03o`000?ljaC[o>/Dj00[o>/Dj00?o0000o`?l0ol3o0<00_l3o0<0
0ol0003o;M8]obgB;@03obgB;@Go00002olIiQT00ol0003o1oP7o`Oh1`03o`Oh1`03o`000?lbcC;o
</db00Oo</db00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoHiaS00?o0000oiYUV_nJIIX00_nJIIX0
0ol0003o/Djaok5>/@0=ok5>/@03o`000?oI9]WofBKI00;ofBKI00?o0000on`Ck?o/4n`02Oo/4n`0
0ol0003ol`ccoo<<l`03oo<<l`03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n007ooP7
n0?o00001?oO8=l00ol0003odRgBom8]dP05om8]dP03o`000?nfBKKo]TVf00[o]TVf00?o0000ogV6
NOmiQWT00omiQWT00ol0003o>l@koc_4>`09oc_4>`03o`000?ljaC[o>/Dj00So>/Dj00?o0000o`?l
0ol3o0<01?l3o0<5o`0000Co0?l000?o0000oaWV6OlIiQT02OlIiQT00ol0003o1oP7o`Oh1`03o`Oh
1`03o`000?lbcC;o</db00So</db00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oHiaS00Go0000oiYU
V_nJII[oVVFJo`00000>ok5>/@03o`000?oI9]WofBKI00CofBKI0_l00009on`Ck003o`000?oc3??o
l`cc00;ol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000omlP
gooO8=l01OoO8=l00ol0003odRgBom8]dP03om8]dP03o`000?nfBKKo]TVf00[o]TVf00?o0000ogV6
NOmiQWT01?miQWT00ol0003o>l@koc_4>`09oc_4>`03o`000?ljaC[o>/Dj00Oo>/Dj00?o0000o`?l
0ol3o0<01Ol3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lIiQWo6NHI00Oo6NHI00?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o</dboc;=<P08oc;=<P03o`000?n>LHkoSW6>00SoSW6>0_l0000>of>L
H`Co00003?naC[42o`0000WofBKI00?o0000on`Ck?o/4n`01oo/4n`01?l0003ol`ccoo<<lol0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ogb3OomlPg`07omlPg`;o00000ooB;M800ol0
003o]TVfokI9]P09okI9]P03o`000?miQWWoNHIi00KoNHIi00?o0000oc_4>olka3/02Olka3/00ol0
003o>/Djoc[5>P05oc[5>P03o`000?l3o0?o0o`300Ko0o`300?o0000o`3o0?l0o`002?l0o`000ol0
003o6NHIoaWV6@06oaWV6@03o`000?l7n0Oo1oP700Co1oP700?o0000oc;=<_lbcC802OlbcC84o`00
00?oSW6>0ol0000@of>LH`05o`000?o3?<?o`cc3ol<l`ol000002_naC[400ol0003ofBKIomTVf@0:
omTVf@Ko00000oo/4n`00ol0003ol`cco`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooP7n?oh1oP01?oh1oP00ol0
003ogb3OomlPg`0:omlPg`04o`000?oB;M;odRgBo`0000[o]TVf00?o0000ogV6NOmiQWT01omiQWT0
0ol0003o>l@koc_4>`09oc_4>`03o`000?ljaC[o>/Dj00Co>/Dj00?o0000o`?l0ol3o0<01ol3o0<0
0ol0003o0?l0o`3o0008o`3o00;o00001_lIiQT00ol0003o1oP7o`Oh1`05o`Oh1`03o`000?lbcC;o
</db00Wo</db00Co0000obcC;?l/dbco;=</0ol0000Bof>LH`03o`000?o3?<?o`cc300?o`cc30_l0
0006ok5>/@;o00003OoI9]T00ol0003omPWfooH9mP03ooH9mPGo00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooP7n?oh1oP00ooh1oP0
0ol0003ogb3OomlPg`0<omlPg`;o00002_nfBKH00ol0003oNHIiogV6N@08ogV6N@03o`000?lka3_o
>l@k00[o>l@k00?o0000oc[5>_ljaCX00_ljaCX00ol0003o0o`3o`?l0`08o`?l0`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lIiQWo6NHI00;o6NHI00?o0000o`Oh1ol7n0L01_l7n0L0
0ol0003o</dboc;=<P08oc;=<P03o`000?l/dbco;=</00Co;=</00?o0000of>LHomSW6<03omSW6<0
0ol0003o`cc3ol<l``06ol<l``;o00000onaC[400ol0003ofBKIomTVf@0=omTVf@03o`000?of2OKo
mPWf00OomPWf0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on0OhooP7n002ooP7n003o`000?oO8=oogb3O
00kogb3O00?o0000okI9]_nfBKH01onfBKH00ol0003oNHIiogV6N@0:ogV6N@03o`000?lka3_o>l@k
00Wo>l@k00Go0000oc[5>_ljaC[o>/Djo`00000;o`?l0`03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lIiQWo6NHIoaWV6Ol000002?l7n0L00ol0003o</dboc;=<P08oc;=<P03o`000?l/
dbco;=</00Go;=</00?o0000of>LHomSW6<03_mSW6<00ol0003o`cc3ol<l``08ol<l``03o`000?na
C[7o000000oofBKI00?o0000ooH9m_of2OH02?of2OH01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oh1oSon0Oho`00017ogb3O00?o0000okI9]_nfBKH01_nfBKH00ol0003oNHIi
ogV6N@0;ogV6N@03o`000?lka3_o>l@k00Wo>l@k00Co0000oc[5>_ljaC[o00003?l3o0<00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o6NHIo`000009o`Oh1`03o`000?lbcC;o</db00So
</db00?o0000obcC;?l/db`01Ol/db`00ol0003oHiaSof>LH`0=of>LH`03o`000?o3?<?o`cc300[o
`cc300?o0000omTVfOoI9]T03_oI9]T00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BomlPg`03o`00
0?nfBKKo]TVf00Co]TVf00?o0000ogV6NOmiQWT03?miQWT00ol0003o>l@koc_4>`0:oc_4>`?o0000
3?l3o0<00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Oh1ol7n0L02?l7n0L00ol0003o</db
oc;=<P07oc;=<P03o`000?l/dbco;=</00Oo;=</00?o0000of>LHomSW6<03?mSW6<00ol0003o`cc3
ol<l``0;ol<l``;o00003_oI9]T00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooH9m_of2OH00oof2OH00ol0003ogb3OomlPg`0?omlPg`?o00000onf
BKH00ol0003oNHIiogV6N@0>ogV6N@03o`000?lka3_o>l@k00So>l@k00Co0000o`[e2_l:m@[o2_D:
0_l0000:o`?l0`?o00003Ol0o`000ol0003o1oP7o`Oh1`08o`Oh1`03o`000?lbcC;o</db00Oo</db
00?o0000obcC;?l/db`01ol/db`00ol0003oHiaSof>LH`0;of>LH`03o`000?o3?<?o`cc300co`cc3
00?o0000ondBkOl000000_l0000:omTVf@03o`000?of2OKomPWf00SomPWf00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP04ooH9mP03o`000?oO8=oogb3O00cogb3O0_l0
0003ol`cc003o`000?nfBKKo0000017oNHIi00?o0000oc_4>olka3/01olka3/00ol0003o2_D:o`[e
2P04o`[e2P;o00002?l3o0<00ol0003o0?l0o`3o000>o`3o00;o00002?l7n0L00ol0003o</dboc;=
<P06oc;=<P03o`000?l/dbco;=</00Wo;=</00?o0000of>LHomSW6<02OmSW6<00ol0003o`cc3ol<l
``0=ol<l``03o`000?o]4^gokA;]00;okA;]0ol00007omTVf@03o`000?of2OKomPWf00OomPWf00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`000?oO8=oo
gb3O00Wogb3O0_l00006ol`cc003o`000?miQWWoNHIi013oNHIi00?o0000oc_4>olka3/01_lka3/0
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l3o0?o0o`300Co0o`30ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol7n0L00ol0003o</dboc;=<P06oc;=<P03o`000?l/dbco;=</00[o;=</00?o0000
of>LHomSW6<02?mSW6<00ol0003o`cc3ol<l``0=ol<l``03o`000?o]4^gokA;]00GokA;]0ol00004
omTVf@03o`000?of2OKomPWf00OomPWf00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003omPWfooH9mP06ooH9mP03o`000?oO8=oogb3O00Gogb3O0ol00008ol`cc003o`000?miQWWoNHIi
017oNHIi00Co0000oc_4>olka3_o>l@k1?l0000;o`[e2P;o000000Co0o`3o`000?l0003o00000ol:
m@X2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1oP700?o0000oc;=<_lbcC801_lb
cC800ol0003o;=</obcC;00:obcC;003o`000?mSW6?oHiaS00OoHiaS00?o0000ol<l`oo3?<<03_o3
?<<00ol0003okA;]ondBk@08ondBk@Co00002_of2OH00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003omPWfooH9mP07ooH9mP03o`000?oO8=oogb3O00;ogb3O0_l0000<ol`cc003o`000?miQWWo
NHIi013oNHIi1?l00003obo@;`03o`000?l:m@[o2_D:00_o2_D:00?o0000o`[e2_l:m@X01_l:m@X0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obcC;003o`000?mSW6?o
HiaS00KoHiaS00?o0000ol<l`oo3?<<03_o3?<<00ol0003okA;]ondBk@0;ondBk@03o`000?of2OKo
mPWf00OomPWf00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00WomPWf00Co0000omlP
gol0003o00003_o<<l`00ol0003oNHIiogV6N@0?ogV6N@03o`000?l_d2oo;m0_00Ko;m0_00?o0000
o`[e2_l:m@X02_l:m@X00ol0003o2_D:o`[e2P07o`[e2P;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?ldbcCo=</d00So=</d00?o0000obcC;?l/db`03?l/db`00ol0003oHiaSof>LH`05
of>LH`03o`000?o3?<?o`cc300oo`cc30_l0000=ondBk@03o`000?of2OKomPWf00KomPWf00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00[omPWf00?o0000ol`cc?o<<l`03_o<<l`00ol0
003oNHIiogV6N@0>ogV6N@03o`000?l_d2oo;m0_00Oo;m0_00?o0000o`[e2_l:m@X02_l:m@X00ol0
003o2_D:o`[e2P09o`[e2P;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?ldbcCo=</d
00Wo=</d00?o0000obcC;?l/db`02_l/db`4o`0000CoHiaS00?o0000ol<l`oo3?<<04?o3?<<01?l0
003ojQGZo`000?l0000<ondBk@03o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?of2OKomPWf00[omPWf00?o0000ol`cc?o<<l`03oo<<l`@o`0000[o;m0_00?o0000o`[e
2_l:m@X02Ol:m@X00ol0003o0?l0o`00000<o`[e2P05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o=</docC;=009ocC;=003o`000?l/dbco;=</00Oo;=</0ol00004of:MHP?o000000?oHiaS
o`000?o3?<<04Oo3?<<01?l0003ojQGZonXEj_oZ5NX2o`0000_okA;]00?o0000ooH9m_of2OH00oof
2OH00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oc3?<ol`cc00?
ol`cc003o`000?mhQgSoN8Mh00coN8Mh00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2_D:o`[e2P07
o`[e2P04o`000?l0o`3o0?l0o`0000go2_D:00Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?ldbcCo=</d00[o=</d00?o0000obcC;?l/db`00ol/db`3o`0000[oHYeR00?o0000ol<l`oo3?<<0
4?o3?<<00ol0003ojQGZonXEjP04onXEjP;o00002_o]4^d00ol0003omPWfooH9mP04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000comPWf00?o0000ol`cc?o<<l`03oo<<l`00ol0003oN8MhogR7N00<ogR7N003o`000?l_
d2oo;m0_00Wo;m0_00?o0000o`[e2_l:m@X01_l:m@X00ol0003o0?l0o`3o0002o`3o0003o`000?l:
m@[o2_D:00[o2_D:00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?ld
bcCo=</d00[o=</d00?o0000obcC;?l/db`00ol0000=of:MHP03o`000?o3?<?o`cc3013o`cc300?o
0000onXEj_oZ5NX01_oZ5NX2o`0000WokA;]0_l00004ood2o@03o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oc3?<ol`cc00=ol`cc0?o00003omhQgP0
0ol0003o;m0_obo@;`08obo@;`03o`000?l:m@[o2_D:00Go2_D:00?o0000o`3o0?l0o`000ol0o`00
0ol0003o2_D:o`[e2P0:o`[e2P03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o=</docC;=00;ocC;=0;o00004OmRWF800ol0003o`cc3ol<l``0?ol<l``03o`000?oZ5N[o
jQGZ00SojQGZ0_l00007ondBk@03o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooH9m_of2OH02?of2OH00ol0003oc3?<ol`cc009ol`cc0Go00000_nRGJ800ol0
003oN8MhogR7N00=ogR7N003o`000?l_d2oo;m0_00Wo;m0_00?o0000o`[e2_l:m@X01?l:m@X00ol0
003o0?l0o`3o0004o`3o0003o`000?l:m@[o2_D:00So2_D:00?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?ldbcCo=</d00_o=</d00?o0000of:MH_mRWF804?mRWF800ol0
003o`cc3ol<l``0?ol<l``03o`000?oZ5N[ojQGZ00[ojQGZ0_l00004ondBk@03o`000?om0_goo@;m
00Koo@;m0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003omPWfooH9mP07ooH9mP03o`000?o<<lcoc3?<00Coc3?<1Ol00007oj9MXP03
o`000?mhQgSoN8Mh00goN8Mh00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2_D:o`[e2P03o`[e2P03
o`000?l0o`3o0?l000Go0?l000?o0000o`[e2_l:m@X02?l:m@X00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ocC;=?ldbc@02oldbc@00ol0003oHYeRof:MHP0@of:MHP03
o`000?o3?<?o`cc300oo`cc300?o0000onXEj_oZ5NX03?oZ5NX2o`000003ondBkOl0003oo@;m00[o
o@;m00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000ol`cc?l00000
1?l0000<oj9MXP03o`000?mhQgSoN8Mh00koN8Mh00?o0000obo@;ol_d2l02?l_d2l00ol0003o2_D:
o`[e2P02o`[e2P03o`000?l0o`3o0?l000Oo0?l000?o0000o`[e2_l:m@X01ol:m@X00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ocC;=?ldbc@02oldbc@00ol0003oHYeR
of:MHP0Aof:MHP03o`000?o3?<?o`cc300go`cc300?o0000onXEj_oZ5NX03ooZ5NX00ol0003oo@;m
ood2o@0;ood2o@;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooH9m_of2OH01Oof2OH3o`00017oXUfR00?o0000ogR7N?mhQgP03_mh
QgP00ol0003o;m0_obo@;`09obo@;`04o`000?l:m@[o2_D:o`0000[o0?l000?o0000o`[e2_l:m@X0
1ol:m@X00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Oldbc@00ol0003o
HYeRof:MHP0Aof:MHP?o00003Oo3?<<00ol0003ojQGZonXEjP0?onXEjP03o`000?om0_goo@;m00go
o@;m00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_of2OH2o`0000;ohacS00?o0000oj9MX_nRGJ803onRGJ800ol0003o
N8MhogR7N00>ogR7N003o`000?l_d2oo;m0_00So;m0_1Ol0000;o`3o0003o`000?l:m@[o2_D:00Ko
2_D:00?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ocC;=003o`000?mRWF;oHYeR
017oHYeR00?o0000og2?L?m`Sg000ol0000:ol<l``Co00003OoZ5NX00ol0003oo@;mood2o@0?ood2
o@03o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooP7n?oh1oSon0Oh0_l00005on<Lh`03o`000?nRGJ;oXUfR00koXUfR00?o0000ogR7
N?mhQgP03_mhQgP00ol0003o;m0_obo@;`07obo@;`03o`000?lEjQGo5NXE00?o5NXE00?o0000o`3o
0?l0o`002?l0o`000ol0003o2_D:o`[e2P05o`[e2P03o`000?l0o`3o0?l000[o0?l01Ol0000<ocC;
=003o`000?mRWF;oHYeR013oHYeR00?o0000og2?L?m`Sg001?m`Sg03o`0000Ko`cc300?o0000onDJ
iOoU6^D00_oU6^D5o`0000SojQGZ00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00?o
n0Oh00?o0000on<LhooS7><01?oS7><00ol0003oXUfRoj9MXP0=oj9MXP03o`000?mhQgSoN8Mh00oo
N8Mh00?o0000obo@;ol_d2l01?l_d2l2o`0000Oo5NXE00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ocC;=?ldbc@02?ldbc@3o`00013oHYeR00?o0000og2?L?m`Sg002?m`Sg03o`0000;o
`cc300?o0000onDJiOoU6^D02?oU6^D5o`0000?ojQGZ00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oh1oSon0Oh00Con0Oh00?o0000on<LhooS7><01OoS7><00ol0003oXUfRoj9MXP0;oj9MXPCo0000
3omhQgP00ol0003o;m0_obo@;`03obo@;`03o`000?lEjQGo5NXE00So5NXE00?o0000o`3o0?l0o`00
1?l0o`02o`0000So3_4>00?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_ldbc@2o`0000?o<Lha00?o0000of:MH_mRWF803?mRWF800ol0003oL8m`og2?L00<og2?L0;o0000
4?oU6^D3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oS7>?ohacS00KohacS00?o
0000oj9MX_nRGJ802OnRGJ800ol0003o]4^do`000002ofNHI`?o00003?mhQgP01?l0003o;m0_obo@
;ol_d2l2o`0000co5NXE00?o0000o`3o0?l0o`000_l0o`000ol0003o3_4>o`ka3P08o`ka3P03o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o=</docC;=002ocC;=003o`00
0?lacS7o<Lha00Co<Lha0_l0000;of:MHP03o`000?m`Sg3oL8m`00coL8m`00?o0000okE:]Ol00000
4_oU6^D00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on0OhooP7n006ooP7n003o`000?oS7>?ohacS00OohacS00?o
0000oj9MX_nRGJ801_nRGJ82o`0000;o]4^d00?o0000ofNHIomWV6L00omWV6L3o`0000[oN8Mh00?o
0000obo@;ol000003olEjQD01?l0003o0?l0o`000?l0000;o`ka3P03o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o=</do`000?l00009oc7><@03o`000?mRWF;oHYeR00Oo
HYeR00?o0000og2?L?m`Sg003?m`Sg001?l0003o]DZeokE:]Ol0000ConDJi@03o`000?om0_goo@;m
00coo@;m0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ohacSon<Lh`08on<Lh`03o`000?nRGJ;oXUfR00Co
XUfR00?o0000okA;]?ndBk@00ondBk@00ol0003oIiQWofNHI`05ofNHI`?o00001_mhQgP4o`00013o
5NXE00?o0000o`ka3_l>l@h03?l>l@h00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000oc7><OlacS402_lacS42o`0000KoHYeR00?o0000og2?L?m`Sg003?m`Sg000ol0003o
]DZeokE:]@02okE:]@03o`000?oU6^GoiA[U00ooiA[U00?o0000ooH9m_l000002oom0_d2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on0OhooP7n008ooP7n003o`000?oS7>?ohacS00WohacS00Co0000oj9MX_nRGJ;o
XUfR0_l00006okA;]003o`000?mWV6OoIiQW00SoIiQW0ol000000omhQgSo0000o`000004oc?<<`03
o`000?lEjQGo5NXE00go5NXE00?o0000o`ka3_l>l@h03?l>l@h00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000oc7><OlacS403?lacS400ol0003oHYeRof:MHP03o`0000ko
L8m`00?o0000okE:]OneB[D00oneB[D00ol0003oiA[UonDJi@0>onDJi@05o`000?of2OKomPWfooH9
m_l000002?om0_d2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n009ooP7n003o`000?oS7>?ohacS00[o
hacS00?o0000oj9MX_l000002?ndBk@00ol0003oIiQWofNHI`0;ofNHI`03o`000?lcc3?o<l`c00Go
<l`c00?o0000oaGZ5OlEjQD03?lEjQD00ol0003o3_4>o`ka3P0<o`ka3P03o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo<Lha0_l00002ofn@K`03o`000?m`Sg3oL8m`00_o
L8m`00?o0000okE:]OneB[D01?neB[D00ol0003oiA[UonDJi@0=onDJi@03o`000?of2OKomPWf00?o
mPWf00?o0000ood2oOom0_d00_om0_d3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooP7n003o`000?oS7>?ohacS00_ohacS00?o0000okA;]?ndBk@0
1ondBk@00ol0003oIiQWofNHI`0;ofNHI`03o`000?lcc3?o<l`c00Ko<l`c00?o0000oaGZ5OlEjQD0
2olEjQD2o`0000go3_4>00?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l6n@Ko1_T6o`0000ko<Lha00?o0000ofn@Kom_T6l00_m_T6l00ol0003oL8m`og2?L009og2?L003
o`000?neB[Go]DZe00Ko]DZe00?o0000onDJiOoU6^D02ooU6^D00ol0003omPWfooH9mP05ooH9mP04
o`000?om0_go0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son0Oh00?o0000on<LhooS7><02_oS7><2o`0000Wo
]4^d00?o0000ofNHIomWV6L02omWV6L00ol0003o<l`coc?<<`07oc?<<`03o`000?lEjQGo5NXE00Wo
5NXE00Co0000o`3o0?l0o`3o00003?l>l@h00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ki1_l6n@Ko1_T6o`00000>oc7><@03o`000?m_T6ooKi1_00?oKi1_00?o0000
og2?L?m`Sg001om`Sg000ol0003o]DZeokE:]@07okE:]@03o`000?oU6^GoiA[U00[oiA[U00?o0000
ooH9m_of2OH01oof2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooP7n003o`000?oS7>?ohacS
00WohacS00Co0000om`Sg?oL8mco00002OndBk@00ol0003oIiQWofNHI`09ofNHI`03o`000?lcc3?o
<l`c00Wo<l`c00?o0000oaGZ5OlEjQD01olEjQD00ol0003o0?l0o`3o0002o`3o0003o`000?l>l@ko
3_4>00Wo3_4>00?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l6n@Ko
1_T600?o1_T600?o0000oc7><OlacS402_lacS400ol0003oKi1_ofn@K`05ofn@K`03o`000?m`Sg3o
L8m`00GoL8m`00?o0000okE:]OneB[D02?neB[D00ol0003oiA[UonDJi@09onDJi@03o`000?of2OKo
mPWf00SomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oh1oP3o`0000WohacS00?o0000om`S
g?oL8m`00_oL8m`00ol0003o]4^dokA;]006okA;]003o`000?mWV6OoIiQW00WoIiQW00?o0000oc?<
<olcc3<02_lcc3<00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?l0o`3o0?l000Co0?l000?o0000o`ka
3_l>l@h02?l>l@h00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o<Lhaoc7><@0:oc7><@03o`000?m_T6ooKi1_00KoKi1_00?o0000og2?
L?m`Sg000om`Sg000ol0003o]DZeokE:]@09okE:]@03o`000?oU6^GoiA[U00SoiA[U00?o0000ooH9
m_of2OH02Oof2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo8=lP?o00001OoS7><00ol0003o
g2?Lom`Sg003om`Sg003o`000?ndBkCo]4^d00Ko]4^d00?o0000ofNHIomWV6L02OmWV6L00ol0003o
<l`coc?<<`0;oc?<<`03o`000?lEjQGo5NXE00?o5NXE00?o0000o`3o0?l0o`001_l0o`000ol0003o
3_4>o`ka3P08o`ka3P03o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1_T600?o0000oc7><OlacS402OlacS400ol0003oKi1_ofn@K`07ofn@K`05o`000?m`Sg3oL8m`og2?
L?l000003OneB[D00ol0003oiA[UonDJi@06onDJi@03o`000?of2OKomPWf00[omPWf00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?ob3O;olPgb00GolPgb0ol000000ooS7>?o0000om`Sg006om`Sg003
o`000?ndBkCo]4^d00Go]4^d00?o0000ofNHIomWV6L02OmWV6L00ol0003o<l`coc?<<`0<oc?<<`05
o`000?lEjQGo5NXEoaGZ5Ol000002_l0o`000ol0003o3_4>o`ka3P07o`ka3P03o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olXebSo0000o`Ki1P07o`Ki1P03o`000?lacS7o<Lha
00So<Lha00?o0000ofn@Kom_T6l02Om_T6l00ol0003oL8m`o`00000=okE:]@Co00001OoU6^D00ol0
003omPWfooH9mP0;ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003olPgboo8=lP08oo8=lP03
o`000?oL8mcog2?L00Oog2?L00?o0000okA;]?ndBk@01?ndBk@00ol0003oIiQWofNHI`09ofNHI`03
o`000?lcc3?o<l`c00go<l`c00?o0000oaGZ5Ol000003?l0o`0:o`0000Oo0?l00ol00005obSG:003
o`000?l6n@Ko1_T600Ko1_T600?o0000oc7><OlacS401olacS400ol0003oKi1_ofn@K`0:ofn@K`03
o`000?neB[Go]DZe00_o]DZe00?o0000onDJiOoU6^D00_oU6^D3o`000003onDJiOl0003omPWf00_o
mPWf0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003og2?Lom`Sg007om`Sg003o`00
0?ndBkCo]4^d00Go]4^d00?o0000ofNHIomWV6L01omWV6L00ol0003o<l`coc?<<`0?oc?<<`;o0000
2ol0o`000ol0003o6n@Koa_T6`07oa_T6`03o`000?l0o`3o0?l000;o0?l00ol00008obSG:003o`00
0?l6n@Ko1_T600Ko1_T600?o0000oc7><OlacS401olacS400ol0003oKi1_ofn@K`0:ofn@K`03o`00
0?neB[Go]DZe00[o]DZe00?o0000onDJiOoU6^D01_oU6^D00ol0003omPWfooH9mP08ooH9mP?o0000
0_oh1oP00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003og2?Lom`S
g008om`Sg003o`000?ndBkCo]4^d00Co]4^d00?o0000ofNHIomWV6L01omWV6L00ol0003o<l`coc?<
<`0>oc?<<`04o`000?l4n`Co1?/4o`0000Wo0?l000?o0000oa_T6olKi1/02OlKi1/01?l0003o0?l0
o`000?l0000<obSG:003o`000?l6n@Ko1_T600Ko1_T600?o0000oc7><OlacS401_lacS400ol0003o
Ki1_ofn@K`0;ofn@K`03o`000?neB[Go]DZe00Oo]DZe0_l00009onDJi@03o`000?of2OKomPWf00Co
mPWf1?l00006ooP7n003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003olPgboo8=lP09oo8=lP03o`00
0?oL8mcog2?L00Sog2?L00?o0000okA;]?ndBk@00ondBk@>o`0000go<l`c00?o0000o`Ck1?l4n`@0
0_l4n`@00ol0003o0?l0o`3o0005o`3o0003o`000?lKi1_o6n@K00_o6n@K00?o0000obSG:?lXebP0
3?lXebP00ol0003o1_T6o`Ki1P06o`Ki1P03o`000?lacS7o<Lha00Go<Lha00?o0000ofn@Kom_T6l0
3?m_T6l00ol0003o]DZeokE:]@06okE:]@03o`000?oU6^GoiA[U00[oiA[U00?o0000ooH9m_of2OH0
0ol0000:ooP7n0?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000om`Sg?oL8m`02?oL
8m`01Ol0003o]4^dokA;]?ndBkCo000000_oNXEj00?o0000oaSW6?lHiaP00ol00009oc?<<`03o`00
0?l4n`Co1?/400Co1?/400?o0000o`3o0?l0o`000ol0o`000ol0003o6n@Koa_T6`0<oa_T6`03o`00
0?lXebSo:=LX00go:=LX00?o0000o`Ki1_l6n@H01_l6n@H00ol0003o<Lhaoc7><@03oc7><@?o0000
3Om_T6l00ol0003o]DZeokE:]@05okE:]@03o`000?oU6^GoiA[U00coiA[U0_l0000=ooP7n003o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000om`Sg?oL8m`02?oL
8m`4o`0000coNXEj00?o0000oaSW6?lHiaP00olHiaP3o`0000Go<l`c00?o0000o`Ck1?l4n`@01_l4
n`@01Ol0003o0?l0o`3o0?l0o`3o000000oo6n@K00?o0000obSG:?lXebP03OlXebP00ol0003o1_T6
o`Ki1P06o`Ki1P03o`000?lacS7o<Lha00?o00000olWf2L00ol0003oKi1_ofn@K`0;ofn@K`03o`00
0?neB[Go]DZe00?o]DZe00?o0000onDJiOoU6^D03OoU6^D00ol0003on0OhooP7n00;ooP7n003o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo8=l_ob3O802_ob3O83o`0000Kog2?L0ol0
0003oldbc@03o`000?mjQG[oNXEj00[oNXEj00?o0000oaSW6?lHiaP01_lHiaP3o`000003oc?<<ol0
003o1?/400Wo1?/400?o0000o`3o0?l000004?lKi1/00ol0003o:=LXobSG:00=obSG:003o`000?l6
n@Ko1_T600Oo1_T60_l00007obOH9`03o`000?m_T6ooKi1_00[oKi1_00Co0000okE:]OneB[Go]DZe
0ol0000?onDJi@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo8=l_ob3O802_ob
3O801?l0003ojaC[on/Djoo[5>/2o`000004om`Sg?l0003o0000o`0000KocC;=00?o0000ogZ5N_mj
QGX02_mjQGX00ol0003o6>LHoaSW6009oaSW6003o`000?l4n`Co1?/400[o1?/400?o0000oa_T6olK
i1/03olKi1/00ol0003o:=LXobSG:00>obSG:003o`000?l6n@Ko1_T600Ko1_T600?o0000obOH9olW
f2L01olWf2L4o`0000SoKi1_00Co0000okE:]OneB[Go00000oo<<l`2o`0000goiA[U00?o0000ooP7
n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003o
jaC[on/Dj`04on/Dj`03o`000?o=</gocC;=00OocC;=00?o0000ogZ5N_mjQGX02OmjQGX00ol0003o
6>LHoaSW600:oaSW6003o`000?l4n`Co1?/400[o1?/400?o0000oa_T6olKi1/03olKi1/00ol0003o
:=LXobSG:00>obSG:003o`000?l6n@Ko1_T600Go1_T600?o0000obOH9olWf2L02?lWf2L01?l0003o
KI9]offBKOm]TVd7o`0000;oKi1_0_l00006ol`cc0;o00003?oU6^D00ol0003on0OhooP7n009ooP7
n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003olPgboo8=lP08oo8=lP03o`000?o[5>_ojaC[00Go
jaC[00?o0000oldbcOo=</d02?o=</d00ol0003oNXEjogZ5NP08ogZ5NP03o`000?lHiaSo6>LH00[o
6>LH00?o0000o`Ck1?l4n`@02ol4n`@00ol0003o6n@Koa_T6`0>oa_T6`03o`000?lXebSo:=LX00ko
:=LX1Ol00002o`Ki1P03o`000?lWf2Oo9mPW00Wo9mPW00?o0000offBKOm]TVd02?m]TVd3o`0000Wo
c3?<0_l0000:onDJi@03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ob3O;olPgb00SolPgb00?o0000on/Djoo[5>/01oo[5>/00ol0003ocC;=oldbc@07oldbc@03o`00
0?mjQG[oNXEj00SoNXEj00?o0000oaSW6?lHiaP02_lHiaP00ol0003o1?/4o`Ck100:o`Ck10;o0000
3_lKi1/3o`0000go:=LX0ol00005ocO8=`;o00002olWf2L00ol0003oKI9]offBK@0;offBK@;o0000
2_o<<l`2o`0000OoiA[U0ol00009ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:on/Dj`03o`00
0?o=</gocC;=00OocC;=00?o0000ogZ5N_mjQGX02?mjQGX>o`0000Wo1?/40ol000000ol0o`3o0000
oa_T6`0:oa_T6`?o00000_ldbc@00ol0003o:=LXobSG:009obSG:0;o00002Olgb3L00ol0003o9mPW
obOH9`09obOH9`03o`000?m]TVgoKI9]00_oKI9]00?o0000oiMXUol000002oo<<l`2o`0000CoiA[U
00Co0000onl@koo_4>ooka3_0_l00007ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003ojaC[
on/Dj`09on/Dj`03o`000?o=</gocC;=00KocC;=00?o0000ogZ5N_mjQGX02?mjQGX00ol0003o7N8M
oagR7@0:oagR7@03o`000?l4n`Co1?/400Co1?/40ol00005o`3o0003o`000?lKi1_o6n@K00Co6n@K
1?l00006ocC;=003o`000?lXebSo:=LX00Ko:=LX0_l0000;ocO8=`03o`000?lWf2Oo9mPW00Wo9mPW
00?o0000offBKOm]TVd02_m]TVd01Ol0003oUfRGoiMXUonGJ9Oo000000coc3?<0_l000000ooU6^Go
0000onl@k`05onl@k`03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o[5>_ojaC[00SojaC[00?o0000oldbcOo=</d01_o=</d00ol0003oNXEjogZ5NP07ogZ5NP03o`00
0?lMhQgo7N8M00_o7N8M00?o0000o`Ck1?l4n`@00_l4n`@2o`0000Wo0?l000?o0000oa_T6olKi1/0
0ol0000;ocC;=003o`000?lXebSo:=LX00;o:=LX0ol0000>ocO8=`03o`000?lWf2Oo9mPW00Oo9mPW
00?o0000offBKOm]TVd02om]TVd00ol0003oUfRGoiMXU`02oiMXU`03o`000?o<<lcoc3?<00_oc3?<
00?o0000onl@koo_4>l01_o_4>l2o`0000?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o[
5>_ojaC[00OojaC[00?o0000oldbcOo=</d01oo=</d00ol0003oNXEjogZ5NP05ogZ5NP?o00003OlM
hQd4o`0000_o0?l00ol0000?ocC;=004o`000?lXebSo0000o`00017o=lPg00?o0000obOH9olWf2L0
1olWf2L00ol0003oKI9]offBK@0:offBK@03o`000?nGJ9OoUfRG00CoUfRG00?o0000ol`cc?o<<l`0
1oo<<l`3o`0000_oka3_1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/02?o[5>/00ol0003ocC;=oldb
c@06oldbc@03o`000?mjQG[oNXEj00;oNXEj0ol00003oeJYEP03o`000?lMhQgo7N8M00[o7N8M00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AocC;=003o`000?lgb3Oo=lPg017o=lPg00?o
0000obOH9olWf2L01olWf2L00ol0003oKI9]offBK@0:offBK@03o`000?nGJ9OoUfRG00GoUfRG00Co
0000ol`cc?o<<lcoc3?<1Ol00002om</d`03o`000?o_4>ooka3_00Woka3_00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000on/Djoo[5>/01oo[5>/00ol0003ocC;=oldbc@05oldbc@?o0000
00?oNXEjo`000?l000001omFZEH00ol0003o7N8MoagR7@08oagR7@?o00002_l0o`02o`0000;o0?l0
00?o0000ocC;=?ldbc@03oldbc@00ol0003o=lPgocO8=`0AocO8=`03o`000?lWf2Oo9mPW00Oo9mPW
00?o0000offBKOm]TVd02Om]TVd00ol0003oUfRGoiMXU`07oiMXU`?o00001ooC;=<00ol0003oka3_
onl@k`09onl@k`03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000on/Djoo[5>/01oo[
5>/4o`0000;ocC;=0_l00003oki1_P03o`000?mFZEKoEZUF00SoEZUF0_l00006oagR7@;o00000olG
j1L00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000ocC;=?ldbc@03_ld
bc@00ol0003o=lPgocO8=`0BocO8=`03o`000?lWf2Oo9mPW00Go9mPW00?o0000offBKOm]TVd02Om]
TVd00ol0003oUfRGoiMXU`08oiMXU`03o`000?oC;=?odbcC00OodbcC00?o0000onl@koo_4>l02?o_
4>l00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o[5>_ojaC[00CojaC[0_l00004
on/Dj`;o00001Onn@Kh00ol0003oEZUFoeJYEP0:oeJYEP03o`000?lMhQgo7N8M00;o7N8M00?o0000
oaOX5olGj1L01?lGj1L00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
ocC;=?ldbc@03_ldbc@00ol0003o=lPgocO8=`0BocO8=`[o00002_m]TVd00ol0003oUfRGoiMXU`08
oiMXU`03o`000?oC;=?odbcC00OodbcC00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ojaC[on/Djoo[5>/2o`0000OojaC[00?o0000oki1__nn@Kh01?nn@Kh0
0ol0003oEZUFoeJYEP0:oeJYEP04o`000?lMhQgo0000o`0000So5nPG00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?ldbcCo=</d00ko=</d00?o0000ocO8=olgb3L04_lgb3L00ol0003oA[U6
odJiAP07odJiAP03o`000?m]TVgoKI9]00KoKI9]00?o0000oiMXUonGJ9L02_nGJ9L00ol0003odbcC
om</d`06om</d`03o`000?o_4>ooka3_00Soka3_00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o[
5>_o0000o`0000WojaC[00?o0000oki1__nn@Kh01?nn@Kh00ol0003oEZUFoeJYEP0;oeJYEP03o`00
0?lGj1Oo5nPG00Wo5nPG00?o0000o`3o0?l000002Ol0o`000ol0003o=</docC;=00>ocC;=0;o0000
4_lgb3L00ol0003oA[U6odJiAP09odJiAP;o00001_m]TVd00ol0003oUfRGoiMXU`0:oiMXU`03o`00
0?oC;=?odbcC00KodbcC00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000on/Djoo[5>/02Oo[5>/00ol0003o_T6noki1_P05oki1_P03o`000?mFZEKoEZUF00[oEZUF00?o
0000oaOX5olGj1L02_lGj1L2o`0000Wo0?l000?o0000ocC;=?ldbc@03_ldbc@00ol0003o9=/To`00
0002o`0000oo=lPg00?o0000odJiA_m6^DH02om6^DH00ol0003oKI9]offBK@03o`0000goUfRG00?o
0000om</dooC;=<01_oC;=<00ol0003oka3_onl@k`07onl@k`03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003ojaC[on/Dj`09on/Dj`03o`000?nn@Kko_T6n00Go_T6n00?o0000oeJYE_mFZEH02OmFZEH2
o`0000_o5nPG0_l0000;o`3o0003o`000?ldbcCo=</d00co=</d00?o0000obCK9?lTfb@00olTfb@3
o`0000co=lPg00?o0000odJiA_m6^DH03?m6^DH2o`0000;oT6n@00?o0000oiMXUonGJ9L03?nGJ9L0
0ol0003odbcCom</d`05om</d`03o`000?o_4>ooka3_00Ooka3_00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o[5>_ojaC[00[ojaC[00?o0000oki1__nn@Kh01_nn@Kh00ol0003oEZUFoeJYEP07oeJY
EP03o`000?mKY5_o000000[o5nPG00Co0000o`o`3ol?l0oo00002_l0o`000ol0003o=</docC;=00<
ocC;=003o`000?lTfbCo9=/T00Ko9=/T0_l00008ocO8=`;o00003om6^DH00ol0003oT6n@oi1_T002
oi1_T003o`000?nGJ9OoUfRG00_oUfRG00?o0000om</dooC;=<01OoC;=<00ol0003oka3_onl@k`07
onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ojaC[on/Dj`0:on/Dj`03o`000?nn@Kko_T6n
00Ko_T6n00?o0000oeJYE_mFZEH01_mFZEH01Ol0003oFjAKoe^TFomKY5_o000000So5nPG00?o0000
o`o`3ol?l0l00_l?l0l00ol0003o0?l0o`3o0006o`3o00Co00003?ldbc@00ol0003o9=/TobCK9008
obCK90?o00000_lgb3L3o`000003ocG:=Ol0003oA[U600goA[U600?o0000oi1_T?n@Ki001?n@Ki00
0ol0003oUfRGoiMXU`0:oiMXU`03o`000?oC;=?odbcC00GodbcC00?o0000onl@koo_4>l01_o_4>l0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/02oo[5>/00ol0003o_T6noki1_P07oki1
_P03o`000?mFZEKoEZUF00?oEZUF0_l00005oe^TF`03o`000?lGj1Oo5nPG00Co5nPG00?o0000o`o`
3ol?l0l00ol?l0l00ol0003o0?l0o`3o0005o`3o0003o`000?l5nPGo1OX500;o1OX50ol00007ocC;
=0;o00003_lTfb@2o`0000Go=LXe00?o0000odJiA_m6^DH02_m6^DH00ol0003oT6n@oi1_T005oi1_
T003o`000?nGJ9OoUfRG00_oUfRG00?o0000om</dooC;=<01?oC;=<00ol0003oka3_onl@k`06onl@
k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ojaC[on/Dj`0;on/Dj`03o`000?nn@Kko_T6n00Oo
_T6n00?o0000oeJYE_mFZEH00_mFZEH00ol0003oFjAKoe^TF`06oe^TF`03o`000?lGj1Oo5nPG00;o
5nPG00?o0000o`o`3ol?l0l01Ol?l0l00ol0003o0?l0o`3o0002o`3o00;o00002?l5nPD3o`0000;o
=</d0_l000000ol;m0_o0000obCK900=obCK9003o`000?lebSGo=LXe00Go=LXe00?o0000odJiA_m6
^DH02?m6^DH00ol0003oT6n@oi1_T007oi1_T003o`000?nGJ9OoUfRG00[oUfRG00?o0000om</dooC
;=<01?oC;=<00ol0003oka3_onl@k`06onl@k`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[
on/Dj`0<on/Dj`03o`000?nn@Kko_T6n00So_T6n00Co0000oeJYE_mFZEKo00002OmKY5/01Ol0003o
5nPGoaOX5olGj1Oo000000So3o0?00Go0000o`3o0?l0o`3o0?l0o`00000=o`Gj1@;o00001?l;m0/0
0ol0003o9=/TobCK900;obCK9003o`000?lebSGo=LXe00Ko=LXe00?o0000odJiA_m6^DH01om6^DH0
0ol0003oT6n@oi1_T008oi1_T0Co00002?nGJ9L00ol0003odbcCom</d`04om</d`03o`000?o_4>oo
ka3_00Koka3_00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o[5>_ojaC[00_ojaC[0ol00009oki1
_P03o`000?mFZEKo000000_oFjAK00?o0000oaOX5ol000002_l?l0l00ol0003o0?l0o`00000?o`Gj
1@03o`000?l;m0_o2o@;00;o2o@;00?o0000obCK9?lTfb@02olTfb@00ol0003o=LXeocG:=@06ocG:
=@03o`000?m6^DKoA[U600KoA[U600?o0000oi1_T?n@Ki002On@Ki001?l0003o_4>loka3_?nl@k`7
o`0000;oUfRG00?o0000om</dooC;=<00ooC;=<00ol0003oka3_onl@k`05onl@k`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o[5>_ojaC[00SojaC[0ol00003onLHi`03o`000?nn@Kko_T6n00Oo_T6n00?o0000oe^T
FomKY5/02omKY5/00ol0003o3o0?o`o`3`0:o`o`3`03o`000?l5nPGo1OX500go1OX500?o0000o`_d
2ol;m0/01?l;m0/00ol0003o9=/TobCK9009obCK9003o`000?lebSGo=LXe00So=LXe00?o0000odJi
A_m6^DH00om6^DH2o`0000coT6n@00?o0000oka3_?nl@k`02?nl@k`<o`0000?oka3_0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on/Djoo[5>/01_o[5>/3o`0000OoiaSW00?o0000oki1__nn@Kh01_nn@Kh00ol0003o
FjAKoe^TF`0;oe^TF`03o`000?l?l0oo3o0?00Wo3o0?0_l0000>o`Gj1@03o`000?l;m0_o2o@;00Go
2o@;00?o0000obCK9?lTfb@02OlTfb@00ol0003o=LXeocG:=@09ocG:=@03o`000?m6^DKo000000;o
00000_n4Nh@00ol0003oT6n@oi1_T008oi1_T003o`000?nl@kco_4>l00co_4>l00?o0000onXEj_oZ
5NX01_oZ5NX3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003ojaC[on/Dj`03on/Dj`?o00002ooW6>L00ol0003o_T6n
oki1_P04oki1_P03o`000?mKY5_oFjAK00_oFjAK0ol00007o`o`3`?o000000?o2o@;o`000?l5nPD0
3Ol5nPD00ol0003o2o@;o`_d2`06o`_d2`03o`000?lTfbCo9=/T00So9=/T00?o0000ocG:=OlebSD0
2_lebSD00ol0003oQ7^4ohAkQ004ohAkQ003o`000?n@Ki3oT6n@00OoT6n@00?o0000oka3_?nl@k`0
2onl@k`00ol0003ojQGZonXEjP08onXEjP03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004on/Djol0
003o0000o`0000ooiaSW00?o0000oki1__nn@Kh00onn@Kh>o`0000?oA[U60_l00002o`o`3`?o0000
1Ol;m0/00ol0003o1OX5o`Gj1@0:o`Gj1@03o`000?l;m0_o2o@;00Oo2o@;00?o0000obCK9?lTfb@0
2?lTfb@00ol0003o=LXeocG:=@0:ocG:=@03o`000?n4NhCoQ7^400GoQ7^400?o0000oi1_T?n@Ki00
1_n@Ki000ol0003o_4>loka3_00;oka3_003o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;oiaSW00?o0000oki1__nn@Kh00_nn@Kh00ol0003oZEJYojUF
Z@0:ojUFZ@03o`000?m6^DKoA[U600?oA[U60_l00009o`_d2`03o`000?l5nPGo1OX500Wo1OX500?o
0000o`_d2ol;m0/02?l;m0/2o`0000So9=/T00?o0000ocG:=OlebSD02OlebSD00ol0003oQ7^4ohAk
Q007ohAkQ003o`000?n@Ki3oT6n@00CoT6n@00?o0000oka3_?nl@k`02onl@k`00ol0003ojQGZonXE
jP09onXEjP03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oiaSWonLHi`0?onLHi`?o000000?o_T6n
o`000?nYEZT02onYEZT00ol0003oA[U6odJiAP04odJiAP03o`000?l;m0_o2o@;00Wo2o@;00?o0000
o`Gj1Ol5nPD01ol5nPD00ol0003o2o@;o`_d2`09o`_d2`04o`000?lBkA;o0000o`0000Ko9=/T00?o
0000ocG:=OlebSD02OlebSD00ol0003oQ7^4ohAkQ008ohAkQ003o`000?n@Ki3oT6n@00?oT6n@00?o
0000oka3_?nl@k`02onl@k`00ol0003ojQGZonXEjP09onXEjP03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oiaSWonLHi`0<onLHi`;o00000ooV6NH2o`0000coZEJY00?o0000odJiA_m6^DH01?m6^DH0
0ol0003o2o@;o`_d2`0:o`_d2`Wo00002ol;m0/00ol0003o4^dBoa;]4P02oa;]4P?o00000_lTfb@0
0ol0003o=LXeocG:=@0:ocG:=@03o`000?n4NhCoQ7^400WoQ7^400?o0000oi1_T?n@Ki000_n@Ki00
0ol0003o_4>loka3_00:oka3_003o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oW6>L2o`0000GoiQWV00?o0000ol4n`Ol000002_nYEZT00ol0003oA[U6odJiAP06odJi
AP03o`000?l;m0_o2o@;00Wo2o@;00?o0000o`3o0?l0o`001Ol0o`000ol0003o2o@;o`_d2`09o`_d
2`03o`000?lBkA;o4^dB00Go4^dB0ol00009ocG:=@?o00003On4Nh@01Ol0003oT6n@oi1_T?n@Ki3o
000000co_4>l00?o0000onXEj_oZ5NX02OoZ5NX00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onLH
iooW6>L01OoW6>L2o`0000OoiQWV00Co0000ol4n`Oo1?/7o00002OnYEZT00ol0003oA[U6odJiAP06
odJiAP03o`000?l;m0_o2o@;00So2o@;00?o0000o`3o0?l0o`001ol0o`000ol0003o2o@;o`_d2`07
o`_d2`03o`000?lBkA;o4^dB00So4^dB0ol00002ocG:=@Go00000_mUVVD00ol0003oQ7^4ohAkQ00<
ohAkQ003o`000?n@Ki3o000000co_4>l00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onLHiooW6>L00_oW6>L2o`0000SoiQWV00?o0000ol4n`Oo1?/400_o1?/45o`00
00CoZEJY00?o0000odJiA_m6^DH01_m6^DH00ol0003o2o@;o`_d2`08o`_d2`03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`_d2ol;m0/01ol;m0/00ol0003o4^dBoa;]4P08oa;]4P03o`000?l_d2oo;m0_
00;o00002?mUVVD00ol0003oQ7^4ohAkQ00<ohAkQ0Co00002_nl@k`00ol0003ojQGZonXEjP0:onXE
jP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oiaSWo`000?l0000:onHIiP03o`000?o1?/7o`Ck1
00;o`Ck100?o0000ohQgR?n8MhP00_n8MhP4o`0000WoA[U600?o0000o`_d2ol;m0/02?l;m0/00ol0
003o0?l0o`3o0008o`3o0003o`000?l;m0_o2o@;00Go2o@;00?o0000oa;]4_lBkA802?lBkA801Ol0
003o;m0_obo@;ol_d2oo000000[oIIYU0ol0000;ohAkQ004o`000?oL8mcog2?Lom`Sg0Co00001Onl
@k`00ol0003ojQGZonXEjP0;onXEjP03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oiQWVonHIiP0:
onHIiP03o`000?o1?/7o`Ck100?o`Ck100?o0000ohQgR?n8MhP01?n8MhP00ol0003oA[U6odJiAP07
odJiAP03o`000?l;m0_o2o@;00Ko2o@;0_l0000;o`3o0003o`000?l;m0_o2o@;00Go2o@;00?o0000
oa;]4_lBkA802?lBkA800ol0003o;m0_obo@;`02obo@;`03o`000?mUVVGoIIYU00OoIIYU00?o0000
ok5>/OnaC[401?l00006ohAkQ003o`000?oL8mcog2?L00Kog2?L0ol00002oka3_003o`000?oZ5N[o
jQGZ00_ojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oV6NKoiQWV00WoiQWV00?o0000ol4n
`Oo1?/401?o1?/400ol0003oR7N8ohQgR005ohQgR003o`000?m6^DKoA[U600OoA[U600?o0000o`_d
2ol;m0/00_l;m0/3o`000003oa[U6_l0003o0?l000[o0?l000?o0000o`_d2ol;m0/01Ol;m0/00ol0
003o4^dBoa;]4P07oa;]4P03o`000?l_d2oo;m0_00?o;m0_00?o0000ofFJIOmUVVD01omUVVD00ol0
003o/Djaok5>/@04ok5>/@?o00000_n4Nh@00ol0003og2?Lom`Sg00:om`Sg0;o00003_oZ5NX00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onHIi_oV6NH02OoV6NH00ol0003o`Ck1ol4n`@04ol4n`@03
o`000?n8MhSoR7N800KoR7N80_l00007odJiAP03o`000?l;m0_o000000;o00001OlJiAX00ol0003o
0?l0o`3o0008o`3o00?o00001?l;m0/00ol0003o4^dBoa;]4P08oa;]4P03o`000?l_d2oo;m0_00Co
;m0_00?o0000ofFJIOmUVVD01_mUVVD00ol0003o/Djaok5>/@07ok5>/@;o00003_oL8m`00ol0003o
jQGZonXEjP0;onXEjP03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiQWVonHIiP08onHIiP03o`00
0?o1?/7o`Ck100Go`Ck100?o0000ohQgR?n8MhP01?n8MhP00ol0003oOh1oogn0O`03o`0000CoA[U6
0_l00008oa[U6P03o`000?l0o`3o0?l000Oo0?l000Co0000ob_D:ol[e2_o:m@[0ol000000ol;m0_o
0000oa;]4P09oa;]4P03o`000?l_d2oo;m0_00Co;m0_00?o0000ofFJIOmUVVD01OmUVVD00ol0003o
/Djaok5>/@09ok5>/@03o`000?oL8mcog2?L00gog2?L00?o0000onXEj_oZ5NX02_oZ5NX00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onHIi_oV6NH01ooV6NH00ol0003o`Ck1ol4n`@06ol4n`@03o`00
0?n8MhSoR7N800?oR7N800?o0000ogn0OomoP7l01?moP7l2o`000003odJiA_l0003o6^DJ00[o6^DJ
00?o0000o`3o0?l0o`001Ol0o`000ol0003o:m@[ob_D:`05ob_D:`03o`000?lBkA;o4^dB00Oo4^dB
0ol00007obo@;`03o`000?mUVVGoIIYU00CoIIYU00?o0000ok5>/OnaC[402OnaC[400ol0003og2?L
om`Sg00=om`Sg003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oV
6NKoiQWV00GoiQWV0ol00009ol4n`@05o`000?n8MhSoR7N8ohQgR?l000002OmoP7l00ol0003o6^DJ
oa[U6P0;oa[U6P03o`000?l0o`3o0?l000?o0?l000?o0000ob_D:ol[e2/01_l[e2/00ol0003o4^dB
oa;]4P06oa;]4P05o`000?lebSGo=LXeocG:=Ol000001ol_d2l00ol0003oIIYUofFJI@03ofFJI@03
o`000?naC[7o/Dja00Wo/Dja00?o0000om`Sg?oL8m`03_oL8m`00ol0003ojQGZonXEjP09onXEjP03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiQWVo`000004o`0000;okQ7^00?o0000ol4n`Oo1?/40
1oo1?/401?l0003oR7N8ohQgR?l00009ogn0O`;o00003OlJiAX00ol0003o0?l0o`3o0002o`3o0003
o`000?l[e2_o:m@[00So:m@[00?o0000oa;]4_lBkA800olBkA82o`0000Go=LXe00?o0000obo@;ol_
d2l01?l_d2l00ol0003oIIYUofFJI@03ofFJI@03o`000?naC[7o/Dja00Wo/Dja00?o0000om`Sg?oL
8m`03_oL8m`00ol0003ojQGZonXEjP09onXEjP03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000SokQ7^
00?o0000ol4n`Oo1?/401_o1?/400ol0003oR7N8o`000009ogn0O`04o`000?mHYeSoF:MHo`0000go
6^DJ00Co0000o`3o0?l0o`3o00003?l[e2/01Ol0003o4^dBoa;]4_lBkA;o000000So=LXe0_l00005
obo@;`03o`000?mUVVGoIIYU00;oIIYU00?o0000ok5>/OnaC[402OnaC[400ol0003og2?Lom`Sg00>
om`Sg003o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^4NkokQ7^
00OokQ7^00?o0000ol4n`Oo1?/401oo1?/400ol0003oOh1oogn0O`07ogn0O`03o`000?mHYeSoF:MH
00;oF:MH00?o0000oa[U6_lJiAX02_lJiAX00ol0003o0?l0o`00000>ob_D:`03o`000?lBkA;o0000
00_o=LXe00?o0000obo@;ol_d2l00_l_d2l01Ol0003oIIYUofFJIOmUVVGo000000co/Dja00?o0000
om`Sg?oL8m`03_oL8m`3o`0000WojQGZ00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o^4NkokQ7^
00WokQ7^00?o0000ol4n`Oo1?/401_o1?/400ol0003oOh1oogn0O`06ogn0O`03o`000?mHYeSoF:MH
00?oF:MH00?o0000oa[U6_lJiAX02olJiAX00ol0003o:m@[ob_D:`0>ob_D:`03o`000?lebSGo=LXe
00_o=LXe0_l00003obo@;`04o`000?mUVVGoIIYUo`0000[o/Dja0ol0000>om`Sg0;o00000ool0o`2
o`0000OojQGZ00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o^4NkokQ7^00[okQ7^00?o0000ol4n
`Oo1?/401?o1?/400ol0003oOh1oogn0O`06ogn0O`03o`000?mHYeSoF:MH00GoF:MH00?o0000oa[U
6_lJiAX01olJiAX3o`00017o:m@[00?o0000ocG:=OlebSD03OlebSD01Ol0003o;m0_obo@;ol0003o
IIYU00Co00000onaC[45o`0000;oj1OX00?o0000om`Sg?oL8m`02_oL8m`2o`0000Ooo0?l0_l00004
onXEjP03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okQ7^onhAkP0;onhAkP03o`000?o1?/7o`Ck1
00Co`Ck100?o0000ogn0OomoP7l01OmoP7l00ol0003oF:MHoeRWF006oeRWF003o`000?lJiA[o6^DJ
00Co6^DJ0ol00002ob3O8003o`000?l[e2_o:m@[00oo:m@[0_l0000?ocG:=@04o`000?l_d2oo0000
o`0000CoW6>L0ol00008onPGj003o`000?oL8mcog2?L00Oog2?L0_l0000;oo`3o0;o00000_oZ5NX0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000onhAk_o^4Nh03?o^4Nh6o`0000OoOh1o00?o0000oeRW
F?mHYeP02?mHYeP00ol0003o6^DJoa[U6P03o`0000Ko8=lP00?o0000ob_D:ol[e2/03Ol[e2/01?l0
003o@;m0od2o@?l0000?ocG:=@03o`000?nLHicoW6>L00GoW6>L00?o0000onPGj?oX5nP02?oX5nP0
0ol0003og2?Lom`Sg005om`Sg003o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o^4Nh00ol0003oacS7olLha`04olLh
a`03o`000?moP7ooOh1o00?oOh1o00?o0000oeRWF?mHYeP02_mHYeP2o`0000[o8=lP00?o0000ob_D
:ol[e2/02ol[e2/00ol0003o@;m0od2o@002od2o@003o`000?lebSGo=LXe00_o=LXe0_l00007oiaS
W003o`000?oX5nSoj1OX00Woj1OX00?o0000om`Sg?oL8m`00_oL8m`2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00co
o0?l00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oacS7olLha`06olLha`05o`000?moP7ooOh1oogn0
Ool000003OmHYeP00ol0003o8=lPob3O800:ob3O8003o`000?l[e2_o:m@[00Wo:m@[00?o0000od2o
@?m0_d001?m0_d000ol0003o=LXeocG:=@08ocG:=@;o000000?oD:m@o`000?nLHi`01onLHi`00ol0
003oj1OXonPGj009onPGj004o`000?oL8mco0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00>oo`3o003o`000?o^4NkokQ7^
00WokQ7^00?o0000olLhaoo7><L02?o7><L00ol0003oOh1oo`00000=oeRWF003o`000?lPgb3o8=lP
00_o8=lP00?o0000ob_D:ol[e2/02?l[e2/00ol0003o@;m0od2o@006od2o@003o`000?lebSGo=LXe
00Go=LXe0_l00003oe2_D003o`000?nLHicoW6>L00KoW6>L00?o0000onPGj?oX5nP02_oX5nP00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000oo`3o?ol
0o`03ool0o`00ol0003okQ7^onhAkP07onhAkP03o`000?o7><OoacS700[oacS700?o0000oeRWF?mH
YeP03?mHYeP00ol0003o8=lPob3O800<ob3O8003o`000?l[e2_o:m@[00Ko:m@[00?o0000od2o@?m0
_d002?m0_d000ol0003o=LXeocG:=@02ocG:=@;o00001_m@[e000ol0003oW6>LoiaSW005oiaSW003
o`000?oX5nSoj1OX00[oj1OX00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^4NkokQ7^00GokQ7^
00?o0000olLhaoo7><L03?o7><L2o`0000coF:MH00?o0000ob3O8?lPgb003OlPgb000ol0003o:m@[
ob_D:`04ob_D:`03o`000?m0_d3o@;m000[o@;m000Co0000ocG:=Ol0003o00002?m@[e000ol0003o
W6>LoiaSW006oiaSW003o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00Aoo`3o0Co0000
0_o^4Nh00ol0003oacS7olLha`0=olLha`03o`000?mmPWgo000000;o00002?mHYeP00ol0003o8=lP
ob3O800?ob3O80Ko00003_m0_d000ol0003oD:m@oe2_D008oe2_D003o`000?nLHicoW6>L00KoW6>L
00?o0000onPGj?oX5nP02OoX5nP00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?ol0ocoo0?l017oo0?l00Co0000oo4>lOoa3_7ol@ka
0_l0000?olLha`03o`000?mmPWgoOH9m00?oOH9m0ol00005oeRWF0;o00004?lPgb001_l0003o6>LH
oaSW6?l0003o3O8=o`0000ko@;m000?o0000oe2_D?m@[e002Om@[e000ol0003oW6>LoiaSW005oiaS
W003o`000?oX5nSoj1OX00Woj1OX00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00ooo0?l00?o0000oo4>lOoa3_400ooa3_400ol0003o
acS7olLha`0=olLha`03o`000?mmPWgoOH9m00KoOH9m0ol000001?mHYeSo0000oc7><OlacS43o`00
00co8=lP00Go0000oaSW6?lHiaSo6>LHo`000002o`gb3@03o`000?m0_d3o@;m000_o@;m000?o0000
oe2_D?m@[e002Om@[e000ol0003oW6>LoiaSW006oiaSW003o`000?oX5nSoj1OX00Soj1OX0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03ool0o`00ol0003ol@kaoo4>l@04oo4>l@oo00003?mmPWd00ol0003o<Lhaoc7><@04oc7>
<@?o00002?lPgb000ol0003o6>LHoaSW6002oaSW6005o`000?l=lPgo3O8=o`gb3Ol000003?m0_d00
0ol0003oD:m@oe2_D009oe2_D003o`000?nLHicoW6>L00GoW6>L3?l00002ooD:m@;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000oo`3
o?ol0o`03_ol0o`00ol0003ol@kaoo4>l@05oo4>l@03o`000?o8=lSob3O800_ob3O800?o0000ogf2
OOmmPWd02_mmPWd00ol0003o<Lhaoc7><@07oc7><@;o00001OlPgb000ol0003o6>LHoaSW6003oaSW
6003o`000?l=lPgo3O8=00;o3O8=00?o0000od2o@?m0_d002Om0_d000ol0003oD:m@oe2_D00:oe2_
D003o`000?nLHicoW6>L00?oW6>L00?o0000omlPgooO8=l02OoO8=l00ol0003om@[eooD:m@02ooD:
m@;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ol@kaoo4>l@06oo4>l@03o`000?o8=lSob3O800[o
b3O800?o0000ogf2OOmmPWd02ommPWd00ol0003o<Lhaoc7><@09oc7><@?o000000?o8=lPo`000?lH
iaP01OlHiaP00ol0003o3O8=o`gb3@03o`gb3@03o`000?m0_d3o@;m000So@;m03_l00003oiaSW0;o
00002ooO8=l00ol0003om@[eooD:m@05ooD:m@03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?ol0ocoo0?l00goo0?l
00?o0000oo4>lOoa3_401Ooa3_400ol0003odbcCo`00000;olPgb003o`000?mmPWgoOH9m00[oOH9m
0_l0000>oc7><@03o`000?lHiaSo6>LH00Go6>LH00?o0000o`gb3Ol=lPd00ol=lPd00ol0003o@;m0
od2o@008od2o@003o`000?nHIiSoV6NH00_oV6NH00?o0000oiaSW?l000003OoO8=l00ol0003om@[e
ooD:m@06ooD:m@;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?oa3_7ol@ka00Kol@ka00Co
0000om</dooC;=?o00002_o8=lP00ol0003oOH9mogf2O@09ogf2O@03o`000?mFZEKo000000ko<Lha
00?o0000oaSW6?lHiaP01OlHiaP00ol0003o3O8=o`gb3@04o`gb3@03o`000?m0_d3o@;m000Ko@;m0
00?o0000oiQWV?nHIiP03OnHIiP00ol0003ogb3OomlPg`0<omlPg`03o`000?oe2_Gom@[e00Som@[e
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo0?loo`3o00;oo`3o003o`000?oa3_7ol@ka00Gol@ka00?o0000om</dooC;=<00_oC
;=<00ol0003ob3O8olPgb006olPgb003o`000?mmPWgoOH9m00SoOH9m0_l00003oeJYEP03o`000?la
cS7o<Lha00_o<Lha00?o0000oaSW6?lHiaP01OlHiaP00ol0003o3O8=o`gb3@05o`gb3@03o`000?m0
_d3o@;m000Go@;m000?o0000oiQWV?nHIiP03OnHIiP00ol0003ogb3OomlPg`0;omlPg`03o`000?oe
2_Gom@[e00Wom@[e00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?oa3_7ol@ka00Kol@ka00?o0000
om</dooC;=<00ooC;=<00ol0003ob3O8olPgb005olPgb003o`000?mmPWgoOH9m00OoOH9m00?o0000
oeJYE_mFZEH00omFZEH00ol0003o<Lhaoc7><@0:oc7><@03o`000?lHiaSo6>LH00Ko6>LH00?o0000
o`gb3Ol=lPd01_l=lPd00ol0003o@;m0od2o@004od2o@003o`000?nHIiSoV6NH00goV6NH3ol0000;
ooD:m@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008oo`3o003o`000?oa3_7ol@ka00Kol@ka00?o0000om</dooC;=<01OoC;=<00ol0
003ob3O8olPgb004olPgb003o`000?mmPWgoOH9m00GoOH9m0_l00006oeJYEP03o`000?lacS7o<Lha
00Wo<Lha0_l00008oaSW6003o`000?l=lPgo3O8=00Ko3O8=1Ol000000om0_d3o0000oiQWV00?oiQW
V003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003oo`3o003o`000?oa3_7ol@ka00Kol@ka00?o0000om</dooC;=<01_oC;=<00ol0003o
b3O8olPgb004o`0000KoOH9m00?o0000oeJYE_mFZEH01omFZEH00ol0003o<Lhaoc7><@05oc7><@?o
000000?o8MhQo`000?lHiaP01olHiaP00ol0003o3O8=o`gb3@05o`gb3@03o`000?m@[e3oD:m@00?o
D:m@0_l0000?oiQWV0;o00003OoQ7^400ol0003om@[eooD:m@08ooD:m@03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wol@ka00?o0000om</dooC;=<01ooC;=<2o`0000Co[5>/00Co0000ogf2OOmmPWgo
OH9m0_l0000:oeJYEP03o`000?lacS7o<Lha00;o<Lha0ol00005ob7N8@03o`000?lHiaSo6>LH00Go
6>LH00?o0000o`gb3Ol=lPd01?l=lPd00ol0003oD:m@oe2_D006oe2_D003o`000?nHIiSoV6NH00[o
V6NH0_l00002ol8m`P03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000ooD:mOoe2_D02?oe2_D00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo4>lOoa3_401_oa3_400ol0003odbcCom</d`08om</d`03o`00
0?n/Djco[5>/00Co[5>/00?o0000ogf2OOl000003?mFZEH00ol0003o<Lhao`000002o`0000Wo8MhQ
00?o0000oaSW6?lHiaP01?lHiaP00ol0003o3O8=o`gb3@03o`gb3@03o`000?m@[e3oD:m@00SoD:m@
1_l00004oiQWV0;o00001Oo2?L800ol0003ohAkQon4Nh@09on4Nh@03o`000?oe2_Gom@[e00Som@[e
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oa3_7ol@ka00Gol@ka00?o0000om</dooC;=<01ooC
;=<00ol0003o[5>/ojaC[006ojaC[003o`000?mFZEKoEZUF00coEZUF00?o0000ob7N8OlQgR402_lQ
gR400ol0003o6>LHoaSW6004oaSW6004o`000?l=lPgo3O8=o`gb3@;o00002om@[e000ol0003oWV6N
oiiQWP03oiiQWPCo00002?o2?L800ol0003ohAkQon4Nh@08on4Nh@03o`000?oe2_Gom@[e00Oom@[e
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo4>lOoa3_400ooa3_400ol0003odbcCom</d`07om</d`03o`000?n/
Djco[5>/00Oo[5>/00?o0000oeJYE_mFZEH03?mFZEH00ol0003o8MhQob7N8@0;ob7N8@03o`000?lH
iaSo6>LH00?o6>LH00Co0000o`gb3Ol=lPgo00003Om@[e000ol0003oWV6NoiiQWP06oiiQWP03o`00
0?o2?L;o`Sg200Oo`Sg200?o0000on4NhOoQ7^401ooQ7^400ol0003om@[eooD:m@06ooD:m@04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00;ol@ka00?o0000om</dooC;=<0
1_oC;=<00ol0003o[5>/ojaC[009ojaC[003o`000?mFZEKoEZUF00WoEZUF0_l0000>ob7N8@?o0000
0olHiaP00ol0003o3O8=o`00000=oe2_D003o`000?nNHIkoWV6N00OoWV6N00?o0000ol8m`_o2?L80
2?o2?L8:o`0000Kom@[e0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OodbcC00?o
0000ojaC[?n/Dj`02_n/Dj`00ol0003oEZUFoeJYEP06oeJYEP;o000000?oC[5>o`000?lQgR402olQ
gR42o`0000?o?L8m1Ol0000>oe2_D003o`000?nNHIkoWV6N00OoWV6N00?o0000ol8m`_o2?L802?o2
?L800ol0003oj1OXonPGj006onPGj003o`000?oe2_Gom@[e00?om@[e00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003oiaSWonLHi`03onLHi`Co00000_oC;=<00ol0003o[5>/ojaC[00;
ojaC[003o`000?mFZEKoEZUF00?oEZUF0ol00004odjaCP03o`000?lQgR7o8MhQ00Oo8MhQ0_l00008
ocg2?@03o`000?m@[e3oD:m@00goD:m@00?o0000oiiQW_nNHIh02?nNHIh00ol0003o`Sg2ol8m`P07
ol8m`P03o`000?oX5nSoj1OX00Ooj1OX0ol000000ooe2_Go0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?oW6>OoiaSW00OoiaSW0_l0000?ojaC[003o`000?mFZEKoEZUF00;o00002?m>/Dh00ol0
003o8MhQob7N8@05ob7N8@03o`000?lm`Sgo?L8m00So?L8m00?o0000oe2_D?m@[e003Om@[e000ol0
003oWV6NoiiQWP08oiiQWP03o`000?o2?L;o`Sg200Ko`Sg200?o0000onPGj?oX5nP02?oX5nP01?l0
003omPWfooH9m_l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003oiaSWonLHi`09onLH
i`03o`000?n/Djco[5>/00ko[5>/0_l0000;odjaCP03o`000?lQgR7o8MhQ00;o8MhQ0_l0000;ocg2
?@03o`000?m@[e3oD:m@00goD:m@00?o0000oiiQW_nNHIh02?nNHIh00ol0003o`Sg2ol8m`P06ol8m
`P03o`000?oX5nSoj1OX00Ooj1OX00Go0000ooH9m_of2OKomPWfo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003oiaSWonLHi`0:onLHi`03o`000?n/Djco[5>/00go[5>/0_l0000<odjaCP04o`000?lQgR7o0000
o`0000go?L8m00?o0000oe2_D?m@[e003?m@[e000ol0003oWV6NoiiQWP09oiiQWP03o`000?o2?L;o
`Sg200Ko`Sg200?o0000onPGj?oX5nP01_oX5nP00ol0003omPWfooH9mP03ooH9mP03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003oiaSWonLHi`0:onLHi`03o`000?n/Djco[5>/00co[5>/00Co0000oiIY
U_nFJIKo00003?m>/Dh00ol0003o?L8mocg2?@0>ocg2?@03o`000?m@[e3oD:m@00SoD:m@1?l0000;
oiiQWP03o`000?o2?L;o`Sg200Ko`Sg200?o0000onPGj?oX5nP01OoX5nP00ol0003omPWfooH9mP04
ooH9mP03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003oiaSWonLHi`0;onLHi`03o`000?n/Djco[5>/
00_o[5>/00?o0000oiIYU_nFJIH00_nFJIH00ol0003oC[5>odjaCP09odjaCP03o`000?lm`Sgo?L8m
00ko?L8m00Co0000oe2_D?m@[e3oD:m@1ol00003ofbCK003o`000?nNHIkoWV6N00WoWV6N00?o0000
ol8m`_o2?L801_o2?L800ol0003oj1OXonPGj004onPGj003o`000?of2OKomPWf00KomPWf00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oW6>OoiaSW00coiaSW00?o0000ojaC[?n/Dj`02_n/Dj`00ol0
003oUVVFoiIYUP03oiIYUP03o`000?m>/DkoC[5>00SoC[5>00?o0000ocg2?Olm`Sd03_lm`Sd4o`00
00_oK9=/00?o0000oiiQW_nNHIh02?nNHIh00ol0003o`Sg2ol8m`P05ol8m`P03o`000?oX5nSoj1OX
00Goj1OX00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onLHiooW
6>L03?oW6>L7o`0000Go[5>/00?o0000oiIYU_nFJIH01OnFJIH00ol0003oC[5>odjaCP07odjaCP03
o`000?lm`Sgo?L8m00ko?L8m00?o0000ofbCK?m/Tf`03Om/Tf`00ol0003oWV6NoiiQWP08oiiQWP03
o`000?o2?L;o`Sg200Co`Sg200?o0000onPGj?oX5nP01?oX5nP00ol0003omPWfooH9mP07ooH9mP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003oiaSWonLHi`0=onLHi`03o`000?o:=L[obSG:00CobSG:
1Ol00009oiIYUP03o`000?m>/DkoC[5>00KoC[5>00?o0000ocg2?Olm`Sd03_lm`Sd00ol0003oK9=/
ofbCK00=ofbCK003o`000?nNHIkoWV6N00SoWV6N00Co0000ol8m`_o2?L;o`Sg21Ol00004onPGj003
o`000?of2OKomPWf00WomPWf1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onLHi`03o`000?o:=L[obSG:00WobSG:
0_l00009oiIYUP03o`000?m>/DkoC[5>00KoC[5>00?o0000ocg2?Olm`Sd03?lm`Sd00ol0003oK9=/
ofbCK00?ofbCK0Ko00001?nNHIh4o`0000GohacS0_l000000ooX5nSo0000ooH9mP0;ooH9mP04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?ob3O;olPgboo8=lP?o00002_oW6>L00ol0003o
bSG:olXebP09olXebP03o`000?nWF:Oo000000;o00001onFJIH00ol0003oC[5>odjaCP05odjaCP03
o`000?lm`Sgo?L8m00So?L8m1Ol0000AofbCK003o`000?n^DJko[U6^00?o[U6^1?l0000;on<Lh`03
o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000oo8=l_ob3O801Oob3O82o`0000OoiaSW
00?o0000olXeb_o:=LX02_o:=LX00ol0003oYeRWojMHY`02ojMHY`?o00001OnFJIH00ol0003oC[5>
odjaCP04odjaCP04o`000?lm`Sgo?L8mocg2?@Oo00001?mLXe`00ol0003oK9=/ofbCK00>ofbCK003
o`000?n^DJko[U6^00Oo[U6^00?o0000on<LhooS7><02OoS7><00ol0003omPWfooH9mP09ooH9mP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003olPgboo8=lP08oo8=lP;o00001?oW6>L00ol0003obSG:
olXebP0;olXebP03o`000?nWF:OoYeRW00GoYeRW0ol00003oiIYUP04o`000?m>/DkoC[5>odjaCPKo
00003?mLXe`00ol0003oK9=/ofbCK00=ofbCK003o`000?n^DJko[U6^00Oo[U6^00?o0000on<LhooS
7><02_oS7><00ol0003omPWfooH9mP08ooH9mP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo8=lP?o000000?oiaSWo`000?o:=LX0
3?o:=LX00ol0003oYeRWojMHY`08ojMHY`?o000000CoUVVFo`000?l0003o00000_nPGj000ol0003o
G:=LoebSG00=oebSG003o`000?m/TfcoK9=/00coK9=/00?o0000ojiA[_n^DJh02?n^DJh00ol0003o
hacSon<Lh`0;on<Lh`03o`000?of2OKomPWf00KomPWf00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
lPgb00?o0000olXeb_o:=LX03?o:=LX00ol0003oYeRWojMHY`0;ojMHY`03o`000?nPGj3oX5nP00?o
X5nP00?o0000oebSG?mLXe`03?mLXe`00ol0003oIiQWo`00000=ofbCK003o`000?n^DJko[U6^00So
[U6^00?o0000on<LhooS7><03?oS7><3o`0000GomPWf00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?ob3O;olPgb00colPgb00?o0000olXeb_o:=LX03?o:=LX00ol0003oYeRWojMHY`0:ojMHY`03o`00
0?nPGj3oX5nP00GoX5nP00?o0000oebSG?mLXe`02_mLXe`01?l0003oIiQWofNHIomWV6L2o`0000[o
K9=/00?o0000ojiA[_n^DJh02On^DJh00ol0003ohacSon<Lh`0<on<Lh`03o`000?oh1oSon0Oh00?o
000000?omPWfo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?ob3O;olPgb00_olPgb00?o0000olXeb_o:=LX0
3?o:=LX00ol0003oYeRWojMHY`09ojMHY`03o`000?nPGj3oX5nP00KoX5nP00?o0000oebSG?mLXe`0
2OmLXe`00ol0003oIiQWofNHI`02ofNHI`03o`000?nRGJ;o000000;o00001om/Tf`00ol0003o[U6^
ojiA[P09ojiA[P03o`000?oS7>?ohacS00_ohacS00?o0000ooP7n?oh1oP01?oh1oP00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo8=l_ob3O802oob3O800ol0003obSG:olXebP0;olXebP03o`000?nW
F:OoYeRW00SoYeRW00?o0000oj1OX?nPGj001onPGj000ol0003oG:=LoebSG008oebSG003o`000?mW
V6OoIiQW00?oIiQW00?o0000oj9MX_nRGJ800_nRGJ82o`0000CoK9=/00?o0000ojiA[_n^DJh02_n^
DJh00ol0003ohacSon<Lh`0:on<Lh`03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?ob3O;olPgb00[olPgb0ol0000;olXebPKo00001?nWF:L00ol0003oX5nPoj1OX008
oj1OX003o`000?mLXecoG:=L00OoG:=L00?o0000ofNHIomWV6L00omWV6L00ol0003oXUfRoj9MXP05
oj9MXP?o000000?oK9=/o`000?n^DJh02on^DJh00ol0003ohacSon<Lh`09on<Lh`03o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;olPgb00WolPgb00?o0000onDJ
iOoU6^D01?l00006olXebP03o`000?o:=L[obSG:00CobSG:1?l0000<oj1OX003o`000?mLXecoG:=L
00GoG:=L00?o0000ofNHIomWV6L01?mWV6L00ol0003oXUfRoj9MXP08oj9MXP03o`000?n^DJko[U6^
00_o[U6^00?o0000on<LhooS7><02?oS7><00ol0003on0OhooP7n008ooP7n0Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?ob3O;olPgb00OolPgb00?o0000onDJiOoU6^D01OoU6^D3o`0000;obSG:00?o0000olXeb_o:
=LX02?o:=LX00ol0003oX5nPoj1OX00:oj1OX003o`000?mLXecoG:=L00CoG:=L00?o0000ofNHIomW
V6L01OmWV6L00ol0003oXUfRoj9MXP08oj9MXP03o`000?n^DJko[U6^00Wo[U6^1?l00008on<Lh`03
o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003olPgb
oo8=lP05oo8=lP03o`000?oU6^GoiA[U00WoiA[U0_l0000<olXebP03o`000?nPGj3oX5nP00WoX5nP
00?o0000oebSG?mLXe`00omLXe`00ol0003oIiQWofNHI`05ofNHI`03o`000?nRGJ;oXUfR00[oXUfR
00?o0000ojiA[_n^DJh01?n^DJh4o`0000Cog2?L00?o0000on<LhooS7><01?oS7><00ol0003on0Oh
ooP7n00:ooP7n003o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D02ooU
6^D00ol0003obSG:olXebP0:olXebP03o`000?nPGj3oX5nP00WoX5nP00?o0000oebSG?mLXe`00_mL
Xe`00ol0003oIiQWofNHI`06ofNHI`03o`000?nRGJ;oXUfR00[oXUfR00?o0000ojiA[_n^DJh01?l0
0009om`Sg0Ko00003?oh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo8=l_ob3O;olPgb0_l0
000=onDJi@03o`000?o:=L[obSG:00[obSG:00?o0000oj1OX?nPGj002OnPGj001Ol0003oG:=LoebS
G?mLXeco000000WoIiQW00?o0000oj9MX_nRGJ802onRGJ82o`0000gog2?L00?o0000ooD:mOoe2_D0
0_oe2_D00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgbo`00
0002ooT6n@;o00002ooU6^D00ol0003obSG:olXebP0;olXebP03o`000?nPGj3oX5nP00WoX5nP00?o
0000oebSG?l000002OmWV6L00ol0003oXUfRoj9MXP0<oj9MXP03o`000?oL8mcog2?L00cog2?L00?o
0000ooD:mOoe2_D00ooe2_D00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on@KiooT6n@03ooT6n@;o00002_oU6^D00ol0003obSG:olXebP0:olXebP03o`000?nPGj3o
X5nP00SoX5nP1Ol00008ofNHI`03o`000?nRGJ;oXUfR00coXUfR00?o0000om`Sg?oL8m`02ooL8m`0
0ol0003om@[eooD:m@05ooD:m@03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooi1_T2o`0000SoiA[U00?o0000olXeb_o:=LX02_o:=LX00ol0003oX5nPoj1OX007oj1O
X003o`000?nSG:?oXebS00?oXebS0ol00005ofNHI`03o`000?nRGJ;oXUfR00_oXUfR00?o0000om`S
g?oL8m`03?oL8m`00ol0003om@[eooD:m@06ooD:m@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000Won@Ki00?o0000onDJiOoU6^D01OoU6^D2o`0000co
bSG:00?o0000oj1OX?nPGj001OnPGj000ol0003oXebSoj=LX`07oj=LX`?o000000?oIiQWo`000?nR
GJ803OnRGJ800ol0003og2?Lom`Sg00<om`Sg003o`000?oe2_Gom@[e00Kom@[e00?o0000ooP7n?oh
1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?oi1_Won@Ki00Oon@Ki
0_l00004onDJi@03o`000?o/4ncok1?/00;o00002_o:=LX00ol0003oX5nPoj1OX003oj1OX0;o0000
3OnSG:<2o`0000goXUfR0ol0000=om`Sg003o`000?oe2_Gom@[e00Oom@[e00?o0000ooP7n?oh1oP0
1Ooh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00Son@Ki0_l0
00000ooU6^Go0000on`Ck004on`Ck003o`000?o:=L[obSG:00OobSG:00Co0000oj1OX?nPGj3oX5nP
0_l00002oldbc@03o`000?nSG:?oXebS00coXebS3Ol00003om/Tf`03o`000?oL8mcog2?L00[og2?L
00?o0000ooD:mOoe2_D02?oe2_D01?l0003on0OhooP7n?oh1oP4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003on@Ki
ooT6n@09ooT6n@03o`000?o/4ncok1?/00Gok1?/0_l00008olXebP03o`000?nPGj3o000000GocC;=
00?o0000oj=LXonSG:<02onSG:<00ol0003o/Djaok5>/@09ok5>/@03o`000?oK9=_ofbCK00;ofbCK
0_l00009om`Sg003o`000?oe2_Gom@[e00[om@[e0ol00004ood2o@03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?oi1_Won@Ki00Son@Ki00?o0000on`Ck?o/4n`01oo/4n`4o`0000?obSG:0ol0
0007oldbc@03o`000?nSG:?oXebS00[oXebS00?o0000ok5>/OnaC[402OnaC[400ol0003ofbCKom/T
f`04om/Tf`;o00001ooL8m`00ol0003om@[eooD:m@0:ooD:m@03o`000?om0_goo@;m00Goo@;m00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on`Ck?o/4n`02?o/4n`0
1?l0003ojaC[on/Djoo[5>/3o`0000;oh1oP00?o0000oldbcOo=</d01_o=</d00ol0003oXebSoj=L
X`08oj=LX`03o`000?naC[7o/Dja00[o/Dja00?o0000om/TfooK9=/01_oK9=/00ol0003og2?Lom`S
g004om`Sg003o`000?oe2_Gom@[e00Wom@[e00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ok1?/on`Ck008on`Ck003o`000?o[5>_o
jaC[00CojaC[00Go0000on0Oh?oP7n3oh1oPo`000008oldbc@03o`000?nSG:?oXebS00OoXebS00?o
0000ok5>/OnaC[402_naC[400ol0003ofbCKom/Tf`07om/Tf`;o00001?oL8m`00ol0003om@[eooD:
m@08ooD:m@03o`000?om0_goo@;m00Woo@;m00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T00ooi1_T0
0ol0003ok1?/on`Ck008on`Ck003o`000?o[5>_ojaC[00CojaC[00?o0000on0Oh?oP7n000_oP7n00
0ol0003ocC;=oldbc@07oldbc@03o`000?nSG:?oXebS00KoXebS00?o0000ok5>/OnaC[402_naC[40
0ol0003ofbCKom/Tf`09om/Tf`05o`000?oL8mcog2?Lom`Sg?l000002Ooe2_D00ol0003oo@;mood2
o@0;ood2o@03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ok1?/00?o0000on/Djoo[5>/01?o[5>/00ol0003oh1oPon0Oh003
on0Oh003o`000?o=</gocC;=00OocC;=00?o0000oj=LXonSG:<01OnSG:<00ol0003o/Djaok5>/@0:
ok5>/@03o`000?oK9=_ofbCK00WofbCK1?l00009ooD:m@03o`000?om0_goo@;m00goo@;m0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?oi1_Won@Ki
ooT6nOl000002_o/4n`00ol0003ojaC[on/Dj`05on/Dj`03o`000?oP7n3oh1oP00?oh1oP00?o0000
oldbcOo=</d02?o=</d00ol0003oXebSoj=LX`04oj=LX`03o`000?naC[7o/Dja00Wo/Dja00?o0000
om/TfooK9=/02?oK9=/2o`0000?omPWf00?o0000ooD:mOoe2_D01_oe2_D00ol0003oo@;mood2o@0>
ood2o@03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003ok1?/on`Ck006on`Ck003o`000?o[5>_ojaC[
00GojaC[00?o0000on0Oh?oP7n001?oP7n000ol0003ocC;=oldbc@09oldbc@03o`000?nSG:?oXebS
00;oXebS00?o0000ok5>/OnaC[402_naC[400ol0003ofbCKom/Tf`06om/Tf`;o00001_of2OH8o`00
017oo@;m00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?o/4ncok1?/00Gok1?/00?o0000on/Djoo[
5>/01Oo[5>/00ol0003oh1oPon0Oh005on0Oh003o`000?o=</gocC;=00WocC;=00Go0000oj=LXonS
G:?oXebSo`00000<ok5>/@03o`000?oK9=_ofbCK00CofbCK0_l00008ooH9mP03o`000?om0_goo@;m
00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on`Ck?o/
4n`00oo/4n`00ol0003ojaC[on/Dj`06on/Dj`03o`000?oP7n3oh1oP00Goh1oP00?o0000oldbcOo=
</d02_o=</d00ol0003oXebSo`000004o`0000Wo/Dja00?o0000om/TfooK9=/00_oK9=/2o`0000[o
mPWf00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0<ood2o@;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on@KiooT6n@07ooT6n@03o`00
0?o/4ncok1?/00;ok1?/00?o0000on/Djoo[5>/01_o[5>/00ol0003oh1oPon0Oh007on0Oh0;o0000
2oo=</d00ol0003oi1_Ton@Ki003on@Ki0Oo00000_naC[400ol0003ofbCKom/Tf`02o`0000_omPWf
00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T02Ooi
1_T01Ol0003ok1?/on`Ck?o/4nco000000SojaC[00?o0000on0Oh?oP7n001ooP7n000ol0003ol0o`
o`000002o`0000SocC;=00?o0000on@Ki?oT6n@02_oT6n@5o`0000gomPWf00?o0000ood2oOom0_d0
2?om0_d00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<ooT6n@03o`000?o/4nco000000WojaC[00?o
0000on0Oh?oP7n001_oP7n000ol0003ol0o`oo0?l003oo0?l0?o00001?o=</d00ol0003oi1_Ton@K
i00=on@Ki003o`000?of2OKomPWf00gomPWf00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2
o@06ood2o@03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on@Ki00?o0000on/Djoo[5>/01oo[5>/00ol0003oh1oPon0Oh007
on0Oh003o`000?o`3o3ol0o`00Kol0o`0ol000000oo=</go0000on@Ki00>on@Ki003o`000?of2OKo
mPWf00comPWf00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@05ood2o@03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooT6
n@03o`000?o[5>_ojaC[00;ojaC[1_l00008on0Oh003o`000?o`3o3ol0o`00[ol0o`00?o0000on@K
i?oT6n@03ooT6n@00ol0003omPWfooH9mP0:ooH9mP;o00003Oom0_d00ol0003oo@;mood2o@03ood2
o@03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooT6n@Go00001_of2OH00ol0003oh1oPon0Oh005on0Oh003o`000?o`3o3ol0o`00[o
l0o`00?o0000on@Ki?oT6n@03ooT6n@00ol0003omPWfooH9mP07ooH9mP?o000000?ooP7no`000?om
0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooT6n@03o`000?of2OKomPWf00WomPWf00?o0000on0Oh?oP
7n000ooP7n000ol0003ol0o`oo0?l00;oo0?l003o`000?oT6nCoi1_T00ooi1_T00?o0000ooH9m_of
2OH01Oof2OH2o`0000GooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on@Kio`000?l00000
3Oof2OH00ol0003oh1oPon0Oh002on0Oh003o`000?o`3o3ol0o`00_ol0o`5?l00004ooH9mP;o0000
2?on0Oh00ol0003oo@;mood2o@0;ood2o@;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooH9mP04o`000?oP7n3oh1oPo`0000kol0o`
00?o0000ooP7n?oh1oP04?oh1oP00ol0003omPWfo`000002o`0000[ooP7n00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_of2OH00ol0003oh1oPo`00000>oo0?l003o`00
0?oh1oSon0Oh017on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@08ood2o@03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003omPWfooH9mP0=ooH9mP03o`000?o`3o3ol0o`00Wol0o`1Ol0
000BooP7n0;o00003oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003omPWfooH9mP0<ooH9mP03o`000?o`3o3ol0o`00;ol0o`1ol00004ood2o@03o`000?oh1oSo
n0Oh00oon0Oh00?o0000ood2oOl000004?on0Oh00ol0003oo@;mood2o@03ood2o@;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?of2OKomPWf00comPWf1?l0000<ood2o@03o`000?oh1oSon0Oh00con0Oh0_l00003ood2
o@03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d00_om0_d00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?oh1oSon0Oh00_o
n0Oh00?o0000ood2oOom0_d01?om0_d00ol0003ooP7nooh1oP0=ooh1oP04o`000?om0_goo@;mo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00koo@;m00?o0000ooP7n?oh
1oP02Ooh1oP2o`0000Ooo@;m00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?oh1oSon0Oh00Kon0Oh0_l0000:ood2o@03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oh1oP00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooh1oP2o`0000koo@;m00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooP7n?l000004Oom0_d00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02_l00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`07o`00o`;oool00ol0
0?l2oooo00Go003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Go003o0_ooo`05o`00o`03oooo0?l00?oo
003o00;o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o
00?o003o0_ooo`05o`00o`;oool00ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`003Ol00?l2oooo00?o
003o0_ooo`06o`00o`;oool00ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l3oooo00?o003o0_ooo`05o`00o`?oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02ol00?l3oooo00Co003o0oooo`03o`00o`?oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0008o`00o`Goool01Ol00?l2oooo0003o`00oooo
o`3oool000?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool02_l00?l2oooo00Oo003o00?oool0o`00ool00?l02?l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`0;o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool03?l00?l2oooo00Ko003o00?oool0o`00ool00?l01ol00?l2oooo00Ko
003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1_l00?l2oooo01So003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o0_ooo`06o`00o`;oool0
2Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_oo
o`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`02o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`07o`00o`;oool02?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool00ol00?l2oooo00?o003o0_ooo`0:o`00o`;oool01ol00?l2oooo00;o003o0_ooo`05
o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
023o003o1?ooo`0=o`00o`?oool01Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(370) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.993 .007 .993 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.994 .006 .994 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.994 .006 .994 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.993 .007 .993 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.972 .028 .972 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.992 .008 .992 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.973 .027 .973 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.965 .035 .965 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.948 .052 .948 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.987 .013 .987 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.941 .059 .941 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.993 .007 .993 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.878 .122 .878 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.893 .107 .893 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.805 .195 .805 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.925 .075 .925 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.986 .014 .986 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.989 .011 .989 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.97 .03 .97 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.645 .355 .645 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.935 .065 .935 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.84 .16 .84 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.833 .167 .833 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.87 .13 .87 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.921 .079 .921 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.951 .049 .951 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.811 .189 .811 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.91 .09 .91 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.716 .284 .716 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.944 .056 .944 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.908 .092 .908 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.848 .152 .848 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.904 .096 .904 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.72 .28 .72 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.934 .066 .934 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.834 .166 .834 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.995 .005 .995 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.95 .05 .95 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.755 .245 .755 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.412 .588 .412 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.491 .509 .491 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.977 .023 .977 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.978 .022 .978 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.902 .098 .902 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.993 .007 .993 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.787 .213 .787 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.795 .205 .795 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.48 .52 .48 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.475 .525 .475 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.346 .654 .346 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.764 .236 .764 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.797 .203 .797 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.994 .006 .994 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.772 .228 .772 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.681 .319 .681 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.963 .037 .963 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.551 .449 .551 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.927 .073 .927 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.871 .129 .871 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.481 .519 .481 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.371 .629 .371 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.677 .323 .677 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.105 .895 .105 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.123 .877 .123 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.235 .765 .235 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.513 .487 .513 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.504 .496 .504 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.923 .077 .923 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.186 .814 .186 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.202 .798 .202 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.799 .201 .799 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.964 .036 .964 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.992 .008 .992 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.287 .713 .287 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.351 .649 .351 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.672 .328 .672 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.992 .008 .992 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.739 .261 .739 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.354 .646 .354 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.604 .396 .604 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.098 .902 .098 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.516 .484 .516 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.319 .681 .319 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.968 .032 .968 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.078 .922 .078 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.067 .933 .067 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.884 .116 .884 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.04 .96 .04 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.018 .982 .018 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.638 .362 .638 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.924 .076 .924 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.228 .772 .228 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.046 .954 .046 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.491 .509 .491 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.103 .897 .103 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.2 .8 .2 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.943 .057 .943 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.01 .99 .01 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.128 .872 .128 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.139 .861 .139 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.812 .188 .812 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.245 .755 .245 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.315 .685 .315 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.032 .968 .032 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.047 .953 .047 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.1 .9 .1 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.019 .981 .019 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.376 .624 .376 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.651 .349 .651 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.992 .008 .992 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.814 .186 .814 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.178 .822 .178 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.196 .804 .196 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.422 .578 .422 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.97 .03 .97 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.1 .9 .1 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.167 .833 .167 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.652 .348 .652 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.06 .94 .06 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.993 .007 .993 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.039 .961 .039 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.898 .102 .898 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.97 .03 .97 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.644 .356 .644 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.706 .294 .706 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.095 .905 .095 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.911 .089 .911 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.319 .681 .319 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.48 .52 .48 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.073 .927 .073 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.253 .747 .253 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.433 .567 .433 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.992 .008 .992 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.992 .008 .992 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.945 .055 .945 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.147 .853 .147 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.138 .862 .138 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.028 .972 .028 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.866 .134 .866 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.214 .786 .214 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.964 .036 .964 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.194 .806 .194 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.199 .801 .199 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.211 .789 .211 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.691 .309 .691 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.772 .228 .772 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.631 .369 .631 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.021 .979 .021 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.197 .803 .197 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.33 .67 .33 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.608 .392 .608 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.866 .134 .866 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.993 .007 .993 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.957 .043 .957 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.214 .786 .214 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.411 .589 .411 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.189 .811 .189 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.856 .144 .856 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.771 .229 .771 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.992 .008 .992 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.624 .376 .624 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.892 .108 .892 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.962 .038 .962 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.16 .84 .16 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.282 .718 .282 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.949 .051 .949 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.173 .827 .173 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.703 .297 .703 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.554 .446 .554 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.531 .469 .531 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.386 .614 .386 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.913 .087 .913 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.879 .121 .879 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.889 .111 .889 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.915 .085 .915 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.437 .563 .437 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.97 .03 .97 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.834 .166 .834 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.392 .608 .392 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.442 .558 .442 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.993 .007 .993 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.703 .297 .703 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.576 .424 .576 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.992 .008 .992 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.966 .034 .966 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.867 .133 .867 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.962 .038 .962 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.451 .549 .451 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.94 .06 .94 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.816 .184 .816 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.745 .255 .745 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.993 .007 .993 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.718 .282 .718 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.603 .397 .603 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.993 .007 .993 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.765 .235 .765 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.988 .012 .988 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.994 .006 .994 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.61 .39 .61 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.99 .01 .99 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.681 .319 .681 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.991 .009 .991 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.81 .19 .81 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.899 .101 .899 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.835 .165 .835 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.918 .082 .918 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.938 .062 .938 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.839 .161 .839 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.699 .301 .699 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.825 .175 .825 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.9 .1 .9 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.939 .061 .939 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.919 .081 .919 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.93 .07 .93 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.988 .012 .988 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.855 .145 .855 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.964 .036 .964 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.991 .009 .991 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.972 .028 .972 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.953 .047 .953 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.865 .135 .865 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.965 .035 .965 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.939 .061 .939 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.926 .074 .926 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.954 .046 .954 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.992 .008 .992 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.991 .009 .991 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.992 .008 .992 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.991 .009 .991 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.992 .008 .992 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oom
0_d01?l0003om0_doo@;m?l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?om
0_goo@;m00goo@;m00?o0000oo@;m?od2o@00_od2o@00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00?om0_d00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m
00[oo@;m00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003om0_doo@;m006oo@;m003
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Ooo@;m
00?o0000oo@;m?od2o@02?od2o@00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com0_d00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooL8m`03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ol@kaoo4>l@05oo4>l@03o`000?od
2oCom0_d00_om0_d0ol00003oo8=lP03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooL8moog2?L00oog2?L00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003ol@kaoo4>l@06
oo4>l@03o`000?od2oCom0_d00[om0_d00?o0000oo8=l_ob3O801?ob3O800ol0003oo@;mood2o@0:
ood2o@04o`000?o`3o3ol0o`oo0?l0;o00002_om0_d2o`000003oo0?l?l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003om`SgooL8m`05ooL8m`03o`000?om0_go
o@;m00Woo@;m00?o0000ooP7n?l000002oon0Oh00ol0003ol@kaoo4>l@06oo4>l@03o`000?od2oCo
m0_d00Wom0_d00?o0000oo8=l_ob3O801_ob3O800ol0003oo@;mood2o@08ood2o@03o`000?o`3o3o
l0o`00Col0o`0_l00005ood2o@?o00001?o`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooL8m`03o`000?om0_goo@;m00Ooo@;m0_l00003ooP7
n003o`000?on0OkooP7n00OooP7n00?o0000oo4>lOoa3_401ooa3_400ol0003om0_doo@;m009oo@;
m003o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d01Oom0_d2o`0000Wol0o`0_l000000oom
0_go0000o`000007oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooL8moog
2?L02?og2?L00ol0003oo@;mood2o@06ood2o@03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on
0Oh01oon0Oh00ol0003ol@kaoo4>l@08oo4>l@03o`000?od2oCom0_d00Oom0_d00?o0000oo8=l_ob
3O802Oob3O800ol0003oo@;mood2o@03ood2o@03o`000?o`3o3ol0o`00_ol0o`00?o0000oo0?l?o`
3o001oo`3o000ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfo`000005ood2o@;o00002oog2?L2o`0000Koo@;m
00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?oa3_7ol@ka00Sol@ka
00?o0000oo@;m?od2o@01_od2o@00ol0003olPgboo8=lP0;oo8=lP05o`000?om0_goo@;mood2oOl0
00003_o`3o000ol0003ol0o`oo0?l008oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?of2OKomPWfooH9m_l0
00000oom0_d00ol0003om`SgooL8m`0:ooL8m`04o`000?o/4ncok1?/o`0000?oo@;m0_l00008ooP7
n003o`000?on0OkooP7n00KooP7n00?o0000oo4>lOoa3_402Ooa3_400ol0003om0_doo@;m005oo@;
m003o`000?ob3O;olPgb00colPgb00?o0000ood2oOl000003oo`3o000ol0003ol0o`oo0?l008oo0?
l003o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9mP03ooH9mP03o`000?om0_go000000_o
m`Sg0_l00004on`Ck003o`000?om0_go000000_on0Oh00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l@kaoo4>l@09oo4>l@03o`000?od2oCom0_d00Com0_d00?o0000oo8=l_ob3O803_ob3O800ol0003o
l0o`oo0?l00>oo0?l003o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooH9m_of2OH0
1?of2OH00ol0003om`SgooL8m`09ooL8m`03o`000?o/4ncok1?/00Gok1?/00?o0000ooP7n?oh1oP0
2_oh1oP00ol0003ooP7nooh1oP05ooh1oP03o`000?oa3_7ol@ka00[ol@ka00?o0000oo@;m?od2o@0
0ood2o@00ol0003olPgboo8=lP0>oo8=lP03o`000?o`3o3ol0o`00gol0o`00?o0000oo0?l?o`3o00
2_o`3o000ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9
mP05ooH9mP03o`000?og2?Oom`Sg00Oom`Sg0_l00008on`Ck003o`000?oh1oSon0Oh00_on0Oh00?o
0000ooh1o_on0Oh01?on0Oh00ol0003ol@kaoo4>l@0:oo4>l@04o`000?od2oCom0_doo@;m0?o0000
3oob3O800ol0003ol0o`oo0?l00>oo0?l003o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000ooL8moog2?L01?og2?L2o`0000_ok1?/1?l0
0009ooP7n003o`000?on0OkooP7n00?ooP7n00?o0000oo4>lOoa3_402ooa3_401?l0003om0_do`00
0?l00003om/Tf`;o00003?ob3O82o`00013ol0o`00?o0000oo0?l?o`3o002oo`3o000ol0003oo@;m
ood2o@0=ood2o@04o`000?om0_goo@;mood2o@?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003omPWf
ooH9mP07ooH9mP03o`000?og2?Oom`Sg00?om`Sg00?o0000on`Ck?o/4n`02oo/4n`01?l0003od2o@
om0_d?o@;m05o`0000Gon0Oh00?o0000ooh1o_on0Oh00_on0Oh00ol0003ol@kaoo4>l@0<oo4>l@03
o`000?oK9=_ofbCK00GofbCK0_l00008oo8=lP;o00000_oE:]D00ol0003ol0o`oo0?l00=oo0?l003
o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@05ood2o@?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003omPWfooH9mP09ooH9mP03o`000?og2?Oom`Sg00;o0000
3Oo/4n`00ol0003od2o@om0_d007om0_d0Ko00000_on0Oh4o`0000gol@ka00?o0000om/TfooK9=/0
1ooK9=/2o`0000GolPgb00?o0000omDZeOoE:]D00ooE:]D00ol0003ol0o`oo0?l00<oo0?l003o`00
0?o`3o3ol0o`00col0o`00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@09ood2o@03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?of2OKomPWf00WomPWf00?o
0000ooL8mol000003oo/4n`00ol0003od2o@om0_d00<om0_d0?o00001?oY5^T3o`0000Wol@ka00?o
0000om/TfooK9=/02_oK9=/2o`000003oo8=l_l0003o000000OoeB[E00?o0000oo0?l?o`3o002oo`
3o000ol0003ol0o`oo0?l00<oo0?l003o`000?om0_goo@;m00Koo@;m1?l0000<ood2o@03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000
on`Ck?o/4n`03_o/4n`00ol0003od2o@om0_d00=om0_d003o`000?oY5^WojAKY00KojAKY0ol00005
oo4>l@03o`000?oK9=_ofbCK00gofbCK00?o0000omDZeOoE:]D02?oE:]D00ol0003ol0o`oo0?l009
oo0?l003o`000?o`3o3ol0o`00gol0o`00Co0000ood2oOom0_goo@;m1Ol00003oo<<l`03o`000?om
0_goo@;m00_oo@;m00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooH9m_of2OH02oof2OH2o`0000ook1?/00?o0000om0_d?o@;m003Oo@;m000ol0003ojAKYonTFj@0:
onTFj@?o000000?ol@kao`000?oK9=/03ooK9=/00ol0003oeB[EomDZe@09omDZe@03o`000?o`3o3o
l0o`00Sol0o`00?o0000oo0?l?o`3o003_o`3o03o`0000Sol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?of2OKomPWf00SomPWf0ol000000ooN
8Mko0000on`Ck00>on`Ck003o`000?o@;m3od2o@00god2o@00?o0000onTFjOoY5^T03OoY5^T00ol0
003ofbCKom/Tf`0?om/Tf`03o`000?oE:]GoeB[E00[oeB[E2ol0000;oo0?l0Go00003?oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003ol`cco`000?on0Oko0000
00SomPWf0ol00005omhQgP03o`000?o/4ncok1?/00cok1?/00?o0000om0_d?o@;m003Oo@;m000ol0
003ojAKYonTFj@0=onTFj@;o00004?oK9=/00ol0003oeB[EomDZe@0:omDZe@03o`000?o@;m3od2o@
00Ood2o@00?o0000oo0?l?o`3o000_o`3o07o`0000CoeRWF00?o0000oo<<looc3?<02_oc3?<00ol0
003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003ol`ccoo<<looc3?<2o`00
00GomPWf0ol00009omhQgP;o00002oo/4n`00ol0003od2o@om0_d00=om0_d003o`000?oY5^WojAKY
00gojAKY00Co0000olDjaOo5>/Go00003ooK9=/00ol0003oeB[EomDZe@09omDZe@03o`000?o@;m3o
d2o@00Wod2o@1?l0000;omHYeP03o`000?oc3??ol`cc00[ol`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo<<looc3?<01?oc3?<00ol0003omPWfo`000002o`00
00cogR7N00Co0000oke2_Ol0003o00002Oo/4n`00ol0003od2o@om0_d00=om0_d003o`000?oY5^Wo
jAKY00gojAKY00Go0000olDjaOo5>/GoaC[5o`00000=om/Tf`03o`000?oE:]GoeB[E00[oeB[E00?o
0000om0_d?o@;m002Oo@;m000ol0003oeRWFomHYeP0<omHYeP03o`000?oc3??ol`cc00[ol`cc00?o
0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo<<looc3?<01_oc3?<0
0ol0003ogR7NomhQgP0<omhQgP03o`000?nm@[go_D:m00;o_D:m0_l00007on`Ck003o`000?o@;m3o
d2o@00cod2o@00?o0000onTFjOoY5^T03OoY5^T00ol0003oaC[5olDja@03olDja@03o`000?oK9=_o
fbCK00[ofbCK00?o0000omDZeOoE:]D02_oE:]D00ol0003od2o@om0_d009om0_d003o`000?oF:MKo
eRWF00coeRWF00?o0000oo<<looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003ol`ccoo<<l`06oo<<l`03o`000?oN8MkogR7N00_ogR7N00?o0000oke2
_Onm@[d01Onm@[d00ol0003ok1?/on`Ck003on`Ck003o`000?o@;m3od2o@00god2o@00?o0000onTF
jOoY5^T03OoY5^T00ol0003oaC[5olDja@04olDja@03o`000?oK9=_ofbCK00WofbCK00?o0000omDZ
eOoE:]D02OoE:]D00ol0003od2o@om0_d00:om0_d003o`000?oF:MKoeRWF00coeRWF00?o0000oo<<
looc3?<02ooc3?<00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l`ccoo<<l`07oo<<l`03o`000?oN8MkogR7N00_ogR7N00?o0000oke2_Onm@[d01_nm@[d2o`0000?o
k1?/00?o0000om0_d?o@;m003Oo@;m000ol0003ojAKYonTFj@0<onTFj@03o`000?o5>/GoaC[500Ko
aC[500?o0000om/TfooK9=/02?oK9=/00ol0003oeB[EomDZe@09omDZe@03o`000?o@;m3od2o@00[o
d2o@00?o0000omHYe_oF:MH03?oF:MH00ol0003ol`ccoo<<l`0;oo<<l`03o`000?om0_goo@;m00[o
o@;m00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo<<looc3?<02?oc3?<00ol0003ogR7NomhQgP0:omhQgP03o`00
0?nm@[go_D:m00Wo_D:m0_l000000oo/4nco0000om0_d00<om0_d0?o00003_oY5^T00ol0003oaC[5
olDja@07olDja@03o`000?oK9=_ofbCK00OofbCK00?o0000omDZeOoE:]D02OoE:]D00ol0003od2o@
om0_d00;om0_d003o`000?oF:MKoeRWF00coeRWF00?o0000oo<<looc3?<02_oc3?<00ol0003oo@;m
ood2o@08ood2o@?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo<<looc3?<02_oc3?<00ol0003ogR7NomhQ
gP09omhQgP03o`000?nm@[go_D:m00_o_D:m00?o0000om0_d?o@;m002_o@;m02o`0000?oYUVV00?o
0000onTFjOoY5^T02_oY5^T00ol0003oaC[5olDja@09olDja@03o`000?oK9=_ofbCK00KofbCK00?o
0000omDZeOoE:]D02?oE:]D00ol0003od2o@om0_d00<om0_d003o`000?oF:MKoeRWF00coeRWF00?o
0000oo<<looc3?<02_oc3?<00ol0003oo@;mood2o@04ood2o@Co00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000omhQg_oN8Mh02?oN8Mh0
0ol0003o_D:moke2_@0<oke2_@03o`000?o@;m3od2o@00Sod2o@0_l00006ojIIYP;o00002_oY5^T0
0ol0003oaC[5olDja@0:olDja@03o`000?oK9=_ofbCK00GofbCK00?o0000omDZeOoE:]D02?oE:]D0
0ol0003od2o@om0_d00<om0_d003o`000?oF:MKoeRWF00coeRWF00?o0000oo<<looc3?<02ooc3?<0
0ol0003oo@;mo`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo<<l`03o`000?oN8MkogR7N00OogR7N00?o0000oke2_Onm@[d03_nm@[d00ol0003od2o@om0_d004
om0_d0?o00002_nVFJH00ol0003ojAKYonTFj@07onTFj@03o`000?o5>/GoaC[500_oaC[500?o0000
om/TfooK9=/00ooK9=/00ol0003oeB[EomDZe@09omDZe@03o`000?o@;m3od2o@00cod2o@00?o0000
omHYe_oF:MH03?oF:MH00ol0003ol`ccoo<<l`0;oo<<l`;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003ol`ccoo<<l`0<oo<<l`03o`000?oN8MkogR7N00OogR7N00?o0000oke2_Onm@[d03onm@[d01?l0
003od2o@om0_d?o@;m02o`0000koYUVV0_l00006onTFj@03o`000?o5>/GoaC[500goaC[500?o0000
om/TfooK9=/00_oK9=/00ol0003oeB[EomDZe@08omDZe@03o`000?o@;m3od2o@00cod2o@0ol0000=
omHYeP03o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00ool`cc00?o0000omhQg_oN8Mh01_oN8Mh00ol0003o_D:moke2_@0@oke2_@Co00004_nVFJH00ol0
003ojAKYonTFj@03onTFj@03o`000?o5>/GoaC[500koaC[500Go0000om/TfooK9=_ofbCKo`000005
omDZe@Oo00003?o@;m001Ol0003o[U6^ojiA[_n^DJko000000coeRWF00?o0000oo<<looc3?<02?oc
3?<3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000ool`cc00?o0000omhQg_oN8Mh01_oN8Mh00ol0003o_D:moke2_@0=
oke2_@?o000000CoQ7^4o`000?l0003o00004onVFJH2o`0000;ojAKY00?o0000olDjaOo5>/D04?o5
>/D00ol0003ofbCKo`000006o`0000Oo/dbc00?o0000om0_d?o@;m002?o@;m000ol0003o[U6^ojiA
[P03ojiA[P;o00002?oF:MH3o`0000Kol`cc1?l00002oo0?l003o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003on0Oho`000?oI9]T3o`0000gol`cc00?o0000omhQg_oN8Mh01?oN8Mh00ol0003o_D:moke2
_@0;oke2_@?o00000on4Nh@01Ol0003oOH9mo`000?m@[e3o000001CoYUVV00?o0000onTFjOl00000
4oo5>/D00ol0003o/dbcok=</`0=ok=</`03o`000?o@;m3od2o@00God2o@0_l00008ojiA[P03o`00
0?oF:MKoeRWF00Go00000ooC;=<00ol0003ol`ccoo<<l`03o`0000Ool0o`00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oh1oSon0Oho`0000CofBKI0ol0000:oo<<l`03o`000?oN8MkogR7N00?ogR7N
00?o0000oke2_Onm@[d02Onm@[d3o`0000GoQ7^400Co0000ogf2OOmmPWgo00000_m@[e000ol0003o
YUVVojIIYP0BojIIYP03o`000?o5>/GoaC[501;oaC[500?o0000ok=</oncC;<03_ncC;<00ol0003o
d2o@om0_d003om0_d003o`000?n^DJko[U6^00Wo[U6^0_l00009om</d`;o00002_o`3o000ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooP7n?oh1oSon0Oho`000007omTVf@;o00001ooc3?<5o`0000;o
gR7N00?o0000oke2_Onm@[d01_nm@[d3o`0000SoQ7^400Co0000ogf2OOmmPWgo00000om@[e000ol0
003oYUVVojIIYP0AojIIYP03o`000?o5>/GoaC[5017oaC[500?o0000ok=</oncC;<04?ncC;<01Ol0
003od2o@om0_d?o@;m3o000000co[U6^00?o0000om</dooC;=<02?oC;=<00ol0003ol0o`oo0?l00:
oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Con0Oh00?o0000omTVfOoI9]T01ooI9]T3o`00
0004oo<<lol0003o0000o`0000GoaC[50_l00006oke2_@?o00002_n4Nh@01Ol0003oOH9mogf2OOmm
PWgo000000CoD:m@00?o0000ojIIY_nVFJH04?nVFJH00ol0003oaC[5olDja@0AolDja@03o`000?nc
C;?o/dbc017o/dbc00?o0000om0_d?l000003On^DJh00ol0003odbcCom</d`08om</d`03o`000?o`
3o3ol0o`00[ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Con0Oh00?o0000
omTVfOoI9]T02_oI9]T00ol0003oaC[5olDja@08olDja@03o`000?nm@[go_D:m00?o00003On4Nh@0
1Ol0003oOH9mogf2OOmmPWgo000000GoD:m@00?o0000ojIIY_nVFJH03onVFJH00ol0003oaC[5olDj
a@0AolDja@03o`000?ncC;?o/dbc01;o/dbc00?o0000ojiA[_n^DJh03?n^DJh00ol0003odbcCom</
d`08om</d`03o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooP7n?oh1oP01Ooh1oP0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o5>/GoaC[500WoaC[50_l0000?ohAkQ003o`000?mmPWgo
OH9m00;oOH9m00?o0000oe2_D?m@[e001?m@[e000ol0003oYUVVojIIYP0=ojIIYP?o00004Oo5>/D0
0ol0003o/dbcok=</`0Cok=</`03o`000?n^DJko[U6^00_o[U6^00?o0000om</dooC;=<02OoC;=<0
0ol0003ol0o`oo0?l00;oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ooh1oP;o00002?oh1oP0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o5>/GoaC[500WoaC[500?o0000ohAkQ?n4Nh@03On4Nh@0
0ol0003oOH9mogf2O@03ogf2O@03o`000?m@[e3oD:m@00GoD:m@00?o0000ojIIY_nVFJH02_nVFJH2
o`0000?oNXEj00?o0000olDjaOo5>/D03_o5>/D00ol0003o/dbcok=</`0Cok=</`03o`000?n^DJko
[U6^00_o[U6^00?o0000om</dooC;=<02OoC;=<00ol0003ol0o`oo0?l00;oo0?l003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000GooP7n00?o0000ooP7n?oh1oP01ooh1oP2o`0000_ofBKI00?o0000olDj
aOo5>/D02oo5>/D00ol0003oQ7^4ohAkQ00<ohAkQ003o`000?mmPWgoOH9m00?oOH9m00?o0000oe2_
D?m@[e001_m@[e000ol0003oYUVVojIIYP07ojIIYP;o00001_mjQGX2o`0000koaC[500?o0000ok=<
/oncC;<04oncC;<00ol0003o[U6^ojiA[P0;ojiA[P03o`000?oC;=?odbcC00WodbcC00?o0000oo0?
l?o`3o003?o`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ooh1o_on0OkooP7no`000009ooP7
n003o`000?o_4>oo000000_ofBKI00?o0000olDjaOo5>/D02oo5>/D00ol0003oQ7^4ohAkQ00;ohAk
Q003o`000?mmPWgoOH9m00CoOH9m00?o0000oe2_D?m@[e001om@[e000ol0003oYUVVojIIYP05ojII
YP03o`000?mjQG[oNXEj00SoNXEj00?o0000olDjaOo5>/D02_o5>/D00ol0003o/dbcok=</`0Dok=<
/`03o`000?n^DJko[U6^00_o[U6^00?o0000om</dooC;=<02OoC;=<00ol0003ol0o`oo0?l00<oo0?
l003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7no`000009ooP7n004o`000?o_4>ooka3_o`00
00_ofBKI00?o0000olDjaOo5>/D02oo5>/D00ol0003oQ7^4ohAkQ00;ohAkQ003o`000?mmPWgoOH9m
00CoOH9m00?o0000oe2_D?m@[e002?m@[e000ol0003oYUVVojIIYP02ojIIYP;o00003?mjQGX2o`00
00[oaC[500?o0000ok=</oncC;<05?ncC;<00ol0003o[U6^ojiA[P0;ojiA[P03o`000?oC;=?odbcC
00WodbcC00?o0000oo0?l?o`3o003Oo`3o000ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7n007ooP7n003
o`000?o_4>ooka3_00;oka3_00?o0000omTVfOoI9]T02?oI9]T00ol0003oaC[5olDja@0<olDja@03
o`000?n4NhCoQ7^400WoQ7^400?o0000ogf2OOmmPWd01OmmPWd00ol0003oD:m@oe2_D009oe2_D004
o`000?nVFJKo0000o`00013oNXEj0_l00008olDja@03o`000?ncC;?o/dbc01Co/dbc0ol0000;ojiA
[P03o`000?oC;=?odbcC00WodbcC00?o0000oo0?l?o`3o003Oo`3o001?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o_4>ooka3_00?oka3_00?o0000omTV
fOoI9]T02?oI9]T00ol0003oaC[5olDja@0;olDja@;o00002_n4Nh@00ol0003oOH9mogf2O@06ogf2
O@03o`000?m@[e3oD:m@00[oD:m@00?o0000ogZ5N_mjQGX04_mjQGX00ol0003oaC[5olDja@04olDj
a@03o`000?ncC;?o/dbc01Go/dbc00?o0000oiaSW?nLHi`01Ol00005ojiA[P03o`000?oC;=?odbcC
00[odbcC00?o0000oo0?l?o`3o003_o`3o03o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003on0OhooP7n004ooP7n003
o`000?o_4>ooka3_00Coka3_00?o0000omTVfOoI9]T01ooI9]T00ol0003oaC[5olDja@0;olDja@04
o`000?mkQ7_oNhAko`0000WoQ7^400?o0000ogf2OOmmPWd01_mmPWd00ol0003oD:m@oe2_D00:oe2_
D003o`000?mjQG[oNXEj01?oNXEj0_l00003olDja@Co00005?ncC;<00ol0003oW6>LoiaSW006oiaS
W0Co000000?o[U6^o`000?oC;=<02ooC;=<00ol0003ol0o`oo0?l00>oo0?l003o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o_4>ooka3_00Goka3_00?o0000omTVfOoI
9]T01ooI9]T00ol0003oaC[5olDja@09olDja@;o00001?mkQ7/00ol0003oQ7^4ohAkQ005ohAkQ003
o`000?mmPWgoOH9m00OoOH9m00?o0000oe2_D?m@[e002_m@[e000ol0003oNXEjogZ5NP0EogZ5NP03
o`000?o5>/Go000000CoSG:=0ol0000@ok=</`03o`000?nLHicoW6>L00_oW6>L0_l0000<om</d`03
o`000?o`3o3ol0o`00col0o`0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7n?oh1oP00_oh1oP00ol0003oka3_
onl@k`06onl@k`03o`000?oI9]WofBKI00OofBKI00?o0000olDjaOo5>/D02?o5>/D00ol0003oNhAk
og^4N`05og^4N`03o`000?n4NhCoQ7^400CoQ7^400?o0000ogf2OOmmPWd01ommPWd00ol0003oD:m@
oe2_D00:oe2_D003o`000?mjQG[oNXEj01KoNXEj00?o0000ohebSOn=LXd01_n=LXd3o`0000co/dbc
00?o0000oiaSW?nLHi`03OnLHi`00ol0003odbcCom</d`09om</d`Go00002Oo`3o02o`000003oo@;
m?l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooP7n?l0003oka3_00Woka3_00?o0000omTVfOoI9]T01_oI
9]T00ol0003oaC[5olDja@07olDja@03o`000?mkQ7_oNhAk00OoNhAk00?o0000ohAkQ?n4Nh@00_n4
Nh@00ol0003oOH9mogf2O@08ogf2O@03o`000?m@[e3oD:m@00WoD:m@00?o0000ogZ5N_mjQGX05omj
QGX00ol0003oSG:=ohebS@09ohebS@?o00002OncC;<00ol0003oW6>LoiaSW00>oiaSW0Ko00001?oC
;=<00ol0003ogB;MomdRg@03omdRg@Go00000_o`3o02o`0000Com0_d00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?o`3o3ol0o`oo0?l?l000002oo_4>l00ol0003ofBKIomTVf@06omTVf@03o`000?o5
>/GoaC[500GoaC[50_l0000;og^4N`04o`000?n4NhCoQ7^4o`0000_oOH9m00?o0000oe2_D?m@[e00
2Om@[e000ol0003oNXEjogZ5NP0FogZ5NP03o`000?n=LXgoSG:=00goSG:=0ol00005ok=</`03o`00
0?nLHicoW6>L00ooW6>L00?o0000ok9=/_nbCK800onbCK84o`0000_ogB;M0_l00006oo@;m003o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ol0o`oo0?l002oo0?l0ko00001_oI9]T00ol0003oaC[5olDj
a@05olDja@03o`000?mkQ7_oNhAk00coNhAk00?o0000ohAkQ?l000002ommPWd00ol0003oD:m@oe2_
D007oe2_D0?o00006?mjQGX00ol0003oSG:=ohebS@0@ohebS@?o000000?o/dbco`000?nLHi`04?nL
Hi`00ol0003o/Tfbok9=/P07ok9=/P03o`000?oM8]gogB;M00[ogB;M00?o0000oo@;m?od2o@01Ood
2o@00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005oo0?l003o`000?oG:=OoebSG00_oebSG0_l00004
omTVf@03o`000?o5>/GoaC[500?oaC[50_l0000@og^4N`03o`000?mmPWgoOH9m00[oOH9m00?o0000
oe2_D?m@[e000om@[e04o`0000;o;M8]00?o0000ogZ5N_mjQGX05OmjQGX00ol0003oSG:=ohebS@0D
ohebS@03o`000?nLHicoW6>L013oW6>L00?o0000ok9=/_nbCK801onbCK800ol0003ogB;MomdRg@0:
omdRg@03o`000?od2oCom0_d00Gom0_d00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?o`3o3ol0o`
00Gol0o`00?o0000omLXeooG:=L03OoG:=L6o`0000?oaC[500?o0000og^4NomkQ7/04?mkQ7/00ol0
003oOH9mogf2O@0:ogf2O@03o`000?m@[e3o000000?o00001ol]dRd00ol0003oNXEjogZ5NP0DogZ5
NP03o`000?n=LXgoSG:=01CoSG:=00?o0000oiaSW?nLHi`03onLHi`00ol0003o/Tfbok9=/P08ok9=
/P03o`000?oM8]gogB;M00[ogB;M00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o001_o`3o000ol0003oebSGomLXe`0=omLXe`03o`000?nhAkSo^4Nh00?o
^4Nh00?o0000olDjaOl000004omkQ7/4o`0000WoOH9m0_l0000<obgB;@03o`000?mjQG[oNXEj01?o
NXEj00?o0000ohebSOn=LXd05On=LXd00ol0003oW6>LoiaSW00>oiaSW003o`000?nbCK;o/Tfb00So
/Tfb00?o0000omdRgOoM8]d02OoM8]d00ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?o`3o3ol0o`00Sol0o`00?o0000omLXeooG:=L02ooG:=L00ol0003o^4NhokQ7^005okQ7^003o`00
0?mkQ7_oNhAk01;oNhAk00Co0000oc[5>_ljaC[o>/Dj1Ol00003ogf2O@03o`000?l]dRgo;M8]00go
;M8]0ol0000@ogZ5NP;o00006?n=LXd00ol0003oW6>LoiaSW00=oiaSW003o`000?nbCK;o/Tfb00Wo
/Tfb00?o0000omdRgOoM8]d02OoM8]d00ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ol0o`00?o0000omLXeooG:=L02_oG:=L00ol0003o^4NhokQ7^006okQ7^003o`00
0?mkQ7_oNhAk017oNhAk00?o0000oc[5>_ljaCX01oljaCX3o`00013o;M8]00?o0000oaSW6?lHiaP0
1Ol00009ogZ5NP;o000000?o<Lhao`000?n=LXd05on=LXd00ol0003oW6>LoiaSW00=oiaSW003o`00
0?nbCK;o/Tfb00Wo/Tfb00?o0000omdRgOoM8]d02?oM8]d2o`0000[om0_d00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oi1_Won@Ki00;on@Ki00?o0000oo0?l?o`3o002Oo`3o000ol0003oebSGomLX
e`0:omLXe`03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000og^4NomkQ7/03omkQ7/00ol0003o>/Djoc[5
>P0:oc[5>P03o`000?l]dRgo;M8]00go;M8]00?o0000oaSW6?lHiaP01_lHiaP4o`0000CoNXEj00?o
0000oc7><OlacS400_lacS400ol0003oSG:=ohebS@0FohebS@03o`000?nLHicoW6>L00_oW6>L00?o
0000ok9=/_nbCK802onbCK800ol0003ogB;MomdRg@06omdRg@03o`000?o]4^go000000[om0_d00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00?on@Ki00?o0000oo0?l?o`3o002?o`3o0=
o`0000[o^4Nh00?o0000og^4NomkQ7/03omkQ7/00ol0003o>/Djoc[5>P0;oc[5>P03o`000?l]dRgo
;M8]00co;M8]00?o0000oaSW6?lHiaP02_lHiaP4o`0000Go<Lha00?o0000ohebSOn=LXd05_n=LXd0
0ol0003oW6>LoiaSW00:oiaSW003o`000?nbCK;o/Tfb00co/Tfb00?o0000omdRgOoM8]d01?oM8]d2
o`0000?okA;]00?o0000oo@;m?od2o@02?od2o@00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooT6
nOoi1_T00ooi1_T00ol0003ol0o`oo0?l007oo0?l003o`000?oE:]GoeB[E00WoeB[E00?o0000okQ7
^?nhAkP02OnhAkP00ol0003oNhAkog^4N`0=og^4N`03o`000?ljaC[o>/Dj00co>/Dj00?o0000obgB
;Ol]dRd03?l]dRd00ol0003o6>LHoaSW600;oaSW6003o`000?l7n0Oo000000Ko<Lha00?o0000oheb
SOn=LXd05_n=LXd00ol0003oW6>LoiaSW009oiaSW003o`000?nbCK;o/Tfb00co/Tfb00?o0000omdR
gOoM8]d00ooM8]d00ol0003okA;]ondBk@03ondBk@03o`000?od2oCom0_d00Som0_d00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000oo0?l?o`3o001_o`3o000ol0003o
eB[EomDZe@08omDZe@03o`000?nhAkSo^4Nh00_o^4Nh00?o0000og^4NomkQ7/02?mkQ7/4o`0000oo
>/Dj00?o0000obgB;Ol]dRd02ol]dRd00ol0003o6>LHoaSW600;oaSW6004o`000?l7n0Oo1oP7o`00
00Oo<Lha00?o0000ohebSOn=LXd05On=LXd00ol0003oW6>LoiaSW008oiaSW003o`000?nbCK;o/Tfb
00go/Tfb00?o0000omdRgOoM8]d00_oM8]d00ol0003okA;]ondBk@05ondBk@03o`000?od2oCom0_d
00Oom0_d00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Gon@Ki00?o0000oo0?l?o`
3o001Oo`3o000ol0003oeB[EomDZe@08omDZe@03o`000?nhAkSo^4Nh00_o^4Nh00?o0000og^4Nomk
Q7/00omkQ7/5o`0000?o?<<l00?o0000oc[5>_ljaCX03_ljaCX00ol0003o;M8]obgB;@0:obgB;@03
o`000?lHiaSo6>LH00[o6>LH00Go0000o`Oh1ol7n0Oo1oP7o`000007oc7><@03o`000?n=LXgoSG:=
01GoSG:=00?o0000oiaSW?nLHi`02?nLHi`00ol0003o/Tfbok9=/P0=ok9=/P03o`000?oM8]gogB;M
00;o00002?o]4^d00ol0003om0_doo@;m008oo@;m0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?o`3o3ol0o`00Go
l0o`00?o0000omDZeOoE:]D02?oE:]D00ol0003o^4NhokQ7^00<okQ7^0Go00002Oll`c`00ol0003o
>/Djoc[5>P0<oc[5>P;o00003?l]dRd00ol0003o6>LHoaSW600:oaSW6005o`000?l7n0Oo1oP7o`Oh
1ol000002?lacS400ol0003oSG:=ohebS@0DohebS@?o00001onLHi`00ol0003o/Tfbok9=/P0>ok9=
/P03o`000?oM8]go000000_okA;]00?o0000oo@;m?od2o@01_od2o@00ol0003oo@;mood2o@06ood2
o@03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ol0o`oo0?l004oo0?l003o`000?oE:]GoeB[E00Oo
eB[E00?o0000okQ7^?nhAkP03?nhAkP01?l0003oNXEjogZ5N_l0000;occ3?003o`000?ljaC[o>/Dj
00_o>/Dj00Co0000o`;m0_l2o@;o00002_l]dRd00ol0003o6>LHoaSW600:oaSW6003o`000?l7n0Oo
1oP700;o1oP700?o0000oc7><OlacS401_lacS400ol0003oSG:=ohebS@0AohebS@?o00000omTVf@0
0ol0003oW6>LoiaSW004oiaSW003o`000?nbCK;o/Tfb00go/Tfb1?l0000;ondBk@03o`000?od2oCo
m0_d00Gom0_d00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00Co0000oo0?
l?o`3o3ol0o`1?l00008omDZe@03o`000?nhAkSo^4Nh00_o^4Nh00?o0000ogZ5N_mjQGX00_mjQGX0
0ol0003o?<<locc3?008occ3?003o`000?ljaC[o>/Dj00[o>/Dj00?o0000o`;m0_l2o@800_l2o@80
0ol0003o;M8]obgB;@03obgB;@Go00002olHiaP00ol0003o1oP7o`Oh1`03o`Oh1`03o`000?lacS7o
<Lha00Oo<Lha00?o0000ohebSOn=LXd03_n=LXd2o`0000OoI9]T00?o0000oiaSW?nLHi`00_nLHi`0
0ol0003o/Tfbok9=/P0=ok9=/P03o`000?oJ9M[ofRGJ00;ofRGJ00?o0000ondBkOo]4^d02Oo]4^d0
0ol0003om0_doo@;m003oo@;m003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@07ooT6
n@?o00001?oP7n000ol0003oeB[EomDZe@05omDZe@03o`000?nhAkSo^4Nh00[o^4Nh00?o0000ogZ5
N_mjQGX00omjQGX00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00So>/Dj00?o0000o`;m
0_l2o@801?l2o@85o`0000Co0?l000?o0000oaSW6?lHiaP02OlHiaP00ol0003o1oP7o`Oh1`03o`Oh
1`03o`000?lacS7o<Lha00So<Lha00?o0000ohebSOn=LXd02_n=LXd3o`0000[oI9]T00Go0000oiaS
W?nLHicoW6>Lo`00000>ok9=/P03o`000?oJ9M[ofRGJ00CofRGJ0_l00009ondBk@03o`000?od2oCo
m0_d00;om0_d00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on0O
h?oP7n001OoP7n000ol0003oeB[EomDZe@03omDZe@03o`000?nhAkSo^4Nh00[o^4Nh00?o0000ogZ5
N_mjQGX01?mjQGX00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Oo>/Dj00?o0000o`;m
0_l2o@801Ol2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lHiaSo6>LH00Oo6>LH00?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o<Lhaoc7><@08oc7><@03o`000?n=LXgoSG:=00SoSG:=0_l0000>ofBK
I0Co00003?nbCK82o`0000WofRGJ00?o0000ondBkOo]4^d01oo]4^d01?l0003om0_doo@;m?l0000?
ood2o@03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oh1oPon0Oh007on0Oh0;o00000ooE:]D00ol0
003o^4NhokQ7^009okQ7^003o`000?mjQG[oNXEj00KoNXEj00?o0000occ3??ll`c`02Oll`c`00ol0
003o>/Djoc[5>P05oc[5>P03o`000?l2o@;o0_d200Ko0_d200?o0000o`3o0?l0o`002?l0o`000ol0
003o6>LHoaSW6006oaSW6003o`000?l7n0Oo1oP700Co1oP700?o0000oc7><OlacS402OlacS44o`00
00?oSG:=0ol0000@ofBKI005o`000?o3?<?o`cc3ol<l`ol000002_nbCK800ol0003ofRGJomXUfP0:
omXUfPKo00000oo]4^d00ol0003om0_do`00000@ood2o@03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0
003oh1oPon0Oh00:on0Oh004o`000?oE:]GoeB[Eo`0000[o^4Nh00?o0000ogZ5N_mjQGX01omjQGX0
0ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Co>/Dj00?o0000o`;m0_l2o@801ol2o@80
0ol0003o0?l0o`3o0008o`3o00;o00001_lHiaP00ol0003o1oP7o`Oh1`05o`Oh1`03o`000?lacS7o
<Lha00Wo<Lha00Co0000obcC;?l/dbco;=</0ol0000BofBKI003o`000?o3?<?o`cc300?o`cc30_l0
0006ok9=/P;o00003OoJ9MX00ol0003om`SgooL8m`03ooL8m`Go00004Oom0_d00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooT6nOoi1_T00ooi1_T0
0ol0003oh1oPon0Oh00<on0Oh0;o00002_nhAkP00ol0003oNXEjogZ5NP08ogZ5NP03o`000?ll`cco
?<<l00[o?<<l00?o0000oc[5>_ljaCX00_ljaCX00ol0003o0_d2o`;m0P08o`;m0P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lHiaSo6>LH00;o6>LH00?o0000o`Oh1ol7n0L01_l7n0L0
0ol0003o<Lhaoc7><@08oc7><@03o`000?l/dbco;=</00Co;=</00?o0000ofBKI?mTVf@03omTVf@0
0ol0003o`cc3ol<l``06ol<l``;o00000onbCK800ol0003ofRGJomXUfP0=omXUfP03o`000?og2?Oo
m`Sg00Oom`Sg0_l0000@ood2o@03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on@KiooT6n@02ooT6n@03o`000?oP7n3oh1oP
00koh1oP00?o0000okQ7^?nhAkP01onhAkP00ol0003oNXEjogZ5NP0:ogZ5NP03o`000?ll`cco?<<l
00Wo?<<l00Go0000oc[5>_ljaC[o>/Djo`00000;o`;m0P03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lHiaSo6>LHoaSW6?l000002?l7n0L00ol0003o<Lhaoc7><@08oc7><@03o`000?l/
dbco;=</00Go;=</00?o0000ofBKI?mTVf@03_mTVf@00ol0003o`cc3ol<l``08ol<l``03o`000?nb
CK;o000000oofRGJ00?o0000ooL8moog2?L02?og2?L01?l0003oo@;mo`000?l0000>ood2o@03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oi1_Won@Kio`00017oh1oP00?o0000okQ7^?nhAkP01_nhAkP00ol0003oNXEj
ogZ5NP0;ogZ5NP03o`000?ll`cco?<<l00Wo?<<l00Co0000oc[5>_ljaC[o00003?l2o@800ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o6>LHo`000009o`Oh1`03o`000?lacS7o<Lha00So
<Lha00?o0000obcC;?l/db`01Ol/db`00ol0003oI9]TofBKI00=ofBKI003o`000?o3?<?o`cc300[o
`cc300?o0000omXUf_oJ9MX03_oJ9MX00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00;o
o@;m00?o0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bon0Oh003o`00
0?nhAkSo^4Nh00Co^4Nh00?o0000ogZ5N_mjQGX03?mjQGX00ol0003o?<<locc3?00:occ3?0?o0000
3?l2o@800ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Oh1ol7n0L02?l7n0L00ol0003o<Lha
oc7><@07oc7><@03o`000?l/dbco;=</00Oo;=</00?o0000ofBKI?mTVf@03?mTVf@00ol0003o`cc3
ol<l``0;ol<l``;o00003_oJ9MX00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00?oo@;m
0_l0000:ood2o@03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L00oog2?L00ol0003oh1oPon0Oh00?on0Oh0?o00000onh
AkP00ol0003oNXEjogZ5NP0>ogZ5NP03o`000?ll`cco?<<l00So?<<l00Co0000o`[e2_l:m@[o2_D:
0_l0000:o`;m0P?o00003Ol0o`000ol0003o1oP7o`Oh1`08o`Oh1`03o`000?lacS7o<Lha00Oo<Lha
00?o0000obcC;?l/db`01ol/db`00ol0003oI9]TofBKI00;ofBKI003o`000?o3?<?o`cc300co`cc3
00?o0000onhAk_l000000_l0000:omXUfP03o`000?og2?Oom`Sg00Som`Sg00?o0000ood2oOom0_d0
1Oom0_d2o`0000Soo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`04ooL8m`03o`000?oP7n3oh1oP00coh1oP0_l0
0003olhacP03o`000?nhAkSo0000017oNXEj00?o0000occ3??ll`c`01oll`c`00ol0003o2_D:o`[e
2P04o`[e2P;o00002?l2o@800ol0003o0?l0o`3o000>o`3o00;o00002?l7n0L00ol0003o<Lhaoc7>
<@06oc7><@03o`000?l/dbco;=</00Wo;=</00?o0000ofBKI?mTVf@02OmTVf@00ol0003o`cc3ol<l
``0=ol<l``03o`000?o^4NkokQ7^00;okQ7^0ol00007omXUfP03o`000?og2?Oom`Sg00Oom`Sg00?o
0000ood2oOom0_d02?om0_d2o`0000Koo@;m00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?oP7n3o
h1oP00Woh1oP0_l00006olhacP03o`000?mjQG[oNXEj013oNXEj00?o0000occ3??ll`c`01_ll`c`0
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l2o@;o0_d200Co0_d20ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol7n0L00ol0003o<Lhaoc7><@06oc7><@03o`000?l/dbco;=</00[o;=</00?o0000
ofBKI?mTVf@02?mTVf@00ol0003o`cc3ol<l``0=ol<l``03o`000?o^4NkokQ7^00GokQ7^0ol00004
omXUfP03o`000?og2?Oom`Sg00Oom`Sg00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@02
ood2o@;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om`SgooL8m`06ooL8m`03o`000?oP7n3oh1oP00Goh1oP0ol00008olhacP03o`000?mjQG[oNXEj
017oNXEj00Co0000occ3??ll`cco?<<l1?l0000;o`[e2P;o000000Co0_d2o`000?l0003o00000ol8
m`P2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1oP700?o0000oc7><OlacS401_la
cS400ol0003o;=</obcC;00:obcC;003o`000?mTVfCoI9]T00OoI9]T00?o0000ol<l`oo3?<<03_o3
?<<00ol0003okQ7^onhAkP08onhAkPCo00002_og2?L00ol0003oo@;mood2o@0;ood2o@;o000000?o
o@;mo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003om`SgooL8m`07ooL8m`03o`000?oP7n3oh1oP00;oh1oP0_l0000<olhacP03o`000?mjQG[o
NXEj013oNXEj1?l00003obo@;`03o`000?l:m@[o2_D:00_o2_D:00?o0000o`Sg2?l8m`P01_l8m`P0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obcC;003o`000?mTVfCo
I9]T00KoI9]T00?o0000ol<l`oo3?<<03_o3?<<00ol0003okQ7^onhAkP0;onhAkP03o`000?og2?Oo
m`Sg00Oom`Sg00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00Co0000on0O
h?l0003o00003_o><Lh00ol0003oNXEjogZ5NP0?ogZ5NP03o`000?l_d2oo;m0_00Ko;m0_00?o0000
o`[e2_l:m@X02_l:m@X00ol0003o2?L8o`Sg2007o`Sg20;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lbcC;o</db00So</db00?o0000obcC;?l/db`03?l/db`00ol0003oI9]TofBKI005
ofBKI003o`000?o3?<?o`cc300oo`cc30_l0000=onhAkP03o`000?og2?Oom`Sg00Kom`Sg00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00[om`Sg00?o0000olhac_o><Lh03_o><Lh00ol0
003oNXEjogZ5NP0>ogZ5NP03o`000?l_d2oo;m0_00Oo;m0_00?o0000o`[e2_l:m@X02_l:m@X00ol0
003o2?L8o`Sg2009o`Sg20;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lbcC;o</db
00Wo</db00?o0000obcC;?l/db`02_l/db`4o`0000CoI9]T00?o0000ol<l`oo3?<<04?o3?<<01?l0
003ojaC[o`000?l0000<onhAkP03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?og2?Oom`Sg00[om`Sg00?o0000olhac_o><Lh03oo><Lh@o`0000[o;m0_00?o0000o`[e
2_l:m@X02Ol:m@X00ol0003o0?l0o`00000<o`Sg2005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o</dboc;=<P09oc;=<P03o`000?l/dbco;=</00Oo;=</0ol00004of:MHP?o000000?oI9]T
o`000?o3?<<04Oo3?<<01?l0003ojaC[on/Djoo[5>/2o`0000_okQ7^00?o0000ooL8moog2?L00oog
2?L00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02_og2?L00ol0003ocS7>olhacP0?
olhacP03o`000?miQWWoNHIi00coNHIi00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2_D:o`[e2P07
o`[e2P04o`000?l0o`3o0?l0o`0000go2?L800Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lbcC;o</db00[o</db00?o0000obcC;?l/db`00ol/db`3o`0000[oHYeR00?o0000ol<l`oo3?<<0
4?o3?<<00ol0003ojaC[on/Dj`04on/Dj`;o00002_o^4Nh00ol0003om`SgooL8m`04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000com`Sg00?o0000olhac_o><Lh03oo><Lh00ol0003oNHIiogV6N@0<ogV6N@03o`000?l_
d2oo;m0_00Wo;m0_00?o0000o`[e2_l:m@X01_l:m@X00ol0003o0?l0o`3o0002o`3o0003o`000?l8
m`So2?L800[o2?L800?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?lb
cC;o</db00[o</db00?o0000obcC;?l/db`00ol0000=of:MHP03o`000?o3?<?o`cc3013o`cc300?o
0000on/Djoo[5>/01_o[5>/2o`0000WokQ7^0_l00004ood2o@03o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003ocS7>olhacP0=olhacP?o00003omiQWT0
0ol0003o;m0_obo@;`08obo@;`03o`000?l:m@[o2_D:00Go2_D:00?o0000o`3o0?l0o`000ol0o`00
0ol0003o2?L8o`Sg200:o`Sg2003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o</dboc;=<P0;oc;=<P;o00004OmRWF800ol0003o`cc3ol<l``0?ol<l``03o`000?o[5>_o
jaC[00SojaC[0_l00007onhAkP03o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooL8moog2?L02?og2?L00ol0003ocS7>olhacP09olhacPGo00000_nUFZD00ol0
003oNHIiogV6N@0=ogV6N@03o`000?l_d2oo;m0_00Wo;m0_00?o0000o`[e2_l:m@X01?l:m@X00ol0
003o0?l0o`3o0004o`3o0003o`000?l8m`So2?L800So2?L800?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lbcC;o</db00_o</db00?o0000of:MH_mRWF804?mRWF800ol0
003o`cc3ol<l``0?ol<l``03o`000?o[5>_ojaC[00[ojaC[0_l00004onhAkP03o`000?om0_goo@;m
00Koo@;m0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om`SgooL8m`07ooL8m`03o`000?o><LkocS7>00CocS7>1Ol00007ojEJY@03
o`000?miQWWoNHIi00goNHIi00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2_D:o`[e2P03o`[e2P03
o`000?l0o`3o0?l000Go0?l000?o0000o`Sg2?l8m`P02?l8m`P00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000oc;=<_lbcC802olbcC800ol0003oHYeRof:MHP0@of:MHP03
o`000?o3?<?o`cc300oo`cc300?o0000on/Djoo[5>/03?o[5>/2o`000003onhAk_l0003oo@;m00[o
o@;m00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000olhac_l00000
1?l0000<ojEJY@03o`000?miQWWoNHIi00koNHIi00?o0000obo@;ol_d2l02?l_d2l00ol0003o2_D:
o`[e2P02o`[e2P03o`000?l0o`3o0?l000Oo0?l000?o0000o`Sg2?l8m`P01ol8m`P00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000oc;=<_lbcC802olbcC800ol0003oHYeR
of:MHP0Aof:MHP03o`000?o3?<?o`cc300go`cc300?o0000on/Djoo[5>/03oo[5>/00ol0003oo@;m
ood2o@0;ood2o@;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L01Oog2?L3o`00017oYEZU00?o0000ogV6NOmiQWT03_mi
QWT00ol0003o;m0_obo@;`09obo@;`04o`000?l:m@[o2_D:o`0000[o0?l000?o0000o`Sg2?l8m`P0
1ol8m`P00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003OlbcC800ol0003o
HYeRof:MHP0Aof:MHP?o00003Oo3?<<00ol0003ojaC[on/Dj`0?on/Dj`03o`000?om0_goo@;m00go
o@;m00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_og2?L2o`0000;oi1_T00?o0000ojEJYOnUFZD03onUFZD00ol0003o
NHIiogV6N@0>ogV6N@03o`000?l_d2oo;m0_00So;m0_1Ol0000;o`3o0003o`000?l8m`So2?L800Ko
2?L800?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=oc;=<P03o`000?mRWF;oHYeR
017oHYeR00?o0000og><LomcS7<00ol0000:ol<l``Co00003Oo[5>/00ol0003oo@;mood2o@0?ood2
o@03o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooP7n?oh1oSon0Oh0_l00005on@Ki003o`000?nUFZGoYEZU00koYEZU00?o0000ogV6
NOmiQWT03_miQWT00ol0003o;m0_obo@;`07obo@;`03o`000?lCk1?o4n`C00?o4n`C00?o0000o`3o
0?l0o`002?l0o`000ol0003o2?L8o`Sg2005o`Sg2003o`000?l0o`3o0?l000[o0?l01Ol0000<oc;=
<P03o`000?mRWF;oHYeR013oHYeR00?o0000og><LomcS7<01?mcS7<3o`0000Ko`cc300?o0000onHI
i_oV6NH00_oV6NH5o`0000SojaC[00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00?o
n0Oh00?o0000on@Ki?oT6n@01?oT6n@00ol0003oYEZUojEJY@0=ojEJY@03o`000?miQWWoNHIi00oo
NHIi00?o0000obo@;ol_d2l01?l_d2l2o`0000Oo4n`C00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000oc;=<_lbcC802?lbcC83o`00013oHYeR00?o0000og><LomcS7<02?mcS7<3o`0000;o
`cc300?o0000onHIi_oV6NH02?oV6NH5o`0000?ojaC[00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oh1oSon0Oh00Con0Oh00?o0000on@Ki?oT6n@01OoT6n@00ol0003oYEZUojEJY@0;ojEJY@Co0000
3omiQWT00ol0003o;m0_obo@;`03obo@;`03o`000?lCk1?o4n`C00So4n`C00?o0000o`3o0?l0o`00
1?l0o`02o`0000So3?<<00?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_lbcC82o`0000?o<<l`00?o0000of:MH_mRWF803?mRWF800ol0003oLhacog><L`0<og><L`;o0000
4?oV6NH3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oT6nCoi1_T00Koi1_T00?o
0000ojEJYOnUFZD02OnUFZD00ol0003o]dRgo`000002ofVFJ@?o00003?miQWT01?l0003o;m0_obo@
;ol_d2l2o`0000co4n`C00?o0000o`3o0?l0o`000_l0o`000ol0003o3?<<o`cc3008o`cc3003o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o</dboc;=<P02oc;=<P03o`00
0?l`cc3o<<l`00Co<<l`0_l0000;of:MHP03o`000?mcS7?oLhac00coLhac00?o0000okM8]ol00000
4_oV6NH00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on0OhooP7n006ooP7n003o`000?oT6nCoi1_T00Ooi1_T00?o
0000ojEJYOnUFZD01_nUFZD2o`0000;o]dRg00?o0000ofVFJOmYUVT00omYUVT3o`0000[oNHIi00?o
0000obo@;ol000003olCk1<01?l0003o0?l0o`000?l0000;o`cc3003o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o</dbo`000?l00009oc3?<003o`000?mRWF;oHYeR00Oo
HYeR00?o0000og><LomcS7<03?mcS7<01?l0003o]dRgokM8]ol0000ConHIiP03o`000?om0_goo@;m
00coo@;m0ol000000oom0_go0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003oi1_Ton@Ki008on@Ki003o`000?nUFZGoYEZU00Co
YEZU00?o0000okM8]ongB;L00ongB;L00ol0003oJIIYofVFJ@05ofVFJ@?o00001_miQWT4o`00013o
4n`C00?o0000o`cc3?l<l``03?l<l``00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000oc3?<?l`cc002_l`cc02o`0000KoHYeR00?o0000og><LomcS7<03?mcS7<00ol0003o
]dRgokM8]`02okM8]`03o`000?oV6NKoiQWV00ooiQWV00?o0000ooH9m_l000002oom0_d2o`0000Co
o@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on0OhooP7n008ooP7n003o`000?oT6nCoi1_T00Woi1_T00Co0000ojEJYOnUFZGo
YEZU0_l00006okM8]`03o`000?mYUVWoJIIY00SoJIIY0ol000000omiQWWo0000o`000004oc?<<`03
o`000?lCk1?o4n`C00go4n`C00?o0000o`cc3?l<l``03?l<l``00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000oc3?<?l`cc003?l`cc000ol0003oHYeRof:MHP03o`0000ko
Lhac00?o0000okM8]ongB;L00ongB;L00ol0003oiQWVonHIiP0>onHIiP05o`000?of2OKomPWfooH9
m_l000002?om0_d2o`0000Ooo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n009ooP7n003o`000?oT6nCoi1_T00[o
i1_T00?o0000ojEJYOl000002?ngB;L00ol0003oJIIYofVFJ@0;ofVFJ@03o`000?lcc3?o<l`c00Go
<l`c00?o0000oa?/4olCk1<03?lCk1<00ol0003o3?<<o`cc300<o`cc3003o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo<<l`0_l00002og6>L@03o`000?mcS7?oLhac00_o
Lhac00?o0000okM8]ongB;L01?ngB;L00ol0003oiQWVonHIiP0=onHIiP03o`000?of2OKomPWf00?o
mPWf00?o0000ood2oOom0_d00_om0_d3o`0000Woo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooP7n003o`000?oT6nCoi1_T00_oi1_T00?o0000okM8]ongB;L0
1ongB;L00ol0003oJIIYofVFJ@0;ofVFJ@03o`000?lcc3?o<l`c00Ko<l`c00?o0000oa?/4olCk1<0
2olCk1<2o`0000go3?<<00?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l5nPGo1OX5o`0000ko<<l`00?o0000og6>LOmaSW400_maSW400ol0003oLhacog><L`09og><L`03
o`000?ngB;Oo]dRg00Ko]dRg00?o0000onHIi_oV6NH02ooV6NH00ol0003omPWfooH9mP05ooH9mP04
o`000?om0_go0000o`0000coo@;m00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son0Oh00?o0000on@Ki?oT6n@02_oT6n@2o`0000Wo
]dRg00?o0000ofVFJOmYUVT02omYUVT00ol0003o<l`coc?<<`07oc?<<`03o`000?lCk1?o4n`C00Wo
4n`C00Co0000o`3o0?l0o`3o00003?l<l``00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Gj1Ol5nPGo1OX5o`00000>oc3?<003o`000?maSW7oLHia00?oLHia00?o0000
og><LomcS7<01omcS7<00ol0003o]dRgokM8]`07okM8]`03o`000?oV6NKoiQWV00[oiQWV00?o0000
ooH9m_of2OH01oof2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooP7n003o`000?oT6nCoi1_T
00Woi1_T00Co0000omhQg_oN8Mko00002OngB;L00ol0003oJIIYofVFJ@09ofVFJ@03o`000?lcc3?o
<l`c00Wo<l`c00?o0000oa?/4olCk1<01olCk1<00ol0003o0?l0o`3o0002o`3o0003o`000?l<l`co
3?<<00Wo3?<<00?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l5nPGo
1OX500?o1OX500?o0000oc3?<?l`cc002_l`cc000ol0003oLHiaog6>L@05og6>L@03o`000?mcS7?o
Lhac00GoLhac00?o0000okM8]ongB;L02?ngB;L00ol0003oiQWVonHIiP09onHIiP03o`000?of2OKo
mPWf00SomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oh1oP3o`0000Woi1_T00?o0000omhQ
g_oN8Mh00_oN8Mh00ol0003o]dRgokM8]`06okM8]`03o`000?mYUVWoJIIY00WoJIIY00?o0000oc?<
<olcc3<02_lcc3<00ol0003o4n`Coa?/4`05oa?/4`03o`000?l0o`3o0?l000Co0?l000?o0000o`cc
3?l<l``02?l<l``00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o<<l`oc3?<00:oc3?<003o`000?maSW7oLHia00KoLHia00?o0000og><
LomcS7<00omcS7<00ol0003o]dRgokM8]`09okM8]`03o`000?oV6NKoiQWV00SoiQWV00?o0000ooH9
m_of2OH02Oof2OH00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo8=lP?o00001OoT6n@00ol0003o
gR7NomhQgP03omhQgP03o`000?ngB;Oo]dRg00Ko]dRg00?o0000ofVFJOmYUVT02OmYUVT00ol0003o
<l`coc?<<`0;oc?<<`03o`000?lCk1?o4n`C00?o4n`C00?o0000o`3o0?l0o`001_l0o`000ol0003o
3?<<o`cc3008o`cc3003o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1OX500?o0000oc3?<?l`cc002Ol`cc000ol0003oLHiaog6>L@07og6>L@05o`000?mcS7?oLhacog><
Lol000003OngB;L00ol0003oiQWVonHIiP06onHIiP03o`000?of2OKomPWf00[omPWf00?o0000ood2
oOom0_d03Oom0_d00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?ob3O;olPgb00GolPgb0ol000000ooT6nCo0000omhQgP06omhQgP03
o`000?ngB;Oo]dRg00Go]dRg00?o0000ofVFJOmYUVT02OmYUVT00ol0003o<l`coc?<<`0<oc?<<`05
o`000?lCk1?o4n`Coa?/4ol000002_l0o`000ol0003o3?<<o`cc3007o`cc3003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olUfRGo0000o`Gj1@07o`Gj1@03o`000?l`cc3o<<l`
00So<<l`00?o0000og6>LOmaSW402OmaSW400ol0003oLhaco`00000=okM8]`Co00001OoV6NH00ol0
003omPWfooH9mP0;ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003olPgboo8=lP08oo8=lP03
o`000?oN8MkogR7N00OogR7N00?o0000okM8]ongB;L01?ngB;L00ol0003oJIIYofVFJ@09ofVFJ@03
o`000?lcc3?o<l`c00go<l`c00?o0000oa?/4ol000003?l0o`0:o`0000Oo0?l00ol00005obGJ9@03
o`000?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001ol`cc000ol0003oLHiaog6>L@0:og6>L@03
o`000?ngB;Oo]dRg00_o]dRg00?o0000onHIi_oV6NH00_oV6NH3o`000003onHIi_l0003omPWf00_o
mPWf0ol0000>ood2o@03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003ogR7NomhQgP07omhQgP03o`00
0?ngB;Oo]dRg00Go]dRg00?o0000ofVFJOmYUVT01omYUVT00ol0003o<l`coc?<<`0?oc?<<`;o0000
2ol0o`000ol0003o6NHIoaWV6@07oaWV6@03o`000?l0o`3o0?l000;o0?l00ol00008obGJ9@03o`00
0?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001ol`cc000ol0003oLHiaog6>L@0:og6>L@03o`00
0?ngB;Oo]dRg00[o]dRg00?o0000onHIi_oV6NH01_oV6NH00ol0003omPWfooH9mP08ooH9mP?o0000
0_oh1oP00ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003ogR7NomhQ
gP08omhQgP03o`000?ngB;Oo]dRg00Co]dRg00?o0000ofVFJOmYUVT01omYUVT00ol0003o<l`coc?<
<`0>oc?<<`04o`000?l4n`Co1?/4o`0000Wo0?l000?o0000oaWV6OlIiQT02OlIiQT01?l0003o0?l0
o`000?l0000<obGJ9@03o`000?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001_l`cc000ol0003o
LHiaog6>L@0;og6>L@03o`000?ngB;Oo]dRg00Oo]dRg0_l00009onHIiP03o`000?of2OKomPWf00Co
mPWf1?l00006ooP7n003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003olPgboo8=lP09oo8=lP03o`00
0?oN8MkogR7N00SogR7N00?o0000okM8]ongB;L00ongB;L>o`0000go<l`c00?o0000o`Ck1?l4n`@0
0_l4n`@00ol0003o0?l0o`3o0005o`3o0003o`000?lIiQWo6NHI00_o6NHI00?o0000obGJ9OlUfRD0
3?lUfRD00ol0003o1OX5o`Gj1@06o`Gj1@03o`000?l`cc3o<<l`00Go<<l`00?o0000og6>LOmaSW40
3?maSW400ol0003o]dRgokM8]`06okM8]`03o`000?oV6NKoiQWV00[oiQWV00?o0000ooH9m_of2OH0
0ol0000:ooP7n0?o00002_om0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000omhQg_oN8Mh02?oN
8Mh01Ol0003o]dRgokM8]ongB;Oo000000_oOH9m00?o0000oa[U6_lJiAX00ol00009oc?<<`03o`00
0?l4n`Co1?/400Co1?/400?o0000o`3o0?l0o`000ol0o`000ol0003o6NHIoaWV6@0<oaWV6@03o`00
0?lUfRGo9MXU00go9MXU00?o0000o`Gj1Ol5nPD01_l5nPD00ol0003o<<l`oc3?<003oc3?<0?o0000
3OmaSW400ol0003o]dRgokM8]`05okM8]`03o`000?oV6NKoiQWV00coiQWV0_l0000=ooP7n003o`00
0?on0OkooP7n00?o00001oom0_d00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000omhQg_oN8Mh02?oN
8Mh4o`0000coOH9m00?o0000oa[U6_lJiAX00olJiAX3o`0000Go<l`c00?o0000o`Ck1?l4n`@01_l4
n`@01Ol0003o0?l0o`3o0?l0o`3o000000oo6NHI00?o0000obGJ9OlUfRD03OlUfRD00ol0003o1OX5
o`Gj1@06o`Gj1@03o`000?l`cc3o<<l`00?o00000olXebP00ol0003oLHiaog6>L@0;og6>L@03o`00
0?ngB;Oo]dRg00?o]dRg00?o0000onHIi_oV6NH03OoV6NH00ol0003on0OhooP7n00;ooP7n003o`00
0?on0OkooP7n00CooP7n0ol00004ood2o@03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo8=l_ob3O802_ob3O83o`0000KogR7N0ol0
0003oll`c`03o`000?mmPWgoOH9m00[oOH9m00?o0000oa[U6_lJiAX01_lJiAX3o`000003oc?<<ol0
003o1?/400Wo1?/400?o0000o`3o0?l000004?lIiQT00ol0003o9MXUobGJ9@0=obGJ9@03o`000?l5
nPGo1OX500Oo1OX50_l00007obSG:003o`000?maSW7oLHia00[oLHia00Co0000okM8]ongB;Oo]dRg
0ol0000?onHIiP03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo8=l_ob3O802_ob
3O801?l0003ok1?/on`Ck?o/4n`2o`000004omhQg_l0003o0000o`0000Kocc3?00?o0000ogf2OOmm
PWd02_mmPWd00ol0003o6^DJoa[U6P09oa[U6P03o`000?l4n`Co1?/400[o1?/400?o0000oaWV6OlI
iQT03olIiQT00ol0003o9MXUobGJ9@0>obGJ9@03o`000?l5nPGo1OX500Ko1OX500?o0000obSG:?lX
ebP01olXebP4o`0000SoLHia00Co0000okM8]ongB;Oo00000oo?<<l2o`0000goiQWV00?o0000ooP7
n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003o
k1?/on`Ck004on`Ck003o`000?o?<<oocc3?00Oocc3?00?o0000ogf2OOmmPWd02OmmPWd00ol0003o
6^DJoa[U6P0:oa[U6P03o`000?l4n`Co1?/400[o1?/400?o0000oaWV6OlIiQT03olIiQT00ol0003o
9MXUobGJ9@0>obGJ9@03o`000?l5nPGo1OX500Go1OX500?o0000obSG:?lXebP02?lXebP01?l0003o
Ki1_ofn@Kom_T6l7o`0000;oLHia0_l00006oll`c`;o00003?oV6NH00ol0003on0OhooP7n009ooP7
n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003olPgboo8=lP08oo8=lP03o`000?o/4ncok1?/00Go
k1?/00?o0000oll`coo?<<l02?o?<<l00ol0003oOH9mogf2O@08ogf2O@03o`000?lJiA[o6^DJ00[o
6^DJ00?o0000o`Ck1?l4n`@02ol4n`@00ol0003o6NHIoaWV6@0>oaWV6@03o`000?lUfRGo9MXU00ko
9MXU1Ol00002o`Gj1@03o`000?lXebSo:=LX00Wo:=LX00?o0000ofn@Kom_T6l02?m_T6l3o`0000Wo
cc3?0_l0000:onHIiP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ob3O;olPgb00SolPgb00?o0000on`Ck?o/4n`01oo/4n`00ol0003occ3?oll`c`07oll`c`03o`00
0?mmPWgoOH9m00SoOH9m00?o0000oa[U6_lJiAX02_lJiAX00ol0003o1?/4o`Ck100:o`Ck10;o0000
3_lIiQT3o`0000go9MXU0ol00005ocK9=P;o00002olXebP00ol0003oKi1_ofn@K`0;ofn@K`;o0000
2_o?<<l2o`0000OoiQWV0ol00009ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:on`Ck003o`00
0?o?<<oocc3?00Oocc3?00?o0000ogf2OOmmPWd02?mmPWd>o`0000Wo1?/40ol000000ol0o`3o0000
oaWV6@0:oaWV6@?o00000_lbcC800ol0003o9MXUobGJ9@09obGJ9@;o00002OlfbCH00ol0003o:=LX
obSG:009obSG:003o`000?m_T6ooKi1_00_oKi1_00?o0000oiYUV_l000002oo?<<l2o`0000CoiQWV
00Co0000oo0?l?o`3o3ol0o`0_l00007ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003ok1?/
on`Ck009on`Ck003o`000?o?<<oocc3?00Kocc3?00?o0000ogf2OOmmPWd02?mmPWd00ol0003o7n0O
oaoP7`0:oaoP7`03o`000?l4n`Co1?/400Co1?/40ol00005o`3o0003o`000?lIiQWo6NHI00Co6NHI
1?l00006oc;=<P03o`000?lUfRGo9MXU00Ko9MXU0_l0000;ocK9=P03o`000?lXebSo:=LX00Wo:=LX
00?o0000ofn@Kom_T6l02_m_T6l01Ol0003oVVFJoiYUV_nJII[o000000cocc3?0_l000000ooV6NKo
0000oo0?l005oo0?l003o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o/4ncok1?/00Sok1?/00?o0000oll`coo?<<l01_o?<<l00ol0003oOH9mogf2O@07ogf2O@03o`00
0?lOh1oo7n0O00_o7n0O00?o0000o`Ck1?l4n`@00_l4n`@2o`0000Wo0?l000?o0000oaWV6OlIiQT0
0ol0000;oc;=<P03o`000?lUfRGo9MXU00;o9MXU0ol0000>ocK9=P03o`000?lXebSo:=LX00Oo:=LX
00?o0000ofn@Kom_T6l02om_T6l00ol0003oVVFJoiYUVP02oiYUVP03o`000?o?<<oocc3?00_occ3?
00?o0000oo0?l?o`3o001_o`3o02o`0000?on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o/
4ncok1?/00Ook1?/00?o0000oll`coo?<<l01oo?<<l00ol0003oOH9mogf2O@05ogf2O@?o00003OlO
h1l4o`0000_o0?l00ol0000?oc;=<P04o`000?lUfRGo0000o`00017o=/Tf00?o0000obSG:?lXebP0
1olXebP00ol0003oKi1_ofn@K`0:ofn@K`03o`000?nJII[oVVFJ00CoVVFJ00?o0000oll`coo?<<l0
1oo?<<l3o`0000_ol0o`1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`02?o/4n`00ol0003occ3?oll`
c`06oll`c`03o`000?mmPWgoOH9m00;oOH9m0ol00003oeRWF003o`000?lOh1oo7n0O00[o7n0O00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aoc;=<P03o`000?lfbCKo=/Tf017o=/Tf00?o
0000obSG:?lXebP01olXebP00ol0003oKi1_ofn@K`0:ofn@K`03o`000?nJII[oVVFJ00GoVVFJ00Co
0000oll`coo?<<oocc3?1Ol00002omDZe@03o`000?o`3o3ol0o`00Wol0o`00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000on`Ck?o/4n`01oo/4n`00ol0003occ3?oll`c`05oll`c`?o0000
00?oOH9mo`000?l000001omHYeP00ol0003o7n0OoaoP7`08oaoP7`?o00002_l0o`02o`0000;o0?l0
00?o0000oc;=<_lbcC803olbcC800ol0003o=/TfocK9=P0AocK9=P03o`000?lXebSo:=LX00Oo:=LX
00?o0000ofn@Kom_T6l02Om_T6l00ol0003oVVFJoiYUVP07oiYUVP?o00001ooE:]D00ol0003ol0o`
oo0?l009oo0?l003o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000on`Ck?o/4n`01oo/
4n`4o`0000;occ3?0_l00003ol4n`@03o`000?mHYeSoF:MH00SoF:MH0_l00006oaoP7`;o00000olI
iQT00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000oc;=<_lbcC803_lb
cC800ol0003o=/TfocK9=P0BocK9=P03o`000?lXebSo:=LX00Go:=LX00?o0000ofn@Kom_T6l02Om_
T6l00ol0003oVVFJoiYUVP08oiYUVP03o`000?oE:]GoeB[E00OoeB[E00?o0000oo0?l?o`3o002?o`
3o000ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o/4ncok1?/00Cok1?/0_l00004
on/Dj`;o00001Oo1?/400ol0003oF:MHoeRWF00:oeRWF003o`000?lOh1oo7n0O00;o7n0O00?o0000
oaWV6OlIiQT01?lIiQT00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
oc;=<_lbcC803_lbcC800ol0003o=/TfocK9=P0BocK9=P[o00002_m_T6l00ol0003oVVFJoiYUVP08
oiYUVP03o`000?oE:]GoeB[E00OoeB[E00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ok1?/on`Ck?o/4n`2o`0000OojaC[00?o0000ol4n`Oo1?/401?o1?/40
0ol0003oF:MHoeRWF00:oeRWF004o`000?lOh1oo0000o`0000So6NHI00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lbcC;o</db00ko</db00?o0000ocK9=_lfbCH04_lfbCH00ol0003oB;M8
odRgB007odRgB003o`000?m_T6ooKi1_00KoKi1_00?o0000oiYUV_nJIIX02_nJIIX00ol0003oeB[E
omDZe@06omDZe@03o`000?o`3o3ol0o`00Sol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o/
4nco0000o`0000WojaC[00?o0000ol4n`Oo1?/401?o1?/400ol0003oF:MHoeRWF00;oeRWF003o`00
0?lIiQWo6NHI00Wo6NHI00?o0000o`3o0?l000002Ol0o`000ol0003o</dboc;=<P0>oc;=<P;o0000
4_lfbCH00ol0003oB;M8odRgB009odRgB0;o00001_m_T6l00ol0003oVVFJoiYUVP0:oiYUVP03o`00
0?oE:]GoeB[E00KoeB[E00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000on/Djoo[5>/02Oo[5>/00ol0003o`Ck1ol4n`@05ol4n`@03o`000?mHYeSoF:MH00[oF:MH00?o
0000oaWV6OlIiQT02_lIiQT2o`0000Wo0?l000?o0000oc;=<_lbcC803_lbcC800ol0003o8m`So`00
0002o`0000oo=/Tf00?o0000odRgB?m8]dP02om8]dP00ol0003oKi1_ofn@K`03o`0000goVVFJ00?o
0000omDZeOoE:]D01_oE:]D00ol0003ol0o`oo0?l007oo0?l003o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003ojaC[on/Dj`09on/Dj`03o`000?o1?/7o`Ck100Go`Ck100?o0000oeRWF?mHYeP02OmHYeP2
o`0000_o6NHI0_l0000;o`3o0003o`000?lbcC;o</db00co</db00?o0000ob?L8olSg2<00olSg2<3
o`0000co=/Tf00?o0000odRgB?m8]dP03?m8]dP2o`0000;oTfbC00?o0000oiYUV_nJIIX03?nJIIX0
0ol0003oeB[EomDZe@05omDZe@03o`000?o`3o3ol0o`00Ool0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o[5>_ojaC[00[ojaC[00?o0000ol4n`Oo1?/401_o1?/400ol0003oF:MHoeRWF007oeRW
F003o`000?mNXEko000000[o6NHI00Co0000oa7^4OlAkQ7o00002_l0o`000ol0003o</dboc;=<P0<
oc;=<P03o`000?lSg2?o8m`S00Ko8m`S0_l00008ocK9=P;o00003om8]dP00ol0003oTfbCoi=/T`02
oi=/T`03o`000?nJII[oVVFJ00_oVVFJ00?o0000omDZeOoE:]D01OoE:]D00ol0003ol0o`oo0?l007
oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ojaC[on/Dj`0:on/Dj`03o`000?o1?/7o`Ck1
00Ko`Ck100?o0000oeRWF?mHYeP01_mHYeP01Ol0003oGZ5NoejQG_mNXEko000000So6NHI00?o0000
oa7^4OlAkQ400_lAkQ400ol0003o0?l0o`3o0006o`3o00Co00003?lbcC800ol0003o8m`Sob?L8`08
ob?L8`?o00000_lfbCH3o`000003ocK9=_l0003oB;M800goB;M800?o0000oi=/TonCK9<01?nCK9<0
0ol0003oVVFJoiYUVP0:oiYUVP03o`000?oE:]GoeB[E00GoeB[E00?o0000oo0?l?o`3o001_o`3o00
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/Djoo[5>/02oo[5>/00ol0003o`Ck1ol4n`@07ol4n
`@03o`000?mHYeSoF:MH00?oF:MH0_l00005oejQGP03o`000?lIiQWo6NHI00Co6NHI00?o0000oa7^
4OlAkQ400olAkQ400ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co1?/400;o1?/40ol00007oc;=
<P;o00003_lSg2<2o`0000Go=/Tf00?o0000odRgB?m8]dP02_m8]dP00ol0003oTfbCoi=/T`05oi=/
T`03o`000?nJII[oVVFJ00_oVVFJ00?o0000omDZeOoE:]D01?oE:]D00ol0003ol0o`oo0?l006oo0?
l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ojaC[on/Dj`0;on/Dj`03o`000?o1?/7o`Ck100Oo
`Ck100?o0000oeRWF?mHYeP00_mHYeP00ol0003oGZ5NoejQGP06oejQGP03o`000?lIiQWo6NHI00;o
6NHI00?o0000oa7^4OlAkQ401OlAkQ400ol0003o0?l0o`3o0002o`3o00;o00002?l4n`@3o`0000;o
</db0_l000000ol9mPWo0000ob?L8`0=ob?L8`03o`000?lfbCKo=/Tf00Go=/Tf00?o0000odRgB?m8
]dP02?m8]dP00ol0003oTfbCoi=/T`07oi=/T`03o`000?nJII[oVVFJ00[oVVFJ00?o0000omDZeOoE
:]D01?oE:]D00ol0003ol0o`oo0?l006oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ojaC[
on/Dj`0<on/Dj`03o`000?o1?/7o`Ck100So`Ck100Co0000oeRWF?mHYeSo00002OmNXEh01Ol0003o
6NHIoaWV6OlIiQWo000000So4NhA00Go0000o`3o0?l0o`3o0?l0o`00000=o`Ck10;o00001?l9mPT0
0ol0003o8m`Sob?L8`0;ob?L8`03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000odRgB?m8]dP01om8]dP0
0ol0003oTfbCoi=/T`08oi=/T`Co00002?nJIIX00ol0003oeB[EomDZe@04omDZe@03o`000?o`3o3o
l0o`00Kol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o[5>_ojaC[00_ojaC[0ol00009ol4n
`@03o`000?mHYeSo000000_oGZ5N00?o0000oaWV6Ol000002_lAkQ400ol0003o0?l0o`00000?o`Ck
1003o`000?l9mPWo2OH900;o2OH900?o0000ob?L8olSg2<02olSg2<00ol0003o=/TfocK9=P06ocK9
=P03o`000?m8]dSoB;M800KoB;M800?o0000oi=/TonCK9<02OnCK9<01?l0003o_T6noki1__nn@Kh7
o`0000;oVVFJ00?o0000omDZeOoE:]D00ooE:]D00ol0003ol0o`oo0?l005oo0?l003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o[5>_ojaC[00SojaC[0ol00003onPGj003o`000?o1?/7o`Ck100Oo`Ck100?o0000oejQ
G_mNXEh02omNXEh00ol0003o4NhAoa7^4@0:oa7^4@03o`000?l4n`Co1?/400go1?/400?o0000o`Wf
2Ol9mPT01?l9mPT00ol0003o8m`Sob?L8`09ob?L8`03o`000?lfbCKo=/Tf00So=/Tf00?o0000odRg
B?m8]dP00om8]dP2o`0000coTfbC00?o0000oki1__nn@Kh02?nn@Kh<o`0000?ol0o`0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on/Djoo[5>/01_o[5>/3o`0000Ooj1OX00?o0000ol4n`Oo1?/401_o1?/400ol0003o
GZ5NoejQGP0;oejQGP03o`000?lAkQ7o4NhA00Wo4NhA0_l0000>o`Ck1003o`000?l9mPWo2OH900Go
2OH900?o0000ob?L8olSg2<02OlSg2<00ol0003o=/TfocK9=P09ocK9=P03o`000?m8]dSo000000;o
00000_n7N8L00ol0003oTfbCoi=/T`08oi=/T`03o`000?nn@Kko_T6n00co_T6n00?o0000on/Djoo[
5>/01_o[5>/3o`0000?oo0?l0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003ojaC[on/Dj`03on/Dj`?o00002ooX5nP00ol0003o`Ck1
ol4n`@04ol4n`@03o`000?mNXEkoGZ5N00_oGZ5N0ol00007oa7^4@?o000000?o2o@;o`000?l4n`@0
3Ol4n`@00ol0003o2OH9o`Wf2@06o`Wf2@03o`000?lSg2?o8m`S00So8m`S00?o0000ocK9=_lfbCH0
2_lfbCH00ol0003oQgR7ohMhQ`04ohMhQ`03o`000?nCK9?oTfbC00OoTfbC00?o0000oki1__nn@Kh0
2onn@Kh00ol0003ojaC[on/Dj`08on/Dj`03o`000?ol0ocoo0?l00Coo0?l0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004on/Djol0
003o0000o`0000ooj1OX00?o0000ol4n`Oo1?/400oo1?/4>o`0000?oBKI90_l00002oa7^4@?o0000
1Ol;m0/00ol0003o1?/4o`Ck100:o`Ck1003o`000?l9mPWo2OH900Oo2OH900?o0000ob?L8olSg2<0
2?lSg2<00ol0003o=/TfocK9=P0:ocK9=P03o`000?n7N8OoQgR700GoQgR700?o0000oi=/TonCK9<0
1_nCK9<00ol0003o_T6noki1_P0;oki1_P03o`000?o[5>_ojaC[00SojaC[00?o0000oo`3o?ol0o`0
1ool0o`2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;oj1OX00?o0000ol4n`Oo1?/400_o1?/400ol0003o[E:]ojeB
[@0:ojeB[@03o`000?m9]TWoBKI900?oBKI90_l00009o`_d2`03o`000?l4n`Co1?/400Wo1?/400?o
0000o`Wf2Ol9mPT02?l9mPT2o`0000So8m`S00?o0000ocK9=_lfbCH02OlfbCH00ol0003oQgR7ohMh
Q`07ohMhQ`03o`000?nCK9?oTfbC00CoTfbC00?o0000oki1__nn@Kh02onn@Kh00ol0003ojaC[on/D
j`09on/Dj`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oj1OXonPGj00?onPGj0?o000000?o`Ck1
o`000?n]DZd02on]DZd00ol0003oBKI9odVfB@04odVfB@03o`000?l;m0_o2o@;00Wo2o@;00?o0000
o`Ck1?l4n`@01ol4n`@00ol0003o2OH9o`Wf2@09o`Wf2@04o`000?lBkA;o0000o`0000Ko8m`S00?o
0000ocK9=_lfbCH02OlfbCH00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?nCK9?oTfbC00?oTfbC00?o
0000oki1__nn@Kh02onn@Kh00ol0003ojaC[on/Dj`09on/Dj`03o`000?ol0ocoo0?l00Woo0?l00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oj1OXonPGj00<onPGj0;o00000ooW6>L2o`0000co[E:]00?o0000odVfBOm9]TT01?m9]TT0
0ol0003o2o@;o`_d2`0:o`_d2`Wo00002ol9mPT00ol0003o4^dBoa;]4P02oa;]4P?o00000_lSg2<0
0ol0003o=/TfocK9=P0:ocK9=P03o`000?n7N8OoQgR700WoQgR700?o0000oi=/TonCK9<00_nCK9<0
0ol0003o_T6noki1_P0:oki1_P03o`000?o[5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oX5nP2o`0000GoiaSW00?o0000ol<l`ol000002_n]DZd00ol0003oBKI9odVfB@06odVf
B@03o`000?l;m0_o2o@;00Wo2o@;00?o0000o`3o0?l0o`001Ol0o`000ol0003o2OH9o`Wf2@09o`Wf
2@03o`000?lBkA;o4^dB00Go4^dB0ol00009ocK9=P?o00003On7N8L01Ol0003oTfbCoi=/TonCK9?o
000000co_T6n00?o0000on/Djoo[5>/02Oo[5>/00ol0003oo0?loo`3o00:oo`3o003o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onPG
j?oX5nP01OoX5nP2o`0000OoiaSW00Co0000ol<l`oo3?<?o00002On]DZd00ol0003oBKI9odVfB@06
odVfB@03o`000?l;m0_o2o@;00So2o@;00?o0000o`3o0?l0o`001ol0o`000ol0003o2OH9o`Wf2@07
o`Wf2@03o`000?lBkA;o4^dB00So4^dB0ol00002ocK9=PGo00000_mYUVT00ol0003oQgR7ohMhQ`0<
ohMhQ`03o`000?nCK9?o000000co_T6n00?o0000on/Djoo[5>/02_o[5>/00ol0003oo0?loo`3o00:
oo`3o003o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onPGj?oX5nP00_oX5nP2o`0000SoiaSW00?o0000ol<l`oo3?<<00_o3?<<5o`00
00Co[E:]00?o0000odVfBOm9]TT01_m9]TT00ol0003o2o@;o`_d2`08o`_d2`03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Wf2Ol9mPT01ol9mPT00ol0003o4^dBoa;]4P08oa;]4P03o`000?lbcC;o</db
00;o00002?mYUVT00ol0003oQgR7ohMhQ`0<ohMhQ`Co00002_nn@Kh00ol0003ojaC[on/Dj`0:on/D
j`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oj1OXo`000?l0000:onLHi`03o`000?o3?<?o`cc3
00;o`cc300?o0000ohebSOn=LXd00_n=LXd4o`0000WoBKI900?o0000o`_d2ol;m0/02?l;m0/00ol0
003o0?l0o`3o0008o`3o0003o`000?l9mPWo2OH900Go2OH900?o0000oa;]4_lBkA802?lBkA801Ol0
003o</dboc;=<_lbcC;o000000[oJIIY0ol0000;ohMhQ`04o`000?oM8]gogB;MomdRg@Co00001Onn
@Kh00ol0003ojaC[on/Dj`0;on/Dj`03o`000?ol0ocoo0?l00_oo0?l00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oiaSWonLHi`0:
onLHi`03o`000?o3?<?o`cc300?o`cc300?o0000ohebSOn=LXd01?n=LXd00ol0003oBKI9odVfB@07
odVfB@03o`000?l;m0_o2o@;00Ko2o@;0_l0000;o`3o0003o`000?l9mPWo2OH900Go2OH900?o0000
oa;]4_lBkA802?lBkA800ol0003o</dboc;=<P02oc;=<P03o`000?mYUVWoJIIY00OoJIIY00?o0000
ok=</oncC;<01?l00006ohMhQ`03o`000?oM8]gogB;M00KogB;M0ol00002oki1_P03o`000?o[5>_o
jaC[00_ojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oW6>OoiaSW00WoiaSW00?o0000ol<l
`oo3?<<01?o3?<<00ol0003oSG:=ohebS@05ohebS@03o`000?m9]TWoBKI900OoBKI900?o0000o`_d
2ol;m0/00_l;m0/3o`000003oa[U6_l0003o0?l000[o0?l000?o0000o`Wf2Ol9mPT01Ol9mPT00ol0
003o4^dBoa;]4P07oa;]4P03o`000?lbcC;o</db00?o</db00?o0000ofVFJOmYUVT01omYUVT00ol0
003o/dbcok=</`04ok=</`?o00000_n7N8L00ol0003ogB;MomdRg@0:omdRg@;o00003_o[5>/00ol0
003oo0?loo`3o00;oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onLHiooW6>L02OoW6>L00ol0003o`cc3ol<l``04ol<l``03
o`000?n=LXgoSG:=00KoSG:=0_l00007odVfB@03o`000?l;m0_o000000;o00001OlJiAX00ol0003o
0?l0o`3o0008o`3o00?o00001?l9mPT00ol0003o4^dBoa;]4P08oa;]4P03o`000?lbcC;o</db00Co
</db00?o0000ofVFJOmYUVT01_mYUVT00ol0003o/dbcok=</`07ok=</`;o00003_oM8]d00ol0003o
jaC[on/Dj`0;on/Dj`03o`000?ol0ocoo0?l00coo0?l00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiaSWonLHi`08onLHi`03o`00
0?o3?<?o`cc300Go`cc300?o0000ohebSOn=LXd01?n=LXd00ol0003oPgb3oh=lP`03o`0000CoBKI9
0_l00008oa[U6P03o`000?l0o`3o0?l000Oo0?l000Co0000ob[E:_lZeB[o:]DZ0ol000000ol9mPWo
0000oa;]4P09oa;]4P03o`000?lbcC;o</db00Co</db00?o0000ofVFJOmYUVT01OmYUVT00ol0003o
/dbcok=</`09ok=</`03o`000?oM8]gogB;M00gogB;M00?o0000on/Djoo[5>/02_o[5>/00ol0003o
o0?loo`3o00<oo`3o003o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onLHiooW6>L01ooW6>L00ol0003o`cc3ol<l``06ol<l``03o`00
0?n=LXgoSG:=00?oSG:=00?o0000oh=lPon3O8<01?n3O8<2o`000003odVfBOl0003o6^DJ00[o6^DJ
00?o0000o`3o0?l0o`001Ol0o`000ol0003o:]DZob[E:P05ob[E:P03o`000?lBkA;o4^dB00Oo4^dB
0ol00007oc;=<P03o`000?mYUVWoJIIY00CoJIIY00?o0000ok=</oncC;<02OncC;<00ol0003ogB;M
omdRg@0=omdRg@03o`000?o[5>_ojaC[00[ojaC[00?o0000oo`3o?ol0o`02ool0o`00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oW
6>OoiaSW00GoiaSW0ol00009ol<l``05o`000?n=LXgoSG:=ohebSOl000002On3O8<00ol0003o6^DJ
oa[U6P0;oa[U6P03o`000?l0o`3o0?l000?o0?l000?o0000ob[E:_lZeBX01_lZeBX00ol0003o4^dB
oa;]4P06oa;]4P05o`000?lfbCKo=/TfocK9=_l000001olbcC800ol0003oJIIYofVFJ@03ofVFJ@03
o`000?ncC;?o/dbc00Wo/dbc00?o0000omdRgOoM8]d03_oM8]d00ol0003ojaC[on/Dj`09on/Dj`03
o`000?ol0ocoo0?l00[oo0?l00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003oiaSWo`000004o`0000;oka3_00?o0000ol<l`oo3?<<0
1oo3?<<01?l0003oSG:=ohebSOl00009oh=lP`;o00003OlJiAX00ol0003o0?l0o`3o0002o`3o0003
o`000?lZeB[o:]DZ00So:]DZ00?o0000oa;]4_lBkA800olBkA82o`0000Go=/Tf00?o0000oc;=<_lb
cC801?lbcC800ol0003oJIIYofVFJ@03ofVFJ@03o`000?ncC;?o/dbc00Wo/dbc00?o0000omdRgOoM
8]d03_oM8]d00ol0003ojaC[on/Dj`09on/Dj`03o`000?ol0ocoo0?l00Woo0?l00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Soka3_
00?o0000ol<l`oo3?<<01_o3?<<00ol0003oSG:=o`000009oh=lP`04o`000?mJYE[oFZEJo`0000go
6^DJ00Co0000o`3o0?l0o`3o00003?lZeBX01Ol0003o4^dBoa;]4_lBkA;o000000So=/Tf0_l00005
oc;=<P03o`000?mYUVWoJIIY00;oJIIY00?o0000ok=</oncC;<02OncC;<00ol0003ogB;MomdRg@0>
omdRg@03o`000?o[5>_ojaC[00WojaC[00?o0000oo`3o?ol0o`02Ool0o`00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o_4>ooka3_
00Ooka3_00?o0000ol<l`oo3?<<01oo3?<<00ol0003oPgb3oh=lP`07oh=lP`03o`000?mJYE[oFZEJ
00;oFZEJ00?o0000oa[U6_lJiAX02_lJiAX00ol0003o0?l0o`00000>ob[E:P03o`000?lBkA;o0000
00_o=/Tf00?o0000oc;=<_lbcC800_lbcC801Ol0003oJIIYofVFJOmYUVWo000000co/dbc00?o0000
omdRgOoM8]d03_oM8]d3o`0000WojaC[00?o0000oo`3o?ol0o`02?ol0o`00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o_4>ooka3_
00Woka3_00?o0000ol<l`oo3?<<01_o3?<<00ol0003oPgb3oh=lP`06oh=lP`03o`000?mJYE[oFZEJ
00?oFZEJ00?o0000oa[U6_lJiAX02olJiAX00ol0003o:]DZob[E:P0>ob[E:P03o`000?lfbCKo=/Tf
00_o=/Tf0_l00003oc;=<P04o`000?mYUVWoJIIYo`0000[o/dbc0ol0000>omdRg@;o00000ool0o`2
o`0000OojaC[00?o0000oo`3o?ol0o`01ool0o`00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o_4>ooka3_00[oka3_00?o0000ol<l
`oo3?<<01?o3?<<00ol0003oPgb3oh=lP`06oh=lP`03o`000?mJYE[oFZEJ00GoFZEJ00?o0000oa[U
6_lJiAX01olJiAX3o`00017o:]DZ00?o0000ocK9=_lfbCH03OlfbCH01Ol0003o</dboc;=<_l0003o
JIIY00Co00000oncC;<5o`0000;ojAKY00?o0000omdRgOoM8]d02_oM8]d2o`0000Ooo0?l0_l00004
on/Dj`03o`000?ol0ocoo0?l00Soo0?l00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oka3_onl@k`0;onl@k`03o`000?o3?<?o`cc3
00Co`cc300?o0000oh=lPon3O8<01On3O8<00ol0003oFZEJoeZUFP06oeZUFP03o`000?lJiA[o6^DJ
00Co6^DJ0ol00002ob3O8003o`000?lZeB[o:]DZ00oo:]DZ0_l0000?ocK9=P04o`000?lbcC;o0000
o`0000CoWf2O0ol00008onTFj@03o`000?oM8]gogB;M00OogB;M0_l0000;oo`3o0;o00000_o[5>/0
0ol0003oo0?loo`3o007oo`3o003o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000onl@koo_4>l03?o_4>l6o`0000OoPgb300?o0000oeZU
F_mJYEX02?mJYEX00ol0003o6^DJoa[U6P03o`0000Ko8=lP00?o0000ob[E:_lZeBX03OlZeBX01?l0
003o@;m0od2o@?l0000?ocK9=P03o`000?nOH9ooWf2O00GoWf2O00?o0000onTFjOoY5^T02?oY5^T0
0ol0003ogB;MomdRg@05omdRg@03o`000?ol0ocoo0?l00goo0?l0ol00008oo`3o003o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o_4>l00ol0003obCK9olTfb@04olTf
b@03o`000?n3O8?oPgb300?oPgb300?o0000oeZUF_mJYEX02_mJYEX2o`0000[o8=lP00?o0000ob[E
:_lZeBX02olZeBX00ol0003o@;m0od2o@002od2o@003o`000?lfbCKo=/Tf00_o=/Tf0_l00007oimP
W`03o`000?oY5^WojAKY00WojAKY00?o0000omdRgOoM8]d00_oM8]d2o`0001;oo0?l00?o0000oo`3
o?ol0o`00ool0o`3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000onl@koo_4>l02oo_4>l00ol0003obCK9olTfb@06olTfb@05o`000?n3O8?oPgb3oh=l
Pol000003OmJYEX00ol0003o8=lPob3O800:ob3O8003o`000?lZeB[o:]DZ00Wo:]DZ00?o0000od2o
@?m0_d001?m0_d000ol0003o=/TfocK9=P08ocK9=P;o000000?oE:]Do`000?nOH9l01onOH9l00ol0
003ojAKYonTFj@09onTFj@04o`000?oM8]go0000o`0001Coo0?l00?o0000oo`3o?ol0o`00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?o_4>ooka3_
00Woka3_00?o0000olTfbOo9=/T02?o9=/T00ol0003oPgb3o`00000=oeZUFP03o`000?lPgb3o8=lP
00_o8=lP00?o0000ob[E:_lZeBX02?lZeBX00ol0003o@;m0od2o@006od2o@003o`000?lfbCKo=/Tf
00Go=/Tf0_l00003oeB[E003o`000?nOH9ooWf2O00KoWf2O00?o0000onTFjOoY5^T02_oY5^T00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003oka3_onl@k`07onl@k`03o`000?o9=/WobCK900[obCK900?o0000oeZUF_mJ
YEX03?mJYEX00ol0003o8=lPob3O800<ob3O8003o`000?lZeB[o:]DZ00Ko:]DZ00?o0000od2o@?m0
_d002?m0_d000ol0003o=/TfocK9=P02ocK9=P;o00001_mDZe@00ol0003oWf2OoimPW`05oimPW`03
o`000?oY5^WojAKY00[ojAKY00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?o_4>ooka3_00Goka3_
00?o0000olTfbOo9=/T03?o9=/T2o`0000coFZEJ00?o0000ob3O8?lPgb003OlPgb000ol0003o:]DZ
ob[E:P04ob[E:P03o`000?m0_d3o@;m000[o@;m000Co0000ocK9=_l0003o00002?mDZe@00ol0003o
Wf2OoimPW`06oimPW`03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_o_4>l00ol0003obCK9olTfb@0=olTfb@03o`000?n1OX7o000000;o00002?mJYEX00ol0003o8=lP
ob3O800?ob3O80Ko00003_m0_d000ol0003oE:]DoeB[E008oeB[E003o`000?nOH9ooWf2O00KoWf2O
00?o0000onTFjOoY5^T02OoY5^T00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo4>lOoa3_7ol@ka
0_l0000?olTfb@03o`000?n1OX7oPGj100?oPGj10ol00005oeZUFP;o00004?lPgb001_l0003o6NHI
oaWV6Ol0003o3o0?o`0000ko@;m000?o0000oeB[E?mDZe@02OmDZe@00ol0003oWf2OoimPW`05oimP
W`03o`000?oY5^WojAKY00WojAKY00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo4>lOoa3_400ooa3_400ol0003o
bCK9olTfb@0=olTfb@03o`000?n1OX7oPGj100KoPGj10ol000001?mJYE[o0000oc?<<olcc3<3o`00
00co8=lP00Go0000oaWV6OlIiQWo6NHIo`000002o`o`3`03o`000?m0_d3o@;m000_o@;m000?o0000
oeB[E?mDZe@02OmDZe@00ol0003oWf2OoimPW`06oimPW`03o`000?oY5^WojAKY00SojAKY0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003ol@kaoo4>l@04oo4>l@oo00003?n1OX400ol0003o<l`coc?<<`04oc?<
<`?o00002?lPgb000ol0003o6NHIoaWV6@02oaWV6@05o`000?l?l0oo3o0?o`o`3ol000003?m0_d00
0ol0003oE:]DoeB[E009oeB[E003o`000?nOH9ooWf2O00GoWf2O3?l00002ooH9mP;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003ol@kaoo4>l@05oo4>l@03o`000?o;=<_obcC;00_obcC;00?o0000oh5n
POn1OX402_n1OX400ol0003o<l`coc?<<`07oc?<<`;o00001OlPgb000ol0003o6NHIoaWV6@03oaWV
6@03o`000?l?l0oo3o0?00;o3o0?00?o0000od2o@?m0_d002Om0_d000ol0003oE:]DoeB[E00:oeB[
E003o`000?nOH9ooWf2O00?oWf2O00?o0000on4NhOoQ7^402OoQ7^400ol0003omPWfooH9mP02ooH9
mP;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol@kaoo4>l@06oo4>l@03o`000?o;=<_obcC;00[o
bcC;00?o0000oh5nPOn1OX402on1OX400ol0003o<l`coc?<<`09oc?<<`?o000000?o8=lPo`000?lI
iQT01OlIiQT00ol0003o3o0?o`o`3`03o`o`3`03o`000?m0_d3o@;m000So@;m03_l00003oimPW`;o
00002ooQ7^400ol0003omPWfooH9mP05ooH9mP03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo4>lOoa3_401Ooa3_400ol0003oeB[Eo`00000;ol/db`03o`000?n1OX7oPGj100[oPGj1
0_l0000>oc?<<`03o`000?lIiQWo6NHI00Go6NHI00?o0000o`o`3ol?l0l00ol?l0l00ol0003o@;m0
od2o@008od2o@003o`000?nKI9_oVfBK00_oVfBK00?o0000oimPWol000003OoQ7^400ol0003omPWf
ooH9mP06ooH9mP;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00Kol@ka00Co
0000omDZeOoE:]Go00002_o;=</00ol0003oPGj1oh5nP@09oh5nP@03o`000?mIYUWo000000ko<l`c
00?o0000oaWV6OlIiQT01OlIiQT00ol0003o3o0?o`o`3`04o`o`3`03o`000?m0_d3o@;m000Ko@;m0
00?o0000oi]TVonKI9/03OnKI9/00ol0003ohAkQon4Nh@0<on4Nh@03o`000?of2OKomPWf00SomPWf
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oa3_7ol@ka00Gol@ka00?o0000omDZeOoE:]D00_oE
:]D00ol0003obcC;ol/db`06ol/db`03o`000?n1OX7oPGj100SoPGj10_l00003oeVVF@03o`000?lc
c3?o<l`c00_o<l`c00?o0000oaWV6OlIiQT01OlIiQT00ol0003o3o0?o`o`3`05o`o`3`03o`000?m0
_d3o@;m000Go@;m000?o0000oi]TVonKI9/03OnKI9/00ol0003ohAkQon4Nh@0;on4Nh@03o`000?of
2OKomPWf00WomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?oa3_7ol@ka00Kol@ka00?o0000
omDZeOoE:]D00ooE:]D00ol0003obcC;ol/db`05ol/db`03o`000?n1OX7oPGj100OoPGj100?o0000
oeVVFOmIYUT00omIYUT00ol0003o<l`coc?<<`0:oc?<<`03o`000?lIiQWo6NHI00Ko6NHI00?o0000
o`o`3ol?l0l01_l?l0l00ol0003o@;m0od2o@004od2o@003o`000?nKI9_oVfBK00goVfBK3ol0000;
ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?oa3_7ol@ka00Kol@ka00?o0000omDZeOoE:]D01OoE:]D00ol0
003obcC;ol/db`04ol/db`03o`000?n1OX7oPGj100GoPGj10_l00006oeVVF@03o`000?lcc3?o<l`c
00Wo<l`c0_l00008oaWV6@03o`000?l?l0oo3o0?00Ko3o0?1Ol000000om0_d3o0000oi]TV`0?oi]T
V`03o`000?oS7>?ohacS00_ohacS00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?oa3_7ol@ka00Kol@ka00?o0000omDZeOoE:]D01_oE:]D00ol0003o
bcC;ol/db`04o`0000KoPGj100?o0000oeVVFOmIYUT01omIYUT00ol0003o<l`coc?<<`05oc?<<`?o
000000?o8m`So`000?lIiQT01olIiQT00ol0003o3o0?o`o`3`05o`o`3`03o`000?mA[U7oDJiA00?o
DJiA0_l0000?oi]TV`;o00003OoS7><00ol0003omPWfooH9mP08ooH9mP03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wol@ka00?o0000omDZeOoE:]D01ooE:]D2o`0000Co[U6^00Co0000oh5nPOn1OX7o
PGj10_l0000:oeVVF@03o`000?lcc3?o<l`c00;o<l`c0ol00005ob?L8`03o`000?lIiQWo6NHI00Go
6NHI00?o0000o`o`3ol?l0l01?l?l0l00ol0003oDJiAoe6^D@06oe6^D@03o`000?nKI9_oVfBK00[o
VfBK0_l00002olDja@03o`000?oS7>?ohacS00[ohacS00?o0000ooH9m_of2OH02?of2OH00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo4>lOoa3_401_oa3_400ol0003oeB[EomDZe@08omDZe@03o`00
0?n^DJko[U6^00Co[U6^00?o0000oh5nPOl000003?mIYUT00ol0003o<l`co`000002o`0000Wo8m`S
00?o0000oaWV6OlIiQT01?lIiQT00ol0003o3o0?o`o`3`03o`o`3`03o`000?mA[U7oDJiA00SoDJiA
1_l00004oi]TV`;o00001Oo5>/D00ol0003ohacSon<Lh`09on<Lh`03o`000?of2OKomPWf00SomPWf
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oa3_7ol@ka00Gol@ka00?o0000omDZeOoE:]D01ooE
:]D00ol0003o[U6^ojiA[P06ojiA[P03o`000?mIYUWoFJII00coFJII00?o0000ob?L8olSg2<02_lS
g2<00ol0003o6NHIoaWV6@04oaWV6@04o`000?l?l0oo3o0?o`o`3`;o00002omA[U400ol0003oXEjQ
oj5NX@03oj5NX@Co00002?o5>/D00ol0003ohacSon<Lh`08on<Lh`03o`000?of2OKomPWf00OomPWf
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo4>lOoa3_400ooa3_400ol0003oeB[EomDZe@07omDZe@03o`000?n^
DJko[U6^00Oo[U6^00?o0000oeVVFOmIYUT03?mIYUT00ol0003o8m`Sob?L8`0;ob?L8`03o`000?lI
iQWo6NHI00?o6NHI00Co0000o`o`3ol?l0oo00003OmA[U400ol0003oXEjQoj5NX@06oj5NX@03o`00
0?o5>/GoaC[500OoaC[500?o0000on<LhooS7><01ooS7><00ol0003omPWfooH9mP06ooH9mP04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa3_7ol@ka00;ol@ka00?o0000omDZeOoE:]D0
1_oE:]D00ol0003o[U6^ojiA[P09ojiA[P03o`000?mIYUWoFJII00WoFJII0_l0000>ob?L8`?o0000
0olIiQT00ol0003o3o0?o`00000=oe6^D@03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000olDjaOo5>/D0
2?o5>/D:o`0000KomPWf0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OoeB[E00?o
0000ojiA[_n^DJh02_n^DJh00ol0003oFJIIoeVVF@06oeVVF@;o000000?oDJiAo`000?lSg2<02olS
g2<2o`0000?o?/4n1Ol0000>oe6^D@03o`000?nQGZ7oXEjQ00OoXEjQ00?o0000olDjaOo5>/D02?o5
>/D00ol0003ojQGZonXEjP06onXEjP03o`000?of2OKomPWf00?omPWf00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003oj1OXonPGj003onPGj0Co00000_oE:]D00ol0003o[U6^ojiA[P0;
ojiA[P03o`000?mIYUWoFJII00?oFJII0ol00004oe6^D@03o`000?lSg2?o8m`S00Oo8m`S0_l00008
ock1?P03o`000?mA[U7oDJiA00goDJiA00?o0000oj5NXOnQGZ402?nQGZ400ol0003oaC[5olDja@07
olDja@03o`000?oZ5N[ojQGZ00OojQGZ0ol000000oof2OKo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?oX5nSoj1OX00Ooj1OX0_l0000?ojiA[P03o`000?mIYUWoFJII00;o00002?mA[U400ol0
003o8m`Sob?L8`05ob?L8`03o`000?ln`Cko?/4n00So?/4n00?o0000oe6^DOmA[U403OmA[U400ol0
003oXEjQoj5NX@08oj5NX@03o`000?o5>/GoaC[500KoaC[500?o0000onXEj_oZ5NX02?oZ5NX01?l0
003om`SgooL8mol0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003oj1OXonPGj009onPG
j003o`000?n^DJko[U6^00ko[U6^0_l0000;oe6^D@03o`000?lSg2?o8m`S00;o8m`S0_l0000;ock1
?P03o`000?mA[U7oDJiA00goDJiA00?o0000oj5NXOnQGZ402?nQGZ400ol0003oaC[5olDja@06olDj
a@03o`000?oZ5N[ojQGZ00OojQGZ00Go0000ooL8moog2?Oom`Sgo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003oj1OXonPGj00:onPGj003o`000?n^DJko[U6^00go[U6^0_l0000<oe6^D@04o`000?lSg2?o0000
o`0000go?/4n00?o0000oe6^DOmA[U403?mA[U400ol0003oXEjQoj5NX@09oj5NX@03o`000?o5>/Go
aC[500KoaC[500?o0000onXEj_oZ5NX01_oZ5NX00ol0003om`SgooL8m`03ooL8m`03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003oj1OXonPGj00:onPGj003o`000?n^DJko[U6^00co[U6^00Co0000oiYU
V_nJII[o00003?mA[U400ol0003o?/4nock1?P0>ock1?P03o`000?mA[U7oDJiA00SoDJiA1?l0000;
oj5NX@03o`000?o5>/GoaC[500KoaC[500?o0000onXEj_oZ5NX01OoZ5NX00ol0003om`SgooL8m`04
ooL8m`03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003oj1OXonPGj00;onPGj003o`000?n^DJko[U6^
00_o[U6^00?o0000oiYUV_nJIIX00_nJIIX00ol0003oDJiAoe6^D@09oe6^D@03o`000?ln`Cko?/4n
00ko?/4n00Co0000oe6^DOmA[U7oDJiA1ol00003ofjAKP03o`000?nQGZ7oXEjQ00WoXEjQ00?o0000
olDjaOo5>/D01_o5>/D00ol0003ojQGZonXEjP04onXEjP03o`000?og2?Oom`Sg00Kom`Sg00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oX5nSoj1OX00coj1OX00?o0000ojiA[_n^DJh02_n^DJh00ol0
003oVVFJoiYUVP03oiYUVP03o`000?mA[U7oDJiA00SoDJiA00?o0000ock1?_ln`Ch03_ln`Ch4o`00
00_oKY5^00?o0000oj5NXOnQGZ402?nQGZ400ol0003oaC[5olDja@05olDja@03o`000?oZ5N[ojQGZ
00GojQGZ00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onPGj?oX
5nP03?oX5nP7o`0000Go[U6^00?o0000oiYUV_nJIIX01OnJIIX00ol0003oDJiAoe6^D@07oe6^D@03
o`000?ln`Cko?/4n00ko?/4n00?o0000ofjAK_m^TFh03Om^TFh00ol0003oXEjQoj5NX@08oj5NX@03
o`000?o5>/GoaC[500CoaC[500?o0000onXEj_oZ5NX01?oZ5NX00ol0003om`SgooL8m`07ooL8m`03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003oj1OXonPGj00=onPGj003o`000?o<<lcoc3?<00Coc3?<
1Ol00009oiYUVP03o`000?mA[U7oDJiA00KoDJiA00?o0000ock1?_ln`Ch03_ln`Ch00ol0003oKY5^
ofjAKP0=ofjAKP03o`000?nQGZ7oXEjQ00SoXEjQ00Co0000olDjaOo5>/GoaC[51Ol00004onXEjP03
o`000?og2?Oom`Sg00Wom`Sg1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onPGj003o`000?o<<lcoc3?<00Woc3?<
0_l00009oiYUVP03o`000?mA[U7oDJiA00KoDJiA00?o0000ock1?_ln`Ch03?ln`Ch00ol0003oKY5^
ofjAKP0?ofjAKPKo00001?nQGZ44o`0000Goi1_T0_l000000ooZ5N[o0000ooL8m`0;ooL8m`04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?oc3??ol`ccoo<<l`?o00002_oX5nP00ol0003o
c3?<ol`cc009ol`cc003o`000?n/Djco000000;o00001onJIIX00ol0003oDJiAoe6^D@05oe6^D@03
o`000?ln`Cko?/4n00So?/4n1Ol0000AofjAKP03o`000?n`Ck3o/4n`00?o/4n`1?l0000;on@Ki003
o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000oo<<looc3?<01Ooc3?<2o`0000Ooj1OX
00?o0000ol`cc?o<<l`02_o<<l`00ol0003o[5>/ojaC[002ojaC[0?o00001OnJIIX00ol0003oDJiA
oe6^D@04oe6^D@04o`000?ln`Cko?/4nock1?POo00001?mPWf000ol0003oKY5^ofjAKP0>ofjAKP03
o`000?n`Ck3o/4n`00Oo/4n`00?o0000on@Ki?oT6n@02OoT6n@00ol0003om`SgooL8m`09ooL8m`03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`08oo<<l`;o00001?oX5nP00ol0003oc3?<
ol`cc00;ol`cc003o`000?n/Djco[5>/00Go[5>/0ol00003oiYUVP04o`000?mA[U7oDJiAoe6^D@Ko
00003?mPWf000ol0003oKY5^ofjAKP0=ofjAKP03o`000?n`Ck3o/4n`00Oo/4n`00?o0000on@Ki?oT
6n@02_oT6n@00ol0003om`SgooL8m`08ooL8m`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo<<l`?o000000?oj1OXo`000?o<<l`0
3?o<<l`00ol0003o[5>/ojaC[008ojaC[0?o000000CoVVFJo`000?l0003o00000_nSG:<00ol0003o
H9mPof2OH00=of2OH003o`000?m^TFkoKY5^00coKY5^00?o0000ok1?/?n`Ck002?n`Ck000ol0003o
i1_Ton@Ki00;on@Ki003o`000?og2?Oom`Sg00Kom`Sg00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
l`cc00?o0000ol`cc?o<<l`03?o<<l`00ol0003o[5>/ojaC[00;ojaC[003o`000?nSG:?oXebS00?o
XebS00?o0000of2OH?mPWf003?mPWf000ol0003oK9=/o`00000=ofjAKP03o`000?n`Ck3o/4n`00So
/4n`00?o0000on@Ki?oT6n@03?oT6n@3o`0000Gom`Sg00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oc3??ol`cc00col`cc00?o0000ol`cc?o<<l`03?o<<l`00ol0003o[5>/ojaC[00:ojaC[003o`00
0?nSG:?oXebS00GoXebS00?o0000of2OH?mPWf002_mPWf001?l0003oK9=/ofbCK?m/Tf`2o`0000[o
KY5^00?o0000ok1?/?n`Ck002On`Ck000ol0003oi1_Ton@Ki00<on@Ki003o`000?oh1oSon0Oh00?o
000000?om`Sgo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?oc3??ol`cc00_ol`cc00?o0000ol`cc?o<<l`0
3?o<<l`00ol0003o[5>/ojaC[009ojaC[003o`000?nSG:?oXebS00KoXebS00?o0000of2OH?mPWf00
2OmPWf000ol0003oK9=/ofbCK002ofbCK003o`000?nTFjCo000000;o00001om^TFh00ol0003o/4n`
ok1?/009ok1?/003o`000?oT6nCoi1_T00_oi1_T00?o0000ooP7n?oh1oP01?oh1oP00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo<<looc3?<02ooc3?<00ol0003oc3?<ol`cc00;ol`cc003o`000?n/
Djco[5>/00So[5>/00?o0000oj=LXonSG:<01onSG:<00ol0003oH9mPof2OH008of2OH003o`000?m/
TfcoK9=/00?oK9=/00?o0000ojAKY?nTFj@00_nTFj@2o`0000CoKY5^00?o0000ok1?/?n`Ck002_n`
Ck000ol0003oi1_Ton@Ki00:on@Ki003o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?oc3??ol`cc00[ol`cc0ol0000;ol`cc0Ko00001?n/Dj`00ol0003oXebSoj=LX`08
oj=LX`03o`000?mPWf3oH9mP00OoH9mP00?o0000ofbCK?m/Tf`00om/Tf`00ol0003oY5^TojAKY005
ojAKY0?o000000?oKY5^o`000?n`Ck002on`Ck000ol0003oi1_Ton@Ki009on@Ki003o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?oc3??ol`cc00Wol`cc00?o0000onHI
i_oV6NH01?l00006ol`cc003o`000?o<<lcoc3?<00Coc3?<1?l0000<oj=LX`03o`000?mPWf3oH9mP
00GoH9mP00?o0000ofbCK?m/Tf`01?m/Tf`00ol0003oY5^TojAKY008ojAKY003o`000?n`Ck3o/4n`
00_o/4n`00?o0000on@Ki?oT6n@02?oT6n@00ol0003on0OhooP7n008ooP7n0Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?oc3??ol`cc00Ool`cc00?o0000onHIi_oV6NH01OoV6NH3o`0000;oc3?<00?o0000ol`cc?o<
<l`02?o<<l`00ol0003oXebSoj=LX`0:oj=LX`03o`000?mPWf3oH9mP00CoH9mP00?o0000ofbCK?m/
Tf`01Om/Tf`00ol0003oY5^TojAKY008ojAKY003o`000?n`Ck3o/4n`00Wo/4n`1?l00008on@Ki003
o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ol`cc
oo<<l`05oo<<l`03o`000?oV6NKoiQWV00WoiQWV0_l0000<ol`cc003o`000?nSG:?oXebS00WoXebS
00?o0000of2OH?mPWf000omPWf000ol0003oK9=/ofbCK005ofbCK003o`000?nTFjCoY5^T00[oY5^T
00?o0000ok1?/?n`Ck001?n`Ck04o`0000CogB;M00?o0000on@Ki?oT6n@01?oT6n@00ol0003on0Oh
ooP7n00:ooP7n003o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000onHIi_oV6NH02ooV
6NH00ol0003oc3?<ol`cc00:ol`cc003o`000?nSG:?oXebS00WoXebS00?o0000of2OH?mPWf000_mP
Wf000ol0003oK9=/ofbCK006ofbCK003o`000?nTFjCoY5^T00[oY5^T00?o0000ok1?/?n`Ck001?l0
0009omdRg@Ko00003?oh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo<<looc3??ol`cc0_l0
000=onHIiP03o`000?o<<lcoc3?<00[oc3?<00?o0000oj=LXonSG:<02OnSG:<01Ol0003oH9mPof2O
H?mPWf3o000000WoK9=/00?o0000ojAKY?nTFj@02onTFj@2o`0000gogB;M00?o0000ooH9m_of2OH0
0_of2OH00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol`cco`00
0002ooX5nP;o00002ooV6NH00ol0003oc3?<ol`cc00;ol`cc003o`000?nSG:?oXebS00WoXebS00?o
0000of2OH?l000002Om/Tf`00ol0003oY5^TojAKY00<ojAKY003o`000?oM8]gogB;M00cogB;M00?o
0000ooH9m_of2OH00oof2OH00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003onPGjooX5nP03ooX5nP;o00002_oV6NH00ol0003oc3?<ol`cc00:ol`cc003o`000?nSG:?o
XebS00SoXebS1Ol00008ofbCK003o`000?nTFjCoY5^T00coY5^T00?o0000omdRgOoM8]d02ooM8]d0
0ol0003omPWfooH9mP05ooH9mP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooj1OX2o`0000SoiQWV00?o0000ol`cc?o<<l`02_o<<l`00ol0003oXebSoj=LX`07oj=L
X`03o`000?nVFJKoYUVV00?oYUVV0ol00005ofbCK003o`000?nTFjCoY5^T00_oY5^T00?o0000omdR
gOoM8]d03?oM8]d00ol0003omPWfooH9mP06ooH9mP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000WonPGj00?o0000onHIi_oV6NH01OoV6NH2o`0000co
c3?<00?o0000oj=LXonSG:<01OnSG:<00ol0003oYUVVojIIYP07ojIIYP?o000000?oK9=/o`000?nT
Fj@03OnTFj@00ol0003ogB;MomdRg@0<omdRg@03o`000?of2OKomPWf00KomPWf00?o0000ooP7n?oh
1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?oj1O[onPGj00OonPGj
0_l00004onHIiP03o`000?o]4^gokA;]00;o00002_o<<l`00ol0003oXebSoj=LX`03oj=LX`;o0000
3OnVFJH2o`0000goY5^T0ol0000=omdRg@03o`000?of2OKomPWf00OomPWf00?o0000ooP7n?oh1oP0
1Ooh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00SonPGj0_l0
00000ooV6NKo0000ondBk@04ondBk@03o`000?o<<lcoc3?<00Ooc3?<00Co0000oj=LXonSG:?oXebS
0_l00002oll`c`03o`000?nVFJKoYUVV00coYUVV3Ol00003omdRg@03o`000?oM8]gogB;M00[ogB;M
00?o0000ooH9m_of2OH02?of2OH01?l0003on0OhooP7n?oh1oP4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003onPGj
ooX5nP09ooX5nP03o`000?o]4^gokA;]00GokA;]0_l00008ol`cc003o`000?nSG:?o000000Gocc3?
00?o0000ojIIY_nVFJH02onVFJH00ol0003o]4^dokA;]009okA;]003o`000?oM8]gogB;M00;ogB;M
0_l00009omdRg@03o`000?of2OKomPWf00[omPWf0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000ondBkOo]4^d01oo]4^d4o`0000?oc3?<0ol0
0007oll`c`03o`000?nVFJKoYUVV00[oYUVV00?o0000okA;]?ndBk@02OndBk@00ol0003ogB;MomdR
g@04omdRg@;o00001ooM8]d00ol0003omPWfooH9mP0:ooH9mP03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000ondBkOo]4^d02?o]4^d0
1?l0003ok1?/on`Ck?o/4n`3o`0000;ohQgR00?o0000oll`coo?<<l01_o?<<l00ol0003oYUVVojII
YP08ojIIYP03o`000?ndBkCo]4^d00[o]4^d00?o0000omdRgOoM8]d01_oM8]d00ol0003ogB;MomdR
g@04omdRg@03o`000?of2OKomPWf00WomPWf00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003okA;]ondBk@08ondBk@03o`000?o/4nco
k1?/00Cok1?/00Go0000on8Mh_oR7N;ohQgRo`000008oll`c`03o`000?nVFJKoYUVV00OoYUVV00?o
0000okA;]?ndBk@02_ndBk@00ol0003ogB;MomdRg@07omdRg@;o00001?oM8]d00ol0003omPWfooH9
mP08ooH9mP03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003okA;]ondBk@08ondBk@03o`000?o/4ncok1?/00Cok1?/00?o0000on8Mh_oR7N800_oR7N80
0ol0003occ3?oll`c`07oll`c`03o`000?nVFJKoYUVV00KoYUVV00?o0000okA;]?ndBk@02_ndBk@0
0ol0003ogB;MomdRg@09omdRg@05o`000?oM8]gogB;MomdRgOl000002Oof2OH00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_okA;]00?o0000on`Ck?o/4n`01?o/4n`00ol0003ohQgRon8MhP03
on8MhP03o`000?o?<<oocc3?00Oocc3?00?o0000ojIIY_nVFJH01OnVFJH00ol0003o]4^dokA;]00:
okA;]003o`000?oM8]gogB;M00WogB;M1?l00009ooH9mP03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?oj1O[onPGj
ooX5n_l000002_o]4^d00ol0003ok1?/on`Ck005on`Ck003o`000?oR7N;ohQgR00?ohQgR00?o0000
oll`coo?<<l02?o?<<l00ol0003oYUVVojIIYP04ojIIYP03o`000?ndBkCo]4^d00Wo]4^d00?o0000
omdRgOoM8]d02?oM8]d2o`0000?omPWf00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003okA;]ondBk@06ondBk@03o`000?o/4ncok1?/
00Gok1?/00?o0000on8Mh_oR7N801?oR7N800ol0003occ3?oll`c`09oll`c`03o`000?nVFJKoYUVV
00;oYUVV00?o0000okA;]?ndBk@02_ndBk@00ol0003ogB;MomdRg@06omdRg@;o00001_of2OH8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o]4^gokA;]00GokA;]00?o0000on`Ck?o/
4n`01Oo/4n`00ol0003ohQgRon8MhP05on8MhP03o`000?o?<<oocc3?00Wocc3?00Go0000ojIIY_nV
FJKoYUVVo`00000<okA;]003o`000?oM8]gogB;M00CogB;M0_l00008ooH9mP03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000ondBkOo]
4^d00oo]4^d00ol0003ok1?/on`Ck006on`Ck003o`000?oR7N;ohQgR00GohQgR00?o0000oll`coo?
<<l02_o?<<l00ol0003oYUVVo`000004o`0000Wo]4^d00?o0000omdRgOoM8]d00_oM8]d2o`0000[o
mPWf00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP07ooX5nP03o`00
0?o]4^gokA;]00;okA;]00?o0000on`Ck?o/4n`01_o/4n`00ol0003ohQgRon8MhP07on8MhP;o0000
2oo?<<l00ol0003oiA[UonDJi@03onDJi@Oo00000_ndBk@00ol0003ogB;MomdRg@02o`0000_omPWf
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooX5n_oj1OX02Ooj
1OX01Ol0003okA;]ondBkOo]4^go000000Sok1?/00?o0000on8Mh_oR7N801ooR7N800ol0003ol@ka
o`000002o`0000Socc3?00?o0000onDJiOoU6^D02_oU6^D5o`0000gomPWf00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<ooX5nP03o`000?o]4^go000000Wok1?/00?o
0000on8Mh_oR7N801_oR7N800ol0003ol@kaoo4>l@03oo4>l@?o00001?o?<<l00ol0003oiA[UonDJ
i@0=onDJi@03o`000?of2OKomPWf00gomPWf00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_onPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003ohQgRon8MhP07
on8MhP03o`000?oa3_7ol@ka00Kol@ka0ol000000oo?<<oo0000onDJi@0>onDJi@03o`000?of2OKo
mPWf00comPWf00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooX5
nP03o`000?o/4ncok1?/00;ok1?/1_l00008on8MhP03o`000?oa3_7ol@ka00[ol@ka00?o0000onDJ
iOoU6^D03ooU6^D00ol0003omPWfooH9mP0:ooH9mP;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooX5nPGo00001_of2OH00ol0003ohQgRon8MhP05on8MhP03o`000?oa3_7ol@ka00[o
l@ka00?o0000onDJiOoU6^D03ooU6^D00ol0003omPWfooH9mP07ooH9mP?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooX5nP03o`000?of2OKomPWf00WomPWf00?o0000on8Mh_oR
7N800ooR7N800ol0003ol@kaoo4>l@0;oo4>l@03o`000?oU6^GoiA[U00ooiA[U00?o0000ooH9m_of
2OH01Oof2OH2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?onPGjo`000?l00000
3Oof2OH00ol0003ohQgRon8MhP02on8MhP03o`000?oa3_7ol@ka00_ol@ka5?l00004ooH9mP;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooH9mP04o`000?oR7N;ohQgRo`0000kol@ka
00?o0000ooP7n?oh1oP04?oh1oP00ol0003omPWfo`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_of2OH00ol0003ohQgRo`00000>oo4>l@03o`00
0?oh1oSon0Oh017on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003omPWfooH9mP0=ooH9mP03o`000?oa3_7ol@ka00Wol@ka1Ol0
000BooP7n0;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oa3_7ol@ka00;ol@ka1ol00004ood2o@03o`000?oh1oSo
n0Oh00oon0Oh00?o0000ood2oOl000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?of2OKomPWf00comPWf1?l0000<ood2o@03o`000?oh1oSon0Oh00con0Oh0_l00003ood2
o@03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0=ood2o@03o`000?oh1oSon0Oh00_o
n0Oh00?o0000ood2oOom0_d01?om0_d00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00koo@;m00?o0000ooP7n?oh
1oP02Ooh1oP2o`0000Ooo@;m00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oo@;m
ood2o@0?ood2o@03o`000?oh1oSon0Oh00Kon0Oh0_l0000:ood2o@03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oh1oP00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ood2oOom0_d02?om0_d0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooh1oP2o`0000koo@;m00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooP7n?l000004Oom0_d00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?om0_goo@;m00coo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oom0_d00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo@;mood2o@0>ood2o@04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0<ood2o@Co00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?om0_d3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ood2o@?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02ol00?l00oooo`3o003oo`00o`08o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000Go003o0oooo`03o`00o`;oool02Ol0
0?l00oooo`3o003oo`00o`07o`00o`;oool00ol00?l00oooo`3o003oo`00o`06o`00o`;oool0Iol0
0?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool01?l00?l2oooo00?o003o00?oool0
o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool000co003o0_ooo`08o`00o`03oooo0?l00?oo
003o00Ko003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o
00Oo003o00?oool0o`00ool00?l01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`003Ol00?l2oooo00So
003o00?oool0o`00ool00?l01Ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool0
2?l00?l00oooo`3o003oo`00o`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00Wo003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool03?l00?l3oooo00Wo003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02ol00?l3oooo00[o003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0008o`00o`Goool03?l00?l00oooo`3o003oo`00
o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003o
oooo0?l00?l00_ooo`0:o`00o`;oool03Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00_o003o0_ooo`0<o`00o`03oooo0?l00?oo003o00;o003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool03?l00?l2oooo00co003o00Coool0o`00ool00?oo003o0_ooo`06o`00
o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko
003o0_ooo`0Ho`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool00ol00?l00oooo`3o
003oo`00o`06o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo
003o0Oooool006So003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool0
00?o<S;<o`00ool00?l00_l00?l00oooo`3o003oo`00o`04o`00o`;oool01?l00?l00oooo`3o003o
o`00o`05o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0
oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l5oooo00?o003o0_ooo`03o`00o`;oool01Ol00?l:oooo00Co003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0P
o`00o`Coool01_l00?l:oooo00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(380) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.994 .006 .994 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.994 .006 .994 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.994 .006 .994 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.993 .007 .993 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.973 .027 .973 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.992 .008 .992 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.974 .026 .974 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.966 .034 .966 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.95 .05 .95 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.987 .013 .987 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.944 .056 .944 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.993 .007 .993 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.882 .118 .882 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.898 .102 .898 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.811 .189 .811 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.928 .072 .928 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.986 .014 .986 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.989 .011 .989 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.971 .029 .971 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.655 .345 .655 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.939 .061 .939 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.848 .152 .848 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.842 .158 .842 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.876 .124 .876 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.923 .077 .923 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.953 .047 .953 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.819 .181 .819 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.914 .086 .914 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.728 .272 .728 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.947 .053 .947 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.911 .089 .911 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.853 .147 .853 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.909 .091 .909 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.726 .274 .726 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.936 .064 .936 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.842 .158 .842 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.995 .005 .995 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.952 .048 .952 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.763 .237 .763 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.422 .578 .422 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.502 .498 .502 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.979 .021 .979 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.979 .021 .979 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.907 .093 .907 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.994 .006 .994 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.796 .204 .796 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.805 .195 .805 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.487 .513 .487 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.479 .521 .479 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.357 .643 .357 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.773 .227 .773 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.804 .196 .804 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.994 .006 .994 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.778 .222 .778 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.69 .31 .69 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.964 .036 .964 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.565 .435 .565 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.931 .069 .931 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.876 .124 .876 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.488 .512 .488 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.383 .617 .383 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.69 .31 .69 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.115 .885 .115 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.132 .868 .132 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.235 .765 .235 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.527 .473 .527 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.517 .483 .517 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.927 .073 .927 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.187 .813 .187 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.202 .798 .202 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.807 .193 .807 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.966 .034 .966 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.993 .007 .993 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.298 .702 .298 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.364 .636 .364 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.688 .312 .688 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.992 .008 .992 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.746 .254 .746 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.361 .639 .361 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.621 .379 .621 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.105 .895 .105 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.527 .473 .527 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.333 .667 .333 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.97 .03 .97 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.072 .928 .072 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.074 .926 .074 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.889 .111 .889 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.038 .962 .038 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.018 .982 .018 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.648 .352 .648 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.926 .074 .926 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.228 .772 .228 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.047 .953 .047 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.501 .499 .501 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.105 .895 .105 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.207 .793 .207 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.945 .055 .945 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.008 .992 .008 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.128 .872 .128 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.149 .851 .149 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.821 .179 .821 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.249 .751 .249 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.32 .68 .32 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.025 .975 .025 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.039 .961 .039 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.091 .909 .091 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.016 .984 .016 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.39 .61 .39 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.663 .337 .663 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.992 .008 .992 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.819 .181 .819 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.178 .822 .178 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.187 .813 .187 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.44 .56 .44 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.972 .028 .972 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.105 .895 .105 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.163 .837 .163 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.658 .342 .658 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.067 .933 .067 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.993 .007 .993 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.035 .965 .035 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.903 .097 .903 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.972 .028 .972 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.655 .345 .655 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.717 .283 .717 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.091 .909 .091 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.913 .087 .913 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.325 .675 .325 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.478 .522 .478 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.072 .928 .072 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.257 .743 .257 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.443 .557 .443 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.992 .008 .992 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.992 .008 .992 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.947 .053 .947 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.138 .862 .138 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.134 .866 .134 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.027 .973 .027 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.873 .127 .873 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.219 .781 .219 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.966 .034 .966 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.191 .809 .191 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.193 .807 .193 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.205 .795 .205 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.701 .299 .701 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.776 .224 .776 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.642 .358 .642 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.019 .981 .019 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.207 .793 .207 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.344 .656 .344 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.62 .38 .62 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.871 .129 .871 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.993 .007 .993 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.959 .041 .959 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.218 .782 .218 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.426 .574 .426 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.186 .814 .186 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.86 .14 .86 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.78 .22 .78 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.992 .008 .992 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.635 .365 .635 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.897 .103 .897 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.964 .036 .964 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.165 .835 .165 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.289 .711 .289 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.951 .049 .951 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.175 .825 .175 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.713 .287 .713 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.553 .447 .553 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.543 .457 .543 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.388 .612 .388 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.917 .083 .917 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.886 .114 .886 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.895 .105 .895 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.92 .08 .92 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.448 .552 .448 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.972 .028 .972 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.839 .161 .839 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.397 .603 .397 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.449 .551 .449 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.993 .007 .993 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.707 .293 .707 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.588 .412 .588 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.992 .008 .992 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.968 .032 .968 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.871 .129 .871 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.963 .037 .963 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.463 .537 .463 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.942 .058 .942 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.822 .178 .822 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.754 .246 .754 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.993 .007 .993 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.726 .274 .726 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.613 .387 .613 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.768 .232 .768 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.988 .012 .988 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.615 .385 .615 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.991 .009 .991 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.692 .308 .692 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.992 .008 .992 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.819 .181 .819 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.904 .096 .904 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.843 .157 .843 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.92 .08 .92 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.94 .06 .94 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.845 .155 .845 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.706 .294 .706 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.831 .169 .831 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.903 .097 .903 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.941 .059 .941 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.923 .077 .923 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.933 .067 .933 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.989 .011 .989 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.861 .139 .861 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.966 .034 .966 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.991 .009 .991 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.973 .027 .973 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.955 .045 .955 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.871 .129 .871 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.967 .033 .967 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.941 .059 .941 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.931 .069 .931 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.991 .009 .991 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.956 .044 .956 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.993 .007 .993 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.991 .009 .991 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.992 .008 .992 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.991 .009 .991 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.993 .007 .993 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oom
0_d01?l0003om@[eooD:mOl0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?om
0_goo@;m00goo@;m00?o0000ooD:mOoe2_D00_oe2_D00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003oo@;mood2o@0<ood2o@03o`000?oe2_Gom@[e00?om@[e00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m
00[oo@;m00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003om@[eooD:m@06ooD:m@03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Ooo@;m
00?o0000ooD:mOoe2_D02?oe2_D00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oh1oSo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com@[e00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooP7n003o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003olPgboo8=lP05oo8=lP03o`000?oe
2_Gom@[e00_om@[e0ol00003oo<<l`03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003olPgboo8=lP06
oo8=lP03o`000?oe2_Gom@[e00[om@[e00?o0000oo<<looc3?<01?oc3?<00ol0003oo@;mood2o@0:
ood2o@04o`000?oa3_7ol@kaoo4>l@;o00002_om0_d2o`000003oo0?l?l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003on0OhooP7n005ooP7n003o`000?om0_go
o@;m00Woo@;m00?o0000ooP7n?l000002oon0Oh00ol0003olPgboo8=lP06oo8=lP03o`000?oe2_Go
m@[e00Wom@[e00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@08ood2o@03o`000?oa3_7o
l@ka00Col@ka0_l00005ood2o@?o00001?o`3o000ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooP7n003o`000?om0_goo@;m00Ooo@;m0_l00003ooP7
n003o`000?on0OkooP7n00OooP7n00?o0000oo8=l_ob3O801oob3O800ol0003om@[eooD:m@09ooD:
m@03o`000?oc3??ol`cc00Ool`cc00?o0000ood2oOom0_d01Oom0_d2o`0000Wol@ka0_l000000oom
0_go0000o`000007oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooP7n?oh
1oP02?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on
0Oh01oon0Oh00ol0003olPgboo8=lP08oo8=lP03o`000?oe2_Gom@[e00Oom@[e00?o0000oo<<looc
3?<02Ooc3?<00ol0003oo@;mood2o@03ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000oo0?l?o`
3o001oo`3o000ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfo`000005ood2o@;o00002ooh1oP2o`0000Koo@;m
00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?ob3O;olPgb00SolPgb
00?o0000ooD:mOoe2_D01_oe2_D00ol0003ol`ccoo<<l`0;oo<<l`05o`000?om0_goo@;mood2oOl0
00003_oa3_400ol0003ol0o`oo0?l008oo0?l003o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?of2OKomPWfooH9m_l0
00000oom0_d00ol0003on0OhooP7n00:ooP7n004o`000?o]4^gokA;]o`0000?oo@;m0_l00008ooP7
n003o`000?on0OkooP7n00KooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003om@[eooD:m@05ooD:
m@03o`000?oc3??ol`cc00col`cc00?o0000ood2oOl000003ooa3_400ol0003ol0o`oo0?l008oo0?
l003o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9mP03ooH9mP03o`000?om0_go000000_o
n0Oh0_l00004ondBk@03o`000?om0_go000000_on0Oh00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
lPgboo8=lP09oo8=lP03o`000?oe2_Gom@[e00Com@[e00?o0000oo<<looc3?<03_oc3?<00ol0003o
l@kaoo4>l@0>oo4>l@03o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooH9m_of2OH0
1?of2OH00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]00GokA;]00?o0000ooP7n?oh1oP0
2_oh1oP00ol0003ooP7nooh1oP05ooh1oP03o`000?ob3O;olPgb00[olPgb00?o0000ooD:mOoe2_D0
0ooe2_D00ol0003ol`ccoo<<l`0>oo<<l`03o`000?oa3_7ol@ka00gol@ka00?o0000oo0?l?o`3o00
2_o`3o000ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9
mP05ooH9mP03o`000?oh1oSon0Oh00Oon0Oh0_l00008ondBk@03o`000?oh1oSon0Oh00_on0Oh00?o
0000ooh1o_on0Oh01?on0Oh00ol0003olPgboo8=lP0:oo8=lP04o`000?oe2_Gom@[eooD:m@?o0000
3ooc3?<00ol0003ol@kaoo4>l@0>oo4>l@03o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?of2OKomPWf00OomPWf00?o0000ooP7n?oh1oP01?oh1oP2o`0000_okA;]1?l0
0009ooP7n003o`000?on0OkooP7n00?ooP7n00?o0000oo8=l_ob3O802oob3O801?l0003om@[eo`00
0?l00003om`Sg0;o00003?oc3?<2o`00013ol@ka00?o0000oo0?l?o`3o002oo`3o000ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003omPWf
ooH9mP07ooH9mP03o`000?oh1oSon0Oh00?on0Oh00?o0000ondBkOo]4^d02oo]4^d01?l0003odBkA
om4^dOoA;]45o`0000Gon0Oh00?o0000ooh1o_on0Oh00_on0Oh00ol0003olPgboo8=lP0<oo8=lP03
o`000?oL8mcog2?L00Gog2?L0_l00008oo<<l`;o00000_oF:MH00ol0003ol@kaoo4>l@0=oo4>l@03
o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003omPWfooH9mP09ooH9mP03o`000?oh1oSon0Oh00;o0000
3Oo]4^d00ol0003odBkAom4^d@07om4^d@Ko00000_on0Oh4o`0000golPgb00?o0000om`Sg?oL8m`0
1ooL8m`2o`0000Gol`cc00?o0000omHYe_oF:MH00ooF:MH00ol0003ol@kaoo4>l@0<oo4>l@03o`00
0?o`3o3ol0o`00col0o`00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?of2OKomPWf00WomPWf00?o
0000ooP7n?l000003oo]4^d00ol0003odBkAom4^d@0<om4^d@?o00001?oY5^T3o`0000WolPgb00?o
0000om`Sg?oL8m`02_oL8m`2o`000003oo<<lol0003o000000OoeRWF00?o0000oo4>lOoa3_402ooa
3_400ol0003ol0o`oo0?l00<oo0?l003o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000
ondBkOo]4^d03_o]4^d00ol0003odBkAom4^d@0=om4^d@03o`000?oY5^WojAKY00KojAKY0ol00005
oo8=lP03o`000?oL8mcog2?L00gog2?L00?o0000omHYe_oF:MH02?oF:MH00ol0003ol@kaoo4>l@09
oo4>l@03o`000?o`3o3ol0o`00gol0o`00Co0000ood2oOom0_goo@;m1Ol00003oo@;m003o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooH9m_of2OH02oof2OH2o`0000ookA;]00?o0000om4^dOoA;]403OoA;]400ol0003ojAKYonTFj@0:
onTFj@?o000000?olPgbo`000?oL8m`03ooL8m`00ol0003oeRWFomHYeP09omHYeP03o`000?oa3_7o
l@ka00Sol@ka00?o0000oo0?l?o`3o003_o`3o03o`0000Som0_d00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?of2OKomPWf00SomPWf0ol000000ooP
7n3o0000ondBk@0>ondBk@03o`000?oA;]7odBkA00godBkA00?o0000onTFjOoY5^T03OoY5^T00ol0
003og2?Lom`Sg00?om`Sg003o`000?oF:MKoeRWF00[oeRWF2ol0000;oo0?l0Go00003?od2o@00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003ol`cco`000?on0Oko0000
00SomPWf0ol00005on0Oh003o`000?o]4^gokA;]00cokA;]00?o0000om4^dOoA;]403OoA;]400ol0
003ojAKYonTFj@0=onTFj@;o00004?oL8m`00ol0003oeRWFomHYeP0:omHYeP03o`000?oB;M;odRgB
00OodRgB00?o0000oo0?l?o`3o000_o`3o07o`0000Cof2OH00?o0000oo@;m?od2o@02_od2o@00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003ol`ccoo<<looc3?<2o`00
00GomPWf0ol00009on0Oh0;o00002oo]4^d00ol0003odBkAom4^d@0=om4^d@03o`000?oY5^WojAKY
00gojAKY00Co0000olHia_o6>LKo00003ooL8m`00ol0003oeRWFomHYeP09omHYeP03o`000?oB;M;o
dRgB00WodRgB1?l0000;omPWf003o`000?od2oCom0_d00[om0_d00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo<<looc3?<01?oc3?<00ol0003omPWfo`000002o`00
00coh1oP00Co0000oki1__l0003o00002Oo]4^d00ol0003odBkAom4^d@0=om4^d@03o`000?oY5^Wo
jAKY00gojAKY00Go0000olHia_o6>LKoaSW6o`00000=om`Sg003o`000?oF:MKoeRWF00[oeRWF00?o
0000om8]d_oB;M802OoB;M800ol0003of2OHomPWf00<omPWf003o`000?od2oCom0_d00[om0_d00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo<<looc3?<01_oc3?<0
0ol0003oh1oPon0Oh00<on0Oh003o`000?nn@Kko_T6n00;o_T6n0_l00007ondBk@03o`000?oA;]7o
dBkA00codBkA00?o0000onTFjOoY5^T03OoY5^T00ol0003oaSW6olHiaP03olHiaP03o`000?oL8mco
g2?L00[og2?L00?o0000omHYe_oF:MH02_oF:MH00ol0003odRgBom8]dP09om8]dP03o`000?oH9mSo
f2OH00cof2OH00?o0000oo@;m?od2o@02ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003ol`ccoo<<l`06oo<<l`03o`000?oP7n3oh1oP00_oh1oP00?o0000oki1
__nn@Kh01Onn@Kh00ol0003okA;]ondBk@03ondBk@03o`000?oA;]7odBkA00godBkA00?o0000onTF
jOoY5^T03OoY5^T00ol0003oaSW6olHiaP04olHiaP03o`000?oL8mcog2?L00Wog2?L00?o0000omHY
e_oF:MH02OoF:MH00ol0003odRgBom8]dP0:om8]dP03o`000?oH9mSof2OH00cof2OH00?o0000oo@;
m?od2o@02ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l`ccoo<<l`07oo<<l`03o`000?oP7n3oh1oP00_oh1oP00?o0000oki1__nn@Kh01_nn@Kh2o`0000?o
kA;]00?o0000om4^dOoA;]403OoA;]400ol0003ojAKYonTFj@0<onTFj@03o`000?o6>LKoaSW600Ko
aSW600?o0000om`Sg?oL8m`02?oL8m`00ol0003oeRWFomHYeP09omHYeP03o`000?oB;M;odRgB00[o
dRgB00?o0000omPWf?oH9mP03?oH9mP00ol0003om0_doo@;m00;oo@;m003o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo<<looc3?<02?oc3?<00ol0003oh1oPon0Oh00:on0Oh003o`00
0?nn@Kko_T6n00Wo_T6n0_l000000oo]4^go0000om4^d@0<om4^d@?o00003_oY5^T00ol0003oaSW6
olHiaP07olHiaP03o`000?oL8mcog2?L00Oog2?L00?o0000omHYe_oF:MH02OoF:MH00ol0003odRgB
om8]dP0;om8]dP03o`000?oH9mSof2OH00cof2OH00?o0000oo@;m?od2o@02_od2o@00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo<<looc3?<02_oc3?<00ol0003oh1oPon0O
h009on0Oh003o`000?nn@Kko_T6n00_o_T6n00?o0000om4^dOoA;]402_oA;]42o`0000?oZ5NX00?o
0000onTFjOoY5^T02_oY5^T00ol0003oaSW6olHiaP09olHiaP03o`000?oL8mcog2?L00Kog2?L00?o
0000omHYe_oF:MH02?oF:MH00ol0003odRgBom8]dP0<om8]dP03o`000?oH9mSof2OH00cof2OH00?o
0000oo@;m?od2o@02_od2o@00ol0003ooP7nooh1oP04ooh1oPCo00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on0Oh?oP7n002?oP7n00
0ol0003o_T6noki1_P0<oki1_P03o`000?oA;]7odBkA00SodBkA0_l00006ojQGZ0;o00002_oY5^T0
0ol0003oaSW6olHiaP0:olHiaP03o`000?oL8mcog2?L00Gog2?L00?o0000omHYe_oF:MH02?oF:MH0
0ol0003odRgBom8]dP0<om8]dP03o`000?oH9mSof2OH00cof2OH00?o0000oo@;m?od2o@02ood2o@0
0ol0003ooP7no`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo<<l`03o`000?oP7n3oh1oP00Ooh1oP00?o0000oki1__nn@Kh03_nn@Kh00ol0003odBkAom4^d@04
om4^d@?o00002_nXEjP00ol0003ojAKYonTFj@07onTFj@03o`000?o6>LKoaSW600_oaSW600?o0000
om`Sg?oL8m`00ooL8m`00ol0003oeRWFomHYeP09omHYeP03o`000?oB;M;odRgB00codRgB00?o0000
omPWf?oH9mP03?oH9mP00ol0003om0_doo@;m00;oo@;m0;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003ol`ccoo<<l`0<oo<<l`03o`000?oP7n3oh1oP00Ooh1oP00?o0000oki1__nn@Kh03onn@Kh01?l0
003odBkAom4^dOoA;]42o`0000koZ5NX0_l00006onTFj@03o`000?o6>LKoaSW600goaSW600?o0000
om`Sg?oL8m`00_oL8m`00ol0003oeRWFomHYeP08omHYeP03o`000?oB;M;odRgB00codRgB0ol0000=
omPWf003o`000?od2oCom0_d00_om0_d00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00ool`cc00?o0000on0Oh?oP7n001_oP7n000ol0003o_T6noki1_P0@oki1_PCo00004_nXEjP00ol0
003ojAKYonTFj@03onTFj@03o`000?o6>LKoaSW600koaSW600Go0000om`Sg?oL8mcog2?Lo`000005
omHYePOo00003?oB;M801Ol0003o/Djaok5>/OnaC[7o000000cof2OH00?o0000oo@;m?od2o@02?od
2o@3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000ool`cc00?o0000on0Oh?oP7n001_oP7n000ol0003o_T6noki1_P0=
oki1_P?o000000CoQWV6o`000?l0003o00004onXEjP2o`0000;ojAKY00?o0000olHia_o6>LH04?o6
>LH00ol0003og2?Lo`000006o`0000Oo]4^d00?o0000om8]d_oB;M802?oB;M800ol0003o/Djaok5>
/@03ok5>/@;o00002?oH9mP3o`0000Kom0_d1?l00002oo0?l003o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003on0Oho`000?oJ9MX3o`0000gol`cc00?o0000on0Oh?oP7n001?oP7n000ol0003o_T6noki1
_P0;oki1_P?o00000on6NHH01Ol0003oP7n0o`000?mA[U7o000001CoZ5NX00?o0000onTFjOl00000
4oo6>LH00ol0003o]4^dokA;]00=okA;]003o`000?oB;M;odRgB00GodRgB0_l00008ok5>/@03o`00
0?oH9mSof2OH00Go00000ooD:m@00ol0003om0_doo@;m003o`0000Ool0o`00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oh1oSon0Oho`0000CofRGJ0ol0000:oo<<l`03o`000?oP7n3oh1oP00?oh1oP
00?o0000oki1__nn@Kh02Onn@Kh3o`0000GoQWV600Co0000oh1oP?n0Oh3o00000_mA[U400ol0003o
Z5NXojQGZ00BojQGZ003o`000?o6>LKoaSW601;oaSW600?o0000okA;]?ndBk@03_ndBk@00ol0003o
dRgBom8]dP03om8]dP03o`000?naC[7o/Dja00Wo/Dja0_l00009om@[e0;o00002_o`3o000ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooP7n?oh1oSon0Oho`000007omXUfP;o00001ooc3?<5o`0000;o
h1oP00?o0000oki1__nn@Kh01_nn@Kh3o`0000SoQWV600Co0000oh1oP?n0Oh3o00000omA[U400ol0
003oZ5NXojQGZ00AojQGZ003o`000?o6>LKoaSW6017oaSW600?o0000okA;]?ndBk@04?ndBk@01Ol0
003odRgBom8]d_oB;M;o000000co/Dja00?o0000om@[e?oD:m@02?oD:m@00ol0003ol0o`oo0?l00:
oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Con0Oh00?o0000omXUf_oJ9MX01ooJ9MX3o`00
0004oo<<lol0003o0000o`0000GoacS70_l00006oki1_P?o00002_n6NHH01Ol0003oP7n0oh1oP?n0
Oh3o000000CoDJiA00?o0000ojQGZ?nXEjP04?nXEjP00ol0003oaSW6olHiaP0AolHiaP03o`000?nd
BkCo]4^d017o]4^d00?o0000om8]d_l000003OnaC[400ol0003oe2_Dom@[e008om@[e003o`000?o`
3o3ol0o`00[ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Con0Oh00?o0000
omXUf_oJ9MX02_oJ9MX00ol0003oacS7olLha`08olLha`03o`000?nn@Kko_T6n00?o00003On6NHH0
1Ol0003oP7n0oh1oP?n0Oh3o000000GoDJiA00?o0000ojQGZ?nXEjP03onXEjP00ol0003oaSW6olHi
aP0AolHiaP03o`000?ndBkCo]4^d01;o]4^d00?o0000ok5>/OnaC[403?naC[400ol0003oe2_Dom@[
e008om@[e003o`000?o`3o3ol0o`00_ol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooP7n?oh1oP01Ooh1oP0
0ol0003ofRGJomXUfP0:omXUfP03o`000?o7><OoacS700WoacS70_l0000?ohIiQP03o`000?n0Oh3o
P7n000;oP7n000?o0000oe6^DOmA[U401?mA[U400ol0003oZ5NXojQGZ00=ojQGZ0?o00004Oo6>LH0
0ol0003o]4^dokA;]00CokA;]003o`000?naC[7o/Dja00_o/Dja00?o0000om@[e?oD:m@02OoD:m@0
0ol0003ol0o`oo0?l00;oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ooh1oP;o00002?oh1oP0
0ol0003ofRGJomXUfP0:omXUfP03o`000?o7><OoacS700WoacS700?o0000ohIiQ_n6NHH03On6NHH0
0ol0003oP7n0oh1oP003oh1oP003o`000?mA[U7oDJiA00GoDJiA00?o0000ojQGZ?nXEjP02_nXEjP2
o`0000?oNXEj00?o0000olHia_o6>LH03_o6>LH00ol0003o]4^dokA;]00CokA;]003o`000?naC[7o
/Dja00_o/Dja00?o0000om@[e?oD:m@02OoD:m@00ol0003ol0o`oo0?l00;oo0?l003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000GooP7n00?o0000ooP7n?oh1oP01ooh1oP2o`0000_ofRGJ00?o0000olLh
aoo7><L02oo7><L00ol0003oQWV6ohIiQP0<ohIiQP03o`000?n0Oh3oP7n000?oP7n000?o0000oe6^
DOmA[U401_mA[U400ol0003oZ5NXojQGZ007ojQGZ0;o00001_mjQGX2o`0000koaSW600?o0000okA;
]?ndBk@04ondBk@00ol0003o/Djaok5>/@0;ok5>/@03o`000?oD:mCoe2_D00Woe2_D00?o0000oo0?
l?o`3o003?o`3o000ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ooh1o_on0OkooP7no`000009ooP7
n003o`000?o`3o3o000000_ofRGJ00?o0000olLhaoo7><L02oo7><L00ol0003oQWV6ohIiQP0;ohIi
QP03o`000?n0Oh3oP7n000CoP7n000?o0000oe6^DOmA[U401omA[U400ol0003oZ5NXojQGZ005ojQG
Z003o`000?mjQG[oNXEj00SoNXEj00?o0000olHia_o6>LH02_o6>LH00ol0003o]4^dokA;]00DokA;
]003o`000?naC[7o/Dja00_o/Dja00?o0000om@[e?oD:m@02OoD:m@00ol0003ol0o`oo0?l00<oo0?
l003o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7no`000009ooP7n004o`000?o`3o3ol0o`o`00
00_ofRGJ00?o0000olLhaoo7><L02oo7><L00ol0003oQWV6ohIiQP0;ohIiQP03o`000?n0Oh3oP7n0
00CoP7n000?o0000oe6^DOmA[U402?mA[U400ol0003oZ5NXojQGZ002ojQGZ0;o00003?mjQGX2o`00
00[oaSW600?o0000okA;]?ndBk@05?ndBk@00ol0003o/Djaok5>/@0;ok5>/@03o`000?oD:mCoe2_D
00Woe2_D00?o0000oo0?l?o`3o003Oo`3o000ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7n007ooP7n003
o`000?o`3o3ol0o`00;ol0o`00?o0000omXUf_oJ9MX02?oJ9MX00ol0003oacS7olLha`0<olLha`03
o`000?n6NHKoQWV600WoQWV600?o0000oh1oP?n0Oh001On0Oh000ol0003oDJiAoe6^D@09oe6^D@04
o`000?nXEjSo0000o`00013oNXEj0_l00008olHiaP03o`000?ndBkCo]4^d01Co]4^d0ol0000;ok5>
/@03o`000?oD:mCoe2_D00Woe2_D00?o0000oo0?l?o`3o003Oo`3o001?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o`3o3ol0o`00?ol0o`00?o0000omXU
f_oJ9MX02?oJ9MX00ol0003oacS7olLha`0;olLha`;o00002_n6NHH00ol0003oP7n0oh1oP006oh1o
P003o`000?mA[U7oDJiA00[oDJiA00?o0000ogZ5N_mjQGX04_mjQGX00ol0003oaSW6olHiaP04olHi
aP03o`000?ndBkCo]4^d01Go]4^d00?o0000oieRWOnMHYd01Ol00005ok5>/@03o`000?oD:mCoe2_D
00[oe2_D00?o0000oo0?l?o`3o003_o`3o03o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003on0OhooP7n004ooP7n003
o`000?o`3o3ol0o`00Col0o`00?o0000omXUf_oJ9MX01ooJ9MX00ol0003oacS7olLha`0;olLha`04
o`000?mlPgcoO8=lo`0000WoQWV600?o0000oh1oP?n0Oh001_n0Oh000ol0003oDJiAoe6^D@0:oe6^
D@03o`000?mjQG[oNXEj01?oNXEj0_l00003olHiaPCo00005?ndBk@00ol0003oWF:MoieRW@06oieR
W@Co000000?o/Djao`000?oD:m@02ooD:m@00ol0003ol0o`oo0?l00>oo0?l003o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o`3o3ol0o`00Gol0o`00?o0000omXUf_oJ
9MX01ooJ9MX00ol0003oacS7olLha`09olLha`;o00001?mlPg`00ol0003oQWV6ohIiQP05ohIiQP03
o`000?n0Oh3oP7n000OoP7n000?o0000oe6^DOmA[U402_mA[U400ol0003oNXEjogZ5NP0EogZ5NP03
o`000?o6>LKo000000CoSG:=0ol0000@okA;]003o`000?nMHYgoWF:M00_oWF:M0_l0000<om@[e003
o`000?o`3o3ol0o`00col0o`0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7n?oh1oP00_oh1oP00ol0003ol0o`
oo0?l006oo0?l003o`000?oJ9M[ofRGJ00OofRGJ00?o0000olLhaoo7><L02?o7><L00ol0003oO8=l
ogb3O005ogb3O003o`000?n6NHKoQWV600CoQWV600?o0000oh1oP?n0Oh001on0Oh000ol0003oDJiA
oe6^D@0:oe6^D@03o`000?mjQG[oNXEj01KoNXEj00?o0000ohebSOn=LXd01_n=LXd3o`0000co]4^d
00?o0000oieRWOnMHYd03OnMHYd00ol0003oe2_Dom@[e009om@[e0Go00002Oo`3o02o`000003oo@;
m?l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooP7n?l0003ol0o`00Wol0o`00?o0000omXUf_oJ9MX01_oJ
9MX00ol0003oacS7olLha`07olLha`03o`000?mlPgcoO8=l00OoO8=l00?o0000ohIiQ_n6NHH00_n6
NHH00ol0003oP7n0oh1oP008oh1oP003o`000?mA[U7oDJiA00WoDJiA00?o0000ogZ5N_mjQGX05omj
QGX00ol0003oSG:=ohebS@09ohebS@?o00002OndBk@00ol0003oWF:MoieRW@0>oieRW@Ko00001?oD
:m@00ol0003ogR7NomhQgP03omhQgPGo00000_o`3o02o`0000Com0_d00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?oa3_7ol@kaoo4>lOl000002oo`3o000ol0003ofRGJomXUfP06omXUfP03o`000?o7
><OoacS700GoacS70_l0000;ogb3O004o`000?n6NHKoQWV6o`0000_oP7n000?o0000oe6^DOmA[U40
2OmA[U400ol0003oNXEjogZ5NP0FogZ5NP03o`000?n=LXgoSG:=00goSG:=0ol00005okA;]003o`00
0?nMHYgoWF:M00ooWF:M00?o0000okA;]?ndBk@00ondBk@4o`0000_ogR7N0_l00006oo@;m003o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@02oo4>l@ko00001_oJ9MX00ol0003oacS7olLh
a`05olLha`03o`000?mlPgcoO8=l00coO8=l00?o0000ohIiQ_l000002on0Oh000ol0003oDJiAoe6^
D@07oe6^D@?o00006?mjQGX00ol0003oSG:=ohebS@0@ohebS@?o000000?o]4^do`000?nMHYd04?nM
HYd00ol0003o]4^dokA;]007okA;]003o`000?oN8MkogR7N00[ogR7N00?o0000oo@;m?od2o@01Ood
2o@00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005oo4>l@03o`000?oI9]WofBKI00_ofBKI0_l00004
omXUfP03o`000?o7><OoacS700?oacS70_l0000@ogb3O003o`000?n0Oh3oP7n000[oP7n000?o0000
oe6^DOmA[U400omA[U44o`0000;o;M8]00?o0000ogZ5N_mjQGX05OmjQGX00ol0003oSG:=ohebS@0D
ohebS@03o`000?nMHYgoWF:M013oWF:M00?o0000okA;]?ndBk@01ondBk@00ol0003ogR7NomhQgP0:
omhQgP03o`000?od2oCom0_d00Gom0_d00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?oa3_7ol@ka
00Gol@ka00?o0000omTVfOoI9]T03OoI9]T6o`0000?oacS700?o0000ogb3O?mlPg`04?mlPg`00ol0
003oP7n0oh1oP00:oh1oP003o`000?mA[U7o000000?o00001ol]dRd00ol0003oNXEjogZ5NP0DogZ5
NP03o`000?n=LXgoSG:=01CoSG:=00?o0000oieRWOnMHYd03onMHYd00ol0003o]4^dokA;]008okA;
]003o`000?oN8MkogR7N00[ogR7N00?o0000oo@;m?od2o@01Ood2o@00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo4>lOoa3_401_oa3_400ol0003ofBKIomTVf@0=omTVf@03o`000?niA[Wo^DJi00?o
^DJi00?o0000olLhaol000004omlPg`4o`0000WoP7n00_l0000<obgB;@03o`000?mjQG[oNXEj01?o
NXEj00?o0000ohebSOn=LXd05On=LXd00ol0003oWF:MoieRW@0>oieRW@03o`000?ndBkCo]4^d00So
]4^d00?o0000omhQg_oN8Mh02OoN8Mh00ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?oa3_7ol@ka00Sol@ka00?o0000omTVfOoI9]T02ooI9]T00ol0003o^DJiokU6^@05okU6^@03o`00
0?mlPgcoO8=l01;oO8=l00Co0000oc[5>_ljaC[o>/Dj1Ol00003oh1oP003o`000?l]dRgo;M8]00go
;M8]0ol0000@ogZ5NP;o00006?n=LXd00ol0003oWF:MoieRW@0=oieRW@03o`000?ndBkCo]4^d00Wo
]4^d00?o0000omhQg_oN8Mh02OoN8Mh00ol0003om0_doo@;m007oo@;m003o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ol@ka00?o0000omTVfOoI9]T02_oI9]T00ol0003o^DJiokU6^@06okU6^@03o`00
0?mlPgcoO8=l017oO8=l00?o0000oc[5>_ljaCX01oljaCX3o`00013o;M8]00?o0000oaOX5olGj1L0
1Ol00009ogZ5NP;o000000?o<<l`o`000?n=LXd05on=LXd00ol0003oWF:MoieRW@0=oieRW@03o`00
0?ndBkCo]4^d00Wo]4^d00?o0000omhQg_oN8Mh02?oN8Mh2o`0000[om0_d00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oi1_Won@Ki00;on@Ki00?o0000oo4>lOoa3_402Ooa3_400ol0003ofBKIomTV
f@0:omTVf@03o`000?niA[Wo^DJi00Oo^DJi00?o0000ogb3O?mlPg`03omlPg`00ol0003o>/Djoc[5
>P0:oc[5>P03o`000?l]dRgo;M8]00go;M8]00?o0000oaOX5olGj1L01_lGj1L4o`0000CoNXEj00?o
0000oc3?<?l`cc000_l`cc000ol0003oSG:=ohebS@0FohebS@03o`000?nMHYgoWF:M00_oWF:M00?o
0000okA;]?ndBk@02ondBk@00ol0003ogR7NomhQgP06omhQgP03o`000?o^4Nko000000[om0_d00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00?on@Ki00?o0000oo4>lOoa3_402?oa3_4=
o`0000[o^DJi00?o0000ogb3O?mlPg`03omlPg`00ol0003o>/Djoc[5>P0;oc[5>P03o`000?l]dRgo
;M8]00co;M8]00?o0000oaOX5olGj1L02_lGj1L4o`0000Go<<l`00?o0000ohebSOn=LXd05_n=LXd0
0ol0003oWF:MoieRW@0:oieRW@03o`000?ndBkCo]4^d00co]4^d00?o0000omhQg_oN8Mh01?oN8Mh2
o`0000?okQ7^00?o0000oo@;m?od2o@02?od2o@00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooT6
nOoi1_T00ooi1_T00ol0003ol@kaoo4>l@07oo4>l@03o`000?oG:=OoebSG00WoebSG00?o0000okU6
^OniA[T02OniA[T00ol0003oO8=logb3O00=ogb3O003o`000?ljaC[o>/Dj00co>/Dj00?o0000obgB
;Ol]dRd03?l]dRd00ol0003o5nPGoaOX5`0;oaOX5`03o`000?l6n@Ko000000Ko<<l`00?o0000oheb
SOn=LXd05_n=LXd00ol0003oWF:MoieRW@09oieRW@03o`000?ndBkCo]4^d00co]4^d00?o0000omhQ
g_oN8Mh00ooN8Mh00ol0003okQ7^onhAkP03onhAkP03o`000?od2oCom0_d00Som0_d00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000oo4>lOoa3_401_oa3_400ol0003o
ebSGomLXe`08omLXe`03o`000?niA[Wo^DJi00_o^DJi00?o0000ogb3O?mlPg`02?mlPg`4o`0000oo
>/Dj00?o0000obgB;Ol]dRd02ol]dRd00ol0003o5nPGoaOX5`0;oaOX5`04o`000?l6n@Ko1_T6o`00
00Oo<<l`00?o0000ohebSOn=LXd05On=LXd00ol0003oWF:MoieRW@08oieRW@03o`000?ndBkCo]4^d
00go]4^d00?o0000omhQg_oN8Mh00_oN8Mh00ol0003okQ7^onhAkP05onhAkP03o`000?od2oCom0_d
00Oom0_d00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Gon@Ki00?o0000oo4>lOoa
3_401Ooa3_400ol0003oebSGomLXe`08omLXe`03o`000?niA[Wo^DJi00_o^DJi00?o0000ogb3O?ml
Pg`00omlPg`5o`0000?o?<<l00?o0000oc[5>_ljaCX03_ljaCX00ol0003o;M8]obgB;@0:obgB;@03
o`000?lGj1Oo5nPG00[o5nPG00Go0000o`Ki1_l6n@Ko1_T6o`000007oc3?<003o`000?n=LXgoSG:=
01GoSG:=00?o0000oieRWOnMHYd02?nMHYd00ol0003o]4^dokA;]00=okA;]003o`000?oN8MkogR7N
00;o00002?o^4Nh00ol0003om0_doo@;m008oo@;m0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oa3_7ol@ka00Go
l@ka00?o0000omLXeooG:=L02?oG:=L00ol0003o^DJiokU6^@0<okU6^@Go00002Oll`c`00ol0003o
>/Djoc[5>P0<oc[5>P;o00003?l]dRd00ol0003o5nPGoaOX5`0:oaOX5`05o`000?l6n@Ko1_T6o`Ki
1_l000002?l`cc000ol0003oSG:=ohebS@0DohebS@?o00001onMHYd00ol0003o]4^dokA;]00>okA;
]003o`000?oN8Mko000000_okQ7^00?o0000oo@;m?od2o@01_od2o@00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ol@kaoo4>l@04oo4>l@03o`000?oG:=OoebSG00Oo
ebSG00?o0000okU6^OniA[T03?niA[T01?l0003oO8=logb3O?l0000;occ3?003o`000?ljaC[o>/Dj
00_o>/Dj00Co0000o`;m0_l2o@;o00002_l]dRd00ol0003o5nPGoaOX5`0:oaOX5`03o`000?l6n@Ko
1_T600;o1_T600?o0000oc3?<?l`cc001_l`cc000ol0003oSG:=ohebS@0AohebS@?o00000omUVVD0
0ol0003oWF:MoieRW@04oieRW@03o`000?ndBkCo]4^d00go]4^d1?l0000;onhAkP03o`000?od2oCo
m0_d00Gom0_d00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00Co0000oo4>
lOoa3_7ol@ka1?l00008omLXe`03o`000?niA[Wo^DJi00_o^DJi00?o0000ogb3O?mlPg`00_mlPg`0
0ol0003o?<<locc3?008occ3?003o`000?ljaC[o>/Dj00[o>/Dj00?o0000o`;m0_l2o@800_l2o@80
0ol0003o;M8]obgB;@03obgB;@Go00002olGj1L00ol0003o1_T6o`Ki1P03o`Ki1P03o`000?l`cc3o
<<l`00Oo<<l`00?o0000ohebSOn=LXd03_n=LXd2o`0000OoIIYU00?o0000oieRWOnMHYd00_nMHYd0
0ol0003o]4^dokA;]00=okA;]003o`000?oL8mcog2?L00;og2?L00?o0000onhAk_o^4Nh02Oo^4Nh0
0ol0003om0_doo@;m003oo@;m003o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@07ooT6
n@?o00001?oQ7^400ol0003oebSGomLXe`05omLXe`03o`000?niA[Wo^DJi00[o^DJi00?o0000ogb3
O?mlPg`00omlPg`00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00So>/Dj00?o0000o`;m
0_l2o@801?l2o@85o`0000Co0?l000?o0000oaOX5olGj1L02OlGj1L00ol0003o1_T6o`Ki1P03o`Ki
1P03o`000?l`cc3o<<l`00So<<l`00?o0000ohebSOn=LXd02_n=LXd3o`0000[oIIYU00Go0000oieR
WOnMHYgoWF:Mo`00000>okA;]003o`000?oL8mcog2?L00Cog2?L0_l00009onhAkP03o`000?od2oCo
m0_d00;om0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on4N
hOoQ7^401OoQ7^400ol0003oebSGomLXe`03omLXe`03o`000?niA[Wo^DJi00[o^DJi00?o0000ogb3
O?mlPg`01?mlPg`00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Oo>/Dj00?o0000o`;m
0_l2o@801Ol2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lGj1Oo5nPG00Oo5nPG00?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o<<l`oc3?<008oc3?<003o`000?n=LXgoSG:=00SoSG:=0_l0000>ofFJ
I@Co00003?ndBk@2o`0000Wog2?L00?o0000onhAk_o^4Nh01oo^4Nh01?l0003om0_doo@;m?l0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ohAkQon4Nh@07on4Nh@;o00000ooG:=L00ol0
003o^DJiokU6^@09okU6^@03o`000?mlPgcoO8=l00KoO8=l00?o0000occ3??ll`c`02Oll`c`00ol0
003o>/Djoc[5>P05oc[5>P03o`000?l2o@;o0_d200Ko0_d200?o0000o`3o0?l0o`002?l0o`000ol0
003o5nPGoaOX5`06oaOX5`03o`000?l6n@Ko1_T600Co1_T600?o0000oc3?<?l`cc002Ol`cc04o`00
00?oSG:=0ol0000@ofFJI@05o`000?o4>lCoa3_4ol@ka?l000002_ndBk@00ol0003og2?Lom`Sg00:
om`Sg0Ko00000oo^4Nh00ol0003om0_do`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0
003ohAkQon4Nh@0:on4Nh@04o`000?oG:=OoebSGo`0000[o^DJi00?o0000ogb3O?mlPg`01omlPg`0
0ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Co>/Dj00?o0000o`;m0_l2o@801ol2o@80
0ol0003o0?l0o`3o0008o`3o00;o00001_lGj1L00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?l`cc3o
<<l`00Wo<<l`00Co0000obcC;?l/dbco;=</0ol0000BofFJI@03o`000?o4>lCoa3_400?oa3_40_l0
0006okA;]0;o00003OoL8m`00ol0003om`SgooL8m`03ooL8m`Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooT6nOoi1_T00ooi1_T0
0ol0003ohAkQon4Nh@0<on4Nh@;o00002_niA[T00ol0003oO8=logb3O008ogb3O003o`000?ll`cco
?<<l00[o?<<l00?o0000oc[5>_ljaCX00_ljaCX00ol0003o0_d2o`;m0P08o`;m0P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lGj1Oo5nPG00;o5nPG00?o0000o`Ki1_l6n@H01_l6n@H0
0ol0003o<<l`oc3?<008oc3?<003o`000?l/dbco;=</00Co;=</00?o0000ofFJIOmUVVD03omUVVD0
0ol0003oa3_4ol@ka006ol@ka0;o00000ondBk@00ol0003og2?Lom`Sg00=om`Sg003o`000?og2?Oo
m`Sg00Oom`Sg0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on@KiooT6n@02ooT6n@03o`000?oQ7^7ohAkQ
00kohAkQ00?o0000okU6^OniA[T01oniA[T00ol0003oO8=logb3O00:ogb3O003o`000?ll`cco?<<l
00Wo?<<l00Go0000oc[5>_ljaC[o>/Djo`00000;o`;m0P03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lGj1Oo5nPGoaOX5ol000002?l6n@H00ol0003o<<l`oc3?<008oc3?<003o`000?l/
dbco;=</00Go;=</00?o0000ofFJIOmUVVD03_mUVVD00ol0003oa3_4ol@ka008ol@ka003o`000?nd
BkCo000000oog2?L00?o0000ooL8moog2?L02?og2?L01?l0003oo@;mo`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oi1_Won@Kio`00017ohAkQ00?o0000okU6^OniA[T01_niA[T00ol0003oO8=l
ogb3O00;ogb3O003o`000?ll`cco?<<l00Wo?<<l00Co0000oc[5>_ljaC[o00003?l2o@800ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5nPGo`000009o`Ki1P03o`000?l`cc3o<<l`00So
<<l`00?o0000obcC;?l/db`01Ol/db`00ol0003oIIYUofFJI@0=ofFJI@03o`000?o4>lCoa3_400[o
a3_400?o0000om`Sg?oL8m`03_oL8m`00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00;o
o@;m00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bon4Nh@03o`00
0?niA[Wo^DJi00Co^DJi00?o0000ogb3O?mlPg`03?mlPg`00ol0003o?<<locc3?00:occ3?0?o0000
3?l2o@800ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Ki1_l6n@H02?l6n@H00ol0003o<<l`
oc3?<007oc3?<003o`000?l/dbco;=</00Oo;=</00?o0000ofFJIOmUVVD03?mUVVD00ol0003oa3_4
ol@ka00;ol@ka0;o00003_oL8m`00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00?oo@;m
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L00oog2?L00ol0003ohAkQon4Nh@0?on4Nh@?o00000oni
A[T00ol0003oO8=logb3O00>ogb3O003o`000?ll`cco?<<l00So?<<l00Co0000o`Wf2Ol9mPWo2OH9
0_l0000:o`;m0P?o00003Ol0o`000ol0003o1_T6o`Ki1P08o`Ki1P03o`000?l`cc3o<<l`00Oo<<l`
00?o0000obcC;?l/db`01ol/db`00ol0003oIIYUofFJI@0;ofFJI@03o`000?o4>lCoa3_400coa3_4
00?o0000onhAk_l000000_l0000:om`Sg003o`000?og2?Oom`Sg00Som`Sg00?o0000ood2oOom0_d0
1Oom0_d2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`04ooL8m`03o`000?oQ7^7ohAkQ00cohAkQ0_l0
0003oll`c`03o`000?niA[Wo0000017oO8=l00?o0000occ3??ll`c`01oll`c`00ol0003o2OH9o`Wf
2@04o`Wf2@;o00002?l2o@800ol0003o0?l0o`3o000>o`3o00;o00002?l6n@H00ol0003o<<l`oc3?
<006oc3?<003o`000?l/dbco;=</00Wo;=</00?o0000ofFJIOmUVVD02OmUVVD00ol0003oa3_4ol@k
a00=ol@ka003o`000?o^4NkokQ7^00;okQ7^0ol00007om`Sg003o`000?og2?Oom`Sg00Oom`Sg00?o
0000ood2oOom0_d02?om0_d2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?oQ7^7o
hAkQ00WohAkQ0_l00006oll`c`03o`000?mlPgcoO8=l013oO8=l00?o0000occ3??ll`c`01_ll`c`0
0ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l2o@;o0_d200Co0_d20ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol6n@H00ol0003o<<l`oc3?<006oc3?<003o`000?l/dbco;=</00[o;=</00?o0000
ofFJIOmUVVD02?mUVVD00ol0003oa3_4ol@ka00=ol@ka003o`000?o^4NkokQ7^00GokQ7^0ol00004
om`Sg003o`000?og2?Oom`Sg00Oom`Sg00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om`SgooL8m`06ooL8m`03o`000?oQ7^7ohAkQ00GohAkQ0ol00008oll`c`03o`000?mlPgcoO8=l
017oO8=l00Co0000occ3??ll`cco?<<l1?l0000;o`Wf2@;o000000Co0_d2o`000?l0003o00000ol6
n@H2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1_T600?o0000oc3?<?l`cc001_l`
cc000ol0003o;=</obcC;00:obcC;003o`000?mUVVGoIIYU00OoIIYU00?o0000ol@ka?o4>l@03_o4
>l@00ol0003okQ7^onhAkP08onhAkPCo00002_og2?L00ol0003oo@;mood2o@0;ood2o@;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003om`SgooL8m`07ooL8m`03o`000?oQ7^7ohAkQ00;ohAkQ0_l0000<oll`c`03o`000?mlPgco
O8=l013oO8=l1?l00003obo@;`03o`000?l9mPWo2OH900_o2OH900?o0000o`Ki1_l6n@H01_l6n@H0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obcC;003o`000?mUVVGo
IIYU00KoIIYU00?o0000ol@ka?o4>l@03_o4>l@00ol0003okQ7^onhAkP0;onhAkP03o`000?og2?Oo
m`Sg00Oom`Sg00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00Co0000on4N
hOl0003o00003_o?<<l00ol0003oO8=logb3O00?ogb3O003o`000?l_d2oo;m0_00Ko;m0_00?o0000
o`Wf2Ol9mPT02_l9mPT00ol0003o1_T6o`Ki1P07o`Ki1P;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?lacS7o<Lha00So<Lha00?o0000obcC;?l/db`03?l/db`00ol0003oIIYUofFJI@05
ofFJI@03o`000?o4>lCoa3_400ooa3_40_l0000=onhAkP03o`000?og2?Oom`Sg00Kom`Sg00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00[om`Sg00?o0000oll`coo?<<l03_o?<<l00ol0
003oO8=logb3O00>ogb3O003o`000?l_d2oo;m0_00Oo;m0_00?o0000o`Wf2Ol9mPT02_l9mPT00ol0
003o1_T6o`Ki1P09o`Ki1P;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?lacS7o<Lha
00Wo<Lha00?o0000obcC;?l/db`02_l/db`4o`0000CoIIYU00?o0000ol@ka?o4>l@04?o4>l@01?l0
003ok1?/o`000?l0000<onhAkP03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?og2?Oom`Sg00[om`Sg00?o0000oll`coo?<<l03oo?<<l@o`0000[o;m0_00?o0000o`Wf
2Ol9mPT02Ol9mPT00ol0003o0?l0o`00000<o`Ki1P05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o<Lhaoc7><@09oc7><@03o`000?l/dbco;=</00Oo;=</0ol00004of>LH`?o000000?oIIYU
o`000?o4>l@04Oo4>l@01?l0003ok1?/on`Ck?o/4n`2o`0000_okQ7^00?o0000ooL8moog2?L00oog
2?L00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02_og2?L00ol0003occ3?oll`c`0?
oll`c`03o`000?mjQG[oNXEj00coNXEj00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2OH9o`Wf2@07
o`Wf2@04o`000?l0o`3o0?l0o`0000go1_T600Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?lacS7o<Lha00[o<Lha00?o0000obcC;?l/db`00ol/db`3o`0000[oHiaS00?o0000ol@ka?o4>l@0
4?o4>l@00ol0003ok1?/on`Ck004on`Ck0;o00002_o^4Nh00ol0003om`SgooL8m`04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000com`Sg00?o0000oll`coo?<<l03oo?<<l00ol0003oNXEjogZ5NP0<ogZ5NP03o`000?l_
d2oo;m0_00Wo;m0_00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o0?l0o`3o0002o`3o0003o`000?l6
n@Ko1_T600[o1_T600?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?la
cS7o<Lha00[o<Lha00?o0000obcC;?l/db`00ol0000=of>LH`03o`000?o4>lCoa3_4013oa3_400?o
0000on`Ck?o/4n`01_o/4n`2o`0000WokQ7^0_l00004ood2o@03o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003occ3?oll`c`0=oll`c`?o00003omjQGX0
0ol0003o;m0_obo@;`08obo@;`03o`000?l9mPWo2OH900Go2OH900?o0000o`3o0?l0o`000ol0o`00
0ol0003o1_T6o`Ki1P0:o`Ki1P03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o<Lhaoc7><@0;oc7><@;o00004OmSW6<00ol0003oa3_4ol@ka00?ol@ka003o`000?o/4nco
k1?/00Sok1?/0_l00007onhAkP03o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooL8moog2?L02?og2?L00ol0003occ3?oll`c`09oll`c`Go00000_nWF:L00ol0
003oNXEjogZ5NP0=ogZ5NP03o`000?l_d2oo;m0_00Wo;m0_00?o0000o`Wf2Ol9mPT01?l9mPT00ol0
003o0?l0o`3o0004o`3o0003o`000?l6n@Ko1_T600So1_T600?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?lacS7o<Lha00_o<Lha00?o0000of>LHomSW6<04?mSW6<00ol0
003oa3_4ol@ka00?ol@ka003o`000?o/4ncok1?/00[ok1?/0_l00004onhAkP03o`000?om0_goo@;m
00Koo@;m0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om`SgooL8m`07ooL8m`03o`000?o?<<oocc3?00Cocc3?1Ol00007ojMHY`03
o`000?mjQG[oNXEj00goNXEj00?o0000obo@;ol_d2l02Ol_d2l00ol0003o2OH9o`Wf2@03o`Wf2@03
o`000?l0o`3o0?l000Go0?l000?o0000o`Ki1_l6n@H02?l6n@H00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000oc7><OlacS402olacS400ol0003oHiaSof>LH`0@of>LH`03
o`000?o4>lCoa3_400ooa3_400?o0000on`Ck?o/4n`03?o/4n`2o`000003onhAk_l0003oo@;m00[o
o@;m00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000oll`col00000
1?l0000<ojMHY`03o`000?mjQG[oNXEj00koNXEj00?o0000obo@;ol_d2l02?l_d2l00ol0003o2OH9
o`Wf2@02o`Wf2@03o`000?l0o`3o0?l000Oo0?l000?o0000o`Ki1_l6n@H01ol6n@H00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000oc7><OlacS402olacS400ol0003oHiaS
of>LH`0Aof>LH`03o`000?o4>lCoa3_400goa3_400?o0000on`Ck?o/4n`03oo/4n`00ol0003oo@;m
ood2o@0;ood2o@;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L01Oog2?L3o`00017oYeRW00?o0000ogZ5N_mjQGX03_mj
QGX00ol0003o;m0_obo@;`09obo@;`04o`000?l9mPWo2OH9o`0000[o0?l000?o0000o`Ki1_l6n@H0
1ol6n@H00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003OlacS400ol0003o
HiaSof>LH`0Aof>LH`?o00003Oo4>l@00ol0003ok1?/on`Ck00?on`Ck003o`000?om0_goo@;m00go
o@;m00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_og2?L2o`0000;oiA[U00?o0000ojMHYonWF:L03onWF:L00ol0003o
NXEjogZ5NP0>ogZ5NP03o`000?l_d2oo;m0_00So;m0_1Ol0000;o`3o0003o`000?l6n@Ko1_T600Ko
1_T600?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=oc7><@03o`000?mSW6?oHiaS
017oHiaS00?o0000ogJ9M_mfRGH00ol0000:ol@ka0Co00003Oo/4n`00ol0003oo@;mood2o@0?ood2
o@03o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooT6nOoi1_Won@Ki0_l00005onDJi@03o`000?nWF:OoYeRW00koYeRW00?o0000ogZ5
N_mjQGX03_mjQGX00ol0003o;m0_obo@;`07obo@;`03o`000?lBkA;o4^dB00?o4^dB00?o0000o`3o
0?l0o`002?l0o`000ol0003o1_T6o`Ki1P05o`Ki1P03o`000?l0o`3o0?l000[o0?l01Ol0000<oc7>
<@03o`000?mSW6?oHiaS013oHiaS00?o0000ogJ9M_mfRGH01?mfRGH3o`0000Koa3_400?o0000onLH
iooW6>L00_oW6>L5o`0000Sok1?/00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00?o
n@Ki00?o0000onDJiOoU6^D01?oU6^D00ol0003oYeRWojMHY`0=ojMHY`03o`000?mjQG[oNXEj00oo
NXEj00?o0000obo@;ol_d2l01?l_d2l2o`0000Oo4^dB00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000oc7><OlacS402?lacS43o`00013oHiaS00?o0000ogJ9M_mfRGH02?mfRGH3o`0000;o
a3_400?o0000onLHiooW6>L02?oW6>L5o`0000?ok1?/00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oi1_Won@Ki00Con@Ki00?o0000onDJiOoU6^D01OoU6^D00ol0003oYeRWojMHY`0;ojMHY`Co0000
3omjQGX00ol0003o;m0_obo@;`03obo@;`03o`000?lBkA;o4^dB00So4^dB00?o0000o`3o0?l0o`00
1?l0o`02o`0000So2OH900?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_lacS42o`0000?o;m0_00?o0000of>LHomSW6<03?mSW6<00ol0003oMXUfogJ9MP0<ogJ9MP;o0000
4?oW6>L3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oU6^GoiA[U00KoiA[U00?o
0000ojMHYonWF:L02OnWF:L00ol0003o^TFjo`000002ofbCK0?o00003?mjQGX01?l0003o;m0_obo@
;ol_d2l2o`0000co4^dB00?o0000o`3o0?l0o`000_l0o`000ol0003o2OH9o`Wf2@08o`Wf2@03o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o<Lhaoc7><@02oc7><@03o`00
0?l_d2oo;m0_00Co;m0_0_l0000;of>LH`03o`000?mfRGKoMXUf00coMXUf00?o0000okU6^Ol00000
4_oW6>L00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on@KiooT6n@06ooT6n@03o`000?oU6^GoiA[U00OoiA[U00?o
0000ojMHYonWF:L01_nWF:L2o`0000;o^TFj00?o0000ofbCK?m/Tf`00om/Tf`3o`0000[oNXEj00?o
0000obo@;ol000003olBkA801?l0003o0?l0o`000?l0000;o`Wf2@03o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o<Lhao`000?l00009obo@;`03o`000?mSW6?oHiaS00Oo
HiaS00?o0000ogJ9M_mfRGH03?mfRGH01?l0003o^DJiokU6^Ol0000ConLHi`03o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003oiA[UonDJi@08onDJi@03o`000?nWF:OoYeRW00Co
YeRW00?o0000okY5^_njAKX00onjAKX00ol0003oK9=/ofbCK005ofbCK0?o00001_mjQGX4o`00013o
4^dB00?o0000o`Wf2Ol9mPT03?l9mPT00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoHiaS00?o0000ogJ9M_mfRGH03?mfRGH00ol0003o
^DJiokU6^@02okU6^@03o`000?oW6>OoiaSW00ooiaSW00?o0000ooL8mol000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oU6^GoiA[U00WoiA[U00Co0000ojMHYonWF:Oo
YeRW0_l00006okY5^P03o`000?m/TfcoK9=/00SoK9=/0ol000000omjQG[o0000o`000004oc?<<`03
o`000?lBkA;o4^dB00go4^dB00?o0000o`Wf2Ol9mPT03?l9mPT00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oHiaSof>LH`03o`0000ko
MXUf00?o0000okU6^OniA[T00oniA[T00ol0003oiaSWonLHi`0>onLHi`05o`000?og2?Oom`SgooL8
mol000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@09ooT6n@03o`000?oU6^GoiA[U00[o
iA[U00?o0000ojMHYol000002?njAKX00ol0003oK9=/ofbCK00;ofbCK003o`000?lcc3?o<l`c00Go
<l`c00?o0000oa;]4_lBkA803?lBkA800ol0003o2OH9o`Wf2@0<o`Wf2@03o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002og:=LP03o`000?mfRGKoMXUf00_o
MXUf00?o0000okU6^OniA[T01?niA[T00ol0003oiaSWonLHi`0=onLHi`03o`000?og2?Oom`Sg00?o
m`Sg00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooT6n@03o`000?oU6^GoiA[U00_oiA[U00?o0000okY5^_njAKX0
1onjAKX00ol0003oK9=/ofbCK00;ofbCK003o`000?lcc3?o<l`c00Ko<l`c00?o0000oa;]4_lBkA80
2olBkA82o`0000go2OH900?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000og:=L_mbSG800_mbSG800ol0003oMXUfogJ9MP09ogJ9MP03
o`000?niA[Wo^DJi00Ko^DJi00?o0000onLHiooW6>L02ooW6>L00ol0003om`SgooL8m`05ooL8m`04
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son@Ki00?o0000onDJiOoU6^D02_oU6^D2o`0000Wo
^TFj00?o0000ofbCK?m/Tf`02om/Tf`00ol0003o<l`coc?<<`07oc?<<`03o`000?lBkA;o4^dB00Wo
4^dB00Co0000o`3o0?l0o`3o00003?l9mPT00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?mbSG;oLXeb00?oLXeb00?o0000
ogJ9M_mfRGH01omfRGH00ol0003o^DJiokU6^@07okU6^@03o`000?oW6>OoiaSW00[oiaSW00?o0000
ooL8moog2?L01oog2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooT6n@03o`000?oU6^GoiA[U
00WoiA[U00Co0000on0Oh?oP7n3o00002OnjAKX00ol0003oK9=/ofbCK009ofbCK003o`000?lcc3?o
<l`c00Wo<l`c00?o0000oa;]4_lBkA801olBkA800ol0003o0?l0o`3o0002o`3o0003o`000?l9mPWo
2OH900Wo2OH900?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oLXebog:=LP05og:=LP03o`000?mfRGKo
MXUf00GoMXUf00?o0000okU6^OniA[T02?niA[T00ol0003oiaSWonLHi`09onLHi`03o`000?og2?Oo
m`Sg00Som`Sg00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oi1_T3o`0000WoiA[U00?o0000on0O
h?oP7n000_oP7n000ol0003o^TFjokY5^P06okY5^P03o`000?m/TfcoK9=/00WoK9=/00?o0000oc?<
<olcc3<02_lcc3<00ol0003o4^dBoa;]4P05oa;]4P03o`000?l0o`3o0?l000Co0?l000?o0000o`Wf
2Ol9mPT02?l9mPT00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?mbSG;oLXeb00KoLXeb00?o0000ogJ9
M_mfRGH00omfRGH00ol0003o^DJiokU6^@09okU6^@03o`000?oW6>OoiaSW00SoiaSW00?o0000ooL8
moog2?L02Oog2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo<<l`?o00001OoU6^D00ol0003o
h1oPon0Oh003on0Oh003o`000?njAK[o^TFj00Ko^TFj00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003o
<l`coc?<<`0;oc?<<`03o`000?lBkA;o4^dB00?o4^dB00?o0000o`3o0?l0o`001_l0o`000ol0003o
2OH9o`Wf2@08o`Wf2@03o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oLXebog:=LP07og:=LP05o`000?mfRGKoMXUfogJ9
M_l000003OniA[T00ol0003oiaSWonLHi`06onLHi`03o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?oc3??ol`cc00Gol`cc0ol000000ooU6^Go0000on0Oh006on0Oh003
o`000?njAK[o^TFj00Go^TFj00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003o<l`coc?<<`0<oc?<<`05
o`000?lBkA;o4^dBoa;]4_l000002_l0o`000ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olSg2?o0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000og:=L_mbSG802OmbSG800ol0003oMXUfo`00000=okU6^@Co00001OoW6>L00ol0
003om`SgooL8m`0;ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ol`ccoo<<l`08oo<<l`03
o`000?oP7n3oh1oP00Ooh1oP00?o0000okY5^_njAKX01?njAKX00ol0003oK9=/ofbCK009ofbCK003
o`000?lcc3?o<l`c00go<l`c00?o0000oa;]4_l000003?l0o`0:o`0000Oo0?l00ol00005ob?L8`03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oLXebog:=LP0:og:=LP03
o`000?niA[Wo^DJi00_o^DJi00?o0000onLHiooW6>L00_oW6>L3o`000003onLHiol0003om`Sg00_o
m`Sg0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003oh1oPon0Oh007on0Oh003o`00
0?njAK[o^TFj00Go^TFj00?o0000ofbCK?m/Tf`01om/Tf`00ol0003o<l`coc?<<`0?oc?<<`;o0000
2ol0o`000ol0003o5nPGoaOX5`07oaOX5`03o`000?l0o`3o0?l000;o0?l00ol00008ob?L8`03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oLXebog:=LP0:og:=LP03o`00
0?niA[Wo^DJi00[o^DJi00?o0000onLHiooW6>L01_oW6>L00ol0003om`SgooL8m`08ooL8m`?o0000
0_oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003oh1oPon0O
h008on0Oh003o`000?njAK[o^TFj00Co^TFj00?o0000ofbCK?m/Tf`01om/Tf`00ol0003o<l`coc?<
<`0>oc?<<`04o`000?l4n`Co1?/4o`0000Wo0?l000?o0000oaOX5olGj1L02OlGj1L01?l0003o0?l0
o`000?l0000<ob?L8`03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
LXebog:=LP0;og:=LP03o`000?niA[Wo^DJi00Oo^DJi0_l00009onLHi`03o`000?og2?Oom`Sg00Co
m`Sg1?l00006ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003ol`ccoo<<l`09oo<<l`03o`00
0?oP7n3oh1oP00Soh1oP00?o0000okY5^_njAKX00onjAKX>o`0000go<l`c00?o0000o`Ck1?l4n`@0
0_l4n`@00ol0003o0?l0o`3o0005o`3o0003o`000?lGj1Oo5nPG00_o5nPG00?o0000ob?L8olSg2<0
3?lSg2<00ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000og:=L_mbSG80
3?mbSG800ol0003o^DJiokU6^@06okU6^@03o`000?oW6>OoiaSW00[oiaSW00?o0000ooL8moog2?L0
0ol0000:ooT6n@?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on0Oh?oP7n002?oP
7n001Ol0003o^TFjokY5^_njAK[o000000_oP7n000?o0000oagR7OlMhQd00ol00009oc?<<`03o`00
0?l4n`Co1?/400Co1?/400?o0000o`3o0?l0o`000ol0o`000ol0003o5nPGoaOX5`0<oaOX5`03o`00
0?lSg2?o8m`S00go8m`S00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmbSG800ol0003o^DJiokU6^@05okU6^@03o`000?oW6>OoiaSW00coiaSW0_l0000=ooT6n@03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on0Oh?oP7n002?oP
7n04o`0000coP7n000?o0000oagR7OlMhQd00olMhQd3o`0000Go<l`c00?o0000o`Ck1?l4n`@01_l4
n`@01Ol0003o0?l0o`3o0?l0o`3o000000oo5nPG00?o0000ob?L8olSg2<03OlSg2<00ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000olZeBX00ol0003oLXebog:=LP0;og:=LP03o`00
0?niA[Wo^DJi00?o^DJi00?o0000onLHiooW6>L03OoW6>L00ol0003on@KiooT6n@0;ooT6n@03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo<<looc3?<02_oc3?<3o`0000Koh1oP0ol0
0003om4^d@03o`000?n0Oh3oP7n000[oP7n000?o0000oagR7OlMhQd01_lMhQd3o`000003oc?<<ol0
003o1?/400Wo1?/400?o0000o`3o0?l000004?lGj1L00ol0003o8m`Sob?L8`0=ob?L8`03o`000?l4
n`Co1?/400Oo1?/40_l00007ob[E:P03o`000?mbSG;oLXeb00[oLXeb00Co0000okU6^OniA[Wo^DJi
0ol0000?onLHi`03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo<<looc3?<02_oc
3?<01?l0003okA;]ondBkOo]4^d2o`000004on0Oh?l0003o0000o`0000KodBkA00?o0000oh1oP?n0
Oh002_n0Oh000ol0003o7N8MoagR7@09oagR7@03o`000?l4n`Co1?/400[o1?/400?o0000oaOX5olG
j1L03olGj1L00ol0003o8m`Sob?L8`0>ob?L8`03o`000?l4n`Co1?/400Ko1?/400?o0000ob[E:_lZ
eBX01olZeBX4o`0000SoLXeb00Co0000okU6^OniA[Wo00000ooA;]42o`0000goiaSW00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003o
kA;]ondBk@04ondBk@03o`000?oA;]7odBkA00OodBkA00?o0000oh1oP?n0Oh002On0Oh000ol0003o
7N8MoagR7@0:oagR7@03o`000?l4n`Co1?/400[o1?/400?o0000oaOX5olGj1L03olGj1L00ol0003o
8m`Sob?L8`0>ob?L8`03o`000?l4n`Co1?/400Go1?/400?o0000ob[E:_lZeBX02?lZeBX01?l0003o
LXebog:=L_mbSG87o`0000;oLXeb0_l00006om4^d@;o00003?oW6>L00ol0003on@KiooT6n@09ooT6
n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003ol`ccoo<<l`08oo<<l`03o`000?o]4^gokA;]00Go
kA;]00?o0000om4^dOoA;]402?oA;]400ol0003oP7n0oh1oP008oh1oP003o`000?lMhQgo7N8M00[o
7N8M00?o0000o`Ck1?l4n`@02ol4n`@00ol0003o5nPGoaOX5`0>oaOX5`03o`000?lSg2?o8m`S00ko
8m`S1Ol00002o`Ck1003o`000?lZeB[o:]DZ00Wo:]DZ00?o0000og:=L_mbSG802?mbSG83o`0000Wo
dBkA0_l0000:onLHi`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oc3??ol`cc00Sol`cc00?o0000ondBkOo]4^d01oo]4^d00ol0003odBkAom4^d@07om4^d@03o`00
0?n0Oh3oP7n000SoP7n000?o0000oagR7OlMhQd02_lMhQd00ol0003o1?/4o`Ck100:o`Ck10;o0000
3_lGj1L3o`0000go8m`S0ol00005ocC;=0;o00002olZeBX00ol0003oLXebog:=LP0;og:=LP;o0000
2_oA;]42o`0000OoiaSW0ol00009ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:ondBk@03o`00
0?oA;]7odBkA00OodBkA00?o0000oh1oP?n0Oh002?n0Oh0>o`0000Wo1?/40ol000000ol0o`3o0000
oaOX5`0:oaOX5`?o00000_l_d2l00ol0003o8m`Sob?L8`09ob?L8`;o00002Oldbc@00ol0003o:]DZ
ob[E:P09ob[E:P03o`000?mbSG;oLXeb00_oLXeb00?o0000oiaSW?l000002ooA;]42o`0000CoiaSW
00Co0000oo0?l?o`3o3ol0o`0_l00007ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003okA;]
ondBk@09ondBk@03o`000?oA;]7odBkA00KodBkA00?o0000oh1oP?n0Oh002?n0Oh000ol0003o8MhQ
ob7N8@0:ob7N8@03o`000?l4n`Co1?/400Co1?/40ol00005o`3o0003o`000?lGj1Oo5nPG00Co5nPG
1?l00006obo@;`03o`000?lSg2?o8m`S00Ko8m`S0_l0000;ocC;=003o`000?lZeB[o:]DZ00Wo:]DZ
00?o0000og:=L_mbSG802_mbSG801Ol0003oW6>LoiaSW?nLHico000000codBkA0_l000000ooW6>Oo
0000oo0?l005oo0?l003o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o]4^gokA;]00SokA;]00?o0000om4^dOoA;]401_oA;]400ol0003oP7n0oh1oP007oh1oP003o`00
0?lQgR7o8MhQ00_o8MhQ00?o0000o`Ck1?l4n`@00_l4n`@2o`0000Wo0?l000?o0000oaOX5olGj1L0
0ol0000;obo@;`03o`000?lSg2?o8m`S00;o8m`S0ol0000>ocC;=003o`000?lZeB[o:]DZ00Oo:]DZ
00?o0000og:=L_mbSG802ombSG800ol0003oW6>LoiaSW002oiaSW003o`000?oA;]7odBkA00_odBkA
00?o0000oo0?l?o`3o001_o`3o02o`0000?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o]
4^gokA;]00OokA;]00?o0000om4^dOoA;]401ooA;]400ol0003oP7n0oh1oP005oh1oP0?o00003OlQ
gR44o`0000_o0?l00ol0000?obo@;`04o`000?lSg2?o0000o`00017o=</d00?o0000ob[E:_lZeBX0
1olZeBX00ol0003oLXebog:=LP0:og:=LP03o`000?nLHicoW6>L00CoW6>L00?o0000om4^dOoA;]40
1ooA;]43o`0000_ol0o`1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d02?o]4^d00ol0003odBkAom4^
d@06om4^d@03o`000?n0Oh3oP7n000;oP7n00ol00003oe^TF`03o`000?lQgR7o8MhQ00[o8MhQ00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aobo@;`03o`000?ldbcCo=</d017o=</d00?o
0000ob[E:_lZeBX01olZeBX00ol0003oLXebog:=LP0:og:=LP03o`000?nLHicoW6>L00GoW6>L00Co
0000om4^dOoA;]7odBkA1Ol00002omLXe`03o`000?o`3o3ol0o`00Wol0o`00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000ondBkOo]4^d01oo]4^d00ol0003odBkAom4^d@05om4^d@?o0000
00?oP7n0o`000?l000001omKY5/00ol0003o8MhQob7N8@08ob7N8@?o00002_l0o`02o`0000;o0?l0
00?o0000obo@;ol_d2l03ol_d2l00ol0003o=</docC;=00AocC;=003o`000?lZeB[o:]DZ00Oo:]DZ
00?o0000og:=L_mbSG802OmbSG800ol0003oW6>LoiaSW007oiaSW0?o00001ooG:=L00ol0003ol0o`
oo0?l009oo0?l003o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000ondBkOo]4^d01oo]
4^d4o`0000;odBkA0_l00003ol<l``03o`000?mKY5_oFjAK00SoFjAK0_l00006ob7N8@;o00000olJ
iAX00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obo@;ol_d2l03_l_
d2l00ol0003o=</docC;=00BocC;=003o`000?lZeB[o:]DZ00Go:]DZ00?o0000og:=L_mbSG802Omb
SG800ol0003oW6>LoiaSW008oiaSW003o`000?oG:=OoebSG00OoebSG00?o0000oo0?l?o`3o002?o`
3o000ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o]4^gokA;]00CokA;]0_l00004
on`Ck0;o00001Oo3?<<00ol0003oFjAKoe^TF`0:oe^TF`03o`000?lQgR7o8MhQ00;o8MhQ00?o0000
oa[U6_lJiAX01?lJiAX00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obo@;ol_d2l03_l_d2l00ol0003o=</docC;=00BocC;=0[o00002_mbSG800ol0003oW6>LoiaSW008
oiaSW003o`000?oG:=OoebSG00OoebSG00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003okA;]ondBkOo]4^d2o`0000Ook1?/00?o0000ol<l`oo3?<<01?o3?<<0
0ol0003oFjAKoe^TF`0:oe^TF`04o`000?lQgR7o0000o`0000So6^DJ00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?l_d2oo;m0_00ko;m0_00?o0000ocC;=?ldbc@04_ldbc@00ol0003oBKI9
odVfB@07odVfB@03o`000?mbSG;oLXeb00KoLXeb00?o0000oiaSW?nLHi`02_nLHi`00ol0003oebSG
omLXe`06omLXe`03o`000?o`3o3ol0o`00Sol0o`00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o]
4^go0000o`0000Wok1?/00?o0000ol<l`oo3?<<01?o3?<<00ol0003oFjAKoe^TF`0;oe^TF`03o`00
0?lJiA[o6^DJ00Wo6^DJ00?o0000o`3o0?l000002Ol0o`000ol0003o;m0_obo@;`0>obo@;`;o0000
4_ldbc@00ol0003oBKI9odVfB@09odVfB@;o00001_mbSG800ol0003oW6>LoiaSW00:oiaSW003o`00
0?oG:=OoebSG00KoebSG00?o0000oo0?l?o`3o002?o`3o000ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000on`Ck?o/4n`02Oo/4n`00ol0003o`cc3ol<l``05ol<l``03o`000?mKY5_oFjAK00[oFjAK00?o
0000oa[U6_lJiAX02_lJiAX2o`0000Wo0?l000?o0000obo@;ol_d2l03_l_d2l00ol0003o8]dRo`00
0002o`0000oo=</d00?o0000odVfBOm9]TT02om9]TT00ol0003oLXebog:=LP03o`0000goW6>L00?o
0000omLXeooG:=L01_oG:=L00ol0003ol0o`oo0?l007oo0?l003o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003ok1?/on`Ck009on`Ck003o`000?o3?<?o`cc300Go`cc300?o0000oe^TFomKY5/02OmKY5/2
o`0000_o6^DJ0_l0000;o`3o0003o`000?l_d2oo;m0_00co;m0_00?o0000ob;M8_lRgB800olRgB83
o`0000co=</d00?o0000odVfBOm9]TT03?m9]TT2o`0000;oUVVF00?o0000oiaSW?nLHi`03?nLHi`0
0ol0003oebSGomLXe`05omLXe`03o`000?o`3o3ol0o`00Ool0o`00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o/4ncok1?/00[ok1?/00?o0000ol<l`oo3?<<01_o3?<<00ol0003oFjAKoe^TF`07oe^T
F`03o`000?mRWF;o000000[o6^DJ00Co0000oa;]4_lBkA;o00002_l0o`000ol0003o;m0_obo@;`0<
obo@;`03o`000?lRgB;o8]dR00Ko8]dR0_l00008ocC;=0;o00003om9]TT00ol0003oUVVFoiIYUP02
oiIYUP03o`000?nLHicoW6>L00_oW6>L00?o0000omLXeooG:=L01OoG:=L00ol0003ol0o`oo0?l007
oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ok1?/on`Ck00:on`Ck003o`000?o3?<?o`cc3
00Ko`cc300?o0000oe^TFomKY5/01_mKY5/01Ol0003oHYeRof:MH_mRWF;o000000So6^DJ00?o0000
oa;]4_lBkA800_lBkA800ol0003o0?l0o`3o0006o`3o00Co00003?l_d2l00ol0003o8]dRob;M8P08
ob;M8P?o00000_ldbc@3o`000003ocO8=ol0003oBKI900goBKI900?o0000oiIYU_nFJIH01?nFJIH0
0ol0003oW6>LoiaSW00:oiaSW003o`000?oG:=OoebSG00GoebSG00?o0000oo0?l?o`3o001_o`3o00
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000on`Ck?o/4n`02oo/4n`00ol0003o`cc3ol<l``07ol<l
``03o`000?mKY5_oFjAK00?oFjAK0_l00005of:MHP03o`000?lJiA[o6^DJ00Co6^DJ00?o0000oa;]
4_lBkA800olBkA800ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co1?/400;o1?/40ol00007obo@
;`;o00003_lRgB82o`0000Go=lPg00?o0000odVfBOm9]TT02_m9]TT00ol0003oUVVFoiIYUP05oiIY
UP03o`000?nLHicoW6>L00_oW6>L00?o0000omLXeooG:=L01?oG:=L00ol0003ol0o`oo0?l006oo0?
l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ok1?/on`Ck00;on`Ck003o`000?o3?<?o`cc300Oo
`cc300?o0000oe^TFomKY5/00_mKY5/00ol0003oHYeRof:MHP06of:MHP03o`000?lJiA[o6^DJ00;o
6^DJ00?o0000oa;]4_lBkA801OlBkA800ol0003o0?l0o`3o0002o`3o00;o00002?l4n`@3o`0000;o
;m0_0_l000000ol8m`So0000ob;M8P0=ob;M8P03o`000?lgb3Oo=lPg00Go=lPg00?o0000odVfBOm9
]TT02?m9]TT00ol0003oUVVFoiIYUP07oiIYUP03o`000?nLHicoW6>L00[oW6>L00?o0000omLXeooG
:=L01?oG:=L00ol0003ol0o`oo0?l006oo0?l003o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003ok1?/
on`Ck00<on`Ck003o`000?o3?<?o`cc300So`cc300Co0000oe^TFomKY5_o00002OmRWF801Ol0003o
6^DJoa[U6_lJiA[o000000So4^dB00Go0000o`3o0?l0o`3o0?l0o`00000=o`Ck10;o00001?l8m`P0
0ol0003o8]dRob;M8P0;ob;M8P03o`000?lgb3Oo=lPg00Ko=lPg00?o0000odVfBOm9]TT01om9]TT0
0ol0003oUVVFoiIYUP08oiIYUPCo00002?nLHi`00ol0003oebSGomLXe`04omLXe`03o`000?o`3o3o
l0o`00Kol0o`00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o/4ncok1?/00_ok1?/0ol00009ol<l
``03o`000?mKY5_o000000_oHYeR00?o0000oa[U6_l000002_lBkA800ol0003o0?l0o`00000?o`Ck
1003o`000?l8m`So2?L800;o2?L800?o0000ob;M8_lRgB802olRgB800ol0003o=lPgocO8=`06ocO8
=`03o`000?m9]TWoBKI900KoBKI900?o0000oiIYU_nFJIH02OnFJIH01?l0003o`Ck1ol4n`Oo1?/47
o`0000;oW6>L00?o0000omLXeooG:=L00ooG:=L00ol0003ol0o`oo0?l005oo0?l003o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o/4ncok1?/00Sok1?/0ol00003onTFj@03o`000?o3?<?o`cc300Oo`cc300?o0000of:M
H_mRWF802omRWF800ol0003o4^dBoa;]4P0:oa;]4P03o`000?l4n`Co1?/400go1?/400?o0000o`Sg
2?l8m`P01?l8m`P00ol0003o8]dRob;M8P09ob;M8P03o`000?lgb3Oo=lPg00So=lPg00?o0000odVf
BOm9]TT00om9]TT2o`0000coUVVF00?o0000ol4n`Oo1?/402?o1?/4<o`0000?ol0o`0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000on`Ck?o/4n`01_o/4n`3o`0000OojAKY00?o0000ol<l`oo3?<<01_o3?<<00ol0003o
HYeRof:MHP0;of:MHP03o`000?lBkA;o4^dB00Wo4^dB0_l0000>o`Ck1003o`000?l8m`So2?L800Go
2?L800?o0000ob;M8_lRgB802OlRgB800ol0003o=lPgocO8=`09ocO8=`03o`000?m9]TWo000000;o
00000_n;M8/00ol0003oUVVFoiIYUP08oiIYUP03o`000?o1?/7o`Ck100co`Ck100?o0000on/Djoo[
5>/01_o[5>/3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003ok1?/on`Ck003on`Ck0?o00002ooY5^T00ol0003o`cc3
ol<l``04ol<l``03o`000?mRWF;oHYeR00_oHYeR0ol00007oa;]4P?o000000?o3?<<o`000?l4n`@0
3Ol4n`@00ol0003o2?L8o`Sg2006o`Sg2003o`000?lRgB;o8]dR00So8]dR00?o0000ocO8=olgb3L0
2_lgb3L00ol0003oRgB;oh]dR`04oh]dR`03o`000?nFJIKoUVVF00OoUVVF00?o0000ol4n`Oo1?/40
2oo1?/400ol0003ojaC[on/Dj`08on/Dj`03o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004on`Ck?l0
003o0000o`0000oojAKY00?o0000ol<l`oo3?<<00oo3?<<>o`0000?oC;=<0_l00002oa;]4P?o0000
1Ol<l``00ol0003o1?/4o`Ck100:o`Ck1003o`000?l8m`So2?L800Oo2?L800?o0000ob;M8_lRgB80
2?lRgB800ol0003o=lPgocO8=`0:ocO8=`03o`000?n;M8_oRgB;00GoRgB;00?o0000oiIYU_nFJIH0
1_nFJIH00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?o[5>_ojaC[00SojaC[00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;ojAKY00?o0000ol<l`oo3?<<00_o3?<<00ol0003o/4n`ok1?
/00:ok1?/003o`000?m</dcoC;=<00?oC;=<0_l00009o`cc3003o`000?l4n`Co1?/400Wo1?/400?o
0000o`Sg2?l8m`P02?l8m`P2o`0000So8]dR00?o0000ocO8=olgb3L02Olgb3L00ol0003oRgB;oh]d
R`07oh]dR`03o`000?nFJIKoUVVF00CoUVVF00?o0000ol4n`Oo1?/402oo1?/400ol0003ojaC[on/D
j`09on/Dj`03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ojAKYonTFj@0?onTFj@?o000000?o`cc3
o`000?n`Ck002on`Ck000ol0003oC;=<odbcC004odbcC003o`000?l<l`co3?<<00Wo3?<<00?o0000
o`Ck1?l4n`@01ol4n`@00ol0003o2?L8o`Sg2009o`Sg2004o`000?lBkA;o0000o`0000Ko8]dR00?o
0000ocO8=olgb3L02Olgb3L00ol0003oRgB;oh]dR`08oh]dR`03o`000?nFJIKoUVVF00?oUVVF00?o
0000ol4n`Oo1?/402oo1?/400ol0003ojaC[on/Dj`09on/Dj`03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003ojAKYonTFj@0<onTFj@;o00000ooX5nP2o`0000co/4n`00?o0000odbcC?m</d`01?m</d`0
0ol0003o3?<<o`cc300:o`cc30Wo00002ol8m`P00ol0003o4^dBoa;]4P02oa;]4P?o00000_lRgB80
0ol0003o=lPgocO8=`0:ocO8=`03o`000?n;M8_oRgB;00WoRgB;00?o0000oiIYU_nFJIH00_nFJIH0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o[5>_ojaC[00WojaC[00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_oY5^T2o`0000Goj1OX00?o0000olDjaOl000002_n`Ck000ol0003oC;=<odbcC006odbc
C003o`000?l<l`co3?<<00Wo3?<<00?o0000o`3o0?l0o`001Ol0o`000ol0003o2?L8o`Sg2009o`Sg
2003o`000?lBkA;o4^dB00Go4^dB0ol00009ocO8=`?o00003On;M8/01Ol0003oUVVFoiIYU_nFJIKo
000000co`Ck100?o0000on/Djoo[5>/02Oo[5>/00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onTF
jOoY5^T01OoY5^T2o`0000Ooj1OX00Co0000olDjaOo5>/Go00002On`Ck000ol0003oC;=<odbcC006
odbcC003o`000?l<l`co3?<<00So3?<<00?o0000o`3o0?l0o`001ol0o`000ol0003o2?L8o`Sg2007
o`Sg2003o`000?lBkA;o4^dB00So4^dB0ol00002ocO8=`Go00000_m]TVd00ol0003oRgB;oh]dR`0<
oh]dR`03o`000?nFJIKo000000co`Ck100?o0000on/Djoo[5>/02_o[5>/00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onTFjOoY5^T00_oY5^T2o`0000Soj1OX00?o0000olDjaOo5>/D00_o5>/D5o`00
00Co/4n`00?o0000odbcC?m</d`01_m</d`00ol0003o3?<<o`cc3008o`cc3003o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Sg2?l8m`P01ol8m`P00ol0003o4^dBoa;]4P08oa;]4P03o`000?ldbcCo=</d
00;o00002?m]TVd00ol0003oRgB;oh]dR`0<oh]dR`Co00002_o1?/400ol0003ojaC[on/Dj`0:on/D
j`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003ojAKYo`000?l0000:onPGj003o`000?o5>/GoaC[5
00;oaC[500?o0000oi1_T?n@Ki000_n@Ki04o`0000WoC;=<00?o0000o`cc3?l<l``02?l<l``00ol0
003o0?l0o`3o0008o`3o0003o`000?l8m`So2?L800Go2?L800?o0000oa;]4_lBkA802?lBkA801Ol0
003o=</docC;=?ldbcCo000000[oKI9]0ol0000;oh]dR`04o`000?oN8MkogR7NomhQgPCo00001Oo1
?/400ol0003ojaC[on/Dj`0;on/Dj`03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003oj1OXonPGj00:
onPGj003o`000?o5>/GoaC[500?oaC[500?o0000oi1_T?n@Ki001?n@Ki000ol0003oC;=<odbcC007
odbcC003o`000?l<l`co3?<<00Ko3?<<0_l0000;o`3o0003o`000?l8m`So2?L800Go2?L800?o0000
oa;]4_lBkA802?lBkA800ol0003o=</docC;=002ocC;=003o`000?m]TVgoKI9]00OoKI9]00?o0000
okI9]_nfBKH01?l00006oh]dR`03o`000?oN8MkogR7N00KogR7N0ol00002ol4n`@03o`000?o[5>_o
jaC[00_ojaC[00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oX5nSoj1OX00Woj1OX00?o0000olDj
aOo5>/D01?o5>/D00ol0003oT6n@oi1_T005oi1_T003o`000?m</dcoC;=<00OoC;=<00?o0000o`cc
3?l<l``00_l<l``3o`000003oa[U6_l0003o0?l000[o0?l000?o0000o`Sg2?l8m`P01Ol8m`P00ol0
003o4^dBoa;]4P07oa;]4P03o`000?ldbcCo=</d00?o=</d00?o0000offBKOm]TVd01om]TVd00ol0
003o]TVfokI9]P04okI9]P?o00000_n;M8/00ol0003ogR7NomhQgP0:omhQgP;o00003_o[5>/00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onPGj?oX5nP02OoX5nP00ol0003oaC[5olDja@04olDja@03
o`000?n@Ki3oT6n@00KoT6n@0_l00007odbcC003o`000?l<l`co000000;o00001OlJiAX00ol0003o
0?l0o`3o0008o`3o00?o00001?l8m`P00ol0003o4^dBoa;]4P08oa;]4P03o`000?ldbcCo=</d00Co
=</d00?o0000offBKOm]TVd01_m]TVd00ol0003o]TVfokI9]P07okI9]P;o00003_oN8Mh00ol0003o
jaC[on/Dj`0;on/Dj`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003oj1OXonPGj008onPGj003o`00
0?o5>/GoaC[500GoaC[500?o0000oi1_T?n@Ki001?n@Ki000ol0003oQWV6ohIiQP03o`0000CoC;=<
0_l00008oa[U6P03o`000?l0o`3o0?l000Oo0?l000Co0000obWF:OlYeRWo:MHY0ol000000ol8m`So
0000oa;]4P09oa;]4P03o`000?ldbcCo=</d00Co=</d00?o0000offBKOm]TVd01Om]TVd00ol0003o
]TVfokI9]P09okI9]P03o`000?oN8MkogR7N00gogR7N00?o0000on/Djoo[5>/02_o[5>/00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onPGj?oX5nP01ooX5nP00ol0003oaC[5olDja@06olDja@03o`00
0?n@Ki3oT6n@00?oT6n@00?o0000ohIiQ_n6NHH01?n6NHH2o`000003odbcC?l0003o6^DJ00[o6^DJ
00?o0000o`3o0?l0o`001Ol0o`000ol0003o:MHYobWF:@05obWF:@03o`000?lBkA;o4^dB00Oo4^dB
0ol00007ocC;=003o`000?m]TVgoKI9]00CoKI9]00?o0000okI9]_nfBKH02OnfBKH00ol0003ogR7N
omhQgP0=omhQgP03o`000?o[5>_ojaC[00[ojaC[00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oX
5nSoj1OX00Goj1OX0ol00009olDja@05o`000?n@Ki3oT6n@oi1_T?l000002On6NHH00ol0003o6^DJ
oa[U6P0;oa[U6P03o`000?l0o`3o0?l000?o0?l000?o0000obWF:OlYeRT01_lYeRT00ol0003o4^dB
oa;]4P06oa;]4P05o`000?lhacSo><LhocS7>?l000001oldbc@00ol0003oKI9]offBK@03offBK@03
o`000?nfBKKo]TVf00Wo]TVf00?o0000omhQg_oN8Mh03_oN8Mh00ol0003ojaC[on/Dj`09on/Dj`03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003oj1OXo`000004o`0000;oka3_00?o0000olDjaOo5>/D0
1oo5>/D01?l0003oT6n@oi1_T?l00009ohIiQP;o00003OlJiAX00ol0003o0?l0o`3o0002o`3o0003
o`000?lYeRWo:MHY00So:MHY00?o0000oa;]4_lBkA800olBkA82o`0000Go><Lh00?o0000ocC;=?ld
bc@01?ldbc@00ol0003oKI9]offBK@03offBK@03o`000?nfBKKo]TVf00Wo]TVf00?o0000omhQg_oN
8Mh03_oN8Mh00ol0003ojaC[on/Dj`09on/Dj`03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Soka3_
00?o0000olDjaOo5>/D01_o5>/D00ol0003oT6n@o`000009ohIiQP04o`000?mLXecoG:=Lo`0000go
6^DJ00Co0000o`3o0?l0o`3o00003?lYeRT01Ol0003o4^dBoa;]4_lBkA;o000000So><Lh0_l00005
ocC;=003o`000?m]TVgoKI9]00;oKI9]00?o0000okI9]_nfBKH02OnfBKH00ol0003ogR7NomhQgP0>
omhQgP03o`000?o[5>_ojaC[00WojaC[00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o_4>ooka3_
00Ooka3_00?o0000olDjaOo5>/D01oo5>/D00ol0003oQWV6ohIiQP07ohIiQP03o`000?mLXecoG:=L
00;oG:=L00?o0000oa[U6_lJiAX02_lJiAX00ol0003o0?l0o`00000>obWF:@03o`000?lBkA;o0000
00_o><Lh00?o0000ocC;=?ldbc@00_ldbc@01Ol0003oKI9]offBKOm]TVgo000000co]TVf00?o0000
omhQg_oN8Mh03_oN8Mh3o`0000WojaC[00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o_4>ooka3_
00Woka3_00?o0000olDjaOo5>/D01_o5>/D00ol0003oQWV6ohIiQP06ohIiQP03o`000?mLXecoG:=L
00?oG:=L00?o0000oa[U6_lJiAX02olJiAX00ol0003o:MHYobWF:@0>obWF:@03o`000?lhacSo><Lh
00_o><Lh0_l00003ocC;=004o`000?m]TVgoKI9]o`0000[o]TVf0ol0000>omhQgP;o00000ool0o`2
o`0000OojaC[00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o_4>ooka3_00[oka3_00?o0000olDj
aOo5>/D01?o5>/D00ol0003oQWV6ohIiQP06ohIiQP03o`000?mLXecoG:=L00GoG:=L00?o0000oa[U
6_lJiAX01olJiAX3o`00017o:MHY00?o0000ocS7>?lhacP03OlhacP01Ol0003o=</docC;=?l0003o
KI9]00Co00000onfBKH5o`0000;ojQGZ00?o0000omhQg_oN8Mh02_oN8Mh2o`0000Ooo0?l0_l00004
on/Dj`03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oka3_onl@k`0;onl@k`03o`000?o5>/GoaC[5
00CoaC[500?o0000ohIiQ_n6NHH01On6NHH00ol0003oG:=LoebSG006oebSG003o`000?lJiA[o6^DJ
00Co6^DJ0ol00002ob3O8003o`000?lYeRWo:MHY00oo:MHY0_l0000?ocS7>004o`000?ldbcCo0000
o`0000CoXUfR0ol00008onXEjP03o`000?oN8MkogR7N00OogR7N0_l0000;oo`3o0;o00000_o[5>/0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000onl@koo_4>l03?o_4>l6o`0000OoQWV600?o0000oebS
G?mLXe`02?mLXe`00ol0003o6^DJoa[U6P03o`0000Ko8=lP00?o0000obWF:OlYeRT03OlYeRT01?l0
003o@Ki1od6n@Ol0000?ocS7>003o`000?nRGJ;oXUfR00GoXUfR00?o0000onXEj_oZ5NX02?oZ5NX0
0ol0003ogR7NomhQgP05omhQgP03o`000?ol0ocoo0?l00goo0?l0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o_4>l00ol0003obcC;ol/db`04ol/d
b`03o`000?n6NHKoQWV600?oQWV600?o0000oebSG?mLXe`02_mLXe`2o`0000[o8=lP00?o0000obWF
:OlYeRT02olYeRT00ol0003o@Ki1od6n@@02od6n@@03o`000?lhacSo><Lh00_o><Lh0_l00007oj9M
XP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000omhQg_oN8Mh00_oN8Mh2o`0001;oo0?l00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000onl@koo_4>l02oo_4>l00ol0003obcC;ol/db`06ol/db`05o`000?n6NHKoQWV6ohIi
Q_l000003OmLXe`00ol0003o8=lPob3O800:ob3O8003o`000?lYeRWo:MHY00Wo:MHY00?o0000od6n
@Om1_T401?m1_T400ol0003o><LhocS7>008ocS7>0;o000000?oF:MHo`000?nRGJ801onRGJ800ol0
003ojQGZonXEjP09onXEjP04o`000?oN8Mko0000o`0001Coo0?l00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?o_4>ooka3_
00Woka3_00?o0000ol/dboo;=</02?o;=</00ol0003oQWV6o`00000=oebSG003o`000?lPgb3o8=lP
00_o8=lP00?o0000obWF:OlYeRT02?lYeRT00ol0003o@Ki1od6n@@06od6n@@03o`000?lhacSo><Lh
00Go><Lh0_l00003oeRWF003o`000?nRGJ;oXUfR00KoXUfR00?o0000onXEj_oZ5NX02_oZ5NX00ol0
003oo0?loo`3o00Eoo`3o0;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003oka3_onl@k`07onl@k`03o`000?o;=<_obcC;00[obcC;00?o0000oebSG?mL
Xe`03?mLXe`00ol0003o8=lPob3O800<ob3O8003o`000?lYeRWo:MHY00Ko:MHY00?o0000od6n@Om1
_T402?m1_T400ol0003o><LhocS7>002ocS7>0;o00001_mHYeP00ol0003oXUfRoj9MXP05oj9MXP03
o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oo`3o?ol0o`05Ool0o`00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?o_4>ooka3_00Goka3_
00?o0000ol/dboo;=</03?o;=</2o`0000coG:=L00?o0000ob3O8?lPgb003OlPgb000ol0003o:MHY
obWF:@04obWF:@03o`000?m1_T7o@Ki100[o@Ki100Co0000ocS7>?l0003o00002?mHYeP00ol0003o
XUfRoj9MXP06oj9MXP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`05Ool0o`00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_o_4>l00ol0003obcC;ol/db`0=ol/db`03o`000?n4NhCo000000;o00002?mLXe`00ol0003o8=lP
ob3O800?ob3O80Ko00003_m1_T400ol0003oF:MHoeRWF008oeRWF003o`000?nRGJ;oXUfR00KoXUfR
00?o0000onXEj_oZ5NX02OoZ5NX00ol0003oo0?loo`3o00Doo`3o003o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo8=l_ob3O;olPgb
0_l0000?ol/db`03o`000?n4NhCoQ7^400?oQ7^40ol00005oebSG0;o00004?lPgb001_l0003o6^DJ
oa[U6_l0003o4NhAo`0000ko@Ki100?o0000oeRWF?mHYeP02OmHYeP00ol0003oXUfRoj9MXP05oj9M
XP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oo`3o?ol0o`04ool0o`2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo8=l_ob3O800oob3O800ol0003o
bcC;ol/db`0=ol/db`03o`000?n4NhCoQ7^400KoQ7^40ol000001?mLXeco0000ocC;=?ldbc@3o`00
00co8=lP00Go0000oa[U6_lJiA[o6^DJo`000002oa7^4@03o`000?m1_T7o@Ki100_o@Ki100?o0000
oeRWF?mHYeP02OmHYeP00ol0003oXUfRoj9MXP06oj9MXP03o`000?oZ5N[ojQGZ00SojQGZ0_l0000A
oo`3o0?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003olPgboo8=lP04oo8=lPoo00003?n4Nh@00ol0003o=</docC;=004ocC;
=0?o00002?lPgb000ol0003o6^DJoa[U6P02oa[U6P05o`000?lAkQ7o4NhAoa7^4Ol000003?m1_T40
0ol0003oF:MHoeRWF009oeRWF003o`000?nRGJ;oXUfR00GoXUfR3?l00002ooH9mP;o00003Ool0o`2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003olPgboo8=lP05oo8=lP03o`000?o><LkocS7>00_ocS7>00?o0000ohAk
Q?n4Nh@02_n4Nh@00ol0003o=</docC;=007ocC;=0;o00001OlPgb000ol0003o6^DJoa[U6P03oa[U
6P03o`000?lAkQ7o4NhA00;o4NhA00?o0000od6n@Om1_T402Om1_T400ol0003oF:MHoeRWF00:oeRW
F003o`000?nRGJ;oXUfR00?oXUfR00?o0000on8Mh_oR7N802OoR7N800ol0003omPWfooH9mP02ooH9
mP;o00002Ool0o`2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP06oo8=lP03o`000?o><LkocS7>00[o
cS7>00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003o=</docC;=009ocC;=0?o000000?o8=lPo`000?lJ
iAX01OlJiAX00ol0003o4NhAoa7^4@03oa7^4@03o`000?m1_T7o@Ki100So@Ki13_l00003oj9MXP;o
00002ooR7N800ol0003omPWfooH9mP05ooH9mP03o`000?ol0ocoo0?l00?oo0?l0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo8=l_ob3O801Oob3O800ol0003oebSGo`00000;olhacP03o`000?n4NhCoQ7^400[oQ7^4
0_l0000>ocC;=003o`000?lJiA[o6^DJ00Go6^DJ00?o0000oa7^4OlAkQ400olAkQ400ol0003o@Ki1
od6n@@08od6n@@03o`000?nNHIkoWV6N00_oWV6N00?o0000oj9MX_l000003OoR7N800ol0003omPWf
ooH9mP06ooH9mP;o000000?oo0?lo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00KolPgb00Co
0000omLXeooG:=Oo00002_o><Lh00ol0003oQ7^4ohAkQ009ohAkQ003o`000?mMXUgo000000ko=</d
00?o0000oa[U6_lJiAX01OlJiAX00ol0003o4NhAoa7^4@04oa7^4@03o`000?m1_T7o@Ki100Ko@Ki1
00?o0000oiiQW_nNHIh03OnNHIh00ol0003ohQgRon8MhP0<on8MhP03o`000?of2OKomPWf00SomPWf
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00GolPgb00?o0000omLXeooG:=L00_oG
:=L00ol0003ocS7>olhacP06olhacP03o`000?n4NhCoQ7^400SoQ7^40_l00003oefRG@03o`000?ld
bcCo=</d00_o=</d00?o0000oa[U6_lJiAX01OlJiAX00ol0003o4NhAoa7^4@05oa7^4@03o`000?m1
_T7o@Ki100Go@Ki100?o0000oiiQW_nNHIh03OnNHIh00ol0003ohQgRon8MhP0;on8MhP03o`000?of
2OKomPWf00WomPWf00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000
omLXeooG:=L00ooG:=L00ol0003ocS7>olhacP05olhacP03o`000?n4NhCoQ7^400OoQ7^400?o0000
oefRGOmMXUd00omMXUd00ol0003o=</docC;=00:ocC;=003o`000?lJiA[o6^DJ00Ko6^DJ00?o0000
oa7^4OlAkQ401_lAkQ400ol0003o@Ki1od6n@@04od6n@@03o`000?nNHIkoWV6N00goWV6N3ol0000;
ooH9mP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000omLXeooG:=L01OoG:=L00ol0
003ocS7>olhacP04olhacP03o`000?n4NhCoQ7^400GoQ7^40_l00006oefRG@03o`000?ldbcCo=</d
00Wo=</d0_l00008oa[U6P03o`000?lAkQ7o4NhA00Ko4NhA1Ol000000om1_T7o0000oiiQWP0?oiiQ
WP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000omLXeooG:=L01_oG:=L00ol0003o
cS7>olhacP04o`0000KoQ7^400?o0000oefRGOmMXUd01omMXUd00ol0003o=</docC;=005ocC;=0?o
000000?o9]TVo`000?lJiAX01olJiAX00ol0003o4NhAoa7^4@05oa7^4@03o`000?mC[5?oDjaC00?o
DjaC0_l0000?oiiQWP;o00003OoU6^D00ol0003omPWfooH9mP08ooH9mP03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000WolPgb00?o0000omLXeooG:=L01ooG:=L2o`0000Co/4n`00Co0000ohAkQ?n4NhCo
Q7^40_l0000:oefRG@03o`000?ldbcCo=</d00;o=</d0ol00005obKI9P03o`000?lJiA[o6^DJ00Go
6^DJ00?o0000oa7^4OlAkQ401?lAkQ400ol0003oDjaCoe>/D`06oe>/D`03o`000?nNHIkoWV6N00[o
WV6N0_l00002olLha`03o`000?oU6^GoiA[U00[oiA[U00?o0000ooH9m_of2OH02?of2OH00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo8=l_ob3O801_ob3O800ol0003oebSGomLXe`08omLXe`03o`00
0?n`Ck3o/4n`00Co/4n`00?o0000ohAkQ?l000003?mMXUd00ol0003o=</do`000002o`0000Wo9]TV
00?o0000oa[U6_lJiAX01?lJiAX00ol0003o4NhAoa7^4@03oa7^4@03o`000?mC[5?oDjaC00SoDjaC
1_l00004oiiQWP;o00001Oo7><L00ol0003oiA[UonDJi@09onDJi@03o`000?of2OKomPWf00SomPWf
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?ob3O;olPgb00GolPgb00?o0000omLXeooG:=L01ooG
:=L00ol0003o/4n`ok1?/006ok1?/003o`000?mMXUgoGJ9M00coGJ9M00?o0000obKI9_lVfBH02_lV
fBH00ol0003o6^DJoa[U6P04oa[U6P04o`000?lAkQ7o4NhAoa7^4@;o00002omC[5<00ol0003oY5^T
ojAKY003ojAKY0Co00002?o7><L00ol0003oiA[UonDJi@08onDJi@03o`000?of2OKomPWf00OomPWf
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo8=l_ob3O800oob3O800ol0003oebSGomLXe`07omLXe`03o`000?n`
Ck3o/4n`00Oo/4n`00?o0000oefRGOmMXUd03?mMXUd00ol0003o9]TVobKI9P0;obKI9P03o`000?lJ
iA[o6^DJ00?o6^DJ00Co0000oa7^4OlAkQ7o00003OmC[5<00ol0003oY5^TojAKY006ojAKY003o`00
0?o7><OoacS700OoacS700?o0000onDJiOoU6^D01ooU6^D00ol0003omPWfooH9mP06ooH9mP04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00;olPgb00?o0000omLXeooG:=L0
1_oG:=L00ol0003o/4n`ok1?/009ok1?/003o`000?mMXUgoGJ9M00WoGJ9M0_l0000>obKI9P?o0000
0olJiAX00ol0003o4NhAo`00000=oe>/D`03o`000?nTFjCoY5^T00OoY5^T00?o0000olLhaoo7><L0
2?o7><L:o`0000KomPWf0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OoebSG00?o
0000ok1?/?n`Ck002_n`Ck000ol0003oGJ9MoefRG@06oefRG@;o000000?oEJYEo`000?lVfBH02olV
fBH2o`0000?o?l0o1Ol0000>oe>/D`03o`000?nTFjCoY5^T00OoY5^T00?o0000olLhaoo7><L02?o7
><L00ol0003ojaC[on/Dj`06on/Dj`03o`000?of2OKomPWf00?omPWf00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003ojAKYonTFj@03onTFj@Co00000_oG:=L00ol0003o/4n`ok1?/00;
ok1?/003o`000?mMXUgoGJ9M00?oGJ9M0ol00004oeFZE@03o`000?lVfBKo9]TV00Oo9]TV0_l00008
oco0?`03o`000?mC[5?oDjaC00goDjaC00?o0000ojAKY?nTFj@02?nTFj@00ol0003oacS7olLha`07
olLha`03o`000?o[5>_ojaC[00OojaC[0ol000000oof2OKo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?oY5^WojAKY00OojAKY0_l0000?ok1?/003o`000?mMXUgoGJ9M00;o00002?mEZUD00ol0
003o9]TVobKI9P05obKI9P03o`000?lo`3oo?l0o00So?l0o00?o0000oe>/DomC[5<03OmC[5<00ol0
003oY5^TojAKY008ojAKY003o`000?o7><OoacS700KoacS700?o0000on/Djoo[5>/02?o[5>/01?l0
003om`SgooL8mol0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003ojAKYonTFj@09onTF
j@03o`000?n`Ck3o/4n`00ko/4n`0_l0000;oeFZE@03o`000?lVfBKo9]TV00;o9]TV0_l0000;oco0
?`03o`000?mC[5?oDjaC00goDjaC00?o0000ojAKY?nTFj@02?nTFj@00ol0003oacS7olLha`06olLh
a`03o`000?o[5>_ojaC[00OojaC[00Go0000ooL8moog2?Oom`Sgo`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ojAKYonTFj@0:onTFj@03o`000?n`Ck3o/4n`00go/4n`0_l0000<oeFZE@04o`000?lVfBKo0000
o`0000go?l0o00?o0000oe>/DomC[5<03?mC[5<00ol0003oY5^TojAKY009ojAKY003o`000?o7><Oo
acS700KoacS700?o0000on/Djoo[5>/01_o[5>/00ol0003om`SgooL8m`03ooL8m`03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003ojAKYonTFj@0:onTFj@03o`000?n`Ck3o/4n`00co/4n`00Co0000oiiQ
W_nNHIko00003?mEZUD00ol0003o?l0ooco0?`0>oco0?`03o`000?mC[5?oDjaC00SoDjaC1?l0000;
ojAKY003o`000?o7><OoacS700KoacS700?o0000on/Djoo[5>/01Oo[5>/00ol0003om`SgooL8m`04
ooL8m`03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003ojAKYonTFj@0;onTFj@03o`000?n`Ck3o/4n`
00_o/4n`00?o0000oiiQW_nNHIh00_nNHIh00ol0003oEJYEoeFZE@09oeFZE@03o`000?lo`3oo?l0o
00ko?l0o00Co0000oe>/DomC[5?oDjaC1ol00003og6>L@03o`000?nTFjCoY5^T00WoY5^T00?o0000
olLhaoo7><L01_o7><L00ol0003ojaC[on/Dj`04on/Dj`03o`000?og2?Oom`Sg00Kom`Sg00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oY5^WojAKY00cojAKY00?o0000ok1?/?n`Ck002_n`Ck000ol0
003oWV6NoiiQWP03oiiQWP03o`000?mEZUGoEJYE00SoEJYE00?o0000oco0?olo`3l03_lo`3l4o`00
00_oLHia00?o0000ojAKY?nTFj@02?nTFj@00ol0003oacS7olLha`05olLha`03o`000?o[5>_ojaC[
00GojaC[00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onTFjOoY
5^T03?oY5^T7o`0000Go/4n`00?o0000oiiQW_nNHIh01OnNHIh00ol0003oEJYEoeFZE@07oeFZE@03
o`000?lo`3oo?l0o00ko?l0o00?o0000og6>LOmaSW403OmaSW400ol0003oY5^TojAKY008ojAKY003
o`000?o7><OoacS700CoacS700?o0000on/Djoo[5>/01?o[5>/00ol0003om`SgooL8m`07ooL8m`03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003ojAKYonTFj@0=onTFj@03o`000?o=</gocC;=00CocC;=
1Ol00009oiiQWP03o`000?mEZUGoEJYE00KoEJYE00?o0000oco0?olo`3l03_lo`3l00ol0003oLHia
og6>L@0=og6>L@03o`000?nTFjCoY5^T00SoY5^T00Co0000olLhaoo7><OoacS71Ol00004on/Dj`03
o`000?og2?Oom`Sg00Wom`Sg1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onTFj@03o`000?o=</gocC;=00WocC;=
0_l00009oiiQWP03o`000?mEZUGoEJYE00KoEJYE00?o0000oco0?olo`3l03?lo`3l00ol0003oLHia
og6>L@0?og6>L@Ko00001?nTFj@4o`0000GoiA[U0_l000000oo[5>_o0000ooL8m`0;ooL8m`04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?oc3??ol`ccoo<<l`?o00002_oY5^T00ol0003o
cC;=oldbc@09oldbc@03o`000?n`Ck3o000000;o00001onNHIh00ol0003oEJYEoeFZE@05oeFZE@03
o`000?lo`3oo?l0o00So?l0o1Ol0000Aog6>L@03o`000?ncC;?o/dbc00?o/dbc1?l0000;onDJi@03
o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000oo<<looc3?<01Ooc3?<2o`0000OojAKY
00?o0000oldbcOo=</d02_o=</d00ol0003o/4n`ok1?/002ok1?/0?o00001OnNHIh00ol0003oEJYE
oeFZE@04oeFZE@04o`000?lo`3oo?l0ooco0?`Oo00001?mSW6<00ol0003oLHiaog6>L@0>og6>L@03
o`000?ncC;?o/dbc00Oo/dbc00?o0000onDJiOoU6^D02OoU6^D00ol0003om`SgooL8m`09ooL8m`03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003ol`ccoo<<l`08oo<<l`;o00001?oY5^T00ol0003ocC;=
oldbc@0;oldbc@03o`000?n`Ck3o/4n`00Go/4n`0ol00003oiiQWP04o`000?mEZUGoEJYEoeFZE@Ko
00003?mSW6<00ol0003oLHiaog6>L@0=og6>L@03o`000?ncC;?o/dbc00Oo/dbc00?o0000onDJiOoU
6^D02_oU6^D00ol0003om`SgooL8m`08ooL8m`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo<<l`?o000000?ojAKYo`000?o=</d0
3?o=</d00ol0003o/4n`ok1?/008ok1?/0?o000000CoWV6No`000?l0003o00000_nUFZD00ol0003o
HiaSof>LH`0=of>LH`03o`000?maSW7oLHia00coLHia00?o0000ok=</oncC;<02?ncC;<00ol0003o
iA[UonDJi@0;onDJi@03o`000?og2?Oom`Sg00Kom`Sg00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
l`cc00?o0000oldbcOo=</d03?o=</d00ol0003o/4n`ok1?/00;ok1?/003o`000?nUFZGoYEZU00?o
YEZU00?o0000of>LHomSW6<03?mSW6<00ol0003oL8m`o`00000=og6>L@03o`000?ncC;?o/dbc00So
/dbc00?o0000onDJiOoU6^D03?oU6^D3o`0000Gom`Sg00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?oc3??ol`cc00col`cc00?o0000oldbcOo=</d03?o=</d00ol0003o/4n`ok1?/00:ok1?/003o`00
0?nUFZGoYEZU00GoYEZU00?o0000of>LHomSW6<02_mSW6<01?l0003oL8m`og2?L?m`Sg02o`0000[o
LHia00?o0000ok=</oncC;<02OncC;<00ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00?o
000000?om`Sgo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?oc3??ol`cc00_ol`cc00?o0000oldbcOo=</d0
3?o=</d00ol0003o/4n`ok1?/009ok1?/003o`000?nUFZGoYEZU00KoYEZU00?o0000of>LHomSW6<0
2OmSW6<00ol0003oL8m`og2?L002og2?L003o`000?nWF:Oo000000;o00001omaSW400ol0003o/dbc
ok=</`09ok=</`03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01?oh1oP00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo<<looc3?<02ooc3?<00ol0003ocC;=oldbc@0;oldbc@03o`000?n`
Ck3o/4n`00So/4n`00?o0000ojEJYOnUFZD01onUFZD00ol0003oHiaSof>LH`08of>LH`03o`000?m`
Sg3oL8m`00?oL8m`00?o0000ojMHYonWF:L00_nWF:L2o`0000CoLHia00?o0000ok=</oncC;<02_nc
C;<00ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?oc3??ol`cc00[ol`cc0ol0000;oldbc@Ko00001?n`Ck000ol0003oYEZUojEJY@08
ojEJY@03o`000?mSW6?oHiaS00OoHiaS00?o0000og2?L?m`Sg000om`Sg000ol0003oYeRWojMHY`05
ojMHY`?o000000?oLHiao`000?ncC;<02oncC;<00ol0003oiA[UonDJi@09onDJi@03o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?oc3??ol`cc00Wol`cc00?o0000onPG
j?oX5nP01?l00006oldbc@03o`000?o><LkocS7>00CocS7>1?l0000<ojEJY@03o`000?mSW6?oHiaS
00GoHiaS00?o0000og2?L?m`Sg001?m`Sg000ol0003oYeRWojMHY`08ojMHY`03o`000?ncC;?o/dbc
00_o/dbc00?o0000onDJiOoU6^D02?oU6^D00ol0003on0OhooP7n008ooP7n0Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?oc3??ol`cc00Ool`cc00?o0000onPGj?oX5nP01OoX5nP3o`0000;ocC;=00?o0000olhac_o>
<Lh02?o><Lh00ol0003oYEZUojEJY@0:ojEJY@03o`000?mSW6?oHiaS00CoHiaS00?o0000og2?L?m`
Sg001Om`Sg000ol0003oYeRWojMHY`08ojMHY`03o`000?ncC;?o/dbc00Wo/dbc1?l00008onDJi@03
o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003ol`cc
oo<<l`05oo<<l`03o`000?oX5nSoj1OX00Woj1OX0_l0000<olhacP03o`000?nUFZGoYEZU00WoYEZU
00?o0000of>LHomSW6<00omSW6<00ol0003oL8m`og2?L005og2?L003o`000?nWF:OoYeRW00[oYeRW
00?o0000ok=</oncC;<01?ncC;<4o`0000CogR7N00?o0000onDJiOoU6^D01?oU6^D00ol0003on0Oh
ooP7n00:ooP7n003o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00?ol`cc00?o0000onPGj?oX5nP02ooX
5nP00ol0003ocS7>olhacP0:olhacP03o`000?nUFZGoYEZU00WoYEZU00?o0000of>LHomSW6<00_mS
W6<00ol0003oL8m`og2?L006og2?L003o`000?nWF:OoYeRW00[oYeRW00?o0000ok=</oncC;<01?l0
0009omhQgPKo00003?oh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo<<looc3??ol`cc0_l0
000=onPGj003o`000?o><LkocS7>00[ocS7>00?o0000ojEJYOnUFZD02OnUFZD01Ol0003oHiaSof>L
HomSW6?o000000WoL8m`00?o0000ojMHYonWF:L02onWF:L2o`0000gogR7N00?o0000ooH9m_of2OH0
0_of2OH00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol`cco`00
0002ooX5nP;o00002ooX5nP00ol0003ocS7>olhacP0;olhacP03o`000?nUFZGoYEZU00WoYEZU00?o
0000of>LHol000002Om`Sg000ol0003oYeRWojMHY`0<ojMHY`03o`000?oN8MkogR7N00cogR7N00?o
0000ooH9m_of2OH00oof2OH00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003onPGjooX5nP03ooX5nP;o00002_oX5nP00ol0003ocS7>olhacP0:olhacP03o`000?nUFZGo
YEZU00SoYEZU1Ol00008og2?L003o`000?nWF:OoYeRW00coYeRW00?o0000omhQg_oN8Mh02ooN8Mh0
0ol0003omPWfooH9mP05ooH9mP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooj1OX2o`0000Soj1OX00?o0000olhac_o><Lh02_o><Lh00ol0003oYEZUojEJY@07ojEJ
Y@03o`000?nYEZWoZEJY00?oZEJY0ol00005og2?L003o`000?nWF:OoYeRW00_oYeRW00?o0000omhQ
g_oN8Mh03?oN8Mh00ol0003omPWfooH9mP06ooH9mP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000WonPGj00?o0000onPGj?oX5nP01OoX5nP2o`0000co
cS7>00?o0000ojEJYOnUFZD01OnUFZD00ol0003oZEJYojUFZ@07ojUFZ@?o000000?oL8m`o`000?nW
F:L03OnWF:L00ol0003ogR7NomhQgP0<omhQgP03o`000?of2OKomPWf00KomPWf00?o0000ooP7n?oh
1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?oj1O[onPGj00OonPGj
0_l00004onPGj003o`000?o^4NkokQ7^00;o00002_o><Lh00ol0003oYEZUojEJY@03ojEJY@;o0000
3OnYEZT2o`0000goYeRW0ol0000=omhQgP03o`000?of2OKomPWf00OomPWf00?o0000ooP7n?oh1oP0
1Ooh1oP00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00SonPGj0_l0
00000ooX5nSo0000onhAkP04onhAkP03o`000?o><LkocS7>00OocS7>00Co0000ojEJYOnUFZGoYEZU
0_l00002om8]dP03o`000?nYEZWoZEJY00coZEJY3Ol00003omlPg`03o`000?oN8MkogR7N00[ogR7N
00?o0000ooH9m_of2OH02?of2OH01?l0003on0OhooP7n?oh1oP4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003onPGj
ooX5nP09ooX5nP03o`000?o^4NkokQ7^00GokQ7^0_l00008olhacP03o`000?nUFZGo000000GodRgB
00?o0000ojUFZOnYEZT02onYEZT00ol0003o]dRgokM8]`09okM8]`03o`000?oO8=oogb3O00;ogb3O
0_l00009omhQgP03o`000?of2OKomPWf00[omPWf0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000onhAk_o^4Nh01oo^4Nh4o`0000?ocS7>0ol0
0007om8]dP03o`000?nYEZWoZEJY00[oZEJY00?o0000okM8]ongB;L02OngB;L00ol0003ogb3OomlP
g`04omlPg`;o00001ooN8Mh00ol0003omPWfooH9mP0:ooH9mP03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onhAk_o^4Nh02?o^4Nh0
1?l0003okA;]ondBkOo]4^d3o`0000;ohacS00?o0000om8]d_oB;M801_oB;M800ol0003oZEJYojUF
Z@08ojUFZ@03o`000?ngB;Oo]dRg00[o]dRg00?o0000omlPgooO8=l01_oO8=l00ol0003ogR7NomhQ
gP04omhQgP03o`000?of2OKomPWf00WomPWf00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003okQ7^onhAkP08onhAkP03o`000?o]4^go
kA;]00CokA;]00Go0000on<LhooS7>?ohacSo`000008om8]dP03o`000?nYEZWoZEJY00OoZEJY00?o
0000okM8]ongB;L02_ngB;L00ol0003ogb3OomlPg`07omlPg`;o00001?oN8Mh00ol0003omPWfooH9
mP08ooH9mP03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003okQ7^onhAkP08onhAkP03o`000?o]4^gokA;]00CokA;]00?o0000on<LhooS7><00_oS7><0
0ol0003odRgBom8]dP07om8]dP03o`000?nYEZWoZEJY00KoZEJY00?o0000okM8]ongB;L02_ngB;L0
0ol0003ogb3OomlPg`09omlPg`05o`000?oN8MkogR7NomhQg_l000002Oof2OH00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_okQ7^00?o0000ondBkOo]4^d01?o]4^d00ol0003ohacSon<Lh`03
on<Lh`03o`000?oB;M;odRgB00OodRgB00?o0000ojUFZOnYEZT01OnYEZT00ol0003o]dRgokM8]`0:
okM8]`03o`000?oO8=oogb3O00Wogb3O1?l00009ooH9mP03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?oj1O[onPGj
ooX5n_l000002_o^4Nh00ol0003okA;]ondBk@05ondBk@03o`000?oS7>?ohacS00?ohacS00?o0000
om8]d_oB;M802?oB;M800ol0003oZEJYojUFZ@04ojUFZ@03o`000?ngB;Oo]dRg00Wo]dRg00?o0000
omlPgooO8=l02?oO8=l2o`0000?om`Sg00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003okQ7^onhAkP06onhAkP03o`000?o]4^gokA;]
00GokA;]00?o0000on<LhooS7><01?oS7><00ol0003odRgBom8]dP09om8]dP03o`000?nYEZWoZEJY
00;oZEJY00?o0000okM8]ongB;L02_ngB;L00ol0003ogb3OomlPg`06omlPg`;o00001_og2?L8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o^4NkokQ7^00GokQ7^00?o0000ondBkOo]
4^d01Oo]4^d00ol0003ohacSon<Lh`05on<Lh`03o`000?oB;M;odRgB00WodRgB00Go0000ojUFZOnY
EZWoZEJYo`00000<okM8]`03o`000?oO8=oogb3O00Cogb3O0_l00008ooL8m`03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onhAk_o^
4Nh00oo^4Nh00ol0003okA;]ondBk@06ondBk@03o`000?oS7>?ohacS00GohacS00?o0000om8]d_oB
;M802_oB;M800ol0003oZEJYo`000004o`0000Wo]dRg00?o0000omlPgooO8=l00_oO8=l2o`0000[o
m`Sg00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP07ooX5nP03o`00
0?o^4NkokQ7^00;okQ7^00?o0000ondBkOo]4^d01_o]4^d00ol0003ohacSon<Lh`07on<Lh`;o0000
2ooB;M800ol0003oiaSWonLHi`03onLHi`Oo00000_ngB;L00ol0003ogb3OomlPg`02o`0000_om`Sg
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooX5n_oj1OX02Ooj
1OX01Ol0003okQ7^onhAk_o^4Nko000000SokA;]00?o0000on<LhooS7><01ooS7><00ol0003ol@ka
o`000002o`0000SodRgB00?o0000onLHiooW6>L02_oW6>L5o`0000gom`Sg00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<ooX5nP03o`000?o^4Nko000000WokA;]00?o
0000on<LhooS7><01_oS7><00ol0003ol@kaoo4>l@03oo4>l@?o00001?oB;M800ol0003oiaSWonLH
i`0=onLHi`03o`000?og2?Oom`Sg00gom`Sg00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_onPGj00?o0000ondBkOo]4^d01oo]4^d00ol0003ohacSon<Lh`07
on<Lh`03o`000?oa3_7ol@ka00Kol@ka0ol000000ooB;M;o0000onLHi`0>onLHi`03o`000?og2?Oo
m`Sg00com`Sg00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooX5
nP03o`000?o]4^gokA;]00;okA;]1_l00008on<Lh`03o`000?oa3_7ol@ka00[ol@ka00?o0000onLH
iooW6>L03ooW6>L00ol0003om`SgooL8m`0:ooL8m`;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooX5nPGo00001_og2?L00ol0003ohacSon<Lh`05on<Lh`03o`000?oa3_7ol@ka00[o
l@ka00?o0000onLHiooW6>L03ooW6>L00ol0003om`SgooL8m`07ooL8m`?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooX5nP03o`000?og2?Oom`Sg00Wom`Sg00?o0000on<LhooS
7><00ooS7><00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oW6>OoiaSW00ooiaSW00?o0000ooL8moog
2?L01Oog2?L2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?onPGjo`000?l00000
3Oog2?L00ol0003ohacSon<Lh`02on<Lh`03o`000?oa3_7ol@ka00_ol@ka5?l00004ooL8m`;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooL8m`04o`000?oS7>?ohacSo`0000kol@ka
00?o0000ooP7n?oh1oP04?oh1oP00ol0003om`Sgo`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_og2?L00ol0003ohacSo`00000>oo4>l@03o`00
0?oh1oSon0Oh017on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003om`SgooL8m`0=ooL8m`03o`000?oa3_7ol@ka00Wol@ka1Ol0
000BooP7n0;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oa3_7ol@ka00;ol@ka1ol00004ood2o@03o`000?oh1oSo
n0Oh00oon0Oh00?o0000ood2oOl000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?og2?Oom`Sg00com`Sg1?l0000<ood2o@03o`000?oh1oSon0Oh00con0Oh0_l00003ood2
o@03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0=ood2o@03o`000?oh1oSon0Oh00_o
n0Oh00?o0000ood2oOom0_d01?om0_d00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003om`SgooL8m`0:ooL8m`03o`000?om0_goo@;m00koo@;m00?o0000ooP7n?oh
1oP02Ooh1oP2o`0000Ooo@;m00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003oo@;m
ood2o@0?ood2o@03o`000?oh1oSon0Oh00Kon0Oh0_l0000:ood2o@03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oh1oP00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooh1oP2o`0000koo@;m00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooP7n?l000004Oom0_d00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ood2oOom0_d04Oom0_d5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?om0_goo@;m013oo@;m00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d02oom0_d2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003oo@;mood2o@09ood2o@;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ood2o@;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool02Ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`06o`00o`;oool01?l0
0?l2oooo00Go003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Co003o0_ooo`06o`00o`;oool00ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000go003o00?oool0o`00ool00?l00_l00?l2oooo
00Ko003o0_ooo`03o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo000=o`00o`;oool00ol00?l2oooo00Ko
003o0_ooo`03o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00go003o0_ooo`03o`00o`;oool0
1Ol00?l3oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`02o`00o`04oooo0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool0
1?l00?l3oooo00Co003o0_ooo`0=o`00o`;oool01?l00?l2oooo00?o003o0oooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0<o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03oooo00Co003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00_o003o0oooo`07o`00o`Coool01Ol00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0008o`00o`Goool01ol00?l4oooo00Ko003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00[o003o0_ooo`07
o`00o`?oool00_l00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool0
06Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02ol00?l2oooo
00Go003o0oooo`04o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0<o`00o`;o
ool01?l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;o
ool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Go003o
00?oool0o`00ool00?l01?l00?l2oooo00Co003o0_ooo`06o`00o`;oool00ol00?l2oooo00Co003o
0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o0_ooo`000olb</co003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o0_oo
o`04o`00o`;oool01_l00?l2oooo00?o003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo
001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5
oooo00?o003o0_ooo`03o`00o`;oool01_l00?l2oooo00Co003o0_ooo`05o`00o`;oool00_l00?l2
oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00
o`Goool08?l00?l4oooo00Wo003o1Oooo`07o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7o
oooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(390) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.994 .006 .994 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.994 .006 .994 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.994 .006 .994 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.993 .007 .993 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.975 .025 .975 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.992 .008 .992 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.975 .025 .975 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.967 .033 .967 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.952 .048 .952 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.988 .012 .988 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.946 .054 .946 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.993 .007 .993 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.886 .114 .886 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.902 .098 .902 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.989 .011 .989 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.817 .183 .817 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.931 .069 .931 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.986 .014 .986 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.989 .011 .989 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.973 .027 .973 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.666 .334 .666 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.943 .057 .943 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.856 .144 .856 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.85 .15 .85 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.883 .117 .883 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.926 .074 .926 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.955 .045 .955 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.827 .173 .827 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.918 .082 .918 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.739 .261 .739 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.949 .051 .949 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.914 .086 .914 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.859 .141 .859 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.913 .087 .913 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.732 .268 .732 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.939 .061 .939 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.849 .151 .849 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.953 .047 .953 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.771 .229 .771 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.431 .569 .431 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.513 .487 .513 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.98 .02 .98 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.98 .02 .98 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.911 .089 .911 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.994 .006 .994 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.804 .196 .804 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.813 .187 .813 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.493 .507 .493 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.484 .516 .484 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.368 .632 .368 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.781 .219 .781 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.811 .189 .811 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.994 .006 .994 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.785 .215 .785 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.698 .302 .698 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.966 .034 .966 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.579 .421 .579 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.935 .065 .935 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.881 .119 .881 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.495 .505 .495 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.396 .604 .396 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.701 .299 .701 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.125 .875 .125 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.141 .859 .141 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.237 .763 .237 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.54 .46 .54 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.529 .471 .529 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.931 .069 .931 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.189 .811 .189 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.202 .798 .202 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.814 .186 .814 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.967 .033 .967 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.993 .007 .993 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.309 .691 .309 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.377 .623 .377 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.703 .297 .703 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.992 .008 .992 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.753 .247 .753 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.369 .631 .369 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.638 .362 .638 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.111 .889 .111 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.537 .463 .537 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.346 .654 .346 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.971 .029 .971 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.067 .933 .067 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.081 .919 .081 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.895 .105 .895 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.038 .962 .038 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.019 .981 .019 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.658 .342 .658 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.929 .071 .929 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.229 .771 .229 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.049 .951 .049 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.51 .49 .51 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.107 .893 .107 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.215 .785 .215 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.948 .052 .948 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.007 .993 .007 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.13 .87 .13 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.159 .841 .159 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.829 .171 .829 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.254 .746 .254 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.325 .675 .325 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.019 .981 .019 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.032 .968 .032 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.083 .917 .083 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.014 .986 .014 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.404 .596 .404 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.675 .325 .675 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.992 .008 .992 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.824 .176 .824 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.18 .82 .18 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.179 .821 .179 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.458 .542 .458 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.973 .027 .973 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.11 .89 .11 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.16 .84 .16 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.664 .336 .664 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.074 .926 .074 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.993 .007 .993 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.031 .969 .031 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.907 .093 .907 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.973 .027 .973 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.665 .335 .665 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.728 .272 .728 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.088 .912 .088 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.916 .084 .916 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.332 .668 .332 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.477 .523 .477 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.072 .928 .072 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.261 .739 .261 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.453 .547 .453 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.993 .007 .993 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.992 .008 .992 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.949 .051 .949 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.13 .87 .13 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.13 .87 .13 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.027 .973 .027 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.88 .12 .88 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.225 .775 .225 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.967 .033 .967 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.188 .812 .188 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.188 .812 .188 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.2 .8 .2 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.711 .289 .711 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.779 .221 .779 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.653 .347 .653 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.018 .982 .018 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.218 .782 .218 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.358 .642 .358 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.631 .369 .631 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.876 .124 .876 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.993 .007 .993 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.961 .039 .961 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.223 .777 .223 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.441 .559 .441 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.185 .815 .185 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.864 .136 .864 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.79 .21 .79 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.992 .008 .992 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.646 .354 .646 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.901 .099 .901 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.966 .034 .966 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.171 .829 .171 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.296 .704 .296 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.953 .047 .953 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.177 .823 .177 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.723 .277 .723 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.553 .447 .553 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.555 .445 .555 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.39 .61 .39 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.921 .079 .921 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.891 .109 .891 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.9 .1 .9 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.924 .076 .924 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.459 .541 .459 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.973 .027 .973 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.845 .155 .845 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.403 .597 .403 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.457 .543 .457 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.993 .007 .993 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.711 .289 .711 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.601 .399 .601 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.992 .008 .992 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.969 .031 .969 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.874 .126 .874 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.965 .035 .965 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.474 .526 .474 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.944 .056 .944 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.827 .173 .827 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.762 .238 .762 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.994 .006 .994 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.735 .265 .735 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.623 .377 .623 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.771 .229 .771 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.989 .011 .989 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.621 .379 .621 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.991 .009 .991 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.703 .297 .703 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.992 .008 .992 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.828 .172 .828 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.908 .092 .908 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.851 .149 .851 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.922 .078 .922 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.942 .058 .942 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.85 .15 .85 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.712 .288 .712 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.837 .163 .837 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.907 .093 .907 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.944 .056 .944 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.926 .074 .926 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.937 .063 .937 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.989 .011 .989 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.867 .133 .867 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.968 .032 .968 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.991 .009 .991 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.974 .026 .974 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.956 .044 .956 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.877 .123 .877 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.968 .032 .968 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.942 .058 .942 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.935 .065 .935 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.958 .042 .958 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.993 .007 .993 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.992 .008 .992 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.992 .008 .992 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.991 .009 .991 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.993 .007 .993 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo@;mood2o@05ood2o@Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oom0_d3o`000003o`00ool0003oo@;m00koo@;m00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?om0_goo@;m00goo@;m00?o0000ood2
oOom0_d03oom0_d01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m013oo@;m0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo@;mood2o@0?ood2o@03
o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?oo@;m0_l0000@ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ood2o@?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oom
0_d01?l0003omPWfooH9m_l0000>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ood2o@?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?om
0_goo@;m00goo@;m00?o0000ooH9m_of2OH00_of2OH00ol0003oo@;mood2o@0;ood2o@03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ood2o@03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003oo@;mood2o@0<ood2o@03o`000?of2OKomPWf00?omPWf00?o0000
ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?om0_goo@;m
00koo@;m00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m
00[oo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@08ood2o@03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003omPWfooH9mP06ooH9mP03
o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo@;m
ood2o@0>ood2o@;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?om0_goo@;m00Ooo@;m
00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oh1oSo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000comPWf00Co0000ood2oOom0_goo@;m0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?om0_goo@;m00coo@;m0_l00003ooP7n003o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003olPgboo8=lP05oo8=lP03o`000?of
2OKomPWf00_omPWf0ol00003oo<<l`03o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo@;m00?o0000
ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003olPgboo8=lP06
oo8=lP03o`000?of2OKomPWf00[omPWf00?o0000oo<<looc3?<01?oc3?<00ol0003oo@;mood2o@0:
ood2o@04o`000?oa3_7ol@kaoo4>l@;o00002_om0_d2o`000003oo4>lOl0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ood2oOom0_d02oom0_d00ol0003on0OhooP7n005ooP7n003o`000?om0_go
o@;m00Woo@;m00?o0000ooT6nOl000002oon0Oh00ol0003olPgboo8=lP06oo8=lP03o`000?of2OKo
mPWf00WomPWf00?o0000oo<<looc3?<01_oc3?<00ol0003oo@;mood2o@08ood2o@03o`000?oa3_7o
l@ka00Col@ka0_l00005ood2o@?o00001?oa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Soo@;m0_l00008ooP7n003o`000?om0_goo@;m00Ooo@;m0_l00003ooT6
n@03o`000?on0OkooP7n00OooP7n00?o0000oo8=l_ob3O801oob3O800ol0003omPWfooH9mP09ooH9
mP03o`000?oc3??ol`cc00Ool`cc00?o0000ood2oOom0_d01Oom0_d2o`0000Wol@ka0_l000000oom
0_go0000o`000007oo4>l@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000Soo@;m00?o0000ooP7n?oh
1oP02?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on
0Oh01oon0Oh00ol0003olPgboo8=lP08oo8=lP03o`000?of2OKomPWf00OomPWf00?o0000oo<<looc
3?<02Ooc3?<00ol0003oo@;mood2o@03ood2o@03o`000?oa3_7ol@ka00_ol@ka00?o0000oo4>lOoa
3_401ooa3_400ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`Sgo`000005ood2o@;o00002ooh1oP2o`0000Koo@;m
00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ooP7nooh1oP06ooh1oP03o`000?ob3O;olPgb00SolPgb
00?o0000ooH9m_of2OH01_of2OH00ol0003ol`ccoo<<l`0;oo<<l`05o`000?om0_goo@;mood2oOl0
00003_oa3_400ol0003ol@kaoo4>l@08oo4>l@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?og2?Oom`SgooL8mol0
00000oom0_d00ol0003on0OhooP7n00:ooP7n004o`000?o]4^gokA;]o`0000?oo@;m0_l00008ooT6
n@03o`000?on0OkooP7n00KooP7n00?o0000oo8=l_ob3O802Oob3O800ol0003omPWfooH9mP05ooH9
mP03o`000?oc3??ol`cc00col`cc00?o0000ood2oOl000003ooa3_400ol0003ol@kaoo4>l@08oo4>
l@03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`SgooL8m`03ooL8m`03o`000?om0_go000000_o
n0Oh0_l00004ondBk@03o`000?om0_go000000_on@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
lPgboo8=lP09oo8=lP03o`000?of2OKomPWf00ComPWf00?o0000oo<<looc3?<03_oc3?<00ol0003o
l@kaoo4>l@0>oo4>l@03o`000?oa3_7ol@ka00Wol@ka00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooL8moog2?L0
1?og2?L00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]00GokA;]00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP05ooh1oP03o`000?ob3O;olPgb00[olPgb00?o0000ooH9m_of2OH0
0oof2OH00ol0003ol`ccoo<<l`0>oo<<l`03o`000?oa3_7ol@ka00gol@ka00?o0000oo4>lOoa3_40
2_oa3_400ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`SgooL8
m`05ooL8m`03o`000?oh1oSon0Oh00Oon0Oh0_l00008ondBk@03o`000?oi1_Won@Ki00_on@Ki00?o
0000ooh1o_on0Oh01?on0Oh00ol0003olPgboo8=lP0:oo8=lP04o`000?of2OKomPWfooH9mP?o0000
3ooc3?<00ol0003ol@kaoo4>l@0>oo4>l@03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooP7n?oh1oP01?oh1oP2o`0000_okA;]1?l0
0009ooT6n@03o`000?on0OkooP7n00?ooP7n00?o0000oo8=l_ob3O802oob3O801?l0003omPWfo`00
0?l00003omdRg@;o00003?oc3?<2o`00013ol@ka00?o0000oo4>lOoa3_402ooa3_400ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003om`Sg
ooL8m`07ooL8m`03o`000?oh1oSon0Oh00?on0Oh00?o0000ondBkOo]4^d02oo]4^d01?l0003odRgB
om8]d_oB;M85o`0000Gon@Ki00?o0000ooh1o_on0Oh00_on0Oh00ol0003olPgboo8=lP0<oo8=lP03
o`000?oM8]gogB;M00GogB;M0_l00008oo<<l`;o00000_oH9mP00ol0003ol@kaoo4>l@0=oo4>l@03
o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003om`SgooL8m`09ooL8m`03o`000?oh1oSon0Oh00;o0000
3Oo]4^d00ol0003odRgBom8]dP07om8]dPKo00000_on0Oh4o`0000golPgb00?o0000omdRgOoM8]d0
1ooM8]d2o`0000Gol`cc00?o0000omPWf?oH9mP00ooH9mP00ol0003ol@kaoo4>l@0<oo4>l@03o`00
0?oa3_7ol@ka00col@ka00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o
0000ooP7n?l000003oo]4^d00ol0003odRgBom8]dP0<om8]dP?o00001?oZ5NX3o`0000WolPgb00?o
0000omdRgOoM8]d02_oM8]d2o`000003oo<<lol0003o000000Oof2OH00?o0000oo4>lOoa3_402ooa
3_400ol0003ol@kaoo4>l@0<oo4>l@03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?og2?Oom`Sg00_om`Sg00?o0000
ondBkOo]4^d03_o]4^d00ol0003odRgBom8]dP0=om8]dP03o`000?oZ5N[ojQGZ00KojQGZ0ol00005
oo8=lP03o`000?oM8]gogB;M00gogB;M00?o0000omPWf?oH9mP02?oH9mP00ol0003ol@kaoo4>l@09
oo4>l@03o`000?oa3_7ol@ka00gol@ka00Co0000ood2oOom0_goo@;m1Ol00003oo@;m003o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooL8moog2?L02oog2?L2o`0000ookA;]00?o0000om8]d_oB;M803OoB;M800ol0003ojQGZonXEjP0:
onXEjP?o000000?olPgbo`000?oM8]d03ooM8]d00ol0003of2OHomPWf009omPWf003o`000?oa3_7o
l@ka00Sol@ka00?o0000oo4>lOoa3_403_oa3_43o`0000Som0_d00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?og2?Oom`Sg00Som`Sg0ol000000ooQ
7^7o0000ondBk@0>ondBk@03o`000?oB;M;odRgB00godRgB00?o0000onXEj_oZ5NX03OoZ5NX00ol0
003ogB;MomdRg@0?omdRg@03o`000?oH9mSof2OH00[of2OH2ol0000;oo4>l@Go00003?od2o@00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003ol`cco`000?on0Oko0000
00Som`Sg0ol00005on4Nh@03o`000?o]4^gokA;]00cokA;]00?o0000om8]d_oB;M803OoB;M800ol0
003ojQGZonXEjP0=onXEjP;o00004?oM8]d00ol0003of2OHomPWf00:omPWf003o`000?oC;=?odbcC
00OodbcC00?o0000oo4>lOoa3_400_oa3_47o`0000CofBKI00?o0000oo@;m?od2o@02_od2o@00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003ol`ccoo<<looc3?<2o`00
00Gom`Sg0ol00009on4Nh@;o00002oo]4^d00ol0003odRgBom8]dP0=om8]dP03o`000?oZ5N[ojQGZ
00gojQGZ00Co0000olLhaoo7><Oo00003ooM8]d00ol0003of2OHomPWf009omPWf003o`000?oC;=?o
dbcC00WodbcC1?l0000;omTVf@03o`000?od2oCom0_d00[om0_d00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo<<looc3?<01?oc3?<00ol0003om`Sgo`000002o`00
00cohAkQ00Co0000ol0o`?l0003o00002Oo]4^d00ol0003odRgBom8]dP0=om8]dP03o`000?oZ5N[o
jQGZ00gojQGZ00Go0000olLhaoo7><OoacS7o`00000=omdRg@03o`000?oH9mSof2OH00[of2OH00?o
0000om</dooC;=<02OoC;=<00ol0003ofBKIomTVf@0<omTVf@03o`000?od2oCom0_d00[om0_d00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo<<looc3?<01_oc3?<0
0ol0003ohAkQon4Nh@0<on4Nh@03o`000?o0?l3o`3o000;o`3o00_l00007ondBk@03o`000?oB;M;o
dRgB00codRgB00?o0000onXEj_oZ5NX03OoZ5NX00ol0003oacS7olLha`03olLha`03o`000?oM8]go
gB;M00[ogB;M00?o0000omPWf?oH9mP02_oH9mP00ol0003odbcCom</d`09om</d`03o`000?oI9]Wo
fBKI00cofBKI00?o0000oo@;m?od2o@02ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003ol`ccoo<<l`06oo<<l`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ol0o
`?o0?l001Oo0?l000ol0003okA;]ondBk@03ondBk@03o`000?oB;M;odRgB00godRgB00?o0000onXE
j_oZ5NX03OoZ5NX00ol0003oacS7olLha`04olLha`03o`000?oM8]gogB;M00WogB;M00?o0000omPW
f?oH9mP02OoH9mP00ol0003odbcCom</d`0:om</d`03o`000?oI9]WofBKI00cofBKI00?o0000oo@;
m?od2o@02ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l`ccoo<<l`07oo<<l`03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ol0o`?o0?l001_o0?l02o`0000?o
kA;]00?o0000om8]d_oB;M803OoB;M800ol0003ojQGZonXEjP0<onXEjP03o`000?o7><OoacS700Ko
acS700?o0000omdRgOoM8]d02?oM8]d00ol0003of2OHomPWf009omPWf003o`000?oC;=?odbcC00[o
dbcC00?o0000omTVfOoI9]T03?oI9]T00ol0003om0_doo@;m00;oo@;m003o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo<<looc3?<02?oc3?<00ol0003ohAkQon4Nh@0:on4Nh@03o`00
0?o0?l3o`3o000Wo`3o00_l000000oo]4^go0000om8]dP0<om8]dP?o00003_oZ5NX00ol0003oacS7
olLha`07olLha`03o`000?oM8]gogB;M00OogB;M00?o0000omPWf?oH9mP02OoH9mP00ol0003odbcC
om</d`0;om</d`03o`000?oI9]WofBKI00cofBKI00?o0000oo@;m?od2o@02_od2o@00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo<<looc3?<02_oc3?<00ol0003ohAkQon4N
h@09on4Nh@03o`000?o0?l3o`3o000_o`3o000?o0000om8]d_oB;M802_oB;M82o`0000?oZEJY00?o
0000onXEj_oZ5NX02_oZ5NX00ol0003oacS7olLha`09olLha`03o`000?oM8]gogB;M00KogB;M00?o
0000omPWf?oH9mP02?oH9mP00ol0003odbcCom</d`0<om</d`03o`000?oI9]WofBKI00cofBKI00?o
0000oo@;m?od2o@02_od2o@00ol0003ooP7nooh1oP04ooh1oPCo00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on4NhOoQ7^402?oQ7^40
0ol0003o`3o0ol0o`00<ol0o`003o`000?oB;M;odRgB00SodRgB0_l00006ojUFZ@;o00002_oZ5NX0
0ol0003oacS7olLha`0:olLha`03o`000?oM8]gogB;M00GogB;M00?o0000omPWf?oH9mP02?oH9mP0
0ol0003odbcCom</d`0<om</d`03o`000?oI9]WofBKI00cofBKI00?o0000oo@;m?od2o@02ood2o@0
0ol0003ooP7no`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo<<l`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ol0o`?o0?l003_o0?l000ol0003odRgBom8]dP04
om8]dP?o00002_nYEZT00ol0003ojQGZonXEjP07onXEjP03o`000?o7><OoacS700_oacS700?o0000
omdRgOoM8]d00ooM8]d00ol0003of2OHomPWf009omPWf003o`000?oC;=?odbcC00codbcC00?o0000
omTVfOoI9]T03?oI9]T00ol0003om0_doo@;m00;oo@;m0;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003ol`ccoo<<l`0<oo<<l`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ol0o`?o0?l003oo0?l001?l0
003odRgBom8]d_oB;M82o`0000koZEJY0_l00006onXEjP03o`000?o7><OoacS700goacS700?o0000
omdRgOoM8]d00_oM8]d00ol0003of2OHomPWf008omPWf003o`000?oC;=?odbcC00codbcC0ol0000=
omTVf@03o`000?od2oCom0_d00_om0_d00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00ool`cc00?o0000on4NhOoQ7^401_oQ7^400ol0003o`3o0ol0o`00@ol0o`0Co00004_nYEZT00ol0
003ojQGZonXEjP03onXEjP03o`000?o7><OoacS700koacS700Go0000omdRgOoM8]gogB;Mo`000005
omPWf0Oo00003?oC;=<01Ol0003o/dbcok=</oncC;?o000000cofBKI00?o0000oo@;m?od2o@02?od
2o@3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000ool`cc00?o0000on4NhOoQ7^401_oQ7^400ol0003o`3o0ol0o`00=
ol0o`0?o000000CoRGJ9o`000?l0003o00004onYEZT2o`0000;ojQGZ00?o0000olLhaoo7><L04?o7
><L00ol0003ogB;Mo`000006o`0000Oo]TVf00?o0000om</dooC;=<02?oC;=<00ol0003o/dbcok=<
/`03ok=</`;o00002?oI9]T3o`0000Kom0_d1?l00002oo4>l@03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003on@Kio`000?oK9=/3o`0000gol`cc00?o0000on4NhOoQ7^401?oQ7^400ol0003o`3o0ol0o
`00;ol0o`0?o00000on9MXT01Ol0003oPWf2o`000?mC[5?o000001CoZEJY00?o0000onXEj_l00000
4oo7><L00ol0003o]TVfokI9]P0=okI9]P03o`000?oC;=?odbcC00GodbcC0_l00008ok=</`03o`00
0?oI9]WofBKI00Go00000ooF:MH00ol0003om0_doo@;m003o`0000Ool@ka00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oi1_Won@Kio`0000CofbCK0ol0000:oo<<l`03o`000?oQ7^7ohAkQ00?ohAkQ
00?o0000ol0o`?o0?l002Oo0?l03o`0000GoRGJ900Co0000oh9mP_n2OH;o00000_mC[5<00ol0003o
ZEJYojUFZ@0BojUFZ@03o`000?o7><OoacS701;oacS700?o0000okI9]_nfBKH03_nfBKH00ol0003o
dbcCom</d`03om</d`03o`000?ncC;?o/dbc00Wo/dbc0_l00009omHYeP;o00002_oa3_400ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooT6nOoi1_Won@Kio`000007om/Tf`;o00001ooc3?<5o`0000;o
hAkQ00?o0000ol0o`?o0?l001_o0?l03o`0000SoRGJ900Co0000oh9mP_n2OH;o00000omC[5<00ol0
003oZEJYojUFZ@0AojUFZ@03o`000?o7><OoacS7017oacS700?o0000okI9]_nfBKH04?nfBKH01Ol0
003odbcCom</dooC;=?o000000co/dbc00?o0000omHYe_oF:MH02?oF:MH00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Con@Ki00?o0000om/TfooK9=/01ooK9=/3o`00
0004oo<<lol0003o0000o`0000Gob3O80_l00006ol0o`0?o00002_n9MXT01Ol0003oPWf2oh9mP_n2
OH;o000000CoDjaC00?o0000ojUFZOnYEZT04?nYEZT00ol0003oacS7olLha`0AolLha`03o`000?nf
BKKo]TVf017o]TVf00?o0000om</dol000003OncC;<00ol0003oeRWFomHYeP08omHYeP03o`000?oa
3_7ol@ka00[ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000
om/TfooK9=/02_oK9=/00ol0003ob3O8olPgb008olPgb003o`000?o0?l3o`3o000?o00003On9MXT0
1Ol0003oPWf2oh9mP_n2OH;o000000GoDjaC00?o0000ojUFZOnYEZT03onYEZT00ol0003oacS7olLh
a`0AolLha`03o`000?nfBKKo]TVf01;o]TVf00?o0000ok=</oncC;<03?ncC;<00ol0003oeRWFomHY
eP08omHYeP03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooT6nOoi1_T01Ooi1_T0
0ol0003ofbCKom/Tf`0:om/Tf`03o`000?o8=lSob3O800Wob3O80_l0000?ohUfR@03o`000?n2OH;o
PWf200;oPWf200?o0000oe>/DomC[5<01?mC[5<00ol0003oZEJYojUFZ@0=ojUFZ@?o00004Oo7><L0
0ol0003o]TVfokI9]P0CokI9]P03o`000?ncC;?o/dbc00_o/dbc00?o0000omHYe_oF:MH02OoF:MH0
0ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ooh1oP;o00002?oi1_T0
0ol0003ofbCKom/Tf`0:om/Tf`03o`000?o8=lSob3O800Wob3O800?o0000ohUfROn9MXT03On9MXT0
0ol0003oPWf2oh9mPP03oh9mPP03o`000?mC[5?oDjaC00GoDjaC00?o0000ojUFZOnYEZT02_nYEZT2
o`0000?oNXEj00?o0000olLhaoo7><L03_o7><L00ol0003o]TVfokI9]P0CokI9]P03o`000?ncC;?o
/dbc00_o/dbc00?o0000omHYe_oF:MH02OoF:MH00ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000GooP7n00?o0000ooT6nOoi1_T01ooi1_T2o`0000_ofbCK00?o0000olPg
b?o8=lP02oo8=lP00ol0003oRGJ9ohUfR@0<ohUfR@03o`000?n2OH;oPWf200?oPWf200?o0000oe>/
DomC[5<01_mC[5<00ol0003oZEJYojUFZ@07ojUFZ@;o00001_mjQGX2o`0000koacS700?o0000okI9
]_nfBKH04onfBKH00ol0003o/dbcok=</`0;ok=</`03o`000?oF:MKoeRWF00WoeRWF00?o0000oo4>
lOoa3_403?oa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ooh1o_on0OkooP7no`000009ooT6
n@03o`000?oa3_7o000000_ofbCK00?o0000olPgb?o8=lP02oo8=lP00ol0003oRGJ9ohUfR@0;ohUf
R@03o`000?n2OH;oPWf200CoPWf200?o0000oe>/DomC[5<01omC[5<00ol0003oZEJYojUFZ@05ojUF
Z@03o`000?mjQG[oNXEj00SoNXEj00?o0000olLhaoo7><L02_o7><L00ol0003o]TVfokI9]P0DokI9
]P03o`000?ncC;?o/dbc00_o/dbc00?o0000omHYe_oF:MH02OoF:MH00ol0003ol@kaoo4>l@0<oo4>
l@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7no`000009ooT6n@04o`000?oa3_7ol@kao`00
00_ofbCK00?o0000olPgb?o8=lP02oo8=lP00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?n2OH;oPWf2
00CoPWf200?o0000oe>/DomC[5<02?mC[5<00ol0003oZEJYojUFZ@02ojUFZ@;o00003?mjQGX2o`00
00[oacS700?o0000okI9]_nfBKH05?nfBKH00ol0003o/dbcok=</`0;ok=</`03o`000?oF:MKoeRWF
00WoeRWF00?o0000oo4>lOoa3_403Ooa3_400ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03
o`000?oa3_7ol@ka00;ol@ka00?o0000om/TfooK9=/02?oK9=/00ol0003ob3O8olPgb00<olPgb003
o`000?n9MXWoRGJ900WoRGJ900?o0000oh9mP_n2OH801On2OH800ol0003oDjaCoe>/D`09oe>/D`04
o`000?nYEZWo0000o`00013oNXEj0_l00008olLha`03o`000?nfBKKo]TVf01Co]TVf0ol0000;ok=<
/`03o`000?oF:MKoeRWF00WoeRWF00?o0000oo4>lOoa3_403Ooa3_401?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003on@KiooT6n@06ooT6n@03o`000?oa3_7ol@ka00?ol@ka00?o0000om/T
fooK9=/02?oK9=/00ol0003ob3O8olPgb00;olPgb0;o00002_n9MXT00ol0003oPWf2oh9mPP06oh9m
PP03o`000?mC[5?oDjaC00[oDjaC00?o0000ogZ5N_mjQGX04_mjQGX00ol0003oacS7olLha`04olLh
a`03o`000?nfBKKo]TVf01Go]TVf00?o0000oiiQW_nNHIh01Ol00005ok=</`03o`000?oF:MKoeRWF
00[oeRWF00?o0000oo4>lOoa3_403_oa3_43o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003on@KiooT6n@04ooT6n@03
o`000?oa3_7ol@ka00Col@ka00?o0000om/TfooK9=/01ooK9=/00ol0003ob3O8olPgb00;olPgb004
o`000?mnPGkoOX5no`0000WoRGJ900?o0000oh9mP_n2OH801_n2OH800ol0003oDjaCoe>/D`0:oe>/
D`03o`000?mjQG[oNXEj01?oNXEj0_l00003olLha`Co00005?nfBKH00ol0003oWV6NoiiQWP06oiiQ
WPCo000000?o/dbco`000?oF:MH02ooF:MH00ol0003ol@kaoo4>l@0>oo4>l@03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003on@KiooT6n@03ooT6n@03o`000?oa3_7ol@ka00Gol@ka00?o0000om/TfooK
9=/01ooK9=/00ol0003ob3O8olPgb009olPgb0;o00001?mnPGh00ol0003oRGJ9ohUfR@05ohUfR@03
o`000?n2OH;oPWf200OoPWf200?o0000oe>/DomC[5<02_mC[5<00ol0003oNXEjogZ5NP0EogZ5NP03
o`000?o7><Oo000000CoSG:=0ol0000@okI9]P03o`000?nNHIkoWV6N00_oWV6N0_l0000<omHYeP03
o`000?oa3_7ol@ka00col@ka0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooT6nOoi1_T00_oi1_T00ol0003ol@ka
oo4>l@06oo4>l@03o`000?oK9=_ofbCK00OofbCK00?o0000olPgb?o8=lP02?o8=lP00ol0003oOX5n
ogj1OP05ogj1OP03o`000?n9MXWoRGJ900CoRGJ900?o0000oh9mP_n2OH801on2OH800ol0003oDjaC
oe>/D`0:oe>/D`03o`000?mjQG[oNXEj01KoNXEj00?o0000ohebSOn=LXd01_n=LXd3o`0000co]TVf
00?o0000oiiQW_nNHIh03OnNHIh00ol0003oeRWFomHYeP09omHYePGo00002Ooa3_42o`000003ooD:
mOl0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooT6nOl0003ol@ka00Wol@ka00?o0000om/TfooK9=/01_oK
9=/00ol0003ob3O8olPgb007olPgb003o`000?mnPGkoOX5n00OoOX5n00?o0000ohUfROn9MXT00_n9
MXT00ol0003oPWf2oh9mPP08oh9mPP03o`000?mC[5?oDjaC00WoDjaC00?o0000ogZ5N_mjQGX05omj
QGX00ol0003oSG:=ohebS@09ohebS@?o00002OnfBKH00ol0003oWV6NoiiQWP0>oiiQWPKo00001?oF
:MH00ol0003oh1oPon0Oh003on0Oh0Go00000_oa3_42o`0000Com@[e00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?ob3O;olPgboo8=l_l000002ooa3_400ol0003ofbCKom/Tf`06om/Tf`03o`000?o8
=lSob3O800Gob3O80_l0000;ogj1OP04o`000?n9MXWoRGJ9o`0000_oPWf200?o0000oe>/DomC[5<0
2OmC[5<00ol0003oNXEjogZ5NP0FogZ5NP03o`000?n=LXgoSG:=00goSG:=0ol00005okI9]P03o`00
0?nNHIkoWV6N00ooWV6N00?o0000okI9]_nfBKH00onfBKH4o`0000_oh1oP0_l00006ooD:m@03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP02oo8=lPko00001_oK9=/00ol0003ob3O8olPg
b005olPgb003o`000?mnPGkoOX5n00coOX5n00?o0000ohUfROl000002on2OH800ol0003oDjaCoe>/
D`07oe>/D`?o00006?mjQGX00ol0003oSG:=ohebS@0@ohebS@?o000000?o]TVfo`000?nNHIh04?nN
HIh00ol0003o]TVfokI9]P07okI9]P03o`000?oP7n3oh1oP00[oh1oP00?o0000ooD:mOoe2_D01Ooe
2_D00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005oo8=lP03o`000?oK9=_ofbCK00_ofbCK0_l00004
om/Tf`03o`000?o8=lSob3O800?ob3O80_l0000@ogj1OP03o`000?n2OH;oPWf200[oPWf200?o0000
oe>/DomC[5<00omC[5<4o`0000;o;]4^00?o0000ogZ5N_mjQGX05OmjQGX00ol0003oSG:=ohebS@0D
ohebS@03o`000?nNHIkoWV6N013oWV6N00?o0000okI9]_nfBKH01onfBKH00ol0003oh1oPon0Oh00:
on0Oh003o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;olPgb
00GolPgb00?o0000om/TfooK9=/03OoK9=/6o`0000?ob3O800?o0000ogj1O_mnPGh04?mnPGh00ol0
003oPWf2oh9mPP0:oh9mPP03o`000?mC[5?o000000?o00001ol^dBh00ol0003oNXEjogZ5NP0DogZ5
NP03o`000?n=LXgoSG:=01CoSG:=00?o0000oiiQW_nNHIh03onNHIh00ol0003o]TVfokI9]P08okI9
]P03o`000?oP7n3oh1oP00[oh1oP00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo8=l_ob3O801_ob3O800ol0003ofbCKom/Tf`0=om/Tf`03o`000?nkA;_o^dBk00?o
^dBk00?o0000olPgb?l000004omnPGh4o`0000WoPWf20_l0000<obkA;P03o`000?mjQG[oNXEj01?o
NXEj00?o0000ohebSOn=LXd05On=LXd00ol0003oWV6NoiiQWP0>oiiQWP03o`000?nfBKKo]TVf00So
]TVf00?o0000on0Oh?oP7n002OoP7n000ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?ob3O;olPgb00SolPgb00?o0000om/TfooK9=/02ooK9=/00ol0003o^dBkok]4^`05ok]4^`03o`00
0?mnPGkoOX5n01;oOX5n00Co0000oc[5>_ljaC[o>/Dj1Ol00003oh9mPP03o`000?l^dBko;]4^00go
;]4^0ol0000@ogZ5NP;o00006?n=LXd00ol0003oWV6NoiiQWP0=oiiQWP03o`000?nfBKKo]TVf00Wo
]TVf00?o0000on0Oh?oP7n002OoP7n000ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_olPgb00?o0000om/TfooK9=/02_oK9=/00ol0003o^dBkok]4^`06ok]4^`03o`00
0?mnPGkoOX5n017oOX5n00?o0000oc[5>_ljaCX01oljaCX3o`00013o;]4^00?o0000oaKY5_lFjAH0
1Ol00009ogZ5NP;o000000?o<<l`o`000?n=LXd05on=LXd00ol0003oWV6NoiiQWP0=oiiQWP03o`00
0?nfBKKo]TVf00Wo]TVf00?o0000on0Oh?oP7n002?oP7n02o`0000[om@[e00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oi1_Won@Ki00;on@Ki00?o0000oo8=l_ob3O802Oob3O800ol0003ofbCKom/T
f`0:om/Tf`03o`000?nkA;_o^dBk00Oo^dBk00?o0000ogj1O_mnPGh03omnPGh00ol0003o>/Djoc[5
>P0:oc[5>P03o`000?l^dBko;]4^00go;]4^00?o0000oaKY5_lFjAH01_lFjAH4o`0000CoNXEj00?o
0000oc3?<?l`cc000_l`cc000ol0003oSG:=ohebS@0FohebS@03o`000?nNHIkoWV6N00_oWV6N00?o
0000okI9]_nfBKH02onfBKH00ol0003oh1oPon0Oh006on0Oh003o`000?o_4>oo000000[om@[e00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00?on@Ki00?o0000oo8=l_ob3O802?ob3O8=
o`0000[o^dBk00?o0000ogj1O_mnPGh03omnPGh00ol0003o>/Djoc[5>P0;oc[5>P03o`000?l^dBko
;]4^00co;]4^00?o0000oaKY5_lFjAH02_lFjAH4o`0000Go<<l`00?o0000ohebSOn=LXd05_n=LXd0
0ol0003oWV6NoiiQWP0:oiiQWP03o`000?nfBKKo]TVf00co]TVf00?o0000on0Oh?oP7n001?oP7n02
o`0000?oka3_00?o0000ooD:mOoe2_D02?oe2_D00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooT6
nOoi1_T00ooi1_T00ol0003olPgboo8=lP07oo8=lP03o`000?oI9]WofBKI00WofBKI00?o0000ok]4
^onkA;/02OnkA;/00ol0003oOX5nogj1OP0=ogj1OP03o`000?ljaC[o>/Dj00co>/Dj00?o0000obkA
;_l^dBh03?l^dBh00ol0003o5^TFoaKY5P0;oaKY5P03o`000?l6n@Ko000000Ko<<l`00?o0000oheb
SOn=LXd05_n=LXd00ol0003oWV6NoiiQWP09oiiQWP03o`000?nfBKKo]TVf00co]TVf00?o0000on0O
h?oP7n000ooP7n000ol0003oka3_onl@k`03onl@k`03o`000?oe2_Gom@[e00Som@[e00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000oo8=l_ob3O801_ob3O800ol0003o
fBKIomTVf@08omTVf@03o`000?nkA;_o^dBk00_o^dBk00?o0000ogj1O_mnPGh02?mnPGh4o`0000oo
>/Dj00?o0000obkA;_l^dBh02ol^dBh00ol0003o5^TFoaKY5P0;oaKY5P04o`000?l6n@Ko1_T6o`00
00Oo<<l`00?o0000ohebSOn=LXd05On=LXd00ol0003oWV6NoiiQWP08oiiQWP03o`000?nfBKKo]TVf
00go]TVf00?o0000on0Oh?oP7n000_oP7n000ol0003oka3_onl@k`05onl@k`03o`000?oe2_Gom@[e
00Oom@[e00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Gon@Ki00?o0000oo8=l_ob
3O801Oob3O800ol0003ofBKIomTVf@08omTVf@03o`000?nkA;_o^dBk00_o^dBk00?o0000ogj1O_mn
PGh00omnPGh5o`0000?o?<<l00?o0000oc[5>_ljaCX03_ljaCX00ol0003o;]4^obkA;P0:obkA;P03
o`000?lFjAKo5^TF00[o5^TF00Go0000o`Ki1_l6n@Ko1_T6o`000007oc3?<003o`000?n=LXgoSG:=
01GoSG:=00?o0000oiiQW_nNHIh02?nNHIh00ol0003o]TVfokI9]P0=okI9]P03o`000?oP7n3oh1oP
00;o00002?o_4>l00ol0003om@[eooD:m@08ooD:m@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?ob3O;olPgb00Go
lPgb00?o0000omTVfOoI9]T02?oI9]T00ol0003o^dBkok]4^`0<ok]4^`Go00002Oll`c`00ol0003o
>/Djoc[5>P0<oc[5>P;o00003?l^dBh00ol0003o5^TFoaKY5P0:oaKY5P05o`000?l6n@Ko1_T6o`Ki
1_l000002?l`cc000ol0003oSG:=ohebS@0DohebS@?o00001onNHIh00ol0003o]TVfokI9]P0>okI9
]P03o`000?oP7n3o000000_oka3_00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003olPgboo8=lP04oo8=lP03o`000?oI9]WofBKI00Oo
fBKI00?o0000ok]4^onkA;/03?nkA;/01?l0003oOX5nogj1O_l0000;occ3?003o`000?ljaC[o>/Dj
00_o>/Dj00Co0000o`7n0Ol1oP7o00002_l^dBh00ol0003o5^TFoaKY5P0:oaKY5P03o`000?l6n@Ko
1_T600;o1_T600?o0000oc3?<?l`cc001_l`cc000ol0003oSG:=ohebS@0AohebS@?o00000omWV6L0
0ol0003oWV6NoiiQWP04oiiQWP03o`000?nfBKKo]TVf00go]TVf1?l0000;onl@k`03o`000?oe2_Go
m@[e00Gom@[e00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00Co0000oo8=
l_ob3O;olPgb1?l00008omTVf@03o`000?nkA;_o^dBk00_o^dBk00?o0000ogj1O_mnPGh00_mnPGh0
0ol0003o?<<locc3?008occ3?003o`000?ljaC[o>/Dj00[o>/Dj00?o0000o`7n0Ol1oP400_l1oP40
0ol0003o;]4^obkA;P03obkA;PGo00002olFjAH00ol0003o1_T6o`Ki1P03o`Ki1P03o`000?l`cc3o
<<l`00Oo<<l`00?o0000ohebSOn=LXd03_n=LXd2o`0000OoIiQW00?o0000oiiQW_nNHIh00_nNHIh0
0ol0003o]TVfokI9]P0=okI9]P03o`000?oM8]gogB;M00;ogB;M00?o0000onl@koo_4>l02Oo_4>l0
0ol0003om@[eooD:m@03ooD:m@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@07ooT6
n@?o00001?oR7N800ol0003ofBKIomTVf@05omTVf@03o`000?nkA;_o^dBk00[o^dBk00?o0000ogj1
O_mnPGh00omnPGh00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00So>/Dj00?o0000o`7n
0Ol1oP401?l1oP45o`0000Co0?l000?o0000oaKY5_lFjAH02OlFjAH00ol0003o1_T6o`Ki1P03o`Ki
1P03o`000?l`cc3o<<l`00So<<l`00?o0000ohebSOn=LXd02_n=LXd3o`0000[oIiQW00Go0000oiiQ
W_nNHIkoWV6No`00000>okI9]P03o`000?oM8]gogB;M00CogB;M0_l00009onl@k`03o`000?oe2_Go
m@[e00;om@[e00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000on8M
h_oR7N801OoR7N800ol0003ofBKIomTVf@03omTVf@03o`000?nkA;_o^dBk00[o^dBk00?o0000ogj1
O_mnPGh01?mnPGh00ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Oo>/Dj00?o0000o`7n
0Ol1oP401Ol1oP400ol0003o0?l0o`3o0007o`3o0003o`000?lFjAKo5^TF00Oo5^TF00?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o<<l`oc3?<008oc3?<003o`000?n=LXgoSG:=00SoSG:=0_l0000>ofNH
I`Co00003?nfBKH2o`0000WogB;M00?o0000onl@koo_4>l01oo_4>l01?l0003om@[eooD:mOl0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ohQgRon8MhP07on8MhP;o00000ooI9]T00ol0
003o^dBkok]4^`09ok]4^`03o`000?mnPGkoOX5n00KoOX5n00?o0000occ3??ll`c`02Oll`c`00ol0
003o>/Djoc[5>P05oc[5>P03o`000?l1oP7o0Oh100Ko0Oh100?o0000o`3o0?l0o`002?l0o`000ol0
003o5^TFoaKY5P06oaKY5P03o`000?l6n@Ko1_T600Co1_T600?o0000oc3?<?l`cc002Ol`cc04o`00
00?oSG:=0ol0000@ofNHI`05o`000?o5>/GoaC[5olDjaOl000002_nfBKH00ol0003ogB;MomdRg@0:
omdRg@Ko00000oo_4>l00ol0003om@[eo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0
003ohQgRon8MhP0:on8MhP04o`000?oI9]WofBKIo`0000[o^dBk00?o0000ogj1O_mnPGh01omnPGh0
0ol0003o?<<locc3?009occ3?003o`000?ljaC[o>/Dj00Co>/Dj00?o0000o`7n0Ol1oP401ol1oP40
0ol0003o0?l0o`3o0008o`3o00;o00001_lFjAH00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?l`cc3o
<<l`00Wo<<l`00Co0000obgB;Ol]dRgo;M8]0ol0000BofNHI`03o`000?o5>/GoaC[500?oaC[50_l0
0006okI9]P;o00003OoM8]d00ol0003om`SgooL8m`03ooL8m`Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooT6nOoi1_T00ooi1_T0
0ol0003ohQgRon8MhP0<on8MhP;o00002_nkA;/00ol0003oOX5nogj1OP08ogj1OP03o`000?ll`cco
?<<l00[o?<<l00?o0000oc[5>_ljaCX00_ljaCX00ol0003o0Oh1o`7n0@08o`7n0@03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lFjAKo5^TF00;o5^TF00?o0000o`Ki1_l6n@H01_l6n@H0
0ol0003o<<l`oc3?<008oc3?<003o`000?l]dRgo;M8]00Co;M8]00?o0000ofNHIomWV6L03omWV6L0
0ol0003oaC[5olDja@06olDja@;o00000onfBKH00ol0003ogB;MomdRg@0=omdRg@03o`000?og2?Oo
m`Sg00Oom`Sg0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on@KiooT6n@02ooT6n@03o`000?oR7N;ohQgR
00kohQgR00?o0000ok]4^onkA;/01onkA;/00ol0003oOX5nogj1OP0:ogj1OP03o`000?ll`cco?<<l
00Wo?<<l00Go0000oc[5>_ljaC[o>/Djo`00000;o`7n0@03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lFjAKo5^TFoaKY5_l000002?l6n@H00ol0003o<<l`oc3?<008oc3?<003o`000?l]
dRgo;M8]00Go;M8]00?o0000ofNHIomWV6L03_mWV6L00ol0003oaC[5olDja@08olDja@03o`000?nf
BKKo000000oogB;M00?o0000ooL8moog2?L02?og2?L01?l0003oo@;mo`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oi1_Won@Kio`00017ohQgR00?o0000ok]4^onkA;/01_nkA;/00ol0003oOX5n
ogj1OP0;ogj1OP03o`000?ll`cco?<<l00Wo?<<l00Co0000oc[5>_ljaC[o00003?l1oP400ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5^TFo`000009o`Ki1P03o`000?l`cc3o<<l`00So
<<l`00?o0000obgB;Ol]dRd01Ol]dRd00ol0003oIiQWofNHI`0=ofNHI`03o`000?o5>/GoaC[500[o
aC[500?o0000omdRgOoM8]d03_oM8]d00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00;o
o@;m00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bon8MhP03o`00
0?nkA;_o^dBk00Co^dBk00?o0000ogj1O_mnPGh03?mnPGh00ol0003o?<<locc3?00:occ3?0?o0000
3?l1oP400ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Ki1_l6n@H02?l6n@H00ol0003o<<l`
oc3?<007oc3?<003o`000?l]dRgo;M8]00Oo;M8]00?o0000ofNHIomWV6L03?mWV6L00ol0003oaC[5
olDja@0;olDja@;o00003_oM8]d00ol0003om`SgooL8m`07ooL8m`03o`000?om0_goo@;m00?oo@;m
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L00oog2?L00ol0003ohQgRon8MhP0?on8MhP?o00000onk
A;/00ol0003oOX5nogj1OP0>ogj1OP03o`000?ll`cco?<<l00So?<<l00Co0000o`Wf2Ol9mPWo2OH9
0_l0000:o`7n0@?o00003Ol0o`000ol0003o1_T6o`Ki1P08o`Ki1P03o`000?l`cc3o<<l`00Oo<<l`
00?o0000obgB;Ol]dRd01ol]dRd00ol0003oIiQWofNHI`0;ofNHI`03o`000?o5>/GoaC[500coaC[5
00?o0000onl@kol000000_l0000:omdRg@03o`000?og2?Oom`Sg00Som`Sg00?o0000ood2oOom0_d0
1Oom0_d2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`04ooL8m`03o`000?oR7N;ohQgR00cohQgR0_l0
0003om4^d@03o`000?nkA;_o0000017oOX5n00?o0000occ3??ll`c`01oll`c`00ol0003o2OH9o`Wf
2@04o`Wf2@;o00002?l1oP400ol0003o0?l0o`3o000>o`3o00;o00002?l6n@H00ol0003o<<l`oc3?
<006oc3?<003o`000?l]dRgo;M8]00Wo;M8]00?o0000ofNHIomWV6L02OmWV6L00ol0003oaC[5olDj
a@0=olDja@03o`000?o_4>ooka3_00;oka3_0ol00007omdRg@03o`000?og2?Oom`Sg00Oom`Sg00?o
0000ood2oOom0_d02?om0_d2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`000?oR7N;o
hQgR00WohQgR0_l00006om4^d@03o`000?mnPGkoOX5n013oOX5n00?o0000occ3??ll`c`01_ll`c`0
0ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100Co0Oh10ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol6n@H00ol0003o<<l`oc3?<006oc3?<003o`000?l]dRgo;M8]00[o;M8]00?o0000
ofNHIomWV6L02?mWV6L00ol0003oaC[5olDja@0=olDja@03o`000?o_4>ooka3_00Goka3_0ol00004
omdRg@03o`000?og2?Oom`Sg00Oom`Sg00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om`SgooL8m`06ooL8m`03o`000?oR7N;ohQgR00GohQgR0ol00008om4^d@03o`000?mnPGkoOX5n
017oOX5n00Co0000occ3??ll`cco?<<l1?l0000;o`Wf2@;o000000Co0Oh1o`000?l0003o00000ol4
n`@2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1_T600?o0000oc3?<?l`cc001_l`
cc000ol0003o;M8]obgB;@0:obgB;@03o`000?mWV6OoIiQW00OoIiQW00?o0000olDjaOo5>/D03_o5
>/D00ol0003oka3_onl@k`08onl@k`Co00002_og2?L00ol0003oo@;mood2o@0;ood2o@;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003om`SgooL8m`07ooL8m`03o`000?oR7N;ohQgR00;ohQgR0_l0000<om4^d@03o`000?mnPGko
OX5n013oOX5n1?l00003oc3?<003o`000?l9mPWo2OH900_o2OH900?o0000o`Ck1?l4n`@01_l4n`@0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obgB;@03o`000?mWV6Oo
IiQW00KoIiQW00?o0000olDjaOo5>/D03_o5>/D00ol0003oka3_onl@k`0;onl@k`03o`000?og2?Oo
m`Sg00Oom`Sg00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00Co0000on8M
h_l0003o00003_oA;]400ol0003oOX5nogj1OP0?ogj1OP03o`000?l`cc3o<<l`00Ko<<l`00?o0000
o`Wf2Ol9mPT02_l9mPT00ol0003o1?/4o`Ck1007o`Ck10;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l`cc3o<<l`00So<<l`00?o0000obgB;Ol]dRd03?l]dRd00ol0003oIiQWofNHI`05
ofNHI`03o`000?o5>/GoaC[500ooaC[50_l0000=onl@k`03o`000?og2?Oom`Sg00Kom`Sg00?o0000
ood2oOom0_d03_om0_d00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00[om`Sg00?o0000om4^dOoA;]403_oA;]400ol0
003oOX5nogj1OP0>ogj1OP03o`000?l`cc3o<<l`00Oo<<l`00?o0000o`Wf2Ol9mPT02_l9mPT00ol0
003o1?/4o`Ck1009o`Ck10;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l`cc3o<<l`
00Wo<<l`00?o0000obgB;Ol]dRd02_l]dRd4o`0000CoIiQW00?o0000olDjaOo5>/D04?o5>/D01?l0
003okA;]o`000?l0000<onl@k`03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d03Oom0_d0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?og2?Oom`Sg00[om`Sg00?o0000om4^dOoA;]403ooA;]4@o`0000[o<<l`00?o0000o`Wf
2Ol9mPT02Ol9mPT00ol0003o0?l0o`00000<o`Ck1005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o<<l`oc3?<009oc3?<003o`000?l]dRgo;M8]00Oo;M8]0ol00004of>LH`?o000000?oIiQW
o`000?o5>/D04Oo5>/D01?l0003okA;]ondBkOo]4^d2o`0000_oka3_00?o0000ooL8moog2?L00oog
2?L00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02_og2?L00ol0003odBkAom4^d@0?
om4^d@03o`000?mkQ7_oNhAk00coNhAk00?o0000oc3?<?l`cc002Ol`cc000ol0003o2OH9o`Wf2@07
o`Wf2@04o`000?l0o`3o0?l0o`0000go1?/400Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l`cc3o<<l`00[o<<l`00?o0000obgB;Ol]dRd00ol]dRd3o`0000[oHiaS00?o0000olDjaOo5>/D0
4?o5>/D00ol0003okA;]ondBk@04ondBk@;o00002_o_4>l00ol0003om`SgooL8m`04o`0000ooo@;m
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000com`Sg00?o0000om4^dOoA;]403ooA;]400ol0003oNhAkog^4N`0<og^4N`03o`000?l`
cc3o<<l`00Wo<<l`00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o0?l0o`3o0002o`3o0003o`000?l4
n`Co1?/400[o1?/400?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l`
cc3o<<l`00[o<<l`00?o0000obgB;Ol]dRd00ol0000=of>LH`03o`000?o5>/GoaC[5013oaC[500?o
0000ondBkOo]4^d01_o]4^d2o`0000Woka3_0_l00004ood2o@03o`000?om0_goo@;m00_oo@;m00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003odBkAom4^d@0=om4^d@?o00003omkQ7/0
0ol0003o<<l`oc3?<008oc3?<003o`000?l9mPWo2OH900Go2OH900?o0000o`3o0?l0o`000ol0o`00
0ol0003o1?/4o`Ck100:o`Ck1003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o<<l`oc3?<00;oc3?<0;o00004OmSW6<00ol0003oaC[5olDja@0?olDja@03o`000?o]4^go
kA;]00SokA;]0_l00007onl@k`03o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooL8moog2?L02?og2?L00ol0003odBkAom4^d@09om4^d@Go00000_nZEJX00ol0
003oNhAkog^4N`0=og^4N`03o`000?l`cc3o<<l`00Wo<<l`00?o0000o`Wf2Ol9mPT01?l9mPT00ol0
003o0?l0o`3o0004o`3o0003o`000?l4n`Co1?/400So1?/400?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l`cc3o<<l`00_o<<l`00?o0000of>LHomSW6<04?mSW6<00ol0
003oaC[5olDja@0?olDja@03o`000?o]4^gokA;]00[okA;]0_l00004onl@k`03o`000?om0_goo@;m
00Koo@;m0_l0000:ood2o@03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003om`SgooL8m`07ooL8m`03o`000?oA;]7odBkA00CodBkA1Ol00007ojYEZP03
o`000?mkQ7_oNhAk00goNhAk00?o0000oc3?<?l`cc002Ol`cc000ol0003o2OH9o`Wf2@03o`Wf2@03
o`000?l0o`3o0?l000Go0?l000?o0000o`Ck1?l4n`@02?l4n`@00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000oc3?<?l`cc002ol`cc000ol0003oHiaSof>LH`0@of>LH`03
o`000?o5>/GoaC[500ooaC[500?o0000ondBkOo]4^d03?o]4^d2o`000003onl@kol0003oo@;m00[o
o@;m00?o0000ood2oOom0_d01_om0_d00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000om4^dOl00000
1?l0000<ojYEZP03o`000?mkQ7_oNhAk00koNhAk00?o0000oc3?<?l`cc002?l`cc000ol0003o2OH9
o`Wf2@02o`Wf2@03o`000?l0o`3o0?l000Oo0?l000?o0000o`Ck1?l4n`@01ol4n`@00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000oc3?<?l`cc002ol`cc000ol0003oHiaS
of>LH`0Aof>LH`03o`000?o5>/GoaC[500goaC[500?o0000ondBkOo]4^d03oo]4^d00ol0003oo@;m
ood2o@0;ood2o@;o00001Oom0_d2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooL8moog2?L01Oog2?L3o`00017oZUFZ00?o0000og^4NomkQ7/03_mk
Q7/00ol0003o<<l`oc3?<009oc3?<004o`000?l9mPWo2OH9o`0000[o0?l000?o0000o`Ck1?l4n`@0
1ol4n`@00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol`cc000ol0003o
HiaSof>LH`0Aof>LH`?o00003Oo5>/D00ol0003okA;]ondBk@0?ondBk@03o`000?om0_goo@;m00go
o@;m00Go0000ood2oOom0_goo@;mo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_og2?L2o`0000;oiQWV00?o0000ojYEZ_nZEJX03onZEJX00ol0003o
NhAkog^4N`0>og^4N`03o`000?l`cc3o<<l`00So<<l`1Ol0000;o`3o0003o`000?l4n`Co1?/400Ko
1?/400?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=oc3?<003o`000?mSW6?oHiaS
017oHiaS00?o0000ogV6NOmiQWT00ol0000:olDja@Co00003Oo]4^d00ol0003oo@;mood2o@0?ood2
o@03o`000?om0_go000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooT6nOoi1_Won@Ki0_l00005onHIiP03o`000?nZEJ[oZUFZ00koZUFZ00?o0000og^4
NomkQ7/03_mkQ7/00ol0003o<<l`oc3?<007oc3?<003o`000?lAkQ7o4NhA00?o4NhA00?o0000o`3o
0?l0o`002?l0o`000ol0003o1?/4o`Ck1005o`Ck1003o`000?l0o`3o0?l000[o0?l01Ol0000<oc3?
<003o`000?mSW6?oHiaS013oHiaS00?o0000ogV6NOmiQWT01?miQWT3o`0000KoaC[500?o0000onPG
j?oX5nP00_oX5nP5o`0000SokA;]00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00?o
n@Ki00?o0000onHIi_oV6NH01?oV6NH00ol0003oZUFZojYEZP0=ojYEZP03o`000?mkQ7_oNhAk00oo
NhAk00?o0000oc3?<?l`cc001?l`cc02o`0000Oo4NhA00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000oc3?<?l`cc002?l`cc03o`00013oHiaS00?o0000ogV6NOmiQWT02?miQWT3o`0000;o
aC[500?o0000onPGj?oX5nP02?oX5nP5o`0000?okA;]00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oi1_Won@Ki00Con@Ki00?o0000onHIi_oV6NH01OoV6NH00ol0003oZUFZojYEZP0;ojYEZPCo0000
3omkQ7/00ol0003o<<l`oc3?<003oc3?<003o`000?lAkQ7o4NhA00So4NhA00?o0000o`3o0?l0o`00
1?l0o`02o`0000So2?L800?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l`cc02o`0000?o;m0_00?o0000of>LHomSW6<03?mSW6<00ol0003oNHIiogV6N@0<ogV6N@;o0000
4?oX5nP3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oV6NKoiQWV00KoiQWV00?o
0000ojYEZ_nZEJX02OnZEJX00ol0003o_D:mo`000002ofjAKP?o00003?mkQ7/01?l0003o<<l`oc3?
<?l`cc02o`0000co4NhA00?o0000o`3o0?l0o`000_l0o`000ol0003o2?L8o`Sg2008o`Sg2003o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o<<l`oc3?<002oc3?<003o`00
0?l_d2oo;m0_00Co;m0_0_l0000;of>LH`03o`000?miQWWoNHIi00coNHIi00?o0000oka3_?l00000
4_oX5nP00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on@KiooT6n@06ooT6n@03o`000?oV6NKoiQWV00OoiQWV00?o
0000ojYEZ_nZEJX01_nZEJX2o`0000;o_D:m00?o0000ofjAK_m^TFh00om^TFh3o`0000[oNhAk00?o
0000oc3?<?l000003olAkQ401?l0003o0?l0o`000?l0000;o`Sg2003o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o<<l`o`000?l00009obo@;`03o`000?mSW6?oHiaS00Oo
HiaS00?o0000ogV6NOmiQWT03?miQWT01?l0003o_4>loka3_?l0000ConPGj003o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003oiQWVonHIiP08onHIiP03o`000?nZEJ[oZUFZ00Co
ZUFZ00?o0000oke2_Onm@[d00onm@[d00ol0003oKY5^ofjAKP05ofjAKP?o00001_mkQ7/4o`00013o
4NhA00?o0000o`Sg2?l8m`P03?l8m`P00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoHiaS00?o0000ogV6NOmiQWT03?miQWT00ol0003o
_4>loka3_002oka3_003o`000?oX5nSoj1OX00ooj1OX00?o0000ooL8mol000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oV6NKoiQWV00WoiQWV00Co0000ojYEZ_nZEJ[o
ZUFZ0_l00006oke2_@03o`000?m^TFkoKY5^00SoKY5^0ol000000omkQ7_o0000o`000004oc?<<`03
o`000?lAkQ7o4NhA00go4NhA00?o0000o`Sg2?l8m`P03?l8m`P00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oHiaSof>LH`03o`0000ko
NHIi00?o0000oka3_?nl@k`00onl@k`00ol0003oj1OXonPGj00>onPGj005o`000?og2?Oom`SgooL8
mol000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@09ooT6n@03o`000?oV6NKoiQWV00[o
iQWV00?o0000ojYEZ_l000002?nm@[d00ol0003oKY5^ofjAKP0;ofjAKP03o`000?lcc3?o<l`c00Go
<l`c00?o0000oa7^4OlAkQ403?lAkQ400ol0003o2?L8o`Sg200<o`Sg2003o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002ogB;M003o`000?miQWWoNHIi00_o
NHIi00?o0000oka3_?nl@k`01?nl@k`00ol0003oj1OXonPGj00=onPGj003o`000?og2?Oom`Sg00?o
m`Sg00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooT6n@03o`000?oV6NKoiQWV00_oiQWV00?o0000oke2_Onm@[d0
1onm@[d00ol0003oKY5^ofjAKP0;ofjAKP03o`000?lcc3?o<l`c00Ko<l`c00?o0000oa7^4OlAkQ40
2olAkQ42o`0000go2?L800?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000ogB;M?mdRg@00_mdRg@00ol0003oNHIiogV6N@09ogV6N@03
o`000?nl@kco_4>l00Ko_4>l00?o0000onPGj?oX5nP02ooX5nP00ol0003om`SgooL8m`05ooL8m`04
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son@Ki00?o0000onHIi_oV6NH02_oV6NH2o`0000Wo
_D:m00?o0000ofjAK_m^TFh02om^TFh00ol0003o<l`coc?<<`07oc?<<`03o`000?lAkQ7o4NhA00Wo
4NhA00Co0000o`3o0?l0o`3o00003?l8m`P00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?mdRgCoM8]d00?oM8]d00?o0000
ogV6NOmiQWT01omiQWT00ol0003o_4>loka3_007oka3_003o`000?oX5nSoj1OX00[oj1OX00?o0000
ooL8moog2?L01oog2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooT6n@03o`000?oV6NKoiQWV
00WoiQWV00Co0000on8Mh_oR7N;o00002Onm@[d00ol0003oKY5^ofjAKP09ofjAKP03o`000?lcc3?o
<l`c00Wo<l`c00?o0000oa7^4OlAkQ401olAkQ400ol0003o0?l0o`3o0002o`3o0003o`000?l8m`So
2?L800Wo2?L800?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oM8]dogB;M005ogB;M003o`000?miQWWo
NHIi00GoNHIi00?o0000oka3_?nl@k`02?nl@k`00ol0003oj1OXonPGj009onPGj003o`000?og2?Oo
m`Sg00Som`Sg00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oi1_T3o`0000WoiQWV00?o0000on8M
h_oR7N800_oR7N800ol0003o_D:moke2_@06oke2_@03o`000?m^TFkoKY5^00WoKY5^00?o0000oc?<
<olcc3<02_lcc3<00ol0003o4NhAoa7^4@05oa7^4@03o`000?l0o`3o0?l000Co0?l000?o0000o`Sg
2?l8m`P02?l8m`P00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?mdRgCoM8]d00KoM8]d00?o0000ogV6
NOmiQWT00omiQWT00ol0003o_4>loka3_009oka3_003o`000?oX5nSoj1OX00Soj1OX00?o0000ooL8
moog2?L02Oog2?L00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo<<l`?o00001OoV6NH00ol0003o
hQgRon8MhP03on8MhP03o`000?nm@[go_D:m00Ko_D:m00?o0000ofjAK_m^TFh02Om^TFh00ol0003o
<l`coc?<<`0;oc?<<`03o`000?lAkQ7o4NhA00?o4NhA00?o0000o`3o0?l0o`001_l0o`000ol0003o
2?L8o`Sg2008o`Sg2003o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oM8]dogB;M007ogB;M005o`000?miQWWoNHIiogV6
NOl000003Onl@k`00ol0003oj1OXonPGj006onPGj003o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?oc3??ol`cc00Gol`cc0ol000000ooV6NKo0000on8MhP06on8MhP03
o`000?nm@[go_D:m00Go_D:m00?o0000ofjAK_m^TFh02Om^TFh00ol0003o<l`coc?<<`0<oc?<<`05
o`000?lAkQ7o4NhAoa7^4Ol000002_l0o`000ol0003o2?L8o`Sg2007o`Sg2003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olQgR7o0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000ogB;M?mdRg@02OmdRg@00ol0003oNHIio`00000=oka3_0Co00001OoX5nP00ol0
003om`SgooL8m`0;ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ol`ccoo<<l`08oo<<l`03
o`000?oR7N;ohQgR00OohQgR00?o0000oke2_Onm@[d01?nm@[d00ol0003oKY5^ofjAKP09ofjAKP03
o`000?lcc3?o<l`c00go<l`c00?o0000oa7^4Ol000003?l0o`0:o`0000Oo0?l00ol00005ob7N8@03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oM8]dogB;M00:ogB;M003
o`000?nl@kco_4>l00_o_4>l00?o0000onPGj?oX5nP00_oX5nP3o`000003onPGj?l0003om`Sg00_o
m`Sg0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003ohQgRon8MhP07on8MhP03o`00
0?nm@[go_D:m00Go_D:m00?o0000ofjAK_m^TFh01om^TFh00ol0003o<l`coc?<<`0?oc?<<`;o0000
2ol0o`000ol0003o5NXEoaGZ5@07oaGZ5@03o`000?l0o`3o0?l000;o0?l00ol00008ob7N8@03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oM8]dogB;M00:ogB;M003o`00
0?nl@kco_4>l00[o_4>l00?o0000onPGj?oX5nP01_oX5nP00ol0003om`SgooL8m`08ooL8m`?o0000
0_oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003ohQgRon8M
hP08on8MhP03o`000?nm@[go_D:m00Co_D:m00?o0000ofjAK_m^TFh01om^TFh00ol0003o<l`coc?<
<`0>oc?<<`04o`000?l4n`Co1?/4o`0000Wo0?l000?o0000oaGZ5OlEjQD02OlEjQD01?l0003o0?l0
o`000?l0000<ob7N8@03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
M8]dogB;M00;ogB;M003o`000?nl@kco_4>l00Oo_4>l0_l00009onPGj003o`000?og2?Oom`Sg00Co
m`Sg1?l00006ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003ol`ccoo<<l`09oo<<l`03o`00
0?oR7N;ohQgR00SohQgR00?o0000oke2_Onm@[d00onm@[d>o`0000go<l`c00?o0000o`Ck1?l4n`@0
0_l4n`@00ol0003o0?l0o`3o0005o`3o0003o`000?lEjQGo5NXE00_o5NXE00?o0000ob7N8OlQgR40
3?lQgR400ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000ogB;M?mdRg@0
3?mdRg@00ol0003o_4>loka3_006oka3_003o`000?oX5nSoj1OX00[oj1OX00?o0000ooL8moog2?L0
0ol0000:ooT6n@?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on8Mh_oR7N802?oR
7N801Ol0003o_D:moke2_Onm@[go000000_oPgb300?o0000oaoO7olOgal00ol00009oc?<<`03o`00
0?l4n`Co1?/400Co1?/400?o0000o`3o0?l0o`000ol0o`000ol0003o5NXEoaGZ5@0<oaGZ5@03o`00
0?lQgR7o8MhQ00go8MhQ00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmdRg@00ol0003o_4>loka3_005oka3_003o`000?oX5nSoj1OX00coj1OX0_l0000=ooT6n@03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000on8Mh_oR7N802?oR
7N84o`0000coPgb300?o0000oaoO7olOgal00olOgal3o`0000Go<l`c00?o0000o`Ck1?l4n`@01_l4
n`@01Ol0003o0?l0o`3o0?l0o`3o000000oo5NXE00?o0000ob7N8OlQgR403OlQgR400ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000ol[e2/00ol0003oM8]dogB;M00;ogB;M003o`00
0?nl@kco_4>l00?o_4>l00?o0000onPGj?oX5nP03OoX5nP00ol0003on@KiooT6n@0;ooT6n@03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo<<looc3?<02_oc3?<3o`0000KohQgR0ol0
0003om</d`03o`000?n3O8?oPgb300[oPgb300?o0000oaoO7olOgal01_lOgal3o`000003oc?<<ol0
003o1?/400Wo1?/400?o0000o`3o0?l000004?lEjQD00ol0003o8MhQob7N8@0=ob7N8@03o`000?l4
n`Co1?/400Oo1?/40_l00007ob_D:`03o`000?mdRgCoM8]d00[oM8]d00Co0000oka3_?nl@kco_4>l
0ol0000?onPGj003o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo<<looc3?<02_oc
3?<01?l0003okQ7^onhAk_o^4Nh2o`000004on8Mh_l0003o0000o`0000KodbcC00?o0000oh=lPon3
O8<02_n3O8<00ol0003o7mlOoaoO7`09oaoO7`03o`000?l4n`Co1?/400[o1?/400?o0000oaGZ5OlE
jQD03olEjQD00ol0003o8MhQob7N8@0>ob7N8@03o`000?l4n`Co1?/400Ko1?/400?o0000ob_D:ol[
e2/01ol[e2/4o`0000SoM8]d00Co0000oka3_?nl@kco00000ooC;=<2o`0000goj1OX00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003o
kQ7^onhAkP04onhAkP03o`000?oC;=?odbcC00OodbcC00?o0000oh=lPon3O8<02On3O8<00ol0003o
7mlOoaoO7`0:oaoO7`03o`000?l4n`Co1?/400[o1?/400?o0000oaGZ5OlEjQD03olEjQD00ol0003o
8MhQob7N8@0>ob7N8@03o`000?l4n`Co1?/400Go1?/400?o0000ob_D:ol[e2/02?l[e2/01?l0003o
MHYeogF:MOmeRWD7o`0000;oM8]d0_l00006om</d`;o00003?oX5nP00ol0003on@KiooT6n@09ooT6
n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003ol`ccoo<<l`08oo<<l`03o`000?o^4NkokQ7^00Go
kQ7^00?o0000om</dooC;=<02?oC;=<00ol0003oPgb3oh=lP`08oh=lP`03o`000?lOgaoo7mlO00[o
7mlO00?o0000o`Ck1?l4n`@02ol4n`@00ol0003o5NXEoaGZ5@0>oaGZ5@03o`000?lQgR7o8MhQ00ko
8MhQ1Ol00002o`Ck1003o`000?l[e2_o:m@[00Wo:m@[00?o0000ogF:MOmeRWD02?meRWD3o`0000Wo
dbcC0_l0000:onPGj003o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oc3??ol`cc00Sol`cc00?o0000onhAk_o^4Nh01oo^4Nh00ol0003odbcCom</d`07om</d`03o`00
0?n3O8?oPgb300SoPgb300?o0000oaoO7olOgal02_lOgal00ol0003o1?/4o`Ck100:o`Ck10;o0000
3_lEjQD3o`0000go8MhQ0ol00005oc?<<`;o00002ol[e2/00ol0003oMHYeogF:M@0;ogF:M@;o0000
2_oC;=<2o`0000Ooj1OX0ol00009ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:onhAkP03o`00
0?oC;=?odbcC00OodbcC00?o0000oh=lPon3O8<02?n3O8<>o`0000Wo1?/40ol000000ol0o`3o0000
oaGZ5@0:oaGZ5@?o00000_l]dRd00ol0003o8MhQob7N8@09ob7N8@;o00002Olcc3<00ol0003o:m@[
ob_D:`09ob_D:`03o`000?meRWGoMHYe00_oMHYe00?o0000oimPWol000002ooC;=<2o`0000Coj1OX
00Co0000oo4>lOoa3_7ol@ka0_l00007ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003okQ7^
onhAkP09onhAkP03o`000?oC;=?odbcC00KodbcC00?o0000oh=lPon3O8<02?n3O8<00ol0003o9=/T
obCK900:obCK9003o`000?l4n`Co1?/400Co1?/40ol00005o`3o0003o`000?lEjQGo5NXE00Co5NXE
1?l00006obgB;@03o`000?lQgR7o8MhQ00Ko8MhQ0_l0000;oc?<<`03o`000?l[e2_o:m@[00Wo:m@[
00?o0000ogF:MOmeRWD02_meRWD01Ol0003oWf2OoimPWonOH9oo000000codbcC0_l000000ooX5nSo
0000oo4>l@05oo4>l@03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o^4NkokQ7^00SokQ7^00?o0000om</dooC;=<01_oC;=<00ol0003oPgb3oh=lP`07oh=lP`03o`00
0?lTfbCo9=/T00_o9=/T00?o0000o`Ck1?l4n`@00_l4n`@2o`0000Wo0?l000?o0000oaGZ5OlEjQD0
0ol0000;obgB;@03o`000?lQgR7o8MhQ00;o8MhQ0ol0000>oc?<<`03o`000?l[e2_o:m@[00Oo:m@[
00?o0000ogF:MOmeRWD02omeRWD00ol0003oWf2OoimPW`02oimPW`03o`000?oC;=?odbcC00_odbcC
00?o0000oo4>lOoa3_401_oa3_42o`0000?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o^
4NkokQ7^00OokQ7^00?o0000om</dooC;=<01ooC;=<00ol0003oPgb3oh=lP`05oh=lP`?o00003OlT
fb@4o`0000_o0?l00ol0000?obgB;@04o`000?lQgR7o0000o`00017o<l`c00?o0000ob_D:ol[e2/0
1ol[e2/00ol0003oMHYeogF:M@0:ogF:M@03o`000?nOH9ooWf2O00CoWf2O00?o0000om</dooC;=<0
1ooC;=<3o`0000_ol@ka1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh02?o^4Nh00ol0003odbcCom</
d`06om</d`03o`000?n3O8?oPgb300;oPgb30ol00003oejQGP03o`000?lTfbCo9=/T00[o9=/T00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AobgB;@03o`000?lcc3?o<l`c017o<l`c00?o
0000ob_D:ol[e2/01ol[e2/00ol0003oMHYeogF:M@0:ogF:M@03o`000?nOH9ooWf2O00GoWf2O00Co
0000om</dooC;=?odbcC1Ol00002omTVf@03o`000?oa3_7ol@ka00Wol@ka00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003odbcCom</d`05om</d`?o0000
00?oPgb3o`000?l000001omNXEh00ol0003o9=/TobCK9008obCK90?o00002_l0o`02o`0000;o0?l0
00?o0000obgB;Ol]dRd03ol]dRd00ol0003o<l`coc?<<`0Aoc?<<`03o`000?l[e2_o:m@[00Oo:m@[
00?o0000ogF:MOmeRWD02OmeRWD00ol0003oWf2OoimPW`07oimPW`?o00001ooI9]T00ol0003ol@ka
oo4>l@09oo4>l@03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onhAk_o^4Nh01oo^
4Nh4o`0000;odbcC0_l00003olDja@03o`000?mNXEkoGZ5N00SoGZ5N0_l00006obCK90;o00000olL
ha`00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obgB;Ol]dRd03_l]
dRd00ol0003o<l`coc?<<`0Boc?<<`03o`000?l[e2_o:m@[00Go:m@[00?o0000ogF:MOmeRWD02Ome
RWD00ol0003oWf2OoimPW`08oimPW`03o`000?oI9]WofBKI00OofBKI00?o0000oo4>lOoa3_402?oa
3_400ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o^4NkokQ7^00CokQ7^0_l00004
ondBk@;o00001Oo5>/D00ol0003oGZ5NoejQGP0:oejQGP03o`000?lTfbCo9=/T00;o9=/T00?o0000
oacS7?lLha`01?lLha`00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obgB;Ol]dRd03_l]dRd00ol0003o<l`coc?<<`0Boc?<<`[o00002_meRWD00ol0003oWf2OoimPW`08
oimPW`03o`000?oI9]WofBKI00OofBKI00?o0000oo4>lOoa3_402?oa3_400ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003okQ7^onhAk_o^4Nh2o`0000OokA;]00?o0000olDjaOo5>/D01?o5>/D0
0ol0003oGZ5NoejQGP0:oejQGP04o`000?lTfbCo0000o`0000So7><L00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?l]dRgo;M8]00ko;M8]00?o0000oc?<<olcc3<04_lcc3<00ol0003oBkA;
od^dB`07od^dB`03o`000?meRWGoMHYe00KoMHYe00?o0000oimPWonOH9l02_nOH9l00ol0003ofBKI
omTVf@06omTVf@03o`000?oa3_7ol@ka00Sol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o^
4Nko0000o`0000WokA;]00?o0000olDjaOo5>/D01?o5>/D00ol0003oGZ5NoejQGP0;oejQGP03o`00
0?lLhaco7><L00Wo7><L00?o0000o`3o0?l000002Ol0o`000ol0003o;M8]obgB;@0>obgB;@;o0000
4_lcc3<00ol0003oBkA;od^dB`09od^dB`;o00001_meRWD00ol0003oWf2OoimPW`0:oimPW`03o`00
0?oI9]WofBKI00KofBKI00?o0000oo4>lOoa3_402?oa3_400ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000ondBkOo]4^d02Oo]4^d00ol0003oaC[5olDja@05olDja@03o`000?mNXEkoGZ5N00[oGZ5N00?o
0000oacS7?lLha`02_lLha`2o`0000Wo0?l000?o0000obgB;Ol]dRd03_l]dRd00ol0003o8MhQo`00
0002o`0000oo<l`c00?o0000od^dBom;]4/02om;]4/00ol0003oMHYeogF:M@03o`0000goWf2O00?o
0000omTVfOoI9]T01_oI9]T00ol0003ol@kaoo4>l@07oo4>l@03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003okA;]ondBk@09ondBk@03o`000?o5>/GoaC[500GoaC[500?o0000oejQG_mNXEh02OmNXEh2
o`0000_o7><L0_l0000;o`3o0003o`000?l]dRgo;M8]00co;M8]00?o0000ob7N8OlQgR400olQgR43
o`0000co<l`c00?o0000od^dBom;]4/03?m;]4/2o`0000;oVFJI00?o0000oimPWonOH9l03?nOH9l0
0ol0003ofBKIomTVf@05omTVf@03o`000?oa3_7ol@ka00Ool@ka00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o]4^gokA;]00[okA;]00?o0000olDjaOo5>/D01_o5>/D00ol0003oGZ5NoejQGP07oejQ
GP03o`000?mUVVGo000000[o7><L00Co0000oaC[5?lDjaCo00002_l0o`000ol0003o;M8]obgB;@0<
obgB;@03o`000?lQgR7o8MhQ00Ko8MhQ0_l00008oc?<<`;o00003om;]4/00ol0003oVFJIoiUVV@02
oiUVV@03o`000?nOH9ooWf2O00_oWf2O00?o0000omTVfOoI9]T01OoI9]T00ol0003ol@kaoo4>l@07
oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okA;]ondBk@0:ondBk@03o`000?o5>/GoaC[5
00KoaC[500?o0000oejQG_mNXEh01_mNXEh01Ol0003oIIYUofFJIOmUVVGo000000So7><L00?o0000
oaC[5?lDja@00_lDja@00ol0003o0?l0o`3o0006o`3o00Co00003?l]dRd00ol0003o8MhQob7N8@08
ob7N8@?o00000_lcc3<3o`000003ocW6>Ol0003oBkA;00goBkA;00?o0000oiUVVOnIIYT01?nIIYT0
0ol0003oWf2OoimPW`0:oimPW`03o`000?oI9]WofBKI00GofBKI00?o0000oo4>lOoa3_401_oa3_40
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d02oo]4^d00ol0003oaC[5olDja@07olDj
a@03o`000?mNXEkoGZ5N00?oGZ5N0_l00005ofFJI@03o`000?lLhaco7><L00Co7><L00?o0000oaC[
5?lDja@00olDja@00ol0003o0?l0o`3o0005o`3o0003o`000?l3o0?o0o`300;o0o`30ol00007obgB
;@;o00003_lQgR42o`0000Go>LHi00?o0000od^dBom;]4/02_m;]4/00ol0003oVFJIoiUVV@05oiUV
V@03o`000?nOH9ooWf2O00_oWf2O00?o0000omTVfOoI9]T01?oI9]T00ol0003ol@kaoo4>l@06oo4>
l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003okA;]ondBk@0;ondBk@03o`000?o5>/GoaC[500Oo
aC[500?o0000oejQG_mNXEh00_mNXEh00ol0003oIIYUofFJI@06ofFJI@03o`000?lLhaco7><L00;o
7><L00?o0000oaC[5?lDja@01OlDja@00ol0003o0?l0o`3o0002o`3o00;o00002?l3o0<3o`0000;o
;M8]0_l000000ol7n0Oo0000ob7N8@0=ob7N8@03o`000?liaSWo>LHi00Go>LHi00?o0000od^dBom;
]4/02?m;]4/00ol0003oVFJIoiUVV@07oiUVV@03o`000?nOH9ooWf2O00[oWf2O00?o0000omTVfOoI
9]T01?oI9]T00ol0003ol@kaoo4>l@06oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okA;]
ondBk@0<ondBk@03o`000?o5>/GoaC[500SoaC[500Co0000oejQG_mNXEko00002OmUVVD01Ol0003o
7><LoacS7?lLhaco000000So5>/D00Go0000o`3o0?l0o`3o0?l0o`00000=o`?l0`;o00001?l7n0L0
0ol0003o8MhQob7N8@0;ob7N8@03o`000?liaSWo>LHi00Ko>LHi00?o0000od^dBom;]4/01om;]4/0
0ol0003oVFJIoiUVV@08oiUVV@Co00002?nOH9l00ol0003ofBKIomTVf@04omTVf@03o`000?oa3_7o
l@ka00Kol@ka00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00_okA;]0ol00009olDj
a@03o`000?mNXEko000000_oIIYU00?o0000oacS7?l000002_lDja@00ol0003o0?l0o`00000?o`?l
0`03o`000?l7n0Oo1oP700;o1oP700?o0000ob7N8OlQgR402olQgR400ol0003o>LHiocW6>@06ocW6
>@03o`000?m;]4_oBkA;00KoBkA;00?o0000oiUVVOnIIYT02OnIIYT01?l0003o`cc3ol<l`oo3?<<7
o`0000;oWf2O00?o0000omTVfOoI9]T00ooI9]T00ol0003ol@kaoo4>l@05oo4>l@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o]4^gokA;]00SokA;]0ol00003on/Dj`03o`000?o5>/GoaC[500OoaC[500?o0000ofFJ
IOmUVVD02omUVVD00ol0003o5>/DoaC[500:oaC[5003o`000?l3o0?o0o`300go0o`300?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o8MhQob7N8@09ob7N8@03o`000?liaSWo>LHi00So>LHi00?o0000od^d
Bom;]4/00om;]4/2o`0000coVFJI00?o0000ol<l`oo3?<<02?o3?<<<o`0000?ol@ka0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000ondBkOo]4^d01_o]4^d3o`0000OojaC[00?o0000olDjaOo5>/D01_o5>/D00ol0003o
IIYUofFJI@0;ofFJI@03o`000?lDjaCo5>/D00Wo5>/D0_l0000>o`?l0`03o`000?l7n0Oo1oP700Go
1oP700?o0000ob7N8OlQgR402OlQgR400ol0003o>LHiocW6>@09ocW6>@03o`000?m;]4_o000000;o
00000_n>LHh00ol0003oVFJIoiUVV@08oiUVV@03o`000?o3?<?o`cc300co`cc300?o0000on`Ck?o/
4n`01_o/4n`3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003okA;]ondBk@03ondBk@?o00002oo[5>/00ol0003oaC[5
olDja@04olDja@03o`000?mUVVGoIIYU00_oIIYU0ol00007oaC[50?o000000?o3?<<o`000?l3o0<0
3Ol3o0<00ol0003o1oP7o`Oh1`06o`Oh1`03o`000?lQgR7o8MhQ00So8MhQ00?o0000ocW6>OliaST0
2_liaST00ol0003oSW6>ohiaSP04ohiaSP03o`000?nIIYWoVFJI00OoVFJI00?o0000ol<l`oo3?<<0
2oo3?<<00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004ondBkOl0
003o0000o`0000oojaC[00?o0000olDjaOo5>/D00oo5>/D>o`0000?oCk1?0_l00002oaC[50?o0000
1Ol<l``00ol0003o0o`3o`?l0`0:o`?l0`03o`000?l7n0Oo1oP700Oo1oP700?o0000ob7N8OlQgR40
2?lQgR400ol0003o>LHiocW6>@0:ocW6>@03o`000?n>LHkoSW6>00GoSW6>00?o0000oiUVVOnIIYT0
1_nIIYT00ol0003o`cc3ol<l``0;ol<l``03o`000?o/4ncok1?/00Sok1?/00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;ojaC[00?o0000olDjaOo5>/D00_o5>/D00ol0003o/dbcok=<
/`0:ok=</`03o`000?m?/4ooCk1?00?oCk1?0_l00009o`cc3003o`000?l3o0?o0o`300Wo0o`300?o
0000o`Oh1ol7n0L02?l7n0L2o`0000So8MhQ00?o0000ocW6>OliaST02OliaST00ol0003oSW6>ohia
SP07ohiaSP03o`000?nIIYWoVFJI00CoVFJI00?o0000ol<l`oo3?<<02oo3?<<00ol0003ok1?/on`C
k009on`Ck003o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ojaC[on/Dj`0?on/Dj`?o000000?oaC[5
o`000?ncC;<02oncC;<00ol0003oCk1?odn`C`04odn`C`03o`000?l<l`co3?<<00Wo3?<<00?o0000
o`?l0ol3o0<01ol3o0<00ol0003o1oP7o`Oh1`09o`Oh1`04o`000?lBkA;o0000o`0000Ko8MhQ00?o
0000ocW6>OliaST02OliaST00ol0003oSW6>ohiaSP08ohiaSP03o`000?nIIYWoVFJI00?oVFJI00?o
0000ol<l`oo3?<<02oo3?<<00ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003ojaC[on/Dj`0<on/Dj`;o00000ooY5^T2o`0000co/dbc00?o0000odn`Com?/4l01?m?/4l0
0ol0003o3?<<o`cc300:o`cc30Wo00002ol7n0L00ol0003o4^dBoa;]4P02oa;]4P?o00000_lQgR40
0ol0003o>LHiocW6>@0:ocW6>@03o`000?n>LHkoSW6>00WoSW6>00?o0000oiUVVOnIIYT00_nIIYT0
0ol0003o`cc3ol<l``0:ol<l``03o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o[5>/2o`0000GojAKY00?o0000olLhaol000002_ncC;<00ol0003oCk1?odn`C`06odn`
C`03o`000?l<l`co3?<<00Wo3?<<00?o0000o`3o0?l0o`001Ol0o`000ol0003o1oP7o`Oh1`09o`Oh
1`03o`000?lBkA;o4^dB00Go4^dB0ol00009ocW6>@?o00003On>LHh01Ol0003oVFJIoiUVVOnIIYWo
000000co`cc300?o0000on`Ck?o/4n`02Oo/4n`00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/D
joo[5>/01Oo[5>/2o`0000OojAKY00Co0000olLhaoo7><Oo00002OncC;<00ol0003oCk1?odn`C`06
odn`C`03o`000?l<l`co3?<<00So3?<<00?o0000o`3o0?l0o`001ol0o`000ol0003o1oP7o`Oh1`07
o`Oh1`03o`000?lBkA;o4^dB00So4^dB0ol00002ocW6>@Go00000_m`Sg000ol0003oSW6>ohiaSP0<
ohiaSP03o`000?nIIYWo000000co`cc300?o0000on`Ck?o/4n`02_o/4n`00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000on/Djoo[5>/00_o[5>/2o`0000SojAKY00?o0000olLhaoo7><L00_o7><L5o`00
00Co/dbc00?o0000odn`Com?/4l01_m?/4l00ol0003o3?<<o`cc3008o`cc3003o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Oh1ol7n0L01ol7n0L00ol0003o4^dBoa;]4P08oa;]4P03o`000?lgb3Oo=lPg
00;o00002?m`Sg000ol0003oSW6>ohiaSP0<ohiaSPCo00002_o3?<<00ol0003ok1?/on`Ck00:on`C
k003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003ojaC[o`000?l0000:onTFj@03o`000?o7><OoacS7
00;oacS700?o0000oiA[U?nDJi@00_nDJi@4o`0000WoCk1?00?o0000o`cc3?l<l``02?l<l``00ol0
003o0?l0o`3o0008o`3o0003o`000?l7n0Oo1oP700Go1oP700?o0000oa;]4_lBkA802?lBkA801Ol0
003o=lPgocO8=olgb3Oo000000[oL8m`0ol0000;ohiaSP04o`000?oO8=oogb3OomlPg`Co00001Oo3
?<<00ol0003ok1?/on`Ck00;on`Ck003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ojAKYonTFj@0:
onTFj@03o`000?o7><OoacS700?oacS700?o0000oiA[U?nDJi@01?nDJi@00ol0003oCk1?odn`C`07
odn`C`03o`000?l<l`co3?<<00Ko3?<<0_l0000;o`3o0003o`000?l7n0Oo1oP700Go1oP700?o0000
oa;]4_lBkA802?lBkA800ol0003o=lPgocO8=`02ocO8=`03o`000?m`Sg3oL8m`00OoL8m`00?o0000
okU6^OniA[T01?l00006ohiaSP03o`000?oO8=oogb3O00Kogb3O0ol00002ol<l``03o`000?o/4nco
k1?/00_ok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oY5^WojAKY00WojAKY00?o0000olLh
aoo7><L01?o7><L00ol0003oU6^DoiA[U005oiA[U003o`000?m?/4ooCk1?00OoCk1?00?o0000o`cc
3?l<l``00_l<l``3o`000003oa_T6ol0003o0?l000[o0?l000?o0000o`Oh1ol7n0L01Ol7n0L00ol0
003o4^dBoa;]4P07oa;]4P03o`000?lgb3Oo=lPg00?o=lPg00?o0000og2?L?m`Sg001om`Sg000ol0
003o^DJiokU6^@04okU6^@?o00000_n>LHh00ol0003ogb3OomlPg`0:omlPg`;o00003_o/4n`00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onTFjOoY5^T02OoY5^T00ol0003oacS7olLha`04olLha`03
o`000?nDJiCoU6^D00KoU6^D0_l00007odn`C`03o`000?l<l`co000000;o00001OlKi1/00ol0003o
0?l0o`3o0008o`3o00?o00001?l7n0L00ol0003o4^dBoa;]4P08oa;]4P03o`000?lgb3Oo=lPg00Co
=lPg00?o0000og2?L?m`Sg001_m`Sg000ol0003o^DJiokU6^@07okU6^@;o00003_oO8=l00ol0003o
k1?/on`Ck00;on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojAKYonTFj@08onTFj@03o`00
0?o7><OoacS700GoacS700?o0000oiA[U?nDJi@01?nDJi@00ol0003oRWF:ohYeRP03o`0000CoCk1?
0_l00008oa_T6`03o`000?l0o`3o0?l000Oo0?l000Co0000obSG:?lXebSo:=LX0ol000000ol7n0Oo
0000oa;]4P09oa;]4P03o`000?lgb3Oo=lPg00Co=lPg00?o0000og2?L?m`Sg001Om`Sg000ol0003o
^DJiokU6^@09okU6^@03o`000?oO8=oogb3O00gogb3O00?o0000on`Ck?o/4n`02_o/4n`00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onTFjOoY5^T01ooY5^T00ol0003oacS7olLha`06olLha`03o`00
0?nDJiCoU6^D00?oU6^D00?o0000ohYeR_n:MHX01?n:MHX2o`000003odn`Col0003o6n@K00[o6n@K
00?o0000o`3o0?l0o`001Ol0o`000ol0003o:=LXobSG:005obSG:003o`000?lBkA;o4^dB00Oo4^dB
0ol00007ocO8=`03o`000?m`Sg3oL8m`00CoL8m`00?o0000okU6^OniA[T02OniA[T00ol0003ogb3O
omlPg`0=omlPg`03o`000?o/4ncok1?/00[ok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oY
5^WojAKY00GojAKY0ol00009olLha`05o`000?nDJiCoU6^DoiA[U?l000002On:MHX00ol0003o6n@K
oa_T6`0;oa_T6`03o`000?l0o`3o0?l000?o0?l000?o0000obSG:?lXebP01_lXebP00ol0003o4^dB
oa;]4P06oa;]4P05o`000?liaSWo>LHiocW6>Ol000001olgb3L00ol0003oL8m`og2?L003og2?L003
o`000?niA[Wo^DJi00Wo^DJi00?o0000omlPgooO8=l03_oO8=l00ol0003ok1?/on`Ck009on`Ck003
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojAKYo`000004o`0000;ol0o`00?o0000olLhaoo7><L0
1oo7><L01?l0003oU6^DoiA[U?l00009ohYeRP;o00003OlKi1/00ol0003o0?l0o`3o0002o`3o0003
o`000?lXebSo:=LX00So:=LX00?o0000oa;]4_lBkA800olBkA82o`0000Go>LHi00?o0000ocO8=olg
b3L01?lgb3L00ol0003oL8m`og2?L003og2?L003o`000?niA[Wo^DJi00Wo^DJi00?o0000omlPgooO
8=l03_oO8=l00ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sol0o`
00?o0000olLhaoo7><L01_o7><L00ol0003oU6^Do`000009ohYeRP04o`000?mNXEkoGZ5No`0000go
6n@K00Co0000o`3o0?l0o`3o00003?lXebP01Ol0003o4^dBoa;]4_lBkA;o000000So>LHi0_l00005
ocO8=`03o`000?m`Sg3oL8m`00;oL8m`00?o0000okU6^OniA[T02OniA[T00ol0003ogb3OomlPg`0>
omlPg`03o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o`3o3ol0o`
00Ool0o`00?o0000olLhaoo7><L01oo7><L00ol0003oRWF:ohYeRP07ohYeRP03o`000?mNXEkoGZ5N
00;oGZ5N00?o0000oa_T6olKi1/02_lKi1/00ol0003o0?l0o`00000>obSG:003o`000?lBkA;o0000
00_o>LHi00?o0000ocO8=olgb3L00_lgb3L01Ol0003oL8m`og2?L?m`Sg3o000000co^DJi00?o0000
omlPgooO8=l03_oO8=l3o`0000Wok1?/00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00Wol0o`00?o0000olLhaoo7><L01_o7><L00ol0003oRWF:ohYeRP06ohYeRP03o`000?mNXEkoGZ5N
00?oGZ5N00?o0000oa_T6olKi1/02olKi1/00ol0003o:=LXobSG:00>obSG:003o`000?liaSWo>LHi
00_o>LHi0_l00003ocO8=`04o`000?m`Sg3oL8m`o`0000[o^DJi0ol0000>omlPg`;o00000oom0_d2
o`0000Ook1?/00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000olLh
aoo7><L01?o7><L00ol0003oRWF:ohYeRP06ohYeRP03o`000?mNXEkoGZ5N00GoGZ5N00?o0000oa_T
6olKi1/01olKi1/3o`00017o:=LX00?o0000ocW6>OliaST03OliaST01Ol0003o=lPgocO8=ol0003o
L8m`00Co00000oniA[T5o`0000;ojaC[00?o0000omlPgooO8=l02_oO8=l2o`0000Ooo@;m0_l00004
on`Ck003o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ol0o`oo0?l00;oo0?l003o`000?o7><OoacS7
00CoacS700?o0000ohYeR_n:MHX01On:MHX00ol0003oGZ5NoejQGP06oejQGP03o`000?lKi1_o6n@K
00Co6n@K0ol00002ob7N8@03o`000?lXebSo:=LX00oo:=LX0_l0000?ocW6>@04o`000?lgb3Oo0000
o`0000CoYEZU0ol00008on/Dj`03o`000?oO8=oogb3O00Oogb3O0_l0000;ood2o@;o00000_o/4n`0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo0?l?o`3o003?o`3o06o`0000OoRWF:00?o0000oejQ
G_mNXEh02?mNXEh00ol0003o6n@Koa_T6`03o`0000Ko8MhQ00?o0000obSG:?lXebP03OlXebP01?l0
003o@[e2od:m@_l0000?ocW6>@03o`000?nUFZGoYEZU00GoYEZU00?o0000on/Djoo[5>/02?o[5>/0
0ol0003ogb3OomlPg`05omlPg`03o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o`3o000ol0003ocC;=oldbc@04oldb
c@03o`000?n:MH[oRWF:00?oRWF:00?o0000oejQG_mNXEh02_mNXEh2o`0000[o8MhQ00?o0000obSG
:?lXebP02olXebP00ol0003o@[e2od:m@P02od:m@P03o`000?liaSWo>LHi00_o>LHi0_l00007ojEJ
Y@03o`000?o[5>_ojaC[00WojaC[00?o0000omlPgooO8=l00_oO8=l2o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo0?l?o`3o002oo`3o000ol0003ocC;=oldbc@06oldbc@05o`000?n:MH[oRWF:ohYe
R_l000003OmNXEh00ol0003o8MhQob7N8@0:ob7N8@03o`000?lXebSo:=LX00Wo:=LX00?o0000od:m
@_m2_D801?m2_D800ol0003o>LHiocW6>@08ocW6>@;o000000?oFjAKo`000?nUFZD01onUFZD00ol0
003ojaC[on/Dj`09on/Dj`04o`000?oO8=oo0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?o`3o3ol0o`
00Wol0o`00?o0000oldbcOo=</d02?o=</d00ol0003oRWF:o`00000=oejQGP03o`000?lQgR7o8MhQ
00_o8MhQ00?o0000obSG:?lXebP02?lXebP00ol0003o@[e2od:m@P06od:m@P03o`000?liaSWo>LHi
00Go>LHi0_l00003oe^TF`03o`000?nUFZGoYEZU00KoYEZU00?o0000on/Djoo[5>/02_o[5>/00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003ol0o`oo0?l007oo0?l003o`000?o=</gocC;=00[ocC;=00?o0000oejQG_mN
XEh03?mNXEh00ol0003o8MhQob7N8@0<ob7N8@03o`000?lXebSo:=LX00Ko:=LX00?o0000od:m@_m2
_D802?m2_D800ol0003o>LHiocW6>@02ocW6>@;o00001_mKY5/00ol0003oYEZUojEJY@05ojEJY@03
o`000?o[5>_ojaC[00[ojaC[00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?o`3o3ol0o`00Gol0o`
00?o0000oldbcOo=</d03?o=</d2o`0000coGZ5N00?o0000ob7N8OlQgR403OlQgR400ol0003o:=LX
obSG:004obSG:003o`000?m2_D;o@[e200[o@[e200Co0000ocW6>Ol0003o00002?mKY5/00ol0003o
YEZUojEJY@06ojEJY@03o`000?o[5>_ojaC[00WojaC[00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_o`3o000ol0003ocC;=oldbc@0=oldbc@03o`000?n7N8Oo000000;o00002?mNXEh00ol0003o8MhQ
ob7N8@0?ob7N8@Ko00003_m2_D800ol0003oFjAKoe^TF`08oe^TF`03o`000?nUFZGoYEZU00KoYEZU
00?o0000on/Djoo[5>/02Oo[5>/00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo8=l_ob3O;olPgb
0_l0000?oldbc@03o`000?n7N8OoQgR700?oQgR70ol00005oejQGP;o00004?lQgR401_l0003o7><L
oacS7?l0003o4^dBo`0000ko@[e200?o0000oe^TFomKY5/02OmKY5/00ol0003oYEZUojEJY@05ojEJ
Y@03o`000?o[5>_ojaC[00WojaC[00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo8=l_ob3O800oob3O800ol0003o
cC;=oldbc@0=oldbc@03o`000?n7N8OoQgR700KoQgR70ol000001?mNXEko0000ocO8=olgb3L3o`00
00co8MhQ00Go0000oacS7?lLhaco7><Lo`000002oa;]4P03o`000?m2_D;o@[e200_o@[e200?o0000
oe^TFomKY5/02OmKY5/00ol0003oYEZUojEJY@06ojEJY@03o`000?o[5>_ojaC[00SojaC[0_l0000A
ood2o@?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003olPgboo8=lP04oo8=lPoo00003?n7N8L00ol0003o=lPgocO8=`04ocO8
=`?o00002?lQgR400ol0003o7><LoacS7002oacS7005o`000?lBkA;o4^dBoa;]4_l000003?m2_D80
0ol0003oFjAKoe^TF`09oe^TF`03o`000?nUFZGoYEZU00GoYEZU3?l00002ooL8m`;o00003Oom0_d2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003olPgboo8=lP05oo8=lP03o`000?o@;m3od2o@00_od2o@00?o0000ohMh
Qon7N8L02_n7N8L00ol0003o=lPgocO8=`07ocO8=`;o00001OlQgR400ol0003o7><LoacS7003oacS
7003o`000?lBkA;o4^dB00;o4^dB00?o0000od:m@_m2_D802Om2_D800ol0003oFjAKoe^TF`0:oe^T
F`03o`000?nUFZGoYEZU00?oYEZU00?o0000on@Ki?oT6n@02OoT6n@00ol0003om`SgooL8m`02ooL8
m`;o00002Oom0_d2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003olPgboo8=lP06oo8=lP03o`000?o@;m3od2o@00[o
d2o@00?o0000ohMhQon7N8L02on7N8L00ol0003o=lPgocO8=`09ocO8=`?o000000?o8MhQo`000?lL
ha`01OlLha`00ol0003o4^dBoa;]4P03oa;]4P03o`000?m2_D;o@[e200So@[e23_l00003ojEJY@;o
00002ooT6n@00ol0003om`SgooL8m`05ooL8m`03o`000?om0_goo@;m00?oo@;m0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo8=l_ob3O801Oob3O800ol0003ofBKIo`00000;om0_d003o`000?n7N8OoQgR700[oQgR7
0_l0000>ocO8=`03o`000?lLhaco7><L00Go7><L00?o0000oa;]4_lBkA800olBkA800ol0003o@[e2
od:m@P08od:m@P03o`000?nQGZ7oXEjQ00_oXEjQ00?o0000ojEJYOl000003OoT6n@00ol0003om`Sg
ooL8m`06ooL8m`;o000000?oo@;mo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00KolPgb00Co
0000omTVfOoI9]Wo00002_o@;m000ol0003oQgR7ohMhQ`09ohMhQ`03o`000?mPWf3o000000ko=lPg
00?o0000oacS7?lLha`01OlLha`00ol0003o4^dBoa;]4P04oa;]4P03o`000?m2_D;o@[e200Ko@[e2
00?o0000oj5NXOnQGZ403OnQGZ400ol0003oi1_Ton@Ki00<on@Ki003o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?ob3O;olPgb00GolPgb00?o0000omTVfOoI9]T00_oI
9]T00ol0003od2o@om0_d006om0_d003o`000?n7N8OoQgR700SoQgR70_l00003of2OH003o`000?lg
b3Oo=lPg00_o=lPg00?o0000oacS7?lLha`01OlLha`00ol0003o4^dBoa;]4P05oa;]4P03o`000?m2
_D;o@[e200Go@[e200?o0000oj5NXOnQGZ403OnQGZ400ol0003oi1_Ton@Ki00;on@Ki003o`000?og
2?Oom`Sg00Wom`Sg00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000
omTVfOoI9]T00ooI9]T00ol0003od2o@om0_d005om0_d003o`000?n7N8OoQgR700OoQgR700?o0000
of2OH?mPWf000omPWf000ol0003o=lPgocO8=`0:ocO8=`03o`000?lLhaco7><L00Ko7><L00?o0000
oa;]4_lBkA801_lBkA800ol0003o@[e2od:m@P04od:m@P03o`000?nQGZ7oXEjQ00goXEjQ3ol0000;
ooL8m`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000omTVfOoI9]T01OoI9]T00ol0
003od2o@om0_d004om0_d003o`000?n7N8OoQgR700GoQgR70_l00006of2OH003o`000?lgb3Oo=lPg
00Wo=lPg0_l00008oacS7003o`000?lBkA;o4^dB00Ko4^dB1Ol000000om2_D;o0000oj5NX@0?oj5N
X@03o`000?oV6NKoiQWV00_oiQWV00?o0000ooL8moog2?L02Oog2?L00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?ob3O;olPgb00KolPgb00?o0000omTVfOoI9]T01_oI9]T00ol0003o
d2o@om0_d004o`0000KoQgR700?o0000of2OH?mPWf001omPWf000ol0003o=lPgocO8=`05ocO8=`?o
000000?o:=LXo`000?lLha`01olLha`00ol0003o4^dBoa;]4P05oa;]4P03o`000?mDZeCoE:]D00?o
E:]D0_l0000?oj5NX@;o00003OoV6NH00ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000WolPgb00?o0000omTVfOoI9]T01ooI9]T2o`0000Co/Tfb00Co0000ohMhQon7N8Oo
QgR70_l0000:of2OH003o`000?lgb3Oo=lPg00;o=lPg0ol00005obSG:003o`000?lLhaco7><L00Go
7><L00?o0000oa;]4_lBkA801?lBkA800ol0003oE:]DoeB[E006oeB[E003o`000?nQGZ7oXEjQ00[o
XEjQ0_l00002olXebP03o`000?oV6NKoiQWV00[oiQWV00?o0000ooL8moog2?L02?og2?L00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo8=l_ob3O801_ob3O800ol0003ofBKIomTVf@08omTVf@03o`00
0?nbCK;o/Tfb00Co/Tfb00?o0000ohMhQol000003?mPWf000ol0003o=lPgo`000002o`0000Wo:=LX
00?o0000oacS7?lLha`01?lLha`00ol0003o4^dBoa;]4P03oa;]4P03o`000?mDZeCoE:]D00SoE:]D
1_l00004oj5NX@;o00001Oo:=LX00ol0003oiQWVonHIiP09onHIiP03o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?ob3O;olPgb00GolPgb00?o0000omTVfOoI9]T01ooI
9]T00ol0003o/Tfbok9=/P06ok9=/P03o`000?mPWf3oH9mP00coH9mP00?o0000obSG:?lXebP02_lX
ebP00ol0003o7><LoacS7004oacS7004o`000?lBkA;o4^dBoa;]4P;o00002omDZe@00ol0003oYeRW
ojMHY`03ojMHY`Co00002?o:=LX00ol0003oiQWVonHIiP08onHIiP03o`000?og2?Oom`Sg00Oom`Sg
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo8=l_ob3O800oob3O800ol0003ofBKIomTVf@07omTVf@03o`000?nb
CK;o/Tfb00Oo/Tfb00?o0000of2OH?mPWf003?mPWf000ol0003o:=LXobSG:00;obSG:003o`000?lL
haco7><L00?o7><L00Co0000oa;]4_lBkA;o00003OmDZe@00ol0003oYeRWojMHY`06ojMHY`03o`00
0?o:=L[obSG:00OobSG:00?o0000onHIi_oV6NH01ooV6NH00ol0003om`SgooL8m`06ooL8m`04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob3O;olPgb00;olPgb00?o0000omTVfOoI9]T0
1_oI9]T00ol0003o/Tfbok9=/P09ok9=/P03o`000?mPWf3oH9mP00WoH9mP0_l0000>obSG:0?o0000
0olLha`00ol0003o4^dBo`00000=oeB[E003o`000?nWF:OoYeRW00OoYeRW00?o0000olXeb_o:=LX0
2?o:=LX:o`0000Kom`Sg0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OofBKI00?o
0000ok9=/_nbCK802_nbCK800ol0003oH9mPof2OH006of2OH0;o000000?oF:MHo`000?lXebP02olX
ebP2o`0000?o@Ki11Ol0000>oeB[E003o`000?nWF:OoYeRW00OoYeRW00?o0000olXeb_o:=LX02?o:
=LX00ol0003ok1?/on`Ck006on`Ck003o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003ojAKYonTFj@03onTFj@Co00000_oI9]T00ol0003o/Tfbok9=/P0;
ok9=/P03o`000?mPWf3oH9mP00?oH9mP0ol00004oeRWF003o`000?lXebSo:=LX00Oo:=LX0_l00008
od6n@@03o`000?mDZeCoE:]D00goE:]D00?o0000ojMHYonWF:L02?nWF:L00ol0003obSG:olXebP07
olXebP03o`000?o/4ncok1?/00Ook1?/0ol000000oog2?Oo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?oY5^WojAKY00OojAKY0_l0000?ok9=/P03o`000?mPWf3oH9mP00;o00002?mHYeP00ol0
003o:=LXobSG:005obSG:003o`000?m1_T7o@Ki100So@Ki100?o0000oeB[E?mDZe@03OmDZe@00ol0
003oYeRWojMHY`08ojMHY`03o`000?o:=L[obSG:00KobSG:00?o0000on`Ck?o/4n`02?o/4n`01?l0
003on0OhooP7n?l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003ojAKYonTFj@09onTF
j@03o`000?nbCK;o/Tfb00ko/Tfb0_l0000;oeRWF003o`000?lXebSo:=LX00;o:=LX0_l0000;od6n
@@03o`000?mDZeCoE:]D00goE:]D00?o0000ojMHYonWF:L02?nWF:L00ol0003obSG:olXebP06olXe
bP03o`000?o/4ncok1?/00Ook1?/00Go0000ooP7n?oh1oSon0Oho`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ojAKYonTFj@0:onTFj@03o`000?nbCK;o/Tfb00go/Tfb0_l0000<oeRWF004o`000?lXebSo0000
o`0000go@Ki100?o0000oeB[E?mDZe@03?mDZe@00ol0003oYeRWojMHY`09ojMHY`03o`000?o:=L[o
bSG:00KobSG:00?o0000on`Ck?o/4n`01_o/4n`00ol0003on0OhooP7n003ooP7n003o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003ojAKYonTFj@0:onTFj@03o`000?nbCK;o/Tfb00co/Tfb00Co0000oj=L
XonSG:?o00003?mHYeP00ol0003o@Ki1od6n@@0>od6n@@03o`000?mDZeCoE:]D00SoE:]D1?l0000;
ojMHY`03o`000?o:=L[obSG:00KobSG:00?o0000on`Ck?o/4n`01Oo/4n`00ol0003on0OhooP7n004
ooP7n003o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003ojAKYonTFj@0;onTFj@03o`000?nbCK;o/Tfb
00_o/Tfb00?o0000oj=LXonSG:<00_nSG:<00ol0003oF:MHoeRWF009oeRWF003o`000?m1_T7o@Ki1
00ko@Ki100Co0000oeB[E?mDZeCoE:]D1ol00003og><L`03o`000?nWF:OoYeRW00WoYeRW00?o0000
olXeb_o:=LX01_o:=LX00ol0003ok1?/on`Ck004on`Ck003o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oY5^WojAKY00cojAKY00?o0000ok9=/_nbCK802_nbCK800ol0
003oXebSoj=LX`03oj=LX`03o`000?mHYeSoF:MH00SoF:MH00?o0000od6n@Om1_T403_m1_T44o`00
00_oLhac00?o0000ojMHYonWF:L02?nWF:L00ol0003obSG:olXebP05olXebP03o`000?o/4ncok1?/
00Gok1?/00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onTFjOoY
5^T03?oY5^T7o`0000Go/Tfb00?o0000oj=LXonSG:<01OnSG:<00ol0003oF:MHoeRWF007oeRWF003
o`000?m1_T7o@Ki100ko@Ki100?o0000og><LomcS7<03OmcS7<00ol0003oYeRWojMHY`08ojMHY`03
o`000?o:=L[obSG:00CobSG:00?o0000on`Ck?o/4n`01?o/4n`00ol0003on0OhooP7n007ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003ojAKYonTFj@0=onTFj@03o`000?o?<<oocc3?00Cocc3?
1Ol00009oj=LX`03o`000?mHYeSoF:MH00KoF:MH00?o0000od6n@Om1_T403_m1_T400ol0003oLhac
og><L`0=og><L`03o`000?nWF:OoYeRW00SoYeRW00Co0000olXeb_o:=L[obSG:1Ol00004on`Ck003
o`000?oh1oSon0Oh00Won0Oh1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onTFj@03o`000?o?<<oocc3?00Wocc3?
0_l00009oj=LX`03o`000?mHYeSoF:MH00KoF:MH00?o0000od6n@Om1_T403?m1_T400ol0003oLhac
og><L`0?og><L`Ko00001?nWF:L4o`0000GoiQWV0_l000000oo/4nco0000ooP7n00;ooP7n004o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?od2oCom0_doo@;m0?o00002_oY5^T00ol0003o
cc3?oll`c`09oll`c`03o`000?ncC;?o000000;o00001onSG:<00ol0003oF:MHoeRWF005oeRWF003
o`000?m1_T7o@Ki100So@Ki11Ol0000Aog><L`03o`000?nfBKKo]TVf00?o]TVf1?l0000;onHIiP03
o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000oo@;m?od2o@01Ood2o@2o`0000OojAKY
00?o0000oll`coo?<<l02_o?<<l00ol0003o/dbcok=</`02ok=</`?o00001OnSG:<00ol0003oF:MH
oeRWF004oeRWF004o`000?m1_T7o@Ki1od6n@@Oo00001?mWV6L00ol0003oLhacog><L`0>og><L`03
o`000?nfBKKo]TVf00Oo]TVf00?o0000onHIi_oV6NH02OoV6NH00ol0003on0OhooP7n009ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003om0_doo@;m008oo@;m0;o00001?oY5^T00ol0003occ3?
oll`c`0;oll`c`03o`000?ncC;?o/dbc00Go/dbc0ol00003oj=LX`04o`000?mHYeSoF:MHoeRWF0Ko
00003?mWV6L00ol0003oLhacog><L`0=og><L`03o`000?nfBKKo]TVf00Oo]TVf00?o0000onHIi_oV
6NH02_oV6NH00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo@;m0?o000000?ojAKYo`000?o?<<l0
3?o?<<l00ol0003o/dbcok=</`08ok=</`?o000000CoXebSo`000?l0003o00000_nXEjP00ol0003o
IiQWofNHI`0=ofNHI`03o`000?mcS7?oLhac00coLhac00?o0000okI9]_nfBKH02?nfBKH00ol0003o
iQWVonHIiP0;onHIiP03o`000?oh1oSon0Oh00Kon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
m0_d00?o0000oll`coo?<<l03?o?<<l00ol0003o/dbcok=</`0;ok=</`03o`000?nXEjSoZ5NX00?o
Z5NX00?o0000ofNHIomWV6L03?mWV6L00ol0003oMHYeo`00000=og><L`03o`000?nfBKKo]TVf00So
]TVf00?o0000onHIi_oV6NH03?oV6NH3o`0000Gon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?od2oCom0_d00com0_d00?o0000oll`coo?<<l03?o?<<l00ol0003o/dbcok=</`0:ok=</`03o`00
0?nXEjSoZ5NX00GoZ5NX00?o0000ofNHIomWV6L02_mWV6L01?l0003oMHYeogF:MOmeRWD2o`0000[o
Lhac00?o0000okI9]_nfBKH02OnfBKH00ol0003oiQWVonHIiP0<onHIiP03o`000?oi1_Won@Ki00?o
000000?on0Oho`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?od2oCom0_d00_om0_d00?o0000oll`coo?<<l0
3?o?<<l00ol0003o/dbcok=</`09ok=</`03o`000?nXEjSoZ5NX00KoZ5NX00?o0000ofNHIomWV6L0
2OmWV6L00ol0003oMHYeogF:M@02ogF:M@03o`000?nZEJ[o000000;o00001omcS7<00ol0003o]TVf
okI9]P09okI9]P03o`000?oV6NKoiQWV00_oiQWV00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo@;m?od2o@02ood2o@00ol0003occ3?oll`c`0;oll`c`03o`000?nc
C;?o/dbc00So/dbc00?o0000ojQGZ?nXEjP01onXEjP00ol0003oIiQWofNHI`08ofNHI`03o`000?me
RWGoMHYe00?oMHYe00?o0000ojYEZ_nZEJX00_nZEJX2o`0000CoLhac00?o0000okI9]_nfBKH02_nf
BKH00ol0003oiQWVonHIiP0:onHIiP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?od2oCom0_d00[om0_d0ol0000;oll`c`Ko00001?ncC;<00ol0003oZ5NXojQGZ008
ojQGZ003o`000?mWV6OoIiQW00OoIiQW00?o0000ogF:MOmeRWD00omeRWD00ol0003oZUFZojYEZP05
ojYEZP?o000000?oLhaco`000?nfBKH02onfBKH00ol0003oiQWVonHIiP09onHIiP03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?od2oCom0_d00Wom0_d00?o0000onTF
jOoY5^T01?l00006oll`c`03o`000?o@;m3od2o@00Cod2o@1?l0000<ojQGZ003o`000?mWV6OoIiQW
00GoIiQW00?o0000ogF:MOmeRWD01?meRWD00ol0003oZUFZojYEZP08ojYEZP03o`000?nfBKKo]TVf
00_o]TVf00?o0000onHIi_oV6NH02?oV6NH00ol0003on@KiooT6n@08ooT6n@Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?od2oCom0_d00Oom0_d00?o0000onTFjOoY5^T01OoY5^T3o`0000;occ3?00?o0000om0_d?o@
;m002?o@;m000ol0003oZ5NXojQGZ00:ojQGZ003o`000?mWV6OoIiQW00CoIiQW00?o0000ogF:MOme
RWD01OmeRWD00ol0003oZUFZojYEZP08ojYEZP03o`000?nfBKKo]TVf00Wo]TVf1?l00008onHIiP03
o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003om0_d
oo@;m005oo@;m003o`000?oY5^WojAKY00WojAKY0_l0000<om0_d003o`000?nXEjSoZ5NX00WoZ5NX
00?o0000ofNHIomWV6L00omWV6L00ol0003oMHYeogF:M@05ogF:M@03o`000?nZEJ[oZUFZ00[oZUFZ
00?o0000okI9]_nfBKH01?nfBKH4o`0000Coh1oP00?o0000onHIi_oV6NH01?oV6NH00ol0003on@Ki
ooT6n@0:ooT6n@03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00?om0_d00?o0000onTFjOoY5^T02ooY
5^T00ol0003od2o@om0_d00:om0_d003o`000?nXEjSoZ5NX00WoZ5NX00?o0000ofNHIomWV6L00_mW
V6L00ol0003oMHYeogF:M@06ogF:M@03o`000?nZEJ[oZUFZ00[oZUFZ00?o0000okI9]_nfBKH01?l0
0009on0Oh0Ko00003?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo@;m?od2oCom0_d0_l0
000=onTFj@03o`000?o@;m3od2o@00[od2o@00?o0000ojQGZ?nXEjP02OnXEjP01Ol0003oIiQWofNH
IomWV6Oo000000WoMHYe00?o0000ojYEZ_nZEJX02onZEJX2o`0000goh1oP00?o0000ooL8moog2?L0
0_og2?L00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_do`00
0002ooX5nP;o00002ooY5^T00ol0003od2o@om0_d00;om0_d003o`000?nXEjSoZ5NX00WoZ5NX00?o
0000ofNHIol000002OmeRWD00ol0003oZUFZojYEZP0<ojYEZP03o`000?oP7n3oh1oP00coh1oP00?o
0000ooL8moog2?L00oog2?L00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003onPGjooX5nP03ooX5nP;o00002_oY5^T00ol0003od2o@om0_d00:om0_d003o`000?nXEjSo
Z5NX00SoZ5NX1Ol00008ogF:M@03o`000?nZEJ[oZUFZ00coZUFZ00?o0000on0Oh?oP7n002ooP7n00
0ol0003om`SgooL8m`05ooL8m`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ooj1OX2o`0000SojAKY00?o0000om0_d?o@;m002_o@;m000ol0003oZ5NXojQGZ007ojQG
Z003o`000?n/Djco[5>/00?o[5>/0ol00005ogF:M@03o`000?nZEJ[oZUFZ00_oZUFZ00?o0000on0O
h?oP7n003?oP7n000ol0003om`SgooL8m`06ooL8m`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000WonPGj00?o0000onTFjOoY5^T01OoY5^T2o`0000co
d2o@00?o0000ojQGZ?nXEjP01OnXEjP00ol0003o[5>/ojaC[007ojaC[0?o000000?oMHYeo`000?nZ
EJX03OnZEJX00ol0003oh1oPon0Oh00<on0Oh003o`000?og2?Oom`Sg00Kom`Sg00?o0000ooT6nOoi
1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?oj1O[onPGj00OonPGj
0_l00004onTFj@03o`000?o_4>ooka3_00;o00002_o@;m000ol0003oZ5NXojQGZ003ojQGZ0;o0000
3On/Dj`2o`0000goZUFZ0ol0000=on0Oh003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooT6nOoi1_T0
1Ooi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00SonPGj0_l0
00000ooY5^Wo0000onl@k`04onl@k`03o`000?o@;m3od2o@00Ood2o@00Co0000ojQGZ?nXEjSoZ5NX
0_l00002om@[e003o`000?n/Djco[5>/00co[5>/3Ol00003on4Nh@03o`000?oP7n3oh1oP00[oh1oP
00?o0000ooL8moog2?L02?og2?L01?l0003on@KiooT6nOoi1_T4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003onPGj
ooX5nP09ooX5nP03o`000?o_4>ooka3_00Goka3_0_l00008om0_d003o`000?nXEjSo000000Goe2_D
00?o0000ojaC[?n/Dj`02on/Dj`00ol0003o^TFjokY5^P09okY5^P03o`000?oQ7^7ohAkQ00;ohAkQ
0_l00009on0Oh003o`000?og2?Oom`Sg00[om`Sg0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000onl@koo_4>l01oo_4>l4o`0000?od2o@0ol0
0007om@[e003o`000?n/Djco[5>/00[o[5>/00?o0000okY5^_njAKX02OnjAKX00ol0003ohAkQon4N
h@04on4Nh@;o00001ooP7n000ol0003om`SgooL8m`0:ooL8m`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_4>l02?o_4>l0
1?l0003okQ7^onhAk_o^4Nh3o`0000;oiA[U00?o0000om@[e?oD:m@01_oD:m@00ol0003o[5>/ojaC
[008ojaC[003o`000?njAK[o^TFj00[o^TFj00?o0000on4NhOoQ7^401_oQ7^400ol0003oh1oPon0O
h004on0Oh003o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oka3_onl@k`08onl@k`03o`000?o^4Nko
kQ7^00CokQ7^00Go0000onDJiOoU6^GoiA[Uo`000008om@[e003o`000?n/Djco[5>/00Oo[5>/00?o
0000okY5^_njAKX02_njAKX00ol0003ohAkQon4Nh@07on4Nh@;o00001?oP7n000ol0003om`SgooL8
m`08ooL8m`03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003oka3_onl@k`08onl@k`03o`000?o^4NkokQ7^00CokQ7^00?o0000onDJiOoU6^D00_oU6^D0
0ol0003oe2_Dom@[e007om@[e003o`000?n/Djco[5>/00Ko[5>/00?o0000okY5^_njAKX02_njAKX0
0ol0003ohAkQon4Nh@09on4Nh@05o`000?oP7n3oh1oPon0Oh?l000002Oog2?L00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_oka3_00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oiA[UonDJi@03
onDJi@03o`000?oD:mCoe2_D00Ooe2_D00?o0000ojaC[?n/Dj`01On/Dj`00ol0003o^TFjokY5^P0:
okY5^P03o`000?oQ7^7ohAkQ00WohAkQ1?l00009ooL8m`03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?oj1O[onPGj
ooX5n_l000002_o_4>l00ol0003okQ7^onhAkP05onhAkP03o`000?oU6^GoiA[U00?oiA[U00?o0000
om@[e?oD:m@02?oD:m@00ol0003o[5>/ojaC[004ojaC[003o`000?njAK[o^TFj00Wo^TFj00?o0000
on4NhOoQ7^402?oQ7^42o`0000?om`Sg00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003oka3_onl@k`06onl@k`03o`000?o^4NkokQ7^
00GokQ7^00?o0000onDJiOoU6^D01?oU6^D00ol0003oe2_Dom@[e009om@[e003o`000?n/Djco[5>/
00;o[5>/00?o0000okY5^_njAKX02_njAKX00ol0003ohAkQon4Nh@06on4Nh@;o00001_og2?L8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o_4>ooka3_00Goka3_00?o0000onhAk_o^
4Nh01Oo^4Nh00ol0003oiA[UonDJi@05onDJi@03o`000?oD:mCoe2_D00Woe2_D00Go0000ojaC[?n/
Djco[5>/o`00000<okY5^P03o`000?oQ7^7ohAkQ00CohAkQ0_l00008ooL8m`03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_
4>l00oo_4>l00ol0003okQ7^onhAkP06onhAkP03o`000?oU6^GoiA[U00GoiA[U00?o0000om@[e?oD
:m@02_oD:m@00ol0003o[5>/o`000004o`0000Wo^TFj00?o0000on4NhOoQ7^400_oQ7^42o`0000[o
m`Sg00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP07ooX5nP03o`00
0?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oiA[UonDJi@07onDJi@;o0000
2ooD:m@00ol0003oj1OXonPGj003onPGj0Oo00000_njAKX00ol0003ohAkQon4Nh@02o`0000_om`Sg
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooX5n_oj1OX02Ooj
1OX01Ol0003oka3_onl@koo_4>oo000000SokQ7^00?o0000onDJiOoU6^D01ooU6^D00ol0003olPgb
o`000002o`0000Soe2_D00?o0000onPGj?oX5nP02_oX5nP5o`0000gom`Sg00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<ooX5nP03o`000?o_4>oo000000WokQ7^00?o
0000onDJiOoU6^D01_oU6^D00ol0003olPgboo8=lP03oo8=lP?o00001?oD:m@00ol0003oj1OXonPG
j00=onPGj003o`000?og2?Oom`Sg00gom`Sg00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_onPGj00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oiA[UonDJi@07
onDJi@03o`000?ob3O;olPgb00KolPgb0ol000000ooD:mCo0000onPGj00>onPGj003o`000?og2?Oo
m`Sg00com`Sg00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009ooX5
nP03o`000?o^4NkokQ7^00;okQ7^1_l00008onDJi@03o`000?ob3O;olPgb00[olPgb00?o0000onPG
j?oX5nP03ooX5nP00ol0003om`SgooL8m`0:ooL8m`;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007ooX5nPGo00001_og2?L00ol0003oiA[UonDJi@05onDJi@03o`000?ob3O;olPgb00[o
lPgb00?o0000onPGj?oX5nP03ooX5nP00ol0003om`SgooL8m`07ooL8m`?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005ooX5nP03o`000?og2?Oom`Sg00Wom`Sg00?o0000onDJiOoU
6^D00ooU6^D00ol0003olPgboo8=lP0;oo8=lP03o`000?oX5nSoj1OX00ooj1OX00?o0000ooL8moog
2?L01Oog2?L2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?onPGjo`000?l00000
3Oog2?L00ol0003oiA[UonDJi@02onDJi@03o`000?ob3O;olPgb00_olPgb5?l00004ooL8m`;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooL8m`04o`000?oU6^GoiA[Uo`0000kolPgb
00?o0000ooT6nOoi1_T04?oi1_T00ol0003om`Sgo`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_og2?L00ol0003oiA[Uo`00000>oo8=lP03o`00
0?oi1_Won@Ki017on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003om`SgooL8m`0=ooL8m`03o`000?ob3O;olPgb00WolPgb1Ol0
000BooT6n@;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003om`SgooL8m`0<ooL8m`03o`000?ob3O;olPgb00;olPgb1ol00004ood2o@03o`000?oi1_Wo
n@Ki00oon@Ki00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?og2?Oom`Sg00com`Sg1?l0000<ood2o@03o`000?oi1_Won@Ki00con@Ki0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0=ood2o@03o`000?oi1_Won@Ki00_o
n@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003om`SgooL8m`0:ooL8m`03o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi
1_T02Ooi1_T2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003oo@;m
ood2o@0?ood2o@03o`000?oi1_Won@Ki00Kon@Ki0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo@;mood2o@0>ood2o@05o`000?om0_goo@;mood2oOl000000ooi1_T2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00?oo@;m00?o0000ooT6nOl000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ood2
oOom0_d02oom0_d00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00Ko
o@;m00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@08ood2o@03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2
o@07ood2o@;o00002oom0_d00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
o@;mood2o@03ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3oom0_d00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?om0_goo@;mo`0001?oo@;m
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oom0_d2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ood2o@03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000koo@;m0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo@;m00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo@;m
ood2o@07ood2o@03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ood2o@Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`05o`00o`Koool01ol00?l3oooo00co003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001Ol00?l3oooo00?o003o0_ooo`07o`00o`?oool02Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool02?l00?l3oooo00Ko003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000=o`00o`03oooo0?l00?oo003o00Oo003o0oooo`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000=o`00o`;oool02Ol00?l2oooo00Go003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
3Ol00?l2oooo00[o003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00[o003o0_ooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`0<o`00o`?oool01Ol00?l5oooo0003o`00ooooo`3oool000;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00_o003o0oooo`05o`00o`;oool01?l00?l3oooo00;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l0
0?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l5oooo00Go003o0oooo`05o`00o`;oool00_l0
0?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05
o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o
003o00;oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06
o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o
01Oo003o0_ooo`0;o`00o`;oool01Ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo
00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool0
0?l05ol00?l2oooo00co003o0_ooo`04o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`03
oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`0Ho`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool01?l00?l2oooo00Ko003o
00?oool0o`00ool00?l00_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l0
0?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00
o`02o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00o`03oooo0?l00?oo003o00?o003o0_oo
o`04o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3
oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`03o`00o`;oool00ol00?l2
oooo00Ko003o0_ooo`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol00?l1
ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo023o003o1?ooo`09o`00
o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(400) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.994 .006 .994 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.993 .007 .993 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.976 .024 .976 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.992 .008 .992 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.977 .023 .977 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.969 .031 .969 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.954 .046 .954 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.988 .012 .988 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.949 .051 .949 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.994 .006 .994 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.89 .11 .89 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.906 .094 .906 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.823 .177 .823 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.935 .065 .935 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.987 .013 .987 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.989 .011 .989 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.974 .026 .974 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.676 .324 .676 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.946 .054 .946 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.864 .136 .864 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.858 .142 .858 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.888 .112 .888 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.929 .071 .929 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.957 .043 .957 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.994 .006 .994 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.835 .165 .835 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.921 .079 .921 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.75 .25 .75 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.951 .049 .951 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.917 .083 .917 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.863 .137 .863 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.917 .083 .917 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.738 .262 .738 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.941 .059 .941 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.856 .144 .856 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.955 .045 .955 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.778 .222 .778 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.441 .559 .441 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.524 .476 .524 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.981 .019 .981 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.981 .019 .981 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.916 .084 .916 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.994 .006 .994 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.811 .189 .811 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.822 .178 .822 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.5 .5 .5 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.489 .511 .489 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.379 .621 .379 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.789 .211 .789 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.817 .183 .817 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.994 .006 .994 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.791 .209 .791 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.706 .294 .706 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.968 .032 .968 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.592 .408 .592 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.938 .062 .938 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.886 .114 .886 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.503 .497 .503 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.409 .591 .409 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.712 .288 .712 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.136 .864 .136 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.15 .85 .15 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.239 .761 .239 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.553 .447 .553 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.541 .459 .541 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.934 .066 .934 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.192 .808 .192 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.203 .797 .203 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.822 .178 .822 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.968 .032 .968 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.993 .007 .993 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.321 .679 .321 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.39 .61 .39 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.716 .284 .716 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.993 .007 .993 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.759 .241 .759 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.377 .623 .377 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.654 .346 .654 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.118 .882 .118 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.548 .452 .548 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.359 .641 .359 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.973 .027 .973 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.063 .937 .063 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.089 .911 .089 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.9 .1 .9 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.037 .963 .037 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.02 .98 .02 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.668 .332 .668 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.931 .069 .931 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.231 .769 .231 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.051 .949 .051 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.519 .481 .519 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.11 .89 .11 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.223 .777 .223 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.95 .05 .95 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.007 .993 .007 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.132 .868 .132 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.17 .83 .17 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.836 .164 .836 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.26 .74 .26 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.33 .67 .33 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.014 .986 .014 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.025 .975 .025 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.076 .924 .076 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.012 .988 .012 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.417 .583 .417 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.686 .314 .686 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.993 .007 .993 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.828 .172 .828 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.182 .818 .182 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.171 .829 .171 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.475 .525 .475 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.974 .026 .974 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.117 .883 .117 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.158 .842 .158 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.67 .33 .67 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.082 .918 .082 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.028 .972 .028 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.912 .088 .912 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.974 .026 .974 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.675 .325 .675 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.739 .261 .739 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.086 .914 .086 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.918 .082 .918 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.339 .661 .339 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.476 .524 .476 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.073 .927 .073 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.265 .735 .265 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.463 .537 .463 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.993 .007 .993 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.993 .007 .993 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.951 .049 .951 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.122 .878 .122 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.127 .873 .127 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.027 .973 .027 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.886 .114 .886 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.231 .769 .231 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.969 .031 .969 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.187 .813 .187 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.183 .817 .183 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.195 .805 .195 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.721 .279 .721 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.782 .218 .782 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.663 .337 .663 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.017 .983 .017 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.229 .771 .229 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.372 .628 .372 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.642 .358 .642 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.881 .119 .881 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.994 .006 .994 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.962 .038 .962 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.228 .772 .228 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.455 .545 .455 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.184 .816 .184 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.868 .132 .868 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.798 .202 .798 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.993 .007 .993 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.657 .343 .657 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.905 .095 .905 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.967 .033 .967 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.178 .822 .178 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.304 .696 .304 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.955 .045 .955 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.18 .82 .18 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.732 .268 .732 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.553 .447 .553 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.567 .433 .567 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.393 .607 .393 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.924 .076 .924 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.897 .103 .897 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.906 .094 .906 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.928 .072 .928 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.47 .53 .47 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.974 .026 .974 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.85 .15 .85 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.409 .591 .409 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.465 .535 .465 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.993 .007 .993 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.715 .285 .715 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.612 .388 .612 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.992 .008 .992 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.971 .029 .971 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.878 .122 .878 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.966 .034 .966 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.486 .514 .486 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.946 .054 .946 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.833 .167 .833 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.77 .23 .77 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.994 .006 .994 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.743 .257 .743 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.633 .367 .633 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.775 .225 .775 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.989 .011 .989 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.627 .373 .627 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.991 .009 .991 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.713 .287 .713 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.992 .008 .992 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.836 .164 .836 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.912 .088 .912 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.858 .142 .858 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.924 .076 .924 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.944 .056 .944 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.856 .144 .856 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.718 .282 .718 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.842 .158 .842 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.91 .09 .91 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.946 .054 .946 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.929 .071 .929 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.939 .061 .939 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.989 .011 .989 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.873 .127 .873 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.969 .031 .969 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.991 .009 .991 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.976 .024 .976 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.958 .042 .958 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.883 .117 .883 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.97 .03 .97 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.944 .056 .944 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.939 .061 .939 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.959 .041 .959 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.993 .007 .993 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.992 .008 .992 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.993 .007 .993 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.992 .008 .992 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.993 .007 .993 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ood2o@03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?ooP7n0_l0000@ooh1oP03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003omPWfooH9m_l0000>ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooH9m_of2OH00_of2OH00ol0003ooP7nooh1oP0;ooh1oP03o`000?om
0_goo@;m00Woo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00?omPWf00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooH9m_of2OH01Oof2OH00ol0003ooP7nooh1oP08ooh1oP03o`000?om0_goo@;m
00_oo@;m00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003omPWfooH9mP06ooH9mP03
o`000?on0OkooP7n00KooP7n00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooH9m_of2OH02?of2OH00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00coo@;m
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oi1_Wo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000comPWf00Co0000ooh1o_on0OkooP7n0ol0000@ood2o@03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooT6n@03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ol`ccoo<<l`05oo<<l`03o`000?of
2OKomPWf00_omPWf0ol00003oo@;m003o`000?om0_goo@;m00coo@;m0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003ol`ccoo<<l`06
oo<<l`03o`000?of2OKomPWf00[omPWf00?o0000oo@;m?od2o@01?od2o@00ol0003oo@;mood2o@0:
ood2o@04o`000?ob3O;olPgboo8=lP;o00002_om0_d2o`000003oo4>lOl0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?om0_go
o@;m00Woo@;m00?o0000ooT6nOl000002oon0Oh00ol0003ol`ccoo<<l`06oo<<l`03o`000?of2OKo
mPWf00WomPWf00?o0000oo@;m?od2o@01_od2o@00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;o
lPgb00ColPgb0_l00005ood2o@?o00001?oa3_400ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooT6n@03o`000?om0_goo@;m00Ooo@;m0_l00003ooT6
n@03o`000?on0OkooP7n00OooP7n00?o0000oo<<looc3?<01ooc3?<00ol0003omPWfooH9mP09ooH9
mP03o`000?od2oCom0_d00Oom0_d00?o0000ood2oOom0_d01Oom0_d2o`0000WolPgb0_l000000oom
0_go0000o`000007oo4>l@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooT6nOoi
1_T02?oi1_T00ol0003oo@;mood2o@06ood2o@03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on
0Oh01oon0Oh00ol0003ol`ccoo<<l`08oo<<l`03o`000?of2OKomPWf00OomPWf00?o0000oo@;m?od
2o@02Ood2o@00ol0003oo@;mood2o@03ood2o@03o`000?ob3O;olPgb00_olPgb00?o0000oo4>lOoa
3_401ooa3_400ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`Sgo`000005ooh1oP;o00002ooi1_T2o`0000Koo@;m
00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ooP7nooh1oP06ooh1oP03o`000?oc3??ol`cc00Sol`cc
00?o0000ooH9m_of2OH01_of2OH00ol0003om0_doo@;m00;oo@;m005o`000?om0_goo@;mood2oOl0
00003_ob3O800ol0003ol@kaoo4>l@08oo4>l@03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?og2?Oom`SgooL8mol0
00000oon0Oh00ol0003on@KiooT6n@0:ooT6n@04o`000?o^4NkokQ7^o`0000?oo@;m0_l00008ooT6
n@03o`000?on0OkooP7n00KooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003omPWfooH9mP05ooH9
mP03o`000?od2oCom0_d00com0_d00?o0000ood2oOl000003oob3O800ol0003ol@kaoo4>l@08oo4>
l@03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`SgooL8m`03ooL8m`03o`000?on0Oko000000_o
n@Ki0_l00004onhAkP03o`000?om0_go000000_on@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l`ccoo<<l`09oo<<l`03o`000?of2OKomPWf00ComPWf00?o0000oo@;m?od2o@03_od2o@00ol0003o
lPgboo8=lP0>oo8=lP03o`000?oa3_7ol@ka00Wol@ka00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooL8moog2?L0
1?og2?L00ol0003on@KiooT6n@09ooT6n@03o`000?o^4NkokQ7^00GokQ7^00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP05ooh1oP03o`000?oc3??ol`cc00[ol`cc00?o0000ooH9m_of2OH0
0oof2OH00ol0003om0_doo@;m00>oo@;m003o`000?ob3O;olPgb00golPgb00?o0000oo4>lOoa3_40
2_oa3_400ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`SgooL8
m`05ooL8m`03o`000?oi1_Won@Ki00Oon@Ki0_l00008onhAkP03o`000?oi1_Won@Ki00_on@Ki00?o
0000ooh1o_on0Oh01?on0Oh00ol0003ol`ccoo<<l`0:oo<<l`04o`000?of2OKomPWfooH9mP?o0000
3ood2o@00ol0003olPgboo8=lP0>oo8=lP03o`000?oa3_7ol@ka00[ol@ka00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooT6nOoi1_T01?oi1_T2o`0000_okQ7^1?l0
0009ooT6n@03o`000?on0OkooP7n00?ooP7n00?o0000oo<<looc3?<02ooc3?<01?l0003omPWfo`00
0?l00003omhQgP;o00003?od2o@2o`00013olPgb00?o0000oo4>lOoa3_402ooa3_400ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003om`Sg
ooL8m`07ooL8m`03o`000?oi1_Won@Ki00?on@Ki00?o0000onhAk_o^4Nh02oo^4Nh01?l0003odbcC
om</dooC;=<5o`0000Gon@Ki00?o0000ooh1o_on0Oh00_on0Oh00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oN8MkogR7N00GogR7N0_l00008oo@;m0;o00000_oI9]T00ol0003olPgboo8=lP0=oo8=lP03
o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003om`SgooL8m`09ooL8m`03o`000?oi1_Won@Ki00;o0000
3Oo^4Nh00ol0003odbcCom</d`07om</d`Ko00000_on0Oh4o`0000gol`cc00?o0000omhQg_oN8Mh0
1ooN8Mh2o`0000Gom0_d00?o0000omTVfOoI9]T00ooI9]T00ol0003olPgboo8=lP0<oo8=lP03o`00
0?oa3_7ol@ka00col@ka00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o
0000ooT6nOl000003oo^4Nh00ol0003odbcCom</d`0<om</d`?o00001?o[5>/3o`0000Wol`cc00?o
0000omhQg_oN8Mh02_oN8Mh2o`000003oo@;m?l0003o000000OofBKI00?o0000oo8=l_ob3O802oob
3O800ol0003ol@kaoo4>l@0<oo4>l@03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?og2?Oom`Sg00_om`Sg00?o0000
onhAk_o^4Nh03_o^4Nh00ol0003odbcCom</d`0=om</d`03o`000?o[5>_ojaC[00KojaC[0ol00005
oo<<l`03o`000?oN8MkogR7N00gogR7N00?o0000omTVfOoI9]T02?oI9]T00ol0003olPgboo8=lP09
oo8=lP03o`000?oa3_7ol@ka00gol@ka00Co0000ood2oOom0_goo@;m1Ol00003ooD:m@03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooL8moog2?L02oog2?L2o`0000ookQ7^00?o0000om</dooC;=<03OoC;=<00ol0003ojaC[on/Dj`0:
on/Dj`?o000000?ol`cco`000?oN8Mh03ooN8Mh00ol0003ofBKIomTVf@09omTVf@03o`000?ob3O;o
lPgb00SolPgb00?o0000oo4>lOoa3_403_oa3_43o`0000Som@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?og2?Oom`Sg00Som`Sg0ol000000ooR
7N;o0000onhAkP0>onhAkP03o`000?oC;=?odbcC00godbcC00?o0000on/Djoo[5>/03Oo[5>/00ol0
003ogR7NomhQgP0?omhQgP03o`000?oI9]WofBKI00[ofBKI2ol0000;oo4>l@Go00003?oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003om0_do`000?on0Oko0000
00Som`Sg0ol00005on8MhP03o`000?o^4NkokQ7^00cokQ7^00?o0000om</dooC;=<03OoC;=<00ol0
003ojaC[on/Dj`0=on/Dj`;o00004?oN8Mh00ol0003ofBKIomTVf@0:omTVf@03o`000?oE:]GoeB[E
00OoeB[E00?o0000oo4>lOoa3_400_oa3_47o`0000CofbCK00?o0000ooD:mOoe2_D02_oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003om0_doo@;m?od2o@2o`00
00Gom`Sg0ol00009on8MhP;o00002oo^4Nh00ol0003odbcCom</d`0=om</d`03o`000?o[5>_ojaC[
00gojaC[00Co0000olPgb?o8=lSo00003ooN8Mh00ol0003ofBKIomTVf@09omTVf@03o`000?oE:]Go
eB[E00WoeB[E1?l0000;om/Tf`03o`000?oe2_Gom@[e00[om@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo@;m?od2o@01?od2o@00ol0003om`Sgo`000002o`00
00cohQgR00Co0000ol8m`_l0003o00002Oo^4Nh00ol0003odbcCom</d`0=om</d`03o`000?o[5>_o
jaC[00gojaC[00Go0000olPgb?o8=lSob3O8o`00000=omhQgP03o`000?oI9]WofBKI00[ofBKI00?o
0000omDZeOoE:]D02OoE:]D00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oe2_Gom@[e00[om@[e00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?od2o@01_od2o@0
0ol0003ohQgRon8MhP0<on8MhP03o`000?o2?L;o`Sg200;o`Sg20_l00007onhAkP03o`000?oC;=?o
dbcC00codbcC00?o0000on/Djoo[5>/03Oo[5>/00ol0003ob3O8olPgb003olPgb003o`000?oN8Mko
gR7N00[ogR7N00?o0000omTVfOoI9]T02_oI9]T00ol0003oeB[EomDZe@09omDZe@03o`000?oK9=_o
fbCK00cofbCK00?o0000ooD:mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003om0_doo@;m006oo@;m003o`000?oR7N;ohQgR00_ohQgR00?o0000ol8m
`_o2?L801Oo2?L800ol0003okQ7^onhAkP03onhAkP03o`000?oC;=?odbcC00godbcC00?o0000on/D
joo[5>/03Oo[5>/00ol0003ob3O8olPgb004olPgb003o`000?oN8MkogR7N00WogR7N00?o0000omTV
fOoI9]T02OoI9]T00ol0003oeB[EomDZe@0:omDZe@03o`000?oK9=_ofbCK00cofbCK00?o0000ooD:
mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m0_doo@;m007oo@;m003o`000?oR7N;ohQgR00_ohQgR00?o0000ol8m`_o2?L801_o2?L82o`0000?o
kQ7^00?o0000om</dooC;=<03OoC;=<00ol0003ojaC[on/Dj`0<on/Dj`03o`000?o8=lSob3O800Ko
b3O800?o0000omhQg_oN8Mh02?oN8Mh00ol0003ofBKIomTVf@09omTVf@03o`000?oE:]GoeB[E00[o
eB[E00?o0000om/TfooK9=/03?oK9=/00ol0003om@[eooD:m@0;ooD:m@03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo@;m?od2o@02?od2o@00ol0003ohQgRon8MhP0:on8MhP03o`00
0?o2?L;o`Sg200Wo`Sg20_l000000oo^4Nko0000om</d`0<om</d`?o00003_o[5>/00ol0003ob3O8
olPgb007olPgb003o`000?oN8MkogR7N00OogR7N00?o0000omTVfOoI9]T02OoI9]T00ol0003oeB[E
omDZe@0;omDZe@03o`000?oK9=_ofbCK00cofbCK00?o0000ooD:mOoe2_D02_oe2_D00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo@;m?od2o@02_od2o@00ol0003ohQgRon8M
hP09on8MhP03o`000?o2?L;o`Sg200_o`Sg200?o0000om</dooC;=<02_oC;=<2o`0000?oZeB[00?o
0000on/Djoo[5>/02_o[5>/00ol0003ob3O8olPgb009olPgb003o`000?oN8MkogR7N00KogR7N00?o
0000omTVfOoI9]T02?oI9]T00ol0003oeB[EomDZe@0<omDZe@03o`000?oK9=_ofbCK00cofbCK00?o
0000ooD:mOoe2_D02_oe2_D00ol0003ooP7nooh1oP04ooh1oPCo00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on8Mh_oR7N802?oR7N80
0ol0003o`Sg2ol8m`P0<ol8m`P03o`000?oC;=?odbcC00SodbcC0_l00006oj]DZ`;o00002_o[5>/0
0ol0003ob3O8olPgb00:olPgb003o`000?oN8MkogR7N00GogR7N00?o0000omTVfOoI9]T02?oI9]T0
0ol0003oeB[EomDZe@0<omDZe@03o`000?oK9=_ofbCK00cofbCK00?o0000ooD:mOoe2_D02ooe2_D0
0ol0003ooP7no`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo@;m003o`000?oR7N;ohQgR00OohQgR00?o0000ol8m`_o2?L803_o2?L800ol0003odbcCom</d`04
om</d`?o00002_n[E:/00ol0003ojaC[on/Dj`07on/Dj`03o`000?o8=lSob3O800_ob3O800?o0000
omhQg_oN8Mh00ooN8Mh00ol0003ofBKIomTVf@09omTVf@03o`000?oE:]GoeB[E00coeB[E00?o0000
om/TfooK9=/03?oK9=/00ol0003om@[eooD:m@0;ooD:m@;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003om0_doo@;m00<oo@;m003o`000?oR7N;ohQgR00OohQgR00?o0000ol8m`_o2?L803oo2?L801?l0
003odbcCom</dooC;=<2o`0000koZeB[0_l00006on/Dj`03o`000?o8=lSob3O800gob3O800?o0000
omhQg_oN8Mh00_oN8Mh00ol0003ofBKIomTVf@08omTVf@03o`000?oE:]GoeB[E00coeB[E0ol0000=
om/Tf`03o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oom0_d00?o0000on8Mh_oR7N801_oR7N800ol0003o`Sg2ol8m`P0@ol8m`PCo00004_n[E:/00ol0
003ojaC[on/Dj`03on/Dj`03o`000?o8=lSob3O800kob3O800Go0000omhQg_oN8MkogR7No`000005
omTVf@Oo00003?oE:]D01Ol0003o]TVfokI9]_nfBKKo000000cofbCK00?o0000ooD:mOoe2_D02?oe
2_D3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oom0_d00?o0000on8Mh_oR7N801_oR7N800ol0003o`Sg2ol8m`P0=
ol8m`P?o000000CoS7><o`000?l0003o00004on[E:/2o`0000;ojaC[00?o0000olPgb?o8=lP04?o8
=lP00ol0003ogR7No`000006o`0000Oo]dRg00?o0000omDZeOoE:]D02?oE:]D00ol0003o]TVfokI9
]P03okI9]P;o00002?oK9=/3o`0000Kom@[e1?l00002oo4>l@03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003on@Kio`000?oL8m`3o`0000gom0_d00?o0000on8Mh_oR7N801?oR7N800ol0003o`Sg2ol8m
`P0;ol8m`P?o00000on<Lh`01Ol0003oQ7^4o`000?mDZeCo000001CoZeB[00?o0000on/Djol00000
4oo8=lP00ol0003o]dRgokM8]`0=okM8]`03o`000?oE:]GoeB[E00GoeB[E0_l00008okI9]P03o`00
0?oK9=_ofbCK00Go00000ooG:=L00ol0003om@[eooD:m@03o`0000Ool@ka00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oi1_Won@Kio`0000Cog2?L0ol0000:oo@;m003o`000?oR7N;ohQgR00?ohQgR
00?o0000ol8m`_o2?L802Oo2?L83o`0000GoS7><00Co0000ohAkQ?n4NhCo00000_mDZe@00ol0003o
ZeB[oj]DZ`0Boj]DZ`03o`000?o8=lSob3O801;ob3O800?o0000okM8]ongB;L03_ngB;L00ol0003o
eB[EomDZe@03omDZe@03o`000?nfBKKo]TVf00Wo]TVf0_l00009omLXe`;o00002_oa3_400ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooT6nOoi1_Won@Kio`000007om`Sg0;o00001ood2o@5o`0000;o
hQgR00?o0000ol8m`_o2?L801_o2?L83o`0000SoS7><00Co0000ohAkQ?n4NhCo00000omDZe@00ol0
003oZeB[oj]DZ`0Aoj]DZ`03o`000?o8=lSob3O8017ob3O800?o0000okM8]ongB;L04?ngB;L01Ol0
003oeB[EomDZeOoE:]Go000000co]TVf00?o0000omLXeooG:=L02?oG:=L00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Con@Ki00?o0000om`Sg?oL8m`01ooL8m`3o`00
0004oo@;m?l0003o0000o`0000GobSG:0_l00006ol8m`P?o00002_n<Lh`01Ol0003oQ7^4ohAkQ?n4
NhCo000000CoE:]D00?o0000oj]DZon[E:/04?n[E:/00ol0003ob3O8olPgb00AolPgb003o`000?ng
B;Oo]dRg017o]dRg00?o0000omDZeOl000003OnfBKH00ol0003oebSGomLXe`08omLXe`03o`000?oa
3_7ol@ka00[ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000
om`Sg?oL8m`02_oL8m`00ol0003obSG:olXebP08olXebP03o`000?o2?L;o`Sg200?o00003On<Lh`0
1Ol0003oQ7^4ohAkQ?n4NhCo000000GoE:]D00?o0000oj]DZon[E:/03on[E:/00ol0003ob3O8olPg
b00AolPgb003o`000?ngB;Oo]dRg01;o]dRg00?o0000okI9]_nfBKH03?nfBKH00ol0003oebSGomLX
e`08omLXe`03o`000?oa3_7ol@ka00_ol@ka00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooT6nOoi1_T01Ooi1_T0
0ol0003og2?Lom`Sg00:om`Sg003o`000?o:=L[obSG:00WobSG:0_l0000?ohacS003o`000?n4NhCo
Q7^400;oQ7^400?o0000oeB[E?mDZe@01?mDZe@00ol0003oZeB[oj]DZ`0=oj]DZ`?o00004Oo8=lP0
0ol0003o]dRgokM8]`0CokM8]`03o`000?nfBKKo]TVf00_o]TVf00?o0000omLXeooG:=L02OoG:=L0
0ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ood2oOom0_goo@;mo`000008ooh1oP;o00002?oi1_T0
0ol0003og2?Lom`Sg00:om`Sg003o`000?o:=L[obSG:00WobSG:00?o0000ohacS?n<Lh`03On<Lh`0
0ol0003oQ7^4ohAkQ003ohAkQ003o`000?mDZeCoE:]D00GoE:]D00?o0000oj]DZon[E:/02_n[E:/2
o`0000?oNHIi00?o0000olPgb?o8=lP03_o8=lP00ol0003o]dRgokM8]`0CokM8]`03o`000?nfBKKo
]TVf00_o]TVf00?o0000omLXeooG:=L02OoG:=L00ol0003ol@kaoo4>l@0;oo4>l@03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ood2
oOom0_d00oom0_d2o`0000GooP7n00?o0000ooT6nOoi1_T01ooi1_T2o`0000_og2?L00?o0000olXe
b_o:=LX02oo:=LX00ol0003oS7><ohacS00<ohacS003o`000?n4NhCoQ7^400?oQ7^400?o0000oeB[
E?mDZe@01_mDZe@00ol0003oZeB[oj]DZ`07oj]DZ`;o00001_miQWT2o`0000kob3O800?o0000okM8
]ongB;L04ongB;L00ol0003o]TVfokI9]P0;okI9]P03o`000?oG:=OoebSG00WoebSG00?o0000oo4>
lOoa3_403?oa3_400ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?om0_goo@;m00Koo@;m00Go0000ooh1o_on0OkooP7no`000009ooT6
n@03o`000?ob3O;o000000_og2?L00?o0000olXeb_o:=LX02oo:=LX00ol0003oS7><ohacS00;ohac
S003o`000?n4NhCoQ7^400CoQ7^400?o0000oeB[E?mDZe@01omDZe@00ol0003oZeB[oj]DZ`05oj]D
Z`03o`000?miQWWoNHIi00SoNHIi00?o0000olPgb?o8=lP02_o8=lP00ol0003o]dRgokM8]`0DokM8
]`03o`000?nfBKKo]TVf00_o]TVf00?o0000omLXeooG:=L02OoG:=L00ol0003ol@kaoo4>l@0<oo4>
l@03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7no`000009ooT6n@04o`000?ob3O;olPgbo`00
00_og2?L00?o0000olXeb_o:=LX02oo:=LX00ol0003oS7><ohacS00;ohacS003o`000?n4NhCoQ7^4
00CoQ7^400?o0000oeB[E?mDZe@02?mDZe@00ol0003oZeB[oj]DZ`02oj]DZ`;o00003?miQWT2o`00
00[ob3O800?o0000okM8]ongB;L05?ngB;L00ol0003o]TVfokI9]P0;okI9]P03o`000?oG:=OoebSG
00WoebSG00?o0000oo4>lOoa3_403Ooa3_400ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03
o`000?ob3O;olPgb00;olPgb00?o0000om`Sg?oL8m`02?oL8m`00ol0003obSG:olXebP0<olXebP03
o`000?n<LhcoS7><00WoS7><00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003oE:]DoeB[E009oeB[E004
o`000?n[E:_o0000o`00013oNHIi0_l00008olPgb003o`000?ngB;Oo]dRg01Co]dRg0ol0000;okI9
]P03o`000?oG:=OoebSG00WoebSG00?o0000oo4>lOoa3_403Ooa3_401?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ood2
oOom0_d02Oom0_d00ol0003on@KiooT6n@06ooT6n@03o`000?ob3O;olPgb00?olPgb00?o0000om`S
g?oL8m`02?oL8m`00ol0003obSG:olXebP0;olXebP;o00002_n<Lh`00ol0003oQ7^4ohAkQ006ohAk
Q003o`000?mDZeCoE:]D00[oE:]D00?o0000ogV6NOmiQWT04_miQWT00ol0003ob3O8olPgb004olPg
b003o`000?ngB;Oo]dRg01Go]dRg00?o0000oj1OX?nPGj001Ol00005okI9]P03o`000?oG:=OoebSG
00[oebSG00?o0000oo4>lOoa3_403_oa3_43o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ood2oOom0_d02oom0_d00ol0003on@KiooT6n@04ooT6n@03
o`000?ob3O;olPgb00ColPgb00?o0000om`Sg?oL8m`01ooL8m`00ol0003obSG:olXebP0;olXebP04
o`000?n0Oh3oP7n0o`0000WoS7><00?o0000ohAkQ?n4Nh@01_n4Nh@00ol0003oE:]DoeB[E00:oeB[
E003o`000?miQWWoNHIi01?oNHIi0_l00003olPgb0Co00005?ngB;L00ol0003oX5nPoj1OX006oj1O
X0Co000000?o]TVfo`000?oG:=L02ooG:=L00ol0003ol@kaoo4>l@0>oo4>l@03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ood2oOom
0_d02oom0_d00ol0003on@KiooT6n@03ooT6n@03o`000?ob3O;olPgb00GolPgb00?o0000om`Sg?oL
8m`01ooL8m`00ol0003obSG:olXebP09olXebP;o00001?n0Oh000ol0003oS7><ohacS005ohacS003
o`000?n4NhCoQ7^400OoQ7^400?o0000oeB[E?mDZe@02_mDZe@00ol0003oNHIiogV6N@0EogV6N@03
o`000?o8=lSo000000CoSG:=0ol0000@okM8]`03o`000?nPGj3oX5nP00_oX5nP0_l0000<omLXe`03
o`000?oa3_7ol@ka00col@ka0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooT6nOoi1_T00_oi1_T00ol0003olPgb
oo8=lP06oo8=lP03o`000?oL8mcog2?L00Oog2?L00?o0000olXeb_o:=LX02?o:=LX00ol0003oP7n0
oh1oP005oh1oP003o`000?n<LhcoS7><00CoS7><00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003oE:]D
oeB[E00:oeB[E003o`000?miQWWoNHIi01KoNHIi00?o0000ohebSOn=LXd01_n=LXd3o`0000co]dRg
00?o0000oj1OX?nPGj003OnPGj000ol0003oebSGomLXe`09omLXe`Go00002Ooa3_42o`000003ooD:
mOl0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ood2oOom0_d03?om0_d3o`000003ooT6nOl0003olPgb00WolPgb00?o0000om`Sg?oL8m`01_oL
8m`00ol0003obSG:olXebP07olXebP03o`000?n0Oh3oP7n000OoP7n000?o0000ohacS?n<Lh`00_n<
Lh`00ol0003oQ7^4ohAkQ008ohAkQ003o`000?mDZeCoE:]D00WoE:]D00?o0000ogV6NOmiQWT05omi
QWT00ol0003oSG:=ohebS@09ohebS@?o00002OngB;L00ol0003oX5nPoj1OX00>oj1OX0Ko00001?oG
:=L00ol0003ohQgRon8MhP03on8MhPGo00000_oa3_42o`0000Com@[e00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@0<
ood2o@05o`000?ob3O;olPgboo8=l_l000002oob3O800ol0003og2?Lom`Sg006om`Sg003o`000?o:
=L[obSG:00GobSG:0_l0000;oh1oP004o`000?n<LhcoS7><o`0000_oQ7^400?o0000oeB[E?mDZe@0
2OmDZe@00ol0003oNHIiogV6N@0FogV6N@03o`000?n=LXgoSG:=00goSG:=0ol00005okM8]`03o`00
0?nPGj3oX5nP00ooX5nP00?o0000okM8]ongB;L00ongB;L4o`0000_ohQgR0_l00006ooD:m@03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP02oo8=lPko00001_oL8m`00ol0003obSG:olXe
bP05olXebP03o`000?n0Oh3oP7n000coP7n000?o0000ohacS?l000002on4Nh@00ol0003oE:]DoeB[
E007oeB[E0?o00006?miQWT00ol0003oSG:=ohebS@0@ohebS@?o000000?o]dRgo`000?nPGj004?nP
Gj000ol0003o]dRgokM8]`07okM8]`03o`000?oR7N;ohQgR00[ohQgR00?o0000ooD:mOoe2_D01Ooe
2_D00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?om0_goo@;m00Woo@;m0_l00005oo8=lP03o`000?oM8]gogB;M00_ogB;M0_l00004
om`Sg003o`000?o:=L[obSG:00?obSG:0_l0000@oh1oP003o`000?n4NhCoQ7^400[oQ7^400?o0000
oeB[E?mDZe@00omDZe@4o`0000;o;]4^00?o0000ogV6NOmiQWT05OmiQWT00ol0003oSG:=ohebS@0D
ohebS@03o`000?nPGj3oX5nP013oX5nP00?o0000okM8]ongB;L01ongB;L00ol0003ohQgRon8MhP0:
on8MhP03o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo@;mood2o@08ood2o@03o`000?ob3O;olPgb
00GolPgb00?o0000omdRgOoM8]d03OoM8]d6o`0000?obSG:00?o0000oh1oP?n0Oh004?n0Oh000ol0
003oQ7^4ohAkQ00:ohAkQ003o`000?mDZeCo000000?o00001ol^dBh00ol0003oNHIiogV6N@0DogV6
N@03o`000?n=LXgoSG:=01CoSG:=00?o0000oj1OX?nPGj003onPGj000ol0003o]dRgokM8]`08okM8
]`03o`000?oR7N;ohQgR00[ohQgR00?o0000ooD:mOoe2_D01Ooe2_D00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo8=l_ob3O801_ob3O800ol0003ogB;MomdRg@0=omdRg@03o`000?nl@kco_4>l00?o
_4>l00?o0000olXeb_l000004on0Oh04o`0000WoQ7^40_l0000<obkA;P03o`000?miQWWoNHIi01?o
NHIi00?o0000ohebSOn=LXd05On=LXd00ol0003oX5nPoj1OX00>oj1OX003o`000?ngB;Oo]dRg00So
]dRg00?o0000on8Mh_oR7N802OoR7N800ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ood2o@03o`00
0?ob3O;olPgb00SolPgb00?o0000omdRgOoM8]d02ooM8]d00ol0003o_4>loka3_005oka3_003o`00
0?n0Oh3oP7n001;oP7n000Co0000oc_4>olka3_o>l@k1Ol00003ohAkQ003o`000?l^dBko;]4^00go
;]4^0ol0000@ogV6N@;o00006?n=LXd00ol0003oX5nPoj1OX00=oj1OX003o`000?ngB;Oo]dRg00Wo
]dRg00?o0000on8Mh_oR7N802OoR7N800ol0003om@[eooD:m@07ooD:m@03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_olPgb00?o0000omdRgOoM8]d02_oM8]d00ol0003o_4>loka3_006oka3_003o`00
0?n0Oh3oP7n0017oP7n000?o0000oc_4>olka3/01olka3/3o`00013o;]4^00?o0000oaKY5_lFjAH0
1Ol00009ogV6N@;o000000?o;m0_o`000?n=LXd05on=LXd00ol0003oX5nPoj1OX00=oj1OX003o`00
0?ngB;Oo]dRg00Wo]dRg00?o0000on8Mh_oR7N802?oR7N82o`0000[om@[e00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo8=l_ob3O802Oob3O800ol0003ogB;MomdR
g@0:omdRg@03o`000?nl@kco_4>l00Oo_4>l00?o0000oh1oP?n0Oh003on0Oh000ol0003o>l@koc_4
>`0:oc_4>`03o`000?l^dBko;]4^00go;]4^00?o0000oaKY5_lFjAH01_lFjAH4o`0000CoNHIi00?o
0000obo@;ol_d2l00_l_d2l00ol0003oSG:=ohebS@0FohebS@03o`000?nPGj3oX5nP00_oX5nP00?o
0000okM8]ongB;L02ongB;L00ol0003ohQgRon8MhP06on8MhP03o`000?o`3o3o000000[om@[e00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000oo8=l_ob3O802?ob3O8=
o`0000[o_4>l00?o0000oh1oP?n0Oh003on0Oh000ol0003o>l@koc_4>`0;oc_4>`03o`000?l^dBko
;]4^00co;]4^00?o0000oaKY5_lFjAH02_lFjAH4o`0000Go;m0_00?o0000ohebSOn=LXd05_n=LXd0
0ol0003oX5nPoj1OX00:oj1OX003o`000?ngB;Oo]dRg00co]dRg00?o0000on8Mh_oR7N801?oR7N82
o`0000?ol0o`00?o0000ooD:mOoe2_D02?oe2_D00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5
n_oj1OX00ooj1OX00ol0003olPgboo8=lP07oo8=lP03o`000?oK9=_ofbCK00WofbCK00?o0000oka3
_?nl@k`02Onl@k`00ol0003oP7n0oh1oP00=oh1oP003o`000?lka3_o>l@k00co>l@k00?o0000obkA
;_l^dBh03?l^dBh00ol0003o5^TFoaKY5P0;oaKY5P03o`000?l6n@Ko000000Ko;m0_00?o0000oheb
SOn=LXd05_n=LXd00ol0003oX5nPoj1OX009oj1OX003o`000?ngB;Oo]dRg00co]dRg00?o0000on8M
h_oR7N800ooR7N800ol0003ol0o`oo0?l003oo0?l003o`000?oe2_Gom@[e00Som@[e00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000oo8=l_ob3O801_ob3O800ol0003o
fbCKom/Tf`08om/Tf`03o`000?nl@kco_4>l00_o_4>l00?o0000oh1oP?n0Oh002?n0Oh04o`0000oo
>l@k00?o0000obkA;_l^dBh02ol^dBh00ol0003o5^TFoaKY5P0;oaKY5P04o`000?l6n@Ko1_T6o`00
00Oo;m0_00?o0000ohebSOn=LXd05On=LXd00ol0003oX5nPoj1OX008oj1OX003o`000?ngB;Oo]dRg
00go]dRg00?o0000on8Mh_oR7N800_oR7N800ol0003ol0o`oo0?l005oo0?l003o`000?oe2_Gom@[e
00Oom@[e00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo8=l_ob
3O801Oob3O800ol0003ofbCKom/Tf`08om/Tf`03o`000?nl@kco_4>l00_o_4>l00?o0000oh1oP?n0
Oh000on0Oh05o`0000?o?L8m00?o0000oc_4>olka3/03_lka3/00ol0003o;]4^obkA;P0:obkA;P03
o`000?lFjAKo5^TF00[o5^TF00Go0000o`Ki1_l6n@Ko1_T6o`000007obo@;`03o`000?n=LXgoSG:=
01GoSG:=00?o0000oj1OX?nPGj002?nPGj000ol0003o]dRgokM8]`0=okM8]`03o`000?oR7N;ohQgR
00;o00002?o`3o000ol0003om@[eooD:m@08ooD:m@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?ob3O;olPgb00Go
lPgb00?o0000om/TfooK9=/02?oK9=/00ol0003o_4>loka3_00<oka3_0Go00002Olm`Sd00ol0003o
>l@koc_4>`0<oc_4>`;o00003?l^dBh00ol0003o5^TFoaKY5P0:oaKY5P05o`000?l6n@Ko1_T6o`Ki
1_l000002?l_d2l00ol0003oSG:=ohebS@0DohebS@?o00001onPGj000ol0003o]dRgokM8]`0>okM8
]`03o`000?oR7N;o000000_ol0o`00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003olPgboo8=lP04oo8=lP03o`000?oK9=_ofbCK00Oo
fbCK00?o0000oka3_?nl@k`03?nl@k`01?l0003oOgmoogmoOol0000;ocg2?@03o`000?lka3_o>l@k
00_o>l@k00Co0000o`7n0Ol1oP7o00002_l^dBh00ol0003o5^TFoaKY5P0:oaKY5P03o`000?l6n@Ko
1_T600;o1_T600?o0000obo@;ol_d2l01_l_d2l00ol0003oSG:=ohebS@0AohebS@?o00000omXUfP0
0ol0003oX5nPoj1OX004oj1OX003o`000?ngB;Oo]dRg00go]dRg1?l0000;oo0?l003o`000?oe2_Go
m@[e00Gom@[e00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00KonPGj00Co0000oo8=
l_ob3O;olPgb1?l00008om/Tf`03o`000?nl@kco_4>l00_o_4>l00?o0000ogmoOomoOgl00_moOgl0
0ol0003o?L8mocg2?@08ocg2?@03o`000?lka3_o>l@k00[o>l@k00?o0000o`7n0Ol1oP400_l1oP40
0ol0003o;]4^obkA;P03obkA;PGo00002olFjAH00ol0003o1_T6o`Ki1P03o`Ki1P03o`000?l_d2oo
;m0_00Oo;m0_00?o0000ohebSOn=LXd03_n=LXd2o`0000OoJ9MX00?o0000oj1OX?nPGj000_nPGj00
0ol0003o]dRgokM8]`0=okM8]`03o`000?oO8=oogb3O00;ogb3O00?o0000oo0?l?o`3o002Oo`3o00
0ol0003om@[eooD:m@03ooD:m@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5
nP?o00001?oS7><00ol0003ofbCKom/Tf`05om/Tf`03o`000?nl@kco_4>l00[o_4>l00?o0000ogmo
OomoOgl00omoOgl00ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00So>l@k00?o0000o`7n
0Ol1oP401?l1oP45o`0000Co0?l000?o0000oaKY5_lFjAH02OlFjAH00ol0003o1_T6o`Ki1P03o`Ki
1P03o`000?l_d2oo;m0_00So;m0_00?o0000ohebSOn=LXd02_n=LXd3o`0000[oJ9MX00Go0000oj1O
X?nPGj3oX5nPo`00000>okM8]`03o`000?oO8=oogb3O00Cogb3O0_l00009oo0?l003o`000?oe2_Go
m@[e00;om@[e00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000on<L
hooS7><01OoS7><00ol0003ofbCKom/Tf`03om/Tf`03o`000?nl@kco_4>l00[o_4>l00?o0000ogmo
OomoOgl01?moOgl00ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00Oo>l@k00?o0000o`7n
0Ol1oP401Ol1oP400ol0003o0?l0o`3o0007o`3o0003o`000?lFjAKo5^TF00Oo5^TF00?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o;m0_obo@;`08obo@;`03o`000?n=LXgoSG:=00SoSG:=0_l0000>ofRG
J0Co00003?ngB;L2o`0000Wogb3O00?o0000oo0?l?o`3o001oo`3o001?l0003om@[eooD:mOl0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ohacSon<Lh`07on<Lh`;o00000ooK9=/00ol0
003o_4>loka3_009oka3_003o`000?moOgooOgmo00KoOgmo00?o0000ocg2?Olm`Sd02Olm`Sd00ol0
003o>l@koc_4>`05oc_4>`03o`000?l1oP7o0Oh100Ko0Oh100?o0000o`3o0?l0o`002?l0o`000ol0
003o5^TFoaKY5P06oaKY5P03o`000?l6n@Ko1_T600Co1_T600?o0000obo@;ol_d2l02Ol_d2l4o`00
00?oSG:=0ol0000@ofRGJ005o`000?o6>LKoaSW6olHia_l000002_ngB;L00ol0003ogb3OomlPg`0:
omlPg`Ko00000oo`3o000ol0003om@[eo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0
003ohacSon<Lh`0:on<Lh`04o`000?oK9=_ofbCKo`0000[o_4>l00?o0000ogmoOomoOgl01omoOgl0
0ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00Co>l@k00?o0000o`7n0Ol1oP401ol1oP40
0ol0003o0?l0o`3o0008o`3o00;o00001_lFjAH00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?l_d2oo
;m0_00Wo;m0_00Co0000obkA;_l^dBko;]4^0ol0000BofRGJ003o`000?o6>LKoaSW600?oaSW60_l0
0006okM8]`;o00003OoO8=l00ol0003on0OhooP7n003ooP7n0Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003ohacSon<Lh`0<on<Lh`;o00002_nl@k`00ol0003oOgmoogmoO`08ogmoO`03o`000?lm`Sgo
?L8m00[o?L8m00?o0000oc_4>olka3/00_lka3/00ol0003o0Oh1o`7n0@08o`7n0@03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lFjAKo5^TF00;o5^TF00?o0000o`Ki1_l6n@H01_l6n@H0
0ol0003o;m0_obo@;`08obo@;`03o`000?l^dBko;]4^00Co;]4^00?o0000ofRGJ?mXUfP03omXUfP0
0ol0003oaSW6olHiaP06olHiaP;o00000ongB;L00ol0003ogb3OomlPg`0=omlPg`03o`000?oh1oSo
n0Oh00Oon0Oh0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?oS7>?ohacS
00kohacS00?o0000oka3_?nl@k`01onl@k`00ol0003oOgmoogmoO`0:ogmoO`03o`000?lm`Sgo?L8m
00Wo?L8m00Go0000oc_4>olka3_o>l@ko`00000;o`7n0@03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lFjAKo5^TFoaKY5_l000002?l6n@H00ol0003o;m0_obo@;`08obo@;`03o`000?l^
dBko;]4^00Go;]4^00?o0000ofRGJ?mXUfP03_mXUfP00ol0003oaSW6olHiaP08olHiaP03o`000?ng
B;Oo000000oogb3O00?o0000ooP7n?oh1oP02?oh1oP01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oj1O[onPGjo`00017ohacS00?o0000oka3_?nl@k`01_nl@k`00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?lm`Sgo?L8m00Wo?L8m00Co0000oc_4>olka3_o00003?l1oP400ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5^TFo`000009o`Ki1P03o`000?l_d2oo;m0_00So
;m0_00?o0000obkA;_l^dBh01Ol^dBh00ol0003oJ9MXofRGJ00=ofRGJ003o`000?o6>LKoaSW600[o
aSW600?o0000omlPgooO8=l03_oO8=l00ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bon<Lh`03o`00
0?nl@kco_4>l00Co_4>l00?o0000ogmoOomoOgl03?moOgl00ol0003o?L8mocg2?@0:ocg2?@?o0000
3?l1oP400ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Ki1_l6n@H02?l6n@H00ol0003o;m0_
obo@;`07obo@;`03o`000?l^dBko;]4^00Oo;]4^00?o0000ofRGJ?mXUfP03?mXUfP00ol0003oaSW6
olHiaP0;olHiaP;o00003_oO8=l00ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP00ooh1oP00ol0003ohacSon<Lh`0?on<Lh`?o00000onl
@k`00ol0003oOgmoogmoO`0>ogmoO`03o`000?lm`Sgo?L8m00So?L8m00Co0000o`Wf2Ol9mPWo2OH9
0_l0000:o`7n0@?o00003Ol0o`000ol0003o1_T6o`Ki1P08o`Ki1P03o`000?l_d2oo;m0_00Oo;m0_
00?o0000obkA;_l^dBh01ol^dBh00ol0003oJ9MXofRGJ00;ofRGJ003o`000?o6>LKoaSW600coaSW6
00?o0000oo0?l?l000000_l0000:omlPg`03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n004ooP7n003o`000?oS7>?ohacS00cohacS0_l0
0003om8]dP03o`000?nl@kco0000017oOgmo00?o0000ocg2?Olm`Sd01olm`Sd00ol0003o2OH9o`Wf
2@04o`Wf2@;o00002?l1oP400ol0003o0?l0o`3o000>o`3o00;o00002?l6n@H00ol0003o;m0_obo@
;`06obo@;`03o`000?l^dBko;]4^00Wo;]4^00?o0000ofRGJ?mXUfP02OmXUfP00ol0003oaSW6olHi
aP0=olHiaP03o`000?o`3o3ol0o`00;ol0o`0ol00007omlPg`03o`000?oh1oSon0Oh00Oon0Oh00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oS7>?o
hacS00WohacS0_l00006om8]dP03o`000?moOgooOgmo013oOgmo00?o0000ocg2?Olm`Sd01_lm`Sd0
0ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100Co0Oh10ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol6n@H00ol0003o;m0_obo@;`06obo@;`03o`000?l^dBko;]4^00[o;]4^00?o0000
ofRGJ?mXUfP02?mXUfP00ol0003oaSW6olHiaP0=olHiaP03o`000?o`3o3ol0o`00Gol0o`0ol00004
omlPg`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on0OhooP7n006ooP7n003o`000?oS7>?ohacS00GohacS0ol00008om8]dP03o`000?moOgooOgmo
017oOgmo00Co0000ocg2?Olm`Sgo?L8m1?l0000;o`Wf2@;o000000Co0Oh1o`000?l0003o00000ol3
o0<2o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1_T600?o0000obo@;ol_d2l01_l_
d2l00ol0003o;]4^obkA;P0:obkA;P03o`000?mXUfSoJ9MX00OoJ9MX00?o0000olHia_o6>LH03_o6
>LH00ol0003ol0o`oo0?l008oo0?l0Co00002_oh1oP00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on0OhooP7n007ooP7n003o`000?oS7>?ohacS00;ohacS0_l0000<om8]dP03o`000?moOgoo
Ogmo013oOgmo1?l00003oc7><@03o`000?l9mPWo2OH900_o2OH900?o0000o`?l0ol3o0<01_l3o0<0
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obkA;P03o`000?mXUfSo
J9MX00KoJ9MX00?o0000olHia_o6>LH03_o6>LH00ol0003ol0o`oo0?l00;oo0?l003o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00Won0Oh00Co0000on<L
hol0003o00003_oB;M800ol0003oOgmoogmoO`0?ogmoO`03o`000?lacS7o<Lha00Ko<Lha00?o0000
o`Wf2Ol9mPT02_l9mPT00ol0003o0o`3o`?l0`07o`?l0`;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l^dBko;]4^00So;]4^00?o0000obkA;_l^dBh03?l^dBh00ol0003oJ9MXofRGJ005
ofRGJ003o`000?o6>LKoaSW600ooaSW60_l0000=oo0?l003o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00[on0Oh00?o0000om8]d_oB;M803_oB;M800ol0
003oOgmoogmoO`0>ogmoO`03o`000?lacS7o<Lha00Oo<Lha00?o0000o`Wf2Ol9mPT02_l9mPT00ol0
003o0o`3o`?l0`09o`?l0`;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l^dBko;]4^
00Wo;]4^00?o0000obkA;_l^dBh02_l^dBh4o`0000CoJ9MX00?o0000olHia_o6>LH04?o6>LH01?l0
003okA;]o`000?l0000<oo0?l003o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oh1oSon0Oh00[on0Oh00?o0000om8]d_oB;M803ooB;M8@o`0000[o<Lha00?o0000o`Wf
2Ol9mPT02Ol9mPT00ol0003o0?l0o`00000<o`?l0`05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o;]4^obkA;P09obkA;P03o`000?l^dBko;]4^00Oo;]4^0ol00004ofBKI0?o000000?oJ9MX
o`000?o6>LH04Oo6>LH01?l0003okA;]ondBkOo]4^d2o`0000_ol0o`00?o0000ooP7n?oh1oP00ooh
1oP00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003odRgBom8]dP0?
om8]dP03o`000?mmPWgoOH9m00coOH9m00?o0000oc7><OlacS402OlacS400ol0003o2OH9o`Wf2@07
o`Wf2@04o`000?l0o`3o0?l0o`0000go0o`300Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l^dBko;]4^00[o;]4^00?o0000obkA;_l^dBh00ol^dBh3o`0000[oI9]T00?o0000olHia_o6>LH0
4?o6>LH00ol0003okA;]ondBk@04ondBk@;o00002_o`3o000ol0003on0OhooP7n004o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con0Oh00?o0000om8]d_oB;M803ooB;M800ol0003oOH9mogf2O@0<ogf2O@03o`000?la
cS7o<Lha00Wo<Lha00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o0?l0o`3o0002o`3o0003o`000?l3
o0?o0o`300[o0o`300?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l^
dBko;]4^00[o;]4^00?o0000obkA;_l^dBh00ol0000=ofBKI003o`000?o6>LKoaSW6013oaSW600?o
0000ondBkOo]4^d01_o]4^d2o`0000Wol0o`0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003odRgBom8]dP0=om8]dP?o00003ommPWd0
0ol0003o<Lhaoc7><@08oc7><@03o`000?l9mPWo2OH900Go2OH900?o0000o`3o0?l0o`000ol0o`00
0ol0003o0o`3o`?l0`0:o`?l0`03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o;]4^obkA;P0;obkA;P;o00004OmTVf@00ol0003oaSW6olHiaP0?olHiaP03o`000?o]4^go
kA;]00SokA;]0_l00007oo0?l003o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooP7n?oh1oP02?oh1oP00ol0003odRgBom8]dP09om8]dPGo00000_n]DZd00ol0
003oOH9mogf2O@0=ogf2O@03o`000?lacS7o<Lha00Wo<Lha00?o0000o`Wf2Ol9mPT01?l9mPT00ol0
003o0?l0o`3o0004o`3o0003o`000?l3o0?o0o`300So0o`300?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l^dBko;]4^00_o;]4^00?o0000ofBKI?mTVf@04?mTVf@00ol0
003oaSW6olHiaP0?olHiaP03o`000?o]4^gokA;]00[okA;]0_l00004oo0?l003o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on0OhooP7n007ooP7n003o`000?oB;M;odRgB00CodRgB1Ol00007ojeB[@03
o`000?mmPWgoOH9m00goOH9m00?o0000oc7><OlacS402OlacS400ol0003o2OH9o`Wf2@03o`Wf2@03
o`000?l0o`3o0?l000Go0?l000?o0000o`?l0ol3o0<02?l3o0<00ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000obkA;_l^dBh02ol^dBh00ol0003oI9]TofBKI00@ofBKI003
o`000?o6>LKoaSW600ooaSW600?o0000ondBkOo]4^d03?o]4^d2o`000003oo0?l?l0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000om8]d_l00000
1?l0000<ojeB[@03o`000?mmPWgoOH9m00koOH9m00?o0000oc7><OlacS402?lacS400ol0003o2OH9
o`Wf2@02o`Wf2@03o`000?l0o`3o0?l000Oo0?l000?o0000o`?l0ol3o0<01ol3o0<00ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000obkA;_l^dBh02ol^dBh00ol0003oI9]T
ofBKI00AofBKI003o`000?o6>LKoaSW600goaSW600?o0000ondBkOo]4^d03oo]4^d00ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP01Ooh1oP3o`00017o[E:]00?o0000ogf2OOmmPWd03_mm
PWd00ol0003o<Lhaoc7><@09oc7><@04o`000?l9mPWo2OH9o`0000[o0?l000?o0000o`?l0ol3o0<0
1ol3o0<00ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol^dBh00ol0003o
I9]TofBKI00AofBKI0?o00003Oo6>LH00ol0003okA;]ondBk@0?ondBk@03o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oh1oP2o`0000;oiaSW00?o0000ojeB[On]DZd03on]DZd00ol0003o
OH9mogf2O@0>ogf2O@03o`000?lacS7o<Lha00So<Lha1Ol0000;o`3o0003o`000?l3o0?o0o`300Ko
0o`300?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=obkA;P03o`000?mTVfCoI9]T
017oI9]T00?o0000ogb3O?mlPg`00ol0000:olHiaPCo00003Oo]4^d00ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooT6nOoi1_Won@Ki0_l00005onLHi`03o`000?n]DZgo[E:]00ko[E:]00?o0000ogf2
OOmmPWd03_mmPWd00ol0003o<Lhaoc7><@07oc7><@03o`000?l@ka3o4>l@00?o4>l@00?o0000o`3o
0?l0o`002?l0o`000ol0003o0o`3o`?l0`05o`?l0`03o`000?l0o`3o0?l000[o0?l01Ol0000<obkA
;P03o`000?mTVfCoI9]T013oI9]T00?o0000ogb3O?mlPg`01?mlPg`3o`0000KoaSW600?o0000onPG
j?oX5nP00_oX5nP5o`0000SokA;]00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00?o
n@Ki00?o0000onLHiooW6>L01?oW6>L00ol0003o[E:]ojeB[@0=ojeB[@03o`000?mmPWgoOH9m00oo
OH9m00?o0000oc7><OlacS401?lacS42o`0000Oo4>l@00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000obkA;_l^dBh02?l^dBh3o`00013oI9]T00?o0000ogb3O?mlPg`02?mlPg`3o`0000;o
aSW600?o0000onPGj?oX5nP02?oX5nP5o`0000?okA;]00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oi1_Won@Ki00Con@Ki00?o0000onLHiooW6>L01OoW6>L00ol0003o[E:]ojeB[@0;ojeB[@Co0000
3ommPWd00ol0003o<Lhaoc7><@03oc7><@03o`000?l@ka3o4>l@00So4>l@00?o0000o`3o0?l0o`00
1?l0o`02o`0000So1_T600?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l^dBh2o`0000?o;m0_00?o0000ofBKI?mTVf@03?mTVf@00ol0003oO8=logb3O00<ogb3O0;o0000
4?oX5nP3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oW6>OoiaSW00KoiaSW00?o
0000ojeB[On]DZd02On]DZd00ol0003o_cnoo`000002og2?L0?o00003?mmPWd01?l0003o<Lhaoc7>
<OlacS42o`0000co4>l@00?o0000o`3o0?l0o`000_l0o`000ol0003o1_T6o`Ki1P08o`Ki1P03o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o;]4^obkA;P02obkA;P03o`00
0?l_d2oo;m0_00Co;m0_0_l0000;ofBKI003o`000?mlPgcoO8=l00coO8=l00?o0000oki1__l00000
4_oX5nP00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on@KiooT6n@06ooT6n@03o`000?oW6>OoiaSW00OoiaSW00?o
0000ojeB[On]DZd01_n]DZd2o`0000;o_cno00?o0000og2?L?m`Sg000om`Sg03o`0000[oOH9m00?o
0000oc7><Ol000003ol@ka001?l0003o0?l0o`000?l0000;o`Ki1P03o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o;]4^o`000?l00009obo@;`03o`000?mTVfCoI9]T00Oo
I9]T00?o0000ogb3O?mlPg`03?mlPg`01?l0003o_T6noki1__l0000ConPGj003o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003oiaSWonLHi`08onLHi`03o`000?n]DZgo[E:]00Co
[E:]00?o0000oklo_ono?kl00ono?kl00ol0003oL8m`og2?L005og2?L0?o00001_mmPWd4o`00013o
4>l@00?o0000o`Ki1_l6n@H03?l6n@H00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoI9]T00?o0000ogb3O?mlPg`03?mlPg`00ol0003o
_T6noki1_P02oki1_P03o`000?oX5nSoj1OX00ooj1OX00?o0000ooP7n?l000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oW6>OoiaSW00WoiaSW00Co0000ojeB[On]DZgo
[E:]0_l00006oklo_`03o`000?m`Sg3oL8m`00SoL8m`0ol000000ommPWgo0000o`000004oc?<<`03
o`000?l@ka3o4>l@00go4>l@00?o0000o`Ki1_l6n@H03?l6n@H00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oI9]TofBKI003o`0000ko
O8=l00?o0000oki1__nn@Kh00onn@Kh00ol0003oj1OXonPGj00>onPGj005o`000?oh1oSon0OhooP7
n?l000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@09ooT6n@03o`000?oW6>OoiaSW00[o
iaSW00?o0000ojeB[Ol000002?no?kl00ol0003oL8m`og2?L00;og2?L003o`000?lcc3?o<l`c00Go
<l`c00?o0000oa3_4?l@ka003?l@ka000ol0003o1_T6o`Ki1P0<o`Ki1P03o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002ogN8M`03o`000?mlPgcoO8=l00_o
O8=l00?o0000oki1__nn@Kh01?nn@Kh00ol0003oj1OXonPGj00=onPGj003o`000?oh1oSon0Oh00?o
n0Oh00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooT6n@03o`000?oW6>OoiaSW00_oiaSW00?o0000oklo_ono?kl0
1ono?kl00ol0003oL8m`og2?L00;og2?L003o`000?lcc3?o<l`c00Ko<l`c00?o0000oa3_4?l@ka00
2ol@ka02o`0000go1_T600?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000ogN8MomgR7L00_mgR7L00ol0003oO8=logb3O009ogb3O003
o`000?nn@Kko_T6n00Ko_T6n00?o0000onPGj?oX5nP02ooX5nP00ol0003on0OhooP7n005ooP7n004
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son@Ki00?o0000onLHiooW6>L02_oW6>L2o`0000Wo
_cno00?o0000og2?L?m`Sg002om`Sg000ol0003o<l`coc?<<`07oc?<<`03o`000?l@ka3o4>l@00Wo
4>l@00Co0000o`3o0?l0o`3o00003?l6n@H00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?mgR7OoMhQg00?oMhQg00?o0000
ogb3O?mlPg`01omlPg`00ol0003o_T6noki1_P07oki1_P03o`000?oX5nSoj1OX00[oj1OX00?o0000
ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooT6n@03o`000?oW6>OoiaSW
00WoiaSW00Co0000on<LhooS7>?o00002Ono?kl00ol0003oL8m`og2?L009og2?L003o`000?lcc3?o
<l`c00Wo<l`c00?o0000oa3_4?l@ka001ol@ka000ol0003o0?l0o`3o0002o`3o0003o`000?l6n@Ko
1_T600Wo1_T600?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oMhQgogN8M`05ogN8M`03o`000?mlPgco
O8=l00GoO8=l00?o0000oki1__nn@Kh02?nn@Kh00ol0003oj1OXonPGj009onPGj003o`000?oh1oSo
n0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oi1_T3o`0000WoiaSW00?o0000on<L
hooS7><00_oS7><00ol0003o_cnooklo_`06oklo_`03o`000?m`Sg3oL8m`00WoL8m`00?o0000oc?<
<olcc3<02_lcc3<00ol0003o4>l@oa3_4005oa3_4003o`000?l0o`3o0?l000Co0?l000?o0000o`Ki
1_l6n@H02?l6n@H00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?mgR7OoMhQg00KoMhQg00?o0000ogb3
O?mlPg`00omlPg`00ol0003o_T6noki1_P09oki1_P03o`000?oX5nSoj1OX00Soj1OX00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo@;m0?o00001OoW6>L00ol0003o
hacSon<Lh`03on<Lh`03o`000?no?koo_cno00Ko_cno00?o0000og2?L?m`Sg002Om`Sg000ol0003o
<l`coc?<<`0;oc?<<`03o`000?l@ka3o4>l@00?o4>l@00?o0000o`3o0?l0o`001_l0o`000ol0003o
1_T6o`Ki1P08o`Ki1P03o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oMhQgogN8M`07ogN8M`05o`000?mlPgcoO8=logb3
O?l000003Onn@Kh00ol0003oj1OXonPGj006onPGj003o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?od2oCom0_d00Gom0_d0ol000000ooW6>Oo0000on<Lh`06on<Lh`03
o`000?no?koo_cno00Go_cno00?o0000og2?L?m`Sg002Om`Sg000ol0003o<l`coc?<<`0<oc?<<`05
o`000?l@ka3o4>l@oa3_4?l000002_l0o`000ol0003o1_T6o`Ki1P07o`Ki1P03o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olOh1oo0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000ogN8MomgR7L02OmgR7L00ol0003oO8=lo`00000=oki1_PCo00001OoX5nP00ol0
003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om0_doo@;m008oo@;m003
o`000?oS7>?ohacS00OohacS00?o0000oklo_ono?kl01?no?kl00ol0003oL8m`og2?L009og2?L003
o`000?lcc3?o<l`c00go<l`c00?o0000oa3_4?l000003?l0o`0:o`0000Oo0?l00ol00005oaoP7`03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oMhQgogN8M`0:ogN8M`03
o`000?nn@Kko_T6n00_o_T6n00?o0000onTFjOoY5^T00_oY5^T3o`000003onPGj?l0003on0Oh00_o
n0Oh0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003ohacSon<Lh`07on<Lh`03o`00
0?no?koo_cno00Go_cno00?o0000og2?L?m`Sg001om`Sg000ol0003o<l`coc?<<`0?oc?<<`;o0000
2ol0o`000ol0003o4n`Coa?/4`07oa?/4`03o`000?l0o`3o0?l000;o0?l00ol00008oaoP7`03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oMhQgogN8M`0:ogN8M`03o`00
0?nn@Kko_T6n00[o_T6n00?o0000onTFjOoY5^T01_oY5^T00ol0003on0OhooP7n008ooP7n0?o0000
0_oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003ohacSon<L
h`08on<Lh`03o`000?no?koo_cno00Co_cno00?o0000og2?L?m`Sg001om`Sg000ol0003o<l`coc?<
<`0>oc?<<`04o`000?l5nPGo1OX5o`0000Wo0?l000?o0000oa?/4olCk1<02OlCk1<01?l0003o0?l0
o`000?l0000<oaoP7`03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
MhQgogN8M`0;ogN8M`03o`000?nn@Kko_T6n00Oo_T6n0_l00009onTFj@03o`000?oh1oSon0Oh00Co
n0Oh1?l00006ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m009oo@;m003o`00
0?oS7>?ohacS00SohacS00?o0000oklo_ono?kl00ono?kl>o`0000go<l`c00?o0000o`Gj1Ol5nPD0
0_l5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?lCk1?o4n`C00_o4n`C00?o0000oaoP7olOh1l0
3?lOh1l00ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000ogN8MomgR7L0
3?mgR7L00ol0003o_T6noki1_P06oki1_P03o`000?oY5^WojAKY00[ojAKY00?o0000ooP7n?oh1oP0
0ol0000:ooT6n@?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on<LhooS7><02?oS
7><01Ol0003o_cnooklo_ono?koo000000_oQWV600?o0000ob;M8_lRgB800ol00009oc?<<`03o`00
0?l5nPGo1OX500Co1OX500?o0000o`3o0?l0o`000ol0o`000ol0003o4n`Coa?/4`0<oa?/4`03o`00
0?lOh1oo7n0O00go7n0O00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmgR7L00ol0003o_T6noki1_P05oki1_P03o`000?oY5^WojAKY00cojAKY0_l0000=ooT6n@03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on<LhooS7><02?oS
7><4o`0000coQWV600?o0000ob;M8_lRgB800olRgB83o`0000Go<l`c00?o0000o`Gj1Ol5nPD01_l5
nPD01Ol0003o0?l0o`3o0?l0o`3o000000oo4n`C00?o0000oaoP7olOh1l03OlOh1l00ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000ol]dRd00ol0003oMhQgogN8M`0;ogN8M`03o`00
0?nn@Kko_T6n00?o_T6n00?o0000onTFjOoY5^T03OoY5^T00ol0003on@KiooT6n@0;ooT6n@03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo@;m?od2o@02_od2o@3o`0000KohacS0ol0
0003omDZe@03o`000?n6NHKoQWV600[oQWV600?o0000ob;M8_lRgB801_lRgB83o`000003oc?<<ol0
003o1OX500Wo1OX500?o0000o`3o0?l000004?lCk1<00ol0003o7n0OoaoP7`0=oaoP7`03o`000?l4
n`Co1?/400Oo1?/40_l00007obgB;@03o`000?mgR7OoMhQg00[oMhQg00Co0000oki1__nn@Kko_T6n
0ol0000?onTFj@03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo@;m?od2o@02_od
2o@01?l0003oka3_onl@koo_4>l2o`000004on<Lhol0003o0000o`0000KoeB[E00?o0000ohIiQ_n6
NHH02_n6NHH00ol0003o8]dRob;M8P09ob;M8P03o`000?l5nPGo1OX500[o1OX500?o0000oa?/4olC
k1<03olCk1<00ol0003o7n0OoaoP7`0>oaoP7`03o`000?l4n`Co1?/400Ko1?/400?o0000obgB;Ol]
dRd01ol]dRd4o`0000SoMhQg00Co0000oki1__nn@Kko00000ooF:MH2o`0000gojAKY00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003o
ka3_onl@k`04onl@k`03o`000?oE:]GoeB[E00OoeB[E00?o0000ohIiQ_n6NHH02On6NHH00ol0003o
8]dRob;M8P0:ob;M8P03o`000?l5nPGo1OX500[o1OX500?o0000oa?/4olCk1<03olCk1<00ol0003o
7n0OoaoP7`0>oaoP7`03o`000?l4n`Co1?/400Go1?/400?o0000obgB;Ol]dRd02?l]dRd01?l0003o
N8MhogR7N?mhQgP7o`0000;oMhQg0_l00006omHYeP;o00003?oY5^T00ol0003on@KiooT6n@09ooT6
n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003om0_doo@;m008oo@;m003o`000?o_4>ooka3_00Go
ka3_00?o0000omDZeOoE:]D02?oE:]D00ol0003oQWV6ohIiQP08ohIiQP03o`000?lRgB;o8]dR00[o
8]dR00?o0000o`Gj1Ol5nPD02ol5nPD00ol0003o4n`Coa?/4`0>oa?/4`03o`000?lOh1oo7n0O00ko
7n0O1Ol00002o`Ck1003o`000?l]dRgo;M8]00Wo;M8]00?o0000ogR7N?mhQgP02?mhQgP3o`0000Wo
eRWF0_l0000:onTFj@03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?od2oCom0_d00Som0_d00?o0000onl@koo_4>l01oo_4>l00ol0003oeB[EomDZe@07omDZe@03o`00
0?n6NHKoQWV600SoQWV600?o0000ob;M8_lRgB802_lRgB800ol0003o1OX5o`Gj1@0:o`Gj1@;o0000
3_lCk1<3o`0000go7n0O0ol00005oc7><@;o00002ol]dRd00ol0003oN8MhogR7N00;ogR7N0;o0000
2_oF:MH2o`0000OojAKY0ol00009ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:onl@k`03o`00
0?oE:]GoeB[E00OoeB[E00?o0000ohIiQ_n6NHH02?n6NHH>o`0000Wo1OX50ol000000ol0o`3o0000
oa?/4`0:oa?/4`?o00000_l[e2/00ol0003o7n0OoaoP7`09oaoP7`;o00002OlacS400ol0003o;M8]
obgB;@09obgB;@03o`000?mhQgSoN8Mh00_oN8Mh00?o0000oj9MX_l000002ooF:MH2o`0000CojAKY
00Co0000oo8=l_ob3O;olPgb0_l00007ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003oka3_
onl@k`09onl@k`03o`000?oE:]GoeB[E00KoeB[E00?o0000ohIiQ_n6NHH02?n6NHH00ol0003o9]TV
obKI9P0:obKI9P03o`000?l5nPGo1OX500Co1OX50ol00005o`3o0003o`000?lCk1?o4n`C00Co4n`C
1?l00006ob_D:`03o`000?lOh1oo7n0O00Ko7n0O0_l0000;oc7><@03o`000?l]dRgo;M8]00Wo;M8]
00?o0000ogR7N?mhQgP02_mhQgP01Ol0003oXUfRoj9MX_nRGJ;o000000coeRWF0_l000000ooY5^Wo
0000oo8=lP05oo8=lP03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o_4>ooka3_00Soka3_00?o0000omDZeOoE:]D01_oE:]D00ol0003oQWV6ohIiQP07ohIiQP03o`00
0?lVfBKo9]TV00_o9]TV00?o0000o`Gj1Ol5nPD00_l5nPD2o`0000Wo0?l000?o0000oa?/4olCk1<0
0ol0000;ob_D:`03o`000?lOh1oo7n0O00;o7n0O0ol0000>oc7><@03o`000?l]dRgo;M8]00Oo;M8]
00?o0000ogR7N?mhQgP02omhQgP00ol0003oXUfRoj9MXP02oj9MXP03o`000?oF:MKoeRWF00_oeRWF
00?o0000oo8=l_ob3O801_ob3O82o`0000?on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o_
4>ooka3_00Ooka3_00?o0000omDZeOoE:]D01ooE:]D00ol0003oQWV6ohIiQP05ohIiQP?o00003OlV
fBH4o`0000_o0?l00ol0000?ob_D:`04o`000?lOh1oo0000o`00017o<Lha00?o0000obgB;Ol]dRd0
1ol]dRd00ol0003oN8MhogR7N00:ogR7N003o`000?nRGJ;oXUfR00CoXUfR00?o0000omHYe_oF:MH0
1ooF:MH3o`0000_olPgb1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@koo_4>l02?o_4>l00ol0003oeB[EomDZ
e@06omDZe@03o`000?n6NHKoQWV600;oQWV60ol00003of6NH@03o`000?lVfBKo9]TV00[o9]TV00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aob_D:`03o`000?lacS7o<Lha017o<Lha00?o
0000obgB;Ol]dRd01ol]dRd00ol0003oN8MhogR7N00:ogR7N003o`000?nRGJ;oXUfR00GoXUfR00Co
0000omHYe_oF:MKoeRWF1Ol00002om/Tf`03o`000?ob3O;olPgb00WolPgb00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000onl@koo_4>l01oo_4>l00ol0003oeB[EomDZe@05omDZe@?o0000
00?oQWV6o`000?l000001omQWV400ol0003o9]TVobKI9P08obKI9P?o00002_l0o`02o`0000;o0?l0
00?o0000ob_D:ol[e2/03ol[e2/00ol0003o<Lhaoc7><@0Aoc7><@03o`000?l]dRgo;M8]00Oo;M8]
00?o0000ogR7N?mhQgP02OmhQgP00ol0003oXUfRoj9MXP07oj9MXP?o00001ooK9=/00ol0003olPgb
oo8=lP09oo8=lP03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000onl@koo_4>l01oo_
4>l4o`0000;oeB[E0_l00003olLha`03o`000?mQWV7oHIiQ00SoHIiQ0_l00006obKI9P;o00000olN
hAh00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000ob_D:ol[e2/03_l[
e2/00ol0003o<Lhaoc7><@0Boc7><@03o`000?l]dRgo;M8]00Go;M8]00?o0000ogR7N?mhQgP02Omh
QgP00ol0003oXUfRoj9MXP08oj9MXP03o`000?oK9=_ofbCK00OofbCK00?o0000oo8=l_ob3O802?ob
3O800ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o_4>ooka3_00Coka3_0_l00004
ondBk@;o00001Oo7><L00ol0003oHIiQof6NH@0:of6NH@03o`000?lVfBKo9]TV00;o9]TV00?o0000
oakQ7_lNhAh01?lNhAh00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
ob_D:ol[e2/03_l[e2/00ol0003o<Lhaoc7><@0Boc7><@[o00002_mhQgP00ol0003oXUfRoj9MXP08
oj9MXP03o`000?oK9=_ofbCK00OofbCK00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003oka3_onl@koo_4>l2o`0000OokA;]00?o0000olLhaoo7><L01?o7><L0
0ol0003oHIiQof6NH@0:of6NH@04o`000?lVfBKo0000o`0000So7^4N00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?l[e2_o:m@[00ko:m@[00?o0000oc7><OlacS404_lacS400ol0003oCK9=
odfbC@07odfbC@03o`000?mhQgSoN8Mh00KoN8Mh00?o0000oj9MX_nRGJ802_nRGJ800ol0003ofbCK
om/Tf`06om/Tf`03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o_
4>oo0000o`0000WokA;]00?o0000olLhaoo7><L01?o7><L00ol0003oHIiQof6NH@0;of6NH@03o`00
0?lNhAko7^4N00Wo7^4N00?o0000o`3o0?l000002Ol0o`000ol0003o:m@[ob_D:`0>ob_D:`;o0000
4_lacS400ol0003oCK9=odfbC@09odfbC@;o00001_mhQgP00ol0003oXUfRoj9MXP0:oj9MXP03o`00
0?oK9=_ofbCK00KofbCK00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000ondBkOo]4^d02Oo]4^d00ol0003oacS7olLha`05olLha`03o`000?mQWV7oHIiQ00[oHIiQ00?o
0000oakQ7_lNhAh02_lNhAh2o`0000Wo0?l000?o0000ob_D:ol[e2/03_l[e2/00ol0003o8=lPo`00
0002o`0000oo<Lha00?o0000odfbCOm=/Td02om=/Td00ol0003oN8MhogR7N003o`0000goXUfR00?o
0000om/TfooK9=/01_oK9=/00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003okA;]ondBk@09ondBk@03o`000?o7><OoacS700GoacS700?o0000of6NHOmQWV402OmQWV42
o`0000_o7^4N0_l0000;o`3o0003o`000?l[e2_o:m@[00co:m@[00?o0000ob3O8?lPgb000olPgb03
o`0000co<Lha00?o0000odfbCOm=/Td03?m=/Td2o`0000;oW6>L00?o0000oj9MX_nRGJ803?nRGJ80
0ol0003ofbCKom/Tf`05om/Tf`03o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o]4^gokA;]00[okA;]00?o0000olLhaoo7><L01_o7><L00ol0003oHIiQof6NH@07of6N
H@03o`000?mXUfSo000000[o7^4N00Co0000oaKY5_lFjAKo00002_l0o`000ol0003o:m@[ob_D:`0<
ob_D:`03o`000?lPgb3o8=lP00Ko8=lP0_l00008oc7><@;o00003om=/Td00ol0003oW6>LoiaSW002
oiaSW003o`000?nRGJ;oXUfR00_oXUfR00?o0000om/TfooK9=/01OoK9=/00ol0003olPgboo8=lP07
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okA;]ondBk@0:ondBk@03o`000?o7><OoacS7
00KoacS700?o0000of6NHOmQWV401_mQWV401Ol0003oJ9MXofRGJ?mXUfSo000000So7^4N00?o0000
oaKY5_lFjAH00_lFjAH00ol0003o0?l0o`3o0006o`3o00Co00003?l[e2/00ol0003o8=lPob3O8008
ob3O80?o00000_lacS43o`000003oc[5>_l0003oCK9=00goCK9=00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003oXUfRoj9MXP0:oj9MXP03o`000?oK9=_ofbCK00GofbCK00?o0000oo8=l_ob3O801_ob3O80
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondBkOo]4^d02oo]4^d00ol0003oacS7olLha`07olLh
a`03o`000?mQWV7oHIiQ00?oHIiQ0_l00005ofRGJ003o`000?lNhAko7^4N00Co7^4N00?o0000oaKY
5_lFjAH00olFjAH00ol0003o0?l0o`3o0005o`3o0003o`000?l3o0?o0o`300;o0o`30ol00007ob_D
:`;o00003_lPgb02o`0000Go>/Dj00?o0000odfbCOm=/Td02_m=/Td00ol0003oW6>LoiaSW005oiaS
W003o`000?nRGJ;oXUfR00_oXUfR00?o0000om/TfooK9=/01?oK9=/00ol0003olPgboo8=lP06oo8=
lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003okA;]ondBk@0;ondBk@03o`000?o7><OoacS700Oo
acS700?o0000of6NHOmQWV400_mQWV400ol0003oJ9MXofRGJ006ofRGJ003o`000?lNhAko7^4N00;o
7^4N00?o0000oaKY5_lFjAH01OlFjAH00ol0003o0?l0o`3o0002o`3o00;o00002?l3o0<3o`0000;o
:m@[0_l000000ol7n0Oo0000ob3O800=ob3O8003o`000?ljaC[o>/Dj00Go>/Dj00?o0000odfbCOm=
/Td02?m=/Td00ol0003oW6>LoiaSW007oiaSW003o`000?nRGJ;oXUfR00[oXUfR00?o0000om/TfooK
9=/01?oK9=/00ol0003olPgboo8=lP06oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okA;]
ondBk@0<ondBk@03o`000?o7><OoacS700SoacS700Co0000of6NHOmQWV7o00002OmXUfP01Ol0003o
7^4NoakQ7_lNhAko000000So5^TF00Go0000o`3o0?l0o`3o0?l0o`00000=o`?l0`;o00001?l7n0L0
0ol0003o8=lPob3O800;ob3O8003o`000?ljaC[o>/Dj00Ko>/Dj00?o0000odfbCOm=/Td01om=/Td0
0ol0003oW6>LoiaSW008oiaSW0Co00002?nRGJ800ol0003ofbCKom/Tf`04om/Tf`03o`000?ob3O;o
lPgb00KolPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o]4^gokA;]00_okA;]0ol00009olLh
a`03o`000?mQWV7o000000_oJ9MX00?o0000oakQ7_l000002_lFjAH00ol0003o0?l0o`00000?o`?l
0`03o`000?l7n0Oo1oP700;o1oP700?o0000ob3O8?lPgb002olPgb000ol0003o>/Djoc[5>P06oc[5
>P03o`000?m=/TgoCK9=00KoCK9=00?o0000oiaSW?nLHi`02OnLHi`01?l0003oaC[5olDjaOo5>/D7
o`0000;oXUfR00?o0000om/TfooK9=/00ooK9=/00ol0003olPgboo8=lP05oo8=lP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o]4^gokA;]00SokA;]0ol00003on/Dj`03o`000?o7><OoacS700OoacS700?o0000ofRG
J?mXUfP02omXUfP00ol0003o5^TFoaKY5P0:oaKY5P03o`000?l3o0?o0o`300go0o`300?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o8=lPob3O8009ob3O8003o`000?ljaC[o>/Dj00So>/Dj00?o0000odfb
COm=/Td00om=/Td2o`0000coW6>L00?o0000olDjaOo5>/D02?o5>/D<o`0000?olPgb0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000ondBkOo]4^d01_o]4^d3o`0000OojaC[00?o0000olLhaoo7><L01_o7><L00ol0003o
J9MXofRGJ00;ofRGJ003o`000?lFjAKo5^TF00Wo5^TF0_l0000>o`?l0`03o`000?l7n0Oo1oP700Go
1oP700?o0000ob3O8?lPgb002OlPgb000ol0003o>/Djoc[5>P09oc[5>P03o`000?m=/Tgo000000;o
00000_nAKY400ol0003oW6>LoiaSW008oiaSW003o`000?o5>/GoaC[500coaC[500?o0000on`Ck?o/
4n`01_o/4n`3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003okA;]ondBk@03ondBk@?o00002oo[5>/00ol0003oacS7
olLha`04olLha`03o`000?mXUfSoJ9MX00_oJ9MX0ol00007oaKY5P?o000000?o3O8=o`000?l3o0<0
3Ol3o0<00ol0003o1oP7o`Oh1`06o`Oh1`03o`000?lPgb3o8=lP00So8=lP00?o0000oc[5>_ljaCX0
2_ljaCX00ol0003oTFjAoi5^T@04oi5^T@03o`000?nLHicoW6>L00OoW6>L00?o0000olDjaOo5>/D0
2oo5>/D00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004ondBkOl0
003o0000o`0000oojaC[00?o0000olLhaoo7><L00oo7><L>o`0000?oDZeB0_l00002oaKY5P?o0000
1Ol=lPd00ol0003o0o`3o`?l0`0:o`?l0`03o`000?l7n0Oo1oP700Oo1oP700?o0000ob3O8?lPgb00
2?lPgb000ol0003o>/Djoc[5>P0:oc[5>P03o`000?nAKY7oTFjA00GoTFjA00?o0000oiaSW?nLHi`0
1_nLHi`00ol0003oaC[5olDja@0;olDja@03o`000?o/4ncok1?/00Sok1?/00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;ojaC[00?o0000olLhaoo7><L00_o7><L00ol0003o]TVfokI9
]P0:okI9]P03o`000?mB[E;oDZeB00?oDZeB0_l00009o`gb3@03o`000?l3o0?o0o`300Wo0o`300?o
0000o`Oh1ol7n0L02?l7n0L2o`0000So8=lP00?o0000oc[5>_ljaCX02OljaCX00ol0003oTFjAoi5^
T@07oi5^T@03o`000?nLHicoW6>L00CoW6>L00?o0000olDjaOo5>/D02oo5>/D00ol0003ok1?/on`C
k009on`Ck003o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ojaC[on/Dj`0?on/Dj`?o000000?oacS7
o`000?nfBKH02onfBKH00ol0003oDZeBoe:]DP04oe:]DP03o`000?l=lPgo3O8=00Wo3O8=00?o0000
o`?l0ol3o0<01ol3o0<00ol0003o1oP7o`Oh1`09o`Oh1`04o`000?lBkA;o0000o`0000Ko8=lP00?o
0000oc[5>_ljaCX02OljaCX00ol0003oTFjAoi5^T@08oi5^T@03o`000?nLHicoW6>L00?oW6>L00?o
0000olDjaOo5>/D02oo5>/D00ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003ojaC[on/Dj`0<on/Dj`;o00000ooZ5NX2o`0000co]TVf00?o0000oe:]D_mB[E801?mB[E80
0ol0003o3O8=o`gb3@0:o`gb3@Wo00002ol7n0L00ol0003o4^dBoa;]4P02oa;]4P?o00000_lPgb00
0ol0003o>/Djoc[5>P0:oc[5>P03o`000?nAKY7oTFjA00WoTFjA00?o0000oiaSW?nLHi`00_nLHi`0
0ol0003oaC[5olDja@0:olDja@03o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o[5>/2o`0000GojQGZ00?o0000olTfbOl000002_nfBKH00ol0003oDZeBoe:]DP06oe:]
DP03o`000?l=lPgo3O8=00Wo3O8=00?o0000o`3o0?l0o`001Ol0o`000ol0003o1oP7o`Oh1`09o`Oh
1`03o`000?lBkA;o4^dB00Go4^dB0ol00009oc[5>P?o00003OnAKY401Ol0003oW6>LoiaSW?nLHico
000000coaC[500?o0000on`Ck?o/4n`02Oo/4n`00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on/D
joo[5>/01Oo[5>/2o`0000OojQGZ00Co0000olTfbOo9=/Wo00002OnfBKH00ol0003oDZeBoe:]DP06
oe:]DP03o`000?l=lPgo3O8=00So3O8=00?o0000o`3o0?l0o`001ol0o`000ol0003o1oP7o`Oh1`07
o`Oh1`03o`000?lBkA;o4^dB00So4^dB0ol00002oc[5>PGo00000_mdRg@00ol0003oTFjAoi5^T@0<
oi5^T@03o`000?nLHico000000coaC[500?o0000on`Ck?o/4n`02_o/4n`00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000on/Djoo[5>/00_o[5>/2o`0000SojQGZ00?o0000olTfbOo9=/T00_o9=/T5o`00
00Co]TVf00?o0000oe:]D_mB[E801_mB[E800ol0003o3O8=o`gb3@08o`gb3@03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Oh1ol7n0L01ol7n0L00ol0003o4^dBoa;]4P08oa;]4P03o`000?ljaC[o>/Dj
00;o00002?mdRg@00ol0003oTFjAoi5^T@0<oi5^T@Co00002_o5>/D00ol0003ok1?/on`Ck00:on`C
k003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003ojaC[o`000?l0000:onXEjP03o`000?o9=/WobCK9
00;obCK900?o0000oiMXUonGJ9L00_nGJ9L4o`0000WoDZeB00?o0000o`gb3Ol=lPd02?l=lPd00ol0
003o0?l0o`3o0008o`3o0003o`000?l7n0Oo1oP700Go1oP700?o0000oa;]4_lBkA802?lBkA801Ol0
003o>/Djoc[5>_ljaC[o000000[oM8]d0ol0000;oi5^T@04o`000?oP7n3oh1oPon0Oh0Co00001Oo5
>/D00ol0003ok1?/on`Ck00;on`Ck003o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ojQGZonXEjP0:
onXEjP03o`000?o9=/WobCK900?obCK900?o0000oiMXUonGJ9L01?nGJ9L00ol0003oDZeBoe:]DP07
oe:]DP03o`000?l=lPgo3O8=00Ko3O8=0_l0000;o`3o0003o`000?l7n0Oo1oP700Go1oP700?o0000
oa;]4_lBkA802?lBkA800ol0003o>/Djoc[5>P02oc[5>P03o`000?mdRgCoM8]d00OoM8]d00?o0000
ok]4^onkA;/01?l00006oi5^T@03o`000?oP7n3oh1oP00Koh1oP0ol00002olDja@03o`000?o/4nco
k1?/00_ok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oZ5N[ojQGZ00WojQGZ00?o0000olTf
bOo9=/T01?o9=/T00ol0003oUfRGoiMXU`05oiMXU`03o`000?mB[E;oDZeB00OoDZeB00?o0000o`gb
3Ol=lPd00_l=lPd3o`000003oacS7?l0003o0?l000[o0?l000?o0000o`Oh1ol7n0L01Ol7n0L00ol0
003o4^dBoa;]4P07oa;]4P03o`000?ljaC[o>/Dj00?o>/Dj00?o0000ogB;M?mdRg@01omdRg@00ol0
003o^dBkok]4^`04ok]4^`?o00000_nAKY400ol0003oh1oPon0Oh00:on0Oh0;o00003_o/4n`00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onXEj_oZ5NX02OoZ5NX00ol0003obCK9olTfb@04olTfb@03
o`000?nGJ9OoUfRG00KoUfRG0_l00007oe:]DP03o`000?l=lPgo000000;o00001OlLha`00ol0003o
0?l0o`3o0008o`3o00?o00001?l7n0L00ol0003o4^dBoa;]4P08oa;]4P03o`000?ljaC[o>/Dj00Co
>/Dj00?o0000ogB;M?mdRg@01_mdRg@00ol0003o^dBkok]4^`07ok]4^`;o00003_oP7n000ol0003o
k1?/on`Ck00;on`Ck003o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojQGZonXEjP08onXEjP03o`00
0?o9=/WobCK900GobCK900?o0000oiMXUonGJ9L01?nGJ9L00ol0003oSG:=ohebS@03o`0000CoDZeB
0_l00008oacS7003o`000?l0o`3o0?l000Oo0?l000Co0000obSG:?lXebSo:=LX0ol000000ol7n0Oo
0000oa;]4P09oa;]4P03o`000?ljaC[o>/Dj00Co>/Dj00?o0000ogB;M?mdRg@01OmdRg@00ol0003o
^dBkok]4^`09ok]4^`03o`000?oP7n3oh1oP00goh1oP00?o0000on`Ck?o/4n`02_o/4n`00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onXEj_oZ5NX01ooZ5NX00ol0003obCK9olTfb@06olTfb@03o`00
0?nGJ9OoUfRG00?oUfRG00?o0000ohebSOn=LXd01?n=LXd2o`000003oe:]D_l0003o7><L00[o7><L
00?o0000o`3o0?l0o`001Ol0o`000ol0003o:=LXobSG:005obSG:003o`000?lBkA;o4^dB00Oo4^dB
0ol00007oc[5>P03o`000?mdRgCoM8]d00CoM8]d00?o0000ok]4^onkA;/02OnkA;/00ol0003oh1oP
on0Oh00=on0Oh003o`000?o/4ncok1?/00[ok1?/00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oZ
5N[ojQGZ00GojQGZ0ol00009olTfb@05o`000?nGJ9OoUfRGoiMXUol000002On=LXd00ol0003o7><L
oacS700;oacS7003o`000?l0o`3o0?l000?o0?l000?o0000obSG:?lXebP01_lXebP00ol0003o4^dB
oa;]4P06oa;]4P05o`000?lka3_o>l@koc_4>ol000001oljaCX00ol0003oM8]dogB;M003ogB;M003
o`000?nkA;_o^dBk00Wo^dBk00?o0000on0Oh?oP7n003_oP7n000ol0003ok1?/on`Ck009on`Ck003
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojQGZo`000004o`0000;ol0o`00?o0000olTfbOo9=/T0
1oo9=/T01?l0003oUfRGoiMXUol00009ohebS@;o00003OlLha`00ol0003o0?l0o`3o0002o`3o0003
o`000?lXebSo:=LX00So:=LX00?o0000oa;]4_lBkA800olBkA82o`0000Go>l@k00?o0000oc[5>_lj
aCX01?ljaCX00ol0003oM8]dogB;M003ogB;M003o`000?nkA;_o^dBk00Wo^dBk00?o0000on0Oh?oP
7n003_oP7n000ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sol0o`
00?o0000olTfbOo9=/T01_o9=/T00ol0003oUfRGo`000009ohebS@04o`000?mPWf3oH9mPo`0000go
7><L00Co0000o`3o0?l0o`3o00003?lXebP01Ol0003o4^dBoa;]4_lBkA;o000000So>l@k0_l00005
oc[5>P03o`000?mdRgCoM8]d00;oM8]d00?o0000ok]4^onkA;/02OnkA;/00ol0003oh1oPon0Oh00>
on0Oh003o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o`3o3ol0o`
00Ool0o`00?o0000olTfbOo9=/T01oo9=/T00ol0003oSG:=ohebS@07ohebS@03o`000?mPWf3oH9mP
00;oH9mP00?o0000oacS7?lLha`02_lLha`00ol0003o0?l0o`00000>obSG:003o`000?lBkA;o0000
00_o>l@k00?o0000oc[5>_ljaCX00_ljaCX01Ol0003oM8]dogB;M?mdRgCo000000co^dBk00?o0000
on0Oh?oP7n003_oP7n03o`0000Wok1?/00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00Wol0o`00?o0000olTfbOo9=/T01_o9=/T00ol0003oSG:=ohebS@06ohebS@03o`000?mPWf3oH9mP
00?oH9mP00?o0000oacS7?lLha`02olLha`00ol0003o:=LXobSG:00>obSG:003o`000?lka3_o>l@k
00_o>l@k0_l00003oc[5>P04o`000?mdRgCoM8]do`0000[o^dBk0ol0000>on0Oh0;o00000oom0_d2
o`0000Ook1?/00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000olTf
bOo9=/T01?o9=/T00ol0003oSG:=ohebS@06ohebS@03o`000?mPWf3oH9mP00GoH9mP00?o0000oacS
7?lLha`01olLha`3o`00017o:=LX00?o0000oc_4>olka3/03Olka3/01Ol0003o>/Djoc[5>_l0003o
M8]d00Co00000onkA;/5o`0000;ok1?/00?o0000on0Oh?oP7n002_oP7n02o`0000Ooo@;m0_l00004
on`Ck003o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ol0o`oo0?l00;oo0?l003o`000?o9=/WobCK9
00CobCK900?o0000ohebSOn=LXd01On=LXd00ol0003oH9mPof2OH006of2OH003o`000?lLhaco7><L
00Co7><L0ol00002ob7N8@03o`000?lXebSo:=LX00oo:=LX0_l0000?oc_4>`04o`000?ljaC[o0000
o`0000CoZ5NX0ol00008on`Ck003o`000?oP7n3oh1oP00Ooh1oP0_l0000;ood2o@;o00000_o/4n`0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo0?l?o`3o003?o`3o06o`0000OoSG:=00?o0000of2O
H?mPWf002?mPWf000ol0003o7><LoacS7003o`0000Ko8MhQ00?o0000obSG:?lXebP03OlXebP01?l0
003o@ka3od>l@ol0000?oc_4>`03o`000?nXEjSoZ5NX00GoZ5NX00?o0000on`Ck?o/4n`02?o/4n`0
0ol0003oh1oPon0Oh005on0Oh003o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_o`3o000ol0003occ3?oll`c`04oll`
c`03o`000?n=LXgoSG:=00?oSG:=00?o0000of2OH?mPWf002_mPWf02o`0000[o8MhQ00?o0000obSG
:?lXebP02olXebP00ol0003o@ka3od>l@`02od>l@`03o`000?lka3_o>l@k00_o>l@k0_l00007ojQG
Z003o`000?o/4ncok1?/00Wok1?/00?o0000on0Oh?oP7n000_oP7n02o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo0?l?o`3o002oo`3o000ol0003occ3?oll`c`06oll`c`05o`000?n=LXgoSG:=oheb
SOl000003OmPWf000ol0003o8MhQob7N8@0:ob7N8@03o`000?lXebSo:=LX00Wo:=LX00?o0000od>l
@om3_4<01?m3_4<00ol0003o>l@koc_4>`08oc_4>`;o000000?oGj1Oo`000?nXEjP01onXEjP00ol0
003ok1?/on`Ck009on`Ck004o`000?oP7n3o0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?o`3o3ol0o`
00Wol0o`00?o0000oll`coo?<<l02?o?<<l00ol0003oSG:=o`00000=of2OH003o`000?lQgR7o8MhQ
00_o8MhQ00?o0000obSG:?lXebP02?lXebP00ol0003o@ka3od>l@`06od>l@`03o`000?lka3_o>l@k
00Go>l@k0_l00003oenPG`03o`000?nXEjSoZ5NX00KoZ5NX00?o0000on`Ck?o/4n`02_o/4n`00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003ol0o`oo0?l007oo0?l003o`000?o?<<oocc3?00[occ3?00?o0000of2OH?mP
Wf003?mPWf000ol0003o8MhQob7N8@0<ob7N8@03o`000?lXebSo:=LX00Ko:=LX00?o0000od>l@om3
_4<02?m3_4<00ol0003o>l@koc_4>`02oc_4>`;o00001_mOX5l00ol0003oZ5NXojQGZ005ojQGZ003
o`000?o/4ncok1?/00[ok1?/00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?o`3o3ol0o`00Gol0o`
00?o0000oll`coo?<<l03?o?<<l2o`0000coH9mP00?o0000ob7N8OlQgR403OlQgR400ol0003o:=LX
obSG:004obSG:003o`000?m3_4?o@ka300[o@ka300Co0000oc_4>ol0003o00002?mOX5l00ol0003o
Z5NXojQGZ006ojQGZ003o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_o`3o000ol0003occ3?oll`c`0=oll`c`03o`000?n:MH[o000000;o00002?mPWf000ol0003o8MhQ
ob7N8@0?ob7N8@Ko00003_m3_4<00ol0003oGj1OoenPG`08oenPG`03o`000?nXEjSoZ5NX00KoZ5NX
00?o0000on`Ck?o/4n`02Oo/4n`00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo<<looc3??ol`cc
0_l0000?oll`c`03o`000?n:MH[oRWF:00?oRWF:0ol00005of2OH0;o00004?lQgR401_l0003o7N8M
oagR7Ol0003o5>/Do`0000ko@ka300?o0000oenPGomOX5l02OmOX5l00ol0003oZ5NXojQGZ005ojQG
Z003o`000?o/4ncok1?/00Wok1?/00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003o
cc3?oll`c`0=oll`c`03o`000?n:MH[oRWF:00KoRWF:0ol000001?mPWf3o0000ocW6>OliaST3o`00
00co8MhQ00Go0000oagR7OlMhQgo7N8Mo`000002oaC[5003o`000?m3_4?o@ka300_o@ka300?o0000
oenPGomOX5l02OmOX5l00ol0003oZ5NXojQGZ006ojQGZ003o`000?o/4ncok1?/00Sok1?/0_l0000A
ood2o@?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003ol`ccoo<<l`04oo<<l`oo00003?n:MHX00ol0003o>LHiocW6>@04ocW6
>@?o00002?lQgR400ol0003o7N8MoagR7@02oagR7@05o`000?lDjaCo5>/DoaC[5?l000003?m3_4<0
0ol0003oGj1OoenPG`09oenPG`03o`000?nXEjSoZ5NX00GoZ5NX3?l00002ooL8m`;o00003Oom0_d2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003ol`ccoo<<l`05oo<<l`03o`000?oB;M;odRgB00_odRgB00?o0000ohYe
R_n:MHX02_n:MHX00ol0003o>LHiocW6>@07ocW6>@;o00001OlQgR400ol0003o7N8MoagR7@03oagR
7@03o`000?lDjaCo5>/D00;o5>/D00?o0000od>l@om3_4<02Om3_4<00ol0003oGj1OoenPG`0:oenP
G`03o`000?nXEjSoZ5NX00?oZ5NX00?o0000onDJiOoU6^D02OoU6^D00ol0003om`SgooL8m`02ooL8
m`;o00002Oom0_d2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003ol`ccoo<<l`06oo<<l`03o`000?oB;M;odRgB00[o
dRgB00?o0000ohYeR_n:MHX02on:MHX00ol0003o>LHiocW6>@09ocW6>@?o000000?o8MhQo`000?lM
hQd01OlMhQd00ol0003o5>/DoaC[5003oaC[5003o`000?m3_4?o@ka300So@ka33_l00003ojQGZ0;o
00002ooU6^D00ol0003om`SgooL8m`05ooL8m`03o`000?om0_goo@;m00?oo@;m0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo<<looc3?<01Ooc3?<00ol0003ofbCKo`00000;om8]dP03o`000?n:MH[oRWF:00[oRWF:
0_l0000>ocW6>@03o`000?lMhQgo7N8M00Go7N8M00?o0000oaC[5?lDja@00olDja@00ol0003o@ka3
od>l@`08od>l@`03o`000?nTFjCoY5^T00_oY5^T00?o0000ojQGZ?l000003OoU6^D00ol0003om`Sg
ooL8m`06ooL8m`;o000000?oo@;mo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00Kol`cc00Co
0000om/TfooK9=_o00002_oB;M800ol0003oRWF:ohYeRP09ohYeRP03o`000?mSW6?o000000ko>LHi
00?o0000oagR7OlMhQd01OlMhQd00ol0003o5>/DoaC[5004oaC[5003o`000?m3_4?o@ka300Ko@ka3
00?o0000ojAKY?nTFj@03OnTFj@00ol0003oiA[UonDJi@0<onDJi@03o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oc3??ol`cc00Gol`cc00?o0000om/TfooK9=/00_oK
9=/00ol0003odRgBom8]dP06om8]dP03o`000?n:MH[oRWF:00SoRWF:0_l00003of>LH`03o`000?li
aSWo>LHi00_o>LHi00?o0000oagR7OlMhQd01OlMhQd00ol0003o5>/DoaC[5005oaC[5003o`000?m3
_4?o@ka300Go@ka300?o0000ojAKY?nTFj@03OnTFj@00ol0003oiA[UonDJi@0;onDJi@03o`000?og
2?Oom`Sg00Wom`Sg00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?oc3??ol`cc00Kol`cc00?o0000
om/TfooK9=/00ooK9=/00ol0003odRgBom8]dP05om8]dP03o`000?n:MH[oRWF:00OoRWF:00?o0000
of>LHomSW6<00omSW6<00ol0003o>LHiocW6>@0:ocW6>@03o`000?lMhQgo7N8M00Ko7N8M00?o0000
oaC[5?lDja@01_lDja@00ol0003o@ka3od>l@`04od>l@`03o`000?nTFjCoY5^T00goY5^T3ol0000;
ooL8m`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?oc3??ol`cc00Kol`cc00?o0000om/TfooK9=/01OoK9=/00ol0
003odRgBom8]dP04om8]dP03o`000?n:MH[oRWF:00GoRWF:0_l00006of>LH`03o`000?liaSWo>LHi
00Wo>LHi0_l00008oagR7@03o`000?lDjaCo5>/D00Ko5>/D1Ol000000om3_4?o0000ojAKY00?ojAK
Y003o`000?oW6>OoiaSW00_oiaSW00?o0000ooL8moog2?L02Oog2?L00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?oc3??ol`cc00Kol`cc00?o0000om/TfooK9=/01_oK9=/00ol0003o
dRgBom8]dP04o`0000KoRWF:00?o0000of>LHomSW6<01omSW6<00ol0003o>LHiocW6>@05ocW6>@?o
000000?o:m@[o`000?lMhQd01olMhQd00ol0003o5>/DoaC[5005oaC[5003o`000?mFZEKoEZUF00?o
EZUF0_l0000?ojAKY0;o00003OoW6>L00ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wol`cc00?o0000om/TfooK9=/01ooK9=/2o`0000Co]4^d00Co0000ohYeR_n:MH[o
RWF:0_l0000:of>LH`03o`000?liaSWo>LHi00;o>LHi0ol00005ob_D:`03o`000?lMhQgo7N8M00Go
7N8M00?o0000oaC[5?lDja@01?lDja@00ol0003oEZUFoeJYEP06oeJYEP03o`000?nTFjCoY5^T00[o
Y5^T0_l00002ol`cc003o`000?oW6>OoiaSW00[oiaSW00?o0000ooL8moog2?L02?og2?L00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo<<looc3?<01_oc3?<00ol0003ofbCKom/Tf`08om/Tf`03o`00
0?ndBkCo]4^d00Co]4^d00?o0000ohYeR_l000003?mSW6<00ol0003o>LHio`000002o`0000Wo:m@[
00?o0000oagR7OlMhQd01?lMhQd00ol0003o5>/DoaC[5003oaC[5003o`000?mFZEKoEZUF00SoEZUF
1_l00004ojAKY0;o00001Oo<<l`00ol0003oiaSWonLHi`09onLHi`03o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oc3??ol`cc00Gol`cc00?o0000om/TfooK9=/01ooK
9=/00ol0003o]4^dokA;]006okA;]003o`000?mSW6?oHiaS00coHiaS00?o0000ob_D:ol[e2/02_l[
e2/00ol0003o7N8MoagR7@04oagR7@04o`000?lDjaCo5>/DoaC[50;o00002omFZEH00ol0003oZEJY
ojUFZ@03ojUFZ@Co00002?o<<l`00ol0003oiaSWonLHi`08onLHi`03o`000?og2?Oom`Sg00Oom`Sg
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo<<looc3?<00ooc3?<00ol0003ofbCKom/Tf`07om/Tf`03o`000?nd
BkCo]4^d00Oo]4^d00?o0000of>LHomSW6<03?mSW6<00ol0003o:m@[ob_D:`0;ob_D:`03o`000?lM
hQgo7N8M00?o7N8M00Co0000oaC[5?lDjaCo00003OmFZEH00ol0003oZEJYojUFZ@06ojUFZ@03o`00
0?o<<lcoc3?<00Ooc3?<00?o0000onLHiooW6>L01ooW6>L00ol0003om`SgooL8m`06ooL8m`04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oc3??ol`cc00;ol`cc00?o0000om/TfooK9=/0
1_oK9=/00ol0003o]4^dokA;]009okA;]003o`000?mSW6?oHiaS00WoHiaS0_l0000>ob_D:`?o0000
0olMhQd00ol0003o5>/Do`00000=oeJYEP03o`000?nYEZWoZEJY00OoZEJY00?o0000ol`cc?o<<l`0
2?o<<l`:o`0000Kom`Sg0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OofbCK00?o
0000okA;]?ndBk@02_ndBk@00ol0003oHiaSof>LH`06of>LH`;o000000?oFjAKo`000?l[e2/02ol[
e2/2o`0000?o@[e21Ol0000>oeJYEP03o`000?nYEZWoZEJY00OoZEJY00?o0000ol`cc?o<<l`02?o<
<l`00ol0003okA;]ondBk@06ondBk@03o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003ojQGZonXEjP03onXEjPCo00000_oK9=/00ol0003o]4^dokA;]00;
okA;]003o`000?mSW6?oHiaS00?oHiaS0ol00004oe^TF`03o`000?l[e2_o:m@[00Oo:m@[0_l00008
od:m@P03o`000?mFZEKoEZUF00goEZUF00?o0000ojUFZOnYEZT02?nYEZT00ol0003oc3?<ol`cc007
ol`cc003o`000?o]4^gokA;]00OokA;]0ol000000oog2?Oo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?oZ5N[ojQGZ00OojQGZ0_l0000?okA;]003o`000?mSW6?oHiaS00;o00002?mKY5/00ol0
003o:m@[ob_D:`05ob_D:`03o`000?m2_D;o@[e200So@[e200?o0000oeJYE_mFZEH03OmFZEH00ol0
003oZEJYojUFZ@08ojUFZ@03o`000?o<<lcoc3?<00Koc3?<00?o0000ondBkOo]4^d02?o]4^d01?l0
003on0OhooP7n?l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003ojQGZonXEjP09onXE
jP03o`000?ndBkCo]4^d00ko]4^d0_l0000;oe^TF`03o`000?l[e2_o:m@[00;o:m@[0_l0000;od:m
@P03o`000?mFZEKoEZUF00goEZUF00?o0000ojUFZOnYEZT02?nYEZT00ol0003oc3?<ol`cc006ol`c
c003o`000?o]4^gokA;]00OokA;]00Go0000ooP7n?oh1oSon0Oho`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ojQGZonXEjP0:onXEjP03o`000?ndBkCo]4^d00go]4^d0_l0000<oe^TF`04o`000?l[e2_o0000
o`0000go@[e200?o0000oeJYE_mFZEH03?mFZEH00ol0003oZEJYojUFZ@09ojUFZ@03o`000?o<<lco
c3?<00Koc3?<00?o0000ondBkOo]4^d01_o]4^d00ol0003on0OhooP7n003ooP7n003o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003ojQGZonXEjP0:onXEjP03o`000?ndBkCo]4^d00co]4^d00Co0000ojMH
YonWF:Oo00003?mKY5/00ol0003o@[e2od:m@P0>od:m@P03o`000?mFZEKoEZUF00SoEZUF1?l0000;
ojUFZ@03o`000?o<<lcoc3?<00Koc3?<00?o0000ondBkOo]4^d01Oo]4^d00ol0003on0OhooP7n004
ooP7n003o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003ojQGZonXEjP0;onXEjP03o`000?ndBkCo]4^d
00_o]4^d00?o0000ojMHYonWF:L00_nWF:L00ol0003oFjAKoe^TF`09oe^TF`03o`000?m2_D;o@[e2
00ko@[e200Co0000oeJYE_mFZEKoEZUF1ol00003ogJ9MP03o`000?nYEZWoZEJY00WoZEJY00?o0000
ol`cc?o<<l`01_o<<l`00ol0003okA;]ondBk@04ondBk@03o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oZ5N[ojQGZ00cojQGZ00?o0000okA;]?ndBk@02_ndBk@00ol0
003oYeRWojMHY`03ojMHY`03o`000?mKY5_oFjAK00SoFjAK00?o0000od:m@_m2_D803_m2_D84o`00
00_oMXUf00?o0000ojUFZOnYEZT02?nYEZT00ol0003oc3?<ol`cc005ol`cc003o`000?o]4^gokA;]
00GokA;]00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onXEj_oZ
5NX03?oZ5NX7o`0000Go]4^d00?o0000ojMHYonWF:L01OnWF:L00ol0003oFjAKoe^TF`07oe^TF`03
o`000?m2_D;o@[e200ko@[e200?o0000ogJ9M_mfRGH03OmfRGH00ol0003oZEJYojUFZ@08ojUFZ@03
o`000?o<<lcoc3?<00Coc3?<00?o0000ondBkOo]4^d01?o]4^d00ol0003on0OhooP7n007ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003ojQGZonXEjP0=onXEjP03o`000?oA;]7odBkA00CodBkA
1Ol00009ojMHY`03o`000?mKY5_oFjAK00KoFjAK00?o0000od:m@_m2_D803_m2_D800ol0003oMXUf
ogJ9MP0=ogJ9MP03o`000?nYEZWoZEJY00SoZEJY00Co0000ol`cc?o<<lcoc3?<1Ol00004ondBk@03
o`000?oh1oSon0Oh00Won0Oh1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onXEjP03o`000?oA;]7odBkA00WodBkA
0_l00009ojMHY`03o`000?mKY5_oFjAK00KoFjAK00?o0000od:m@_m2_D803?m2_D800ol0003oMXUf
ogJ9MP0?ogJ9MPKo00001?nYEZT4o`0000GoiaSW0_l000000oo]4^go0000ooP7n00;ooP7n004o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?od2oCom0_doo@;m0?o00002_oZ5NX00ol0003o
dBkAom4^d@09om4^d@03o`000?ngB;Oo000000;o00001onWF:L00ol0003oFjAKoe^TF`05oe^TF`03
o`000?m2_D;o@[e200So@[e21Ol0000AogJ9MP03o`000?nhAkSo^4Nh00?o^4Nh1?l0000;onLHi`03
o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000oo@;m?od2o@01Ood2o@2o`0000OojQGZ
00?o0000om4^dOoA;]402_oA;]400ol0003o]dRgokM8]`02okM8]`?o00001OnWF:L00ol0003oFjAK
oe^TF`04oe^TF`04o`000?m2_D;o@[e2od:m@POo00001?mZUFX00ol0003oMXUfogJ9MP0>ogJ9MP03
o`000?nhAkSo^4Nh00Oo^4Nh00?o0000onLHiooW6>L02OoW6>L00ol0003on0OhooP7n009ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003om0_doo@;m008oo@;m0;o00001?oZ5NX00ol0003odBkA
om4^d@0;om4^d@03o`000?ngB;Oo]dRg00Go]dRg0ol00003ojMHY`04o`000?mKY5_oFjAKoe^TF`Ko
00003?mZUFX00ol0003oMXUfogJ9MP0=ogJ9MP03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000onLHiooW
6>L02_oW6>L00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo@;m0?o000000?ojQGZo`000?oA;]40
3?oA;]400ol0003o]dRgokM8]`08okM8]`?o000000CoYeRWo`000?l0003o00000_n[E:/00ol0003o
JYEZofZEJP0=ofZEJP03o`000?mfRGKoMXUf00coMXUf00?o0000okQ7^?nhAkP02?nhAkP00ol0003o
iaSWonLHi`0;onLHi`03o`000?oh1oSon0Oh00Kon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo@;mood2oOom0_go000000oo
m0_d00?o0000om4^dOoA;]403?oA;]400ol0003o]dRgokM8]`0;okM8]`03o`000?n[E:_oZeB[00?o
ZeB[00?o0000ofZEJ_mZUFX03?mZUFX00ol0003oNHIio`00000=ogJ9MP03o`000?nhAkSo^4Nh00So
^4Nh00?o0000onLHiooW6>L03?oW6>L3o`0000Gon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@03ood2o@03o`00
0?od2oCom0_d00com0_d00?o0000om4^dOoA;]403?oA;]400ol0003o]dRgokM8]`0:okM8]`03o`00
0?n[E:_oZeB[00GoZeB[00?o0000ofZEJ_mZUFX02_mZUFX01?l0003oNHIiogV6NOmiQWT2o`0000[o
MXUf00?o0000okQ7^?nhAkP02OnhAkP00ol0003oiaSWonLHi`0<onLHi`03o`000?oi1_Won@Ki00?o
000000?on0Oho`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo@;mood2o@04ood2o@03o`000?od2oCom0_d00_om0_d00?o0000om4^dOoA;]40
3?oA;]400ol0003o]dRgokM8]`09okM8]`03o`000?n[E:_oZeB[00KoZeB[00?o0000ofZEJ_mZUFX0
2OmZUFX00ol0003oNHIiogV6N@02ogV6N@03o`000?n/Djco000000;o00001omfRGH00ol0003o^4Nh
okQ7^009okQ7^003o`000?oW6>OoiaSW00_oiaSW00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?om
0_goo@;m00Koo@;m00?o0000oo@;m?od2o@02ood2o@00ol0003odBkAom4^d@0;om4^d@03o`000?ng
B;Oo]dRg00So]dRg00?o0000oj]DZon[E:/01on[E:/00ol0003oJYEZofZEJP08ofZEJP03o`000?mi
QWWoNHIi00?oNHIi00?o0000ojaC[?n/Dj`00_n/Dj`2o`0000CoMXUf00?o0000okQ7^?nhAkP02_nh
AkP00ol0003oiaSWonLHi`0:onLHi`03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo@;mood2o@07
ood2o@03o`000?od2oCom0_d00[om0_d0ol0000;om4^d@Ko00001?ngB;L00ol0003oZeB[oj]DZ`08
oj]DZ`03o`000?mZUF[oJYEZ00OoJYEZ00?o0000ogV6NOmiQWT00omiQWT00ol0003o[5>/ojaC[005
ojaC[0?o000000?oMXUfo`000?nhAkP02onhAkP00ol0003oiaSWonLHi`09onLHi`03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo@;mood2o@08ood2o@03o`000?od2oCom0_d00Wom0_d00?o0000onXE
j_oZ5NX01?l00006om4^d@03o`000?oB;M;odRgB00CodRgB1?l0000<oj]DZ`03o`000?mZUF[oJYEZ
00GoJYEZ00?o0000ogV6NOmiQWT01?miQWT00ol0003o[5>/ojaC[008ojaC[003o`000?nhAkSo^4Nh
00_o^4Nh00?o0000onLHiooW6>L02?oW6>L00ol0003on@KiooT6n@08ooT6n@Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo@;mood2o@0:ood2o@03
o`000?od2oCom0_d00Oom0_d00?o0000onXEj_oZ5NX01OoZ5NX3o`0000;odBkA00?o0000om8]d_oB
;M802?oB;M800ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?mZUF[oJYEZ00CoJYEZ00?o0000ogV6NOmi
QWT01OmiQWT00ol0003o[5>/ojaC[008ojaC[003o`000?nhAkSo^4Nh00Wo^4Nh1?l00008onLHi`03
o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ood2oOom0_d02oom0_d00ol0003om0_d
oo@;m005oo@;m003o`000?oZ5N[ojQGZ00WojQGZ0_l0000<om8]dP03o`000?n[E:_oZeB[00WoZeB[
00?o0000ofZEJ_mZUFX00omZUFX00ol0003oNHIiogV6N@05ogV6N@03o`000?n/Djco[5>/00[o[5>/
00?o0000okQ7^?nhAkP01?nhAkP4o`0000CohAkQ00?o0000onLHiooW6>L01?oW6>L00ol0003on@Ki
ooT6n@0:ooT6n@03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00?om0_d00?o0000onXEj_oZ5NX02ooZ
5NX00ol0003odRgBom8]dP0:om8]dP03o`000?n[E:_oZeB[00WoZeB[00?o0000ofZEJ_mZUFX00_mZ
UFX00ol0003oNHIiogV6N@06ogV6N@03o`000?n/Djco[5>/00[o[5>/00?o0000okQ7^?nhAkP01?l0
0009on4Nh@Ko00003?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?om0_goo@;m00coo@;m00Co0000oo@;m?od2oCom0_d0_l0
000=onXEjP03o`000?oB;M;odRgB00[odRgB00?o0000oj]DZon[E:/02On[E:/01Ol0003oJYEZofZE
J_mZUF[o000000WoNHIi00?o0000ojaC[?n/Dj`02on/Dj`2o`0000gohAkQ00?o0000ooL8moog2?L0
0_og2?L00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_do`00
0002oo/4n`;o00002ooZ5NX00ol0003odRgBom8]dP0;om8]dP03o`000?n[E:_oZeB[00WoZeB[00?o
0000ofZEJ_l000002OmiQWT00ol0003o[5>/ojaC[00<ojaC[003o`000?oQ7^7ohAkQ00cohAkQ00?o
0000ooL8moog2?L00oog2?L00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ood2oOom0_d03Oom0_d0
0ol0003on`Ckoo/4n`03oo/4n`;o00002_oZ5NX00ol0003odRgBom8]dP0:om8]dP03o`000?n[E:_o
ZeB[00SoZeB[1Ol00008ogV6N@03o`000?n/Djco[5>/00co[5>/00?o0000on4NhOoQ7^402ooQ7^40
0ol0003om`SgooL8m`05ooL8m`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo@;mood2o@0<ood2
o@;o00001ook1?/2o`0000SojQGZ00?o0000om8]d_oB;M802_oB;M800ol0003oZeB[oj]DZ`07oj]D
Z`03o`000?n_D:oo[e2_00?o[e2_0ol00005ogV6N@03o`000?n/Djco[5>/00_o[5>/00?o0000on4N
hOoQ7^403?oQ7^400ol0003om`SgooL8m`06ooL8m`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o@;mood2o@0;ood2o@03o`000?on0Oko000000Won`Ck00?o0000onXEj_oZ5NX01OoZ5NX2o`0000co
dRgB00?o0000oj]DZon[E:/01On[E:/00ol0003o[e2_ojm@[`07ojm@[`?o000000?oNHIio`000?n/
Dj`03On/Dj`00ol0003ohAkQon4Nh@0<on4Nh@03o`000?og2?Oom`Sg00Kom`Sg00?o0000ooT6nOoi
1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?om0_goo@;m00Soo@;m0_l00003ooh1oP03o`000?ok1?_on`Ck00Oon`Ck
0_l00004onXEjP03o`000?o`3o3ol0o`00;o00002_oB;M800ol0003oZeB[oj]DZ`03oj]DZ`;o0000
3On_D:l2o`0000go[5>/0ol0000=on4Nh@03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooT6nOoi1_T0
1Ooi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?om0_d00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00Son`Ck0_l0
00000ooZ5N[o0000oo0?l004oo0?l003o`000?oB;M;odRgB00OodRgB00Co0000oj]DZon[E:_oZeB[
0_l00002omHYeP03o`000?n_D:oo[e2_00co[e2_3Ol00003on8MhP03o`000?oQ7^7ohAkQ00[ohAkQ
00?o0000ooL8moog2?L02?og2?L01?l0003on@KiooT6nOoi1_T4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ood2o@;o00002?on0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?o`3o3ol0o`00Gol0o`0_l00008om8]dP03o`000?n[E:_o000000GoeRWF
00?o0000ojm@[on_D:l02on_D:l00ol0003o_D:moke2_@09oke2_@03o`000?oR7N;ohQgR00;ohQgR
0_l00009on4Nh@03o`000?og2?Oom`Sg00[om`Sg0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oom0_go0000ooh1
oP0:ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000oo0?l?o`3o001oo`3o04o`0000?odRgB0ol0
0007omHYeP03o`000?n_D:oo[e2_00[o[e2_00?o0000oke2_Onm@[d02Onm@[d00ol0003ohQgRon8M
hP04on8MhP;o00001ooQ7^400ol0003om`SgooL8m`0:ooL8m`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo0?l?o`3o002?o`3o00
1?l0003oka3_onl@koo_4>l3o`0000;oiQWV00?o0000omHYe_oF:MH01_oF:MH00ol0003o[e2_ojm@
[`08ojm@[`03o`000?nm@[go_D:m00[o_D:m00?o0000on8Mh_oR7N801_oR7N800ol0003ohAkQon4N
h@04on4Nh@03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003ol0o`oo0?l008oo0?l003o`000?o_4>oo
ka3_00Coka3_00Go0000onHIi_oV6NKoiQWVo`000008omHYeP03o`000?n_D:oo[e2_00Oo[e2_00?o
0000oke2_Onm@[d02_nm@[d00ol0003ohQgRon8MhP07on8MhP;o00001?oQ7^400ol0003om`SgooL8
m`08ooL8m`03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003ol0o`oo0?l008oo0?l003o`000?o_4>ooka3_00Coka3_00?o0000onHIi_oV6NH00_oV6NH0
0ol0003oeRWFomHYeP07omHYeP03o`000?n_D:oo[e2_00Ko[e2_00?o0000oke2_Onm@[d02_nm@[d0
0ol0003ohQgRon8MhP09on8MhP05o`000?oQ7^7ohAkQon4NhOl000002Oog2?L00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ol0o`00?o0000onl@koo_4>l01?o_4>l00ol0003oiQWVonHIiP03
onHIiP03o`000?oF:MKoeRWF00OoeRWF00?o0000ojm@[on_D:l01On_D:l00ol0003o_D:moke2_@0:
oke2_@03o`000?oR7N;ohQgR00WohQgR1?l00009ooL8m`03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ok1?_on`Ck
oo/4nol000002_o`3o000ol0003oka3_onl@k`05onl@k`03o`000?oV6NKoiQWV00?oiQWV00?o0000
omHYe_oF:MH02?oF:MH00ol0003o[e2_ojm@[`04ojm@[`03o`000?nm@[go_D:m00Wo_D:m00?o0000
on8Mh_oR7N802?oR7N82o`0000?on0Oh00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003ol0o`oo0?l006oo0?l003o`000?o_4>ooka3_
00Goka3_00?o0000onHIi_oV6NH01?oV6NH00ol0003oeRWFomHYeP09omHYeP03o`000?n_D:oo[e2_
00;o[e2_00?o0000oke2_Onm@[d02_nm@[d00ol0003ohQgRon8MhP06on8MhP;o00001_oh1oP8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?o`3o3ol0o`00Gol0o`00?o0000onl@koo_
4>l01Oo_4>l00ol0003oiQWVonHIiP05onHIiP03o`000?oF:MKoeRWF00WoeRWF00Go0000ojm@[on_
D:oo[e2_o`00000<oke2_@03o`000?oR7N;ohQgR00CohQgR0_l00008ooP7n003o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo0?l?o`
3o000oo`3o000ol0003oka3_onl@k`06onl@k`03o`000?oV6NKoiQWV00GoiQWV00?o0000omHYe_oF
:MH02_oF:MH00ol0003o[e2_o`000004o`0000Wo_D:m00?o0000on8Mh_oR7N800_oR7N82o`0000[o
n0Oh00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`00
0?o`3o3ol0o`00;ol0o`00?o0000onl@koo_4>l01_o_4>l00ol0003oiQWVonHIiP07onHIiP;o0000
2ooF:MH00ol0003ojAKYonTFj@03onTFj@Oo00000_nm@[d00ol0003ohQgRon8MhP02o`0000_on0Oh
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/02Ook
1?/01Ol0003ol0o`oo0?l?o`3o3o000000Soka3_00?o0000onHIi_oV6NH01ooV6NH00ol0003ol`cc
o`000002o`0000SoeRWF00?o0000onTFjOoY5^T02_oY5^T5o`0000gon0Oh00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo/4n`03o`000?o`3o3o000000Woka3_00?o
0000onHIi_oV6NH01_oV6NH00ol0003ol`ccoo<<l`03oo<<l`?o00001?oF:MH00ol0003ojAKYonTF
j@0=onTFj@03o`000?oh1oSon0Oh00gon0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on`Ck00?o0000onl@koo_4>l01oo_4>l00ol0003oiQWVonHIiP07
onHIiP03o`000?oc3??ol`cc00Kol`cc0ol000000ooF:MKo0000onTFj@0>onTFj@03o`000?oh1oSo
n0Oh00con0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009oo/4
n`03o`000?o_4>ooka3_00;oka3_1_l00008onHIiP03o`000?oc3??ol`cc00[ol`cc00?o0000onTF
jOoY5^T03ooY5^T00ol0003on0OhooP7n00:ooP7n0;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007oo/4n`Go00001_og2?L00ol0003oiQWVonHIiP05onHIiP03o`000?oc3??ol`cc00[o
l`cc00?o0000onTFjOoY5^T03ooY5^T00ol0003on0OhooP7n007ooP7n0?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005oo/4n`03o`000?og2?Oom`Sg00Wom`Sg00?o0000onHIi_oV
6NH00ooV6NH00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oY5^WojAKY00oojAKY00?o0000ooP7n?oh
1oP01Ooh1oP2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on`Cko`000?l00000
3Oog2?L00ol0003oiQWVonHIiP02onHIiP03o`000?oc3??ol`cc00_ol`cc5?l00004ooP7n0;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooL8m`04o`000?oV6NKoiQWVo`0000kol`cc
00?o0000ooT6nOoi1_T04?oi1_T00ol0003on0Oho`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_og2?L00ol0003oiQWVo`00000>oo<<l`03o`00
0?oi1_Won@Ki017on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003om`SgooL8m`0=ooL8m`03o`000?oc3??ol`cc00Wol`cc1Ol0
000BooT6n@;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oc3??ol`cc00;ol`cc1ol00004ood2o@03o`000?oi1_Wo
n@Ki00oon@Ki00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?og2?Oom`Sg00com`Sg1?l0000<ood2o@03o`000?oi1_Won@Ki00con@Ki0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0=ood2o@03o`000?oi1_Won@Ki00_o
n@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003om`SgooL8m`0:ooL8m`03o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi
1_T02Ooi1_T2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooL8moog2?L02_og2?L00ol0003oo@;m
ood2o@0?ood2o@03o`000?oi1_Won@Ki00Kon@Ki0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo@;mood2o@0>ood2o@05o`000?on0OkooP7nooh1o_l000000ooi1_T2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@0=ood2o@03o`000?on0Oko
oP7n00?ooP7n00?o0000ooT6nOl000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ood2
oOom0_d02oom0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2
o@07ood2o@;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go
o@;m00Goo@;m00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom0_d01?om0_d00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
o@;mood2o@03ood2o@03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?om0_goo@;mo`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool01ol00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Ko003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Go003o0_ooo`04o`00o`;oool01?l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000co003o0_ooo`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`02o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0005o`00o`coool00_l00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00;o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
1Ol00?l<oooo0003o`00ooooo`3oool000Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o
0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool01Ol00?l00oooo`3o003o
o`00o`04o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`06o`00o`03oooo0?l00?oo003o00?o003o0_ooo`04o`00o`;oool01_l00?l2oooo00;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Oo003o00?oool0o`00ool00?l00_l00?l2oooo00Co003o
0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl0
0?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0007o`00o`;oool00ol0
0?l2oooo00Co003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol0
0?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03
o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool02?l00?l01?ooo`3o003oo`00ool0
0?l2oooo00Co003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol0
0?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`09
o`00o`03oooo0?l00?oo003o00;oool01?l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00[o003o00Coool0o`00ooooo`3oool01?l00?l2oooo00Ko003o00Coool0
o`00ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001X
o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool02_l00?l01?ooo`3o003ooooo0?oo
o`05o`00o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Ooo
ool006So003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<
o`00ool00?l02?l00?l3oooo00Go003o0_ooo`04o`00o`;oool01?l00?l2oooo00Co003o0_ooo`06
o`00o`03oc8bc?ooo`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00ooo
o`3o003oo`00o`0Fo`00o`Goool02Ol00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo
00;o003o0_ooo`05o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Go
ool00ol00?l5oooo02Co003o0_ooo`07o`00o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o
;?l00?l1ooooo`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(410) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.994 .006 .994 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.994 .006 .994 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.977 .023 .977 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.993 .007 .993 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.978 .022 .978 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.97 .03 .97 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.956 .044 .956 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.988 .012 .988 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.951 .049 .951 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.994 .006 .994 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.894 .106 .894 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.91 .09 .91 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.829 .171 .829 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.938 .062 .938 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.987 .013 .987 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.99 .01 .99 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.976 .024 .976 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.686 .314 .686 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.949 .051 .949 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.871 .129 .871 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.865 .135 .865 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.894 .106 .894 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.931 .069 .931 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.958 .042 .958 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.842 .158 .842 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.925 .075 .925 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.76 .24 .76 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.954 .046 .954 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.92 .08 .92 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.868 .132 .868 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.92 .08 .92 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.745 .255 .745 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.944 .056 .944 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.863 .137 .863 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.957 .043 .957 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.786 .214 .786 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.451 .549 .451 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.534 .466 .534 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.982 .018 .982 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.982 .018 .982 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.92 .08 .92 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.994 .006 .994 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.818 .182 .818 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.83 .17 .83 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.507 .493 .507 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.495 .505 .495 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.39 .61 .39 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.797 .203 .797 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.823 .177 .823 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.797 .203 .797 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.714 .286 .714 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.969 .031 .969 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.605 .395 .605 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.942 .058 .942 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.89 .11 .89 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.51 .49 .51 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.421 .579 .421 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.723 .277 .723 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.146 .854 .146 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.159 .841 .159 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.242 .758 .242 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.566 .434 .566 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.552 .448 .552 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.938 .062 .938 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.195 .805 .195 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.205 .795 .205 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.828 .172 .828 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.97 .03 .97 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.993 .007 .993 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.332 .668 .332 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.402 .598 .402 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.73 .27 .73 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.993 .007 .993 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.766 .234 .766 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.386 .614 .386 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.668 .332 .668 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.125 .875 .125 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.559 .441 .559 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.373 .627 .373 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.974 .026 .974 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.06 .94 .06 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.096 .904 .096 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.905 .095 .905 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.038 .962 .038 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.021 .979 .021 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.677 .323 .677 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.933 .067 .933 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.234 .766 .234 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.054 .946 .054 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.529 .471 .529 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.113 .887 .113 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.231 .769 .231 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.953 .047 .953 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.008 .992 .008 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.134 .866 .134 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.181 .819 .181 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.843 .157 .843 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.266 .734 .266 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.336 .664 .336 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.008 .992 .008 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.018 .982 .018 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.069 .931 .069 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.01 .99 .01 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.431 .569 .431 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.697 .303 .697 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.993 .007 .993 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.832 .168 .832 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.184 .816 .184 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.164 .836 .164 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.492 .508 .492 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.976 .024 .976 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.123 .877 .123 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.156 .844 .156 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.676 .324 .676 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.09 .91 .09 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.026 .974 .026 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.916 .084 .916 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.975 .025 .975 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.685 .315 .685 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.749 .251 .749 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.084 .916 .084 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.921 .079 .921 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.346 .654 .346 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.475 .525 .475 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.074 .926 .074 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.27 .73 .27 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.473 .527 .473 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.993 .007 .993 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.993 .007 .993 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.952 .048 .952 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.114 .886 .114 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.124 .876 .124 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.028 .972 .028 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.892 .108 .892 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.237 .763 .237 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.971 .029 .971 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.186 .814 .186 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.179 .821 .179 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.191 .809 .191 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.73 .27 .73 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.785 .215 .785 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.673 .327 .673 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.017 .983 .017 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.24 .76 .24 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.386 .614 .386 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.653 .347 .653 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.886 .114 .886 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.994 .006 .994 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.964 .036 .964 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.234 .766 .234 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.469 .531 .469 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.184 .816 .184 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.872 .128 .872 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.807 .193 .807 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.993 .007 .993 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.667 .333 .667 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.908 .092 .908 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.969 .031 .969 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.185 .815 .185 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.313 .687 .313 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.956 .044 .956 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.184 .816 .184 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.741 .259 .741 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.554 .446 .554 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.579 .421 .579 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.396 .604 .396 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.927 .073 .927 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.902 .098 .902 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.91 .09 .91 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.932 .068 .932 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.481 .519 .481 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.975 .025 .975 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.855 .145 .855 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.415 .585 .415 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.473 .527 .473 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.994 .006 .994 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.72 .28 .72 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.624 .376 .624 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.993 .007 .993 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.972 .028 .972 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.882 .118 .882 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.968 .032 .968 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.497 .503 .497 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.948 .052 .948 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.838 .162 .838 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.778 .222 .778 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.994 .006 .994 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.75 .25 .75 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.643 .357 .643 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.778 .222 .778 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.989 .011 .989 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.633 .367 .633 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.991 .009 .991 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.723 .277 .723 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.992 .008 .992 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.844 .156 .844 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.916 .084 .916 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.864 .136 .864 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.926 .074 .926 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.946 .054 .946 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.861 .139 .861 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.724 .276 .724 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.847 .153 .847 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.912 .088 .912 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.947 .053 .947 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.932 .068 .932 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.942 .058 .942 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.989 .011 .989 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.878 .122 .878 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.971 .029 .971 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.992 .008 .992 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.977 .023 .977 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.959 .041 .959 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.888 .112 .888 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.971 .029 .971 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.946 .054 .946 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.943 .057 .943 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.961 .039 .961 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.993 .007 .993 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.992 .008 .992 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.993 .007 .993 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.992 .008 .992 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.993 .007 .993 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003omPWfooH9m_l0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooH9m_of2OH00_of2OH00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00?omPWf00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooH9m_of2OH01Oof2OH00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003omPWfooH9mP06ooH9mP03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooH9m_of2OH02?of2OH00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oi1_Wo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000comPWf00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooT6n@03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ol`ccoo<<l`05oo<<l`03o`000?of
2OKomPWf00_omPWf0ol00003oo@;m003o`000?on0OkooP7n00cooP7n0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003ol`ccoo<<l`06
oo<<l`03o`000?of2OKomPWf00[omPWf00?o0000oo@;m?od2o@01?od2o@00ol0003ooP7nooh1oP0:
ooh1oP04o`000?ob3O;olPgboo8=lP;o00002_om0_d2o`000003oo8=l_l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?om0_go
o@;m00Woo@;m00?o0000ooT6nOl000002oon0Oh00ol0003ol`ccoo<<l`06oo<<l`03o`000?of2OKo
mPWf00WomPWf00?o0000oo@;m?od2o@01_od2o@00ol0003ooP7nooh1oP08ooh1oP03o`000?ob3O;o
lPgb00ColPgb0_l00005ood2o@?o00001?ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooT6n@03o`000?om0_goo@;m00Ooo@;m0_l00003ooT6
n@03o`000?on0OkooP7n00OooP7n00?o0000oo<<looc3?<01ooc3?<00ol0003omPWfooH9mP09ooH9
mP03o`000?od2oCom0_d00Oom0_d00?o0000ooh1o_on0Oh01Oon0Oh2o`0000WolPgb0_l000000oom
0_go0000o`000007oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooT6nOoi
1_T02?oi1_T00ol0003oo@;mood2o@06ood2o@03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on
0Oh01oon0Oh00ol0003ol`ccoo<<l`08oo<<l`03o`000?of2OKomPWf00OomPWf00?o0000oo@;m?od
2o@02Ood2o@00ol0003ooP7nooh1oP03ooh1oP03o`000?ob3O;olPgb00_olPgb00?o0000oo8=l_ob
3O801oob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0Oho`000005ooh1oP;o00002ooi1_T2o`0000Koo@;m
00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ooP7nooh1oP06ooh1oP03o`000?oc3??ol`cc00Sol`cc
00?o0000ooH9m_of2OH01_of2OH00ol0003om0_doo@;m00;oo@;m005o`000?on0OkooP7nooh1o_l0
00003_ob3O800ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oh1oSon0OhooP7n?l0
00000oon0Oh00ol0003on@KiooT6n@0:ooT6n@04o`000?o^4NkokQ7^o`0000?oo@;m0_l00008ooT6
n@03o`000?on0OkooP7n00KooP7n00?o0000oo<<looc3?<02Ooc3?<00ol0003omPWfooH9mP05ooH9
mP03o`000?od2oCom0_d00com0_d00?o0000ooh1o_l000003oob3O800ol0003olPgboo8=lP08oo8=
lP03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7n003ooP7n003o`000?on0Oko000000_o
n@Ki0_l00004onhAkP03o`000?om0_go000000_on@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
l`ccoo<<l`09oo<<l`03o`000?of2OKomPWf00ComPWf00?o0000oo@;m?od2o@03_od2o@00ol0003o
lPgboo8=lP0>oo8=lP03o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooP7n?oh1oP0
1?oh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?o^4NkokQ7^00GokQ7^00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP05ooh1oP03o`000?oc3??ol`cc00[ol`cc00?o0000ooH9m_of2OH0
0oof2OH00ol0003om0_doo@;m00>oo@;m003o`000?ob3O;olPgb00golPgb00?o0000oo8=l_ob3O80
2_ob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7
n005ooP7n003o`000?oi1_Won@Ki00Oon@Ki0_l00008onhAkP03o`000?oi1_Won@Ki00_on@Ki00?o
0000ooh1o_on0Oh01?on0Oh00ol0003ol`ccoo<<l`0:oo<<l`04o`000?of2OKomPWfooH9mP?o0000
3ood2o@00ol0003olPgboo8=lP0>oo8=lP03o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T01?oi1_T2o`0000_okQ7^1?l0
0009ooT6n@03o`000?on0OkooP7n00?ooP7n00?o0000oo<<looc3?<02ooc3?<01?l0003omPWfo`00
0?l00003omlPg`;o00003?od2o@2o`00013olPgb00?o0000oo8=l_ob3O802oob3O800ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003on0Oh
ooP7n007ooP7n003o`000?oi1_Won@Ki00?on@Ki00?o0000onhAk_o^4Nh02oo^4Nh01?l0003oe2_D
om@[e?oD:m@5o`0000Gon@Ki00?o0000ooh1o_on0Oh00_on0Oh00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oO8=oogb3O00Gogb3O0_l00008oo@;m0;o00000_oJ9MX00ol0003olPgboo8=lP0=oo8=lP03
o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n009ooP7n003o`000?oi1_Won@Ki00;o0000
3Oo^4Nh00ol0003oe2_Dom@[e007om@[e0Ko00000_on0Oh4o`0000gol`cc00?o0000omlPgooO8=l0
1ooO8=l2o`0000Gom0_d00?o0000omXUf_oJ9MX00ooJ9MX00ol0003olPgboo8=lP0<oo8=lP03o`00
0?ob3O;olPgb00colPgb00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o
0000ooT6nOl000003oo^4Nh00ol0003oe2_Dom@[e00<om@[e0?o00001?o[5>/3o`0000Wol`cc00?o
0000omlPgooO8=l02_oO8=l2o`000003oo@;m?l0003o000000OofRGJ00?o0000oo8=l_ob3O802oob
3O800ol0003olPgboo8=lP0<oo8=lP03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oh1oSon0Oh00_on0Oh00?o0000
onhAk_o^4Nh03_o^4Nh00ol0003oe2_Dom@[e00=om@[e003o`000?o[5>_ojaC[00KojaC[0ol00005
oo<<l`03o`000?oO8=oogb3O00gogb3O00?o0000omXUf_oJ9MX02?oJ9MX00ol0003olPgboo8=lP09
oo8=lP03o`000?ob3O;olPgb00golPgb00Co0000ood2oOom0_goo@;m1Ol00003ooD:m@03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooP7n?oh1oP02ooh1oP2o`0000ookQ7^00?o0000om@[e?oD:m@03OoD:m@00ol0003ojaC[on/Dj`0:
on/Dj`?o000000?ol`cco`000?oO8=l03ooO8=l00ol0003ofRGJomXUfP09omXUfP03o`000?ob3O;o
lPgb00SolPgb00?o0000oo8=l_ob3O803_ob3O83o`0000Som@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oh1oSon0Oh00Son0Oh0ol000000ooS
7>?o0000onhAkP0>onhAkP03o`000?oD:mCoe2_D00goe2_D00?o0000on/Djoo[5>/03Oo[5>/00ol0
003ogb3OomlPg`0?omlPg`03o`000?oJ9M[ofRGJ00[ofRGJ2ol0000;oo8=lPGo00003?oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003om0_do`000?on0Oko0000
00Son0Oh0ol00005on<Lh`03o`000?o^4NkokQ7^00cokQ7^00?o0000om@[e?oD:m@03OoD:m@00ol0
003ojaC[on/Dj`0=on/Dj`;o00004?oO8=l00ol0003ofRGJomXUfP0:omXUfP03o`000?oF:MKoeRWF
00OoeRWF00?o0000oo8=l_ob3O800_ob3O87o`0000Cog2?L00?o0000ooD:mOoe2_D02_oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003om0_doo@;m?od2o@2o`00
00Gon0Oh0ol00009on<Lh`;o00002oo^4Nh00ol0003oe2_Dom@[e00=om@[e003o`000?o[5>_ojaC[
00gojaC[00Co0000olPgb?o8=lSo00003ooO8=l00ol0003ofRGJomXUfP09omXUfP03o`000?oF:MKo
eRWF00WoeRWF1?l0000;om`Sg003o`000?oe2_Gom@[e00[om@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000oo@;m?od2o@01?od2o@00ol0003on0Oho`000002o`00
00cohacS00Co0000ol@ka?l0003o00002Oo^4Nh00ol0003oe2_Dom@[e00=om@[e003o`000?o[5>_o
jaC[00gojaC[00Go0000olPgb?o8=lSob3O8o`00000=omlPg`03o`000?oJ9M[ofRGJ00[ofRGJ00?o
0000omHYe_oF:MH02OoF:MH00ol0003og2?Lom`Sg00<om`Sg003o`000?oe2_Gom@[e00[om@[e00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?od2o@01_od2o@0
0ol0003ohacSon<Lh`0<on<Lh`03o`000?o4>lCoa3_400;oa3_40_l00007onhAkP03o`000?oD:mCo
e2_D00coe2_D00?o0000on/Djoo[5>/03Oo[5>/00ol0003ob3O8olPgb003olPgb003o`000?oO8=oo
gb3O00[ogb3O00?o0000omXUf_oJ9MX02_oJ9MX00ol0003oeRWFomHYeP09omHYeP03o`000?oL8mco
g2?L00cog2?L00?o0000ooD:mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003om0_doo@;m006oo@;m003o`000?oS7>?ohacS00_ohacS00?o0000ol@k
a?o4>l@01Oo4>l@00ol0003okQ7^onhAkP03onhAkP03o`000?oD:mCoe2_D00goe2_D00?o0000on/D
joo[5>/03Oo[5>/00ol0003ob3O8olPgb004olPgb003o`000?oO8=oogb3O00Wogb3O00?o0000omXU
f_oJ9MX02OoJ9MX00ol0003oeRWFomHYeP0:omHYeP03o`000?oL8mcog2?L00cog2?L00?o0000ooD:
mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m0_doo@;m007oo@;m003o`000?oS7>?ohacS00_ohacS00?o0000ol@ka?o4>l@01_o4>l@2o`0000?o
kQ7^00?o0000om@[e?oD:m@03OoD:m@00ol0003ojaC[on/Dj`0<on/Dj`03o`000?o8=lSob3O800Ko
b3O800?o0000omlPgooO8=l02?oO8=l00ol0003ofRGJomXUfP09omXUfP03o`000?oF:MKoeRWF00[o
eRWF00?o0000om`Sg?oL8m`03?oL8m`00ol0003om@[eooD:m@0;ooD:m@03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000oo@;m?od2o@02?od2o@00ol0003ohacSon<Lh`0:on<Lh`03o`00
0?o4>lCoa3_400Woa3_40_l000000oo^4Nko0000om@[e00<om@[e0?o00003_o[5>/00ol0003ob3O8
olPgb007olPgb003o`000?oO8=oogb3O00Oogb3O00?o0000omXUf_oJ9MX02OoJ9MX00ol0003oeRWF
omHYeP0;omHYeP03o`000?oL8mcog2?L00cog2?L00?o0000ooD:mOoe2_D02_oe2_D00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo@;m?od2o@02_od2o@00ol0003ohacSon<L
h`09on<Lh`03o`000?o4>lCoa3_400_oa3_400?o0000om@[e?oD:m@02_oD:m@2o`0000?o[E:]00?o
0000on/Djoo[5>/02_o[5>/00ol0003ob3O8olPgb009olPgb003o`000?oO8=oogb3O00Kogb3O00?o
0000omXUf_oJ9MX02?oJ9MX00ol0003oeRWFomHYeP0<omHYeP03o`000?oL8mcog2?L00cog2?L00?o
0000ooD:mOoe2_D02_oe2_D00ol0003ooP7nooh1oP04ooh1oPCo00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on<LhooS7><02?oS7><0
0ol0003oa3_4ol@ka00<ol@ka003o`000?oD:mCoe2_D00Soe2_D0_l00006ojeB[@;o00002_o[5>/0
0ol0003ob3O8olPgb00:olPgb003o`000?oO8=oogb3O00Gogb3O00?o0000omXUf_oJ9MX02?oJ9MX0
0ol0003oeRWFomHYeP0<omHYeP03o`000?oL8mcog2?L00cog2?L00?o0000ooD:mOoe2_D02ooe2_D0
0ol0003ooP7no`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
oo@;m003o`000?oS7>?ohacS00OohacS00?o0000ol@ka?o4>l@03_o4>l@00ol0003oe2_Dom@[e004
om@[e0?o00002_n]DZd00ol0003ojaC[on/Dj`07on/Dj`03o`000?o8=lSob3O800_ob3O800?o0000
omlPgooO8=l00ooO8=l00ol0003ofRGJomXUfP09omXUfP03o`000?oF:MKoeRWF00coeRWF00?o0000
om`Sg?oL8m`03?oL8m`00ol0003om@[eooD:m@0;ooD:m@;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003om0_doo@;m00<oo@;m003o`000?oS7>?ohacS00OohacS00?o0000ol@ka?o4>l@03oo4>l@01?l0
003oe2_Dom@[e?oD:m@2o`0000ko[E:]0_l00006on/Dj`03o`000?o8=lSob3O800gob3O800?o0000
omlPgooO8=l00_oO8=l00ol0003ofRGJomXUfP08omXUfP03o`000?oF:MKoeRWF00coeRWF0ol0000=
om`Sg003o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oom0_d00?o0000on<LhooS7><01_oS7><00ol0003oa3_4ol@ka00@ol@ka0Co00004_n]DZd00ol0
003ojaC[on/Dj`03on/Dj`03o`000?o8=lSob3O800kob3O800Go0000omlPgooO8=oogb3Oo`000005
omXUfPOo00003?oF:MH01Ol0003o^DJiokU6^OniA[Wo000000cog2?L00?o0000ooD:mOoe2_D02?oe
2_D3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oom0_d00?o0000on<LhooS7><01_oS7><00ol0003oa3_4ol@ka00=
ol@ka0?o000000CoSg2?o`000?l0003o00004on]DZd2o`0000;ojaC[00?o0000olPgb?o8=lP04?o8
=lP00ol0003ogb3Oo`000006o`0000Oo^4Nh00?o0000omHYe_oF:MH02?oF:MH00ol0003o^DJiokU6
^@03okU6^@;o00002?oL8m`3o`0000Kom@[e1?l00002oo8=lP03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003on@Kio`000?oN8Mh3o`0000gom0_d00?o0000on<LhooS7><01?oS7><00ol0003oa3_4ol@k
a00;ol@ka0?o00000on?L8l01Ol0003oQgR7o`000?mFZEKo000001Co[E:]00?o0000on/Djol00000
4oo8=lP00ol0003o^4NhokQ7^00=okQ7^003o`000?oF:MKoeRWF00GoeRWF0_l00008okU6^@03o`00
0?oL8mcog2?L00Go00000ooH9mP00ol0003om@[eooD:m@03o`0000OolPgb00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oi1_Won@Kio`0000CogR7N0ol0000:oo@;m003o`000?oS7>?ohacS00?ohacS
00?o0000ol@ka?o4>l@02Oo4>l@3o`0000GoSg2?00Co0000ohMhQon7N8Oo00000_mFZEH00ol0003o
[E:]ojeB[@0BojeB[@03o`000?o8=lSob3O801;ob3O800?o0000okQ7^?nhAkP03_nhAkP00ol0003o
eRWFomHYeP03omHYeP03o`000?niA[Wo^DJi00Wo^DJi0_l00009omPWf0;o00002_ob3O800ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooT6nOoi1_Won@Kio`000007omhQgP;o00001ood2o@5o`0000;o
hacS00?o0000ol@ka?o4>l@01_o4>l@3o`0000SoSg2?00Co0000ohMhQon7N8Oo00000omFZEH00ol0
003o[E:]ojeB[@0AojeB[@03o`000?o8=lSob3O8017ob3O800?o0000okQ7^?nhAkP04?nhAkP01Ol0
003oeRWFomHYe_oF:MKo000000co^DJi00?o0000omPWf?oH9mP02?oH9mP00ol0003olPgboo8=lP0:
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000Con@Ki00?o0000omhQg_oN8Mh01ooN8Mh3o`00
0004oo@;m?l0003o0000o`0000Goc3?<0_l00006ol@ka0?o00002_n?L8l01Ol0003oQgR7ohMhQon7
N8Oo000000CoEZUF00?o0000ojeB[On]DZd04?n]DZd00ol0003ob3O8olPgb00AolPgb003o`000?nh
AkSo^4Nh017o^4Nh00?o0000omHYe_l000003OniA[T00ol0003of2OHomPWf008omPWf003o`000?ob
3O;olPgb00[olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00Con@Ki00?o0000
omhQg_oN8Mh02_oN8Mh00ol0003oc3?<ol`cc008ol`cc003o`000?o4>lCoa3_400?o00003On?L8l0
1Ol0003oQgR7ohMhQon7N8Oo000000GoEZUF00?o0000ojeB[On]DZd03on]DZd00ol0003ob3O8olPg
b00AolPgb003o`000?nhAkSo^4Nh01;o^4Nh00?o0000okU6^OniA[T03?niA[T00ol0003of2OHomPW
f008omPWf003o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooT6nOoi1_T01Ooi1_T0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o<<lcoc3?<00Woc3?<0_l0000?ohm`S`03o`000?n7N8Oo
QgR700;oQgR700?o0000oeJYE_mFZEH01?mFZEH00ol0003o[E:]ojeB[@0=ojeB[@?o00004Oo8=lP0
0ol0003o^4NhokQ7^00CokQ7^003o`000?niA[Wo^DJi00_o^DJi00?o0000omPWf?oH9mP02OoH9mP0
0ol0003olPgboo8=lP0;oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ooh1oP;o00002?oi1_T0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o<<lcoc3?<00Woc3?<00?o0000ohm`Son?L8l03On?L8l0
0ol0003oQgR7ohMhQ`03ohMhQ`03o`000?mFZEKoEZUF00GoEZUF00?o0000ojeB[On]DZd02_n]DZd2
o`0000?oNHIi00?o0000olPgb?o8=lP03_o8=lP00ol0003o^4NhokQ7^00CokQ7^003o`000?niA[Wo
^DJi00_o^DJi00?o0000omPWf?oH9mP02OoH9mP00ol0003olPgboo8=lP0;oo8=lP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000GooP7n00?o0000ooT6nOoi1_T01ooi1_T2o`0000_ogR7N00?o0000ol`c
c?o<<l`02oo<<l`00ol0003oSg2?ohm`S`0<ohm`S`03o`000?n7N8OoQgR700?oQgR700?o0000oeJY
E_mFZEH01_mFZEH00ol0003o[E:]ojeB[@07ojeB[@;o00001_miQWT2o`0000kob3O800?o0000okQ7
^?nhAkP04onhAkP00ol0003o^DJiokU6^@0;okU6^@03o`000?oH9mSof2OH00Wof2OH00?o0000oo8=
l_ob3O803?ob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ooh1o_on0OkooP7no`000009ooT6
n@03o`000?ob3O;o000000_ogR7N00?o0000ol`cc?o<<l`02oo<<l`00ol0003oSg2?ohm`S`0;ohm`
S`03o`000?n7N8OoQgR700CoQgR700?o0000oeJYE_mFZEH01omFZEH00ol0003o[E:]ojeB[@05ojeB
[@03o`000?miQWWoNHIi00SoNHIi00?o0000olPgb?o8=lP02_o8=lP00ol0003o^4NhokQ7^00DokQ7
^003o`000?niA[Wo^DJi00_o^DJi00?o0000omPWf?oH9mP02OoH9mP00ol0003olPgboo8=lP0<oo8=
lP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7no`000009ooT6n@04o`000?ob3O;olPgbo`00
00_ogR7N00?o0000ol`cc?o<<l`02oo<<l`00ol0003oSg2?ohm`S`0;ohm`S`03o`000?n7N8OoQgR7
00CoQgR700?o0000oeJYE_mFZEH02?mFZEH00ol0003o[E:]ojeB[@02ojeB[@;o00003?miQWT2o`00
00[ob3O800?o0000okQ7^?nhAkP05?nhAkP00ol0003o^DJiokU6^@0;okU6^@03o`000?oH9mSof2OH
00Wof2OH00?o0000oo8=l_ob3O803Oob3O800ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@07ooT6n@03
o`000?ob3O;olPgb00;olPgb00?o0000omhQg_oN8Mh02?oN8Mh00ol0003oc3?<ol`cc00<ol`cc003
o`000?n?L8ooSg2?00WoSg2?00?o0000ohMhQon7N8L01On7N8L00ol0003oEZUFoeJYEP09oeJYEP04
o`000?n]DZgo0000o`00013oNHIi0_l00008olPgb003o`000?nhAkSo^4Nh01Co^4Nh0ol0000;okU6
^@03o`000?oH9mSof2OH00Wof2OH00?o0000oo8=l_ob3O803Oob3O801?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on@KiooT6n@06ooT6n@03o`000?ob3O;olPgb00?olPgb00?o0000omhQ
g_oN8Mh02?oN8Mh00ol0003oc3?<ol`cc00;ol`cc0;o00002_n?L8l00ol0003oQgR7ohMhQ`06ohMh
Q`03o`000?mFZEKoEZUF00[oEZUF00?o0000ogV6NOmiQWT04_miQWT00ol0003ob3O8olPgb004olPg
b003o`000?nhAkSo^4Nh01Go^4Nh00?o0000oj9MX_nRGJ801Ol00005okU6^@03o`000?oH9mSof2OH
00[of2OH00?o0000oo8=l_ob3O803_ob3O83o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@04ooT6n@03
o`000?ob3O;olPgb00ColPgb00?o0000omhQg_oN8Mh01ooN8Mh00ol0003oc3?<ol`cc00;ol`cc004
o`000?n2OH;oPWf2o`0000WoSg2?00?o0000ohMhQon7N8L01_n7N8L00ol0003oEZUFoeJYEP0:oeJY
EP03o`000?miQWWoNHIi01?oNHIi0_l00003olPgb0Co00005?nhAkP00ol0003oXUfRoj9MXP06oj9M
XPCo000000?o^DJio`000?oH9mP02ooH9mP00ol0003olPgboo8=lP0>oo8=lP03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003on@KiooT6n@03ooT6n@03o`000?ob3O;olPgb00GolPgb00?o0000omhQg_oN
8Mh01ooN8Mh00ol0003oc3?<ol`cc009ol`cc0;o00001?n2OH800ol0003oSg2?ohm`S`05ohm`S`03
o`000?n7N8OoQgR700OoQgR700?o0000oeJYE_mFZEH02_mFZEH00ol0003oNHIiogV6N@0EogV6N@03
o`000?o8=lSo000000CoSG:=0ol0000@okQ7^003o`000?nRGJ;oXUfR00_oXUfR0_l0000<omPWf003
o`000?ob3O;olPgb00colPgb0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T00_oi1_T00ol0003olPgb
oo8=lP06oo8=lP03o`000?oN8MkogR7N00OogR7N00?o0000ol`cc?o<<l`02?o<<l`00ol0003oPWf2
oh9mPP05oh9mPP03o`000?n?L8ooSg2?00CoSg2?00?o0000ohMhQon7N8L01on7N8L00ol0003oEZUF
oeJYEP0:oeJYEP03o`000?miQWWoNHIi01KoNHIi00?o0000ohebSOn=LXd01_n=LXd3o`0000co^4Nh
00?o0000oj9MX_nRGJ803OnRGJ800ol0003of2OHomPWf009omPWf0Go00002Oob3O82o`000003ooH9
m_l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ooT6nOl0003olPgb00WolPgb00?o0000omhQg_oN8Mh01_oN
8Mh00ol0003oc3?<ol`cc007ol`cc003o`000?n2OH;oPWf200OoPWf200?o0000ohm`Son?L8l00_n?
L8l00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?mFZEKoEZUF00WoEZUF00?o0000ogV6NOmiQWT05omi
QWT00ol0003oSG:=ohebS@09ohebS@?o00002OnhAkP00ol0003oXUfRoj9MXP0>oj9MXPKo00001?oH
9mP00ol0003ohacSon<Lh`03on<Lh`Go00000_ob3O82o`0000ComPWf00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oc3??ol`ccoo<<lol000002oob3O800ol0003ogR7NomhQgP06omhQgP03o`000?o<
<lcoc3?<00Goc3?<0_l0000;oh9mPP04o`000?n?L8ooSg2?o`0000_oQgR700?o0000oeJYE_mFZEH0
2OmFZEH00ol0003oNHIiogV6N@0FogV6N@03o`000?n=LXgoSG:=00goSG:=0ol00005okQ7^003o`00
0?nRGJ;oXUfR00ooXUfR00?o0000okU6^OniA[T00oniA[T4o`0000_ohacS0_l00006ooH9mP03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003ol`ccoo<<l`02oo<<l`ko00001_oN8Mh00ol0003oc3?<ol`c
c005ol`cc003o`000?n2OH;oPWf200coPWf200?o0000ohm`Sol000002on7N8L00ol0003oEZUFoeJY
EP07oeJYEP?o00006?miQWT00ol0003oSG:=ohebS@0@ohebS@?o000000?o^4Nho`000?nRGJ804?nR
GJ800ol0003o^DJiokU6^@07okU6^@03o`000?oS7>?ohacS00[ohacS00?o0000ooH9m_of2OH01Oof
2OH00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005oo<<l`03o`000?oN8MkogR7N00_ogR7N0_l00004
omhQgP03o`000?o<<lcoc3?<00?oc3?<0_l0000@oh9mPP03o`000?n7N8OoQgR700[oQgR700?o0000
oeJYE_mFZEH00omFZEH4o`0000;o;m0_00?o0000ogV6NOmiQWT05OmiQWT00ol0003oSG:=ohebS@0D
ohebS@03o`000?nRGJ;oXUfR013oXUfR00?o0000okU6^OniA[T01oniA[T00ol0003ohacSon<Lh`0:
on<Lh`03o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oc3??ol`cc
00Gol`cc00?o0000omhQg_oN8Mh03OoN8Mh6o`0000?oc3?<00?o0000oh9mP_n2OH804?n2OH800ol0
003oQgR7ohMhQ`0:ohMhQ`03o`000?mFZEKo000000?o00001ol_d2l00ol0003oNHIiogV6N@0DogV6
N@03o`000?n=LXgoSG:=01CoSG:=00?o0000oj9MX_nRGJ803onRGJ800ol0003o^DJiokU6^@08okU6
^@03o`000?oS7>?ohacS00[ohacS00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo<<looc3?<01_oc3?<00ol0003ogR7NomhQgP0=omhQgP03o`000?nn@Kko_T6n00?o
_T6n00?o0000ol`cc?l000004on2OH84o`0000WoQgR70_l0000<obo@;`03o`000?miQWWoNHIi01?o
NHIi00?o0000ohebSOn=LXd05On=LXd00ol0003oXUfRoj9MXP0>oj9MXP03o`000?niA[Wo^DJi00So
^DJi00?o0000on<LhooS7><02OoS7><00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oc3??ol`cc00Sol`cc00?o0000omhQg_oN8Mh02ooN8Mh00ol0003o_T6noki1_P05oki1_P03o`00
0?n2OH;oPWf201;oPWf200Co0000oc_4>olka3_o>l@k1Ol00003ohMhQ`03o`000?l_d2oo;m0_00go
;m0_0ol0000@ogV6N@;o00006?n=LXd00ol0003oXUfRoj9MXP0=oj9MXP03o`000?niA[Wo^DJi00Wo
^DJi00?o0000on<LhooS7><02OoS7><00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ol`cc00?o0000omhQg_oN8Mh02_oN8Mh00ol0003o_T6noki1_P06oki1_P03o`00
0?n2OH;oPWf2017oPWf200?o0000oc_4>olka3/01olka3/3o`00013o;m0_00?o0000oaGZ5OlEjQD0
1Ol00009ogV6N@;o000000?o;m0_o`000?n=LXd05on=LXd00ol0003oXUfRoj9MXP0=oj9MXP03o`00
0?niA[Wo^DJi00Wo^DJi00?o0000on<LhooS7><02?oS7><2o`0000[omPWf00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo<<looc3?<02Ooc3?<00ol0003ogR7NomhQ
gP0:omhQgP03o`000?nn@Kko_T6n00Oo_T6n00?o0000oh9mP_n2OH803on2OH800ol0003o>l@koc_4
>`0:oc_4>`03o`000?l_d2oo;m0_00go;m0_00?o0000oaGZ5OlEjQD01_lEjQD4o`0000CoNHIi00?o
0000obo@;ol_d2l00_l_d2l00ol0003oSG:=ohebS@0FohebS@03o`000?nRGJ;oXUfR00_oXUfR00?o
0000okU6^OniA[T02oniA[T00ol0003ohacSon<Lh`06on<Lh`03o`000?oa3_7o000000[omPWf00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000oo<<looc3?<02?oc3?<=
o`0000[o_T6n00?o0000oh9mP_n2OH803on2OH800ol0003o>l@koc_4>`0;oc_4>`03o`000?l_d2oo
;m0_00co;m0_00?o0000oaGZ5OlEjQD02_lEjQD4o`0000Go;m0_00?o0000ohebSOn=LXd05_n=LXd0
0ol0003oXUfRoj9MXP0:oj9MXP03o`000?niA[Wo^DJi00co^DJi00?o0000on<LhooS7><01?oS7><2
o`0000?ol@ka00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ol`ccoo<<l`07oo<<l`03o`000?oM8]gogB;M00WogB;M00?o0000oki1
__nn@Kh02Onn@Kh00ol0003oPWf2oh9mPP0=oh9mPP03o`000?lka3_o>l@k00co>l@k00?o0000obo@
;ol_d2l03?l_d2l00ol0003o5NXEoaGZ5@0;oaGZ5@03o`000?l7n0Oo000000Ko;m0_00?o0000oheb
SOn=LXd05_n=LXd00ol0003oXUfRoj9MXP09oj9MXP03o`000?niA[Wo^DJi00co^DJi00?o0000on<L
hooS7><00ooS7><00ol0003ol@kaoo4>l@03oo4>l@03o`000?of2OKomPWf00SomPWf00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000oo<<looc3?<01_oc3?<00ol0003o
gB;MomdRg@08omdRg@03o`000?nn@Kko_T6n00_o_T6n00?o0000oh9mP_n2OH802?n2OH84o`0000oo
>l@k00?o0000obo@;ol_d2l02ol_d2l00ol0003o5NXEoaGZ5@0;oaGZ5@04o`000?l7n0Oo1oP7o`00
00Oo;m0_00?o0000ohebSOn=LXd05On=LXd00ol0003oXUfRoj9MXP08oj9MXP03o`000?niA[Wo^DJi
00go^DJi00?o0000on<LhooS7><00_oS7><00ol0003ol@kaoo4>l@05oo4>l@03o`000?of2OKomPWf
00OomPWf00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo<<looc
3?<01Ooc3?<00ol0003ogB;MomdRg@08omdRg@03o`000?nn@Kko_T6n00_o_T6n00?o0000oh9mP_n2
OH800on2OH85o`0000?o?L8m00?o0000oc_4>olka3/03_lka3/00ol0003o;m0_obo@;`0:obo@;`03
o`000?lEjQGo5NXE00[o5NXE00Go0000o`Oh1ol7n0Oo1oP7o`000007obo@;`03o`000?n=LXgoSG:=
01GoSG:=00?o0000oj9MX_nRGJ802?nRGJ800ol0003o^DJiokU6^@0=okU6^@03o`000?oS7>?ohacS
00;o00002?oa3_400ol0003omPWfooH9mP08ooH9mPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?oc3??ol`cc00Go
l`cc00?o0000omdRgOoM8]d02?oM8]d00ol0003o_T6noki1_P0<oki1_PGo00002Olm`Sd00ol0003o
>l@koc_4>`0<oc_4>`;o00003?l_d2l00ol0003o5NXEoaGZ5@0:oaGZ5@05o`000?l7n0Oo1oP7o`Oh
1ol000002?l_d2l00ol0003oSG:=ohebS@0DohebS@?o00001onRGJ800ol0003o^DJiokU6^@0>okU6
^@03o`000?oS7>?o000000_ol@ka00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ol`ccoo<<l`04oo<<l`03o`000?oM8]gogB;M00Oo
gB;M00?o0000oki1__nn@Kh03?nn@Kh01?l0003oPGj1oh5nPOl0000;ocg2?@03o`000?lka3_o>l@k
00_o>l@k00Co0000o`;m0_l2o@;o00002_l_d2l00ol0003o5NXEoaGZ5@0:oaGZ5@03o`000?l7n0Oo
1oP700;o1oP700?o0000obo@;ol_d2l01_l_d2l00ol0003oSG:=ohebS@0AohebS@?o00000omZUFX0
0ol0003oXUfRoj9MXP04oj9MXP03o`000?niA[Wo^DJi00go^DJi1?l0000;oo4>l@03o`000?of2OKo
mPWf00GomPWf00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00KonPGj00Co0000oo<<
looc3??ol`cc1?l00008omdRg@03o`000?nn@Kko_T6n00_o_T6n00?o0000oh5nPOn1OX400_n1OX40
0ol0003o?L8mocg2?@08ocg2?@03o`000?lka3_o>l@k00[o>l@k00?o0000o`;m0_l2o@800_l2o@80
0ol0003o;m0_obo@;`03obo@;`Go00002olEjQD00ol0003o1oP7o`Oh1`03o`Oh1`03o`000?l_d2oo
;m0_00Oo;m0_00?o0000ohebSOn=LXd03_n=LXd2o`0000OoJYEZ00?o0000oj9MX_nRGJ800_nRGJ80
0ol0003o^DJiokU6^@0=okU6^@03o`000?oP7n3oh1oP00;oh1oP00?o0000oo4>lOoa3_402Ooa3_40
0ol0003omPWfooH9mP03ooH9mP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5
nP?o00001?oT6n@00ol0003ogB;MomdRg@05omdRg@03o`000?nn@Kko_T6n00[o_T6n00?o0000oh5n
POn1OX400on1OX400ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00So>l@k00?o0000o`;m
0_l2o@801?l2o@85o`0000Co0?l000?o0000oaGZ5OlEjQD02OlEjQD00ol0003o1oP7o`Oh1`03o`Oh
1`03o`000?l_d2oo;m0_00So;m0_00?o0000ohebSOn=LXd02_n=LXd3o`0000[oJYEZ00Go0000oj9M
X_nRGJ;oXUfRo`00000>okU6^@03o`000?oP7n3oh1oP00Coh1oP0_l00009oo4>l@03o`000?of2OKo
mPWf00;omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000on@K
i?oT6n@01OoT6n@00ol0003ogB;MomdRg@03omdRg@03o`000?nn@Kko_T6n00[o_T6n00?o0000oh5n
POn1OX401?n1OX400ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00Oo>l@k00?o0000o`;m
0_l2o@801Ol2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lEjQGo5NXE00Oo5NXE00?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o;m0_obo@;`08obo@;`03o`000?n=LXgoSG:=00SoSG:=0_l0000>ofZE
JPCo00003?niA[T2o`0000Woh1oP00?o0000oo4>lOoa3_401ooa3_401?l0003omPWfooH9m_l0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oi1_Ton@Ki007on@Ki0;o00000ooM8]d00ol0
003o_T6noki1_P09oki1_P03o`000?n1OX7oPGj100KoPGj100?o0000ocg2?Olm`Sd02Olm`Sd00ol0
003o>l@koc_4>`05oc_4>`03o`000?l2o@;o0_d200Ko0_d200?o0000o`3o0?l0o`002?l0o`000ol0
003o5NXEoaGZ5@06oaGZ5@03o`000?l7n0Oo1oP700Co1oP700?o0000obo@;ol_d2l02Ol_d2l4o`00
00?oSG:=0ol0000@ofZEJP05o`000?o7><OoacS7olLhaol000002_niA[T00ol0003oh1oPon0Oh00:
on0Oh0Ko00000ooa3_400ol0003omPWfo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0
003oi1_Ton@Ki00:on@Ki004o`000?oM8]gogB;Mo`0000[o_T6n00?o0000oh5nPOn1OX401on1OX40
0ol0003o?L8mocg2?@09ocg2?@03o`000?lka3_o>l@k00Co>l@k00?o0000o`;m0_l2o@801ol2o@80
0ol0003o0?l0o`3o0008o`3o00;o00001_lEjQD00ol0003o1oP7o`Oh1`05o`Oh1`03o`000?l_d2oo
;m0_00Wo;m0_00Co0000obo@;ol_d2oo;m0_0ol0000BofZEJP03o`000?o7><OoacS700?oacS70_l0
0006okU6^@;o00003OoP7n000ol0003on0OhooP7n003ooP7n0Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003oi1_Ton@Ki00<on@Ki0;o00002_nn@Kh00ol0003oPGj1oh5nP@08oh5nP@03o`000?lm`Sgo
?L8m00[o?L8m00?o0000oc_4>olka3/00_lka3/00ol0003o0_d2o`;m0P08o`;m0P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lEjQGo5NXE00;o5NXE00?o0000o`Oh1ol7n0L01_l7n0L0
0ol0003o;m0_obo@;`08obo@;`03o`000?l_d2oo;m0_00Co;m0_00?o0000ofZEJ_mZUFX03omZUFX0
0ol0003oacS7olLha`06olLha`;o00000oniA[T00ol0003oh1oPon0Oh00=on0Oh003o`000?oh1oSo
n0Oh00Oon0Oh0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?oT6nCoi1_T
00koi1_T00?o0000oki1__nn@Kh01onn@Kh00ol0003oPGj1oh5nP@0:oh5nP@03o`000?lm`Sgo?L8m
00Wo?L8m00Go0000oc_4>olka3_o>l@ko`00000;o`;m0P03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lEjQGo5NXEoaGZ5Ol000002?l7n0L00ol0003o;m0_obo@;`08obo@;`03o`000?l_
d2oo;m0_00Go;m0_00?o0000ofZEJ_mZUFX03_mZUFX00ol0003oacS7olLha`08olLha`03o`000?ni
A[Wo000000ooh1oP00?o0000ooP7n?oh1oP02?oh1oP01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oj1O[onPGjo`00017oi1_T00?o0000oki1__nn@Kh01_nn@Kh00ol0003oPGj1
oh5nP@0;oh5nP@03o`000?lm`Sgo?L8m00Wo?L8m00Co0000oc_4>olka3_o00003?l2o@800ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5NXEo`000009o`Oh1`03o`000?l_d2oo;m0_00So
;m0_00?o0000obo@;ol_d2l01Ol_d2l00ol0003oJYEZofZEJP0=ofZEJP03o`000?o7><OoacS700[o
acS700?o0000on0Oh?oP7n003_oP7n000ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000Bon@Ki003o`00
0?nn@Kko_T6n00Co_T6n00?o0000oh5nPOn1OX403?n1OX400ol0003o?L8mocg2?@0:ocg2?@?o0000
3?l2o@800ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Oh1ol7n0L02?l7n0L00ol0003o;m0_
obo@;`07obo@;`03o`000?l_d2oo;m0_00Oo;m0_00?o0000ofZEJ_mZUFX03?mZUFX00ol0003oacS7
olLha`0;olLha`;o00003_oP7n000ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP00ooh1oP00ol0003oi1_Ton@Ki00?on@Ki0?o00000onn
@Kh00ol0003oPGj1oh5nP@0>oh5nP@03o`000?lm`Sgo?L8m00So?L8m00Co0000o`Wf2Ol9mPWo2OH9
0_l0000:o`;m0P?o00003Ol0o`000ol0003o1oP7o`Oh1`08o`Oh1`03o`000?l_d2oo;m0_00Oo;m0_
00?o0000obo@;ol_d2l01ol_d2l00ol0003oJYEZofZEJP0;ofZEJP03o`000?o7><OoacS700coacS7
00?o0000oo4>lOl000000_l0000:on0Oh003o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n004ooP7n003o`000?oT6nCoi1_T00coi1_T0_l0
0003om@[e003o`000?nn@Kko0000017oPGj100?o0000ocg2?Olm`Sd01olm`Sd00ol0003o2OH9o`Wf
2@04o`Wf2@;o00002?l2o@800ol0003o0?l0o`3o000>o`3o00;o00002?l7n0L00ol0003o;m0_obo@
;`06obo@;`03o`000?l_d2oo;m0_00Wo;m0_00?o0000ofZEJ_mZUFX02OmZUFX00ol0003oacS7olLh
a`0=olLha`03o`000?oa3_7ol@ka00;ol@ka0ol00007on0Oh003o`000?oh1oSon0Oh00Oon0Oh00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oT6nCo
i1_T00Woi1_T0_l00006om@[e003o`000?n1OX7oPGj1013oPGj100?o0000ocg2?Olm`Sd01_lm`Sd0
0ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l2o@;o0_d200Co0_d20ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol7n0L00ol0003o;m0_obo@;`06obo@;`03o`000?l_d2oo;m0_00[o;m0_00?o0000
ofZEJ_mZUFX02?mZUFX00ol0003oacS7olLha`0=olLha`03o`000?oa3_7ol@ka00Gol@ka0ol00004
on0Oh003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on0OhooP7n006ooP7n003o`000?oT6nCoi1_T00Goi1_T0ol00008om@[e003o`000?n1OX7oPGj1
017oPGj100Co0000ocg2?Olm`Sgo?L8m1?l0000;o`Wf2@;o000000Co0_d2o`000?l0003o00000ol2
o@82o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1oP700?o0000obo@;ol_d2l01_l_
d2l00ol0003o;m0_obo@;`0:obo@;`03o`000?mZUF[oJYEZ00OoJYEZ00?o0000olLhaoo7><L03_o7
><L00ol0003ol@kaoo4>l@08oo4>l@Co00002_oh1oP00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on0OhooP7n007ooP7n003o`000?oT6nCoi1_T00;oi1_T0_l0000<om@[e003o`000?n1OX7o
PGj1013oPGj11?l00003oc7><@03o`000?l9mPWo2OH900_o2OH900?o0000o`;m0_l2o@801_l2o@80
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>obo@;`03o`000?mZUF[o
JYEZ00KoJYEZ00?o0000olLhaoo7><L03_o7><L00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00Won0Oh00Co0000on@K
i?l0003o00003_oD:m@00ol0003oPGj1oh5nP@0?oh5nP@03o`000?lacS7o<Lha00Ko<Lha00?o0000
o`Wf2Ol9mPT02_l9mPT00ol0003o0_d2o`;m0P07o`;m0P;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l]dRgo;M8]00So;M8]00?o0000obo@;ol_d2l03?l_d2l00ol0003oJYEZofZEJP05
ofZEJP03o`000?o7><OoacS700ooacS70_l0000=oo4>l@03o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00[on0Oh00?o0000om@[e?oD:m@03_oD:m@00ol0
003oPGj1oh5nP@0>oh5nP@03o`000?lacS7o<Lha00Oo<Lha00?o0000o`Wf2Ol9mPT02_l9mPT00ol0
003o0_d2o`;m0P09o`;m0P;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l]dRgo;M8]
00Wo;M8]00?o0000obo@;ol_d2l02_l_d2l4o`0000CoJYEZ00?o0000olLhaoo7><L04?o7><L01?l0
003okQ7^o`000?l0000<oo4>l@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oh1oSon0Oh00[on0Oh00?o0000om@[e?oD:m@03ooD:m@@o`0000[o<Lha00?o0000o`Wf
2Ol9mPT02Ol9mPT00ol0003o0?l0o`00000<o`;m0P05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o;M8]obgB;@09obgB;@03o`000?l_d2oo;m0_00Oo;m0_0ol00004ofFJI@?o000000?oJYEZ
o`000?o7><L04Oo7><L01?l0003okQ7^onhAk_o^4Nh2o`0000_ol@ka00?o0000ooP7n?oh1oP00ooh
1oP00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oe2_Dom@[e00?
om@[e003o`000?mnPGkoOX5n00coOX5n00?o0000oc7><OlacS402OlacS400ol0003o2OH9o`Wf2@07
o`Wf2@04o`000?l0o`3o0?l0o`0000go0_d200Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l]dRgo;M8]00[o;M8]00?o0000obo@;ol_d2l00ol_d2l3o`0000[oIIYU00?o0000olLhaoo7><L0
4?o7><L00ol0003okQ7^onhAkP04onhAkP;o00002_oa3_400ol0003on0OhooP7n004o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con0Oh00?o0000om@[e?oD:m@03ooD:m@00ol0003oOX5nogj1OP0<ogj1OP03o`000?la
cS7o<Lha00Wo<Lha00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o0?l0o`3o0002o`3o0003o`000?l2
o@;o0_d200[o0_d200?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l]
dRgo;M8]00[o;M8]00?o0000obo@;ol_d2l00ol0000=ofFJI@03o`000?o7><OoacS7013oacS700?o
0000onhAk_o^4Nh01_o^4Nh2o`0000Wol@ka0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oe2_Dom@[e00=om@[e0?o00003omnPGh0
0ol0003o<Lhaoc7><@08oc7><@03o`000?l9mPWo2OH900Go2OH900?o0000o`3o0?l0o`000ol0o`00
0ol0003o0_d2o`;m0P0:o`;m0P03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o;M8]obgB;@0;obgB;@;o00004OmUVVD00ol0003oacS7olLha`0?olLha`03o`000?o^4Nko
kQ7^00SokQ7^0_l00007oo4>l@03o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooP7n?oh1oP02?oh1oP00ol0003oe2_Dom@[e009om@[e0Go00000_n_D:l00ol0
003oOX5nogj1OP0=ogj1OP03o`000?lacS7o<Lha00Wo<Lha00?o0000o`Wf2Ol9mPT01?l9mPT00ol0
003o0?l0o`3o0004o`3o0003o`000?l2o@;o0_d200So0_d200?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l]dRgo;M8]00_o;M8]00?o0000ofFJIOmUVVD04?mUVVD00ol0
003oacS7olLha`0?olLha`03o`000?o^4NkokQ7^00[okQ7^0_l00004oo4>l@03o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on0OhooP7n007ooP7n003o`000?oD:mCoe2_D00Coe2_D1Ol00007ojm@[`03
o`000?mnPGkoOX5n00goOX5n00?o0000oc7><OlacS402OlacS400ol0003o2OH9o`Wf2@03o`Wf2@03
o`000?l0o`3o0?l000Go0?l000?o0000o`;m0_l2o@802?l2o@800ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000obgB;Ol]dRd02ol]dRd00ol0003oIIYUofFJI@0@ofFJI@03
o`000?o7><OoacS700ooacS700?o0000onhAk_o^4Nh03?o^4Nh2o`000003oo4>lOl0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000om@[e?l00000
1?l0000<ojm@[`03o`000?mnPGkoOX5n00koOX5n00?o0000oc7><OlacS402?lacS400ol0003o2OH9
o`Wf2@02o`Wf2@03o`000?l0o`3o0?l000Oo0?l000?o0000o`;m0_l2o@801ol2o@800ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000obgB;Ol]dRd02ol]dRd00ol0003oIIYU
ofFJI@0AofFJI@03o`000?o7><OoacS700goacS700?o0000onhAk_o^4Nh03oo^4Nh00ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP01Ooh1oP3o`00017o[e2_00?o0000ogj1O_mnPGh03_mn
PGh00ol0003o<Lhaoc7><@09oc7><@04o`000?l9mPWo2OH9o`0000[o0?l000?o0000o`;m0_l2o@80
1ol2o@800ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol]dRd00ol0003o
IIYUofFJI@0AofFJI@?o00003Oo7><L00ol0003okQ7^onhAkP0?onhAkP03o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oh1oP2o`0000;oj1OX00?o0000ojm@[on_D:l03on_D:l00ol0003o
OX5nogj1OP0>ogj1OP03o`000?lacS7o<Lha00So<Lha1Ol0000;o`3o0003o`000?l2o@;o0_d200Ko
0_d200?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=obgB;@03o`000?mUVVGoIIYU
017oIIYU00?o0000ogn0OomoP7l00ol0000:olLha`Co00003Oo^4Nh00ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooX5n_oj1O[onPGj0_l00005onPGj003o`000?n_D:oo[e2_00ko[e2_00?o0000ogj1
O_mnPGh03_mnPGh00ol0003o<Lhaoc7><@07oc7><@03o`000?l?l0oo3o0?00?o3o0?00?o0000o`3o
0?l0o`002?l0o`000ol0003o0_d2o`;m0P05o`;m0P03o`000?l0o`3o0?l000[o0?l01Ol0000<obgB
;@03o`000?mUVVGoIIYU013oIIYU00?o0000ogn0OomoP7l01?moP7l3o`0000KoacS700?o0000onTF
jOoY5^T00_oY5^T5o`0000SokQ7^00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00?o
nPGj00?o0000onPGj?oX5nP01?oX5nP00ol0003o[e2_ojm@[`0=ojm@[`03o`000?mnPGkoOX5n00oo
OX5n00?o0000oc7><OlacS401?lacS42o`0000Oo3o0?00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000obgB;Ol]dRd02?l]dRd3o`00013oIIYU00?o0000ogn0OomoP7l02?moP7l3o`0000;o
acS700?o0000onTFjOoY5^T02?oY5^T5o`0000?okQ7^00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oj1O[onPGj00ConPGj00?o0000onPGj?oX5nP01OoX5nP00ol0003o[e2_ojm@[`0;ojm@[`Co0000
3omnPGh00ol0003o<Lhaoc7><@03oc7><@03o`000?l?l0oo3o0?00So3o0?00?o0000o`3o0?l0o`00
1?l0o`02o`0000So1?/400?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l]dRd2o`0000?o;m0_00?o0000ofFJIOmUVVD03?mUVVD00ol0003oOh1oogn0O`0<ogn0O`;o0000
4?oY5^T3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?oX5nSoj1OX00Koj1OX00?o
0000ojm@[on_D:l02On_D:l00ol0003o`Sg2o`000002og><L`?o00003?mnPGh01?l0003o<Lhaoc7>
<OlacS42o`0000co3o0?00?o0000o`3o0?l0o`000_l0o`000ol0003o1?/4o`Ck1008o`Ck1003o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o;M8]obgB;@02obgB;@03o`00
0?l_d2oo;m0_00Co;m0_0_l0000;ofFJI@03o`000?moP7ooOh1o00coOh1o00?o0000oklo_ol00000
4_oY5^T00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oX5nSoj1OX00Ooj1OX00?o
0000ojm@[on_D:l01_n_D:l2o`0000;o`Sg200?o0000og><LomcS7<00omcS7<3o`0000[oOX5n00?o
0000oc7><Ol000003ol?l0l01?l0003o0?l0o`000?l0000;o`Ck1003o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o;M8]o`000?l00009obo@;`03o`000?mUVVGoIIYU00Oo
IIYU00?o0000ogn0OomoP7l03?moP7l01?l0003o_cnooklo_ol0000ConTFj@03o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003oj1OXonPGj008onPGj003o`000?n_D:oo[e2_00Co
[e2_00?o0000ol8m`_o2?L800oo2?L800ol0003oLhacog><L`05og><L`?o00001_mnPGh4o`00013o
3o0?00?o0000o`Ck1?l4n`@03?l4n`@00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoIIYU00?o0000ogn0OomoP7l03?moP7l00ol0003o
_cnooklo_`02oklo_`03o`000?oY5^WojAKY00oojAKY00?o0000ooP7n?l000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oX5nSoj1OX00Woj1OX00Co0000ojm@[on_D:oo
[e2_0_l00006ol8m`P03o`000?mcS7?oLhac00SoLhac0ol000000omnPGko0000o`000004ocC;=003
o`000?l?l0oo3o0?00go3o0?00?o0000o`Ck1?l4n`@03?l4n`@00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oIIYUofFJI@03o`0000ko
Oh1o00?o0000oklo_ono?kl00ono?kl00ol0003ojAKYonTFj@0>onTFj@05o`000?oh1oSon0OhooP7
n?l000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oX5nSoj1OX00[o
j1OX00?o0000ojm@[ol000002?o2?L800ol0003oLhacog><L`0;og><L`03o`000?ldbcCo=</d00Go
=</d00?o0000o`o`3ol?l0l03?l?l0l00ol0003o1?/4o`Ck100<o`Ck1003o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002ogV6N@03o`000?moP7ooOh1o00_o
Oh1o00?o0000oklo_ono?kl01?no?kl00ol0003ojAKYonTFj@0=onTFj@03o`000?oh1oSon0Oh00?o
n0Oh00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooX5nP03o`000?oX5nSoj1OX00_oj1OX00?o0000ol8m`_o2?L80
1oo2?L800ol0003oLhacog><L`0;og><L`03o`000?ldbcCo=</d00Ko=</d00?o0000o`o`3ol?l0l0
2ol?l0l2o`0000go1?/400?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000ogV6NOmiQWT00_miQWT00ol0003oOh1oogn0O`09ogn0O`03
o`000?no?koo_cno00Ko_cno00?o0000onTFjOoY5^T02ooY5^T00ol0003on0OhooP7n005ooP7n004
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000SonPGj00?o0000onPGj?oX5nP02_oX5nP2o`0000Wo
`Sg200?o0000og><LomcS7<02omcS7<00ol0003o=</docC;=007ocC;=003o`000?l?l0oo3o0?00Wo
3o0?00Co0000o`3o0?l0o`3o00003?l4n`@00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?miQWWoNHIi00?oNHIi00?o0000
ogn0OomoP7l01omoP7l00ol0003o_cnooklo_`07oklo_`03o`000?oY5^WojAKY00[ojAKY00?o0000
ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooX5nP03o`000?oX5nSoj1OX
00Woj1OX00Co0000on@Ki?oT6nCo00002Oo2?L800ol0003oLhacog><L`09og><L`03o`000?ldbcCo
=</d00Wo=</d00?o0000o`o`3ol?l0l01ol?l0l00ol0003o0?l0o`3o0002o`3o0003o`000?l4n`Co
1?/400Wo1?/400?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oNHIiogV6N@05ogV6N@03o`000?moP7oo
Oh1o00GoOh1o00?o0000oklo_ono?kl02?no?kl00ol0003ojAKYonTFj@09onTFj@03o`000?oh1oSo
n0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oj1OX3o`0000Woj1OX00?o0000on@K
i?oT6n@00_oT6n@00ol0003o`Sg2ol8m`P06ol8m`P03o`000?mcS7?oLhac00WoLhac00?o0000ocC;
=?ldbc@02_ldbc@00ol0003o3o0?o`o`3`05o`o`3`03o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@02?l4n`@00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?miQWWoNHIi00KoNHIi00?o0000ogn0
OomoP7l00omoP7l00ol0003o_cnooklo_`09oklo_`03o`000?oY5^WojAKY00SojAKY00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003oo@;m0?o00001OoX5nP00ol0003o
i1_Ton@Ki003on@Ki003o`000?o2?L;o`Sg200Ko`Sg200?o0000og><LomcS7<02OmcS7<00ol0003o
=</docC;=00;ocC;=003o`000?l?l0oo3o0?00?o3o0?00?o0000o`3o0?l0o`001_l0o`000ol0003o
1?/4o`Ck1008o`Ck1003o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oNHIiogV6N@07ogV6N@05o`000?moP7ooOh1oogn0
Ool000003Ono?kl00ol0003ojAKYonTFj@06onTFj@03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?od2oCom0_d00Gom0_d0ol000000ooX5nSo0000on@Ki006on@Ki003
o`000?o2?L;o`Sg200Go`Sg200?o0000og><LomcS7<02OmcS7<00ol0003o=</docC;=00<ocC;=005
o`000?l?l0oo3o0?o`o`3ol000002_l0o`000ol0003o1?/4o`Ck1007o`Ck1003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olMhQgo0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000ogV6NOmiQWT02OmiQWT00ol0003oOh1oo`00000=oklo_`Co00001OoY5^T00ol0
003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om0_doo@;m008oo@;m003
o`000?oT6nCoi1_T00Ooi1_T00?o0000ol8m`_o2?L801?o2?L800ol0003oLhacog><L`09og><L`03
o`000?ldbcCo=</d00go=</d00?o0000o`o`3ol000003?l0o`0:o`0000Oo0?l00ol00005oagR7@03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oNHIiogV6N@0:ogV6N@03
o`000?no?koo_cno00_o_cno00?o0000onXEj_oZ5NX00_oZ5NX3o`000003onTFjOl0003on0Oh00_o
n0Oh0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003oi1_Ton@Ki007on@Ki003o`00
0?o2?L;o`Sg200Go`Sg200?o0000og><LomcS7<01omcS7<00ol0003o=</docC;=00?ocC;=0;o0000
2ol0o`000ol0003o4NhAoa7^4@07oa7^4@03o`000?l0o`3o0?l000;o0?l00ol00008oagR7@03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oNHIiogV6N@0:ogV6N@03o`00
0?no?koo_cno00[o_cno00?o0000onXEj_oZ5NX01_oZ5NX00ol0003on0OhooP7n008ooP7n0?o0000
0_oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003oi1_Ton@K
i008on@Ki003o`000?o2?L;o`Sg200Co`Sg200?o0000og><LomcS7<01omcS7<00ol0003o=</docC;
=00>ocC;=004o`000?l5nPGo1OX5o`0000Wo0?l000?o0000oa7^4OlAkQ402OlAkQ401?l0003o0?l0
o`000?l0000<oagR7@03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
NHIiogV6N@0;ogV6N@03o`000?no?koo_cno00Oo_cno0_l00009onXEjP03o`000?oh1oSon0Oh00Co
n0Oh1?l00006ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m009oo@;m003o`00
0?oT6nCoi1_T00Soi1_T00?o0000ol8m`_o2?L800oo2?L8>o`0000go=</d00?o0000o`Gj1Ol5nPD0
0_l5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?lAkQ7o4NhA00_o4NhA00?o0000oagR7OlMhQd0
3?lMhQd00ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000ogV6NOmiQWT0
3?miQWT00ol0003o_cnooklo_`06oklo_`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ooP7n?oh1oP0
0ol0000:ooX5nP?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on@Ki?oT6n@02?oT
6n@01Ol0003o`Sg2ol8m`_o2?L;o000000_oR7N800?o0000obGJ9OlUfRD00ol00009ocC;=003o`00
0?l5nPGo1OX500Co1OX500?o0000o`3o0?l0o`000ol0o`000ol0003o4NhAoa7^4@0<oa7^4@03o`00
0?lMhQgo7N8M00go7N8M00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmiQWT00ol0003o_cnooklo_`05oklo_`03o`000?oZ5N[ojQGZ00cojQGZ0_l0000=ooX5nP03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000on@Ki?oT6n@02?oT
6n@4o`0000coR7N800?o0000obGJ9OlUfRD00olUfRD3o`0000Go=</d00?o0000o`Gj1Ol5nPD01_l5
nPD01Ol0003o0?l0o`3o0?l0o`3o000000oo4NhA00?o0000oagR7OlMhQd03OlMhQd00ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000ol_d2l00ol0003oNHIiogV6N@0;ogV6N@03o`00
0?no?koo_cno00?o_cno00?o0000onXEj_oZ5NX03OoZ5NX00ol0003onPGjooX5nP0;ooX5nP03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000oo@;m?od2o@02_od2o@3o`0000Koi1_T0ol0
0003omLXe`03o`000?n8MhSoR7N800[oR7N800?o0000obGJ9OlUfRD01_lUfRD3o`000003ocC;=?l0
003o1OX500Wo1OX500?o0000o`3o0?l000004?lAkQ400ol0003o7N8MoagR7@0=oagR7@03o`000?l4
n`Co1?/400Oo1?/40_l00007obo@;`03o`000?miQWWoNHIi00[oNHIi00Co0000oklo_ono?koo_cno
0ol0000?onXEjP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo@;m?od2o@02_od
2o@01?l0003ol0o`oo0?l?o`3o02o`000004on@Ki?l0003o0000o`0000KoebSG00?o0000ohQgR?n8
MhP02_n8MhP00ol0003o9MXUobGJ9@09obGJ9@03o`000?l5nPGo1OX500[o1OX500?o0000oa7^4OlA
kQ403olAkQ400ol0003o7N8MoagR7@0>oagR7@03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_
d2l01ol_d2l4o`0000SoNHIi00Co0000oklo_ono?koo00000ooH9mP2o`0000gojQGZ00?o0000ooX5
n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003o
l0o`oo0?l004oo0?l003o`000?oG:=OoebSG00OoebSG00?o0000ohQgR?n8MhP02On8MhP00ol0003o
9MXUobGJ9@0:obGJ9@03o`000?l5nPGo1OX500[o1OX500?o0000oa7^4OlAkQ403olAkQ400ol0003o
7N8MoagR7@0>oagR7@03o`000?l4n`Co1?/400Go1?/400?o0000obo@;ol_d2l02?l_d2l01?l0003o
NhAkog^4NomkQ7/7o`0000;oNHIi0_l00006omPWf0;o00003?oZ5NX00ol0003onPGjooX5nP09ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003om0_doo@;m008oo@;m003o`000?o`3o3ol0o`00Go
l0o`00?o0000omLXeooG:=L02?oG:=L00ol0003oR7N8ohQgR008ohQgR003o`000?lUfRGo9MXU00[o
9MXU00?o0000o`Gj1Ol5nPD02ol5nPD00ol0003o4NhAoa7^4@0>oa7^4@03o`000?lMhQgo7N8M00ko
7N8M1Ol00002o`Ck1003o`000?l_d2oo;m0_00Wo;m0_00?o0000og^4NomkQ7/02?mkQ7/3o`0000Wo
f2OH0_l0000:onXEjP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?od2oCom0_d00Som0_d00?o0000oo0?l?o`3o001oo`3o000ol0003oebSGomLXe`07omLXe`03o`00
0?n8MhSoR7N800SoR7N800?o0000obGJ9OlUfRD02_lUfRD00ol0003o1OX5o`Gj1@0:o`Gj1@;o0000
3_lAkQ43o`0000go7N8M0ol00005oc3?<0;o00002ol_d2l00ol0003oNhAkog^4N`0;og^4N`;o0000
2_oH9mP2o`0000OojQGZ0ol00009ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:oo0?l003o`00
0?oG:=OoebSG00OoebSG00?o0000ohQgR?n8MhP02?n8MhP>o`0000Wo1OX50ol000000ol0o`3o0000
oa7^4@0:oa7^4@?o00000_lYeRT00ol0003o7N8MoagR7@09oagR7@;o00002Ol`cc000ol0003o;m0_
obo@;`09obo@;`03o`000?mkQ7_oNhAk00_oNhAk00?o0000ojAKY?l000002ooH9mP2o`0000CojQGZ
00Co0000oo8=l_ob3O;olPgb0_l00007ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003ol0o`
oo0?l009oo0?l003o`000?oG:=OoebSG00KoebSG00?o0000ohQgR?n8MhP02?n8MhP00ol0003o:=LX
obSG:00:obSG:003o`000?l5nPGo1OX500Co1OX50ol00005o`3o0003o`000?lAkQ7o4NhA00Co4NhA
1?l00006obWF:@03o`000?lMhQgo7N8M00Ko7N8M0_l0000;oc3?<003o`000?l_d2oo;m0_00Wo;m0_
00?o0000og^4NomkQ7/02_mkQ7/01Ol0003oY5^TojAKY?nTFjCo000000cof2OH0_l000000ooZ5N[o
0000oo8=lP05oo8=lP03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o`3o3ol0o`00Sol0o`00?o0000omLXeooG:=L01_oG:=L00ol0003oR7N8ohQgR007ohQgR003o`00
0?lXebSo:=LX00_o:=LX00?o0000o`Gj1Ol5nPD00_l5nPD2o`0000Wo0?l000?o0000oa7^4OlAkQ40
0ol0000;obWF:@03o`000?lMhQgo7N8M00;o7N8M0ol0000>oc3?<003o`000?l_d2oo;m0_00Oo;m0_
00?o0000og^4NomkQ7/02omkQ7/00ol0003oY5^TojAKY002ojAKY003o`000?oH9mSof2OH00_of2OH
00?o0000oo8=l_ob3O801_ob3O82o`0000?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o`
3o3ol0o`00Ool0o`00?o0000omLXeooG:=L01ooG:=L00ol0003oR7N8ohQgR005ohQgR0?o00003OlX
ebP4o`0000_o0?l00ol0000?obWF:@04o`000?lMhQgo0000o`00017o<<l`00?o0000obo@;ol_d2l0
1ol_d2l00ol0003oNhAkog^4N`0:og^4N`03o`000?nTFjCoY5^T00CoY5^T00?o0000omPWf?oH9mP0
1ooH9mP3o`0000_olPgb1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003oebSGomLX
e`06omLXe`03o`000?n8MhSoR7N800;oR7N80ol00003of>LH`03o`000?lXebSo:=LX00[o:=LX00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AobWF:@03o`000?l`cc3o<<l`017o<<l`00?o
0000obo@;ol_d2l01ol_d2l00ol0003oNhAkog^4N`0:og^4N`03o`000?nTFjCoY5^T00GoY5^T00Co
0000omPWf?oH9mSof2OH1Ol00002omdRg@03o`000?ob3O;olPgb00WolPgb00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`3o000ol0003oebSGomLXe`05omLXe`?o0000
00?oR7N8o`000?l000001omSW6<00ol0003o:=LXobSG:008obSG:0?o00002_l0o`02o`0000;o0?l0
00?o0000obWF:OlYeRT03olYeRT00ol0003o<<l`oc3?<00Aoc3?<003o`000?l_d2oo;m0_00Oo;m0_
00?o0000og^4NomkQ7/02OmkQ7/00ol0003oY5^TojAKY007ojAKY0?o00001ooM8]d00ol0003olPgb
oo8=lP09oo8=lP03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`
3o04o`0000;oebSG0_l00003olTfb@03o`000?mSW6?oHiaS00SoHiaS0_l00006obSG:0;o00000olO
gal00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obWF:OlYeRT03_lY
eRT00ol0003o<<l`oc3?<00Boc3?<003o`000?l_d2oo;m0_00Go;m0_00?o0000og^4NomkQ7/02Omk
Q7/00ol0003oY5^TojAKY008ojAKY003o`000?oM8]gogB;M00OogB;M00?o0000oo8=l_ob3O802?ob
3O800ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`00Col0o`0_l00004
onhAkP;o00001Oo9=/T00ol0003oHiaSof>LH`0:of>LH`03o`000?lXebSo:=LX00;o:=LX00?o0000
oaoO7olOgal01?lOgal00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obWF:OlYeRT03_lYeRT00ol0003o<<l`oc3?<00Boc3?<0[o00002_mkQ7/00ol0003oY5^TojAKY008
ojAKY003o`000?oM8]gogB;M00OogB;M00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ol0o`oo0?l?o`3o02o`0000OokQ7^00?o0000olTfbOo9=/T01?o9=/T0
0ol0003oHiaSof>LH`0:of>LH`04o`000?lXebSo0000o`0000So7mlO00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lYeRWo:MHY00ko:MHY00?o0000oc3?<?l`cc004_l`cc000ol0003oD:m@
oe2_D007oe2_D003o`000?mkQ7_oNhAk00KoNhAk00?o0000ojAKY?nTFj@02_nTFj@00ol0003ogB;M
omdRg@06omdRg@03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o`
3o3o0000o`0000WokQ7^00?o0000olTfbOo9=/T01?o9=/T00ol0003oHiaSof>LH`0;of>LH`03o`00
0?lOgaoo7mlO00Wo7mlO00?o0000o`3o0?l000002Ol0o`000ol0003o:MHYobWF:@0>obWF:@;o0000
4_l`cc000ol0003oD:m@oe2_D009oe2_D0;o00001_mkQ7/00ol0003oY5^TojAKY00:ojAKY003o`00
0?oM8]gogB;M00KogB;M00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onhAk_o^4Nh02Oo^4Nh00ol0003obCK9olTfb@05olTfb@03o`000?mSW6?oHiaS00[oHiaS00?o
0000oaoO7olOgal02_lOgal2o`0000Wo0?l000?o0000obWF:OlYeRT03_lYeRT00ol0003o7n0Oo`00
0002o`0000oo<<l`00?o0000oe2_D?m@[e002om@[e000ol0003oNhAkog^4N`03o`0000goY5^T00?o
0000omdRgOoM8]d01_oM8]d00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003okQ7^onhAkP09onhAkP03o`000?o9=/WobCK900GobCK900?o0000of>LHomSW6<02OmSW6<2
o`0000_o7mlO0_l0000;o`3o0003o`000?lYeRWo:MHY00co:MHY00?o0000oaoP7olOh1l00olOh1l3
o`0000co<<l`00?o0000oe2_D?m@[e003?m@[e02o`0000;oWf2O00?o0000ojAKY?nTFj@03?nTFj@0
0ol0003ogB;MomdRg@05omdRg@03o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o^4NkokQ7^00[okQ7^00?o0000olTfbOo9=/T01_o9=/T00ol0003oHiaSof>LH`07of>L
H`03o`000?m[U6_o000000[o7mlO00Co0000oaSW6?lHiaSo00002_l0o`000ol0003o:MHYobWF:@0<
obWF:@03o`000?lOh1oo7n0O00Ko7n0O0_l00008oc3?<0;o00003om@[e000ol0003oWf2OoimPW`02
oimPW`03o`000?nTFjCoY5^T00_oY5^T00?o0000omdRgOoM8]d01OoM8]d00ol0003olPgboo8=lP07
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okQ7^onhAkP0:onhAkP03o`000?o9=/WobCK9
00KobCK900?o0000of>LHomSW6<01_mSW6<01Ol0003oJiA[of^DJom[U6_o000000So7mlO00?o0000
oaSW6?lHiaP00_lHiaP00ol0003o0?l0o`3o0006o`3o00Co00003?lYeRT00ol0003o7n0OoaoP7`08
oaoP7`?o00000_l`cc03o`000003oc_4>ol0003oD:m@00goD:m@00?o0000oimPWonOH9l01?nOH9l0
0ol0003oY5^TojAKY00:ojAKY003o`000?oM8]gogB;M00GogB;M00?o0000oo8=l_ob3O801_ob3O80
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh02oo^4Nh00ol0003obCK9olTfb@07olTf
b@03o`000?mSW6?oHiaS00?oHiaS0_l00005of^DJ`03o`000?lOgaoo7mlO00Co7mlO00?o0000oaSW
6?lHiaP00olHiaP00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200;o0_d20ol00007obWF
:@;o00003_lOh1l2o`0000Go>l@k00?o0000oe2_D?m@[e002_m@[e000ol0003oWf2OoimPW`05oimP
W`03o`000?nTFjCoY5^T00_oY5^T00?o0000omdRgOoM8]d01?oM8]d00ol0003olPgboo8=lP06oo8=
lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003okQ7^onhAkP0;onhAkP03o`000?o9=/WobCK900Oo
bCK900?o0000of>LHomSW6<00_mSW6<00ol0003oJiA[of^DJ`06of^DJ`03o`000?lOgaoo7mlO00;o
7mlO00?o0000oaSW6?lHiaP01OlHiaP00ol0003o0?l0o`3o0002o`3o00;o00002?l2o@83o`0000;o
:MHY0_l000000ol6n@Ko0000oaoP7`0=oaoP7`03o`000?lka3_o>l@k00Go>l@k00?o0000oe2_D?m@
[e002?m@[e000ol0003oWf2OoimPW`07oimPW`03o`000?nTFjCoY5^T00[oY5^T00?o0000omdRgOoM
8]d01?oM8]d00ol0003olPgboo8=lP06oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okQ7^
onhAkP0<onhAkP03o`000?o9=/WobCK900SobCK900Co0000of>LHomSW6?o00002Om[U6/01Ol0003o
7mlOoaoO7olOgaoo000000So6>LH00Go0000o`3o0?l0o`3o0?l0o`00000=o`;m0P;o00001?l6n@H0
0ol0003o7n0OoaoP7`0;oaoP7`03o`000?lka3_o>l@k00Ko>l@k00?o0000oe2_D?m@[e001om@[e00
0ol0003oWf2OoimPW`08oimPW`Co00002?nTFj@00ol0003ogB;MomdRg@04omdRg@03o`000?ob3O;o
lPgb00KolPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o^4NkokQ7^00_okQ7^0ol00009olTf
b@03o`000?mSW6?o000000_oJiA[00?o0000oaoO7ol000002_lHiaP00ol0003o0?l0o`00000?o`;m
0P03o`000?l6n@Ko1_T600;o1_T600?o0000oaoP7olOh1l02olOh1l00ol0003o>l@koc_4>`06oc_4
>`03o`000?m@[e3oD:m@00KoD:m@00?o0000oimPWonOH9l02OnOH9l01?l0003oacS7olLhaoo7><L7
o`0000;oY5^T00?o0000omdRgOoM8]d00ooM8]d00ol0003olPgboo8=lP05oo8=lP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o^4NkokQ7^00SokQ7^0ol00003on`Ck003o`000?o9=/WobCK900OobCK900?o0000of^D
Jom[U6/02om[U6/00ol0003o6>LHoaSW600:oaSW6003o`000?l2o@;o0_d200go0_d200?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o7n0OoaoP7`09oaoP7`03o`000?lka3_o>l@k00So>l@k00?o0000oe2_
D?m@[e000om@[e02o`0000coWf2O00?o0000olLhaoo7><L02?o7><L<o`0000?olPgb0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onhAk_o^4Nh01_o^4Nh3o`0000Ook1?/00?o0000olTfbOo9=/T01_o9=/T00ol0003o
JiA[of^DJ`0;of^DJ`03o`000?lHiaSo6>LH00Wo6>LH0_l0000>o`;m0P03o`000?l6n@Ko1_T600Go
1_T600?o0000oaoP7olOh1l02OlOh1l00ol0003o>l@koc_4>`09oc_4>`03o`000?m@[e3o000000;o
00000_nDJi@00ol0003oWf2OoimPW`08oimPW`03o`000?o7><OoacS700coacS700?o0000ondBkOo]
4^d01_o]4^d3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003okQ7^onhAkP03onhAkP?o00002oo/4n`00ol0003obCK9
olTfb@04olTfb@03o`000?m[U6_oJiA[00_oJiA[0ol00007oaSW60?o000000?o3O8=o`000?l2o@80
3Ol2o@800ol0003o1_T6o`Ki1P06o`Ki1P03o`000?lOh1oo7n0O00So7n0O00?o0000oc_4>olka3/0
2_lka3/00ol0003oU6^DoiA[U004oiA[U003o`000?nOH9ooWf2O00OoWf2O00?o0000olLhaoo7><L0
2oo7><L00ol0003okA;]ondBk@08ondBk@03o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onhAk_l0
003o0000o`0000ook1?/00?o0000olTfbOo9=/T00oo9=/T>o`0000?oE:]D0_l00002oaSW60?o0000
1Ol=lPd00ol0003o0_d2o`;m0P0:o`;m0P03o`000?l6n@Ko1_T600Oo1_T600?o0000oaoP7olOh1l0
2?lOh1l00ol0003o>l@koc_4>`0:oc_4>`03o`000?nDJiCoU6^D00GoU6^D00?o0000oimPWonOH9l0
1_nOH9l00ol0003oacS7olLha`0;olLha`03o`000?o]4^gokA;]00SokA;]00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;ok1?/00?o0000olTfbOo9=/T00_o9=/T00ol0003o^DJiokU6
^@0:okU6^@03o`000?mDZeCoE:]D00?oE:]D0_l00009o`gb3@03o`000?l2o@;o0_d200Wo0_d200?o
0000o`Ki1_l6n@H02?l6n@H2o`0000So7n0O00?o0000oc_4>olka3/02Olka3/00ol0003oU6^DoiA[
U007oiA[U003o`000?nOH9ooWf2O00CoWf2O00?o0000olLhaoo7><L02oo7><L00ol0003okA;]ondB
k@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003ok1?/on`Ck00?on`Ck0?o000000?obCK9
o`000?niA[T02oniA[T00ol0003oE:]DoeB[E004oeB[E003o`000?l=lPgo3O8=00Wo3O8=00?o0000
o`;m0_l2o@801ol2o@800ol0003o1_T6o`Ki1P09o`Ki1P04o`000?lBkA;o0000o`0000Ko7n0O00?o
0000oc_4>olka3/02Olka3/00ol0003oU6^DoiA[U008oiA[U003o`000?nOH9ooWf2O00?oWf2O00?o
0000olLhaoo7><L02oo7><L00ol0003okA;]ondBk@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003ok1?/on`Ck00<on`Ck0;o00000oo[5>/2o`0000co^DJi00?o0000oeB[E?mDZe@01?mDZe@0
0ol0003o3O8=o`gb3@0:o`gb3@Wo00002ol6n@H00ol0003o4^dBoa;]4P02oa;]4P?o00000_lOh1l0
0ol0003o>l@koc_4>`0:oc_4>`03o`000?nDJiCoU6^D00WoU6^D00?o0000oimPWonOH9l00_nOH9l0
0ol0003oacS7olLha`0:olLha`03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o/4n`2o`0000GojaC[00?o0000ol`cc?l000002_niA[T00ol0003oE:]DoeB[E006oeB[
E003o`000?l=lPgo3O8=00Wo3O8=00?o0000o`3o0?l0o`001Ol0o`000ol0003o1_T6o`Ki1P09o`Ki
1P03o`000?lBkA;o4^dB00Go4^dB0ol00009oc_4>`?o00003OnDJi@01Ol0003oWf2OoimPWonOH9oo
000000coacS700?o0000ondBkOo]4^d02Oo]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000on`C
k?o/4n`01Oo/4n`2o`0000OojaC[00Co0000ol`cc?o<<lco00002OniA[T00ol0003oE:]DoeB[E006
oeB[E003o`000?l=lPgo3O8=00So3O8=00?o0000o`3o0?l0o`001ol0o`000ol0003o1_T6o`Ki1P07
o`Ki1P03o`000?lBkA;o4^dB00So4^dB0ol00002oc_4>`Go00000_mhQgP00ol0003oU6^DoiA[U00<
oiA[U003o`000?nOH9oo000000coacS700?o0000ondBkOo]4^d02_o]4^d00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000on`Ck?o/4n`00_o/4n`2o`0000SojaC[00?o0000ol`cc?o<<l`00_o<<l`5o`00
00Co^DJi00?o0000oeB[E?mDZe@01_mDZe@00ol0003o3O8=o`gb3@08o`gb3@03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Ki1_l6n@H01ol6n@H00ol0003o4^dBoa;]4P08oa;]4P03o`000?lm`Sgo?L8m
00;o00002?mhQgP00ol0003oU6^DoiA[U00<oiA[U0Co00002_o7><L00ol0003okA;]ondBk@0:ondB
k@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003ok1?/o`000?l0000:on/Dj`03o`000?o<<lcoc3?<
00;oc3?<00?o0000oiYUV_nJIIX00_nJIIX4o`0000WoE:]D00?o0000o`gb3Ol=lPd02?l=lPd00ol0
003o0?l0o`3o0008o`3o0003o`000?l6n@Ko1_T600Go1_T600?o0000oa;]4_lBkA802?lBkA801Ol0
003o?L8mocg2?Olm`Sgo000000[oN8Mh0ol0000;oiA[U004o`000?oQ7^7ohAkQon4Nh@Co00001Oo7
><L00ol0003okA;]ondBk@0;ondBk@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ojaC[on/Dj`0:
on/Dj`03o`000?o<<lcoc3?<00?oc3?<00?o0000oiYUV_nJIIX01?nJIIX00ol0003oE:]DoeB[E007
oeB[E003o`000?l=lPgo3O8=00Ko3O8=0_l0000;o`3o0003o`000?l6n@Ko1_T600Go1_T600?o0000
oa;]4_lBkA802?lBkA800ol0003o?L8mocg2?@02ocg2?@03o`000?mhQgSoN8Mh00OoN8Mh00?o0000
oke2_Onm@[d01?l00006oiA[U003o`000?oQ7^7ohAkQ00KohAkQ0ol00002olLha`03o`000?o]4^go
kA;]00_okA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o[5>_ojaC[00WojaC[00?o0000ol`c
c?o<<l`01?o<<l`00ol0003oVVFJoiYUVP05oiYUVP03o`000?mDZeCoE:]D00OoE:]D00?o0000o`gb
3Ol=lPd00_l=lPd3o`000003oacS7?l0003o0?l000[o0?l000?o0000o`Ki1_l6n@H01Ol6n@H00ol0
003o4^dBoa;]4P07oa;]4P03o`000?lm`Sgo?L8m00?o?L8m00?o0000ogR7N?mhQgP01omhQgP00ol0
003o_D:moke2_@04oke2_@?o00000_nDJi@00ol0003ohAkQon4Nh@0:on4Nh@;o00003_o]4^d00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000on/Djoo[5>/02Oo[5>/00ol0003oc3?<ol`cc004ol`cc003
o`000?nJII[oVVFJ00KoVVFJ0_l00007oeB[E003o`000?l=lPgo000000;o00001OlLha`00ol0003o
0?l0o`3o0008o`3o00?o00001?l6n@H00ol0003o4^dBoa;]4P08oa;]4P03o`000?lm`Sgo?L8m00Co
?L8m00?o0000ogR7N?mhQgP01_mhQgP00ol0003o_D:moke2_@07oke2_@;o00003_oQ7^400ol0003o
kA;]ondBk@0;ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojaC[on/Dj`08on/Dj`03o`00
0?o<<lcoc3?<00Goc3?<00?o0000oiYUV_nJIIX01?nJIIX00ol0003oT6n@oi1_T003o`0000CoE:]D
0_l00008oacS7003o`000?l0o`3o0?l000Oo0?l000Co0000obOH9olWf2Oo9mPW0ol000000ol6n@Ko
0000oa;]4P09oa;]4P03o`000?lm`Sgo?L8m00Co?L8m00?o0000ogR7N?mhQgP01OmhQgP00ol0003o
_D:moke2_@09oke2_@03o`000?oQ7^7ohAkQ00gohAkQ00?o0000ondBkOo]4^d02_o]4^d00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000on/Djoo[5>/01oo[5>/00ol0003oc3?<ol`cc006ol`cc003o`00
0?nJII[oVVFJ00?oVVFJ00?o0000oi1_T?n@Ki001?n@Ki02o`000003oeB[E?l0003o7><L00[o7><L
00?o0000o`3o0?l0o`001Ol0o`000ol0003o9mPWobOH9`05obOH9`03o`000?lBkA;o4^dB00Oo4^dB
0ol00007ocg2?@03o`000?mhQgSoN8Mh00CoN8Mh00?o0000oke2_Onm@[d02Onm@[d00ol0003ohAkQ
on4Nh@0=on4Nh@03o`000?o]4^gokA;]00[okA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o[
5>_ojaC[00GojaC[0ol00009ol`cc005o`000?nJII[oVVFJoiYUV_l000002On@Ki000ol0003o7><L
oacS700;oacS7003o`000?l0o`3o0?l000?o0?l000?o0000obOH9olWf2L01_lWf2L00ol0003o4^dB
oa;]4P06oa;]4P05o`000?ll`cco?<<locc3??l000001olm`Sd00ol0003oN8MhogR7N003ogR7N003
o`000?nm@[go_D:m00Wo_D:m00?o0000on4NhOoQ7^403_oQ7^400ol0003okA;]ondBk@09ondBk@03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ojaC[o`000004o`0000;ol@ka00?o0000ol`cc?o<<l`0
1oo<<l`01?l0003oVVFJoiYUV_l00009oi1_T0;o00003OlLha`00ol0003o0?l0o`3o0002o`3o0003
o`000?lWf2Oo9mPW00So9mPW00?o0000oa;]4_lBkA800olBkA82o`0000Go?<<l00?o0000ocg2?Olm
`Sd01?lm`Sd00ol0003oN8MhogR7N003ogR7N003o`000?nm@[go_D:m00Wo_D:m00?o0000on4NhOoQ
7^403_oQ7^400ol0003okA;]ondBk@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sol@ka
00?o0000ol`cc?o<<l`01_o<<l`00ol0003oVVFJo`000009oi1_T004o`000?mRWF;oHYeRo`0000go
7><L00Co0000o`3o0?l0o`3o00003?lWf2L01Ol0003o4^dBoa;]4_lBkA;o000000So?<<l0_l00005
ocg2?@03o`000?mhQgSoN8Mh00;oN8Mh00?o0000oke2_Onm@[d02Onm@[d00ol0003ohAkQon4Nh@0>
on4Nh@03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oa3_7ol@ka
00Ool@ka00?o0000ol`cc?o<<l`01oo<<l`00ol0003oT6n@oi1_T007oi1_T003o`000?mRWF;oHYeR
00;oHYeR00?o0000oacS7?lLha`02_lLha`00ol0003o0?l0o`00000>obOH9`03o`000?lBkA;o0000
00_o?<<l00?o0000ocg2?Olm`Sd00_lm`Sd01Ol0003oN8MhogR7N?mhQgSo000000co_D:m00?o0000
on4NhOoQ7^403_oQ7^43o`0000WokA;]00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oa3_7ol@ka
00Wol@ka00?o0000ol`cc?o<<l`01_o<<l`00ol0003oT6n@oi1_T006oi1_T003o`000?mRWF;oHYeR
00?oHYeR00?o0000oacS7?lLha`02olLha`00ol0003o9mPWobOH9`0>obOH9`03o`000?ll`cco?<<l
00_o?<<l0_l00003ocg2?@04o`000?mhQgSoN8Mho`0000[o_D:m0ol0000>on4Nh@;o00000oom0_d2
o`0000OokA;]00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oa3_7ol@ka00[ol@ka00?o0000ol`c
c?o<<l`01?o<<l`00ol0003oT6n@oi1_T006oi1_T003o`000?mRWF;oHYeR00GoHYeR00?o0000oacS
7?lLha`01olLha`3o`00017o9mPW00?o0000occ3??ll`c`03Oll`c`01Ol0003o?L8mocg2?Ol0003o
N8Mh00Co00000onm@[d5o`0000;okA;]00?o0000on4NhOoQ7^402_oQ7^42o`0000Ooo@;m0_l00004
ondBk@03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ol@kaoo4>l@0;oo4>l@03o`000?o<<lcoc3?<
00Coc3?<00?o0000oi1_T?n@Ki001On@Ki000ol0003oHYeRof:MHP06of:MHP03o`000?lLhaco7><L
00Co7><L0ol00002ob;M8P03o`000?lWf2Oo9mPW00oo9mPW0_l0000?occ3?004o`000?lm`Sgo0000
o`0000CoZUFZ0ol00008ondBk@03o`000?oQ7^7ohAkQ00OohAkQ0_l0000;ood2o@;o00000_o]4^d0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo4>lOoa3_403?oa3_46o`0000OoT6n@00?o0000of:M
H_mRWF802?mRWF800ol0003o7><LoacS7003o`0000Ko8]dR00?o0000obOH9olWf2L03OlWf2L01?l0
003oAKY5odFjAOl0000?occ3?003o`000?nZEJ[oZUFZ00GoZUFZ00?o0000ondBkOo]4^d02?o]4^d0
0ol0003ohAkQon4Nh@05on4Nh@03o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oa3_400ol0003odBkAom4^d@04om4^
d@03o`000?n@Ki3oT6n@00?oT6n@00?o0000of:MH_mRWF802_mRWF82o`0000[o8]dR00?o0000obOH
9olWf2L02olWf2L00ol0003oAKY5odFjA@02odFjA@03o`000?ll`cco?<<l00_o?<<l0_l00007ojYE
ZP03o`000?o]4^gokA;]00WokA;]00?o0000on4NhOoQ7^400_oQ7^42o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo4>lOoa3_402ooa3_400ol0003odBkAom4^d@06om4^d@05o`000?n@Ki3oT6n@oi1_
T?l000003OmRWF800ol0003o8]dRob;M8P0:ob;M8P03o`000?lWf2Oo9mPW00Wo9mPW00?o0000odFj
AOm5^TD01?m5^TD00ol0003o?<<locc3?008occ3?0;o000000?oHYeRo`000?nZEJX01onZEJX00ol0
003okA;]ondBk@09ondBk@04o`000?oQ7^7o0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?oa3_7ol@ka
00Wol@ka00?o0000om4^dOoA;]402?oA;]400ol0003oT6n@o`00000=of:MHP03o`000?lRgB;o8]dR
00_o8]dR00?o0000obOH9olWf2L02?lWf2L00ol0003oAKY5odFjA@06odFjA@03o`000?ll`cco?<<l
00Go?<<l0_l00003of:MHP03o`000?nZEJ[oZUFZ00KoZUFZ00?o0000ondBkOo]4^d02_o]4^d00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003ol@kaoo4>l@07oo4>l@03o`000?oA;]7odBkA00[odBkA00?o0000of:MH_mR
WF803?mRWF800ol0003o8]dRob;M8P0<ob;M8P03o`000?lWf2Oo9mPW00Ko9mPW00?o0000odFjAOm5
^TD02?m5^TD00ol0003o?<<locc3?002occ3?0;o00001_mRWF800ol0003oZUFZojYEZP05ojYEZP03
o`000?o]4^gokA;]00[okA;]00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oa3_7ol@ka00Gol@ka
00?o0000om4^dOoA;]403?oA;]42o`0000coHYeR00?o0000ob;M8_lRgB803OlRgB800ol0003o9mPW
obOH9`04obOH9`03o`000?m5^TGoAKY500[oAKY500Co0000occ3??l0003o00002?mRWF800ol0003o
ZUFZojYEZP06ojYEZP03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_oa3_400ol0003odBkAom4^d@0=om4^d@03o`000?n=LXgo000000;o00002?mRWF800ol0003o8]dR
ob;M8P0?ob;M8PKo00003_m5^TD00ol0003oHYeRof:MHP08of:MHP03o`000?nZEJ[oZUFZ00KoZUFZ
00?o0000ondBkOo]4^d02Oo]4^d00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo@;m?od2oCom0_d
0_l0000?om4^d@03o`000?n=LXgoSG:=00?oSG:=0ol00005of:MHP;o00004?lRgB801_l0003o7n0O
oaoP7ol0003o5nPGo`0000koAKY500?o0000of:MH_mRWF802OmRWF800ol0003oZUFZojYEZP05ojYE
ZP03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003o
dBkAom4^d@0=om4^d@03o`000?n=LXgoSG:=00KoSG:=0ol000001?mRWF;o0000oc_4>olka3/3o`00
00co8]dR00Go0000oaoP7olOh1oo7n0Oo`000002oaOX5`03o`000?m5^TGoAKY500_oAKY500?o0000
of:MH_mRWF802OmRWF800ol0003oZUFZojYEZP06ojYEZP03o`000?o]4^gokA;]00SokA;]0_l0000A
ood2o@?o000000?oo@;mo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003om0_doo@;m004oo@;m0oo00003?n=LXd00ol0003o>l@koc_4>`04oc_4
>`?o00002?lRgB800ol0003o7n0OoaoP7`02oaoP7`05o`000?lGj1Oo5nPGoaOX5ol000003?m5^TD0
0ol0003oHYeRof:MHP09of:MHP03o`000?nZEJ[oZUFZ00GoZUFZ3?l00002ooL8m`;o00003Oom0_d2
o`0000Goo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003om0_doo@;m005oo@;m003o`000?oD:mCoe2_D00_oe2_D00?o0000oheb
SOn=LXd02_n=LXd00ol0003o>l@koc_4>`07oc_4>`;o00001OlRgB800ol0003o7n0OoaoP7`03oaoP
7`03o`000?lGj1Oo5nPG00;o5nPG00?o0000odFjAOm5^TD02Om5^TD00ol0003oHYeRof:MHP0:of:M
HP03o`000?nZEJ[oZUFZ00?oZUFZ00?o0000onHIi_oV6NH02OoV6NH00ol0003om`SgooL8m`02ooL8
m`;o00002Oom0_d2o`0000Ooo@;m00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m006oo@;m003o`000?oD:mCoe2_D00[o
e2_D00?o0000ohebSOn=LXd02on=LXd00ol0003o>l@koc_4>`09oc_4>`?o000000?o8]dRo`000?lO
h1l01OlOh1l00ol0003o5nPGoaOX5`03oaOX5`03o`000?m5^TGoAKY500SoAKY53_l00003ojYEZP;o
00002ooV6NH00ol0003om`SgooL8m`05ooL8m`03o`000?om0_goo@;m00?oo@;m0ol00009ood2o@03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo@;m?od2o@01Ood2o@00ol0003og2?Lo`00000;om@[e003o`000?n=LXgoSG:=00[oSG:=
0_l0000>oc_4>`03o`000?lOh1oo7n0O00Go7n0O00?o0000oaOX5olGj1L00olGj1L00ol0003oAKY5
odFjA@08odFjA@03o`000?nWF:OoYeRW00_oYeRW00?o0000ojYEZ_l000003OoV6NH00ol0003om`Sg
ooL8m`06ooL8m`;o000000?oo@;mo`000?l000003Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00Kom0_d00Co
0000om`Sg?oL8mco00002_oD:m@00ol0003oSG:=ohebS@09ohebS@03o`000?mVVFKo000000ko>l@k
00?o0000oaoP7olOh1l01OlOh1l00ol0003o5nPGoaOX5`04oaOX5`03o`000?m5^TGoAKY500KoAKY5
00?o0000ojMHYonWF:L03OnWF:L00ol0003oiQWVonHIiP0<onHIiP03o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000om`Sg?oL8m`00_oL
8m`00ol0003oe2_Dom@[e006om@[e003o`000?n=LXgoSG:=00SoSG:=0_l00003ofJIIP03o`000?lk
a3_o>l@k00_o>l@k00?o0000oaoP7olOh1l01OlOh1l00ol0003o5nPGoaOX5`05oaOX5`03o`000?m5
^TGoAKY500GoAKY500?o0000ojMHYonWF:L03OnWF:L00ol0003oiQWVonHIiP0;onHIiP03o`000?og
2?Oom`Sg00Wom`Sg00?o0000ood2oOom0_d03Oom0_d00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000
om`Sg?oL8m`00ooL8m`00ol0003oe2_Dom@[e005om@[e003o`000?n=LXgoSG:=00OoSG:=00?o0000
ofJII_mVVFH00omVVFH00ol0003o>l@koc_4>`0:oc_4>`03o`000?lOh1oo7n0O00Ko7n0O00?o0000
oaOX5olGj1L01_lGj1L00ol0003oAKY5odFjA@04odFjA@03o`000?nWF:OoYeRW00goYeRW3ol0000;
ooL8m`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000om`Sg?oL8m`01OoL8m`00ol0
003oe2_Dom@[e004om@[e003o`000?n=LXgoSG:=00GoSG:=0_l00006ofJIIP03o`000?lka3_o>l@k
00Wo>l@k0_l00008oaoP7`03o`000?lGj1Oo5nPG00Ko5nPG1Ol000000om5^TGo0000ojMHY`0?ojMH
Y`03o`000?oX5nSoj1OX00_oj1OX00?o0000ooL8moog2?L02Oog2?L00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000om`Sg?oL8m`01_oL8m`00ol0003o
e2_Dom@[e004o`0000KoSG:=00?o0000ofJII_mVVFH01omVVFH00ol0003o>l@koc_4>`05oc_4>`?o
000000?o;]4^o`000?lOh1l01olOh1l00ol0003o5nPGoaOX5`05oaOX5`03o`000?mHYeSoF:MH00?o
F:MH0_l0000?ojMHY`;o00003OoX5nP00ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00go
o@;m00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wom0_d00?o0000om`Sg?oL8m`01ooL8m`2o`0000Co]TVf00Co0000ohebSOn=LXgo
SG:=0_l0000:ofJIIP03o`000?lka3_o>l@k00;o>l@k0ol00005obkA;P03o`000?lOh1oo7n0O00Go
7n0O00?o0000oaOX5olGj1L01?lGj1L00ol0003oF:MHoeRWF006oeRWF003o`000?nWF:OoYeRW00[o
YeRW0_l00002olhacP03o`000?oX5nSoj1OX00[oj1OX00?o0000ooL8moog2?L02?og2?L00ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@01_od2o@00ol0003og2?Lom`Sg008om`Sg003o`00
0?nfBKKo]TVf00Co]TVf00?o0000ohebSOl000003?mVVFH00ol0003o>l@ko`000002o`0000Wo;]4^
00?o0000oaoP7olOh1l01?lOh1l00ol0003o5nPGoaOX5`03oaOX5`03o`000?mHYeSoF:MH00SoF:MH
1_l00004ojMHY`;o00001Oo><Lh00ol0003oj1OXonPGj009onPGj003o`000?og2?Oom`Sg00Som`Sg
00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000om`Sg?oL8m`01ooL
8m`00ol0003o]TVfokI9]P06okI9]P03o`000?mVVFKoIYUV00coIYUV00?o0000obkA;_l^dBh02_l^
dBh00ol0003o7n0OoaoP7`04oaoP7`04o`000?lGj1Oo5nPGoaOX5`;o00002omHYeP00ol0003o[5>/
ojaC[003ojaC[0Co00002?o><Lh00ol0003oj1OXonPGj008onPGj003o`000?og2?Oom`Sg00Oom`Sg
0ol0000=ood2o@03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003og2?Lom`Sg007om`Sg003o`000?nf
BKKo]TVf00Oo]TVf00?o0000ofJII_mVVFH03?mVVFH00ol0003o;]4^obkA;P0;obkA;P03o`000?lO
h1oo7n0O00?o7n0O00Co0000oaOX5olGj1Oo00003OmHYeP00ol0003o[5>/ojaC[006ojaC[003o`00
0?o><LkocS7>00OocS7>00?o0000onPGj?oX5nP01ooX5nP00ol0003om`SgooL8m`06ooL8m`04o`00
0?on0OkooP7nooh1oP;o00002oom0_d00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00;om0_d00?o0000om`Sg?oL8m`0
1_oL8m`00ol0003o]TVfokI9]P09okI9]P03o`000?mVVFKoIYUV00WoIYUV0_l0000>obkA;P?o0000
0olOh1l00ol0003o5nPGo`00000=oeRWF003o`000?n/Djco[5>/00Oo[5>/00?o0000olhac_o><Lh0
2?o><Lh:o`0000Kom`Sg0_l00006ooh1oP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000Oog2?L00?o
0000okI9]_nfBKH02_nfBKH00ol0003oIYUVofJIIP06ofJIIP;o000000?oGj1Oo`000?l^dBh02ol^
dBh2o`0000?oA;]41Ol0000>oeRWF003o`000?n/Djco[5>/00Oo[5>/00?o0000olhac_o><Lh02?o>
<Lh00ol0003okQ7^onhAkP06onhAkP03o`000?og2?Oom`Sg00?om`Sg00?o0000ooh1o_on0Oh01oon
0Oh2o`0000Soo@;m00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003ojaC[on/Dj`03on/Dj`Co00000_oL8m`00ol0003o]TVfokI9]P0;
okI9]P03o`000?mVVFKoIYUV00?oIYUV0ol00004oenPG`03o`000?l^dBko;]4^00Oo;]4^0_l00008
odBkA003o`000?mHYeSoF:MH00goF:MH00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003ocS7>olhacP07
olhacP03o`000?o^4NkokQ7^00OokQ7^0ol000000oog2?Oo0000ooh1oP0;ooh1oP;o00001Oom0_d0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o[5>_ojaC[00OojaC[0_l0000?okI9]P03o`000?mVVFKoIYUV00;o00002?mOX5l00ol0
003o;]4^obkA;P05obkA;P03o`000?m4^dCoA;]400SoA;]400?o0000oeRWF?mHYeP03OmHYeP00ol0
003o[5>/ojaC[008ojaC[003o`000?o><LkocS7>00KocS7>00?o0000onhAk_o^4Nh02?o^4Nh01?l0
003on0OhooP7n?l0000?ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003ojaC[on/Dj`09on/D
j`03o`000?nfBKKo]TVf00ko]TVf0_l0000;oenPG`03o`000?l^dBko;]4^00;o;]4^0_l0000;odBk
A003o`000?mHYeSoF:MH00goF:MH00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003ocS7>olhacP06olha
cP03o`000?o^4NkokQ7^00OokQ7^00Go0000ooP7n?oh1oSon0Oho`00000@ooh1oP;o000000?oo@;m
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ojaC[on/Dj`0:on/Dj`03o`000?nfBKKo]TVf00go]TVf0_l0000<oenPG`04o`000?l^dBko0000
o`0000goA;]400?o0000oeRWF?mHYeP03?mHYeP00ol0003o[5>/ojaC[009ojaC[003o`000?o><Lko
cS7>00KocS7>00?o0000onhAk_o^4Nh01_o^4Nh00ol0003on0OhooP7n003ooP7n003o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003ojaC[on/Dj`0:on/Dj`03o`000?nfBKKo]TVf00co]TVf00Co0000oj]D
Zon[E:_o00003?mOX5l00ol0003oA;]4odBkA00>odBkA003o`000?mHYeSoF:MH00SoF:MH1?l0000;
ojaC[003o`000?o><LkocS7>00KocS7>00?o0000onhAk_o^4Nh01Oo^4Nh00ol0003on0OhooP7n004
ooP7n003o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003ojaC[on/Dj`0;on/Dj`03o`000?nfBKKo]TVf
00_o]TVf00?o0000oj]DZon[E:/00_n[E:/00ol0003oGj1OoenPG`09oenPG`03o`000?m4^dCoA;]4
00koA;]400Co0000oeRWF?mHYeSoF:MH1ol00003ogV6N@03o`000?n/Djco[5>/00Wo[5>/00?o0000
olhac_o><Lh01_o><Lh00ol0003okQ7^onhAkP04onhAkP03o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o[5>_ojaC[00cojaC[00?o0000okI9]_nfBKH02_nfBKH00ol0
003oZeB[oj]DZ`03oj]DZ`03o`000?mOX5ooGj1O00SoGj1O00?o0000odBkA?m4^d@03_m4^d@4o`00
00_oNHIi00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003ocS7>olhacP05olhacP03o`000?o^4NkokQ7^
00GokQ7^00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000on/Djoo[
5>/03?o[5>/7o`0000Go]TVf00?o0000oj]DZon[E:/01On[E:/00ol0003oGj1OoenPG`07oenPG`03
o`000?m4^dCoA;]400koA;]400?o0000ogV6NOmiQWT03OmiQWT00ol0003o[5>/ojaC[008ojaC[003
o`000?o><LkocS7>00CocS7>00?o0000onhAk_o^4Nh01?o^4Nh00ol0003on0OhooP7n007ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oB;M;odRgB00CodRgB
1Ol00009oj]DZ`03o`000?mOX5ooGj1O00KoGj1O00?o0000odBkA?m4^d@03_m4^d@00ol0003oNHIi
ogV6N@0=ogV6N@03o`000?n/Djco[5>/00So[5>/00Co0000olhac_o><LkocS7>1Ol00004onhAkP03
o`000?oh1oSon0Oh00Won0Oh1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=on/Dj`03o`000?oB;M;odRgB00WodRgB
0_l00009oj]DZ`03o`000?mOX5ooGj1O00KoGj1O00?o0000odBkA?m4^d@03?m4^d@00ol0003oNHIi
ogV6N@0?ogV6N@Ko00001?n/Dj`4o`0000Goj1OX0_l000000oo^4Nko0000ooP7n00;ooP7n004o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?oe2_Gom@[eooD:m@?o00002_o[5>/00ol0003o
dRgBom8]dP09om8]dP03o`000?njAK[o000000;o00001on[E:/00ol0003oGj1OoenPG`05oenPG`03
o`000?m4^dCoA;]400SoA;]41Ol0000AogV6N@03o`000?njAK[o^TFj00?o^TFj1?l0000;onPGj003
o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000ooD:mOoe2_D01Ooe2_D2o`0000OojaC[
00?o0000om8]d_oB;M802_oB;M800ol0003o^TFjokY5^P02okY5^P?o00001On[E:/00ol0003oGj1O
oenPG`04oenPG`04o`000?m4^dCoA;]4odBkA0Oo00001?m^TFh00ol0003oNHIiogV6N@0>ogV6N@03
o`000?njAK[o^TFj00Oo^TFj00?o0000onPGj?oX5nP02OoX5nP00ol0003on0OhooP7n009ooP7n003
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003om@[eooD:m@08ooD:m@;o00001?o[5>/00ol0003odRgB
om8]dP0;om8]dP03o`000?njAK[o^TFj00Go^TFj0ol00003oj]DZ`04o`000?mOX5ooGj1OoenPG`Ko
00003?m^TFh00ol0003oNHIiogV6N@0=ogV6N@03o`000?njAK[o^TFj00Oo^TFj00?o0000onPGj?oX
5nP02_oX5nP00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ooD:m@?o000000?ojaC[o`000?oB;M80
3?oB;M800ol0003o^TFjokY5^P08okY5^P?o000000CoZeB[o`000?l0003o00000_n]DZd00ol0003o
KY5^ofjAKP0=ofjAKP03o`000?miQWWoNHIi00coNHIi00?o0000okY5^_njAKX02?njAKX00ol0003o
j1OXonPGj00;onPGj003o`000?oh1oSon0Oh00Kon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
m@[e00?o0000om8]d_oB;M803?oB;M800ol0003o^TFjokY5^P0;okY5^P03o`000?n]DZgo[E:]00?o
[E:]00?o0000ofjAK_m^TFh03?m^TFh00ol0003oOH9mo`00000=ogV6N@03o`000?njAK[o^TFj00So
^TFj00?o0000onPGj?oX5nP03?oX5nP3o`0000Gon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oe2_Gom@[e00com@[e00?o0000om8]d_oB;M803?oB;M800ol0003o^TFjokY5^P0:okY5^P03o`00
0?n]DZgo[E:]00Go[E:]00?o0000ofjAK_m^TFh02_m^TFh01?l0003oOH9mogf2OOmmPWd2o`0000[o
NHIi00?o0000okY5^_njAKX02OnjAKX00ol0003oj1OXonPGj00<onPGj003o`000?oi1_Won@Ki00?o
000000?on0Oho`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000om8]d_oB;M80
3?oB;M800ol0003o^TFjokY5^P09okY5^P03o`000?n]DZgo[E:]00Ko[E:]00?o0000ofjAK_m^TFh0
2Om^TFh00ol0003oOH9mogf2O@02ogf2O@03o`000?n_D:oo000000;o00001omiQWT00ol0003o^TFj
okY5^P09okY5^P03o`000?oX5nSoj1OX00_oj1OX00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000ooD:mOoe2_D02ooe2_D00ol0003odRgBom8]dP0;om8]dP03o`000?nj
AK[o^TFj00So^TFj00?o0000ojeB[On]DZd01on]DZd00ol0003oKY5^ofjAKP08ofjAKP03o`000?mm
PWgoOH9m00?oOH9m00?o0000ojm@[on_D:l00_n_D:l2o`0000CoNHIi00?o0000okY5^_njAKX02_nj
AKX00ol0003oj1OXonPGj00:onPGj003o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?oe2_Gom@[e00[om@[e0ol0000;om8]dPKo00001?njAKX00ol0003o[E:]ojeB[@08
ojeB[@03o`000?m^TFkoKY5^00OoKY5^00?o0000ogf2OOmmPWd00ommPWd00ol0003o[e2_ojm@[`05
ojm@[`?o000000?oNHIio`000?njAKX02onjAKX00ol0003oj1OXonPGj009onPGj003o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oe2_Gom@[e00Wom@[e00?o0000on/D
joo[5>/01?l00006om8]dP03o`000?oC;=?odbcC00CodbcC1?l0000<ojeB[@03o`000?m^TFkoKY5^
00GoKY5^00?o0000ogf2OOmmPWd01?mmPWd00ol0003o[e2_ojm@[`08ojm@[`03o`000?njAK[o^TFj
00_o^TFj00?o0000onPGj?oX5nP02?oX5nP00ol0003on@KiooT6n@08ooT6n@Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?oe2_Gom@[e00Oom@[e00?o0000on/Djoo[5>/01Oo[5>/3o`0000;odRgB00?o0000om</dooC
;=<02?oC;=<00ol0003o[E:]ojeB[@0:ojeB[@03o`000?m^TFkoKY5^00CoKY5^00?o0000ogf2OOmm
PWd01OmmPWd00ol0003o[e2_ojm@[`08ojm@[`03o`000?njAK[o^TFj00Wo^TFj1?l00008onPGj003
o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[e
ooD:m@05ooD:m@03o`000?o[5>_ojaC[00WojaC[0_l0000<om</d`03o`000?n]DZgo[E:]00Wo[E:]
00?o0000ofjAK_m^TFh00om^TFh00ol0003oOH9mogf2O@05ogf2O@03o`000?n_D:oo[e2_00[o[e2_
00?o0000okY5^_njAKX01?njAKX4o`0000CohQgR00?o0000onPGj?oX5nP01?oX5nP00ol0003on@Ki
ooT6n@0:ooT6n@03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oe2_Gom@[e00?om@[e00?o0000on/Djoo[5>/02oo[
5>/00ol0003odbcCom</d`0:om</d`03o`000?n]DZgo[E:]00Wo[E:]00?o0000ofjAK_m^TFh00_m^
TFh00ol0003oOH9mogf2O@06ogf2O@03o`000?n_D:oo[e2_00[o[e2_00?o0000okY5^_njAKX01?l0
0009on8MhPKo00003?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000ooD:mOoe2_Gom@[e0_l0
000=on/Dj`03o`000?oC;=?odbcC00[odbcC00?o0000ojeB[On]DZd02On]DZd01Ol0003oKY5^ofjA
K_m^TFko000000WoOH9m00?o0000ojm@[on_D:l02on_D:l2o`0000gohQgR00?o0000ooP7n?oh1oP0
0_oh1oP00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om@[eo`00
0002oo/4n`;o00002oo[5>/00ol0003odbcCom</d`0;om</d`03o`000?n]DZgo[E:]00Wo[E:]00?o
0000ofjAK_l000002OmmPWd00ol0003o[e2_ojm@[`0<ojm@[`03o`000?oR7N;ohQgR00cohQgR00?o
0000ooP7n?oh1oP00ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on`Ckoo/4n`03oo/4n`;o00002_o[5>/00ol0003odbcCom</d`0:om</d`03o`000?n]DZgo
[E:]00So[E:]1Ol00008ogf2O@03o`000?n_D:oo[e2_00co[e2_00?o0000on8Mh_oR7N802ooR7N80
0ol0003on0OhooP7n005ooP7n003o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001ook1?/2o`0000SojaC[00?o0000om</dooC;=<02_oC;=<00ol0003o[E:]ojeB[@07ojeB
[@03o`000?nbCK;o/Tfb00?o/Tfb0ol00005ogf2O@03o`000?n_D:oo[e2_00_o[e2_00?o0000on8M
h_oR7N803?oR7N800ol0003on0OhooP7n006ooP7n003o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?on0Oko000000Won`Ck00?o0000on/Djoo[5>/01Oo[5>/2o`0000co
dbcC00?o0000ojeB[On]DZd01On]DZd00ol0003o/Tfbok9=/P07ok9=/P?o000000?oOH9mo`000?n_
D:l03On_D:l00ol0003ohQgRon8MhP0<on8MhP03o`000?oh1oSon0Oh00Kon0Oh00?o0000ooT6nOoi
1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ooh1oP03o`000?ok1?_on`Ck00Oon`Ck
0_l00004on/Dj`03o`000?oa3_7ol@ka00;o00002_oC;=<00ol0003o[E:]ojeB[@03ojeB[@;o0000
3OnbCK82o`0000go[e2_0ol0000=on8MhP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T0
1Ooi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00Son`Ck0_l0
00000oo[5>_o0000oo4>l@04oo4>l@03o`000?oC;=?odbcC00OodbcC00Co0000ojeB[On]DZgo[E:]
0_l00002omLXe`03o`000?nbCK;o/Tfb00co/Tfb3Ol00003on@Ki003o`000?oR7N;ohQgR00[ohQgR
00?o0000ooP7n?oh1oP02?oh1oP01?l0003on@KiooT6nOoi1_T4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?on0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oa3_7ol@ka00Gol@ka0_l00008om</d`03o`000?n]DZgo000000GoebSG
00?o0000ok9=/_nbCK802onbCK800ol0003o_d2ookm0_`09okm0_`03o`000?oT6nCoi1_T00;oi1_T
0_l00009on8MhP03o`000?oh1oSon0Oh00[on0Oh0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ooh1
oP0:ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000oo4>lOoa3_401ooa3_44o`0000?odbcC0ol0
0007omLXe`03o`000?nbCK;o/Tfb00[o/Tfb00?o0000okm0_ono@;l02Ono@;l00ol0003oi1_Ton@K
i004on@Ki0;o00001ooR7N800ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo4>lOoa3_402?oa3_40
1?l0003ol0o`oo0?l?o`3o03o`0000;oiaSW00?o0000omLXeooG:=L01_oG:=L00ol0003o/Tfbok9=
/P08ok9=/P03o`000?no@;oo_d2o00[o_d2o00?o0000on@Ki?oT6n@01_oT6n@00ol0003ohQgRon8M
hP04on8MhP03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003ol@kaoo4>l@08oo4>l@03o`000?o`3o3o
l0o`00Col0o`00Go0000onLHiooW6>OoiaSWo`000008omLXe`03o`000?nbCK;o/Tfb00Oo/Tfb00?o
0000okm0_ono@;l02_no@;l00ol0003oi1_Ton@Ki007on@Ki0;o00001?oR7N800ol0003on0OhooP7
n008ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003ol@kaoo4>l@08oo4>l@03o`000?o`3o3ol0o`00Col0o`00?o0000onLHiooW6>L00_oW6>L0
0ol0003oebSGomLXe`07omLXe`03o`000?nbCK;o/Tfb00Ko/Tfb00?o0000okm0_ono@;l02_no@;l0
0ol0003oi1_Ton@Ki009on@Ki005o`000?oR7N;ohQgRon8Mh_l000002Ooh1oP00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ol@ka00?o0000oo0?l?o`3o001?o`3o000ol0003oiaSWonLHi`03
onLHi`03o`000?oG:=OoebSG00OoebSG00?o0000ok9=/_nbCK801OnbCK800ol0003o_d2ookm0_`0:
okm0_`03o`000?oT6nCoi1_T00Woi1_T1?l00009ooP7n003o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ok1?_on`Ck
oo/4nol000002_oa3_400ol0003ol0o`oo0?l005oo0?l003o`000?oW6>OoiaSW00?oiaSW00?o0000
omLXeooG:=L02?oG:=L00ol0003o/Tfbok9=/P04ok9=/P03o`000?no@;oo_d2o00Wo_d2o00?o0000
on@Ki?oT6n@02?oT6n@2o`0000?on0Oh00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003ol@kaoo4>l@06oo4>l@03o`000?o`3o3ol0o`
00Gol0o`00?o0000onLHiooW6>L01?oW6>L00ol0003oebSGomLXe`09omLXe`03o`000?nbCK;o/Tfb
00;o/Tfb00?o0000okm0_ono@;l02_no@;l00ol0003oi1_Ton@Ki006on@Ki0;o00001_oh1oP8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?oa3_7ol@ka00Gol@ka00?o0000oo0?l?o`
3o001Oo`3o000ol0003oiaSWonLHi`05onLHi`03o`000?oG:=OoebSG00WoebSG00Go0000ok9=/_nb
CK;o/Tfbo`00000<okm0_`03o`000?oT6nCoi1_T00Coi1_T0_l00008ooP7n003o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo4>lOoa
3_400ooa3_400ol0003ol0o`oo0?l006oo0?l003o`000?oW6>OoiaSW00GoiaSW00?o0000omLXeooG
:=L02_oG:=L00ol0003o/Tfbo`000004o`0000Wo_d2o00?o0000on@Ki?oT6n@00_oT6n@2o`0000[o
n0Oh00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`00
0?oa3_7ol@ka00;ol@ka00?o0000oo0?l?o`3o001_o`3o000ol0003oiaSWonLHi`07onLHi`;o0000
2ooG:=L00ol0003ojQGZonXEjP03onXEjPOo00000_no@;l00ol0003oi1_Ton@Ki002o`0000_on0Oh
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/02Ook
1?/01Ol0003ol@kaoo4>lOoa3_7o000000Sol0o`00?o0000onLHiooW6>L01ooW6>L00ol0003ol`cc
o`000002o`0000SoebSG00?o0000onXEj_oZ5NX02_oZ5NX5o`0000gon0Oh00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo/4n`03o`000?oa3_7o000000Wol0o`00?o
0000onLHiooW6>L01_oW6>L00ol0003ol`ccoo<<l`03oo<<l`?o00001?oG:=L00ol0003ojQGZonXE
jP0=onXEjP03o`000?oh1oSon0Oh00gon0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on`Ck00?o0000oo0?l?o`3o001oo`3o000ol0003oiaSWonLHi`07
onLHi`03o`000?oc3??ol`cc00Kol`cc0ol000000ooG:=Oo0000onXEjP0>onXEjP03o`000?oh1oSo
n0Oh00con0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009oo/4
n`03o`000?o`3o3ol0o`00;ol0o`1_l00008onLHi`03o`000?oc3??ol`cc00[ol`cc00?o0000onXE
j_oZ5NX03ooZ5NX00ol0003on0OhooP7n00:ooP7n0;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007oo/4n`Go00001_oh1oP00ol0003oiaSWonLHi`05onLHi`03o`000?oc3??ol`cc00[o
l`cc00?o0000onXEj_oZ5NX03ooZ5NX00ol0003on0OhooP7n007ooP7n0?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005oo/4n`03o`000?oh1oSon0Oh00Won0Oh00?o0000onLHiooW
6>L00ooW6>L00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oZ5N[ojQGZ00oojQGZ00?o0000ooP7n?oh
1oP01Ooh1oP2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on`Cko`000?l00000
3Ooh1oP00ol0003oiaSWonLHi`02onLHi`03o`000?oc3??ol`cc00_ol`cc5?l00004ooP7n0;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooP7n004o`000?oW6>OoiaSWo`0000kol`cc
00?o0000ooT6nOoi1_T04?oi1_T00ol0003on0Oho`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_oh1oP00ol0003oiaSWo`00000>oo<<l`03o`00
0?oi1_Won@Ki017on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n00=ooP7n003o`000?oc3??ol`cc00Wol`cc1Ol0
000BooT6n@;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003on0OhooP7n00<ooP7n003o`000?oc3??ol`cc00;ol`cc1ol00004ood2o@03o`000?oi1_Wo
n@Ki00oon@Ki00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?oh1oSon0Oh00con0Oh1?l0000<ood2o@03o`000?oi1_Won@Ki00con@Ki0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooP7n?oh1oP03?oh1oP00ol0003oo@;mood2o@0=ood2o@03o`000?oi1_Won@Ki00_o
n@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003on0OhooP7n00:ooP7n003o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi
1_T02Ooi1_T2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oo@;m
ood2o@0?ood2o@03o`000?oi1_Won@Ki00Kon@Ki0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aood2o@?o00001_oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo@;mood2o@0>ood2o@05o`000?on0OkooP7nooh1o_l000000ooi1_T2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@0=ood2o@03o`000?on0Oko
oP7n00?ooP7n00?o0000ooT6nOl000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ood2
oOom0_d02oom0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2
o@07ood2o@;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go
o@;m00Goo@;m00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom0_d01?om0_d00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
o@;mood2o@03ood2o@03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?om0_goo@;mo`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool01_l00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00So003o0_ooo`08o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000co003o0_ooo`08o`00o`;oool01ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00co003o0_ooo`08o`00o`;oool01ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`001Ol00?l<oooo00Go
003o0_ooo`07o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00Go003o3?ooo`05o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00Go003o00?oool0o`00ool00?l01?l00?l2oooo00So003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`06o`00o`03oooo0?l00?oo003o00?o003o0_ooo`08o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool01ol00?l00oooo`3o003oo`00o`02o`00o`;oool0
2?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00?o003o0_oo
o`08o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool02?l00?l01?ooo`3o003oo`00ool00?l2oooo00So003o0_oo
o`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00Wo003o00?oool0o`00ool00?l00_ooo`08
o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo
00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0:o`00o`04oooo0?l00?ooool0
oooo00So003o0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1
ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00[o003o00Coool0o`00
ooooo`3oool02?l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool0
06So003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00
ool00?l02?l00?l3oooo00So003o0_ooo`07o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo
0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko
003o1Oooo`09o`00o`;oool01_l00?l4oooo00So003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo
003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0To`00o`;oool0
2?l00?l2oooo00Wo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(420) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.994 .006 .994 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.994 .006 .994 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.978 .022 .978 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.993 .007 .993 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.979 .021 .979 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.971 .029 .971 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.958 .042 .958 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.988 .012 .988 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.953 .047 .953 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.994 .006 .994 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.898 .102 .898 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.914 .086 .914 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.834 .166 .834 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.941 .059 .941 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.987 .013 .987 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.99 .01 .99 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.977 .023 .977 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.695 .305 .695 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.952 .048 .952 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.877 .123 .877 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.872 .128 .872 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.899 .101 .899 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.933 .067 .933 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.96 .04 .96 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.849 .151 .849 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.928 .072 .928 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.77 .23 .77 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.956 .044 .956 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.923 .077 .923 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.873 .127 .873 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.923 .077 .923 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.75 .25 .75 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.946 .054 .946 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.869 .131 .869 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.958 .042 .958 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.793 .207 .793 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.461 .539 .461 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.545 .455 .545 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.983 .017 .983 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.983 .017 .983 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.924 .076 .924 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.994 .006 .994 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.825 .175 .825 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.837 .163 .837 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.515 .485 .515 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.5 .5 .5 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.401 .599 .401 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.804 .196 .804 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.829 .171 .829 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.803 .197 .803 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.721 .279 .721 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.971 .029 .971 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.617 .383 .617 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.945 .055 .945 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.895 .105 .895 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.518 .482 .518 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.433 .567 .433 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.733 .267 .733 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.157 .843 .157 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.168 .832 .168 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.245 .755 .245 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.578 .422 .578 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.564 .436 .564 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.941 .059 .941 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.199 .801 .199 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.207 .793 .207 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.835 .165 .835 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.971 .029 .971 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.993 .007 .993 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.343 .657 .343 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.415 .585 .415 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.742 .258 .742 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.993 .007 .993 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.772 .228 .772 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.394 .606 .394 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.683 .317 .683 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.132 .868 .132 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.569 .431 .569 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.387 .613 .387 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.975 .025 .975 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.056 .944 .056 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.104 .896 .104 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.91 .09 .91 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.039 .961 .039 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.023 .977 .023 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.686 .314 .686 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.936 .064 .936 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.236 .764 .236 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.057 .943 .057 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.538 .462 .538 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.117 .883 .117 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.24 .76 .24 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.955 .045 .955 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.009 .991 .009 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.137 .863 .137 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.192 .808 .192 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.85 .15 .85 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.272 .728 .272 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.343 .657 .343 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.004 .996 .004 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.013 .987 .013 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.063 .937 .063 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.009 .991 .009 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.445 .555 .445 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.708 .292 .708 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.993 .007 .993 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.837 .163 .837 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.187 .813 .187 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.157 .843 .157 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.509 .491 .509 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.977 .023 .977 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.13 .87 .13 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.154 .846 .154 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.682 .318 .682 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.099 .901 .099 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.024 .976 .024 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.92 .08 .92 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.976 .024 .976 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.694 .306 .694 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.758 .242 .758 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.083 .917 .083 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.923 .077 .923 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.354 .646 .354 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.475 .525 .475 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.075 .925 .075 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.275 .725 .275 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.483 .517 .483 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.993 .007 .993 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.993 .007 .993 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.954 .046 .954 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.107 .893 .107 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.121 .879 .121 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.03 .97 .03 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.898 .102 .898 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.243 .757 .243 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.972 .028 .972 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.186 .814 .186 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.176 .824 .176 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.188 .812 .188 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.739 .261 .739 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.789 .211 .789 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.683 .317 .683 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.018 .982 .018 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.251 .749 .251 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.399 .601 .399 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.663 .337 .663 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.89 .11 .89 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.994 .006 .994 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.965 .035 .965 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.24 .76 .24 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.483 .517 .483 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.184 .816 .184 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.876 .124 .876 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.815 .185 .815 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.993 .007 .993 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.677 .323 .677 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.912 .088 .912 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.97 .03 .97 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.192 .808 .192 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.321 .679 .321 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.958 .042 .958 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.188 .812 .188 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.75 .25 .75 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.555 .445 .555 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.59 .41 .59 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.399 .601 .399 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.93 .07 .93 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.906 .094 .906 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.915 .085 .915 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.936 .064 .936 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.492 .508 .492 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.976 .024 .976 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.86 .14 .86 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.422 .578 .422 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.482 .518 .482 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.994 .006 .994 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.724 .276 .724 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.635 .365 .635 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.993 .007 .993 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.973 .027 .973 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.885 .115 .885 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.969 .031 .969 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.509 .491 .509 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.95 .05 .95 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.843 .157 .843 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.785 .215 .785 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.994 .006 .994 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.758 .242 .758 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.652 .348 .652 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.781 .219 .781 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.989 .011 .989 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.639 .361 .639 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.991 .009 .991 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.733 .267 .733 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.993 .007 .993 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.852 .148 .852 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.919 .081 .919 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.871 .129 .871 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.928 .072 .928 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.948 .052 .948 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.866 .134 .866 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.73 .27 .73 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.852 .148 .852 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.915 .085 .915 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.949 .051 .949 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.935 .065 .935 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.945 .055 .945 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.99 .01 .99 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.883 .117 .883 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.972 .028 .972 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.992 .008 .992 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.978 .022 .978 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.96 .04 .96 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.893 .107 .893 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.972 .028 .972 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.947 .053 .947 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.946 .054 .946 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.963 .037 .963 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.994 .006 .994 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.992 .008 .992 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.993 .007 .993 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.992 .008 .992 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.993 .007 .993 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003om`SgooL8mol0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooL8moog2?L00_og2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`06ooL8m`03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooL8moog2?L02?og2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oi1_Wo0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com`Sg00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooT6n@03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om0_doo@;m005oo@;m003o`000?og
2?Oom`Sg00_om`Sg0ol00003ooD:m@03o`000?on0OkooP7n00cooP7n0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003om0_doo@;m006
oo@;m003o`000?og2?Oom`Sg00[om`Sg00?o0000ooD:mOoe2_D01?oe2_D00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oc3??ol`ccoo<<l`;o00002_om0_d2o`000003oo8=l_l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?om0_go
o@;m00Woo@;m00?o0000ooX5n_l000002oon0Oh00ol0003om0_doo@;m006oo@;m003o`000?og2?Oo
m`Sg00Wom`Sg00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP08ooh1oP03o`000?oc3??o
l`cc00Col`cc0_l00005ood2o@?o00001?ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooT6n@03o`000?om0_goo@;m00Ooo@;m0_l00003ooX5
nP03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?od2o@01ood2o@00ol0003om`SgooL8m`09ooL8
m`03o`000?oe2_Gom@[e00Oom@[e00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Wol`cc0_l000000oom
0_go0000o`000007oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooT6nOoi
1_T02?oi1_T00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on
0Oh01oon0Oh00ol0003om0_doo@;m008oo@;m003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooD:mOoe
2_D02Ooe2_D00ol0003ooP7nooh1oP03ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000oo8=l_ob
3O801oob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0Oho`000005ooh1oP;o00002ooi1_T2o`0000Koo@;m
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?od2oCom0_d00Som0_d
00?o0000ooL8moog2?L01_og2?L00ol0003om@[eooD:m@0;ooD:m@05o`000?on0OkooP7nooh1o_l0
00003_oc3?<00ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oh1oSon0OhooP7n?l0
00000oon0Oh00ol0003on@KiooT6n@0:ooT6n@04o`000?o_4>ooka3_o`0000?oo@;m0_l00008ooX5
nP03o`000?on0OkooP7n00KooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003om`SgooL8m`05ooL8
m`03o`000?oe2_Gom@[e00com@[e00?o0000ooh1o_l000003ooc3?<00ol0003olPgboo8=lP08oo8=
lP03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7n003ooP7n003o`000?on0Oko000000_o
n@Ki0_l00004onl@k`03o`000?om0_go000000_onPGj00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m0_doo@;m009oo@;m003o`000?og2?Oom`Sg00Com`Sg00?o0000ooD:mOoe2_D03_oe2_D00ol0003o
l`ccoo<<l`0>oo<<l`03o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooP7n?oh1oP0
1?oh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?o_4>ooka3_00Goka3_00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003ooP7nooh1oP05ooh1oP03o`000?od2oCom0_d00[om0_d00?o0000ooL8moog2?L0
0oog2?L00ol0003om@[eooD:m@0>ooD:m@03o`000?oc3??ol`cc00gol`cc00?o0000oo8=l_ob3O80
2_ob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7
n005ooP7n003o`000?oi1_Won@Ki00Oon@Ki0_l00008onl@k`03o`000?oj1O[onPGj00_onPGj00?o
0000ooh1o_on0Oh01?on0Oh00ol0003om0_doo@;m00:oo@;m004o`000?og2?Oom`SgooL8m`?o0000
3ooe2_D00ol0003ol`ccoo<<l`0>oo<<l`03o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T01?oi1_T2o`0000_oka3_1?l0
0009ooX5nP03o`000?on0OkooP7n00?ooP7n00?o0000oo@;m?od2o@02ood2o@01?l0003om`Sgo`00
0?l00003on0Oh0;o00003?oe2_D2o`00013ol`cc00?o0000oo8=l_ob3O802oob3O800ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003on0Oh
ooP7n007ooP7n003o`000?oi1_Won@Ki00?on@Ki00?o0000onl@koo_4>l02oo_4>l01?l0003oeRWF
omHYe_oF:MH5o`0000GonPGj00?o0000ooh1o_on0Oh00_on0Oh00ol0003om0_doo@;m00<oo@;m003
o`000?oP7n3oh1oP00Goh1oP0_l00008ooD:m@;o00000_oL8m`00ol0003ol`ccoo<<l`0=oo<<l`03
o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n009ooP7n003o`000?oi1_Won@Ki00;o0000
3Oo_4>l00ol0003oeRWFomHYeP07omHYePKo00000_on0Oh4o`0000gom0_d00?o0000on0Oh?oP7n00
1ooP7n02o`0000Gom@[e00?o0000om`Sg?oL8m`00ooL8m`00ol0003ol`ccoo<<l`0<oo<<l`03o`00
0?ob3O;olPgb00colPgb00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o
0000ooT6nOl000003oo_4>l00ol0003oeRWFomHYeP0<omHYeP?o00001?o/4n`3o`0000Wom0_d00?o
0000on0Oh?oP7n002_oP7n02o`000003ooD:mOl0003o000000Oog2?L00?o0000oo<<looc3?<02ooc
3?<00ol0003olPgboo8=lP0<oo8=lP03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oh1oSon0Oh00_on0Oh00?o0000
onl@koo_4>l03_o_4>l00ol0003oeRWFomHYeP0=omHYeP03o`000?o/4ncok1?/00Kok1?/0ol00005
oo@;m003o`000?oP7n3oh1oP00goh1oP00?o0000om`Sg?oL8m`02?oL8m`00ol0003ol`ccoo<<l`09
oo<<l`03o`000?ob3O;olPgb00golPgb00Co0000ood2oOom0_goo@;m1Ol00003ooD:m@03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooP7n?oh1oP02ooh1oP2o`0000ooka3_00?o0000omHYe_oF:MH03OoF:MH00ol0003ok1?/on`Ck00:
on`Ck0?o000000?om0_do`000?oP7n003ooP7n000ol0003og2?Lom`Sg009om`Sg003o`000?oc3??o
l`cc00Sol`cc00?o0000oo8=l_ob3O803_ob3O83o`0000Som@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oh1oSon0Oh00Son0Oh0ol000000ooU
6^Go0000onl@k`0>onl@k`03o`000?oF:MKoeRWF00goeRWF00?o0000on`Ck?o/4n`03Oo/4n`00ol0
003oh1oPon0Oh00?on0Oh003o`000?oL8mcog2?L00[og2?L2ol0000;oo8=lPGo00003?oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003om@[eo`000?on0Oko0000
00Son0Oh0ol00005onDJi@03o`000?o_4>ooka3_00coka3_00?o0000omHYe_oF:MH03OoF:MH00ol0
003ok1?/on`Ck00=on`Ck0;o00004?oP7n000ol0003og2?Lom`Sg00:om`Sg003o`000?oG:=OoebSG
00OoebSG00?o0000oo8=l_ob3O800_ob3O87o`0000CogB;M00?o0000ooD:mOoe2_D02_oe2_D00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003om@[eooD:mOoe2_D2o`00
00Gon0Oh0ol00009onDJi@;o00002oo_4>l00ol0003oeRWFomHYeP0=omHYeP03o`000?o/4ncok1?/
00gok1?/00Co0000olTfbOo9=/Wo00003ooP7n000ol0003og2?Lom`Sg009om`Sg003o`000?oG:=Oo
ebSG00WoebSG1?l0000;omdRg@03o`000?oe2_Gom@[e00[om@[e00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000ooD:mOoe2_D01?oe2_D00ol0003on0Oho`000002o`00
00coiA[U00Co0000olDjaOl0003o00002Oo_4>l00ol0003oeRWFomHYeP0=omHYeP03o`000?o/4nco
k1?/00gok1?/00Go0000olTfbOo9=/WobCK9o`00000=on0Oh003o`000?oL8mcog2?L00[og2?L00?o
0000omLXeooG:=L02OoG:=L00ol0003ogB;MomdRg@0<omdRg@03o`000?oe2_Gom@[e00[om@[e00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooD:mOoe2_D01_oe2_D0
0ol0003oiA[UonDJi@0<onDJi@03o`000?o5>/GoaC[500;oaC[50_l00007onl@k`03o`000?oF:MKo
eRWF00coeRWF00?o0000on`Ck?o/4n`03Oo/4n`00ol0003obCK9olTfb@03olTfb@03o`000?oP7n3o
h1oP00[oh1oP00?o0000om`Sg?oL8m`02_oL8m`00ol0003oebSGomLXe`09omLXe`03o`000?oM8]go
gB;M00cogB;M00?o0000ooD:mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003om@[eooD:m@06ooD:m@03o`000?oU6^GoiA[U00_oiA[U00?o0000olDj
aOo5>/D01Oo5>/D00ol0003oka3_onl@k`03onl@k`03o`000?oF:MKoeRWF00goeRWF00?o0000on`C
k?o/4n`03Oo/4n`00ol0003obCK9olTfb@04olTfb@03o`000?oP7n3oh1oP00Woh1oP00?o0000om`S
g?oL8m`02OoL8m`00ol0003oebSGomLXe`0:omLXe`03o`000?oM8]gogB;M00cogB;M00?o0000ooD:
mOoe2_D02ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m@[eooD:m@07ooD:m@03o`000?oU6^GoiA[U00_oiA[U00?o0000olDjaOo5>/D01_o5>/D2o`0000?o
ka3_00?o0000omHYe_oF:MH03OoF:MH00ol0003ok1?/on`Ck00<on`Ck003o`000?o9=/WobCK900Ko
bCK900?o0000on0Oh?oP7n002?oP7n000ol0003og2?Lom`Sg009om`Sg003o`000?oG:=OoebSG00[o
ebSG00?o0000omdRgOoM8]d03?oM8]d00ol0003om@[eooD:m@0;ooD:m@03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000ooD:mOoe2_D02?oe2_D00ol0003oiA[UonDJi@0:onDJi@03o`00
0?o5>/GoaC[500WoaC[50_l000000oo_4>oo0000omHYeP0<omHYeP?o00003_o/4n`00ol0003obCK9
olTfb@07olTfb@03o`000?oP7n3oh1oP00Ooh1oP00?o0000om`Sg?oL8m`02OoL8m`00ol0003oebSG
omLXe`0;omLXe`03o`000?oM8]gogB;M00cogB;M00?o0000ooD:mOoe2_D02_oe2_D00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003oiA[UonDJ
i@09onDJi@03o`000?o5>/GoaC[500_oaC[500?o0000omHYe_oF:MH02_oF:MH2o`0000?o[U6^00?o
0000on`Ck?o/4n`02_o/4n`00ol0003obCK9olTfb@09olTfb@03o`000?oP7n3oh1oP00Koh1oP00?o
0000om`Sg?oL8m`02?oL8m`00ol0003oebSGomLXe`0<omLXe`03o`000?oM8]gogB;M00cogB;M00?o
0000ooD:mOoe2_D02_oe2_D00ol0003ooP7nooh1oP04ooh1oPCo00000oom0_d00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onDJiOoU6^D02?oU6^D0
0ol0003oaC[5olDja@0<olDja@03o`000?oF:MKoeRWF00SoeRWF0_l00006ojiA[P;o00002_o/4n`0
0ol0003obCK9olTfb@0:olTfb@03o`000?oP7n3oh1oP00Goh1oP00?o0000om`Sg?oL8m`02?oL8m`0
0ol0003oebSGomLXe`0<omLXe`03o`000?oM8]gogB;M00cogB;M00?o0000ooD:mOoe2_D02ooe2_D0
0ol0003ooP7no`000003o`0000Soo@;m00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
ooD:m@03o`000?oU6^GoiA[U00OoiA[U00?o0000olDjaOo5>/D03_o5>/D00ol0003oeRWFomHYeP04
omHYeP?o00002_n^DJh00ol0003ok1?/on`Ck007on`Ck003o`000?o9=/WobCK900_obCK900?o0000
on0Oh?oP7n000ooP7n000ol0003og2?Lom`Sg009om`Sg003o`000?oG:=OoebSG00coebSG00?o0000
omdRgOoM8]d03?oM8]d00ol0003om@[eooD:m@0;ooD:m@;o00003Oom0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003om@[eooD:m@0<ooD:m@03o`000?oU6^GoiA[U00OoiA[U00?o0000olDjaOo5>/D03oo5>/D01?l0
003oeRWFomHYe_oF:MH2o`0000ko[U6^0_l00006on`Ck003o`000?o9=/WobCK900gobCK900?o0000
on0Oh?oP7n000_oP7n000ol0003og2?Lom`Sg008om`Sg003o`000?oG:=OoebSG00coebSG0ol0000=
omdRg@03o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oom@[e00?o0000onDJiOoU6^D01_oU6^D00ol0003oaC[5olDja@0@olDja@Co00004_n^DJh00ol0
003ok1?/on`Ck003on`Ck003o`000?o9=/WobCK900kobCK900Go0000on0Oh?oP7n3oh1oPo`000005
om`Sg0Oo00003?oG:=L01Ol0003o^dBkok]4^onkA;_o000000cogB;M00?o0000ooD:mOoe2_D02?oe
2_D3o`0000ooo@;m00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oom@[e00?o0000onDJiOoU6^D01_oU6^D00ol0003oaC[5olDja@0=
olDja@?o000000CoTFjAo`000?l0003o00004on^DJh2o`0000;ok1?/00?o0000olTfbOo9=/T04?o9
=/T00ol0003oh1oPo`000006o`0000Oo^DJi00?o0000omLXeooG:=L02?oG:=L00ol0003o^dBkok]4
^`03ok]4^`;o00002?oM8]d3o`0000Kom@[e1?l00002oo8=lP03o`000?om0_goo@;m00koo@;m00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003onPGjo`000?oO8=l3o`0000gom@[e00?o0000onDJiOoU6^D01?oU6^D00ol0003oaC[5olDj
a@0;olDja@?o00000onAKY401Ol0003oRGJ9o`000?mGZ5Oo000001Co[U6^00?o0000on`Ck?l00000
4oo9=/T00ol0003o^DJiokU6^@0=okU6^@03o`000?oG:=OoebSG00GoebSG0_l00008ok]4^`03o`00
0?oM8]gogB;M00Go00000ooJ9MX00ol0003om@[eooD:m@03o`0000OolPgb00?o0000ood2oOom0_d0
3Oom0_d00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oj1O[onPGjo`0000Cogb3O0ol0000:ooD:m@03o`000?oU6^GoiA[U00?oiA[U
00?o0000olDjaOo5>/D02Oo5>/D3o`0000GoTFjA00Co0000ohUfROn9MXWo00000_mGZ5L00ol0003o
[U6^ojiA[P0BojiA[P03o`000?o9=/WobCK901;obCK900?o0000okU6^OniA[T03_niA[T00ol0003o
ebSGomLXe`03omLXe`03o`000?nkA;_o^dBk00Wo^dBk0_l00009omXUfP;o00002_ob3O800ol0003o
o@;mood2o@0=ood2o@03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooX5n_oj1O[onPGjo`000007omlPg`;o00001ooe2_D5o`0000;o
iA[U00?o0000olDjaOo5>/D01_o5>/D3o`0000SoTFjA00Co0000ohUfROn9MXWo00000omGZ5L00ol0
003o[U6^ojiA[P0AojiA[P03o`000?o9=/WobCK9017obCK900?o0000okU6^OniA[T04?niA[T01Ol0
003oebSGomLXeooG:=Oo000000co^dBk00?o0000omXUf_oJ9MX02?oJ9MX00ol0003olPgboo8=lP0:
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000ConPGj00?o0000omlPgooO8=l01ooO8=l3o`00
0004ooD:mOl0003o0000o`0000GocC;=0_l00006olDja@?o00002_nAKY401Ol0003oRGJ9ohUfROn9
MXWo000000CoEjQG00?o0000ojiA[_n^DJh04?n^DJh00ol0003obCK9olTfb@0AolTfb@03o`000?ni
A[Wo^DJi017o^DJi00?o0000omLXeol000003OnkA;/00ol0003ofRGJomXUfP08omXUfP03o`000?ob
3O;olPgb00[olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000
omlPgooO8=l02_oO8=l00ol0003ocC;=oldbc@08oldbc@03o`000?o5>/GoaC[500?o00003OnAKY40
1Ol0003oRGJ9ohUfROn9MXWo000000GoEjQG00?o0000ojiA[_n^DJh03on^DJh00ol0003obCK9olTf
b@0AolTfb@03o`000?niA[Wo^DJi01;o^DJi00?o0000ok]4^onkA;/03?nkA;/00ol0003ofRGJomXU
fP08omXUfP03o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX0
0ol0003ogb3OomlPg`0:omlPg`03o`000?o=</gocC;=00WocC;=0_l0000?oi5^T@03o`000?n9MXWo
RGJ900;oRGJ900?o0000oeNXEomGZ5L01?mGZ5L00ol0003o[U6^ojiA[P0=ojiA[P?o00004Oo9=/T0
0ol0003o^DJiokU6^@0CokU6^@03o`000?nkA;_o^dBk00_o^dBk00?o0000omXUf_oJ9MX02OoJ9MX0
0ol0003olPgboo8=lP0;oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ooh1oP;o00002?oj1OX0
0ol0003ogb3OomlPg`0:omlPg`03o`000?o=</gocC;=00WocC;=00?o0000oi5^TOnAKY403OnAKY40
0ol0003oRGJ9ohUfR@03ohUfR@03o`000?mGZ5OoEjQG00GoEjQG00?o0000ojiA[_n^DJh02_n^DJh2
o`0000?oNHIi00?o0000olTfbOo9=/T03_o9=/T00ol0003o^DJiokU6^@0CokU6^@03o`000?nkA;_o
^dBk00_o^dBk00?o0000omXUf_oJ9MX02OoJ9MX00ol0003olPgboo8=lP0;oo8=lP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000GooP7n00?o0000ooX5n_oj1OX01ooj1OX2o`0000_ogb3O00?o0000oldb
cOo=</d02oo=</d00ol0003oTFjAoi5^T@0<oi5^T@03o`000?n9MXWoRGJ900?oRGJ900?o0000oeNX
EomGZ5L01_mGZ5L00ol0003o[U6^ojiA[P07ojiA[P;o00001_miQWT2o`0000kobCK900?o0000okU6
^OniA[T04oniA[T00ol0003o^dBkok]4^`0;ok]4^`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000oo8=
l_ob3O803?ob3O800ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ooh1o_on0OkooP7no`000009ooX5
nP03o`000?oc3??o000000_ogb3O00?o0000oldbcOo=</d02oo=</d00ol0003oTFjAoi5^T@0;oi5^
T@03o`000?n9MXWoRGJ900CoRGJ900?o0000oeNXEomGZ5L01omGZ5L00ol0003o[U6^ojiA[P05ojiA
[P03o`000?miQWWoNHIi00SoNHIi00?o0000olTfbOo9=/T02_o9=/T00ol0003o^DJiokU6^@0DokU6
^@03o`000?nkA;_o^dBk00_o^dBk00?o0000omXUf_oJ9MX02OoJ9MX00ol0003olPgboo8=lP0<oo8=
lP03o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7no`000009ooX5nP04o`000?oc3??ol`cco`00
00_ogb3O00?o0000oldbcOo=</d02oo=</d00ol0003oTFjAoi5^T@0;oi5^T@03o`000?n9MXWoRGJ9
00CoRGJ900?o0000oeNXEomGZ5L02?mGZ5L00ol0003o[U6^ojiA[P02ojiA[P;o00003?miQWT2o`00
00[obCK900?o0000okU6^OniA[T05?niA[T00ol0003o^dBkok]4^`0;ok]4^`03o`000?oJ9M[ofRGJ
00WofRGJ00?o0000oo8=l_ob3O803Oob3O800ol0003oo@;mood2o@06ood2o@?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5nP03
o`000?oc3??ol`cc00;ol`cc00?o0000omlPgooO8=l02?oO8=l00ol0003ocC;=oldbc@0<oldbc@03
o`000?nAKY7oTFjA00WoTFjA00?o0000ohUfROn9MXT01On9MXT00ol0003oEjQGoeNXE`09oeNXE`04
o`000?n^DJko0000o`00013oNHIi0_l00008olTfb@03o`000?niA[Wo^DJi01Co^DJi0ol0000;ok]4
^`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000oo8=l_ob3O803Oob3O801?l0003oo@;mood2oOom0_d5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oc3??ol`cc00?ol`cc00?o0000omlP
gooO8=l02?oO8=l00ol0003ocC;=oldbc@0;oldbc@;o00002_nAKY400ol0003oRGJ9ohUfR@06ohUf
R@03o`000?mGZ5OoEjQG00[oEjQG00?o0000ogV6NOmiQWT04_miQWT00ol0003obCK9olTfb@04olTf
b@03o`000?niA[Wo^DJi01Go^DJi00?o0000oj=LXonSG:<01Ol00005ok]4^`03o`000?oJ9M[ofRGJ
00[ofRGJ00?o0000oo8=l_ob3O803_ob3O83o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP04ooX5nP03
o`000?oc3??ol`cc00Col`cc00?o0000omlPgooO8=l01ooO8=l00ol0003ocC;=oldbc@0;oldbc@04
o`000?n4NhCoQ7^4o`0000WoTFjA00?o0000ohUfROn9MXT01_n9MXT00ol0003oEjQGoeNXE`0:oeNX
E`03o`000?miQWWoNHIi01?oNHIi0_l00003olTfb@Co00005?niA[T00ol0003oXebSoj=LX`06oj=L
X`Co000000?o^dBko`000?oJ9MX02ooJ9MX00ol0003olPgboo8=lP0>oo8=lP03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003onPGjooX5nP03ooX5nP03o`000?oc3??ol`cc00Gol`cc00?o0000omlPgooO
8=l01ooO8=l00ol0003ocC;=oldbc@09oldbc@;o00001?n4Nh@00ol0003oTFjAoi5^T@05oi5^T@03
o`000?n9MXWoRGJ900OoRGJ900?o0000oeNXEomGZ5L02_mGZ5L00ol0003oNHIiogV6N@0EogV6N@03
o`000?o9=/Wo000000CoSW6>0ol0000@okU6^@03o`000?nSG:?oXebS00_oXebS0_l0000<omXUfP03
o`000?ob3O;olPgb00colPgb0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003ol`cc
oo<<l`06oo<<l`03o`000?oO8=oogb3O00Oogb3O00?o0000oldbcOo=</d02?o=</d00ol0003oQ7^4
ohAkQ005ohAkQ003o`000?nAKY7oTFjA00CoTFjA00?o0000ohUfROn9MXT01on9MXT00ol0003oEjQG
oeNXE`0:oeNXE`03o`000?miQWWoNHIi01KoNHIi00?o0000ohiaS_n>LHh01_n>LHh3o`0000co^DJi
00?o0000oj=LXonSG:<03OnSG:<00ol0003ofRGJomXUfP09omXUfPGo00002Oob3O82o`000003ooH9
m_l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ooX5n_l0003ol`cc00Wol`cc00?o0000omlPgooO8=l01_oO
8=l00ol0003ocC;=oldbc@07oldbc@03o`000?n4NhCoQ7^400OoQ7^400?o0000oi5^TOnAKY400_nA
KY400ol0003oRGJ9ohUfR@08ohUfR@03o`000?mGZ5OoEjQG00WoEjQG00?o0000ogV6NOmiQWT05omi
QWT00ol0003oSW6>ohiaSP09ohiaSP?o00002OniA[T00ol0003oXebSoj=LX`0>oj=LX`Ko00001?oJ
9MX00ol0003oi1_Ton@Ki003on@Ki0Go00000_ob3O82o`0000ComPWf00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oc3??ol`ccoo<<lol000002ooc3?<00ol0003ogb3OomlPg`06omlPg`03o`000?o=
</gocC;=00GocC;=0_l0000;ohAkQ004o`000?nAKY7oTFjAo`0000_oRGJ900?o0000oeNXEomGZ5L0
2OmGZ5L00ol0003oNHIiogV6N@0FogV6N@03o`000?n>LHkoSW6>00goSW6>0ol00005okU6^@03o`00
0?nSG:?oXebS00ooXebS00?o0000okY5^_njAKX00onjAKX4o`0000_oi1_T0_l00006ooH9mP03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003ol`ccoo<<l`02oo<<l`ko00001_oO8=l00ol0003ocC;=oldb
c@05oldbc@03o`000?n4NhCoQ7^400coQ7^400?o0000oi5^TOl000002on9MXT00ol0003oEjQGoeNX
E`07oeNXE`?o00006?miQWT00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o^DJio`000?nSG:<04?nS
G:<00ol0003o^TFjokY5^P07okY5^P03o`000?oT6nCoi1_T00[oi1_T00?o0000ooH9m_of2OH01Oof
2OH00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005oo<<l`03o`000?oP7n3oh1oP00_oh1oP0_l00004
omlPg`03o`000?o=</gocC;=00?ocC;=0_l0000@ohAkQ003o`000?n9MXWoRGJ900[oRGJ900?o0000
oeNXEomGZ5L00omGZ5L4o`0000;o;m0_00?o0000ogV6NOmiQWT05OmiQWT00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nSG:?oXebS013oXebS00?o0000okY5^_njAKX01onjAKX00ol0003oi1_Ton@Ki00:
on@Ki003o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oc3??ol`cc
00Gol`cc00?o0000on0Oh?oP7n003OoP7n06o`0000?ocC;=00?o0000ohAkQ?n4Nh@04?n4Nh@00ol0
003oRGJ9ohUfR@0:ohUfR@03o`000?mGZ5Oo000000?o00001ol_d2l00ol0003oNHIiogV6N@0DogV6
N@03o`000?n>LHkoSW6>01CoSW6>00?o0000oj=LXonSG:<03onSG:<00ol0003o^TFjokY5^P08okY5
^P03o`000?oT6nCoi1_T00[oi1_T00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo<<looc3?<01_oc3?<00ol0003oh1oPon0Oh00=on0Oh003o`000?no?koo_cno00?o
_cno00?o0000oldbcOl000004on4Nh@4o`0000WoRGJ90_l0000<obo@;`03o`000?miQWWoNHIi01?o
NHIi00?o0000ohiaS_n>LHh05On>LHh00ol0003oXebSoj=LX`0>oj=LX`03o`000?njAK[o^TFj00So
^TFj00?o0000on@Ki?oT6n@02OoT6n@00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oc3??ol`cc00Sol`cc00?o0000on0Oh?oP7n002ooP7n000ol0003o_cnooklo_`05oklo_`03o`00
0?n4NhCoQ7^401;oQ7^400Co0000occ3??ll`cco?<<l1Ol00003ohUfR@03o`000?l_d2oo;m0_00go
;m0_0ol0000@ogV6N@;o00006?n>LHh00ol0003oXebSoj=LX`0=oj=LX`03o`000?njAK[o^TFj00Wo
^TFj00?o0000on@Ki?oT6n@02OoT6n@00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_ol`cc00?o0000on0Oh?oP7n002_oP7n000ol0003o_cnooklo_`06oklo_`03o`00
0?n4NhCoQ7^4017oQ7^400?o0000occ3??ll`c`01oll`c`3o`00013o;m0_00?o0000oaGZ5OlEjQD0
1Ol00009ogV6N@;o000000?o;m0_o`000?n>LHh05on>LHh00ol0003oXebSoj=LX`0=oj=LX`03o`00
0?njAK[o^TFj00Wo^TFj00?o0000on@Ki?oT6n@02?oT6n@2o`0000[omPWf00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo<<looc3?<02Ooc3?<00ol0003oh1oPon0O
h00:on0Oh003o`000?no?koo_cno00Oo_cno00?o0000ohAkQ?n4Nh@03on4Nh@00ol0003o?<<locc3
?00:occ3?003o`000?l_d2oo;m0_00go;m0_00?o0000oaGZ5OlEjQD01_lEjQD4o`0000CoNHIi00?o
0000obo@;ol_d2l00_l_d2l00ol0003oSW6>ohiaSP0FohiaSP03o`000?nSG:?oXebS00_oXebS00?o
0000okY5^_njAKX02onjAKX00ol0003oi1_Ton@Ki006on@Ki003o`000?ob3O;o000000[omPWf00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000oo<<looc3?<02?oc3?<=
o`0000[o_cno00?o0000ohAkQ?n4Nh@03on4Nh@00ol0003o?<<locc3?00;occ3?003o`000?l_d2oo
;m0_00co;m0_00?o0000oaGZ5OlEjQD02_lEjQD4o`0000Go;m0_00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oXebSoj=LX`0:oj=LX`03o`000?njAK[o^TFj00co^TFj00?o0000on@Ki?oT6n@01?oT6n@2
o`0000?olPgb00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ol`ccoo<<l`07oo<<l`03o`000?oO8=oogb3O00Wogb3O00?o0000oklo
_ono?kl02Ono?kl00ol0003oQ7^4ohAkQ00=ohAkQ003o`000?ll`cco?<<l00co?<<l00?o0000obo@
;ol_d2l03?l_d2l00ol0003o5NXEoaGZ5@0;oaGZ5@03o`000?l7n0Oo000000Ko;m0_00?o0000ohia
S_n>LHh05_n>LHh00ol0003oXebSoj=LX`09oj=LX`03o`000?njAK[o^TFj00co^TFj00?o0000on@K
i?oT6n@00ooT6n@00ol0003olPgboo8=lP03oo8=lP03o`000?of2OKomPWf00SomPWf00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000oo<<looc3?<01_oc3?<00ol0003o
gb3OomlPg`08omlPg`03o`000?no?koo_cno00_o_cno00?o0000ohAkQ?n4Nh@02?n4Nh@4o`0000oo
?<<l00?o0000obo@;ol_d2l02ol_d2l00ol0003o5NXEoaGZ5@0;oaGZ5@04o`000?l7n0Oo1oP7o`00
00Oo;m0_00?o0000ohiaS_n>LHh05On>LHh00ol0003oXebSoj=LX`08oj=LX`03o`000?njAK[o^TFj
00go^TFj00?o0000on@Ki?oT6n@00_oT6n@00ol0003olPgboo8=lP05oo8=lP03o`000?of2OKomPWf
00OomPWf00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo<<looc
3?<01Ooc3?<00ol0003ogb3OomlPg`08omlPg`03o`000?no?koo_cno00_o_cno00?o0000ohAkQ?n4
Nh@00on4Nh@5o`0000?o?/4n00?o0000occ3??ll`c`03_ll`c`00ol0003o;m0_obo@;`0:obo@;`03
o`000?lEjQGo5NXE00[o5NXE00Go0000o`Oh1ol7n0Oo1oP7o`000007obo@;`03o`000?n>LHkoSW6>
01GoSW6>00?o0000oj=LXonSG:<02?nSG:<00ol0003o^TFjokY5^P0=okY5^P03o`000?oT6nCoi1_T
00;o00002?ob3O800ol0003omPWfooH9mP08ooH9mPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?oc3??ol`cc00Go
l`cc00?o0000omlPgooO8=l02?oO8=l00ol0003o_cnooklo_`0<oklo_`Go00002Oln`Ch00ol0003o
?<<locc3?00<occ3?0;o00003?l_d2l00ol0003o5NXEoaGZ5@0:oaGZ5@05o`000?l7n0Oo1oP7o`Oh
1ol000002?l_d2l00ol0003oSW6>ohiaSP0DohiaSP?o00001onSG:<00ol0003o^TFjokY5^P0>okY5
^P03o`000?oT6nCo000000_olPgb00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ol`ccoo<<l`04oo<<l`03o`000?oO8=oogb3O00Oo
gb3O00?o0000oklo_ono?kl03?no?kl01?l0003oPgb3oh=lPol0000;ock1?P03o`000?ll`cco?<<l
00_o?<<l00Co0000o`;m0_l2o@;o00002_l_d2l00ol0003o5NXEoaGZ5@0:oaGZ5@03o`000?l7n0Oo
1oP700;o1oP700?o0000obo@;ol_d2l01_l_d2l00ol0003oSW6>ohiaSP0AohiaSP?o00000om/Tf`0
0ol0003oXebSoj=LX`04oj=LX`03o`000?njAK[o^TFj00go^TFj1?l0000;oo8=lP03o`000?of2OKo
mPWf00GomPWf00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00KonPGj00Co0000oo<<
looc3??ol`cc1?l00008omlPg`03o`000?no?koo_cno00_o_cno00?o0000oh=lPon3O8<00_n3O8<0
0ol0003o?/4nock1?P08ock1?P03o`000?ll`cco?<<l00[o?<<l00?o0000o`;m0_l2o@800_l2o@80
0ol0003o;m0_obo@;`03obo@;`Go00002olEjQD00ol0003o1oP7o`Oh1`03o`Oh1`03o`000?l_d2oo
;m0_00Oo;m0_00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoK9=/00?o0000oj=LXonSG:<00_nSG:<0
0ol0003o^TFjokY5^P0=okY5^P03o`000?oR7N;ohQgR00;ohQgR00?o0000oo8=l_ob3O802Oob3O80
0ol0003omPWfooH9mP03ooH9mP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5
nP?o00001?oU6^D00ol0003ogb3OomlPg`05omlPg`03o`000?no?koo_cno00[o_cno00?o0000oh=l
Pon3O8<00on3O8<00ol0003o?/4nock1?P09ock1?P03o`000?ll`cco?<<l00So?<<l00?o0000o`;m
0_l2o@801?l2o@85o`0000Co0?l000?o0000oaGZ5OlEjQD02OlEjQD00ol0003o1oP7o`Oh1`03o`Oh
1`03o`000?l_d2oo;m0_00So;m0_00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oK9=/00Go0000oj=L
XonSG:?oXebSo`00000>okY5^P03o`000?oR7N;ohQgR00CohQgR0_l00009oo8=lP03o`000?of2OKo
mPWf00;omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onDJ
iOoU6^D01OoU6^D00ol0003ogb3OomlPg`03omlPg`03o`000?no?koo_cno00[o_cno00?o0000oh=l
Pon3O8<01?n3O8<00ol0003o?/4nock1?P09ock1?P03o`000?ll`cco?<<l00Oo?<<l00?o0000o`;m
0_l2o@801Ol2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lEjQGo5NXE00Oo5NXE00?o0000o`Oh
1ol7n0L01?l7n0L00ol0003o;m0_obo@;`08obo@;`03o`000?n>LHkoSW6>00SoSW6>0_l0000>ofbC
K0Co00003?njAKX2o`0000WohQgR00?o0000oo8=l_ob3O801oob3O801?l0003omPWfooH9m_l0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oiA[UonDJi@07onDJi@;o00000ooO8=l00ol0
003o_cnooklo_`09oklo_`03o`000?n3O8?oPgb300KoPgb300?o0000ock1?_ln`Ch02Oln`Ch00ol0
003o?<<locc3?005occ3?003o`000?l2o@;o0_d200Ko0_d200?o0000o`3o0?l0o`002?l0o`000ol0
003o5NXEoaGZ5@06oaGZ5@03o`000?l7n0Oo1oP700Co1oP700?o0000obo@;ol_d2l02Ol_d2l4o`00
00?oSW6>0ol0000@ofbCK005o`000?o7><OoacS7olLhaol000002_njAKX00ol0003ohQgRon8MhP0:
on8MhPKo00000oob3O800ol0003omPWfo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0
003oiA[UonDJi@0:onDJi@04o`000?oO8=oogb3Oo`0000[o_cno00?o0000oh=lPon3O8<01on3O8<0
0ol0003o?/4nock1?P09ock1?P03o`000?ll`cco?<<l00Co?<<l00?o0000o`;m0_l2o@801ol2o@80
0ol0003o0?l0o`3o0008o`3o00;o00001_lEjQD00ol0003o1oP7o`Oh1`05o`Oh1`03o`000?l_d2oo
;m0_00Wo;m0_00Co0000oc3?<?l`cc3o<<l`0ol0000BofbCK003o`000?o7><OoacS700?oacS70_l0
0006okY5^P;o00003OoR7N800ol0003on0OhooP7n003ooP7n0Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003oiA[UonDJi@0<onDJi@;o00002_no?kl00ol0003oPgb3oh=lP`08oh=lP`03o`000?ln`Cko
?/4n00[o?/4n00?o0000occ3??ll`c`00_ll`c`00ol0003o0_d2o`;m0P08o`;m0P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lEjQGo5NXE00;o5NXE00?o0000o`Oh1ol7n0L01_l7n0L0
0ol0003o;m0_obo@;`08obo@;`03o`000?l`cc3o<<l`00Co<<l`00?o0000ofbCK?m/Tf`03om/Tf`0
0ol0003oacS7olLha`06olLha`;o00000onjAKX00ol0003ohQgRon8MhP0=on8MhP03o`000?oh1oSo
n0Oh00Oon0Oh0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?oU6^GoiA[U
00koiA[U00?o0000oklo_ono?kl01ono?kl00ol0003oPgb3oh=lP`0:oh=lP`03o`000?ln`Cko?/4n
00Wo?/4n00Go0000occ3??ll`cco?<<lo`00000;o`;m0P03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lEjQGo5NXEoaGZ5Ol000002?l7n0L00ol0003o;m0_obo@;`08obo@;`03o`000?l`
cc3o<<l`00Go<<l`00?o0000ofbCK?m/Tf`03_m/Tf`00ol0003oacS7olLha`08olLha`03o`000?nj
AK[o000000oohQgR00?o0000ooP7n?oh1oP02?oh1oP01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oj1O[onPGjo`00017oiA[U00?o0000oklo_ono?kl01_no?kl00ol0003oPgb3
oh=lP`0;oh=lP`03o`000?ln`Cko?/4n00Wo?/4n00Co0000occ3??ll`cco00003?l2o@800ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5NXEo`000009o`Oh1`03o`000?l_d2oo;m0_00So
;m0_00?o0000oc3?<?l`cc001Ol`cc000ol0003oK9=/ofbCK00=ofbCK003o`000?o7><OoacS700[o
acS700?o0000on8Mh_oR7N803_oR7N800ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BonDJi@03o`00
0?no?koo_cno00Co_cno00?o0000oh=lPon3O8<03?n3O8<00ol0003o?/4nock1?P0:ock1?P?o0000
3?l2o@800ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Oh1ol7n0L02?l7n0L00ol0003o;m0_
obo@;`07obo@;`03o`000?l`cc3o<<l`00Oo<<l`00?o0000ofbCK?m/Tf`03?m/Tf`00ol0003oacS7
olLha`0;olLha`;o00003_oR7N800ol0003on0OhooP7n007ooP7n003o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP00ooh1oP00ol0003oiA[UonDJi@0?onDJi@?o00000ono
?kl00ol0003oPgb3oh=lP`0>oh=lP`03o`000?ln`Cko?/4n00So?/4n00Co0000o`Wf2Ol9mPWo2OH9
0_l0000:o`;m0P?o00003Ol0o`000ol0003o1oP7o`Oh1`08o`Oh1`03o`000?l_d2oo;m0_00Oo;m0_
00?o0000oc3?<?l`cc001ol`cc000ol0003oK9=/ofbCK00;ofbCK003o`000?o7><OoacS700coacS7
00?o0000oo4>lOl000000_l0000:on8MhP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n004ooP7n003o`000?oU6^GoiA[U00coiA[U0_l0
0003omDZe@03o`000?no?koo0000017oPgb300?o0000ock1?_ln`Ch01oln`Ch00ol0003o2OH9o`Wf
2@04o`Wf2@;o00002?l2o@800ol0003o0?l0o`3o000>o`3o00;o00002?l7n0L00ol0003o;m0_obo@
;`06obo@;`03o`000?l`cc3o<<l`00Wo<<l`00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003oacS7olLh
a`0=olLha`03o`000?oa3_7ol@ka00;ol@ka0ol00007on8MhP03o`000?oh1oSon0Oh00Oon0Oh00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oU6^Go
iA[U00WoiA[U0_l00006omDZe@03o`000?n3O8?oPgb3013oPgb300?o0000ock1?_ln`Ch01_ln`Ch0
0ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l2o@;o0_d200Co0_d20ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol7n0L00ol0003o;m0_obo@;`06obo@;`03o`000?l`cc3o<<l`00[o<<l`00?o0000
ofbCK?m/Tf`02?m/Tf`00ol0003oacS7olLha`0=olLha`03o`000?oa3_7ol@ka00Gol@ka0ol00004
on8MhP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on0OhooP7n006ooP7n003o`000?oU6^GoiA[U00GoiA[U0ol00008omDZe@03o`000?n3O8?oPgb3
017oPgb300Co0000ock1?_ln`Cko?/4n1?l0000;o`Wf2@;o000000Co0_d2o`000?l0003o00000ol1
oP42o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o1oP700?o0000obo@;ol_d2l01_l_
d2l00ol0003o<<l`oc3?<00:oc3?<003o`000?m/TfcoK9=/00OoK9=/00?o0000olLhaoo7><L03_o7
><L00ol0003ol@kaoo4>l@08oo4>l@Co00002_oh1oP00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on0OhooP7n007ooP7n003o`000?oU6^GoiA[U00;oiA[U0_l0000<omDZe@03o`000?n3O8?o
Pgb3013oPgb31?l00003oc;=<P03o`000?l9mPWo2OH900_o2OH900?o0000o`7n0Ol1oP401_l1oP40
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>oc3?<003o`000?m/Tfco
K9=/00KoK9=/00?o0000olLhaoo7><L03_o7><L00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oh1oSo
n0Oh00Oon0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00Won0Oh00Co0000onDJ
iOl0003o00003_oE:]D00ol0003oPgb3oh=lP`0?oh=lP`03o`000?lbcC;o</db00Ko</db00?o0000
o`Wf2Ol9mPT02_l9mPT00ol0003o0Oh1o`7n0@07o`7n0@;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l]dRgo;M8]00So;M8]00?o0000oc3?<?l`cc003?l`cc000ol0003oK9=/ofbCK005
ofbCK003o`000?o7><OoacS700ooacS70_l0000=oo4>l@03o`000?oh1oSon0Oh00Kon0Oh00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00[on0Oh00?o0000omDZeOoE:]D03_oE:]D00ol0
003oPgb3oh=lP`0>oh=lP`03o`000?lbcC;o</db00Oo</db00?o0000o`Wf2Ol9mPT02_l9mPT00ol0
003o0Oh1o`7n0@09o`7n0@;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l]dRgo;M8]
00Wo;M8]00?o0000oc3?<?l`cc002_l`cc04o`0000CoK9=/00?o0000olLhaoo7><L04?o7><L01?l0
003oka3_o`000?l0000<oo4>l@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oh1oSon0Oh00[on0Oh00?o0000omDZeOoE:]D03ooE:]D@o`0000[o</db00?o0000o`Wf
2Ol9mPT02Ol9mPT00ol0003o0?l0o`00000<o`7n0@05o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o;M8]obgB;@09obgB;@03o`000?l`cc3o<<l`00Oo<<l`0ol00004ofJIIP?o000000?oK9=/
o`000?o7><L04Oo7><L01?l0003oka3_onl@koo_4>l2o`0000_ol@ka00?o0000ooP7n?oh1oP00ooh
1oP00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oeB[EomDZe@0?
omDZe@03o`000?moOgooOgmo00coOgmo00?o0000oc;=<_lbcC802OlbcC800ol0003o2OH9o`Wf2@07
o`Wf2@04o`000?l0o`3o0?l0o`0000go0Oh100Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l]dRgo;M8]00[o;M8]00?o0000oc3?<?l`cc000ol`cc03o`0000[oIYUV00?o0000olLhaoo7><L0
4?o7><L00ol0003oka3_onl@k`04onl@k`;o00002_oa3_400ol0003on0OhooP7n004o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con0Oh00?o0000omDZeOoE:]D03ooE:]D00ol0003oOgmoogmoO`0<ogmoO`03o`000?lb
cC;o</db00Wo</db00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o0?l0o`3o0002o`3o0003o`000?l1
oP7o0Oh100[o0Oh100?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l]
dRgo;M8]00[o;M8]00?o0000oc3?<?l`cc000ol0000=ofJIIP03o`000?o7><OoacS7013oacS700?o
0000onl@koo_4>l01_o_4>l2o`0000Wol@ka0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oeB[EomDZe@0=omDZe@?o00003omoOgl0
0ol0003o</dboc;=<P08oc;=<P03o`000?l9mPWo2OH900Go2OH900?o0000o`3o0?l0o`000ol0o`00
0ol0003o0Oh1o`7n0@0:o`7n0@03o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o;M8]obgB;@0;obgB;@;o00004OmVVFH00ol0003oacS7olLha`0?olLha`03o`000?o_4>oo
ka3_00Soka3_0_l00007oo4>l@03o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooP7n?oh1oP02?oh1oP00ol0003oeB[EomDZe@09omDZe@Go00000_naC[400ol0
003oOgmoogmoO`0=ogmoO`03o`000?lbcC;o</db00Wo</db00?o0000o`Wf2Ol9mPT01?l9mPT00ol0
003o0?l0o`3o0004o`3o0003o`000?l1oP7o0Oh100So0Oh100?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l]dRgo;M8]00_o;M8]00?o0000ofJII_mVVFH04?mVVFH00ol0
003oacS7olLha`0?olLha`03o`000?o_4>ooka3_00[oka3_0_l00004oo4>l@03o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on0OhooP7n007ooP7n003o`000?oE:]GoeB[E00CoeB[E1Ol00007ok5>/@03
o`000?moOgooOgmo00goOgmo00?o0000oc;=<_lbcC802OlbcC800ol0003o2OH9o`Wf2@03o`Wf2@03
o`000?l0o`3o0?l000Go0?l000?o0000o`7n0Ol1oP402?l1oP400ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000obgB;Ol]dRd02ol]dRd00ol0003oIYUVofJIIP0@ofJIIP03
o`000?o7><OoacS700ooacS700?o0000onl@koo_4>l03?o_4>l2o`000003oo4>lOl0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000omDZeOl00000
1?l0000<ok5>/@03o`000?moOgooOgmo00koOgmo00?o0000oc;=<_lbcC802?lbcC800ol0003o2OH9
o`Wf2@02o`Wf2@03o`000?l0o`3o0?l000Oo0?l000?o0000o`7n0Ol1oP401ol1oP400ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000obgB;Ol]dRd02ol]dRd00ol0003oIYUV
ofJIIP0AofJIIP03o`000?o7><OoacS700goacS700?o0000onl@koo_4>l03oo_4>l00ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP01Ooh1oP3o`00017o/Dja00?o0000ogmoOomoOgl03_mo
Ogl00ol0003o</dboc;=<P09oc;=<P04o`000?l9mPWo2OH9o`0000[o0?l000?o0000o`7n0Ol1oP40
1ol1oP400ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol]dRd00ol0003o
IYUVofJIIP0AofJIIP?o00003Oo7><L00ol0003oka3_onl@k`0?onl@k`03o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oh1oP2o`0000;ojAKY00?o0000ok5>/OnaC[403onaC[400ol0003o
OgmoogmoO`0>ogmoO`03o`000?lbcC;o</db00So</db1Ol0000;o`3o0003o`000?l1oP7o0Oh100Ko
0Oh100?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=obgB;@03o`000?mVVFKoIYUV
017oIYUV00?o0000oh9mP_n2OH800ol0000:olLha`Co00003Oo_4>l00ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooX5n_oj1O[onPGj0_l00005onTFj@03o`000?naC[7o/Dja00ko/Dja00?o0000ogmo
OomoOgl03_moOgl00ol0003o</dboc;=<P07oc;=<P03o`000?l>l@ko3_4>00?o3_4>00?o0000o`3o
0?l0o`002?l0o`000ol0003o0Oh1o`7n0@05o`7n0@03o`000?l0o`3o0?l000[o0?l01Ol0000<obgB
;@03o`000?mVVFKoIYUV013oIYUV00?o0000oh9mP_n2OH801?n2OH83o`0000KoacS700?o0000onXE
j_oZ5NX00_oZ5NX5o`0000Soka3_00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00?o
nPGj00?o0000onTFjOoY5^T01?oY5^T00ol0003o/Djaok5>/@0=ok5>/@03o`000?moOgooOgmo00oo
Ogmo00?o0000oc;=<_lbcC801?lbcC82o`0000Oo3_4>00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000obgB;Ol]dRd02?l]dRd3o`00013oIYUV00?o0000oh9mP_n2OH802?n2OH83o`0000;o
acS700?o0000onXEj_oZ5NX02?oZ5NX5o`0000?oka3_00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oj1O[onPGj00ConPGj00?o0000onTFjOoY5^T01OoY5^T00ol0003o/Djaok5>/@0;ok5>/@Co0000
3omoOgl00ol0003o</dboc;=<P03oc;=<P03o`000?l>l@ko3_4>00So3_4>00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0o`300?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l]dRd2o`0000?o;m0_00?o0000ofJII_mVVFH03?mVVFH00ol0003oPWf2oh9mPP0<oh9mPP;o0000
4?oZ5NX3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?oY5^WojAKY00KojAKY00?o
0000ok5>/OnaC[402OnaC[400ol0003oaC[5o`000002ogJ9MP?o00003?moOgl01?l0003o</dboc;=
<_lbcC82o`0000co3_4>00?o0000o`3o0?l0o`000_l0o`000ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o;M8]obgB;@02obgB;@03o`00
0?l_d2oo;m0_00Co;m0_0_l0000;ofJIIP03o`000?n2OH;oPWf200coPWf200?o0000ol8m`_l00000
4_oZ5NX00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oY5^WojAKY00OojAKY00?o
0000ok5>/OnaC[401_naC[42o`0000;oaC[500?o0000ogJ9M_mfRGH00omfRGH3o`0000[oOgmo00?o
0000oc;=<_l000003ol>l@h01?l0003o0?l0o`000?l0000;o`?l0`03o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o;M8]o`000?l00009obo@;`03o`000?mVVFKoIYUV00Oo
IYUV00?o0000oh9mP_n2OH803?n2OH801?l0003o`Sg2ol8m`_l0000ConXEjP03o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003ojAKYonTFj@08onTFj@03o`000?naC[7o/Dja00Co
/Dja00?o0000olDjaOo5>/D00oo5>/D00ol0003oMXUfogJ9MP05ogJ9MP?o00001_moOgl4o`00013o
3_4>00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoIYUV00?o0000oh9mP_n2OH803?n2OH800ol0003o
`Sg2ol8m`P02ol8m`P03o`000?oZ5N[ojQGZ00oojQGZ00?o0000ooP7n?l000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oY5^WojAKY00WojAKY00Co0000ok5>/OnaC[7o
/Dja0_l00006olDja@03o`000?mfRGKoMXUf00SoMXUf0ol000000omoOgoo0000o`000004ocC;=003
o`000?l>l@ko3_4>00go3_4>00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oIYUVofJIIP03o`0000ko
PWf200?o0000ol8m`_o2?L800oo2?L800ol0003ojQGZonXEjP0>onXEjP05o`000?oh1oSon0OhooP7
n?l000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oY5^WojAKY00[o
jAKY00?o0000ok5>/Ol000002?o5>/D00ol0003oMXUfogJ9MP0;ogJ9MP03o`000?ldbcCo=</d00Go
=</d00?o0000o`ka3_l>l@h03?l>l@h00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002og^4N`03o`000?n2OH;oPWf200_o
PWf200?o0000ol8m`_o2?L801?o2?L800ol0003ojQGZonXEjP0=onXEjP03o`000?oh1oSon0Oh00?o
n0Oh00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooX5nP03o`000?oY5^WojAKY00_ojAKY00?o0000olDjaOo5>/D0
1oo5>/D00ol0003oMXUfogJ9MP0;ogJ9MP03o`000?ldbcCo=</d00Ko=</d00?o0000o`ka3_l>l@h0
2ol>l@h2o`0000go0o`300?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000og^4NomkQ7/00_mkQ7/00ol0003oPWf2oh9mPP09oh9mPP03
o`000?o2?L;o`Sg200Ko`Sg200?o0000onXEj_oZ5NX02ooZ5NX00ol0003on0OhooP7n005ooP7n004
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000SonPGj00?o0000onTFjOoY5^T02_oY5^T2o`0000Wo
aC[500?o0000ogJ9M_mfRGH02omfRGH00ol0003o=</docC;=007ocC;=003o`000?l>l@ko3_4>00Wo
3_4>00Co0000o`3o0?l0o`3o00003?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?mkQ7_oNhAk00?oNhAk00?o0000
oh9mP_n2OH801on2OH800ol0003o`Sg2ol8m`P07ol8m`P03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000
ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooX5nP03o`000?oY5^WojAKY
00WojAKY00Co0000onHIi_oV6NKo00002Oo5>/D00ol0003oMXUfogJ9MP09ogJ9MP03o`000?ldbcCo
=</d00Wo=</d00?o0000o`ka3_l>l@h01ol>l@h00ol0003o0?l0o`3o0002o`3o0003o`000?l3o0?o
0o`300Wo0o`300?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oNhAkog^4N`05og^4N`03o`000?n2OH;o
PWf200GoPWf200?o0000ol8m`_o2?L802?o2?L800ol0003ojQGZonXEjP09onXEjP03o`000?oh1oSo
n0Oh00Son0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oj1OX3o`0000WojAKY00?o0000onHI
i_oV6NH00_oV6NH00ol0003oaC[5olDja@06olDja@03o`000?mfRGKoMXUf00WoMXUf00?o0000ocC;
=?ldbc@02_ldbc@00ol0003o3_4>o`ka3P05o`ka3P03o`000?l0o`3o0?l000Co0?l000?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?mkQ7_oNhAk00KoNhAk00?o0000oh9m
P_n2OH800on2OH800ol0003o`Sg2ol8m`P09ol8m`P03o`000?oZ5N[ojQGZ00SojQGZ00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003ooD:m@?o00001OoY5^T00ol0003o
iQWVonHIiP03onHIiP03o`000?o5>/GoaC[500KoaC[500?o0000ogJ9M_mfRGH02OmfRGH00ol0003o
=</docC;=00;ocC;=003o`000?l>l@ko3_4>00?o3_4>00?o0000o`3o0?l0o`001_l0o`000ol0003o
0o`3o`?l0`08o`?l0`03o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oNhAkog^4N`07og^4N`05o`000?n2OH;oPWf2oh9m
P_l000003Oo2?L800ol0003ojQGZonXEjP06onXEjP03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?oe2_Gom@[e00Gom@[e0ol000000ooY5^Wo0000onHIiP06onHIiP03
o`000?o5>/GoaC[500GoaC[500?o0000ogJ9M_mfRGH02OmfRGH00ol0003o=</docC;=00<ocC;=005
o`000?l>l@ko3_4>o`ka3_l000002_l0o`000ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olKi1_o0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000og^4NomkQ7/02OmkQ7/00ol0003oPWf2o`00000=ol8m`PCo00001OoZ5NX00ol0
003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:m@08ooD:m@03
o`000?oV6NKoiQWV00OoiQWV00?o0000olDjaOo5>/D01?o5>/D00ol0003oMXUfogJ9MP09ogJ9MP03
o`000?ldbcCo=</d00go=</d00?o0000o`ka3_l000003?l0o`0:o`0000Oo0?l00ol00005oa_T6`03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oNhAkog^4N`0:og^4N`03
o`000?o2?L;o`Sg200_o`Sg200?o0000on/Djoo[5>/00_o[5>/3o`000003onXEj_l0003on0Oh00_o
n0Oh0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oiQWVonHIiP07onHIiP03o`00
0?o5>/GoaC[500GoaC[500?o0000ogJ9M_mfRGH01omfRGH00ol0003o=</docC;=00?ocC;=0;o0000
2ol0o`000ol0003o4>l@oa3_4007oa3_4003o`000?l0o`3o0?l000;o0?l00ol00008oa_T6`03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oNhAkog^4N`0:og^4N`03o`00
0?o2?L;o`Sg200[o`Sg200?o0000on/Djoo[5>/01_o[5>/00ol0003on0OhooP7n008ooP7n0?o0000
0_oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oiQWVonHI
iP08onHIiP03o`000?o5>/GoaC[500CoaC[500?o0000ogJ9M_mfRGH01omfRGH00ol0003o=</docC;
=00>ocC;=004o`000?l5nPGo1OX5o`0000Wo0?l000?o0000oa3_4?l@ka002Ol@ka001?l0003o0?l0
o`000?l0000<oa_T6`03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
NhAkog^4N`0;og^4N`03o`000?o2?L;o`Sg200Oo`Sg20_l00009on/Dj`03o`000?oh1oSon0Oh00Co
n0Oh1?l00006ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om@[eooD:m@09ooD:m@03o`00
0?oV6NKoiQWV00SoiQWV00?o0000olDjaOo5>/D00oo5>/D>o`0000go=</d00?o0000o`Gj1Ol5nPD0
0_l5nPD00ol0003o0?l0o`3o0005o`3o0003o`000?l@ka3o4>l@00_o4>l@00?o0000oa_T6olKi1/0
3?lKi1/00ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000og^4NomkQ7/0
3?mkQ7/00ol0003o`Sg2ol8m`P06ol8m`P03o`000?o[5>_ojaC[00[ojaC[00?o0000ooP7n?oh1oP0
0ol0000:ooX5nP?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onHIi_oV6NH02?oV
6NH01Ol0003oaC[5olDjaOo5>/Go000000_oRgB;00?o0000obSG:?lXebP00ol00009ocC;=003o`00
0?l5nPGo1OX500Co1OX500?o0000o`3o0?l0o`000ol0o`000ol0003o4>l@oa3_400<oa3_4003o`00
0?lKi1_o6n@K00go6n@K00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmkQ7/00ol0003o`Sg2ol8m`P05ol8m`P03o`000?o[5>_ojaC[00cojaC[0_l0000=ooX5nP03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onHIi_oV6NH02?oV
6NH4o`0000coRgB;00?o0000obSG:?lXebP00olXebP3o`0000Go=</d00?o0000o`Gj1Ol5nPD01_l5
nPD01Ol0003o0?l0o`3o0?l0o`3o000000oo4>l@00?o0000oa_T6olKi1/03OlKi1/00ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000olacS400ol0003oNhAkog^4N`0;og^4N`03o`00
0?o2?L;o`Sg200?o`Sg200?o0000on/Djoo[5>/03Oo[5>/00ol0003onPGjooX5nP0;ooX5nP03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000ooD:mOoe2_D02_oe2_D3o`0000KoiQWV0ol0
0003omTVf@03o`000?n;M8_oRgB;00[oRgB;00?o0000obSG:?lXebP01_lXebP3o`000003ocC;=?l0
003o1OX500Wo1OX500?o0000o`3o0?l000004?l@ka000ol0003o6n@Koa_T6`0=oa_T6`03o`000?l4
n`Co1?/400Oo1?/40_l00007oc7><@03o`000?mkQ7_oNhAk00[oNhAk00Co0000ol8m`_o2?L;o`Sg2
0ol0000?on/Dj`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooD:mOoe2_D02_oe
2_D01?l0003ol0o`oo0?l?o`3o02o`000004onHIi_l0003o0000o`0000KofBKI00?o0000oh]dRon;
M8/02_n;M8/00ol0003o:=LXobSG:009obSG:003o`000?l5nPGo1OX500[o1OX500?o0000oa3_4?l@
ka003ol@ka000ol0003o6n@Koa_T6`0>oa_T6`03o`000?l4n`Co1?/400Ko1?/400?o0000oc7><Ola
cS401olacS44o`0000SoNhAk00Co0000ol8m`_o2?L;o00000ooJ9MX2o`0000gojaC[00?o0000ooX5
n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003o
l0o`oo0?l004oo0?l003o`000?oI9]WofBKI00OofBKI00?o0000oh]dRon;M8/02On;M8/00ol0003o
:=LXobSG:00:obSG:003o`000?l5nPGo1OX500[o1OX500?o0000oa3_4?l@ka003ol@ka000ol0003o
6n@Koa_T6`0>oa_T6`03o`000?l4n`Co1?/400Go1?/400?o0000oc7><OlacS402?lacS401?l0003o
OH9mogf2OOmmPWd7o`0000;oNhAk0_l00006omXUfP;o00003?o[5>/00ol0003onPGjooX5nP09ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003om@[eooD:m@08ooD:m@03o`000?o`3o3ol0o`00Go
l0o`00?o0000omTVfOoI9]T02?oI9]T00ol0003oRgB;oh]dR`08oh]dR`03o`000?lXebSo:=LX00[o
:=LX00?o0000o`Gj1Ol5nPD02ol5nPD00ol0003o4>l@oa3_400>oa3_4003o`000?lKi1_o6n@K00ko
6n@K1Ol00002o`Ck1003o`000?lacS7o<Lha00Wo<Lha00?o0000ogf2OOmmPWd02?mmPWd3o`0000Wo
fRGJ0_l0000:on/Dj`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oe2_Gom@[e00Som@[e00?o0000oo0?l?o`3o001oo`3o000ol0003ofBKIomTVf@07omTVf@03o`00
0?n;M8_oRgB;00SoRgB;00?o0000obSG:?lXebP02_lXebP00ol0003o1OX5o`Gj1@0:o`Gj1@;o0000
3_l@ka03o`0000go6n@K0ol00005oc3?<0;o00002olacS400ol0003oOH9mogf2O@0;ogf2O@;o0000
2_oJ9MX2o`0000OojaC[0ol00009ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:oo0?l003o`00
0?oI9]WofBKI00OofBKI00?o0000oh]dRon;M8/02?n;M8/>o`0000Wo1OX50ol000000ol0o`3o0000
oa3_400:oa3_40?o00000_lXebP00ol0003o6n@Koa_T6`09oa_T6`;o00002Ol`cc000ol0003o<Lha
oc7><@09oc7><@03o`000?mmPWgoOH9m00_oOH9m00?o0000ojIIY_l000002ooJ9MX2o`0000CojaC[
00Co0000oo8=l_ob3O;olPgb0_l00007ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002ool0o`00ol0003ol0o`
oo0?l009oo0?l003o`000?oI9]WofBKI00KofBKI00?o0000oh]dRon;M8/02?n;M8/00ol0003o:m@[
ob_D:`0:ob_D:`03o`000?l5nPGo1OX500Co1OX50ol00005o`3o0003o`000?l@ka3o4>l@00Co4>l@
1?l00006obSG:003o`000?lKi1_o6n@K00Ko6n@K0_l0000;oc3?<003o`000?lacS7o<Lha00Wo<Lha
00?o0000ogf2OOmmPWd02_mmPWd01Ol0003oYUVVojIIY_nVFJKo000000cofRGJ0_l000000oo[5>_o
0000oo8=lP05oo8=lP03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?o`3o3ol0o`00Sol0o`00?o0000omTVfOoI9]T01_oI9]T00ol0003oRgB;oh]dR`07oh]dR`03o`00
0?l[e2_o:m@[00_o:m@[00?o0000o`Gj1Ol5nPD00_l5nPD2o`0000Wo0?l000?o0000oa3_4?l@ka00
0ol0000;obSG:003o`000?lKi1_o6n@K00;o6n@K0ol0000>oc3?<003o`000?lacS7o<Lha00Oo<Lha
00?o0000ogf2OOmmPWd02ommPWd00ol0003oYUVVojIIYP02ojIIYP03o`000?oJ9M[ofRGJ00_ofRGJ
00?o0000oo8=l_ob3O801_ob3O82o`0000?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00<oo`3o003o`000?o`
3o3ol0o`00Ool0o`00?o0000omTVfOoI9]T01ooI9]T00ol0003oRgB;oh]dR`05oh]dR`?o00003Ol[
e2/4o`0000_o0?l00ol0000?obSG:004o`000?lKi1_o0000o`00017o<<l`00?o0000oc7><OlacS40
1olacS400ol0003oOH9mogf2O@0:ogf2O@03o`000?nVFJKoYUVV00CoYUVV00?o0000omXUf_oJ9MX0
1ooJ9MX3o`0000_olPgb1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003ofBKIomTV
f@06omTVf@03o`000?n;M8_oRgB;00;oRgB;0ol00003ofJIIP03o`000?l[e2_o:m@[00[o:m@[00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AobSG:003o`000?l`cc3o<<l`017o<<l`00?o
0000oc7><OlacS401olacS400ol0003oOH9mogf2O@0:ogf2O@03o`000?nVFJKoYUVV00GoYUVV00Co
0000omXUf_oJ9M[ofRGJ1Ol00002omhQgP03o`000?ob3O;olPgb00WolPgb00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`3o000ol0003ofBKIomTVf@05omTVf@?o0000
00?oRgB;o`000?l000001omVVFH00ol0003o:m@[ob_D:`08ob_D:`?o00002_l0o`02o`0000;o0?l0
00?o0000obSG:?lXebP03olXebP00ol0003o<<l`oc3?<00Aoc3?<003o`000?lacS7o<Lha00Oo<Lha
00?o0000ogf2OOmmPWd02OmmPWd00ol0003oYUVVojIIYP07ojIIYP?o00001ooN8Mh00ol0003olPgb
oo8=lP09oo8=lP03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?ol0ocoo0?l00koo0?l00?o0000oo0?l?o`3o001oo`
3o04o`0000;ofBKI0_l00003ol/db`03o`000?mVVFKoIYUV00SoIYUV0_l00006ob_D:`;o00000olQ
gR400ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obSG:?lXebP03_lX
ebP00ol0003o<<l`oc3?<00Boc3?<003o`000?lacS7o<Lha00Go<Lha00?o0000ogf2OOmmPWd02Omm
PWd00ol0003oYUVVojIIYP08ojIIYP03o`000?oN8MkogR7N00OogR7N00?o0000oo8=l_ob3O802?ob
3O800ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`00Col0o`0_l00004
onhAkP;o00001Oo;=</00ol0003oIYUVofJIIP0:ofJIIP03o`000?l[e2_o:m@[00;o:m@[00?o0000
ob7N8OlQgR401?lQgR400ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obSG:?lXebP03_lXebP00ol0003o<<l`oc3?<00Boc3?<0[o00002_mmPWd00ol0003oYUVVojIIYP08
ojIIYP03o`000?oN8MkogR7N00OogR7N00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000oo`3
o?ol0o`03ool0o`01?l0003ol0o`oo0?l?o`3o02o`0000OokQ7^00?o0000ol/dboo;=</01?o;=</0
0ol0003oIYUVofJIIP0:ofJIIP04o`000?l[e2_o0000o`0000So8MhQ00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lXebSo:=LX00ko:=LX00?o0000oc3?<?l`cc004_l`cc000ol0003oDZeB
oe:]DP07oe:]DP03o`000?mmPWgoOH9m00KoOH9m00?o0000ojIIY_nVFJH02_nVFJH00ol0003ogR7N
omhQgP06omhQgP03o`000?ob3O;olPgb00SolPgb00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo0?loo`3o00?oo`3o004o`000?o`
3o3o0000o`0000WokQ7^00?o0000ol/dboo;=</01?o;=</00ol0003oIYUVofJIIP0;ofJIIP03o`00
0?lQgR7o8MhQ00Wo8MhQ00?o0000o`3o0?l000002Ol0o`000ol0003o:=LXobSG:00>obSG:0;o0000
4_l`cc000ol0003oDZeBoe:]DP09oe:]DP;o00001_mmPWd00ol0003oYUVVojIIYP0:ojIIYP03o`00
0?oN8MkogR7N00KogR7N00?o0000oo8=l_ob3O802?ob3O800ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?ol0ocoo0?l013oo0?l00?o
0000onhAk_o^4Nh02Oo^4Nh00ol0003obcC;ol/db`05ol/db`03o`000?mVVFKoIYUV00[oIYUV00?o
0000ob7N8OlQgR402_lQgR42o`0000Wo0?l000?o0000obSG:?lXebP03_lXebP00ol0003o7^4No`00
0002o`0000oo<<l`00?o0000oe:]D_mB[E802omB[E800ol0003oOH9mogf2O@03o`0000goYUVV00?o
0000omhQg_oN8Mh01_oN8Mh00ol0003olPgboo8=lP07oo8=lP03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000oo`3o?ol0o`03ool0o`0
0ol0003okQ7^onhAkP09onhAkP03o`000?o;=<_obcC;00GobcC;00?o0000ofJII_mVVFH02OmVVFH2
o`0000_o8MhQ0_l0000;o`3o0003o`000?lXebSo:=LX00co:=LX00?o0000oakQ7_lNhAh00olNhAh3
o`0000co<<l`00?o0000oe:]D_mB[E803?mB[E82o`0000;oXUfR00?o0000ojIIY_nVFJH03?nVFJH0
0ol0003ogR7NomhQgP05omhQgP03o`000?ob3O;olPgb00OolPgb00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo0?loo`3o00>oo`3
o003o`000?o^4NkokQ7^00[okQ7^00?o0000ol/dboo;=</01_o;=</00ol0003oIYUVofJIIP07ofJI
IP03o`000?m^TFko000000[o8MhQ00Co0000oa[U6_lJiA[o00002_l0o`000ol0003o:=LXobSG:00<
obSG:003o`000?lNhAko7^4N00Ko7^4N0_l00008oc3?<0;o00003omB[E800ol0003oXUfRoj9MXP02
oj9MXP03o`000?nVFJKoYUVV00_oYUVV00?o0000omhQg_oN8Mh01OoN8Mh00ol0003olPgboo8=lP07
oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003okQ7^onhAkP0:onhAkP03o`000?o;=<_obcC;
00KobcC;00?o0000ofJII_mVVFH01_mVVFH01Ol0003oKY5^ofjAK_m^TFko000000So8MhQ00?o0000
oa[U6_lJiAX00_lJiAX00ol0003o0?l0o`3o0006o`3o00Co00003?lXebP00ol0003o7^4NoakQ7P08
oakQ7P?o00000_l`cc03o`000003ocg2?Ol0003oDZeB00goDZeB00?o0000oj9MX_nRGJ801?nRGJ80
0ol0003oYUVVojIIYP0:ojIIYP03o`000?oN8MkogR7N00GogR7N00?o0000oo8=l_ob3O801_ob3O80
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhAk_o^4Nh02oo^4Nh00ol0003obcC;ol/db`07ol/d
b`03o`000?mVVFKoIYUV00?oIYUV0_l00005ofjAKP03o`000?lQgR7o8MhQ00Co8MhQ00?o0000oa[U
6_lJiAX00olJiAX00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200;o0_d20ol00007obSG
:0;o00003_lNhAh2o`0000Go?L8m00?o0000oe:]D_mB[E802_mB[E800ol0003oXUfRoj9MXP05oj9M
XP03o`000?nVFJKoYUVV00_oYUVV00?o0000omhQg_oN8Mh01?oN8Mh00ol0003olPgboo8=lP06oo8=
lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000oo`3o?ol0o`03?ol0o`00ol0003okQ7^onhAkP0;onhAkP03o`000?o;=<_obcC;00Oo
bcC;00?o0000ofJII_mVVFH00_mVVFH00ol0003oKY5^ofjAKP06ofjAKP03o`000?lQgR7o8MhQ00;o
8MhQ00?o0000oa[U6_lJiAX01OlJiAX00ol0003o0?l0o`3o0002o`3o00;o00002?l2o@83o`0000;o
:=LX0_l000000ol6n@Ko0000oakQ7P0=oakQ7P03o`000?lm`Sgo?L8m00Go?L8m00?o0000oe:]D_mB
[E802?mB[E800ol0003oXUfRoj9MXP07oj9MXP03o`000?nVFJKoYUVV00[oYUVV00?o0000omhQg_oN
8Mh01?oN8Mh00ol0003olPgboo8=lP06oo8=lP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000oo`3o?ol0o`02ool0o`00ol0003okQ7^
onhAkP0<onhAkP03o`000?o;=<_obcC;00SobcC;00Co0000ofJII_mVVFKo00002Om^TFh01Ol0003o
8MhQob7N8OlQgR7o000000So6^DJ00Go0000o`3o0?l0o`3o0?l0o`00000=o`;m0P;o00001?l6n@H0
0ol0003o7^4NoakQ7P0;oakQ7P03o`000?lm`Sgo?L8m00Ko?L8m00?o0000oe:]D_mB[E801omB[E80
0ol0003oXUfRoj9MXP08oj9MXPCo00002?nVFJH00ol0003ogR7NomhQgP04omhQgP03o`000?ob3O;o
lPgb00KolPgb00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo0?loo`3o00:oo`3o003o`000?o^4NkokQ7^00_okQ7^0ol00009ol/d
b`03o`000?mVVFKo000000_oKY5^00?o0000ob7N8Ol000002_lJiAX00ol0003o0?l0o`00000?o`;m
0P03o`000?l6n@Ko1_T600;o1_T600?o0000oakQ7_lNhAh02olNhAh00ol0003o?L8mocg2?@06ocg2
?@03o`000?mB[E;oDZeB00KoDZeB00?o0000oj9MX_nRGJ802OnRGJ801?l0003ob3O8olPgb?o8=lP7
o`0000;oYUVV00?o0000omhQg_oN8Mh00ooN8Mh00ol0003olPgboo8=lP05oo8=lP03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;oo`3
o003o`000?o^4NkokQ7^00SokQ7^0ol00003ondBk@03o`000?o;=<_obcC;00OobcC;00?o0000ofjA
K_m^TFh02om^TFh00ol0003o6^DJoa[U6P0:oa[U6P03o`000?l2o@;o0_d200go0_d200?o0000o`Ki
1_l6n@H01?l6n@H00ol0003o7^4NoakQ7P09oakQ7P03o`000?lm`Sgo?L8m00So?L8m00?o0000oe:]
D_mB[E800omB[E82o`0000coXUfR00?o0000olPgb?o8=lP02?o8=lP<o`0000?olPgb0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?ol0ocoo0?l00Oo
o0?l00?o0000onhAk_o^4Nh01_o^4Nh3o`0000OokA;]00?o0000ol/dboo;=</01_o;=</00ol0003o
KY5^ofjAKP0;ofjAKP03o`000?lJiA[o6^DJ00Wo6^DJ0_l0000>o`;m0P03o`000?l6n@Ko1_T600Go
1_T600?o0000oakQ7_lNhAh02OlNhAh00ol0003o?L8mocg2?@09ocg2?@03o`000?mB[E;o000000;o
00000_nGJ9L00ol0003oXUfRoj9MXP08oj9MXP03o`000?o8=lSob3O800cob3O800?o0000ondBkOo]
4^d01_o]4^d3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000oo`3o?ol0o`01_ol0o`00ol0003okQ7^onhAkP03onhAkP?o00002oo]4^d00ol0003obcC;
ol/db`04ol/db`03o`000?m^TFkoKY5^00_oKY5^0ol00007oa[U6P?o000000?o3_4>o`000?l2o@80
3Ol2o@800ol0003o1_T6o`Ki1P06o`Ki1P03o`000?lNhAko7^4N00So7^4N00?o0000ocg2?Olm`Sd0
2_lm`Sd00ol0003oUfRGoiMXU`04oiMXU`03o`000?nRGJ;oXUfR00OoXUfR00?o0000olPgb?o8=lP0
2oo8=lP00ol0003okA;]ondBk@08ondBk@03o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000oo`3o?ol0o`00ool0o`4o`000004onhAk_l0
003o0000o`0000ookA;]00?o0000ol/dboo;=</00oo;=</>o`0000?oEjQG0_l00002oa[U6P?o0000
1Ol>l@h00ol0003o0_d2o`;m0P0:o`;m0P03o`000?l6n@Ko1_T600Oo1_T600?o0000oakQ7_lNhAh0
2?lNhAh00ol0003o?L8mocg2?@0:ocg2?@03o`000?nGJ9OoUfRG00GoUfRG00?o0000oj9MX_nRGJ80
1_nRGJ800ol0003ob3O8olPgb00;olPgb003o`000?o]4^gokA;]00SokA;]00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?ol
0oco000000;o00001?ol0o`2o`0001;okA;]00?o0000ol/dboo;=</00_o;=</00ol0003o^dBkok]4
^`0:ok]4^`03o`000?mGZ5OoEjQG00?oEjQG0_l00009o`ka3P03o`000?l2o@;o0_d200Wo0_d200?o
0000o`Ki1_l6n@H02?l6n@H2o`0000So7^4N00?o0000ocg2?Olm`Sd02Olm`Sd00ol0003oUfRGoiMX
U`07oiMXU`03o`000?nRGJ;oXUfR00CoXUfR00?o0000olPgb?o8=lP02oo8=lP00ol0003okA;]ondB
k@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003okA;]ondBk@0?ondBk@?o000000?obcC;
o`000?nkA;/02onkA;/00ol0003oEjQGoeNXE`04oeNXE`03o`000?l>l@ko3_4>00Wo3_4>00?o0000
o`;m0_l2o@801ol2o@800ol0003o1_T6o`Ki1P09o`Ki1P04o`000?lCk1?o0000o`0000Ko7^4N00?o
0000ocg2?Olm`Sd02Olm`Sd00ol0003oUfRGoiMXU`08oiMXU`03o`000?nRGJ;oXUfR00?oXUfR00?o
0000olPgb?o8=lP02oo8=lP00ol0003okA;]ondBk@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003okA;]ondBk@0<ondBk@;o00000oo/4n`2o`0000co^dBk00?o0000oeNXEomGZ5L01?mGZ5L0
0ol0003o3_4>o`ka3P0:o`ka3PWo00002ol6n@H00ol0003o4n`Coa?/4`02oa?/4`?o00000_lNhAh0
0ol0003o?L8mocg2?@0:ocg2?@03o`000?nGJ9OoUfRG00WoUfRG00?o0000oj9MX_nRGJ800_nRGJ80
0ol0003ob3O8olPgb00:olPgb003o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o]4^d2o`0000Gok1?/00?o0000oldbcOl000002_nkA;/00ol0003oEjQGoeNXE`06oeNX
E`03o`000?l>l@ko3_4>00Wo3_4>00?o0000o`3o0?l0o`001Ol0o`000ol0003o1_T6o`Ki1P09o`Ki
1P03o`000?lCk1?o4n`C00Go4n`C0ol00009ocg2?@?o00003OnGJ9L01Ol0003oXUfRoj9MX_nRGJ;o
000000cob3O800?o0000ondBkOo]4^d02Oo]4^d00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000ondB
kOo]4^d01Oo]4^d2o`0000Ook1?/00Co0000oldbcOo=</go00002OnkA;/00ol0003oEjQGoeNXE`06
oeNXE`03o`000?l>l@ko3_4>00So3_4>00?o0000o`3o0?l0o`001ol0o`000ol0003o1_T6o`Ki1P07
o`Ki1P03o`000?lCk1?o4n`C00So4n`C0ol00002ocg2?@Go00000_mkQ7/00ol0003oUfRGoiMXU`0<
oiMXU`03o`000?nRGJ;o000000cob3O800?o0000ondBkOo]4^d02_o]4^d00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000ondBkOo]4^d00_o]4^d2o`0000Sok1?/00?o0000oldbcOo=</d00_o=</d5o`00
00Co^dBk00?o0000oeNXEomGZ5L01_mGZ5L00ol0003o3_4>o`ka3P08o`ka3P03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Ki1_l6n@H01ol6n@H00ol0003o4n`Coa?/4`08oa?/4`03o`000?m0_d3o@;m0
00;o00002?mkQ7/00ol0003oUfRGoiMXU`0<oiMXU`Co00002_o8=lP00ol0003okA;]ondBk@0:ondB
k@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003okA;]o`000?l0000:on`Ck003o`000?o=</gocC;=
00;ocC;=00?o0000oieRWOnMHYd00_nMHYd4o`0000WoEjQG00?o0000o`ka3_l>l@h02?l>l@h00ol0
003o0?l0o`3o0008o`3o0003o`000?l6n@Ko1_T600Go1_T600?o0000oa?/4olCk1<02?lCk1<01Ol0
003o@;m0od2o@?m0_d3o000000[oNhAk0ol0000;oiMXU`04o`000?oR7N;ohQgRon8MhPCo00001Oo8
=lP00ol0003okA;]ondBk@0;ondBk@03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003ok1?/on`Ck00:
on`Ck003o`000?o=</gocC;=00?ocC;=00?o0000oieRWOnMHYd01?nMHYd00ol0003oEjQGoeNXE`07
oeNXE`03o`000?l>l@ko3_4>00Ko3_4>0_l0000;o`3o0003o`000?l6n@Ko1_T600Go1_T600?o0000
oa?/4olCk1<02?lCk1<00ol0003o@;m0od2o@002od2o@003o`000?mkQ7_oNhAk00OoNhAk00?o0000
oklo_ono?kl01?l00006oiMXU`03o`000?oR7N;ohQgR00KohQgR0ol00002olPgb003o`000?o]4^go
kA;]00_okA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/4ncok1?/00Wok1?/00?o0000oldb
cOo=</d01?o=</d00ol0003oWF:MoieRW@05oieRW@03o`000?mGZ5OoEjQG00OoEjQG00?o0000o`ka
3_l>l@h00_l>l@h3o`000003oagR7Ol0003o0?l000[o0?l000?o0000o`Ki1_l6n@H01Ol6n@H00ol0
003o4n`Coa?/4`07oa?/4`03o`000?m0_d3o@;m000?o@;m000?o0000og^4NomkQ7/01omkQ7/00ol0
003o_cnooklo_`04oklo_`?o00000_nGJ9L00ol0003ohQgRon8MhP0:on8MhP;o00003_o]4^d00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000on`Ck?o/4n`02Oo/4n`00ol0003ocC;=oldbc@04oldbc@03
o`000?nMHYgoWF:M00KoWF:M0_l00007oeNXE`03o`000?l>l@ko000000;o00001OlMhQd00ol0003o
0?l0o`3o0008o`3o00?o00001?l6n@H00ol0003o4n`Coa?/4`08oa?/4`03o`000?m0_d3o@;m000Co
@;m000?o0000og^4NomkQ7/01_mkQ7/00ol0003o_cnooklo_`07oklo_`;o00003_oR7N800ol0003o
kA;]ondBk@0;ondBk@03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ok1?/on`Ck008on`Ck003o`00
0?o=</gocC;=00GocC;=00?o0000oieRWOnMHYd01?nMHYd00ol0003oTfbCoi=/T`03o`0000CoEjQG
0_l00008oagR7@03o`000?l0o`3o0?l000Oo0?l000Co0000obOH9olWf2Oo9mPW0ol000000ol6n@Ko
0000oa?/4`09oa?/4`03o`000?m0_d3o@;m000Co@;m000?o0000og^4NomkQ7/01OmkQ7/00ol0003o
_cnooklo_`09oklo_`03o`000?oR7N;ohQgR00gohQgR00?o0000ondBkOo]4^d02_o]4^d00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000on`Ck?o/4n`01oo/4n`00ol0003ocC;=oldbc@06oldbc@03o`00
0?nMHYgoWF:M00?oWF:M00?o0000oi=/TonCK9<01?nCK9<2o`000003oeNXEol0003o7N8M00[o7N8M
00?o0000o`3o0?l0o`001Ol0o`000ol0003o9mPWobOH9`05obOH9`03o`000?lCk1?o4n`C00Oo4n`C
0ol00007od2o@003o`000?mkQ7_oNhAk00CoNhAk00?o0000oklo_ono?kl02Ono?kl00ol0003ohQgR
on8MhP0=on8MhP03o`000?o]4^gokA;]00[okA;]00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o/
4ncok1?/00Gok1?/0ol00009oldbc@05o`000?nMHYgoWF:MoieRWOl000002OnCK9<00ol0003o7N8M
oagR7@0;oagR7@03o`000?l0o`3o0?l000?o0?l000?o0000obOH9olWf2L01_lWf2L00ol0003o4n`C
oa?/4`06oa?/4`05o`000?ln`Cko?/4nock1?_l000001om0_d000ol0003oNhAkog^4N`03og^4N`03
o`000?no?koo_cno00Wo_cno00?o0000on8Mh_oR7N803_oR7N800ol0003okA;]ondBk@09ondBk@03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003ok1?/o`000004o`0000;olPgb00?o0000oldbcOo=</d0
1oo=</d01?l0003oWF:MoieRWOl00009oi=/T`;o00003OlMhQd00ol0003o0?l0o`3o0002o`3o0003
o`000?lWf2Oo9mPW00So9mPW00?o0000oa?/4olCk1<00olCk1<2o`0000Go?/4n00?o0000od2o@?m0
_d001?m0_d000ol0003oNhAkog^4N`03og^4N`03o`000?no?koo_cno00Wo_cno00?o0000on8Mh_oR
7N803_oR7N800ol0003okA;]ondBk@09ondBk@03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000SolPgb
00?o0000oldbcOo=</d01_o=</d00ol0003oWF:Mo`000009oi=/T`04o`000?mTVfCoI9]To`0000go
7N8M00Co0000o`3o0?l0o`3o00003?lWf2L01Ol0003o4n`Coa?/4olCk1?o000000So?/4n0_l00005
od2o@003o`000?mkQ7_oNhAk00;oNhAk00?o0000oklo_ono?kl02Ono?kl00ol0003ohQgRon8MhP0>
on8MhP03o`000?o]4^gokA;]00WokA;]00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ob3O;olPgb
00OolPgb00?o0000oldbcOo=</d01oo=</d00ol0003oTfbCoi=/T`07oi=/T`03o`000?mTVfCoI9]T
00;oI9]T00?o0000oagR7OlMhQd02_lMhQd00ol0003o0?l0o`00000>obOH9`03o`000?lCk1?o0000
00_o?/4n00?o0000od2o@?m0_d000_m0_d001Ol0003oNhAkog^4NomkQ7_o000000co_cno00?o0000
on8Mh_oR7N803_oR7N83o`0000WokA;]00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb
00WolPgb00?o0000oldbcOo=</d01_o=</d00ol0003oTfbCoi=/T`06oi=/T`03o`000?mTVfCoI9]T
00?oI9]T00?o0000oagR7OlMhQd02olMhQd00ol0003o9mPWobOH9`0>obOH9`03o`000?ln`Cko?/4n
00_o?/4n0_l00003od2o@004o`000?mkQ7_oNhAko`0000[o_cno0ol0000>on8MhP;o00000oom0_d2
o`0000OokA;]00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb00[olPgb00?o0000oldb
cOo=</d01?o=</d00ol0003oTfbCoi=/T`06oi=/T`03o`000?mTVfCoI9]T00GoI9]T00?o0000oagR
7OlMhQd01olMhQd3o`00017o9mPW00?o0000ock1?_ln`Ch03Oln`Ch01Ol0003o@;m0od2o@?l0003o
NhAk00Co00000ono?kl5o`0000;okQ7^00?o0000on8Mh_oR7N802_oR7N82o`0000Ooo@;m0_l00004
ondBk@03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003olPgboo8=lP0;oo8=lP03o`000?o=</gocC;=
00CocC;=00?o0000oi=/TonCK9<01OnCK9<00ol0003oI9]TofBKI006ofBKI003o`000?lMhQgo7N8M
00Co7N8M0ol00002ob?L8`03o`000?lWf2Oo9mPW00oo9mPW0_l0000?ock1?P04o`000?m0_d3o0000
o`0000Co[E:]0ol00008onhAkP03o`000?oR7N;ohQgR00OohQgR0_l0000;ood2o@;o00000_o]4^d0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo8=l_ob3O803?ob3O86o`0000OoTfbC00?o0000ofBK
I?mTVf@02?mTVf@00ol0003o7N8MoagR7@03o`0000Ko8m`S00?o0000obOH9olWf2L03OlWf2L01?l0
003oA[U6odJiA_l0000?ock1?P03o`000?n]DZgo[E:]00Go[E:]00?o0000onhAk_o^4Nh02?o^4Nh0
0ol0003ohQgRon8MhP05on8MhP03o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ob3O800ol0003odbcCom</d`04om</
d`03o`000?nCK9?oTfbC00?oTfbC00?o0000ofBKI?mTVf@02_mTVf@2o`0000[o8m`S00?o0000obOH
9olWf2L02olWf2L00ol0003oA[U6odJiAP02odJiAP03o`000?ln`Cko?/4n00_o?/4n0_l00007ojeB
[@03o`000?o^4NkokQ7^00WokQ7^00?o0000on8Mh_oR7N800_oR7N82o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo8=l_ob3O802oob3O800ol0003odbcCom</d`06om</d`05o`000?nCK9?oTfbCoi=/
Tol000003OmTVf@00ol0003o8m`Sob?L8`0:ob?L8`03o`000?lWf2Oo9mPW00Wo9mPW00?o0000odJi
A_m6^DH01?m6^DH00ol0003o?/4nock1?P08ock1?P;o000000?oIYUVo`000?n]DZd01on]DZd00ol0
003okQ7^onhAkP09onhAkP04o`000?oR7N;o0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ob3O;olPgb
00WolPgb00?o0000om</dooC;=<02?oC;=<00ol0003oTfbCo`00000=ofBKI003o`000?lSg2?o8m`S
00_o8m`S00?o0000obOH9olWf2L02?lWf2L00ol0003oA[U6odJiAP06odJiAP03o`000?ln`Cko?/4n
00Go?/4n0_l00003ofJIIP03o`000?n]DZgo[E:]00Ko[E:]00?o0000onhAk_o^4Nh02_o^4Nh00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003olPgboo8=lP07oo8=lP03o`000?oC;=?odbcC00[odbcC00?o0000ofBKI?mT
Vf@03?mTVf@00ol0003o8m`Sob?L8`0<ob?L8`03o`000?lWf2Oo9mPW00Ko9mPW00?o0000odJiA_m6
^DH02?m6^DH00ol0003o?/4nock1?P02ock1?P;o00001_mVVFH00ol0003o[E:]ojeB[@05ojeB[@03
o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?ob3O;olPgb00GolPgb
00?o0000om</dooC;=<03?oC;=<2o`0000coI9]T00?o0000ob?L8olSg2<03OlSg2<00ol0003o9mPW
obOH9`04obOH9`03o`000?m6^DKoA[U600[oA[U600Co0000ock1?_l0003o00002?mVVFH00ol0003o
[E:]ojeB[@06ojeB[@03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_ob3O800ol0003odbcCom</d`0=om</d`03o`000?n@Ki3o000000;o00002?mTVf@00ol0003o8m`S
ob?L8`0?ob?L8`Ko00003_m6^DH00ol0003oIYUVofJIIP08ofJIIP03o`000?n]DZgo[E:]00Ko[E:]
00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo@;m?od2oCom0_d
0_l0000?om</d`03o`000?n@Ki3oT6n@00?oT6n@0ol00005ofBKI0;o00004?lSg2<01_l0003o8MhQ
ob7N8Ol0003o6NHIo`0000koA[U600?o0000ofJII_mVVFH02OmVVFH00ol0003o[E:]ojeB[@05ojeB
[@03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003o
dbcCom</d`0=om</d`03o`000?n@Ki3oT6n@00KoT6n@0ol000001?mTVfCo0000ocg2?Olm`Sd3o`00
00co8m`S00Go0000ob7N8OlQgR7o8MhQo`000002oaWV6@03o`000?m6^DKoA[U600_oA[U600?o0000
ofJII_mVVFH02OmVVFH00ol0003o[E:]ojeB[@06ojeB[@03o`000?o^4NkokQ7^00SokQ7^0_l0000A
ood2o@?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003om0_doo@;m004oo@;m0oo00003?n@Ki000ol0003o?L8mocg2?@04ocg2
?@?o00002?lSg2<00ol0003o8MhQob7N8@02ob7N8@05o`000?lIiQWo6NHIoaWV6Ol000003?m6^DH0
0ol0003oIYUVofJIIP09ofJIIP03o`000?n]DZgo[E:]00Go[E:]3?l00002ooP7n0;o00003Oom0_d2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003om0_doo@;m005oo@;m003o`000?oF:MKoeRWF00_oeRWF00?o0000oi1_
T?n@Ki002_n@Ki000ol0003o?L8mocg2?@07ocg2?@;o00001OlSg2<00ol0003o8MhQob7N8@03ob7N
8@03o`000?lIiQWo6NHI00;o6NHI00?o0000odJiA_m6^DH02Om6^DH00ol0003oIYUVofJIIP0:ofJI
IP03o`000?n]DZgo[E:]00?o[E:]00?o0000onLHiooW6>L02OoW6>L00ol0003on0OhooP7n002ooP7
n0;o00002Oom0_d2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m006oo@;m003o`000?oF:MKoeRWF00[o
eRWF00?o0000oi1_T?n@Ki002on@Ki000ol0003o?L8mocg2?@09ocg2?@?o000000?o8m`So`000?lQ
gR401OlQgR400ol0003o6NHIoaWV6@03oaWV6@03o`000?m6^DKoA[U600SoA[U63_l00003ojeB[@;o
00002ooW6>L00ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00?oo@;m0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo@;m?od2o@01Ood2o@00ol0003ogR7No`00000;omHYeP03o`000?n@Ki3oT6n@00[oT6n@
0_l0000>ocg2?@03o`000?lQgR7o8MhQ00Go8MhQ00?o0000oaWV6OlIiQT00olIiQT00ol0003oA[U6
odJiAP08odJiAP03o`000?nYEZWoZEJY00_oZEJY00?o0000ojeB[Ol000003OoW6>L00ol0003on0Oh
ooP7n006ooP7n0;o000000?oo@;mo`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00Kom0_d00Co
0000omhQg_oN8Mko00002_oF:MH00ol0003oT6n@oi1_T009oi1_T003o`000?mZUF[o000000ko?L8m
00?o0000ob7N8OlQgR401OlQgR400ol0003o6NHIoaWV6@04oaWV6@03o`000?m6^DKoA[U600KoA[U6
00?o0000ojUFZOnYEZT03OnYEZT00ol0003oiaSWonLHi`0<onLHi`03o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000omhQg_oN8Mh00_oN
8Mh00ol0003oeRWFomHYeP06omHYeP03o`000?n@Ki3oT6n@00SoT6n@0_l00003ofZEJP03o`000?lm
`Sgo?L8m00_o?L8m00?o0000ob7N8OlQgR401OlQgR400ol0003o6NHIoaWV6@05oaWV6@03o`000?m6
^DKoA[U600GoA[U600?o0000ojUFZOnYEZT03OnYEZT00ol0003oiaSWonLHi`0;onLHi`03o`000?oh
1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000
omhQg_oN8Mh00ooN8Mh00ol0003oeRWFomHYeP05omHYeP03o`000?n@Ki3oT6n@00OoT6n@00?o0000
ofZEJ_mZUFX00omZUFX00ol0003o?L8mocg2?@0:ocg2?@03o`000?lQgR7o8MhQ00Ko8MhQ00?o0000
oaWV6OlIiQT01_lIiQT00ol0003oA[U6odJiAP04odJiAP03o`000?nYEZWoZEJY00goZEJY3ol0000;
ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000omhQg_oN8Mh01OoN8Mh00ol0
003oeRWFomHYeP04omHYeP03o`000?n@Ki3oT6n@00GoT6n@0_l00006ofZEJP03o`000?lm`Sgo?L8m
00Wo?L8m0_l00008ob7N8@03o`000?lIiQWo6NHI00Ko6NHI1Ol000000om6^DKo0000ojUFZ@0?ojUF
Z@03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000omhQg_oN8Mh01_oN8Mh00ol0003o
eRWFomHYeP04o`0000KoT6n@00?o0000ofZEJ_mZUFX01omZUFX00ol0003o?L8mocg2?@05ocg2?@?o
000000?o<Lhao`000?lQgR401olQgR400ol0003o6NHIoaWV6@05oaWV6@03o`000?mJYE[oFZEJ00?o
FZEJ0_l0000?ojUFZ@;o00003OoZ5NX00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wom0_d00?o0000omhQg_oN8Mh01ooN8Mh2o`0000Co^4Nh00Co0000oi1_T?n@Ki3o
T6n@0_l0000:ofZEJP03o`000?lm`Sgo?L8m00;o?L8m0ol00005oc7><@03o`000?lQgR7o8MhQ00Go
8MhQ00?o0000oaWV6OlIiQT01?lIiQT00ol0003oFZEJoeZUFP06oeZUFP03o`000?nYEZWoZEJY00[o
ZEJY0_l00002om0_d003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000ooP7n?oh1oP02?oh1oP00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@01_od2o@00ol0003ogR7NomhQgP08omhQgP03o`00
0?nhAkSo^4Nh00Co^4Nh00?o0000oi1_T?l000003?mZUFX00ol0003o?L8mo`000002o`0000Wo<Lha
00?o0000ob7N8OlQgR401?lQgR400ol0003o6NHIoaWV6@03oaWV6@03o`000?mJYE[oFZEJ00SoFZEJ
1_l00004ojUFZ@;o00001Oo@;m000ol0003ojQGZonXEjP09onXEjP03o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000omhQg_oN8Mh01ooN
8Mh00ol0003o^4NhokQ7^006okQ7^003o`000?mZUF[oJYEZ00coJYEZ00?o0000oc7><OlacS402_la
cS400ol0003o8MhQob7N8@04ob7N8@04o`000?lIiQWo6NHIoaWV6@;o00002omJYEX00ol0003o[U6^
ojiA[P03ojiA[PCo00002?o@;m000ol0003ojQGZonXEjP08onXEjP03o`000?oh1oSon0Oh00Oon0Oh
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003ogR7NomhQgP07omhQgP03o`000?nh
AkSo^4Nh00Oo^4Nh00?o0000ofZEJ_mZUFX03?mZUFX00ol0003o<Lhaoc7><@0;oc7><@03o`000?lQ
gR7o8MhQ00?o8MhQ00Co0000oaWV6OlIiQWo00003OmJYEX00ol0003o[U6^ojiA[P06ojiA[P03o`00
0?o@;m3od2o@00Ood2o@00?o0000onXEj_oZ5NX01ooZ5NX00ol0003on0OhooP7n006ooP7n004o`00
0?on0OkooP7nooh1oP;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00;om0_d00?o0000omhQg_oN8Mh0
1_oN8Mh00ol0003o^4NhokQ7^009okQ7^003o`000?mZUF[oJYEZ00WoJYEZ0_l0000>oc7><@?o0000
0olQgR400ol0003o6NHIo`00000=oeZUFP03o`000?n^DJko[U6^00Oo[U6^00?o0000om0_d?o@;m00
2?o@;m0:o`0000Kon0Oh0_l00006ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OogR7N00?o
0000okQ7^?nhAkP02_nhAkP00ol0003oJYEZofZEJP06ofZEJP;o000000?oHiaSo`000?lacS402ola
cS42o`0000?oAKY51Ol0000>oeZUFP03o`000?n^DJko[U6^00Oo[U6^00?o0000om0_d?o@;m002?o@
;m000ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh01oon
0Oh2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003ok1?/on`Ck003on`Ck0Co00000_oN8Mh00ol0003o^4NhokQ7^00;
okQ7^003o`000?mZUF[oJYEZ00?oJYEZ0ol00004of>LH`03o`000?lacS7o<Lha00Oo<Lha0_l00008
odFjA@03o`000?mJYE[oFZEJ00goFZEJ00?o0000ojiA[_n^DJh02?n^DJh00ol0003od2o@om0_d007
om0_d003o`000?o_4>ooka3_00Ooka3_0ol000000ooh1oSo0000ooh1oP0;ooh1oP;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o/4ncok1?/00Ook1?/0_l0000?okQ7^003o`000?mZUF[oJYEZ00;o00002?mSW6<00ol0
003o<Lhaoc7><@05oc7><@03o`000?m5^TGoAKY500SoAKY500?o0000oeZUF_mJYEX03OmJYEX00ol0
003o[U6^ojiA[P08ojiA[P03o`000?o@;m3od2o@00Kod2o@00?o0000onl@koo_4>l02?o_4>l01?l0
003on@KiooT6nOl0000?ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003ok1?/on`Ck009on`C
k003o`000?nhAkSo^4Nh00ko^4Nh0_l0000;of>LH`03o`000?lacS7o<Lha00;o<Lha0_l0000;odFj
A@03o`000?mJYE[oFZEJ00goFZEJ00?o0000ojiA[_n^DJh02?n^DJh00ol0003od2o@om0_d006om0_
d003o`000?o_4>ooka3_00Ooka3_00Go0000ooT6nOoi1_Won@Kio`00000@ooh1oP;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003ok1?/on`Ck00:on`Ck003o`000?nhAkSo^4Nh00go^4Nh0_l0000<of>LH`04o`000?lacS7o0000
o`0000goAKY500?o0000oeZUF_mJYEX03?mJYEX00ol0003o[U6^ojiA[P09ojiA[P03o`000?o@;m3o
d2o@00Kod2o@00?o0000onl@koo_4>l01_o_4>l00ol0003on@KiooT6n@03ooT6n@03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003ok1?/on`Ck00:on`Ck003o`000?nhAkSo^4Nh00co^4Nh00Co0000ojiA
[_n^DJko00003?mSW6<00ol0003oAKY5odFjA@0>odFjA@03o`000?mJYE[oFZEJ00SoFZEJ1?l0000;
ojiA[P03o`000?o@;m3od2o@00Kod2o@00?o0000onl@koo_4>l01Oo_4>l00ol0003on@KiooT6n@04
ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003ok1?/on`Ck00;on`Ck003o`000?nhAkSo^4Nh
00_o^4Nh00?o0000ojiA[_n^DJh00_n^DJh00ol0003oHiaSof>LH`09of>LH`03o`000?m5^TGoAKY5
00koAKY500Co0000oeZUF_mJYE[oFZEJ1ol00003og^4N`03o`000?n^DJko[U6^00Wo[U6^00?o0000
om0_d?o@;m001_o@;m000ol0003oka3_onl@k`04onl@k`03o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o/4ncok1?/00cok1?/00?o0000okQ7^?nhAkP02_nhAkP00ol0
003o[U6^ojiA[P03ojiA[P03o`000?mSW6?oHiaS00SoHiaS00?o0000odFjAOm5^TD03_m5^TD4o`00
00_oNhAk00?o0000ojiA[_n^DJh02?n^DJh00ol0003od2o@om0_d005om0_d003o`000?o_4>ooka3_
00Goka3_00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000on`Ck?o/
4n`03?o/4n`7o`0000Go^4Nh00?o0000ojiA[_n^DJh01On^DJh00ol0003oHiaSof>LH`07of>LH`03
o`000?m5^TGoAKY500koAKY500?o0000og^4NomkQ7/03OmkQ7/00ol0003o[U6^ojiA[P08ojiA[P03
o`000?o@;m3od2o@00Cod2o@00?o0000onl@koo_4>l01?o_4>l00ol0003on@KiooT6n@07ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003ok1?/on`Ck00=on`Ck003o`000?oD:mCoe2_D00Coe2_D
1Ol00009ojiA[P03o`000?mSW6?oHiaS00KoHiaS00?o0000odFjAOm5^TD03_m5^TD00ol0003oNhAk
og^4N`0=og^4N`03o`000?n^DJko[U6^00So[U6^00Co0000om0_d?o@;m3od2o@1Ol00004onl@k`03
o`000?oi1_Won@Ki00Won@Ki1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=on`Ck003o`000?oD:mCoe2_D00Woe2_D
0_l00009ojiA[P03o`000?mSW6?oHiaS00KoHiaS00?o0000odFjAOm5^TD03?m5^TD00ol0003oNhAk
og^4N`0?og^4N`Ko00001?n^DJh4o`0000GojAKY0_l000000oo_4>oo0000ooT6n@0;ooT6n@04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?oe2_Gom@[eooD:m@?o00002_o/4n`00ol0003o
e2_Dom@[e009om@[e003o`000?nm@[go000000;o00001on^DJh00ol0003oHiaSof>LH`05of>LH`03
o`000?m5^TGoAKY500SoAKY51Ol0000Aog^4N`03o`000?nm@[go_D:m00?o_D:m1?l0000;onTFj@03
o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000ooD:mOoe2_D01Ooe2_D2o`0000Ook1?/
00?o0000om@[e?oD:m@02_oD:m@00ol0003o_D:moke2_@02oke2_@?o00001On^DJh00ol0003oHiaS
of>LH`04of>LH`04o`000?m5^TGoAKY5odFjA@Oo00001?maSW400ol0003oNhAkog^4N`0>og^4N`03
o`000?nm@[go_D:m00Oo_D:m00?o0000onTFjOoY5^T02OoY5^T00ol0003on@KiooT6n@09ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003om@[eooD:m@08ooD:m@;o00001?o/4n`00ol0003oe2_D
om@[e00;om@[e003o`000?nm@[go_D:m00Go_D:m0ol00003ojiA[P04o`000?mSW6?oHiaSof>LH`Ko
00003?maSW400ol0003oNhAkog^4N`0=og^4N`03o`000?nm@[go_D:m00Oo_D:m00?o0000onTFjOoY
5^T02_oY5^T00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ooD:m@?o000000?ok1?/o`000?oD:m@0
3?oD:m@00ol0003o_D:moke2_@08oke2_@?o000000Co[U6^o`000?l0003o00000_n_D:l00ol0003o
LHiaog6>L@0=og6>L@03o`000?mkQ7_oNhAk00coNhAk00?o0000oke2_Onm@[d02?nm@[d00ol0003o
jAKYonTFj@0;onTFj@03o`000?oi1_Won@Ki00Kon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
m@[e00?o0000om@[e?oD:m@03?oD:m@00ol0003o_D:moke2_@0;oke2_@03o`000?n_D:oo[e2_00?o
[e2_00?o0000og6>LOmaSW403?maSW400ol0003oPWf2o`00000=og^4N`03o`000?nm@[go_D:m00So
_D:m00?o0000onTFjOoY5^T03?oY5^T3o`0000Gon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oe2_Gom@[e00com@[e00?o0000om@[e?oD:m@03?oD:m@00ol0003o_D:moke2_@0:oke2_@03o`00
0?n_D:oo[e2_00Go[e2_00?o0000og6>LOmaSW402_maSW401?l0003oPWf2oh9mP_n2OH82o`0000[o
NhAk00?o0000oke2_Onm@[d02Onm@[d00ol0003ojAKYonTFj@0<onTFj@03o`000?oi1_Won@Ki00?o
000000?on@Kio`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000om@[e?oD:m@0
3?oD:m@00ol0003o_D:moke2_@09oke2_@03o`000?n_D:oo[e2_00Ko[e2_00?o0000og6>LOmaSW40
2OmaSW400ol0003oPWf2oh9mPP02oh9mPP03o`000?naC[7o000000;o00001omkQ7/00ol0003o_D:m
oke2_@09oke2_@03o`000?oY5^WojAKY00_ojAKY00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000ooD:mOoe2_D02ooe2_D00ol0003oe2_Dom@[e00;om@[e003o`000?nm
@[go_D:m00So_D:m00?o0000ojm@[on_D:l01on_D:l00ol0003oLHiaog6>L@08og6>L@03o`000?n2
OH;oPWf200?oPWf200?o0000ok5>/OnaC[400_naC[42o`0000CoNhAk00?o0000oke2_Onm@[d02_nm
@[d00ol0003ojAKYonTFj@0:onTFj@03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?oe2_Gom@[e00[om@[e0ol0000;om@[e0Ko00001?nm@[d00ol0003o[e2_ojm@[`08
ojm@[`03o`000?maSW7oLHia00OoLHia00?o0000oh9mP_n2OH800on2OH800ol0003o/Djaok5>/@05
ok5>/@?o000000?oNhAko`000?nm@[d02onm@[d00ol0003ojAKYonTFj@09onTFj@03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oe2_Gom@[e00Wom@[e00?o0000on`C
k?o/4n`01?l00006om@[e003o`000?oE:]GoeB[E00CoeB[E1?l0000<ojm@[`03o`000?maSW7oLHia
00GoLHia00?o0000oh9mP_n2OH801?n2OH800ol0003o/Djaok5>/@08ok5>/@03o`000?nm@[go_D:m
00_o_D:m00?o0000onTFjOoY5^T02?oY5^T00ol0003on@KiooT6n@08ooT6n@Go00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?oe2_Gom@[e00Oom@[e00?o0000on`Ck?o/4n`01Oo/4n`3o`0000;oe2_D00?o0000omDZeOoE
:]D02?oE:]D00ol0003o[e2_ojm@[`0:ojm@[`03o`000?maSW7oLHia00CoLHia00?o0000oh9mP_n2
OH801On2OH800ol0003o/Djaok5>/@08ok5>/@03o`000?nm@[go_D:m00Wo_D:m1?l00008onTFj@03
o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[e
ooD:m@05ooD:m@03o`000?o/4ncok1?/00Wok1?/0_l0000<omDZe@03o`000?n_D:oo[e2_00Wo[e2_
00?o0000og6>LOmaSW400omaSW400ol0003oPWf2oh9mPP05oh9mPP03o`000?naC[7o/Dja00[o/Dja
00?o0000oke2_Onm@[d01?nm@[d4o`0000CohacS00?o0000onTFjOoY5^T01?oY5^T00ol0003on@Ki
ooT6n@0:ooT6n@03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oe2_Gom@[e00?om@[e00?o0000on`Ck?o/4n`02oo/
4n`00ol0003oeB[EomDZe@0:omDZe@03o`000?n_D:oo[e2_00Wo[e2_00?o0000og6>LOmaSW400_ma
SW400ol0003oPWf2oh9mPP06oh9mPP03o`000?naC[7o/Dja00[o/Dja00?o0000oke2_Onm@[d01?l0
0009on<Lh`Ko00003?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000ooD:mOoe2_Gom@[e0_l0
000=on`Ck003o`000?oE:]GoeB[E00[oeB[E00?o0000ojm@[on_D:l02On_D:l01Ol0003oLHiaog6>
LOmaSW7o000000WoPWf200?o0000ok5>/OnaC[402onaC[42o`0000gohacS00?o0000ooP7n?oh1oP0
0_oh1oP00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om@[eo`00
0002oo/4n`;o00002oo/4n`00ol0003oeB[EomDZe@0;omDZe@03o`000?n_D:oo[e2_00Wo[e2_00?o
0000og6>LOl000002On2OH800ol0003o/Djaok5>/@0<ok5>/@03o`000?oS7>?ohacS00cohacS00?o
0000ooP7n?oh1oP00ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on`Ckoo/4n`03oo/4n`;o00002_o/4n`00ol0003oeB[EomDZe@0:omDZe@03o`000?n_D:oo
[e2_00So[e2_1Ol00008oh9mPP03o`000?naC[7o/Dja00co/Dja00?o0000on<LhooS7><02ooS7><0
0ol0003on0OhooP7n005ooP7n003o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001ook1?/2o`0000Sok1?/00?o0000omDZeOoE:]D02_oE:]D00ol0003o[e2_ojm@[`07ojm@
[`03o`000?neB[Go]DZe00?o]DZe0ol00005oh9mPP03o`000?naC[7o/Dja00_o/Dja00?o0000on<L
hooS7><03?oS7><00ol0003on0OhooP7n006ooP7n003o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?on0Oko000000Won`Ck00?o0000on`Ck?o/4n`01Oo/4n`2o`0000co
eB[E00?o0000ojm@[on_D:l01On_D:l00ol0003o]DZeokE:]@07okE:]@?o000000?oPWf2o`000?na
C[403OnaC[400ol0003ohacSon<Lh`0<on<Lh`03o`000?oh1oSon0Oh00Kon0Oh00?o0000ooT6nOoi
1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ooh1oP03o`000?ok1?_on`Ck00Oon`Ck
0_l00004on`Ck003o`000?oa3_7ol@ka00;o00002_oE:]D00ol0003o[e2_ojm@[`03ojm@[`;o0000
3OneB[D2o`0000go/Dja0ol0000=on<Lh`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T0
1Ooi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00Son`Ck0_l0
00000oo/4nco0000oo4>l@04oo4>l@03o`000?oE:]GoeB[E00OoeB[E00Co0000ojm@[on_D:oo[e2_
0_l00002omTVf@03o`000?neB[Go]DZe00co]DZe3Ol00003onDJi@03o`000?oS7>?ohacS00[ohacS
00?o0000ooP7n?oh1oP02?oh1oP01?l0003on@KiooT6nOoi1_T4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?on0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oa3_7ol@ka00Gol@ka0_l00008omDZe@03o`000?n_D:oo000000GofBKI
00?o0000okE:]OneB[D02oneB[D00ol0003o`Sg2ol8m`P09ol8m`P03o`000?oU6^GoiA[U00;oiA[U
0_l00009on<Lh`03o`000?oh1oSon0Oh00[on0Oh0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ooh1
oP0:ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000oo4>lOoa3_401ooa3_44o`0000?oeB[E0ol0
0007omTVf@03o`000?neB[Go]DZe00[o]DZe00?o0000ol8m`_o2?L802Oo2?L800ol0003oiA[UonDJ
i@04onDJi@;o00001ooS7><00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo4>lOoa3_402?oa3_40
1?l0003ol0o`oo0?l?o`3o03o`0000;oj1OX00?o0000omTVfOoI9]T01_oI9]T00ol0003o]DZeokE:
]@08okE:]@03o`000?o2?L;o`Sg200[o`Sg200?o0000onDJiOoU6^D01_oU6^D00ol0003ohacSon<L
h`04on<Lh`03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003ol@kaoo4>l@08oo4>l@03o`000?o`3o3o
l0o`00Col0o`00Go0000onPGj?oX5nSoj1OXo`000008omTVf@03o`000?neB[Go]DZe00Oo]DZe00?o
0000ol8m`_o2?L802_o2?L800ol0003oiA[UonDJi@07onDJi@;o00001?oS7><00ol0003on0OhooP7
n008ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003ol@kaoo4>l@08oo4>l@03o`000?o`3o3ol0o`00Col0o`00?o0000onPGj?oX5nP00_oX5nP0
0ol0003ofBKIomTVf@07omTVf@03o`000?neB[Go]DZe00Ko]DZe00?o0000ol8m`_o2?L802_o2?L80
0ol0003oiA[UonDJi@09onDJi@05o`000?oS7>?ohacSon<Lhol000002Ooh1oP00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ol@ka00?o0000oo0?l?o`3o001?o`3o000ol0003oj1OXonPGj003
onPGj003o`000?oI9]WofBKI00OofBKI00?o0000okE:]OneB[D01OneB[D00ol0003o`Sg2ol8m`P0:
ol8m`P03o`000?oU6^GoiA[U00WoiA[U1?l00009ooP7n003o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ok1?_on`Ck
oo/4nol000002_oa3_400ol0003ol0o`oo0?l005oo0?l003o`000?oX5nSoj1OX00?oj1OX00?o0000
omTVfOoI9]T02?oI9]T00ol0003o]DZeokE:]@04okE:]@03o`000?o2?L;o`Sg200Wo`Sg200?o0000
onDJiOoU6^D02?oU6^D2o`0000?on0Oh00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003ol@kaoo4>l@06oo4>l@03o`000?o`3o3ol0o`
00Gol0o`00?o0000onPGj?oX5nP01?oX5nP00ol0003ofBKIomTVf@09omTVf@03o`000?neB[Go]DZe
00;o]DZe00?o0000ol8m`_o2?L802_o2?L800ol0003oiA[UonDJi@06onDJi@;o00001_oh1oP8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?oa3_7ol@ka00Gol@ka00?o0000oo0?l?o`
3o001Oo`3o000ol0003oj1OXonPGj005onPGj003o`000?oI9]WofBKI00WofBKI00Go0000okE:]One
B[Go]DZeo`00000<ol8m`P03o`000?oU6^GoiA[U00CoiA[U0_l00008ooP7n003o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo4>lOoa
3_400ooa3_400ol0003ol0o`oo0?l006oo0?l003o`000?oX5nSoj1OX00Goj1OX00?o0000omTVfOoI
9]T02_oI9]T00ol0003o]DZeo`000004o`0000Wo`Sg200?o0000onDJiOoU6^D00_oU6^D2o`0000[o
n0Oh00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`00
0?oa3_7ol@ka00;ol@ka00?o0000oo0?l?o`3o001_o`3o000ol0003oj1OXonPGj007onPGj0;o0000
2ooI9]T00ol0003ojaC[on/Dj`03on/Dj`Oo00000_o2?L800ol0003oiA[UonDJi@02o`0000_on0Oh
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/02Ook
1?/01Ol0003ol@kaoo4>lOoa3_7o000000Sol0o`00?o0000onPGj?oX5nP01ooX5nP00ol0003om0_d
o`000002o`0000SofBKI00?o0000on/Djoo[5>/02_o[5>/5o`0000gon0Oh00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo/4n`03o`000?oa3_7o000000Wol0o`00?o
0000onPGj?oX5nP01_oX5nP00ol0003om0_doo@;m003oo@;m0?o00001?oI9]T00ol0003ojaC[on/D
j`0=on/Dj`03o`000?oh1oSon0Oh00gon0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on`Ck00?o0000oo0?l?o`3o001oo`3o000ol0003oj1OXonPGj007
onPGj003o`000?od2oCom0_d00Kom0_d0ol000000ooI9]Wo0000on/Dj`0>on/Dj`03o`000?oh1oSo
n0Oh00con0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009oo/4
n`03o`000?o`3o3ol0o`00;ol0o`1_l00008onPGj003o`000?od2oCom0_d00[om0_d00?o0000on/D
joo[5>/03oo[5>/00ol0003on0OhooP7n00:ooP7n0;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007oo/4n`Go00001_oh1oP00ol0003oj1OXonPGj005onPGj003o`000?od2oCom0_d00[o
m0_d00?o0000on/Djoo[5>/03oo[5>/00ol0003on0OhooP7n007ooP7n0?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005oo/4n`03o`000?oh1oSon0Oh00Won0Oh00?o0000onPGj?oX
5nP00ooX5nP00ol0003om0_doo@;m00;oo@;m003o`000?o[5>_ojaC[00oojaC[00?o0000ooP7n?oh
1oP01Ooh1oP2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on`Cko`000?l00000
3Ooh1oP00ol0003oj1OXonPGj002onPGj003o`000?od2oCom0_d00_om0_d5?l00004ooP7n0;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooP7n004o`000?oX5nSoj1OXo`0000kom0_d
00?o0000ooT6nOoi1_T04?oi1_T00ol0003on0Oho`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_oh1oP00ol0003oj1OXo`00000>oo@;m003o`00
0?oi1_Won@Ki017on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n00=ooP7n003o`000?od2oCom0_d00Wom0_d1Ol0
000BooT6n@;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003on0OhooP7n00<ooP7n003o`000?od2oCom0_d00;om0_d1ol00004ooh1oP03o`000?oi1_Wo
n@Ki00oon@Ki00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?oh1oSon0Oh00con0Oh1?l0000<ooh1oP03o`000?oi1_Won@Ki00con@Ki0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooP7n?oh1oP03?oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?oi1_Won@Ki00_o
n@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00kooP7n00?o0000ooT6nOoi
1_T02Ooi1_T2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?oi1_Won@Ki00Kon@Ki0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aooh1oP?o00001_oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000ooi1_T2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ooT6nOl000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool01?l00?l9oooo00Ko003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Go003o2?ooo`05o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000co003o0_ooo`06o`00o`03oooo0?l00?oo003o00?o003o0_ooo`03o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Oo003o00?oool0o`00ool00?l00ol00?l01?oo
o`3o003oo`00ool00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool0
06_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo
00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`001Ol00?l<oooo00Co003o0_ooo`08o`00
o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o
003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co
003o0_ooo`05o`00o`Coool00_l00?l2oooo00Go003o3?ooo`05o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`02o`00o`04oooo
0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01?l00?l3oooo00Co
003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o0_ooo`09o`00o`03oooo0?l00?oo003o00Co
003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo
0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o
0_ooo`04o`00o`04oooo0?l00?ooool0oooo00Ko003o00?oool0o`00ool00?l00ol00?l2oooo00[o
003o00?oool0o`00ool00?l00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00
J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o
0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool01ol00?l00oooo`3o
003oo`00o`02o`00o`;oool02_l00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo
003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003o
o`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`00
1ol00?l2oooo00?o003o0_ooo`0;o`00o`03oooo0?l00?oo003o00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00
o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00So003o00Co
ool0o`00ool00?oo003o0_ooo`0;o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_oo
o`09o`00o`03oooo0?l00?oo003o00;oool02ol00?l2oooo00?o003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0G
o`00o`;oool02_l00?l01?ooo`3o003ooooo0?ooo`04o`00o`03oooo0?l00?oo003o00Co003o0_oo
o`03o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00[o003o00Coool0o`00ooooo`3oool01?l0
0?l2oooo00Go003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001X
o`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo
003o00So003o0oooo`05o`00o`;oool00ol00?l3oooo00Co003o0_ooo`04o`00o`;oool01_l00?l0
0olb</coool0oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00
ool00?l05_l00?l5oooo00Wo003o0_ooo`06o`00o`Koool01_l00?l2oooo00;o003o0_ooo`05o`00
o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo02Co
003o0_ooo`07o`00o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool0
0?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(430) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.994 .006 .994 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.98 .02 .98 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.993 .007 .993 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.98 .02 .98 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.972 .028 .972 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.959 .041 .959 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.989 .011 .989 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.956 .044 .956 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.994 .006 .994 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.902 .098 .902 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.918 .082 .918 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.99 .01 .99 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.84 .16 .84 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.943 .057 .943 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.987 .013 .987 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.99 .01 .99 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.978 .022 .978 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.704 .296 .704 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.955 .045 .955 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.883 .117 .883 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.878 .122 .878 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.904 .096 .904 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.936 .064 .936 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.962 .038 .962 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.855 .145 .855 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.931 .069 .931 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.779 .221 .779 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.957 .043 .957 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.926 .074 .926 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.877 .123 .877 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.927 .073 .927 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.756 .244 .756 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.948 .052 .948 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.874 .126 .874 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.96 .04 .96 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.799 .201 .799 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.471 .529 .471 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.555 .445 .555 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.984 .016 .984 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.984 .016 .984 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.928 .072 .928 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.832 .168 .832 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.844 .156 .844 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.522 .478 .522 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.506 .494 .506 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.412 .588 .412 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.811 .189 .811 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.835 .165 .835 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.809 .191 .809 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.729 .271 .729 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.972 .028 .972 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.628 .372 .628 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.948 .052 .948 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.899 .101 .899 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.526 .474 .526 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.445 .555 .445 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.742 .258 .742 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.168 .832 .168 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.178 .822 .178 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.249 .751 .249 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.589 .411 .589 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.575 .425 .575 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.944 .056 .944 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.203 .797 .203 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.21 .79 .21 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.841 .159 .841 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.972 .028 .972 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.994 .006 .994 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.354 .646 .354 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.428 .572 .428 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.754 .246 .754 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.993 .007 .993 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.778 .222 .778 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.402 .598 .402 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.696 .304 .696 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.139 .861 .139 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.58 .42 .58 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.4 .6 .4 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.977 .023 .977 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.054 .946 .054 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.112 .888 .112 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.914 .086 .914 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.04 .96 .04 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.026 .974 .026 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.695 .305 .695 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.938 .062 .938 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.24 .76 .24 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.06 .94 .06 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.548 .452 .548 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.121 .879 .121 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.249 .751 .249 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.957 .043 .957 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.01 .99 .01 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.141 .859 .141 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.204 .796 .204 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.857 .143 .857 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.28 .72 .28 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.349 .651 .349 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.007 .993 .007 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.057 .943 .057 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.009 .991 .009 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
0 1 0 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.459 .541 .459 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.718 .282 .718 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.993 .007 .993 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.841 .159 .841 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.191 .809 .191 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.15 .85 .15 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.525 .475 .525 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.978 .022 .978 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.138 .862 .138 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.154 .846 .154 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.687 .313 .687 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.108 .892 .108 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.022 .978 .022 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.924 .076 .924 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.977 .023 .977 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.703 .297 .703 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.768 .232 .768 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.082 .918 .082 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.925 .075 .925 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.362 .638 .362 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.475 .525 .475 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.077 .923 .077 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.28 .72 .28 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.494 .506 .494 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.993 .007 .993 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.956 .044 .956 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.101 .899 .101 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.12 .88 .12 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.032 .968 .032 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.903 .097 .903 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.25 .75 .25 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.973 .027 .973 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.186 .814 .186 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.173 .827 .173 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.185 .815 .185 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.748 .252 .748 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.792 .208 .792 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.693 .307 .693 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.019 .981 .019 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.262 .738 .262 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.412 .588 .412 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.673 .327 .673 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.895 .105 .895 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.994 .006 .994 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.967 .033 .967 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.247 .753 .247 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.496 .504 .496 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.185 .815 .185 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.879 .121 .879 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.822 .178 .822 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.993 .007 .993 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.687 .313 .687 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.915 .085 .915 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.971 .029 .971 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.2 .8 .2 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.33 .67 .33 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.96 .04 .96 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.194 .806 .194 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.758 .242 .758 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.556 .444 .556 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.601 .399 .601 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.403 .597 .403 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.933 .067 .933 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.91 .09 .91 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.919 .081 .919 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.939 .061 .939 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.503 .497 .503 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.977 .023 .977 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.865 .135 .865 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.429 .571 .429 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.49 .51 .49 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.994 .006 .994 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.728 .272 .728 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.646 .354 .646 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.993 .007 .993 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.974 .026 .974 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.888 .112 .888 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.97 .03 .97 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.521 .479 .521 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.951 .049 .951 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.848 .152 .848 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.792 .208 .792 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.994 .006 .994 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.765 .235 .765 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.661 .339 .661 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.995 .005 .995 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.784 .216 .784 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.99 .01 .99 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.995 .005 .995 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.645 .355 .645 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.992 .008 .992 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.742 .258 .742 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.993 .007 .993 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.859 .141 .859 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.923 .077 .923 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.877 .123 .877 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.93 .07 .93 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.949 .051 .949 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.87 .13 .87 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.736 .264 .736 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.857 .143 .857 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.918 .082 .918 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.951 .049 .951 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.938 .062 .938 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.947 .053 .947 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.99 .01 .99 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.888 .112 .888 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.974 .026 .974 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.992 .008 .992 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.979 .021 .979 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.962 .038 .962 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.898 .102 .898 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.974 .026 .974 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.949 .051 .949 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.949 .051 .949 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.992 .008 .992 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.964 .036 .964 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.994 .006 .994 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.993 .007 .993 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.993 .007 .993 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.992 .008 .992 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.994 .006 .994 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?om
0_d4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003oo@;mood2o@0=ood2o@05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003om`SgooL8mol0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?om0_d03oom0_d00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooL8moog2?L00_og2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?om0_goo@;m00koo@;m00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ood2oOom0_d03_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo@;mood2o@0>ood2o@03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`06ooL8m`03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?om0_d00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooL8moog2?L02?og2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oj1O[o0000013oo@;m00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com`Sg00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooX5nP03o`000?om
0_goo@;m00coo@;m00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om0_doo@;m005oo@;m003o`000?og
2?Oom`Sg00_om`Sg0ol00003ooD:m@03o`000?on0OkooP7n00cooP7n0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooX5n_oj1OX00ooj1OX00ol0003oo@;mood2o@0;ood2o@;o00002oon0Oh00ol0003om0_doo@;m006
oo@;m003o`000?og2?Oom`Sg00[om`Sg00?o0000ooD:mOoe2_D01?oe2_D00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oc3??ol`ccoo<<l`;o00002_om0_d2o`000003oo8=l_l0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?om0_go
o@;m00Woo@;m00?o0000ooX5n_l000002oon0Oh00ol0003om0_doo@;m006oo@;m003o`000?og2?Oo
m`Sg00Wom`Sg00?o0000ooD:mOoe2_D01_oe2_D00ol0003ooP7nooh1oP08ooh1oP03o`000?oc3??o
l`cc00Col`cc0_l00005ood2o@?o00001?ob3O800ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooX5nP03o`000?om0_goo@;m00Ooo@;m0_l00003ooX5
nP03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?od2o@01ood2o@00ol0003om`SgooL8m`09ooL8
m`03o`000?oe2_Gom@[e00Oom@[e00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Wol`cc0_l000000oom
0_go0000o`000007oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooX5n_oj
1OX02?oj1OX00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on
0Oh01oon0Oh00ol0003om0_doo@;m008oo@;m003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooD:mOoe
2_D02Ooe2_D00ol0003ooP7nooh1oP03ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000oo8=l_ob
3O801oob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0Oho`000005ooh1oP;o00002ooj1OX2o`0000Koo@;m
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?od2oCom0_d00Som0_d
00?o0000ooL8moog2?L01_og2?L00ol0003om@[eooD:m@0;ooD:m@05o`000?on0OkooP7nooh1o_l0
00003_oc3?<00ol0003olPgboo8=lP08oo8=lP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oh1oSon0OhooP7n?l0
00000oon0Oh00ol0003onPGjooX5nP0:ooX5nP04o`000?o`3o3ol0o`o`0000?oo@;m0_l00008ooX5
nP03o`000?on0OkooP7n00KooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003om`SgooL8m`05ooL8
m`03o`000?oe2_Gom@[e00com@[e00?o0000ooh1o_l000003ooc3?<00ol0003olPgboo8=lP08oo8=
lP03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7n003ooP7n003o`000?on0Oko000000_o
nPGj0_l00004oo0?l003o`000?om0_go000000_onPGj00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m0_doo@;m009oo@;m003o`000?og2?Oom`Sg00Com`Sg00?o0000ooD:mOoe2_D03_oe2_D00ol0003o
l`ccoo<<l`0>oo<<l`03o`000?ob3O;olPgb00WolPgb00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooP7n?oh1oP0
1?oh1oP00ol0003onPGjooX5nP09ooX5nP03o`000?o`3o3ol0o`00Gol0o`00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003ooP7nooh1oP05ooh1oP03o`000?od2oCom0_d00[om0_d00?o0000ooL8moog2?L0
0oog2?L00ol0003om@[eooD:m@0>ooD:m@03o`000?oc3??ol`cc00gol`cc00?o0000oo8=l_ob3O80
2_ob3O800ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0OhooP7
n005ooP7n003o`000?oj1O[onPGj00OonPGj0_l00008oo0?l003o`000?oj1O[onPGj00_onPGj00?o
0000ooh1o_on0Oh01?on0Oh00ol0003om0_doo@;m00:oo@;m004o`000?og2?Oom`SgooL8m`?o0000
3ooe2_D00ol0003ol`ccoo<<l`0>oo<<l`03o`000?ob3O;olPgb00[olPgb00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX01?oj1OX2o`0000_ol0o`1?l0
0009ooX5nP03o`000?on0OkooP7n00?ooP7n00?o0000oo@;m?od2o@02ood2o@01?l0003om`Sgo`00
0?l00003on4Nh@;o00003?oe2_D2o`00013ol`cc00?o0000oo8=l_ob3O802oob3O800ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003on0Oh
ooP7n007ooP7n003o`000?oj1O[onPGj00?onPGj00?o0000oo0?l?o`3o002oo`3o001?l0003oebSG
omLXeooG:=L5o`0000GonPGj00?o0000ooh1o_on0Oh00_on0Oh00ol0003om0_doo@;m00<oo@;m003
o`000?oQ7^7ohAkQ00GohAkQ0_l00008ooD:m@;o00000_oM8]d00ol0003ol`ccoo<<l`0=oo<<l`03
o`000?ob3O;olPgb00_olPgb00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n009ooP7n003o`000?oj1O[onPGj00;o0000
3Oo`3o000ol0003oebSGomLXe`07omLXe`Ko00000_on0Oh4o`0000gom0_d00?o0000on4NhOoQ7^40
1ooQ7^42o`0000Gom@[e00?o0000omdRgOoM8]d00ooM8]d00ol0003ol`ccoo<<l`0<oo<<l`03o`00
0?ob3O;olPgb00colPgb00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o
0000ooX5n_l000003oo`3o000ol0003oebSGomLXe`0<omLXe`?o00001?o/4n`3o`0000Wom0_d00?o
0000on4NhOoQ7^402_oQ7^42o`000003ooD:mOl0003o000000OogB;M00?o0000oo<<looc3?<02ooc
3?<00ol0003olPgboo8=lP0<oo8=lP03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oh1oSon0Oh00_on0Oh00?o0000
oo0?l?o`3o003_o`3o000ol0003oebSGomLXe`0=omLXe`03o`000?o/4ncok1?/00Kok1?/0ol00005
oo@;m003o`000?oQ7^7ohAkQ00gohAkQ00?o0000omdRgOoM8]d02?oM8]d00ol0003ol`ccoo<<l`09
oo<<l`03o`000?ob3O;olPgb00golPgb00Co0000ood2oOom0_goo@;m1Ol00003ooH9mP03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooP7n?oh1oP02ooh1oP2o`0000ool0o`00?o0000omLXeooG:=L03OoG:=L00ol0003ok1?/on`Ck00:
on`Ck0?o000000?om0_do`000?oQ7^403ooQ7^400ol0003ogB;MomdRg@09omdRg@03o`000?oc3??o
l`cc00Sol`cc00?o0000oo8=l_ob3O803_ob3O83o`0000SomPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oh1oSon0Oh00Son0Oh0ol000000ooV
6NKo0000oo0?l00>oo0?l003o`000?oG:=OoebSG00goebSG00?o0000on`Ck?o/4n`03Oo/4n`00ol0
003ohAkQon4Nh@0?on4Nh@03o`000?oM8]gogB;M00[ogB;M2ol0000;oo8=lPGo00003?of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003om@[eo`000?on0Oko0000
00Son0Oh0ol00005onHIiP03o`000?o`3o3ol0o`00col0o`00?o0000omLXeooG:=L03OoG:=L00ol0
003ok1?/on`Ck00=on`Ck0;o00004?oQ7^400ol0003ogB;MomdRg@0:omdRg@03o`000?oI9]WofBKI
00OofBKI00?o0000oo8=l_ob3O800_ob3O87o`0000CogR7N00?o0000ooH9m_of2OH02_of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003om@[eooD:mOoe2_D2o`00
00Gon0Oh0ol00009onHIiP;o00002oo`3o000ol0003oebSGomLXe`0=omLXe`03o`000?o/4ncok1?/
00gok1?/00Co0000olXeb_o:=L[o00003ooQ7^400ol0003ogB;MomdRg@09omdRg@03o`000?oI9]Wo
fBKI00WofBKI1?l0000;omhQgP03o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000ooD:mOoe2_D01?oe2_D00ol0003on0Oho`000002o`00
00coiQWV00Co0000olLhaol0003o00002Oo`3o000ol0003oebSGomLXe`0=omLXe`03o`000?o/4nco
k1?/00gok1?/00Go0000olXeb_o:=L[obSG:o`00000=on4Nh@03o`000?oM8]gogB;M00[ogB;M00?o
0000omTVfOoI9]T02OoI9]T00ol0003ogR7NomhQgP0<omhQgP03o`000?of2OKomPWf00[omPWf00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooD:mOoe2_D01_oe2_D0
0ol0003oiQWVonHIiP0<onHIiP03o`000?o7><OoacS700;oacS70_l00007oo0?l003o`000?oG:=Oo
ebSG00coebSG00?o0000on`Ck?o/4n`03Oo/4n`00ol0003obSG:olXebP03olXebP03o`000?oQ7^7o
hAkQ00[ohAkQ00?o0000omdRgOoM8]d02_oM8]d00ol0003ofBKIomTVf@09omTVf@03o`000?oN8Mko
gR7N00cogR7N00?o0000ooH9m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003om@[eooD:m@06ooD:m@03o`000?oV6NKoiQWV00_oiQWV00?o0000olLh
aoo7><L01Oo7><L00ol0003ol0o`oo0?l003oo0?l003o`000?oG:=OoebSG00goebSG00?o0000on`C
k?o/4n`03Oo/4n`00ol0003obSG:olXebP04olXebP03o`000?oQ7^7ohAkQ00WohAkQ00?o0000omdR
gOoM8]d02OoM8]d00ol0003ofBKIomTVf@0:omTVf@03o`000?oN8MkogR7N00cogR7N00?o0000ooH9
m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m@[eooD:m@07ooD:m@03o`000?oV6NKoiQWV00_oiQWV00?o0000olLhaoo7><L01_o7><L2o`0000?o
l0o`00?o0000omLXeooG:=L03OoG:=L00ol0003ok1?/on`Ck00<on`Ck003o`000?o:=L[obSG:00Ko
bSG:00?o0000on4NhOoQ7^402?oQ7^400ol0003ogB;MomdRg@09omdRg@03o`000?oI9]WofBKI00[o
fBKI00?o0000omhQg_oN8Mh03?oN8Mh00ol0003omPWfooH9mP0;ooH9mP03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000ooD:mOoe2_D02?oe2_D00ol0003oiQWVonHIiP0:onHIiP03o`00
0?o7><OoacS700WoacS70_l000000oo`3o3o0000omLXe`0<omLXe`?o00003_o/4n`00ol0003obSG:
olXebP07olXebP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000omdRgOoM8]d02OoM8]d00ol0003ofBKI
omTVf@0;omTVf@03o`000?oN8MkogR7N00cogR7N00?o0000ooH9m_of2OH02_of2OH00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000ooD:mOoe2_D02_oe2_D00ol0003oiQWVonHI
iP09onHIiP03o`000?o7><OoacS700_oacS700?o0000omLXeooG:=L02_oG:=L2o`0000?o[e2_00?o
0000on`Ck?o/4n`02_o/4n`00ol0003obSG:olXebP09olXebP03o`000?oQ7^7ohAkQ00KohAkQ00?o
0000omdRgOoM8]d02?oM8]d00ol0003ofBKIomTVf@0<omTVf@03o`000?oN8MkogR7N00cogR7N00?o
0000ooH9m_of2OH02_of2OH00ol0003ooP7nooh1oP04ooh1oPCo00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onHIi_oV6NH02?oV6NH0
0ol0003oacS7olLha`0<olLha`03o`000?oG:=OoebSG00SoebSG0_l00006ojm@[`;o00002_o/4n`0
0ol0003obSG:olXebP0:olXebP03o`000?oQ7^7ohAkQ00GohAkQ00?o0000omdRgOoM8]d02?oM8]d0
0ol0003ofBKIomTVf@0<omTVf@03o`000?oN8MkogR7N00cogR7N00?o0000ooH9m_of2OH02oof2OH0
0ol0003ooP7no`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
ooD:m@03o`000?oV6NKoiQWV00OoiQWV00?o0000olLhaoo7><L03_o7><L00ol0003oebSGomLXe`04
omLXe`?o00002_n_D:l00ol0003ok1?/on`Ck007on`Ck003o`000?o:=L[obSG:00_obSG:00?o0000
on4NhOoQ7^400ooQ7^400ol0003ogB;MomdRg@09omdRg@03o`000?oI9]WofBKI00cofBKI00?o0000
omhQg_oN8Mh03?oN8Mh00ol0003omPWfooH9mP0;ooH9mP;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003om@[eooD:m@0<ooD:m@03o`000?oV6NKoiQWV00OoiQWV00?o0000olLhaoo7><L03oo7><L01?l0
003oebSGomLXeooG:=L2o`0000ko[e2_0_l00006on`Ck003o`000?o:=L[obSG:00gobSG:00?o0000
on4NhOoQ7^400_oQ7^400ol0003ogB;MomdRg@08omdRg@03o`000?oI9]WofBKI00cofBKI0ol0000=
omhQgP03o`000?of2OKomPWf00_omPWf00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oom@[e00?o0000onHIi_oV6NH01_oV6NH00ol0003oacS7olLha`0@olLha`Co00004_n_D:l00ol0
003ok1?/on`Ck003on`Ck003o`000?o:=L[obSG:00kobSG:00Go0000on4NhOoQ7^7ohAkQo`000005
omdRg@Oo00003?oI9]T01Ol0003o_D:moke2_Onm@[go000000cogR7N00?o0000ooH9m_of2OH02?of
2OH3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oom@[e00?o0000onHIi_oV6NH01_oV6NH00ol0003oacS7olLha`0=
olLha`?o000000CoU6^Do`000?l0003o00004on_D:l2o`0000;ok1?/00?o0000olXeb_o:=LX04?o:
=LX00ol0003ohAkQo`000006o`0000Oo^TFj00?o0000omTVfOoI9]T02?oI9]T00ol0003o_D:moke2
_@03oke2_@;o00002?oN8Mh3o`0000KomPWf1?l00002oo8=lP03o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003onPGjo`000?oP7n03o`0000gom@[e00?o0000onHIi_oV6NH01?oV6NH00ol0003oacS7olLh
a`0;olLha`?o00000onDJi@01Ol0003oS7><o`000?mIYUWo000001Co[e2_00?o0000on`Ck?l00000
4oo:=LX00ol0003o^TFjokY5^P0=okY5^P03o`000?oI9]WofBKI00GofBKI0_l00008oke2_@03o`00
0?oN8MkogR7N00Go00000ooK9=/00ol0003omPWfooH9mP03o`0000OolPgb00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oj1O[onPGjo`0000Coh1oP0ol0000:ooD:m@03o`000?oV6NKoiQWV00?oiQWV
00?o0000olLhaoo7><L02Oo7><L3o`0000GoU6^D00Co0000ohacS?n<Lhco00000_mIYUT00ol0003o
[e2_ojm@[`0Bojm@[`03o`000?o:=L[obSG:01;obSG:00?o0000okY5^_njAKX03_njAKX00ol0003o
fBKIomTVf@03omTVf@03o`000?nm@[go_D:m00Wo_D:m0_l00009om/Tf`;o00002_ob3O800ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooX5n_oj1O[onPGjo`000007on0Oh0;o00001ooe2_D5o`0000;o
iQWV00?o0000olLhaoo7><L01_o7><L3o`0000SoU6^D00Co0000ohacS?n<Lhco00000omIYUT00ol0
003o[e2_ojm@[`0Aojm@[`03o`000?o:=L[obSG:017obSG:00?o0000okY5^_njAKX04?njAKX01Ol0
003ofBKIomTVfOoI9]Wo000000co_D:m00?o0000om/TfooK9=/02?oK9=/00ol0003olPgboo8=lP0:
oo8=lP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000ConPGj00?o0000on0Oh?oP7n001ooP7n03o`00
0004ooD:mOl0003o0000o`0000Gocc3?0_l00006olLha`?o00002_nDJi@01Ol0003oS7><ohacS?n<
Lhco000000CoFJII00?o0000ojm@[on_D:l04?n_D:l00ol0003obSG:olXebP0AolXebP03o`000?nj
AK[o^TFj017o^TFj00?o0000omTVfOl000003Onm@[d00ol0003ofbCKom/Tf`08om/Tf`03o`000?ob
3O;olPgb00[olPgb00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000
on0Oh?oP7n002_oP7n000ol0003occ3?oll`c`08oll`c`03o`000?o7><OoacS700?o00003OnDJi@0
1Ol0003oS7><ohacS?n<Lhco000000GoFJII00?o0000ojm@[on_D:l03on_D:l00ol0003obSG:olXe
bP0AolXebP03o`000?njAK[o^TFj01;o^TFj00?o0000oke2_Onm@[d03?nm@[d00ol0003ofbCKom/T
f`08om/Tf`03o`000?ob3O;olPgb00_olPgb00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX0
0ol0003oh1oPon0Oh00:on0Oh003o`000?o?<<oocc3?00Wocc3?0_l0000?oiA[U003o`000?n<Lhco
S7><00;oS7><00?o0000oeVVFOmIYUT01?mIYUT00ol0003o[e2_ojm@[`0=ojm@[`?o00004Oo:=LX0
0ol0003o^TFjokY5^P0CokY5^P03o`000?nm@[go_D:m00_o_D:m00?o0000om/TfooK9=/02OoK9=/0
0ol0003olPgboo8=lP0;oo8=lP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ooh1oP;o00002?oj1OX0
0ol0003oh1oPon0Oh00:on0Oh003o`000?o?<<oocc3?00Wocc3?00?o0000oiA[U?nDJi@03OnDJi@0
0ol0003oS7><ohacS003ohacS003o`000?mIYUWoFJII00GoFJII00?o0000ojm@[on_D:l02_n_D:l2
o`0000?oNHIi00?o0000olXeb_o:=LX03_o:=LX00ol0003o^TFjokY5^P0CokY5^P03o`000?nm@[go
_D:m00_o_D:m00?o0000om/TfooK9=/02OoK9=/00ol0003olPgboo8=lP0;oo8=lP03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000GooP7n00?o0000ooX5n_oj1OX01ooj1OX2o`0000_oh1oP00?o0000oll`
coo?<<l02oo?<<l00ol0003oU6^DoiA[U00<oiA[U003o`000?n<LhcoS7><00?oS7><00?o0000oeVV
FOmIYUT01_mIYUT00ol0003o[e2_ojm@[`07ojm@[`;o00001_miQWT2o`0000kobSG:00?o0000okY5
^_njAKX04onjAKX00ol0003o_D:moke2_@0;oke2_@03o`000?oK9=_ofbCK00WofbCK00?o0000oo8=
l_ob3O803?ob3O800ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ooh1o_on0OkooP7no`000009ooX5
nP03o`000?od2oCo000000_oh1oP00?o0000oll`coo?<<l02oo?<<l00ol0003oU6^DoiA[U00;oiA[
U003o`000?n<LhcoS7><00CoS7><00?o0000oeVVFOmIYUT01omIYUT00ol0003o[e2_ojm@[`05ojm@
[`03o`000?miQWWoNHIi00SoNHIi00?o0000olXeb_o:=LX02_o:=LX00ol0003o^TFjokY5^P0DokY5
^P03o`000?nm@[go_D:m00_o_D:m00?o0000om/TfooK9=/02OoK9=/00ol0003olPgboo8=lP0<oo8=
lP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7no`000009ooX5nP04o`000?od2oCom0_do`00
00_oh1oP00?o0000oll`coo?<<l02oo?<<l00ol0003oU6^DoiA[U00;oiA[U003o`000?n<LhcoS7><
00CoS7><00?o0000oeVVFOmIYUT02?mIYUT00ol0003o[e2_ojm@[`02ojm@[`;o00003?miQWT2o`00
00[obSG:00?o0000okY5^_njAKX05?njAKX00ol0003o_D:moke2_@0;oke2_@03o`000?oK9=_ofbCK
00WofbCK00?o0000oo8=l_ob3O803Oob3O800ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5nP03
o`000?od2oCom0_d00;om0_d00?o0000on0Oh?oP7n002?oP7n000ol0003occ3?oll`c`0<oll`c`03
o`000?nDJiCoU6^D00WoU6^D00?o0000ohacS?n<Lh`01On<Lh`00ol0003oFJIIoeVVF@09oeVVF@04
o`000?n_D:oo0000o`00013oNHIi0_l00008olXebP03o`000?njAK[o^TFj01Co^TFj0ol0000;oke2
_@03o`000?oK9=_ofbCK00WofbCK00?o0000oo8=l_ob3O803Oob3O801?l0003ooP7nooh1o_on0Oh5
o`0000?oo@;m00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?od2oCom0_d00?om0_d00?o0000on0O
h?oP7n002?oP7n000ol0003occ3?oll`c`0;oll`c`;o00002_nDJi@00ol0003oS7><ohacS006ohac
S003o`000?mIYUWoFJII00[oFJII00?o0000ogV6NOmiQWT04_miQWT00ol0003obSG:olXebP04olXe
bP03o`000?njAK[o^TFj01Go^TFj00?o0000ojEJYOnUFZD01Ol00005oke2_@03o`000?oK9=_ofbCK
00[ofbCK00?o0000oo8=l_ob3O803_ob3O83o`0000Woo@;m00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP04ooX5nP03
o`000?od2oCom0_d00Com0_d00?o0000on0Oh?oP7n001ooP7n000ol0003occ3?oll`c`0;oll`c`04
o`000?n6NHKoQWV6o`0000WoU6^D00?o0000ohacS?n<Lh`01_n<Lh`00ol0003oFJIIoeVVF@0:oeVV
F@03o`000?miQWWoNHIi01?oNHIi0_l00003olXebPCo00005?njAKX00ol0003oYEZUojEJY@06ojEJ
Y@Co000000?o_D:mo`000?oK9=/02ooK9=/00ol0003olPgboo8=lP0>oo8=lP03o`000?om0_goo@;m
00[oo@;m00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003onPGjooX5nP03ooX5nP03o`000?od2oCom0_d00Gom0_d00?o0000on0Oh?oP
7n001ooP7n000ol0003occ3?oll`c`09oll`c`;o00001?n6NHH00ol0003oU6^DoiA[U005oiA[U003
o`000?n<LhcoS7><00OoS7><00?o0000oeVVFOmIYUT02_mIYUT00ol0003oNHIiogV6N@0EogV6N@03
o`000?o:=L[o000000CoSW6>0ol0000@okY5^P03o`000?nUFZGoYEZU00_oYEZU0_l0000<om/Tf`03
o`000?ob3O;olPgb00colPgb0_l0000>ood2o@03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003om0_d
oo@;m006oo@;m003o`000?oP7n3oh1oP00Ooh1oP00?o0000oll`coo?<<l02?o?<<l00ol0003oQWV6
ohIiQP05ohIiQP03o`000?nDJiCoU6^D00CoU6^D00?o0000ohacS?n<Lh`01on<Lh`00ol0003oFJII
oeVVF@0:oeVVF@03o`000?miQWWoNHIi01KoNHIi00?o0000ohiaS_n>LHh01_n>LHh3o`0000co^TFj
00?o0000ojEJYOnUFZD03OnUFZD00ol0003ofbCKom/Tf`09om/Tf`Go00002Oob3O82o`000003ooH9
m_l0003oo@;m00koo@;m00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ooX5n_l0003om0_d00Wom0_d00?o0000on0Oh?oP7n001_oP
7n000ol0003occ3?oll`c`07oll`c`03o`000?n6NHKoQWV600OoQWV600?o0000oiA[U?nDJi@00_nD
Ji@00ol0003oS7><ohacS008ohacS003o`000?mIYUWoFJII00WoFJII00?o0000ogV6NOmiQWT05omi
QWT00ol0003oSW6>ohiaSP09ohiaSP?o00002OnjAKX00ol0003oYEZUojEJY@0>ojEJY@Ko00001?oK
9=/00ol0003oiA[UonDJi@03onDJi@Go00000_ob3O82o`0000ComPWf00?o0000ood2oOom0_d03?om
0_d00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?od2oCom0_doo@;m?l000002ood2o@00ol0003oh1oPon0Oh006on0Oh003o`000?o?
<<oocc3?00Gocc3?0_l0000;ohIiQP04o`000?nDJiCoU6^Do`0000_oS7><00?o0000oeVVFOmIYUT0
2OmIYUT00ol0003oNHIiogV6N@0FogV6N@03o`000?n>LHkoSW6>00goSW6>0ol00005okY5^P03o`00
0?nUFZGoYEZU00ooYEZU00?o0000oka3_?nl@k`00onl@k`4o`0000_oiA[U0_l00006ooH9mP03o`00
0?om0_goo@;m00coo@;m00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003om0_doo@;m002oo@;m0ko00001_oP7n000ol0003occ3?oll`
c`05oll`c`03o`000?n6NHKoQWV600coQWV600?o0000oiA[U?l000002on<Lh`00ol0003oFJIIoeVV
F@07oeVVF@?o00006?miQWT00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o^TFjo`000?nUFZD04?nU
FZD00ol0003o_4>loka3_007oka3_003o`000?oU6^GoiA[U00[oiA[U00?o0000ooH9m_of2OH01Oof
2OH00ol0003oo@;mood2o@0;ood2o@03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005oo@;m003o`000?oR7N;ohQgR00_ohQgR0_l00004
on0Oh003o`000?o?<<oocc3?00?occ3?0_l0000@ohIiQP03o`000?n<LhcoS7><00[oS7><00?o0000
oeVVFOmIYUT00omIYUT4o`0000;o<<l`00?o0000ogV6NOmiQWT05OmiQWT00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nUFZGoYEZU013oYEZU00?o0000oka3_?nl@k`01onl@k`00ol0003oiA[UonDJi@0:
onDJi@03o`000?of2OKomPWf00GomPWf00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?od2oCom0_d
00Gom0_d00?o0000on8Mh_oR7N803OoR7N86o`0000?occ3?00?o0000ohIiQ_n6NHH04?n6NHH00ol0
003oS7><ohacS00:ohacS003o`000?mIYUWo000000?o00001ol`cc000ol0003oNHIiogV6N@0DogV6
N@03o`000?n>LHkoSW6>01CoSW6>00?o0000ojEJYOnUFZD03onUFZD00ol0003o_4>loka3_008oka3
_003o`000?oU6^GoiA[U00[oiA[U00?o0000ooH9m_of2OH01Oof2OH00ol0003oo@;mood2o@0<ood2
o@03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo@;m?od2o@01_od2o@00ol0003ohQgRon8MhP0=on8MhP03o`000?o1?/7o`Ck100?o
`Ck100?o0000oll`col000004on6NHH4o`0000WoS7><0_l0000<oc3?<003o`000?miQWWoNHIi01?o
NHIi00?o0000ohiaS_n>LHh05On>LHh00ol0003oYEZUojEJY@0>ojEJY@03o`000?nl@kco_4>l00So
_4>l00?o0000onDJiOoU6^D02OoU6^D00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?od2oCom0_d00Som0_d00?o0000on8Mh_oR7N802ooR7N800ol0003o`Ck1ol4n`@05ol4n`@03o`00
0?n6NHKoQWV601;oQWV600Co0000ocg2?Olm`Sgo?L8m1Ol00003ohacS003o`000?l`cc3o<<l`00go
<<l`0ol0000@ogV6N@;o00006?n>LHh00ol0003oYEZUojEJY@0=ojEJY@03o`000?nl@kco_4>l00Wo
_4>l00?o0000onDJiOoU6^D02OoU6^D00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00_o
o@;m00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_om0_d00?o0000on8Mh_oR7N802_oR7N800ol0003o`Ck1ol4n`@06ol4n`@03o`00
0?n6NHKoQWV6017oQWV600?o0000ocg2?Olm`Sd01olm`Sd3o`00013o<<l`00?o0000oaC[5?lDja@0
1Ol00009ogV6N@;o000000?o;m0_o`000?n>LHh05on>LHh00ol0003oYEZUojEJY@0=ojEJY@03o`00
0?nl@kco_4>l00Wo_4>l00?o0000onDJiOoU6^D02?oU6^D2o`0000[omPWf00?o0000ood2oOom0_d0
2_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo@;m?od2o@02Ood2o@00ol0003ohQgRon8M
hP0:on8MhP03o`000?o1?/7o`Ck100Oo`Ck100?o0000ohIiQ_n6NHH03on6NHH00ol0003o?L8mocg2
?@0:ocg2?@03o`000?l`cc3o<<l`00go<<l`00?o0000oaC[5?lDja@01_lDja@4o`0000CoNHIi00?o
0000obo@;ol_d2l00_l_d2l00ol0003oSW6>ohiaSP0FohiaSP03o`000?nUFZGoYEZU00_oYEZU00?o
0000oka3_?nl@k`02onl@k`00ol0003oiA[UonDJi@06onDJi@03o`000?ob3O;o000000[omPWf00?o
0000ood2oOom0_d02_om0_d00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000oo@;m?od2o@02?od2o@=
o`0000[o`Ck100?o0000ohIiQ_n6NHH03on6NHH00ol0003o?L8mocg2?@0;ocg2?@03o`000?l`cc3o
<<l`00co<<l`00?o0000oaC[5?lDja@02_lDja@4o`0000Go;m0_00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oYEZUojEJY@0:ojEJY@03o`000?nl@kco_4>l00co_4>l00?o0000onDJiOoU6^D01?oU6^D2
o`0000?olPgb00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@08ood2o@03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5
n_oj1OX00ooj1OX00ol0003om0_doo@;m007oo@;m003o`000?oP7n3oh1oP00Woh1oP00?o0000ol4n
`Oo1?/402Oo1?/400ol0003oQWV6ohIiQP0=ohIiQP03o`000?lm`Sgo?L8m00co?L8m00?o0000oc3?
<?l`cc003?l`cc000ol0003o5>/DoaC[500;oaC[5003o`000?l8m`So000000Ko;m0_00?o0000ohia
S_n>LHh05_n>LHh00ol0003oYEZUojEJY@09ojEJY@03o`000?nl@kco_4>l00co_4>l00?o0000onDJ
iOoU6^D00ooU6^D00ol0003olPgboo8=lP03oo8=lP03o`000?of2OKomPWf00SomPWf00?o0000ood2
oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000oo@;m?od2o@01_od2o@00ol0003o
h1oPon0Oh008on0Oh003o`000?o1?/7o`Ck100_o`Ck100?o0000ohIiQ_n6NHH02?n6NHH4o`0000oo
?L8m00?o0000oc3?<?l`cc002ol`cc000ol0003o5>/DoaC[500;oaC[5004o`000?l8m`So2?L8o`00
00Oo;m0_00?o0000ohiaS_n>LHh05On>LHh00ol0003oYEZUojEJY@08ojEJY@03o`000?nl@kco_4>l
00go_4>l00?o0000onDJiOoU6^D00_oU6^D00ol0003olPgboo8=lP05oo8=lP03o`000?of2OKomPWf
00OomPWf00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo@;m?od
2o@01Ood2o@00ol0003oh1oPon0Oh008on0Oh003o`000?o1?/7o`Ck100_o`Ck100?o0000ohIiQ_n6
NHH00on6NHH5o`0000?o?l0o00?o0000ocg2?Olm`Sd03_lm`Sd00ol0003o<<l`oc3?<00:oc3?<003
o`000?lDjaCo5>/D00[o5>/D00Go0000o`Sg2?l8m`So2?L8o`000007obo@;`03o`000?n>LHkoSW6>
01GoSW6>00?o0000ojEJYOnUFZD02?nUFZD00ol0003o_4>loka3_00=oka3_003o`000?oU6^GoiA[U
00;o00002?ob3O800ol0003omPWfooH9mP08ooH9mPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?od2oCom0_d00Go
m0_d00?o0000on0Oh?oP7n002?oP7n000ol0003o`Ck1ol4n`@0<ol4n`@Go00002Olo`3l00ol0003o
?L8mocg2?@0<ocg2?@;o00003?l`cc000ol0003o5>/DoaC[500:oaC[5005o`000?l8m`So2?L8o`Sg
2?l000002?l_d2l00ol0003oSW6>ohiaSP0DohiaSP?o00001onUFZD00ol0003o_4>loka3_00>oka3
_003o`000?oU6^Go000000_olPgb00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003om0_doo@;m004oo@;m003o`000?oP7n3oh1oP00Oo
h1oP00?o0000ol4n`Oo1?/403?o1?/401?l0003oQGZ5ohEjQOl0000;oco0?`03o`000?lm`Sgo?L8m
00_o?L8m00Co0000o`;m0_l2o@;o00002_l`cc000ol0003o5>/DoaC[500:oaC[5003o`000?l8m`So
2?L800;o2?L800?o0000obo@;ol_d2l01_l_d2l00ol0003oSW6>ohiaSP0AohiaSP?o00000om]TVd0
0ol0003oYEZUojEJY@04ojEJY@03o`000?nl@kco_4>l00go_4>l1?l0000;oo8=lP03o`000?of2OKo
mPWf00GomPWf00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00KonPGj00Co0000oo@;
m?od2oCom0_d1?l00008on0Oh003o`000?o1?/7o`Ck100_o`Ck100?o0000ohEjQOn5NXD00_n5NXD0
0ol0003o?l0ooco0?`08oco0?`03o`000?lm`Sgo?L8m00[o?L8m00?o0000o`;m0_l2o@800_l2o@80
0ol0003o<<l`oc3?<003oc3?<0Go00002olDja@00ol0003o2?L8o`Sg2003o`Sg2003o`000?l_d2oo
;m0_00Oo;m0_00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoKI9]00?o0000ojEJYOnUFZD00_nUFZD0
0ol0003o_4>loka3_00=oka3_003o`000?oS7>?ohacS00;ohacS00?o0000oo8=l_ob3O802Oob3O80
0ol0003omPWfooH9mP03ooH9mP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5
nP?o00001?oV6NH00ol0003oh1oPon0Oh005on0Oh003o`000?o1?/7o`Ck100[o`Ck100?o0000ohEj
QOn5NXD00on5NXD00ol0003o?l0ooco0?`09oco0?`03o`000?lm`Sgo?L8m00So?L8m00?o0000o`;m
0_l2o@801?l2o@85o`0000Co0?l000?o0000oaC[5?lDja@02OlDja@00ol0003o2?L8o`Sg2003o`Sg
2003o`000?l_d2oo;m0_00So;m0_00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oKI9]00Go0000ojEJ
YOnUFZGoYEZUo`00000>oka3_003o`000?oS7>?ohacS00CohacS0_l00009oo8=lP03o`000?of2OKo
mPWf00;omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00OonPGj00?o0000onHI
i_oV6NH01OoV6NH00ol0003oh1oPon0Oh003on0Oh003o`000?o1?/7o`Ck100[o`Ck100?o0000ohEj
QOn5NXD01?n5NXD00ol0003o?l0ooco0?`09oco0?`03o`000?lm`Sgo?L8m00Oo?L8m00?o0000o`;m
0_l2o@801Ol2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lDjaCo5>/D00Oo5>/D00?o0000o`Sg
2?l8m`P01?l8m`P00ol0003o;m0_obo@;`08obo@;`03o`000?n>LHkoSW6>00SoSW6>0_l0000>offB
K@Co00003?nl@k`2o`0000WohacS00?o0000oo8=l_ob3O801oob3O801?l0003omPWfooH9m_l0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oiQWVonHIiP07onHIiP;o00000ooP7n000ol0
003o`Ck1ol4n`@09ol4n`@03o`000?n5NXGoQGZ500KoQGZ500?o0000oco0?olo`3l02Olo`3l00ol0
003o?L8mocg2?@05ocg2?@03o`000?l2o@;o0_d200Ko0_d200?o0000o`3o0?l0o`002?l0o`000ol0
003o5>/DoaC[5006oaC[5003o`000?l8m`So2?L800Co2?L800?o0000obo@;ol_d2l02Ol_d2l4o`00
00?oSW6>0ol0000@offBK@05o`000?o8=lSob3O8olPgb?l000002_nl@k`00ol0003ohacSon<Lh`0:
on<Lh`Ko00000oob3O800ol0003omPWfo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0
003oiQWVonHIiP0:onHIiP04o`000?oP7n3oh1oPo`0000[o`Ck100?o0000ohEjQOn5NXD01on5NXD0
0ol0003o?l0ooco0?`09oco0?`03o`000?lm`Sgo?L8m00Co?L8m00?o0000o`;m0_l2o@801ol2o@80
0ol0003o0?l0o`3o0008o`3o00;o00001_lDja@00ol0003o2?L8o`Sg2005o`Sg2003o`000?l_d2oo
;m0_00Wo;m0_00Co0000oc7><OlacS7o<Lha0ol0000BoffBK@03o`000?o8=lSob3O800?ob3O80_l0
0006oka3_0;o00003OoS7><00ol0003on@KiooT6n@03ooT6n@Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000ooX5n_oj1OX00ooj1OX0
0ol0003oiQWVonHIiP0<onHIiP;o00002_o1?/400ol0003oQGZ5ohEjQ@08ohEjQ@03o`000?lo`3oo
?l0o00[o?l0o00?o0000ocg2?Olm`Sd00_lm`Sd00ol0003o0_d2o`;m0P08o`;m0P03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lDjaCo5>/D00;o5>/D00?o0000o`Sg2?l8m`P01_l8m`P0
0ol0003o;m0_obo@;`08obo@;`03o`000?lacS7o<Lha00Co<Lha00?o0000offBKOm]TVd03om]TVd0
0ol0003ob3O8olPgb006olPgb0;o00000onl@k`00ol0003ohacSon<Lh`0=on<Lh`03o`000?oi1_Wo
n@Ki00Oon@Ki0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?oV6NKoiQWV
00koiQWV00?o0000ol4n`Oo1?/401oo1?/400ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?lo`3oo?l0o
00Wo?l0o00Go0000ocg2?Olm`Sgo?L8mo`00000;o`;m0P03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lDjaCo5>/DoaC[5?l000002?l8m`P00ol0003o;m0_obo@;`08obo@;`03o`000?la
cS7o<Lha00Go<Lha00?o0000offBKOm]TVd03_m]TVd00ol0003ob3O8olPgb008olPgb003o`000?nl
@kco000000oohacS00?o0000ooT6nOoi1_T02?oi1_T01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?oj1O[onPGjo`00017oiQWV00?o0000ol4n`Oo1?/401_o1?/400ol0003oQGZ5
ohEjQ@0;ohEjQ@03o`000?lo`3oo?l0o00Wo?l0o00Co0000ocg2?Olm`Sgo00003?l2o@800ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5>/Do`000009o`Sg2003o`000?l_d2oo;m0_00So
;m0_00?o0000oc7><OlacS401OlacS400ol0003oKI9]offBK@0=offBK@03o`000?o8=lSob3O800[o
b3O800?o0000on<LhooS7><03_oS7><00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BonHIiP03o`00
0?o1?/7o`Ck100Co`Ck100?o0000ohEjQOn5NXD03?n5NXD00ol0003o?l0ooco0?`0:oco0?`?o0000
3?l2o@800ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Sg2?l8m`P02?l8m`P00ol0003o;m0_
obo@;`07obo@;`03o`000?lacS7o<Lha00Oo<Lha00?o0000offBKOm]TVd03?m]TVd00ol0003ob3O8
olPgb00;olPgb0;o00003_oS7><00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP00ooh1oP00ol0003oiQWVonHIiP0?onHIiP?o00000oo1
?/400ol0003oQGZ5ohEjQ@0>ohEjQ@03o`000?lo`3oo?l0o00So?l0o00Co0000o`[e2_l:m@[o2_D:
0_l0000:o`;m0P?o00003Ol0o`000ol0003o2?L8o`Sg2008o`Sg2003o`000?l_d2oo;m0_00Oo;m0_
00?o0000oc7><OlacS401olacS400ol0003oKI9]offBK@0;offBK@03o`000?o8=lSob3O800cob3O8
00?o0000oo8=l_l000000_l0000:on<Lh`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n004ooP7n003o`000?oV6NKoiQWV00coiQWV0_l0
0003omLXe`03o`000?o1?/7o0000017oQGZ500?o0000oco0?olo`3l01olo`3l00ol0003o2_D:o`[e
2P04o`[e2P;o00002?l2o@800ol0003o0?l0o`3o000>o`3o00;o00002?l8m`P00ol0003o;m0_obo@
;`06obo@;`03o`000?lacS7o<Lha00Wo<Lha00?o0000offBKOm]TVd02Om]TVd00ol0003ob3O8olPg
b00=olPgb003o`000?ob3O;olPgb00;olPgb0ol00007on<Lh`03o`000?oi1_Won@Ki00Oon@Ki00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n005ooP7n003o`000?oV6NKo
iQWV00WoiQWV0_l00006omLXe`03o`000?n5NXGoQGZ5013oQGZ500?o0000oco0?olo`3l01_lo`3l0
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l2o@;o0_d200Co0_d20ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol8m`P00ol0003o;m0_obo@;`06obo@;`03o`000?lacS7o<Lha00[o<Lha00?o0000
offBKOm]TVd02?m]TVd00ol0003ob3O8olPgb00=olPgb003o`000?ob3O;olPgb00GolPgb0ol00004
on<Lh`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on0OhooP7n006ooP7n003o`000?oV6NKoiQWV00GoiQWV0ol00008omLXe`03o`000?n5NXGoQGZ5
017oQGZ500Co0000oco0?olo`3oo?l0o1?l0000;o`[e2P;o000000Co0_d2o`000?l0003o00000ol0
o`02o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2?L800?o0000obo@;ol_d2l01_l_
d2l00ol0003o<Lhaoc7><@0:oc7><@03o`000?m]TVgoKI9]00OoKI9]00?o0000olPgb?o8=lP03_o8
=lP00ol0003olPgboo8=lP08oo8=lPCo00002_oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on0OhooP7n007ooP7n003o`000?oV6NKoiQWV00;oiQWV0_l0000<omLXe`03o`000?n5NXGo
QGZ5013oQGZ51?l00003oc?<<`03o`000?l:m@[o2_D:00_o2_D:00?o0000o`3o0?l0o`001_l0o`00
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>oc7><@03o`000?m]TVgo
KI9]00KoKI9]00?o0000olPgb?o8=lP03_o8=lP00ol0003olPgboo8=lP0;oo8=lP03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00Won0Oh00Co0000onHI
i_l0003o00003_oG:=L00ol0003oQGZ5ohEjQ@0?ohEjQ@03o`000?lcc3?o<l`c00Ko<l`c00?o0000
o`[e2_l:m@X02_l:m@X00ol0003o0?l0o`3o0007o`3o00;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l/dbco;=</00So;=</00?o0000oc7><OlacS403?lacS400ol0003oKI9]offBK@05
offBK@03o`000?o8=lSob3O800oob3O80_l0000=oo8=lP03o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00[on0Oh00?o0000omLXeooG:=L03_oG:=L00ol0
003oQGZ5ohEjQ@0>ohEjQ@03o`000?lcc3?o<l`c00Oo<l`c00?o0000o`[e2_l:m@X02_l:m@X00ol0
003o0?l0o`3o0009o`3o00;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l/dbco;=</
00Wo;=</00?o0000oc7><OlacS402_lacS44o`0000CoKI9]00?o0000olPgb?o8=lP04?o8=lP01?l0
003ol0o`o`000?l0000<oo8=lP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oh1oSon0Oh00[on0Oh00?o0000omLXeooG:=L03ooG:=L@o`0000[o<l`c00?o0000o`[e
2_l:m@X02Ol:m@X00ol0003o0?l0o`00000<o`3o0005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o;=</obcC;009obcC;003o`000?lacS7o<Lha00Oo<Lha0ol00004ofNHI`?o000000?oKI9]
o`000?o8=lP04Oo8=lP01?l0003ol0o`oo0?l?o`3o02o`0000_olPgb00?o0000ooT6nOoi1_T00ooi
1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oebSGomLXe`0?
omLXe`03o`000?n1OX7oPGj100coPGj100?o0000oc?<<olcc3<02Olcc3<00ol0003o2_D:o`[e2P07
o`[e2P04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l/dbco;=</00[o;=</00?o0000oc7><OlacS400olacS43o`0000[oIiQW00?o0000olPgb?o8=lP0
4?o8=lP00ol0003ol0o`oo0?l004oo0?l0;o00002_ob3O800ol0003on@KiooT6n@04o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con0Oh00?o0000omLXeooG:=L03ooG:=L00ol0003oPGj1oh5nP@0<oh5nP@03o`000?lc
c3?o<l`c00Wo<l`c00?o0000o`[e2_l:m@X01_l:m@X00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l/
dbco;=</00[o;=</00?o0000oc7><OlacS400ol0000=ofNHI`03o`000?o8=lSob3O8013ob3O800?o
0000oo0?l?o`3o001_o`3o02o`0000WolPgb0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003oebSGomLXe`0=omLXe`?o00003on1OX40
0ol0003o<l`coc?<<`08oc?<<`03o`000?l:m@[o2_D:00Go2_D:00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o;=</obcC;00;obcC;0;o00004OmWV6L00ol0003ob3O8olPgb00?olPgb003o`000?o`3o3o
l0o`00Sol0o`0_l00007oo8=lP03o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooP7n?oh1oP02?oh1oP00ol0003oebSGomLXe`09omLXe`Go00000_ndBk@00ol0
003oPGj1oh5nP@0=oh5nP@03o`000?lcc3?o<l`c00Wo<l`c00?o0000o`[e2_l:m@X01?l:m@X00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l/dbco;=</00_o;=</00?o0000ofNHIomWV6L04?mWV6L00ol0
003ob3O8olPgb00?olPgb003o`000?o`3o3ol0o`00[ol0o`0_l00004oo8=lP03o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on0OhooP7n007ooP7n003o`000?oG:=OoebSG00CoebSG1Ol00007okA;]003
o`000?n1OX7oPGj100goPGj100?o0000oc?<<olcc3<02Olcc3<00ol0003o2_D:o`[e2P03o`[e2P03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000obcC;?l/db`02ol/db`00ol0003oIiQWofNHI`0@ofNHI`03
o`000?o8=lSob3O800oob3O800?o0000oo0?l?o`3o003?o`3o02o`000003oo8=l_l0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o0000omLXeol00000
1?l0000<okA;]003o`000?n1OX7oPGj100koPGj100?o0000oc?<<olcc3<02?lcc3<00ol0003o2_D:
o`[e2P02o`[e2P03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000obcC;?l/db`02ol/db`00ol0003oIiQW
ofNHI`0AofNHI`03o`000?o8=lSob3O800gob3O800?o0000oo0?l?o`3o003oo`3o000ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooP7n?oh1oP01Ooh1oP3o`00017o]4^d00?o0000oh5nPOn1OX403_n1
OX400ol0003o<l`coc?<<`09oc?<<`04o`000?l:m@[o2_D:o`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol/db`00ol0003o
IiQWofNHI`0AofNHI`?o00003Oo8=lP00ol0003ol0o`oo0?l00?oo0?l003o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oh1oP2o`0000;ojaC[00?o0000okA;]?ndBk@03ondBk@00ol0003o
PGj1oh5nP@0>oh5nP@03o`000?lcc3?o<l`c00So<l`c1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=obcC;003o`000?mWV6OoIiQW
017oIiQW00?o0000ohEjQOn5NXD00ol0000:olPgb0Co00003Oo`3o000ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000ooX5n_oj1O[onPGj0_l00005on/Dj`03o`000?ndBkCo]4^d00ko]4^d00?o0000oh5n
POn1OX403_n1OX400ol0003o<l`coc?<<`07oc?<<`03o`000?l=lPgo3O8=00?o3O8=00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<obcC
;003o`000?mWV6OoIiQW013oIiQW00?o0000ohEjQOn5NXD01?n5NXD3o`0000Kob3O800?o0000on/D
joo[5>/00_o[5>/5o`0000Sol0o`00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00?o
nPGj00?o0000on/Djoo[5>/01?o[5>/00ol0003o]4^dokA;]00=okA;]003o`000?n1OX7oPGj100oo
PGj100?o0000oc?<<olcc3<01?lcc3<2o`0000Oo3O8=00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000obcC;?l/db`02?l/db`3o`00013oIiQW00?o0000ohEjQOn5NXD02?n5NXD3o`0000;o
b3O800?o0000on/Djoo[5>/02?o[5>/5o`0000?ol0o`00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?oj1O[onPGj00ConPGj00?o0000on/Djoo[5>/01Oo[5>/00ol0003o]4^dokA;]00;okA;]0Co0000
3on1OX400ol0003o<l`coc?<<`03oc?<<`03o`000?l=lPgo3O8=00So3O8=00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0Oh100?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l/db`2o`0000?o;m0_00?o0000ofNHIomWV6L03?mWV6L00ol0003oQGZ5ohEjQ@0<ohEjQ@;o0000
4?o[5>/3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o[5>_ojaC[00KojaC[00?o
0000okA;]?ndBk@02OndBk@00ol0003oacS7o`000002ogR7N0?o00003?n1OX401?l0003o<l`coc?<
<olcc3<2o`0000co3O8=00?o0000o`3o0?l0o`000_l0o`000ol0003o0Oh1o`7n0@08o`7n0@03o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o;=</obcC;002obcC;003o`00
0?l_d2oo;m0_00Co;m0_0_l0000;ofNHI`03o`000?n5NXGoQGZ500coQGZ500?o0000ol<l`ol00000
4_o[5>/00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?o[5>_ojaC[00OojaC[00?o
0000okA;]?ndBk@01_ndBk@2o`0000;oacS700?o0000ogR7N?mhQgP00omhQgP3o`0000[oPGj100?o
0000oc?<<ol000003ol=lPd01?l0003o0?l0o`000?l0000;o`7n0@03o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o;=</o`000?l00009obo@;`03o`000?mWV6OoIiQW00Oo
IiQW00?o0000ohEjQOn5NXD03?n5NXD01?l0003o`cc3ol<l`ol0000Con/Dj`03o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003ojaC[on/Dj`08on/Dj`03o`000?ndBkCo]4^d00Co
]4^d00?o0000olLhaoo7><L00oo7><L00ol0003oN8MhogR7N005ogR7N0?o00001_n1OX44o`00013o
3O8=00?o0000o`7n0Ol1oP403?l1oP400ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoIiQW00?o0000ohEjQOn5NXD03?n5NXD00ol0003o
`cc3ol<l``02ol<l``03o`000?o[5>_ojaC[00oojaC[00?o0000ooT6nOl000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?o[5>_ojaC[00WojaC[00Co0000okA;]?ndBkCo
]4^d0_l00006olLha`03o`000?mhQgSoN8Mh00SoN8Mh0ol000000on1OX7o0000o`000004ocG:=@03
o`000?l=lPgo3O8=00go3O8=00?o0000o`7n0Ol1oP403?l1oP400ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oIiQWofNHI`03o`0000ko
QGZ500?o0000ol<l`oo3?<<00oo3?<<00ol0003ojaC[on/Dj`0>on/Dj`05o`000?oi1_Won@KiooT6
nOl000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?o[5>_ojaC[00[o
jaC[00?o0000okA;]?l000002?o7><L00ol0003oN8MhogR7N00;ogR7N003o`000?lebSGo=LXe00Go
=LXe00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o0Oh1o`7n0@0<o`7n0@03o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002ogf2O@03o`000?n5NXGoQGZ500_o
QGZ500?o0000ol<l`oo3?<<01?o3?<<00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oi1_Won@Ki00?o
n@Ki00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooX5nP03o`000?o[5>_ojaC[00_ojaC[00?o0000olLhaoo7><L0
1oo7><L00ol0003oN8MhogR7N00;ogR7N003o`000?lebSGo=LXe00Ko=LXe00?o0000o`gb3Ol=lPd0
2ol=lPd2o`0000go0Oh100?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l4n`Co1?/4o`0000ko;m0_00?o0000ogf2OOmmPWd00_mmPWd00ol0003oQGZ5ohEjQ@09ohEjQ@03
o`000?o3?<?o`cc300Ko`cc300?o0000on/Djoo[5>/02oo[5>/00ol0003on@KiooT6n@05ooT6n@04
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000SonPGj00?o0000on/Djoo[5>/02_o[5>/2o`0000Wo
acS700?o0000ogR7N?mhQgP02omhQgP00ol0003o=LXeocG:=@07ocG:=@03o`000?l=lPgo3O8=00Wo
3O8=00Co0000o`3o0?l0o`3o00003?l1oP400ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Ck1?l4n`Co1?/4o`00000>obo@;`03o`000?mmPWgoOH9m00?oOH9m00?o0000
ohEjQOn5NXD01on5NXD00ol0003o`cc3ol<l``07ol<l``03o`000?o[5>_ojaC[00[ojaC[00?o0000
ooT6nOoi1_T01ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006ooX5nP03o`000?o[5>_ojaC[
00WojaC[00Co0000onLHiooW6>Oo00002Oo7><L00ol0003oN8MhogR7N009ogR7N003o`000?lebSGo
=LXe00Wo=LXe00?o0000o`gb3Ol=lPd01ol=lPd00ol0003o0?l0o`3o0002o`3o0003o`000?l1oP7o
0Oh100Wo0Oh100?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co
1?/400?o1?/400?o0000obo@;ol_d2l02_l_d2l00ol0003oOH9mogf2O@05ogf2O@03o`000?n5NXGo
QGZ500GoQGZ500?o0000ol<l`oo3?<<02?o3?<<00ol0003ojaC[on/Dj`09on/Dj`03o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_oj1OX3o`0000WojaC[00?o0000onLH
iooW6>L00_oW6>L00ol0003oacS7olLha`06olLha`03o`000?mhQgSoN8Mh00WoN8Mh00?o0000ocG:
=OlebSD02_lebSD00ol0003o3O8=o`gb3@05o`gb3@03o`000?l0o`3o0?l000Co0?l000?o0000o`7n
0Ol1oP402?l1oP400ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Ck
1?l4n`@01?l4n`@00ol0003o;m0_obo@;`0:obo@;`03o`000?mmPWgoOH9m00KoOH9m00?o0000ohEj
QOn5NXD00on5NXD00ol0003o`cc3ol<l``09ol<l``03o`000?o[5>_ojaC[00SojaC[00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003ooD:m@?o00001Oo[5>/00ol0003o
iaSWonLHi`03onLHi`03o`000?o7><OoacS700KoacS700?o0000ogR7N?mhQgP02OmhQgP00ol0003o
=LXeocG:=@0;ocG:=@03o`000?l=lPgo3O8=00?o3O8=00?o0000o`3o0?l0o`001_l0o`000ol0003o
0Oh1o`7n0@08o`7n0@03o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1?/400?o0000obo@;ol_d2l02Ol_d2l00ol0003oOH9mogf2O@07ogf2O@05o`000?n5NXGoQGZ5ohEj
QOl000003Oo3?<<00ol0003ojaC[on/Dj`06on/Dj`03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?oe2_Gom@[e00Gom@[e0ol000000oo[5>_o0000onLHi`06onLHi`03
o`000?o7><OoacS700GoacS700?o0000ogR7N?mhQgP02OmhQgP00ol0003o=LXeocG:=@0<ocG:=@05
o`000?l=lPgo3O8=o`gb3Ol000002_l0o`000ol0003o0Oh1o`7n0@07o`7n0@03o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olIiQWo0000o`Ck1007o`Ck1003o`000?l_d2oo;m0_
00So;m0_00?o0000ogf2OOmmPWd02OmmPWd00ol0003oQGZ5o`00000=ol<l``Co00001Oo[5>/00ol0
003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:m@08ooD:m@03
o`000?oW6>OoiaSW00OoiaSW00?o0000olLhaoo7><L01?o7><L00ol0003oN8MhogR7N009ogR7N003
o`000?lebSGo=LXe00go=LXe00?o0000o`gb3Ol000003?l0o`0:o`0000Oo0?l00ol00005oaWV6@03
o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oOH9mogf2O@0:ogf2O@03
o`000?o3?<?o`cc300_o`cc300?o0000on`Ck?o/4n`00_o/4n`3o`000003on/Djol0003on@Ki00_o
n@Ki0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oiaSWonLHi`07onLHi`03o`00
0?o7><OoacS700GoacS700?o0000ogR7N?mhQgP01omhQgP00ol0003o=LXeocG:=@0?ocG:=@;o0000
2ol0o`000ol0003o3_4>o`ka3P07o`ka3P03o`000?l0o`3o0?l000;o0?l00ol00008oaWV6@03o`00
0?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01ol_d2l00ol0003oOH9mogf2O@0:ogf2O@03o`00
0?o3?<?o`cc300[o`cc300?o0000on`Ck?o/4n`01_o/4n`00ol0003on@KiooT6n@08ooT6n@?o0000
0_oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oiaSWonLH
i`08onLHi`03o`000?o7><OoacS700CoacS700?o0000ogR7N?mhQgP01omhQgP00ol0003o=LXeocG:
=@0>ocG:=@04o`000?l6n@Ko1_T6o`0000Wo0?l000?o0000o`ka3_l>l@h02Ol>l@h01?l0003o0?l0
o`000?l0000<oaWV6@03o`000?l4n`Co1?/400Ko1?/400?o0000obo@;ol_d2l01_l_d2l00ol0003o
OH9mogf2O@0;ogf2O@03o`000?o3?<?o`cc300Oo`cc30_l00009on`Ck003o`000?oi1_Won@Ki00Co
n@Ki1?l00006ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om@[eooD:m@09ooD:m@03o`00
0?oW6>OoiaSW00SoiaSW00?o0000olLhaoo7><L00oo7><L>o`0000go=LXe00?o0000o`Ki1_l6n@H0
0_l6n@H00ol0003o0?l0o`3o0005o`3o0003o`000?l>l@ko3_4>00_o3_4>00?o0000oaWV6OlIiQT0
3?lIiQT00ol0003o1?/4o`Ck1006o`Ck1003o`000?l_d2oo;m0_00Go;m0_00?o0000ogf2OOmmPWd0
3?mmPWd00ol0003o`cc3ol<l``06ol<l``03o`000?o/4ncok1?/00[ok1?/00?o0000ooT6nOoi1_T0
0ol0000:ooX5nP?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onLHiooW6>L02?oW
6>L01Ol0003oacS7olLhaoo7><Oo000000_oSW6>00?o0000ob_D:ol[e2/00ol00009ocG:=@03o`00
0?l6n@Ko1_T600Co1_T600?o0000o`3o0?l0o`000ol0o`000ol0003o3_4>o`ka3P0<o`ka3P03o`00
0?lIiQWo6NHI00go6NHI00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o;m0_obo@;`03obo@;`?o0000
3OmmPWd00ol0003o`cc3ol<l``05ol<l``03o`000?o/4ncok1?/00cok1?/0_l0000=ooX5nP03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oe2_Gom@[e00_om@[e00?o0000onLHiooW6>L02?oW
6>L4o`0000coSW6>00?o0000ob_D:ol[e2/00ol[e2/3o`0000Go=LXe00?o0000o`Ki1_l6n@H01_l6
n@H01Ol0003o0?l0o`3o0?l0o`3o000000oo3_4>00?o0000oaWV6OlIiQT03OlIiQT00ol0003o1?/4
o`Ck1006o`Ck1003o`000?l_d2oo;m0_00?o00000olcc3<00ol0003oOH9mogf2O@0;ogf2O@03o`00
0?o3?<?o`cc300?o`cc300?o0000on`Ck?o/4n`03Oo/4n`00ol0003onPGjooX5nP0;ooX5nP03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000ooD:mOoe2_D02_oe2_D3o`0000KoiaSW0ol0
0003omXUfP03o`000?n>LHkoSW6>00[oSW6>00?o0000ob_D:ol[e2/01_l[e2/3o`000003ocG:=Ol0
003o1_T600Wo1_T600?o0000o`3o0?l000004?l>l@h00ol0003o6NHIoaWV6@0=oaWV6@03o`000?l4
n`Co1?/400Oo1?/40_l00007oc?<<`03o`000?mmPWgoOH9m00[oOH9m00Co0000ol<l`oo3?<?o`cc3
0ol0000?on`Ck003o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooD:mOoe2_D02_oe
2_D01?l0003ol@kaoo4>lOoa3_42o`000004onLHiol0003o0000o`0000KofRGJ00?o0000ohiaS_n>
LHh02_n>LHh00ol0003o:m@[ob_D:`09ob_D:`03o`000?l6n@Ko1_T600[o1_T600?o0000o`ka3_l>
l@h03ol>l@h00ol0003o6NHIoaWV6@0>oaWV6@03o`000?l4n`Co1?/400Ko1?/400?o0000oc?<<olc
c3<01olcc3<4o`0000SoOH9m00Co0000ol<l`oo3?<?o00000ooK9=/2o`0000gok1?/00?o0000ooX5
n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003o
l@kaoo4>l@04oo4>l@03o`000?oJ9M[ofRGJ00OofRGJ00?o0000ohiaS_n>LHh02On>LHh00ol0003o
:m@[ob_D:`0:ob_D:`03o`000?l6n@Ko1_T600[o1_T600?o0000o`ka3_l>l@h03ol>l@h00ol0003o
6NHIoaWV6@0>oaWV6@03o`000?l4n`Co1?/400Go1?/400?o0000oc?<<olcc3<02?lcc3<01?l0003o
P7n0oh1oP?n0Oh07o`0000;oOH9m0_l00006om/Tf`;o00003?o/4n`00ol0003onPGjooX5nP09ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003om@[eooD:m@08ooD:m@03o`000?oa3_7ol@ka00Go
l@ka00?o0000omXUf_oJ9MX02?oJ9MX00ol0003oSW6>ohiaSP08ohiaSP03o`000?l[e2_o:m@[00[o
:m@[00?o0000o`Ki1_l6n@H02ol6n@H00ol0003o3_4>o`ka3P0>o`ka3P03o`000?lIiQWo6NHI00ko
6NHI1Ol00002o`Ck1003o`000?lcc3?o<l`c00Wo<l`c00?o0000oh1oP?n0Oh002?n0Oh03o`0000Wo
fbCK0_l0000:on`Ck003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?oe2_Gom@[e00Som@[e00?o0000oo4>lOoa3_401ooa3_400ol0003ofRGJomXUfP07omXUfP03o`00
0?n>LHkoSW6>00SoSW6>00?o0000ob_D:ol[e2/02_l[e2/00ol0003o1_T6o`Ki1P0:o`Ki1P;o0000
3_l>l@h3o`0000go6NHI0ol00005obo@;`;o00002olcc3<00ol0003oP7n0oh1oP00;oh1oP0;o0000
2_oK9=/2o`0000Ook1?/0ol00009ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:oo4>l@03o`00
0?oJ9M[ofRGJ00OofRGJ00?o0000ohiaS_n>LHh02?n>LHh>o`0000Wo1_T60ol000000ol0o`3o0000
o`ka3P0:o`ka3P?o00000_lVfBH00ol0003o6NHIoaWV6@09oaWV6@;o00002Ol_d2l00ol0003o<l`c
oc?<<`09oc?<<`03o`000?n0Oh3oP7n000_oP7n000?o0000ojUFZOl000002ooK9=/2o`0000Cok1?/
00Co0000oo<<looc3??ol`cc0_l00007ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002oom0_d00ol0003ol@ka
oo4>l@09oo4>l@03o`000?oJ9M[ofRGJ00KofRGJ00?o0000ohiaS_n>LHh02?n>LHh00ol0003o;M8]
obgB;@0:obgB;@03o`000?l6n@Ko1_T600Co1_T60ol00005o`3o0003o`000?l>l@ko3_4>00Co3_4>
1?l00006obKI9P03o`000?lIiQWo6NHI00Ko6NHI0_l0000;obo@;`03o`000?lcc3?o<l`c00Wo<l`c
00?o0000oh1oP?n0Oh002_n0Oh001Ol0003oZEJYojUFZOnYEZWo000000cofbCK0_l000000oo/4nco
0000oo<<l`05oo<<l`03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?oa3_7ol@ka00Sol@ka00?o0000omXUf_oJ9MX01_oJ9MX00ol0003oSW6>ohiaSP07ohiaSP03o`00
0?l]dRgo;M8]00_o;M8]00?o0000o`Ki1_l6n@H00_l6n@H2o`0000Wo0?l000?o0000o`ka3_l>l@h0
0ol0000;obKI9P03o`000?lIiQWo6NHI00;o6NHI0ol0000>obo@;`03o`000?lcc3?o<l`c00Oo<l`c
00?o0000oh1oP?n0Oh002on0Oh000ol0003oZEJYojUFZ@02ojUFZ@03o`000?oK9=_ofbCK00_ofbCK
00?o0000oo<<looc3?<01_oc3?<2o`0000?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oa
3_7ol@ka00Ool@ka00?o0000omXUf_oJ9MX01ooJ9MX00ol0003oSW6>ohiaSP05ohiaSP?o00003Ol]
dRd4o`0000_o0?l00ol0000?obKI9P04o`000?lIiQWo0000o`00017o;m0_00?o0000oc?<<olcc3<0
1olcc3<00ol0003oP7n0oh1oP00:oh1oP003o`000?nYEZWoZEJY00CoZEJY00?o0000om/TfooK9=/0
1ooK9=/3o`0000_ol`cc1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_402?oa3_400ol0003ofRGJomXU
fP06omXUfP03o`000?n>LHkoSW6>00;oSW6>0ol00003ofVFJ@03o`000?l]dRgo;M8]00[o;M8]00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AobKI9P03o`000?l_d2oo;m0_017o;m0_00?o
0000oc?<<olcc3<01olcc3<00ol0003oP7n0oh1oP00:oh1oP003o`000?nYEZWoZEJY00GoZEJY00Co
0000om/TfooK9=_ofbCK1Ol00002on0Oh003o`000?oc3??ol`cc00Wol`cc00Co0000ood2oOom0_go
o@;m0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000oo4>lOoa3_401ooa3_400ol0003ofRGJomXUfP05omXUfP?o0000
00?oSW6>o`000?l000001omYUVT00ol0003o;M8]obgB;@08obgB;@?o00002_l0o`02o`0000;o0?l0
00?o0000obKI9_lVfBH03olVfBH00ol0003o;m0_obo@;`0Aobo@;`03o`000?lcc3?o<l`c00Oo<l`c
00?o0000oh1oP?n0Oh002On0Oh000ol0003oZEJYojUFZ@07ojUFZ@?o00001ooP7n000ol0003ol`cc
oo<<l`09oo<<l`03o`000?om0_goo@;m00Coo@;m0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000oo4>lOoa3_401ooa
3_44o`0000;ofRGJ0_l00003ol`cc003o`000?mYUVWoJIIY00SoJIIY0_l00006obgB;@;o00000olS
g2<00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obKI9_lVfBH03_lV
fBH00ol0003o;m0_obo@;`0Bobo@;`03o`000?lcc3?o<l`c00Go<l`c00?o0000oh1oP?n0Oh002On0
Oh000ol0003oZEJYojUFZ@08ojUFZ@03o`000?oP7n3oh1oP00Ooh1oP00?o0000oo<<looc3?<02?oc
3?<00ol0003oo@;mood2o@07ood2o@;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oa3_7ol@ka00Col@ka0_l00004
onl@k`;o00001Oo<<l`00ol0003oJIIYofVFJ@0:ofVFJ@03o`000?l]dRgo;M8]00;o;M8]00?o0000
ob?L8olSg2<01?lSg2<00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obKI9_lVfBH03_lVfBH00ol0003o;m0_obo@;`0Bobo@;`[o00002_n0Oh000ol0003oZEJYojUFZ@08
ojUFZ@03o`000?oP7n3oh1oP00Ooh1oP00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@09
ood2o@?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003ol@kaoo4>lOoa3_42o`0000Ooka3_00?o0000ol`cc?o<<l`01?o<<l`0
0ol0003oJIIYofVFJ@0:ofVFJ@04o`000?l]dRgo0000o`0000So8m`S00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lVfBKo9]TV00ko9]TV00?o0000obo@;ol_d2l04_l_d2l00ol0003oE:]D
oeB[E007oeB[E003o`000?n0Oh3oP7n000KoP7n000?o0000ojUFZOnYEZT02_nYEZT00ol0003oh1oP
on0Oh006on0Oh003o`000?oc3??ol`cc00Sol`cc00?o0000ood2oOom0_d03?om0_d00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?oa
3_7o0000o`0000Woka3_00?o0000ol`cc?o<<l`01?o<<l`00ol0003oJIIYofVFJ@0;ofVFJ@03o`00
0?lSg2?o8m`S00Wo8m`S00?o0000o`3o0?l000002Ol0o`000ol0003o9]TVobKI9P0>obKI9P;o0000
4_l_d2l00ol0003oE:]DoeB[E009oeB[E0;o00001_n0Oh000ol0003oZEJYojUFZ@0:ojUFZ@03o`00
0?oP7n3oh1oP00Koh1oP00?o0000oo<<looc3?<02?oc3?<00ol0003oo@;mood2o@0<ood2o@03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000onl@koo_4>l02Oo_4>l00ol0003oc3?<ol`cc005ol`cc003o`000?mYUVWoJIIY00[oJIIY00?o
0000ob?L8olSg2<02_lSg2<2o`0000Wo0?l000?o0000obKI9_lVfBH03_lVfBH00ol0003o7^4No`00
0002o`0000oo;m0_00?o0000oeB[E?mDZe@02omDZe@00ol0003oP7n0oh1oP003o`0000goZEJY00?o
0000on0Oh?oP7n001_oP7n000ol0003ol`ccoo<<l`07oo<<l`03o`000?om0_goo@;m00coo@;m00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003oka3_onl@k`09onl@k`03o`000?o<<lcoc3?<00Goc3?<00?o0000ofVFJOmYUVT02OmYUVT2
o`0000_o8m`S0_l0000;o`3o0003o`000?lVfBKo9]TV00co9]TV00?o0000oakQ7_lNhAh00olNhAh3
o`0000co;m0_00?o0000oeB[E?mDZe@03?mDZe@2o`0000;oYEZU00?o0000ojUFZOnYEZT03?nYEZT0
0ol0003oh1oPon0Oh005on0Oh003o`000?oc3??ol`cc00Ool`cc00?o0000ood2oOom0_d03?om0_d0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o_4>ooka3_00[oka3_00?o0000ol`cc?o<<l`01_o<<l`00ol0003oJIIYofVFJ@07ofVF
J@03o`000?maSW7o000000[o8m`S00Co0000oacS7?lLhaco00002_l0o`000ol0003o9]TVobKI9P0<
obKI9P03o`000?lNhAko7^4N00Ko7^4N0_l00008obo@;`;o00003omDZe@00ol0003oYEZUojEJY@02
ojEJY@03o`000?nYEZWoZEJY00_oZEJY00?o0000on0Oh?oP7n001OoP7n000ol0003ol`ccoo<<l`07
oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003oka3_onl@k`0:onl@k`03o`000?o<<lcoc3?<
00Koc3?<00?o0000ofVFJOmYUVT01_mYUVT01Ol0003oLHiaog6>LOmaSW7o000000So8m`S00?o0000
oacS7?lLha`00_lLha`00ol0003o0?l0o`3o0006o`3o00Co00003?lVfBH00ol0003o7^4NoakQ7P08
oakQ7P?o00000_l_d2l3o`000003oco0?ol0003oE:]D00goE:]D00?o0000ojEJYOnUFZD01?nUFZD0
0ol0003oZEJYojUFZ@0:ojUFZ@03o`000?oP7n3oh1oP00Goh1oP00?o0000oo<<looc3?<01_oc3?<0
0ol0003oo@;mood2o@0<ood2o@03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000onl@koo_4>l02oo_4>l00ol0003oc3?<ol`cc007ol`c
c003o`000?mYUVWoJIIY00?oJIIY0_l00005og6>L@03o`000?lSg2?o8m`S00Co8m`S00?o0000oacS
7?lLha`00olLha`00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200;o0_d20ol00007obKI
9P;o00003_lNhAh2o`0000Go?l0o00?o0000oeB[E?mDZe@02_mDZe@00ol0003oYEZUojEJY@05ojEJ
Y@03o`000?nYEZWoZEJY00_oZEJY00?o0000on0Oh?oP7n001?oP7n000ol0003ol`ccoo<<l`06oo<<
l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003oka3_onl@k`0;onl@k`03o`000?o<<lcoc3?<00Oo
c3?<00?o0000ofVFJOmYUVT00_mYUVT00ol0003oLHiaog6>L@06og6>L@03o`000?lSg2?o8m`S00;o
8m`S00?o0000oacS7?lLha`01OlLha`00ol0003o0?l0o`3o0002o`3o00;o00002?l2o@83o`0000;o
9]TV0_l000000ol5nPGo0000oakQ7P0=oakQ7P03o`000?lo`3oo?l0o00Go?l0o00?o0000oeB[E?mD
Ze@02?mDZe@00ol0003oYEZUojEJY@07ojEJY@03o`000?nYEZWoZEJY00[oZEJY00?o0000on0Oh?oP
7n001?oP7n000ol0003ol`ccoo<<l`06oo<<l`03o`000?om0_goo@;m00coo@;m00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003oka3_
onl@k`0<onl@k`03o`000?o<<lcoc3?<00Soc3?<00Co0000ofVFJOmYUVWo00002OmaSW401Ol0003o
8m`Sob?L8olSg2?o000000So7><L00Go0000o`3o0?l0o`3o0?l0o`00000=o`;m0P;o00001?l5nPD0
0ol0003o7^4NoakQ7P0;oakQ7P03o`000?lo`3oo?l0o00Ko?l0o00?o0000oeB[E?mDZe@01omDZe@0
0ol0003oYEZUojEJY@08ojEJY@Co00002?nYEZT00ol0003oh1oPon0Oh004on0Oh003o`000?oc3??o
l`cc00Kol`cc00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?o_4>ooka3_00_oka3_0ol00009ol`c
c003o`000?mYUVWo000000_oLHia00?o0000ob?L8ol000002_lLha`00ol0003o0?l0o`00000?o`;m
0P03o`000?l5nPGo1OX500;o1OX500?o0000oakQ7_lNhAh02olNhAh00ol0003o?l0ooco0?`06oco0
?`03o`000?mDZeCoE:]D00KoE:]D00?o0000ojEJYOnUFZD02OnUFZD01?l0003obSG:olXeb_o:=LX7
o`0000;oZEJY00?o0000on0Oh?oP7n000ooP7n000ol0003ol`ccoo<<l`05oo<<l`03o`000?om0_go
o@;m00coo@;m00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?o_4>ooka3_00Soka3_0ol00003onhAkP03o`000?o<<lcoc3?<00Ooc3?<00?o0000og6>
LOmaSW402omaSW400ol0003o7><LoacS700:oacS7003o`000?l2o@;o0_d200go0_d200?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o7^4NoakQ7P09oakQ7P03o`000?lo`3oo?l0o00So?l0o00?o0000oeB[
E?mDZe@00omDZe@2o`0000coYEZU00?o0000olXeb_o:=LX02?o:=LX<o`0000?ol`cc0ol0000=ood2
o@03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000onl@koo_4>l01_o_4>l3o`0000OokQ7^00?o0000ol`cc?o<<l`01_o<<l`00ol0003o
LHiaog6>L@0;og6>L@03o`000?lLhaco7><L00Wo7><L0_l0000>o`;m0P03o`000?l5nPGo1OX500Go
1OX500?o0000oakQ7_lNhAh02OlNhAh00ol0003o?l0ooco0?`09oco0?`03o`000?mDZeCo000000;o
00000_nIIYT00ol0003oYEZUojEJY@08ojEJY@03o`000?o:=L[obSG:00cobSG:00?o0000onhAk_o^
4Nh01_o^4Nh3o`0000?oo@;m0_l00009ood2o@;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003oka3_onl@k`03onl@k`?o00002oo^4Nh00ol0003oc3?<
ol`cc004ol`cc003o`000?maSW7oLHia00_oLHia0ol00007oacS70?o000000?o3o0?o`000?l2o@80
3Ol2o@800ol0003o1OX5o`Gj1@06o`Gj1@03o`000?lNhAko7^4N00So7^4N00?o0000oco0?olo`3l0
2_lo`3l00ol0003oVFJIoiUVV@04oiUVV@03o`000?nUFZGoYEZU00OoYEZU00?o0000olXeb_o:=LX0
2oo:=LX00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00Coo@;m0ol00004ood2o@;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004onl@kol0
003o0000o`0000ookQ7^00?o0000ol`cc?o<<l`00oo<<l`>o`0000?oFZEJ0_l00002oacS70?o0000
1Ol?l0l00ol0003o0_d2o`;m0P0:o`;m0P03o`000?l5nPGo1OX500Oo1OX500?o0000oakQ7_lNhAh0
2?lNhAh00ol0003o?l0ooco0?`0:oco0?`03o`000?nIIYWoVFJI00GoVFJI00?o0000ojEJYOnUFZD0
1_nUFZD00ol0003obSG:olXebP0;olXebP03o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d0
1oom0_d2o`000003ood2oOl0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?ol0o`2o`0001;okQ7^00?o0000ol`cc?o<<l`00_o<<l`00ol0003o_D:moke2
_@0:oke2_@03o`000?mJYE[oFZEJ00?oFZEJ0_l00009o`o`3`03o`000?l2o@;o0_d200Wo0_d200?o
0000o`Gj1Ol5nPD02?l5nPD2o`0000So7^4N00?o0000oco0?olo`3l02Olo`3l00ol0003oVFJIoiUV
V@07oiUVV@03o`000?nUFZGoYEZU00CoYEZU00?o0000olXeb_o:=LX02oo:=LX00ol0003okQ7^onhA
kP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003okQ7^onhAkP0?onhAkP?o000000?oc3?<
o`000?nm@[d02onm@[d00ol0003oFZEJoeZUFP04oeZUFP03o`000?l?l0oo3o0?00Wo3o0?00?o0000
o`;m0_l2o@801ol2o@800ol0003o1OX5o`Gj1@09o`Gj1@04o`000?lCk1?o0000o`0000Ko7^4N00?o
0000oco0?olo`3l02Olo`3l00ol0003oVFJIoiUVV@08oiUVV@03o`000?nUFZGoYEZU00?oYEZU00?o
0000olXeb_o:=LX02oo:=LX00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003okQ7^onhAkP0<onhAkP;o00000oo]4^d2o`0000co_D:m00?o0000oeZUF_mJYEX01?mJYEX0
0ol0003o3o0?o`o`3`0:o`o`3`Wo00002ol5nPD00ol0003o4n`Coa?/4`02oa?/4`?o00000_lNhAh0
0ol0003o?l0ooco0?`0:oco0?`03o`000?nIIYWoVFJI00WoVFJI00?o0000ojEJYOnUFZD00_nUFZD0
0ol0003obSG:olXebP0:olXebP03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o^4Nh2o`0000GokA;]00?o0000oll`col000002_nm@[d00ol0003oFZEJoeZUFP06oeZU
FP03o`000?l?l0oo3o0?00Wo3o0?00?o0000o`3o0?l0o`001Ol0o`000ol0003o1OX5o`Gj1@09o`Gj
1@03o`000?lCk1?o4n`C00Go4n`C0ol00009oco0?`?o00003OnIIYT01Ol0003oYEZUojEJYOnUFZGo
000000cobSG:00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onhA
k_o^4Nh01Oo^4Nh2o`0000OokA;]00Co0000oll`coo?<<oo00002Onm@[d00ol0003oFZEJoeZUFP06
oeZUFP03o`000?l?l0oo3o0?00So3o0?00?o0000o`3o0?l0o`001ol0o`000ol0003o1OX5o`Gj1@07
o`Gj1@03o`000?lCk1?o4n`C00So4n`C0ol00002oco0?`Go00000_mnPGh00ol0003oVFJIoiUVV@0<
oiUVV@03o`000?nUFZGo000000cobSG:00?o0000onhAk_o^4Nh02_o^4Nh00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onhAk_o^4Nh00_o^4Nh2o`0000SokA;]00?o0000oll`coo?<<l00_o?<<l5o`00
00Co_D:m00?o0000oeZUF_mJYEX01_mJYEX00ol0003o3o0?o`o`3`08o`o`3`03o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o4n`Coa?/4`08oa?/4`03o`000?m3_4?o@ka3
00;o00002?mnPGh00ol0003oVFJIoiUVV@0<oiUVV@Co00002_o:=LX00ol0003okQ7^onhAkP0:onhA
kP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003okQ7^o`000?l0000:ondBk@03o`000?o?<<oocc3?
00;occ3?00?o0000oj1OX?nPGj000_nPGj04o`0000WoFZEJ00?o0000o`o`3ol?l0l02?l?l0l00ol0
003o0?l0o`3o0008o`3o0003o`000?l5nPGo1OX500Go1OX500?o0000oa?/4olCk1<02?lCk1<01Ol0
003o@ka3od>l@om3_4?o000000[oOX5n0ol0000;oiUVV@04o`000?oS7>?ohacSon<Lh`Co00001Oo:
=LX00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003okA;]ondBk@0:
ondBk@03o`000?o?<<oocc3?00?occ3?00?o0000oj1OX?nPGj001?nPGj000ol0003oFZEJoeZUFP07
oeZUFP03o`000?l?l0oo3o0?00Ko3o0?0_l0000;o`3o0003o`000?l5nPGo1OX500Go1OX500?o0000
oa?/4olCk1<02?lCk1<00ol0003o@ka3od>l@`02od>l@`03o`000?mnPGkoOX5n00OoOX5n00?o0000
ol8m`_o2?L801?l00006oiUVV@03o`000?oS7>?ohacS00KohacS0ol00002olXebP03o`000?o^4Nko
kQ7^00_okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o]4^gokA;]00WokA;]00?o0000oll`
coo?<<l01?o?<<l00ol0003oX5nPoj1OX005oj1OX003o`000?mJYE[oFZEJ00OoFZEJ00?o0000o`o`
3ol?l0l00_l?l0l3o`000003oakQ7_l0003o0?l000[o0?l000?o0000o`Gj1Ol5nPD01Ol5nPD00ol0
003o4n`Coa?/4`07oa?/4`03o`000?m3_4?o@ka300?o@ka300?o0000ogj1O_mnPGh01omnPGh00ol0
003o`Sg2ol8m`P04ol8m`P?o00000_nIIYT00ol0003ohacSon<Lh`0:on<Lh`;o00003_o^4Nh00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000ondBkOo]4^d02Oo]4^d00ol0003occ3?oll`c`04oll`c`03
o`000?nPGj3oX5nP00KoX5nP0_l00007oeZUFP03o`000?l?l0oo000000;o00001OlNhAh00ol0003o
0?l0o`3o0008o`3o00?o00001?l5nPD00ol0003o4n`Coa?/4`08oa?/4`03o`000?m3_4?o@ka300Co
@ka300?o0000ogj1O_mnPGh01_mnPGh00ol0003o`Sg2ol8m`P07ol8m`P;o00003_oS7><00ol0003o
kQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003okA;]ondBk@08ondBk@03o`00
0?o?<<oocc3?00Gocc3?00?o0000oj1OX?nPGj001?nPGj000ol0003oUVVFoiIYUP03o`0000CoFZEJ
0_l00008oakQ7P03o`000?l0o`3o0?l000Oo0?l000Co0000obOH9olWf2Oo9mPW0ol000000ol5nPGo
0000oa?/4`09oa?/4`03o`000?m3_4?o@ka300Co@ka300?o0000ogj1O_mnPGh01OmnPGh00ol0003o
`Sg2ol8m`P09ol8m`P03o`000?oS7>?ohacS00gohacS00?o0000onhAk_o^4Nh02_o^4Nh00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000ondBkOo]4^d01oo]4^d00ol0003occ3?oll`c`06oll`c`03o`00
0?nPGj3oX5nP00?oX5nP00?o0000oiIYU_nFJIH01?nFJIH2o`000003oeZUF_l0003o7^4N00[o7^4N
00?o0000o`3o0?l0o`001Ol0o`000ol0003o9mPWobOH9`05obOH9`03o`000?lCk1?o4n`C00Oo4n`C
0ol00007od>l@`03o`000?mnPGkoOX5n00CoOX5n00?o0000ol8m`_o2?L802Oo2?L800ol0003ohacS
on<Lh`0=on<Lh`03o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o]
4^gokA;]00GokA;]0ol00009oll`c`05o`000?nPGj3oX5nPoj1OX?l000002OnFJIH00ol0003o7^4N
oakQ7P0;oakQ7P03o`000?l0o`3o0?l000?o0?l000?o0000obOH9olWf2L01_lWf2L00ol0003o4n`C
oa?/4`06oa?/4`05o`000?lo_coo?kloocno?ol000001om3_4<00ol0003oOX5nogj1OP03ogj1OP03
o`000?o2?L;o`Sg200Wo`Sg200?o0000on<LhooS7><03_oS7><00ol0003okQ7^onhAkP09onhAkP03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003okA;]o`000004o`0000;olPgb00?o0000oll`coo?<<l0
1oo?<<l01?l0003oX5nPoj1OX?l00009oiIYUP;o00003OlNhAh00ol0003o0?l0o`3o0002o`3o0003
o`000?lWf2Oo9mPW00So9mPW00?o0000oa?/4olCk1<00olCk1<2o`0000Go?klo00?o0000od>l@om3
_4<01?m3_4<00ol0003oOX5nogj1OP03ogj1OP03o`000?o2?L;o`Sg200Wo`Sg200?o0000on<LhooS
7><03_oS7><00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000SolPgb
00?o0000oll`coo?<<l01_o?<<l00ol0003oX5nPo`000009oiIYUP04o`000?mVVFKoIYUVo`0000go
7^4N00Co0000o`3o0?l0o`3o00003?lWf2L01Ol0003o4n`Coa?/4olCk1?o000000So?klo0_l00005
od>l@`03o`000?mnPGkoOX5n00;oOX5n00?o0000ol8m`_o2?L802Oo2?L800ol0003ohacSon<Lh`0>
on<Lh`03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?ob3O;olPgb
00OolPgb00?o0000oll`coo?<<l01oo?<<l00ol0003oUVVFoiIYUP07oiIYUP03o`000?mVVFKoIYUV
00;oIYUV00?o0000oakQ7_lNhAh02_lNhAh00ol0003o0?l0o`00000>obOH9`03o`000?lCk1?o0000
00_o?klo00?o0000od>l@om3_4<00_m3_4<01Ol0003oOX5nogj1O_mnPGko000000co`Sg200?o0000
on<LhooS7><03_oS7><3o`0000WokQ7^00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb
00WolPgb00?o0000oll`coo?<<l01_o?<<l00ol0003oUVVFoiIYUP06oiIYUP03o`000?mVVFKoIYUV
00?oIYUV00?o0000oakQ7_lNhAh02olNhAh00ol0003o9mPWobOH9`0>obOH9`03o`000?lo_coo?klo
00_o?klo0_l00003od>l@`04o`000?mnPGkoOX5no`0000[o`Sg20ol0000>on<Lh`;o00000oom0_d2
o`0000OokQ7^00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?ob3O;olPgb00[olPgb00?o0000oll`
coo?<<l01?o?<<l00ol0003oUVVFoiIYUP06oiIYUP03o`000?mVVFKoIYUV00GoIYUV00?o0000oakQ
7_lNhAh01olNhAh3o`00017o9mPW00?o0000ocno?olo_cl03Olo_cl01Ol0003o@ka3od>l@ol0003o
OX5n00Co00000oo2?L85o`0000;okQ7^00?o0000on<LhooS7><02_oS7><2o`0000Ooo@;m0_l00004
onhAkP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003olPgboo8=lP0;oo8=lP03o`000?o?<<oocc3?
00Cocc3?00?o0000oiIYU_nFJIH01OnFJIH00ol0003oIYUVofJIIP06ofJIIP03o`000?lNhAko7^4N
00Co7^4N0ol00002obCK9003o`000?lWf2Oo9mPW00oo9mPW0_l0000?ocno?`04o`000?m3_4?o0000
o`0000Co[e2_0ol00008onhAkP03o`000?oS7>?ohacS00OohacS0_l0000;ood2o@;o00000_o^4Nh0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo8=l_ob3O803?ob3O86o`0000OoUVVF00?o0000ofJI
I_mVVFH02?mVVFH00ol0003o7^4NoakQ7P03o`0000Ko9=/T00?o0000obOH9olWf2L03OlWf2L01?l0
003oAkQ7odNhAol0000?ocno?`03o`000?n_D:oo[e2_00Go[e2_00?o0000onhAk_o^4Nh02?o^4Nh0
0ol0003ohacSon<Lh`05on<Lh`03o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ob3O800ol0003oe2_Dom@[e004om@[
e003o`000?nFJIKoUVVF00?oUVVF00?o0000ofJII_mVVFH02_mVVFH2o`0000[o9=/T00?o0000obOH
9olWf2L02olWf2L00ol0003oAkQ7odNhA`02odNhA`03o`000?lo_coo?klo00_o?klo0_l00007ojm@
[`03o`000?o^4NkokQ7^00WokQ7^00?o0000on<LhooS7><00_oS7><2o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo8=l_ob3O802oob3O800ol0003oe2_Dom@[e006om@[e005o`000?nFJIKoUVVFoiIY
U_l000003OmVVFH00ol0003o9=/TobCK900:obCK9003o`000?lWf2Oo9mPW00Wo9mPW00?o0000odNh
Aom7^4L01?m7^4L00ol0003o?kloocno?`08ocno?`;o000000?oJIIYo`000?n_D:l01on_D:l00ol0
003okQ7^onhAkP09onhAkP04o`000?oS7>?o0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?ob3O;olPgb
00WolPgb00?o0000om@[e?oD:m@02?oD:m@00ol0003oUVVFo`00000=ofJIIP03o`000?lTfbCo9=/T
00_o9=/T00?o0000obOH9olWf2L02?lWf2L00ol0003oAkQ7odNhA`06odNhA`03o`000?lo_coo?klo
00Go?klo0_l00003ofVFJ@03o`000?n_D:oo[e2_00Ko[e2_00?o0000onhAk_o^4Nh02_o^4Nh00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003olPgboo8=lP07oo8=lP03o`000?oD:mCoe2_D00[oe2_D00?o0000ofJII_mV
VFH03?mVVFH00ol0003o9=/TobCK900<obCK9003o`000?lWf2Oo9mPW00Ko9mPW00?o0000odNhAom7
^4L02?m7^4L00ol0003o?kloocno?`02ocno?`;o00001_mYUVT00ol0003o[e2_ojm@[`05ojm@[`03
o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?ob3O;olPgb00GolPgb
00?o0000om@[e?oD:m@03?oD:m@2o`0000coIYUV00?o0000obCK9?lTfb@03OlTfb@00ol0003o9mPW
obOH9`04obOH9`03o`000?m7^4OoAkQ700[oAkQ700Co0000ocno?ol0003o00002?mYUVT00ol0003o
[e2_ojm@[`06ojm@[`03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_ob3O800ol0003oe2_Dom@[e00=om@[e003o`000?nCK9?o000000;o00002?mVVFH00ol0003o9=/T
obCK900?obCK90Ko00003_m7^4L00ol0003oJIIYofVFJ@08ofVFJ@03o`000?n_D:oo[e2_00Ko[e2_
00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000oo@;m?od2oCom0_d
0_l0000?om@[e003o`000?nCK9?oTfbC00?oTfbC0ol00005ofJIIP;o00004?lTfb@01_l0003o8m`S
ob?L8ol0003o6n@Ko`0000koAkQ700?o0000ofVFJOmYUVT02OmYUVT00ol0003o[e2_ojm@[`05ojm@
[`03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003o
e2_Dom@[e00=om@[e003o`000?nCK9?oTfbC00KoTfbC0ol000001?mVVFKo0000oco0?olo`3l3o`00
00co9=/T00Go0000ob?L8olSg2?o8m`So`000002oa_T6`03o`000?m7^4OoAkQ700_oAkQ700?o0000
ofVFJOmYUVT02OmYUVT00ol0003o[e2_ojm@[`06ojm@[`03o`000?o^4NkokQ7^00SokQ7^0_l0000A
ood2o@?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003om0_doo@;m004oo@;m0oo00003?nCK9<00ol0003o?l0ooco0?`04oco0
?`?o00002?lTfb@00ol0003o8m`Sob?L8`02ob?L8`05o`000?lKi1_o6n@Koa_T6ol000003?m7^4L0
0ol0003oJIIYofVFJ@09ofVFJ@03o`000?n_D:oo[e2_00Go[e2_3?l00002ooP7n0;o00003Oom0_d2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003om0_doo@;m005oo@;m003o`000?oH9mSof2OH00_of2OH00?o0000oi=/
TonCK9<02_nCK9<00ol0003o?l0ooco0?`07oco0?`;o00001OlTfb@00ol0003o8m`Sob?L8`03ob?L
8`03o`000?lKi1_o6n@K00;o6n@K00?o0000odNhAom7^4L02Om7^4L00ol0003oJIIYofVFJ@0:ofVF
J@03o`000?n_D:oo[e2_00?o[e2_00?o0000onPGj?oX5nP02OoX5nP00ol0003on0OhooP7n002ooP7
n0;o00002Oom0_d2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003om0_doo@;m006oo@;m003o`000?oH9mSof2OH00[o
f2OH00?o0000oi=/TonCK9<02onCK9<00ol0003o?l0ooco0?`09oco0?`?o000000?o9=/To`000?lS
g2<01OlSg2<00ol0003o6n@Koa_T6`03oa_T6`03o`000?m7^4OoAkQ700SoAkQ73_l00003ojm@[`;o
00002ooX5nP00ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00?oo@;m0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000oo@;m?od2o@01Ood2o@00ol0003ogb3Oo`00000;omPWf003o`000?nCK9?oTfbC00[oTfbC
0_l0000>oco0?`03o`000?lSg2?o8m`S00Go8m`S00?o0000oa_T6olKi1/00olKi1/00ol0003oAkQ7
odNhA`08odNhA`03o`000?n/Djco[5>/00_o[5>/00?o0000ojm@[ol000003OoX5nP00ol0003on0Oh
ooP7n006ooP7n0;o000000?oo@;mo`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00Kom0_d00Co
0000omlPgooO8=oo00002_oH9mP00ol0003oTfbCoi=/T`09oi=/T`03o`000?m]TVgo000000ko?l0o
00?o0000ob?L8olSg2<01OlSg2<00ol0003o6n@Koa_T6`04oa_T6`03o`000?m7^4OoAkQ700KoAkQ7
00?o0000ojaC[?n/Dj`03On/Dj`00ol0003oj1OXonPGj00<onPGj003o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000omlPgooO8=l00_oO
8=l00ol0003of2OHomPWf006omPWf003o`000?nCK9?oTfbC00SoTfbC0_l00003offBK@03o`000?lo
`3oo?l0o00_o?l0o00?o0000ob?L8olSg2<01OlSg2<00ol0003o6n@Koa_T6`05oa_T6`03o`000?m7
^4OoAkQ700GoAkQ700?o0000ojaC[?n/Dj`03On/Dj`00ol0003oj1OXonPGj00;onPGj003o`000?oh
1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000
omlPgooO8=l00ooO8=l00ol0003of2OHomPWf005omPWf003o`000?nCK9?oTfbC00OoTfbC00?o0000
offBKOm]TVd00om]TVd00ol0003o?l0ooco0?`0:oco0?`03o`000?lSg2?o8m`S00Ko8m`S00?o0000
oa_T6olKi1/01_lKi1/00ol0003oAkQ7odNhA`04odNhA`03o`000?n/Djco[5>/00go[5>/3ol0000;
ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000omlPgooO8=l01OoO8=l00ol0
003of2OHomPWf004omPWf003o`000?nCK9?oTfbC00GoTfbC0_l00006offBK@03o`000?lo`3oo?l0o
00Wo?l0o0_l00008ob?L8`03o`000?lKi1_o6n@K00Ko6n@K1Ol000000om7^4Oo0000ojaC[00?ojaC
[003o`000?o[5>_ojaC[00_ojaC[00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?od2oCom0_d00Kom0_d00?o0000omlPgooO8=l01_oO8=l00ol0003o
f2OHomPWf004o`0000KoTfbC00?o0000offBKOm]TVd01om]TVd00ol0003o?l0ooco0?`05oco0?`?o
000000?o=</do`000?lSg2<01olSg2<00ol0003o6n@Koa_T6`05oa_T6`03o`000?mLXecoG:=L00?o
G:=L0_l0000?ojaC[0;o00003Oo[5>/00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wom0_d00?o0000omlPgooO8=l01ooO8=l2o`0000Co^TFj00Co0000oi=/TonCK9?o
TfbC0_l0000:offBK@03o`000?lo`3oo?l0o00;o?l0o0ol00005ocC;=003o`000?lSg2?o8m`S00Go
8m`S00?o0000oa_T6olKi1/01?lKi1/00ol0003oG:=LoebSG006oebSG003o`000?n/Djco[5>/00[o
[5>/0_l00002om8]dP03o`000?o[5>_ojaC[00[ojaC[00?o0000ooP7n?oh1oP02?oh1oP00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@01_od2o@00ol0003ogb3OomlPg`08omlPg`03o`00
0?njAK[o^TFj00Co^TFj00?o0000oi=/Tol000003?m]TVd00ol0003o?l0oo`000002o`0000Wo=</d
00?o0000ob?L8olSg2<01?lSg2<00ol0003o6n@Koa_T6`03oa_T6`03o`000?mLXecoG:=L00SoG:=L
1_l00004ojaC[0;o00001OoB;M800ol0003ojaC[on/Dj`09on/Dj`03o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?od2oCom0_d00Gom0_d00?o0000omlPgooO8=l01ooO
8=l00ol0003o^TFjokY5^P06okY5^P03o`000?m]TVgoKI9]00coKI9]00?o0000ocC;=?ldbc@02_ld
bc@00ol0003o8m`Sob?L8`04ob?L8`04o`000?lKi1_o6n@Koa_T6`;o00002omLXe`00ol0003o/Dja
ok5>/@03ok5>/@Co00002?oB;M800ol0003ojaC[on/Dj`08on/Dj`03o`000?oh1oSon0Oh00Oon0Oh
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000oo@;m?od2o@00ood2o@00ol0003ogb3OomlPg`07omlPg`03o`000?nj
AK[o^TFj00Oo^TFj00?o0000offBKOm]TVd03?m]TVd00ol0003o=</docC;=00;ocC;=003o`000?lS
g2?o8m`S00?o8m`S00Co0000oa_T6olKi1_o00003OmLXe`00ol0003o/Djaok5>/@06ok5>/@03o`00
0?oB;M;odRgB00OodRgB00?o0000on/Djoo[5>/01oo[5>/00ol0003on0OhooP7n006ooP7n004o`00
0?on0OkooP7nooh1oP;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?od2oCom0_d00;om0_d00?o0000omlPgooO8=l0
1_oO8=l00ol0003o^TFjokY5^P09okY5^P03o`000?m]TVgoKI9]00WoKI9]0_l0000>ocC;=0?o0000
0olSg2<00ol0003o6n@Ko`00000=oebSG003o`000?naC[7o/Dja00Oo/Dja00?o0000om8]d_oB;M80
2?oB;M8:o`0000Kon0Oh0_l00006ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000Oogb3O00?o
0000okY5^_njAKX02_njAKX00ol0003oKI9]offBK@06offBK@;o000000?oIYUVo`000?ldbc@02old
bc@2o`0000?oAkQ71Ol0000>oebSG003o`000?naC[7o/Dja00Oo/Dja00?o0000om8]d_oB;M802?oB
;M800ol0003ol0o`oo0?l006oo0?l003o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh01oon
0Oh2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003okA;]ondBk@03ondBk@Co00000_oO8=l00ol0003o^TFjokY5^P0;
okY5^P03o`000?m]TVgoKI9]00?oKI9]0ol00004ofJIIP03o`000?ldbcCo=</d00Oo=</d0_l00008
odNhA`03o`000?mLXecoG:=L00goG:=L00?o0000ok5>/OnaC[402?naC[400ol0003odRgBom8]dP07
om8]dP03o`000?o`3o3ol0o`00Ool0o`0ol000000ooh1oSo0000ooh1oP0;ooh1oP;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o]4^gokA;]00OokA;]0_l0000?okY5^P03o`000?m]TVgoKI9]00;o00002?mVVFH00ol0
003o=</docC;=005ocC;=003o`000?m7^4OoAkQ700SoAkQ700?o0000oebSG?mLXe`03OmLXe`00ol0
003o/Djaok5>/@08ok5>/@03o`000?oB;M;odRgB00KodRgB00?o0000oo0?l?o`3o002?o`3o001?l0
003on@KiooT6nOl0000?ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003okA;]ondBk@09ondB
k@03o`000?njAK[o^TFj00ko^TFj0_l0000;ofJIIP03o`000?ldbcCo=</d00;o=</d0_l0000;odNh
A`03o`000?mLXecoG:=L00goG:=L00?o0000ok5>/OnaC[402?naC[400ol0003odRgBom8]dP06om8]
dP03o`000?o`3o3ol0o`00Ool0o`00Go0000ooT6nOoi1_Won@Kio`00000@ooh1oP;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003okA;]ondBk@0:ondBk@03o`000?njAK[o^TFj00go^TFj0_l0000<ofJIIP04o`000?ldbcCo0000
o`0000goAkQ700?o0000oebSG?mLXe`03?mLXe`00ol0003o/Djaok5>/@09ok5>/@03o`000?oB;M;o
dRgB00KodRgB00?o0000oo0?l?o`3o001_o`3o000ol0003on@KiooT6n@03ooT6n@03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003okA;]ondBk@0:ondBk@03o`000?njAK[o^TFj00co^TFj00Co0000ok9=
/_nbCK;o00003?mVVFH00ol0003oAkQ7odNhA`0>odNhA`03o`000?mLXecoG:=L00SoG:=L1?l0000;
ok5>/@03o`000?oB;M;odRgB00KodRgB00?o0000oo0?l?o`3o001Oo`3o000ol0003on@KiooT6n@04
ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003okA;]ondBk@0;ondBk@03o`000?njAK[o^TFj
00_o^TFj00?o0000ok9=/_nbCK800_nbCK800ol0003oIYUVofJIIP09ofJIIP03o`000?m7^4OoAkQ7
00koAkQ700Co0000oebSG?mLXecoG:=L1ol00003ogj1OP03o`000?naC[7o/Dja00Wo/Dja00?o0000
om8]d_oB;M801_oB;M800ol0003ol0o`oo0?l004oo0?l003o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o]4^gokA;]00cokA;]00?o0000okY5^_njAKX02_njAKX00ol0
003o/Tfbok9=/P03ok9=/P03o`000?mVVFKoIYUV00SoIYUV00?o0000odNhAom7^4L03_m7^4L4o`00
00_oOX5n00?o0000ok5>/OnaC[402?naC[400ol0003odRgBom8]dP05om8]dP03o`000?o`3o3ol0o`
00Gol0o`00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000ondBkOo]
4^d03?o]4^d7o`0000Go^TFj00?o0000ok9=/_nbCK801OnbCK800ol0003oIYUVofJIIP07ofJIIP03
o`000?m7^4OoAkQ700koAkQ700?o0000ogj1O_mnPGh03OmnPGh00ol0003o/Djaok5>/@08ok5>/@03
o`000?oB;M;odRgB00CodRgB00?o0000oo0?l?o`3o001?o`3o000ol0003on@KiooT6n@07ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003okA;]ondBk@0=ondBk@03o`000?oE:]GoeB[E00CoeB[E
1Ol00009ok9=/P03o`000?mVVFKoIYUV00KoIYUV00?o0000odNhAom7^4L03_m7^4L00ol0003oOX5n
ogj1OP0=ogj1OP03o`000?naC[7o/Dja00So/Dja00Co0000om8]d_oB;M;odRgB1Ol00004oo0?l003
o`000?oi1_Won@Ki00Won@Ki1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=ondBk@03o`000?oE:]GoeB[E00WoeB[E
0_l00009ok9=/P03o`000?mVVFKoIYUV00KoIYUV00?o0000odNhAom7^4L03?m7^4L00ol0003oOX5n
ogj1OP0?ogj1OPKo00001?naC[44o`0000GojQGZ0_l000000oo`3o3o0000ooT6n@0;ooT6n@04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?of2OKomPWfooH9mP?o00002_o]4^d00ol0003o
eB[EomDZe@09omDZe@03o`000?o1?/7o000000;o00001onbCK800ol0003oIYUVofJIIP05ofJIIP03
o`000?m7^4OoAkQ700SoAkQ71Ol0000Aogj1OP03o`000?no@;oo_d2o00?o_d2o1?l0000;onXEjP03
o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000ooH9m_of2OH01Oof2OH2o`0000OokA;]
00?o0000omDZeOoE:]D02_oE:]D00ol0003o`Ck1ol4n`@02ol4n`@?o00001OnbCK800ol0003oIYUV
ofJIIP04ofJIIP04o`000?m7^4OoAkQ7odNhA`Oo00001?meRWD00ol0003oOX5nogj1OP0>ogj1OP03
o`000?no@;oo_d2o00Oo_d2o00?o0000onXEj_oZ5NX02OoZ5NX00ol0003on@KiooT6n@09ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003omPWfooH9mP08ooH9mP;o00001?o]4^d00ol0003oeB[E
omDZe@0;omDZe@03o`000?o1?/7o`Ck100Go`Ck10ol00003ok9=/P04o`000?mVVFKoIYUVofJIIPKo
00003?meRWD00ol0003oOX5nogj1OP0=ogj1OP03o`000?no@;oo_d2o00Oo_d2o00?o0000onXEj_oZ
5NX02_oZ5NX00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ooH9mP?o000000?okA;]o`000?oE:]D0
3?oE:]D00ol0003o`Ck1ol4n`@08ol4n`@?o000000Co/Tfbo`000?l0003o00000_naC[400ol0003o
MHYeogF:M@0=ogF:M@03o`000?mnPGkoOX5n00coOX5n00?o0000okm0_ono@;l02?no@;l00ol0003o
jQGZonXEjP0;onXEjP03o`000?oi1_Won@Ki00Kon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
mPWf00?o0000omDZeOoE:]D03?oE:]D00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?naC[7o/Dja00?o
/Dja00?o0000ogF:MOmeRWD03?meRWD00ol0003oQWV6o`00000=ogj1OP03o`000?no@;oo_d2o00So
_d2o00?o0000onXEj_oZ5NX03?oZ5NX3o`0000Gon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?of2OKomPWf00comPWf00?o0000omDZeOoE:]D03?oE:]D00ol0003o`Ck1ol4n`@0:ol4n`@03o`00
0?naC[7o/Dja00Go/Dja00?o0000ogF:MOmeRWD02_meRWD01?l0003oQWV6ohIiQ_n6NHH2o`0000[o
OX5n00?o0000okm0_ono@;l02Ono@;l00ol0003ojQGZonXEjP0<onXEjP03o`000?oj1O[onPGj00?o
000000?on@Kio`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000omDZeOoE:]D0
3?oE:]D00ol0003o`Ck1ol4n`@09ol4n`@03o`000?naC[7o/Dja00Ko/Dja00?o0000ogF:MOmeRWD0
2OmeRWD00ol0003oQWV6ohIiQP02ohIiQP03o`000?ncC;?o000000;o00001omnPGh00ol0003o_d2o
okm0_`09okm0_`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000ooH9m_of2OH02oof2OH00ol0003oeB[EomDZe@0;omDZe@03o`000?o1
?/7o`Ck100So`Ck100?o0000ok5>/OnaC[401onaC[400ol0003oMHYeogF:M@08ogF:M@03o`000?n6
NHKoQWV600?oQWV600?o0000ok=</oncC;<00_ncC;<2o`0000CoOX5n00?o0000okm0_ono@;l02_no
@;l00ol0003ojQGZonXEjP0:onXEjP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?of2OKomPWf00[omPWf0ol0000;omDZe@Ko00001?o1?/400ol0003o/Djaok5>/@08
ok5>/@03o`000?meRWGoMHYe00OoMHYe00?o0000ohIiQ_n6NHH00on6NHH00ol0003o/dbcok=</`05
ok=</`?o000000?oOX5no`000?no@;l02ono@;l00ol0003ojQGZonXEjP09onXEjP03o`000?oj1O[o
nPGj00OonPGj00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?of2OKomPWf00WomPWf00?o0000ondB
kOo]4^d01?l00006omDZe@03o`000?oG:=OoebSG00CoebSG1?l0000<ok5>/@03o`000?meRWGoMHYe
00GoMHYe00?o0000ohIiQ_n6NHH01?n6NHH00ol0003o/dbcok=</`08ok=</`03o`000?no@;oo_d2o
00_o_d2o00?o0000onXEj_oZ5NX02?oZ5NX00ol0003onPGjooX5nP08ooX5nPGo00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?of2OKomPWf00OomPWf00?o0000ondBkOo]4^d01Oo]4^d3o`0000;oeB[E00?o0000omLXeooG
:=L02?oG:=L00ol0003o/Djaok5>/@0:ok5>/@03o`000?meRWGoMHYe00CoMHYe00?o0000ohIiQ_n6
NHH01On6NHH00ol0003o/dbcok=</`08ok=</`03o`000?no@;oo_d2o00Wo_d2o1?l00008onXEjP03
o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWf
ooH9mP05ooH9mP03o`000?o]4^gokA;]00WokA;]0_l0000<omLXe`03o`000?naC[7o/Dja00Wo/Dja
00?o0000ogF:MOmeRWD00omeRWD00ol0003oQWV6ohIiQP05ohIiQP03o`000?ncC;?o/dbc00[o/dbc
00?o0000okm0_ono@;l01?no@;l4o`0000CoiA[U00?o0000onXEj_oZ5NX01?oZ5NX00ol0003onPGj
ooX5nP0:ooX5nP03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?of2OKomPWf00?omPWf00?o0000ondBkOo]4^d02oo]
4^d00ol0003oebSGomLXe`0:omLXe`03o`000?naC[7o/Dja00Wo/Dja00?o0000ogF:MOmeRWD00_me
RWD00ol0003oQWV6ohIiQP06ohIiQP03o`000?ncC;?o/dbc00[o/dbc00?o0000okm0_ono@;l01?l0
0009onDJi@Ko00003?oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000ooH9m_of2OKomPWf0_l0
000=ondBk@03o`000?oG:=OoebSG00[oebSG00?o0000ok5>/OnaC[402OnaC[401Ol0003oMHYeogF:
MOmeRWGo000000WoQWV600?o0000ok=</oncC;<02oncC;<2o`0000goiA[U00?o0000ooP7n?oh1oP0
0_oh1oP00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfo`00
0002oo/4n`;o00002oo]4^d00ol0003oebSGomLXe`0;omLXe`03o`000?naC[7o/Dja00Wo/Dja00?o
0000ogF:MOl000002On6NHH00ol0003o/dbcok=</`0<ok=</`03o`000?oU6^GoiA[U00coiA[U00?o
0000ooP7n?oh1oP00ooh1oP00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on`Ckoo/4n`03oo/4n`;o00002_o]4^d00ol0003oebSGomLXe`0:omLXe`03o`000?naC[7o
/Dja00So/Dja1Ol00008ohIiQP03o`000?ncC;?o/dbc00co/dbc00?o0000onDJiOoU6^D02ooU6^D0
0ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001ook1?/2o`0000SokA;]00?o0000omLXeooG:=L02_oG:=L00ol0003o/Djaok5>/@07ok5>
/@03o`000?ngB;Oo]dRg00?o]dRg0ol00005ohIiQP03o`000?ncC;?o/dbc00_o/dbc00?o0000onDJ
iOoU6^D03?oU6^D00ol0003on0OhooP7n006ooP7n003o`000?oj1O[onPGj00OonPGj00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?on0Oko000000Won`Ck00?o0000ondBkOo]4^d01Oo]4^d2o`0000co
ebSG00?o0000ok5>/OnaC[401OnaC[400ol0003o]dRgokM8]`07okM8]`?o000000?oQWV6o`000?nc
C;<03OncC;<00ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00Kon0Oh00?o0000ooX5n_oj
1OX01_oj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ooh1oP03o`000?ok1?_on`Ck00Oon`Ck
0_l00004ondBk@03o`000?ob3O;olPgb00;o00002_oG:=L00ol0003o/Djaok5>/@03ok5>/@;o0000
3OngB;L2o`0000go/dbc0ol0000=onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX0
1Ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00Son`Ck0_l0
00000oo]4^go0000oo8=lP04oo8=lP03o`000?oG:=OoebSG00OoebSG00Co0000ok5>/OnaC[7o/Dja
0_l00002om/Tf`03o`000?ngB;Oo]dRg00co]dRg3Ol00003onLHi`03o`000?oU6^GoiA[U00[oiA[U
00?o0000ooP7n?oh1oP02?oh1oP01?l0003onPGjooX5n_oj1OX4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?on0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?ob3O;olPgb00GolPgb0_l00008omLXe`03o`000?naC[7o000000GofbCK
00?o0000okM8]ongB;L02ongB;L00ol0003oa3_4ol@ka009ol@ka003o`000?oW6>OoiaSW00;oiaSW
0_l00009onDJi@03o`000?oh1oSon0Oh00[on0Oh0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ooh1
oP0:ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000oo8=l_ob3O801oob3O84o`0000?oebSG0ol0
0007om/Tf`03o`000?ngB;Oo]dRg00[o]dRg00?o0000ol@ka?o4>l@02Oo4>l@00ol0003oiaSWonLH
i`04onLHi`;o00001ooU6^D00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo8=l_ob3O802?ob3O80
1?l0003ol@kaoo4>lOoa3_43o`0000;ojAKY00?o0000om/TfooK9=/01_oK9=/00ol0003o]dRgokM8
]`08okM8]`03o`000?o4>lCoa3_400[oa3_400?o0000onLHiooW6>L01_oW6>L00ol0003oiA[UonDJ
i@04onDJi@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003olPgboo8=lP08oo8=lP03o`000?oa3_7o
l@ka00Col@ka00Go0000onTFjOoY5^WojAKYo`000008om/Tf`03o`000?ngB;Oo]dRg00Oo]dRg00?o
0000ol@ka?o4>l@02_o4>l@00ol0003oiaSWonLHi`07onLHi`;o00001?oU6^D00ol0003on0OhooP7
n008ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003olPgboo8=lP08oo8=lP03o`000?oa3_7ol@ka00Col@ka00?o0000onTFjOoY5^T00_oY5^T0
0ol0003ofbCKom/Tf`07om/Tf`03o`000?ngB;Oo]dRg00Ko]dRg00?o0000ol@ka?o4>l@02_o4>l@0
0ol0003oiaSWonLHi`09onLHi`05o`000?oU6^GoiA[UonDJiOl000002Ooh1oP00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_olPgb00?o0000oo4>lOoa3_401?oa3_400ol0003ojAKYonTFj@03
onTFj@03o`000?oK9=_ofbCK00OofbCK00?o0000okM8]ongB;L01OngB;L00ol0003oa3_4ol@ka00:
ol@ka003o`000?oW6>OoiaSW00WoiaSW1?l00009ooP7n003o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ok1?_on`Ck
oo/4nol000002_ob3O800ol0003ol@kaoo4>l@05oo4>l@03o`000?oY5^WojAKY00?ojAKY00?o0000
om/TfooK9=/02?oK9=/00ol0003o]dRgokM8]`04okM8]`03o`000?o4>lCoa3_400Woa3_400?o0000
onLHiooW6>L02?oW6>L2o`0000?on@Ki00?o0000ooP7n?oh1oP01_oh1oP00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003olPgboo8=lP06oo8=lP03o`000?oa3_7ol@ka
00Gol@ka00?o0000onTFjOoY5^T01?oY5^T00ol0003ofbCKom/Tf`09om/Tf`03o`000?ngB;Oo]dRg
00;o]dRg00?o0000ol@ka?o4>l@02_o4>l@00ol0003oiaSWonLHi`06onLHi`;o00001_oi1_T8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?ob3O;olPgb00GolPgb00?o0000oo4>lOoa
3_401Ooa3_400ol0003ojAKYonTFj@05onTFj@03o`000?oK9=_ofbCK00WofbCK00Go0000okM8]ong
B;Oo]dRgo`00000<ol@ka003o`000?oW6>OoiaSW00CoiaSW0_l00008ooT6n@03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo8=l_ob
3O800oob3O800ol0003ol@kaoo4>l@06oo4>l@03o`000?oY5^WojAKY00GojAKY00?o0000om/TfooK
9=/02_oK9=/00ol0003o]dRgo`000004o`0000Woa3_400?o0000onLHiooW6>L00_oW6>L2o`0000[o
n@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`00
0?ob3O;olPgb00;olPgb00?o0000oo4>lOoa3_401_oa3_400ol0003ojAKYonTFj@07onTFj@;o0000
2ooK9=/00ol0003ok1?/on`Ck003on`Ck0Oo00000_o4>l@00ol0003oiaSWonLHi`02o`0000_on@Ki
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/02Ook
1?/01Ol0003olPgboo8=l_ob3O;o000000Sol@ka00?o0000onTFjOoY5^T01ooY5^T00ol0003om0_d
o`000002o`0000SofbCK00?o0000on`Ck?o/4n`02_o/4n`5o`0000gon@Ki00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo/4n`03o`000?ob3O;o000000Wol@ka00?o
0000onTFjOoY5^T01_oY5^T00ol0003om0_doo@;m003oo@;m0?o00001?oK9=/00ol0003ok1?/on`C
k00=on`Ck003o`000?oi1_Won@Ki00gon@Ki00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_on`Ck00?o0000oo4>lOoa3_401ooa3_400ol0003ojAKYonTFj@07
onTFj@03o`000?od2oCom0_d00Kom0_d0ol000000ooK9=_o0000on`Ck00>on`Ck003o`000?oi1_Wo
n@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009oo/4
n`03o`000?oa3_7ol@ka00;ol@ka1_l00008onTFj@03o`000?od2oCom0_d00[om0_d00?o0000on`C
k?o/4n`03oo/4n`00ol0003on@KiooT6n@0:ooT6n@;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007oo/4n`Go00001_oh1oP00ol0003ojAKYonTFj@05onTFj@03o`000?od2oCom0_d00[o
m0_d00?o0000on`Ck?o/4n`03oo/4n`00ol0003on@KiooT6n@07ooT6n@?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005oo/4n`03o`000?oh1oSon0Oh00Won0Oh00?o0000onTFjOoY
5^T00ooY5^T00ol0003om0_doo@;m00;oo@;m003o`000?o/4ncok1?/00ook1?/00?o0000ooT6nOoi
1_T01Ooi1_T2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?on`Cko`000?l00000
3Ooh1oP00ol0003ojAKYonTFj@02onTFj@03o`000?od2oCom0_d00_om0_d5?l00004ooT6n@;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooP7n004o`000?oY5^WojAKYo`0000kom0_d
00?o0000ooX5n_oj1OX04?oj1OX00ol0003on@Kio`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_oh1oP00ol0003ojAKYo`00000>oo@;m003o`00
0?oj1O[onPGj017onPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003on0OhooP7n00=ooP7n003o`000?od2oCom0_d00Wom0_d1Ol0
000BooX5nP;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003on0OhooP7n00<ooP7n003o`000?od2oCom0_d00;om0_d1ol00004ooh1oP03o`000?oj1O[o
nPGj00oonPGj00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?oh1oSon0Oh00con0Oh1?l0000<ooh1oP03o`000?oj1O[onPGj00conPGj0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooP7n?oh1oP03?oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00kooP7n00?o0000ooX5n_oj
1OX02Ooj1OX2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooP7n?oh1oP02_oh1oP00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?oj1O[onPGj00KonPGj0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aooh1oP?o00001_oj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000ooj1OX2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ooX5n_l000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool00ol00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00?o003o0oooo`03o`00o`;oool01ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool02_l00?l2oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000<o`00o`;oool02ol00?l00oooo`3o003oo`00o`03o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo0005o`00o`coool02?l00?l2oooo00Co003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
1Ol00?l<oooo00So003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool0
2ol00?l2oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00Ko003o00?oool0o`00ool00?l0
0ol00?l2oooo00[o003o0oooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`07o`00o`03oooo
0?l00?oo003o00;o003o0_ooo`09o`00o`?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
0007o`00o`;oool00ol00?l2oooo00Ko003o1Oooo`05o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3
oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`08o`00o`04oooo0?l00?oo
003oo`00o`;oool02?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02Ol00?l0
0oooo`3o003oo`00o`02oooo00Wo003o0_ooo`05o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1W
o`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo
00[o003o00Coool0o`00ooooo`3oool02_l00?l2oooo00Co003o0_ooo`06o`00o`03oooo0?l00?oo
003o00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00
o`;oool02_l00?l01?ooo`3o003ooooo0?ooo`03o`00o`03oooo0?l00?oo003o00Co003o0_ooo`05
o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo
00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00So003o0oooo`03o`00
o`03oooo0?l00?oo003o00Co003o0_ooo`05o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo
0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko
003o1Oooo`09o`00o`;oool01?l00?l2oooo00?o003o0_ooo`07o`00o`;oool00_l00?l2oooo00Go
003o1Oooo`1Wo`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool0
9?l00?l2oooo00Ko003o1?ooo`09o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003o
o`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(440) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.994 .006 .994 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.981 .019 .981 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.993 .007 .993 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.981 .019 .981 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.973 .027 .973 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.961 .039 .961 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.989 .011 .989 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.958 .042 .958 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.994 .006 .994 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.905 .095 .905 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.921 .079 .921 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.845 .155 .845 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.946 .054 .946 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.988 .012 .988 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.99 .01 .99 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.979 .021 .979 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.713 .287 .713 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.957 .043 .957 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.889 .111 .889 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.884 .116 .884 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.909 .091 .909 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.938 .062 .938 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.963 .037 .963 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.861 .139 .861 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.934 .066 .934 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.787 .213 .787 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.959 .041 .959 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.929 .071 .929 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.881 .119 .881 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.93 .07 .93 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.762 .238 .762 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.95 .05 .95 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.88 .12 .88 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.996 .004 .996 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.961 .039 .961 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.806 .194 .806 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.481 .519 .481 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.565 .435 .565 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.985 .015 .985 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.985 .015 .985 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.932 .068 .932 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.838 .162 .838 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.85 .15 .85 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.529 .471 .529 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.512 .488 .512 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.423 .577 .423 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.818 .182 .818 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.841 .159 .841 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.814 .186 .814 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.736 .264 .736 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.973 .027 .973 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.638 .362 .638 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.951 .049 .951 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.902 .098 .902 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.534 .466 .534 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.456 .544 .456 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.751 .249 .751 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.178 .822 .178 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.187 .813 .187 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.254 .746 .254 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.601 .399 .601 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.585 .415 .585 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.947 .053 .947 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.208 .792 .208 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.213 .787 .213 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.847 .153 .847 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.973 .027 .973 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.994 .006 .994 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.365 .635 .365 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.441 .559 .441 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.765 .235 .765 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.993 .007 .993 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.784 .216 .784 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.411 .589 .411 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.708 .292 .708 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.147 .853 .147 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.59 .41 .59 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.414 .586 .414 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.978 .022 .978 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.052 .948 .052 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.12 .88 .12 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.918 .082 .918 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.042 .958 .042 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.029 .971 .029 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.704 .296 .704 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.94 .06 .94 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.244 .756 .244 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.063 .937 .063 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.557 .443 .557 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.126 .874 .126 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.258 .742 .258 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.959 .041 .959 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.012 .988 .012 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.145 .855 .145 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.216 .784 .216 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.863 .137 .863 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.287 .713 .287 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.357 .643 .357 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.002 .998 .002 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.052 .948 .052 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.008 .992 .008 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.002 .998 .002 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.472 .528 .472 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.728 .272 .728 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.845 .155 .845 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.195 .805 .195 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.144 .856 .144 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.541 .459 .541 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.979 .021 .979 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.145 .855 .145 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.153 .847 .153 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.693 .307 .693 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.117 .883 .117 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.021 .979 .021 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.927 .073 .927 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.978 .022 .978 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.712 .288 .712 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.777 .223 .777 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.083 .917 .083 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.927 .073 .927 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.37 .63 .37 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.476 .524 .476 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.079 .921 .079 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.286 .714 .286 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.504 .496 .504 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.957 .043 .957 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.095 .905 .095 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.118 .882 .118 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.035 .965 .035 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.908 .092 .908 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.257 .743 .257 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.975 .025 .975 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.187 .813 .187 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.17 .83 .17 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.182 .818 .182 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.757 .243 .757 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.795 .205 .795 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.703 .297 .703 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.02 .98 .02 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.273 .727 .273 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.425 .575 .425 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.683 .317 .683 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.899 .101 .899 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.994 .006 .994 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.968 .032 .968 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.253 .747 .253 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.508 .492 .508 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.186 .814 .186 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.883 .117 .883 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.829 .171 .829 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.696 .304 .696 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.919 .081 .919 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.973 .027 .973 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.208 .792 .208 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.339 .661 .339 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.961 .039 .961 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.199 .801 .199 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.766 .234 .766 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.558 .442 .558 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.612 .388 .612 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.408 .592 .408 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.935 .065 .935 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.914 .086 .914 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.923 .077 .923 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.942 .058 .942 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.514 .486 .514 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.978 .022 .978 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.87 .13 .87 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.436 .564 .436 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.499 .501 .499 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.994 .006 .994 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.733 .267 .733 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.657 .343 .657 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.993 .007 .993 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.976 .024 .976 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.891 .109 .891 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.972 .028 .972 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.532 .468 .532 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.953 .047 .953 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.853 .147 .853 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.799 .201 .799 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.772 .228 .772 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.67 .33 .67 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.995 .005 .995 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.787 .213 .787 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.99 .01 .99 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.651 .349 .651 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.992 .008 .992 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.751 .249 .751 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.993 .007 .993 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.865 .135 .865 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.926 .074 .926 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.882 .118 .882 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.931 .069 .931 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.951 .049 .951 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.875 .125 .875 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.742 .258 .742 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.862 .138 .862 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.92 .08 .92 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.953 .047 .953 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.94 .06 .94 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.949 .051 .949 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.99 .01 .99 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.893 .107 .893 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.975 .025 .975 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.992 .008 .992 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.98 .02 .98 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.963 .037 .963 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.902 .098 .902 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.975 .025 .975 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.951 .049 .951 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.952 .048 .952 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.966 .034 .966 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.994 .006 .994 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.993 .007 .993 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.993 .007 .993 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.994 .006 .994 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003om`SgooL8mol0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?on0Oh03oon0Oh00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooL8moog2?L00_og2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om`SgooL8m`06ooL8m`03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?on0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooL8moog2?L02?og2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oj1O[o0000013ooP7n00?o0000ooh1o_on0Oh02?on
0Oh9o`0000com`Sg00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?om0_goo@;m00ooo@;m
00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooX5nP03o`000?on
0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om0_doo@;m005oo@;m003o`000?og
2?Oom`Sg00_om`Sg0ol00003ooH9mP03o`000?on0OkooP7n00cooP7n0ol0000>ood2o@;o00003Oom
0_d2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooX5n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00002oon0Oh00ol0003om0_doo@;m006
oo@;m003o`000?og2?Oom`Sg00[om`Sg00?o0000ooH9m_of2OH01?of2OH00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oc3??ol`ccoo<<l`;o00002_om0_d2o`000003oo<<lol0003oo@;m00koo@;m00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?on0Oko
oP7n00WooP7n00?o0000ooX5n_l000002oon0Oh00ol0003om0_doo@;m006oo@;m003o`000?og2?Oo
m`Sg00Wom`Sg00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP08ooh1oP03o`000?oc3??o
l`cc00Col`cc0_l00005ood2o@?o00001?oc3?<00ol0003oo@;mood2o@0=ood2o@03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooX5nP03o`000?on0OkooP7n00OooP7n0_l00003ooX5
nP03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?od2o@01ood2o@00ol0003om`SgooL8m`09ooL8
m`03o`000?of2OKomPWf00OomPWf00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Wol`cc0_l000000oom
0_go0000o`000007oo<<l`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooX5n_oj
1OX02?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on
0Oh01oon0Oh00ol0003om0_doo@;m008oo@;m003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooH9m_of
2OH02Oof2OH00ol0003ooP7nooh1oP03ooh1oP03o`000?oc3??ol`cc00_ol`cc00?o0000oo<<looc
3?<01ooc3?<00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@Kio`000005ooh1oP;o00002ooj1OX2o`0000KooP7n
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?od2oCom0_d00Som0_d
00?o0000ooL8moog2?L01_og2?L00ol0003omPWfooH9mP0;ooH9mP05o`000?on0OkooP7nooh1o_l0
00003_oc3?<00ol0003ol`ccoo<<l`08oo<<l`03o`000?om0_goo@;m00goo@;m00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oi1_Won@KiooT6nOl0
00000oon0Oh00ol0003onPGjooX5nP0:ooX5nP04o`000?o`3o3ol0o`o`0000?ooP7n0_l00008ooX5
nP03o`000?on0OkooP7n00KooP7n00?o0000oo@;m?od2o@02Ood2o@00ol0003om`SgooL8m`05ooL8
m`03o`000?of2OKomPWf00comPWf00?o0000ooh1o_l000003ooc3?<00ol0003ol`ccoo<<l`08oo<<
l`03o`000?om0_goo@;m00koo@;m00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@03ooT6n@03o`000?on0Oko000000_o
nPGj0_l00004oo0?l003o`000?on0Oko000000_onPGj00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m0_doo@;m009oo@;m003o`000?og2?Oom`Sg00Com`Sg00?o0000ooH9m_of2OH03_of2OH00ol0003o
l`ccoo<<l`0>oo<<l`03o`000?oc3??ol`cc00Wol`cc00?o0000ood2oOom0_d03_om0_d00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooT6nOoi1_T0
1?oi1_T00ol0003onPGjooX5nP09ooX5nP03o`000?o`3o3ol0o`00Gol0o`00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003ooP7nooh1oP05ooh1oP03o`000?od2oCom0_d00[om0_d00?o0000ooL8moog2?L0
0oog2?L00ol0003omPWfooH9mP0>ooH9mP03o`000?oc3??ol`cc00gol`cc00?o0000oo<<looc3?<0
2_oc3?<00ol0003oo@;mood2o@0>ood2o@03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6
n@05ooT6n@03o`000?oj1O[onPGj00OonPGj0_l00008oo0?l003o`000?oj1O[onPGj00_onPGj00?o
0000ooh1o_on0Oh01?on0Oh00ol0003om0_doo@;m00:oo@;m004o`000?og2?Oom`SgooL8m`?o0000
3oof2OH00ol0003ol`ccoo<<l`0>oo<<l`03o`000?oc3??ol`cc00[ol`cc00?o0000ood2oOom0_d0
3oom0_d3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooX5n_oj1OX01?oj1OX2o`0000_ol0o`1?l0
0009ooX5nP03o`000?on0OkooP7n00?ooP7n00?o0000oo@;m?od2o@02ood2o@01?l0003om`Sgo`00
0?l00003on8MhP;o00003?of2OH2o`00013ol`cc00?o0000oo<<looc3?<02ooc3?<00ol0003oo@;m
ood2o@0=ood2o@04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003on@Ki
ooT6n@07ooT6n@03o`000?oj1O[onPGj00?onPGj00?o0000oo0?l?o`3o002oo`3o001?l0003of2OH
omPWf?oH9mP5o`0000GonPGj00?o0000ooh1o_on0Oh00_on0Oh00ol0003om0_doo@;m00<oo@;m003
o`000?oR7N;ohQgR00GohQgR0_l00008ooH9mP;o00000_oN8Mh00ol0003ol`ccoo<<l`0=oo<<l`03
o`000?oc3??ol`cc00_ol`cc00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@09ooT6n@03o`000?oj1O[onPGj00;o0000
3Oo`3o000ol0003of2OHomPWf007omPWf0Ko00000_on0Oh4o`0000gom0_d00?o0000on8Mh_oR7N80
1ooR7N82o`0000GomPWf00?o0000omhQg_oN8Mh00ooN8Mh00ol0003ol`ccoo<<l`0<oo<<l`03o`00
0?oc3??ol`cc00col`cc00?o0000ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o
0000ooX5n_l000003oo`3o000ol0003of2OHomPWf00<omPWf0?o00001?o]4^d3o`0000Wom0_d00?o
0000on8Mh_oR7N802_oR7N82o`000003ooH9m_l0003o000000OogR7N00?o0000oo<<looc3?<02ooc
3?<00ol0003ol`ccoo<<l`0<oo<<l`03o`000?om0_goo@;m00Koo@;m1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000
oo0?l?o`3o003_o`3o000ol0003of2OHomPWf00=omPWf003o`000?o]4^gokA;]00KokA;]0ol00005
oo@;m003o`000?oR7N;ohQgR00gohQgR00?o0000omhQg_oN8Mh02?oN8Mh00ol0003ol`ccoo<<l`09
oo<<l`03o`000?oc3??ol`cc00gol`cc00Co0000ood2oOom0_goo@;m1Ol00003ooH9mP03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooT6nOoi1_T02ooi1_T2o`0000ool0o`00?o0000omPWf?oH9mP03OoH9mP00ol0003okA;]ondBk@0:
ondBk@?o000000?om0_do`000?oR7N803ooR7N800ol0003ogR7NomhQgP09omhQgP03o`000?oc3??o
l`cc00Sol`cc00?o0000oo<<looc3?<03_oc3?<3o`0000SomPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oi1_Won@Ki00Son@Ki0ol000000ooV
6NKo0000oo0?l00>oo0?l003o`000?oH9mSof2OH00gof2OH00?o0000ondBkOo]4^d03Oo]4^d00ol0
003ohQgRon8MhP0?on8MhP03o`000?oN8MkogR7N00[ogR7N2ol0000;oo<<l`Go00003?of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003omPWfo`000?on0Oko0000
00Son@Ki0ol00005onHIiP03o`000?o`3o3ol0o`00col0o`00?o0000omPWf?oH9mP03OoH9mP00ol0
003okA;]ondBk@0=ondBk@;o00004?oR7N800ol0003ogR7NomhQgP0:omhQgP03o`000?oJ9M[ofRGJ
00OofRGJ00?o0000oo<<looc3?<00_oc3?<7o`0000CogaoO00?o0000ooH9m_of2OH02_of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003omPWfooH9m_of2OH2o`00
00Gon@Ki0ol00009onHIiP;o00002oo`3o000ol0003of2OHomPWf00=omPWf003o`000?o]4^gokA;]
00gokA;]00Co0000ol/dboo;=<_o00003ooR7N800ol0003ogR7NomhQgP09omhQgP03o`000?oJ9M[o
fRGJ00WofRGJ1?l0000;omlOg`03o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000ooH9m_of2OH01?of2OH00ol0003on@Kio`000002o`00
00coiQWV00Co0000olPgb?l0003o00002Oo`3o000ol0003of2OHomPWf00=omPWf003o`000?o]4^go
kA;]00gokA;]00Go0000ol/dboo;=<_obcC;o`00000=on8MhP03o`000?oN8MkogR7N00[ogR7N00?o
0000omXUf_oJ9MX02OoJ9MX00ol0003ogaoOomlOg`0<omlOg`03o`000?of2OKomPWf00[omPWf00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooH9m_of2OH01_of2OH0
0ol0003oiQWVonHIiP0<onHIiP03o`000?o8=lSob3O800;ob3O80_l00007oo0?l003o`000?oH9mSo
f2OH00cof2OH00?o0000ondBkOo]4^d03Oo]4^d00ol0003obcC;ol/db`03ol/db`03o`000?oR7N;o
hQgR00[ohQgR00?o0000omhQg_oN8Mh02_oN8Mh00ol0003ofRGJomXUfP09omXUfP03o`000?oO7moo
gaoO00cogaoO00?o0000ooH9m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003omPWfooH9mP06ooH9mP03o`000?oV6NKoiQWV00_oiQWV00?o0000olPg
b?o8=lP01Oo8=lP00ol0003ol0o`oo0?l003oo0?l003o`000?oH9mSof2OH00gof2OH00?o0000ondB
kOo]4^d03Oo]4^d00ol0003obcC;ol/db`04ol/db`03o`000?oR7N;ohQgR00WohQgR00?o0000omhQ
g_oN8Mh02OoN8Mh00ol0003ofRGJomXUfP0:omXUfP03o`000?oO7moogaoO00cogaoO00?o0000ooH9
m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
mPWfooH9mP07ooH9mP03o`000?oV6NKoiQWV00_oiQWV00?o0000olPgb?o8=lP01_o8=lP2o`0000?o
l0o`00?o0000omPWf?oH9mP03OoH9mP00ol0003okA;]ondBk@0<ondBk@03o`000?o;=<_obcC;00Ko
bcC;00?o0000on8Mh_oR7N802?oR7N800ol0003ogR7NomhQgP09omhQgP03o`000?oJ9M[ofRGJ00[o
fRGJ00?o0000omlOgooO7ml03?oO7ml00ol0003omPWfooH9mP0;ooH9mP03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000ooH9m_of2OH02?of2OH00ol0003oiQWVonHIiP0:onHIiP03o`00
0?o8=lSob3O800Wob3O80_l000000oo`3o3o0000omPWf00<omPWf0?o00003_o]4^d00ol0003obcC;
ol/db`07ol/db`03o`000?oR7N;ohQgR00OohQgR00?o0000omhQg_oN8Mh02OoN8Mh00ol0003ofRGJ
omXUfP0;omXUfP03o`000?oO7moogaoO00cogaoO00?o0000ooH9m_of2OH02_of2OH00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oiQWVonHI
iP09onHIiP03o`000?o8=lSob3O800_ob3O800?o0000omPWf?oH9mP02_oH9mP2o`0000?o/Dja00?o
0000ondBkOo]4^d02_o]4^d00ol0003obcC;ol/db`09ol/db`03o`000?oR7N;ohQgR00KohQgR00?o
0000omhQg_oN8Mh02?oN8Mh00ol0003ofRGJomXUfP0<omXUfP03o`000?oO7moogaoO00cogaoO00?o
0000ooH9m_of2OH02_of2OH00ol0003ooP7nooh1oP04ooh1oPCo00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onHIi_oV6NH02?oV6NH0
0ol0003ob3O8olPgb00<olPgb003o`000?oH9mSof2OH00Sof2OH0_l00006ok5>/@;o00002_o]4^d0
0ol0003obcC;ol/db`0:ol/db`03o`000?oR7N;ohQgR00GohQgR00?o0000omhQg_oN8Mh02?oN8Mh0
0ol0003ofRGJomXUfP0<omXUfP03o`000?oO7moogaoO00cogaoO00?o0000ooH9m_of2OH02oof2OH0
0ol0003ooP7no`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
ooH9mP03o`000?oV6NKoiQWV00OoiQWV00?o0000olPgb?o8=lP03_o8=lP00ol0003of2OHomPWf004
omPWf0?o00002_naC[400ol0003okA;]ondBk@07ondBk@03o`000?o;=<_obcC;00_obcC;00?o0000
on8Mh_oR7N800ooR7N800ol0003ogR7NomhQgP09omhQgP03o`000?oJ9M[ofRGJ00cofRGJ00?o0000
omlOgooO7ml03?oO7ml00ol0003omPWfooH9mP0;ooH9mP;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003omPWfooH9mP0<ooH9mP03o`000?oV6NKoiQWV00OoiQWV00?o0000olPgb?o8=lP03oo8=lP01?l0
003of2OHomPWf?oH9mP2o`0000ko/Dja0_l00006ondBk@03o`000?o;=<_obcC;00gobcC;00?o0000
on8Mh_oR7N800_oR7N800ol0003ogR7NomhQgP08omhQgP03o`000?oJ9M[ofRGJ00cofRGJ0ol0000=
omlOg`03o`000?of2OKomPWf00_omPWf00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oomPWf00?o0000onHIi_oV6NH01_oV6NH00ol0003ob3O8olPgb00@olPgb0Co00004_naC[400ol0
003okA;]ondBk@03ondBk@03o`000?o;=<_obcC;00kobcC;00Go0000on8Mh_oR7N;ohQgRo`000005
omhQgPOo00003?oJ9MX01Ol0003o`3o0ol0o`?o0?l3o000000cogaoO00?o0000ooH9m_of2OH02?of
2OH3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oomPWf00?o0000onHIi_oV6NH01_oV6NH00ol0003ob3O8olPgb00=
olPgb0?o000000CoUfRGo`000?l0003o00004onaC[42o`0000;okA;]00?o0000ol/dboo;=</04?o;
=</00ol0003ohQgRo`000006o`0000Oo^dBk00?o0000omXUf_oJ9MX02?oJ9MX00ol0003o`3o0ol0o
`003ol0o`0;o00002?oO7ml3o`0000KomPWf1?l00002oo<<l`03o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003onPGjo`000?oQ7^43o`0000gomPWf00?o0000onHIi_oV6NH01?oV6NH00ol0003ob3O8olPg
b00;olPgb0?o00000onGJ9L01Ol0003oSW6>o`000?mKY5_o000001Co/Dja00?o0000ondBkOl00000
4oo;=</00ol0003o^dBkok]4^`0=ok]4^`03o`000?oJ9M[ofRGJ00GofRGJ0_l00008ol0o`003o`00
0?oO7moogaoO00Go00000ooL8m`00ol0003omPWfooH9mP03o`0000Ool`cc00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oj1O[onPGjo`0000CohAkQ0ol0000:ooH9mP03o`000?oV6NKoiQWV00?oiQWV
00?o0000olPgb?o8=lP02Oo8=lP3o`0000GoUfRG00Co0000ohiaS_n>LHko00000_mKY5/00ol0003o
/Djaok5>/@0Bok5>/@03o`000?o;=<_obcC;01;obcC;00?o0000ok]4^onkA;/03_nkA;/00ol0003o
fRGJomXUfP03omXUfP03o`000?o0?l3o`3o000Wo`3o00_l00009om`Sg0;o00002_oc3?<00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooX5n_oj1O[onPGjo`000007on4Nh@;o00001oof2OH5o`0000;o
iQWV00?o0000olPgb?o8=lP01_o8=lP3o`0000SoUfRG00Co0000ohiaS_n>LHko00000omKY5/00ol0
003o/Djaok5>/@0Aok5>/@03o`000?o;=<_obcC;017obcC;00?o0000ok]4^onkA;/04?nkA;/01Ol0
003ofRGJomXUf_oJ9M[o000000co`3o000?o0000om`Sg?oL8m`02?oL8m`00ol0003ol`ccoo<<l`0:
oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000ConPGj00?o0000on4NhOoQ7^401ooQ7^43o`00
0004ooH9m_l0003o0000o`0000God2o@0_l00006olPgb0?o00002_nGJ9L01Ol0003oSW6>ohiaS_n>
LHko000000CoFjAK00?o0000ok5>/OnaC[404?naC[400ol0003obcC;ol/db`0Aol/db`03o`000?nk
A;_o^dBk017o^dBk00?o0000omXUf_l000003Oo0?l000ol0003og2?Lom`Sg008om`Sg003o`000?oc
3??ol`cc00[ol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000
on4NhOoQ7^402_oQ7^400ol0003od2o@om0_d008om0_d003o`000?o8=lSob3O800?o00003OnGJ9L0
1Ol0003oSW6>ohiaS_n>LHko000000GoFjAK00?o0000ok5>/OnaC[403onaC[400ol0003obcC;ol/d
b`0Aol/db`03o`000?nkA;_o^dBk01;o^dBk00?o0000ol0o`?o0?l003?o0?l000ol0003og2?Lom`S
g008om`Sg003o`000?oc3??ol`cc00_ol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX0
0ol0003ohAkQon4Nh@0:on4Nh@03o`000?o@;m3od2o@00Wod2o@0_l0000?oiMXU`03o`000?n>LHko
SW6>00;oSW6>00?o0000oe^TFomKY5/01?mKY5/00ol0003o/Djaok5>/@0=ok5>/@?o00004Oo;=</0
0ol0003o^dBkok]4^`0Cok]4^`03o`000?o0?l3o`3o000_o`3o000?o0000om`Sg?oL8m`02OoL8m`0
0ol0003ol`ccoo<<l`0;oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ooh1oP;o00002?oj1OX0
0ol0003ohAkQon4Nh@0:on4Nh@03o`000?o@;m3od2o@00Wod2o@00?o0000oiMXUonGJ9L03OnGJ9L0
0ol0003oSW6>ohiaSP03ohiaSP03o`000?mKY5_oFjAK00GoFjAK00?o0000ok5>/OnaC[402_naC[42
o`0000?oNHIi00?o0000ol/dboo;=</03_o;=</00ol0003o^dBkok]4^`0Cok]4^`03o`000?o0?l3o
`3o000_o`3o000?o0000om`Sg?oL8m`02OoL8m`00ol0003ol`ccoo<<l`0;oo<<l`03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000GooP7n00?o0000ooX5n_oj1OX01ooj1OX2o`0000_ohAkQ00?o0000om0_
d?o@;m002oo@;m000ol0003oUfRGoiMXU`0<oiMXU`03o`000?n>LHkoSW6>00?oSW6>00?o0000oe^T
FomKY5/01_mKY5/00ol0003o/Djaok5>/@07ok5>/@;o00001_miQWT2o`0000kobcC;00?o0000ok]4
^onkA;/04onkA;/00ol0003o`3o0ol0o`00;ol0o`003o`000?oL8mcog2?L00Wog2?L00?o0000oo<<
looc3?<03?oc3?<00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ooh1o_on0OkooP7no`000009ooX5
nP03o`000?od2oCo000000_ohAkQ00?o0000om0_d?o@;m002oo@;m000ol0003oUfRGoiMXU`0;oiMX
U`03o`000?n>LHkoSW6>00CoSW6>00?o0000oe^TFomKY5/01omKY5/00ol0003o/Djaok5>/@05ok5>
/@03o`000?miQWWoNHIi00SoNHIi00?o0000ol/dboo;=</02_o;=</00ol0003o^dBkok]4^`0Dok]4
^`03o`000?o0?l3o`3o000_o`3o000?o0000om`Sg?oL8m`02OoL8m`00ol0003ol`ccoo<<l`0<oo<<
l`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7no`000009ooX5nP04o`000?od2oCom0_do`00
00_ohAkQ00?o0000om0_d?o@;m002oo@;m000ol0003oUfRGoiMXU`0;oiMXU`03o`000?n>LHkoSW6>
00CoSW6>00?o0000oe^TFomKY5/02?mKY5/00ol0003o/Djaok5>/@02ok5>/@;o00003?miQWT2o`00
00[obcC;00?o0000ok]4^onkA;/05?nkA;/00ol0003o`3o0ol0o`00;ol0o`003o`000?oL8mcog2?L
00Wog2?L00?o0000oo<<looc3?<03Ooc3?<00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5nP03
o`000?od2oCom0_d00;om0_d00?o0000on4NhOoQ7^402?oQ7^400ol0003od2o@om0_d00<om0_d003
o`000?nGJ9OoUfRG00WoUfRG00?o0000ohiaS_n>LHh01On>LHh00ol0003oFjAKoe^TF`09oe^TF`04
o`000?naC[7o0000o`00013oNHIi0_l00008ol/db`03o`000?nkA;_o^dBk01Co^dBk0ol0000;ol0o
`003o`000?oL8mcog2?L00Wog2?L00?o0000oo<<looc3?<03Ooc3?<01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?od2oCom0_d00?om0_d00?o0000on4N
hOoQ7^402?oQ7^400ol0003od2o@om0_d00;om0_d0;o00002_nGJ9L00ol0003oSW6>ohiaSP06ohia
SP03o`000?mKY5_oFjAK00[oFjAK00?o0000ogV6NOmiQWT04_miQWT00ol0003obcC;ol/db`04ol/d
b`03o`000?nkA;_o^dBk01Go^dBk00?o0000ojIIY_nVFJH01Ol00005ol0o`003o`000?oL8mcog2?L
00[og2?L00?o0000oo<<looc3?<03_oc3?<3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP04ooX5nP03
o`000?od2oCom0_d00Com0_d00?o0000on4NhOoQ7^401ooQ7^400ol0003od2o@om0_d00;om0_d004
o`000?n8MhSoR7N8o`0000WoUfRG00?o0000ohiaS_n>LHh01_n>LHh00ol0003oFjAKoe^TF`0:oe^T
F`03o`000?miQWWoNHIi01?oNHIi0_l00003ol/db`Co00005?nkA;/00ol0003oYUVVojIIYP06ojII
YPCo000000?o`3o0o`000?oL8m`02ooL8m`00ol0003ol`ccoo<<l`0>oo<<l`03o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003onPGjooX5nP03ooX5nP03o`000?od2oCom0_d00Gom0_d00?o0000on4NhOoQ
7^401ooQ7^400ol0003od2o@om0_d009om0_d0;o00001?n8MhP00ol0003oUfRGoiMXU`05oiMXU`03
o`000?n>LHkoSW6>00OoSW6>00?o0000oe^TFomKY5/02_mKY5/00ol0003oNHIiogV6N@0EogV6N@03
o`000?o;=<_o000000CoSW6>0ol0000@ok]4^`03o`000?nVFJKoYUVV00_oYUVV0_l0000<om`Sg003
o`000?oc3??ol`cc00col`cc0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003om0_d
oo@;m006oo@;m003o`000?oQ7^7ohAkQ00OohAkQ00?o0000om0_d?o@;m002?o@;m000ol0003oR7N8
ohQgR005ohQgR003o`000?nGJ9OoUfRG00CoUfRG00?o0000ohiaS_n>LHh01on>LHh00ol0003oFjAK
oe^TF`0:oe^TF`03o`000?miQWWoNHIi01KoNHIi00?o0000ohiaS_n>LHh01_n>LHh3o`0000co^dBk
00?o0000ojIIY_nVFJH03OnVFJH00ol0003og2?Lom`Sg009om`Sg0Go00002Ooc3?<2o`000003ooL8
mol0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ooX5n_l0003om0_d00Wom0_d00?o0000on4NhOoQ7^401_oQ
7^400ol0003od2o@om0_d007om0_d003o`000?n8MhSoR7N800OoR7N800?o0000oiMXUonGJ9L00_nG
J9L00ol0003oSW6>ohiaSP08ohiaSP03o`000?mKY5_oFjAK00WoFjAK00?o0000ogV6NOmiQWT05omi
QWT00ol0003oSW6>ohiaSP09ohiaSP?o00002OnkA;/00ol0003oYUVVojIIYP0>ojIIYPKo00001?oL
8m`00ol0003oiQWVonHIiP03onHIiPGo00000_oc3?<2o`0000Com`Sg00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oe2_Gom@[eooD:mOl000002ood2o@00ol0003ohAkQon4Nh@06on4Nh@03o`000?o@
;m3od2o@00God2o@0_l0000;ohQgR004o`000?nGJ9OoUfRGo`0000_oSW6>00?o0000oe^TFomKY5/0
2OmKY5/00ol0003oNHIiogV6N@0FogV6N@03o`000?n>LHkoSW6>00goSW6>0ol00005ok]4^`03o`00
0?nVFJKoYUVV00ooYUVV00?o0000oke2_Onm@[d00onm@[d4o`0000_oiQWV0_l00006ooL8m`03o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:m@02ooD:m@ko00001_oQ7^400ol0003od2o@om0_
d005om0_d003o`000?n8MhSoR7N800coR7N800?o0000oiMXUol000002on>LHh00ol0003oFjAKoe^T
F`07oe^TF`?o00006?miQWT00ol0003oSW6>ohiaSP0@ohiaSP?o000000?o^dBko`000?nVFJH04?nV
FJH00ol0003o_D:moke2_@07oke2_@03o`000?oV6NKoiQWV00[oiQWV00?o0000ooL8moog2?L01Oog
2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005ooD:m@03o`000?oS7>?ohacS00_ohacS0_l00004
on4Nh@03o`000?o@;m3od2o@00?od2o@0_l0000@ohQgR003o`000?n>LHkoSW6>00[oSW6>00?o0000
oe^TFomKY5/00omKY5/4o`0000;o<Lha00?o0000ogV6NOmiQWT05OmiQWT00ol0003oSW6>ohiaSP0D
ohiaSP03o`000?nVFJKoYUVV013oYUVV00?o0000oke2_Onm@[d01onm@[d00ol0003oiQWVonHIiP0:
onHIiP03o`000?og2?Oom`Sg00Gom`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oe2_Gom@[e
00Gom@[e00?o0000on<LhooS7><03OoS7><6o`0000?od2o@00?o0000ohQgR?n8MhP04?n8MhP00ol0
003oSW6>ohiaSP0:ohiaSP03o`000?mKY5_o000000?o00001olacS400ol0003oNHIiogV6N@0DogV6
N@03o`000?n>LHkoSW6>01CoSW6>00?o0000ojIIY_nVFJH03onVFJH00ol0003o_D:moke2_@08oke2
_@03o`000?oV6NKoiQWV00[oiQWV00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooD:mOoe2_D01_oe2_D00ol0003ohacSon<Lh`0=on<Lh`03o`000?o3?<?o`cc300?o
`cc300?o0000om0_d?l000004on8MhP4o`0000WoSW6>0_l0000<oc7><@03o`000?miQWWoNHIi01?o
NHIi00?o0000ohiaS_n>LHh05On>LHh00ol0003oYUVVojIIYP0>ojIIYP03o`000?nm@[go_D:m00So
_D:m00?o0000onHIi_oV6NH02OoV6NH00ol0003om`SgooL8m`07ooL8m`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oe2_Gom@[e00Som@[e00?o0000on<LhooS7><02ooS7><00ol0003o`cc3ol<l``05ol<l``03o`00
0?n8MhSoR7N801;oR7N800Co0000ock1?_ln`Cko?/4n1Ol00003ohiaSP03o`000?lacS7o<Lha00go
<Lha0ol0000@ogV6N@;o00006?n>LHh00ol0003oYUVVojIIYP0=ojIIYP03o`000?nm@[go_D:m00Wo
_D:m00?o0000onHIi_oV6NH02OoV6NH00ol0003om`SgooL8m`07ooL8m`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_om@[e00?o0000on<LhooS7><02_oS7><00ol0003o`cc3ol<l``06ol<l``03o`00
0?n8MhSoR7N8017oR7N800?o0000ock1?_ln`Ch01oln`Ch3o`00013o<Lha00?o0000oaGZ5OlEjQD0
1Ol00009ogV6N@;o000000?o;m0_o`000?n>LHh05on>LHh00ol0003oYUVVojIIYP0=ojIIYP03o`00
0?nm@[go_D:m00Wo_D:m00?o0000onHIi_oV6NH02?oV6NH2o`0000[om`Sg00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?ok1?_on`Ck00;on`Ck00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ohacSon<L
h`0:on<Lh`03o`000?o3?<?o`cc300Oo`cc300?o0000ohQgR?n8MhP03on8MhP00ol0003o?/4nock1
?P0:ock1?P03o`000?lacS7o<Lha00go<Lha00?o0000oaGZ5OlEjQD01_lEjQD4o`0000CoNHIi00?o
0000obo@;ol_d2l00_l_d2l00ol0003oSW6>ohiaSP0FohiaSP03o`000?nVFJKoYUVV00_oYUVV00?o
0000oke2_Onm@[d02onm@[d00ol0003oiQWVonHIiP06onHIiP03o`000?oc3??o000000[om`Sg00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooD:mOoe2_D02?oe2_D=
o`0000[o`cc300?o0000ohQgR?n8MhP03on8MhP00ol0003o?/4nock1?P0;ock1?P03o`000?lacS7o
<Lha00co<Lha00?o0000oaGZ5OlEjQD02_lEjQD4o`0000Go;m0_00?o0000ohiaS_n>LHh05_n>LHh0
0ol0003oYUVVojIIYP0:ojIIYP03o`000?nm@[go_D:m00co_D:m00?o0000onHIi_oV6NH01?oV6NH2
o`0000?ol`cc00?o0000ooL8moog2?L02?og2?L00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4
nook1?/00ook1?/00ol0003om@[eooD:m@07ooD:m@03o`000?oR7N;ohQgR00WohQgR00?o0000ol<l
`oo3?<<02Oo3?<<00ol0003oR7N8ohQgR00=ohQgR003o`000?ln`Cko?/4n00co?/4n00?o0000oc7>
<OlacS403?lacS400ol0003o5NXEoaGZ5@0;oaGZ5@03o`000?l8m`So000000Ko;m0_00?o0000ohia
S_n>LHh05_n>LHh00ol0003oYUVVojIIYP09ojIIYP03o`000?nm@[go_D:m00co_D:m00?o0000onHI
i_oV6NH00ooV6NH00ol0003ol`ccoo<<l`03oo<<l`03o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Con`Ck00?o0000ooD:mOoe2_D01_oe2_D00ol0003o
hQgRon8MhP08on8MhP03o`000?o3?<?o`cc300_o`cc300?o0000ohQgR?n8MhP02?n8MhP4o`0000oo
?/4n00?o0000oc7><OlacS402olacS400ol0003o5NXEoaGZ5@0;oaGZ5@04o`000?l8m`So2?L8o`00
00Oo;m0_00?o0000ohiaS_n>LHh05On>LHh00ol0003oYUVVojIIYP08ojIIYP03o`000?nm@[go_D:m
00go_D:m00?o0000onHIi_oV6NH00_oV6NH00ol0003ol`ccoo<<l`05oo<<l`03o`000?og2?Oom`Sg
00Oom`Sg00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooD:mOoe
2_D01Ooe2_D00ol0003ohQgRon8MhP08on8MhP03o`000?o3?<?o`cc300_o`cc300?o0000ohQgR?n8
MhP00on8MhP5o`0000?o@Ki100?o0000ock1?_ln`Ch03_ln`Ch00ol0003o<Lhaoc7><@0:oc7><@03
o`000?lEjQGo5NXE00[o5NXE00Go0000o`Sg2?l8m`So2?L8o`000007obo@;`03o`000?n>LHkoSW6>
01GoSW6>00?o0000ojIIY_nVFJH02?nVFJH00ol0003o_D:moke2_@0=oke2_@03o`000?oV6NKoiQWV
00;o00002?oc3?<00ol0003om`SgooL8m`08ooL8m`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?oe2_Gom@[e00Go
m@[e00?o0000on8Mh_oR7N802?oR7N800ol0003o`cc3ol<l``0<ol<l``Go00002Om1_T400ol0003o
?/4nock1?P0<ock1?P;o00003?lacS400ol0003o5NXEoaGZ5@0:oaGZ5@05o`000?l8m`So2?L8o`Sg
2?l000002?l_d2l00ol0003oSW6>ohiaSP0DohiaSP?o00001onVFJH00ol0003o_D:moke2_@0>oke2
_@03o`000?oV6NKo000000_ol`cc00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000oo/4nook1?/01Ook1?/00ol0003om@[eooD:m@04ooD:m@03o`000?oR7N;ohQgR00Oo
hQgR00?o0000ol<l`oo3?<<03?o3?<<01?l0003oQgR7ohMhQol0000;od6n@@03o`000?ln`Cko?/4n
00_o?/4n00Co0000o`?l0ol3o0?o00002_lacS400ol0003o5NXEoaGZ5@0:oaGZ5@03o`000?l8m`So
2?L800;o2?L800?o0000obo@;ol_d2l01_l_d2l00ol0003oSW6>ohiaSP0AohiaSP?o00000om_T6l0
0ol0003oYUVVojIIYP04ojIIYP03o`000?nm@[go_D:m00go_D:m1?l0000;oo<<l`03o`000?og2?Oo
m`Sg00Gom`Sg00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00Co0000ooD:
mOoe2_Gom@[e1?l00008on8MhP03o`000?o3?<?o`cc300_o`cc300?o0000ohMhQon7N8L00_n7N8L0
0ol0003o@Ki1od6n@@08od6n@@03o`000?ln`Cko?/4n00[o?/4n00?o0000o`?l0ol3o0<00_l3o0<0
0ol0003o<Lhaoc7><@03oc7><@Go00002olEjQD00ol0003o2?L8o`Sg2003o`Sg2003o`000?l_d2oo
;m0_00Oo;m0_00?o0000ohiaS_n>LHh03_n>LHh2o`0000OoKi1_00?o0000ojIIY_nVFJH00_nVFJH0
0ol0003o_D:moke2_@0=oke2_@03o`000?oT6nCoi1_T00;oi1_T00?o0000oo<<looc3?<02Ooc3?<0
0ol0003om`SgooL8m`03ooL8m`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`07oo/4
n`?o00001?oW6>L00ol0003ohQgRon8MhP05on8MhP03o`000?o3?<?o`cc300[o`cc300?o0000ohMh
Qon7N8L00on7N8L00ol0003o@Ki1od6n@@09od6n@@03o`000?ln`Cko?/4n00So?/4n00?o0000o`?l
0ol3o0<01?l3o0<5o`0000Co0?l000?o0000oaGZ5OlEjQD02OlEjQD00ol0003o2?L8o`Sg2003o`Sg
2003o`000?l_d2oo;m0_00So;m0_00?o0000ohiaS_n>LHh02_n>LHh3o`0000[oKi1_00Go0000ojII
Y_nVFJKoYUVVo`00000>oke2_@03o`000?oT6nCoi1_T00Coi1_T0_l00009oo<<l`03o`000?og2?Oo
m`Sg00;om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000onLH
iooW6>L01OoW6>L00ol0003ohQgRon8MhP03on8MhP03o`000?o3?<?o`cc300[o`cc300?o0000ohMh
Qon7N8L01?n7N8L00ol0003o@Ki1od6n@@09od6n@@03o`000?ln`Cko?/4n00Oo?/4n00?o0000o`?l
0ol3o0<01Ol3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lEjQGo5NXE00Oo5NXE00?o0000o`Sg
2?l8m`P01?l8m`P00ol0003o;m0_obo@;`08obo@;`03o`000?n>LHkoSW6>00SoSW6>0_l0000>ofn@
K`Co00003?nm@[d2o`0000Woi1_T00?o0000oo<<looc3?<01ooc3?<01?l0003om`SgooL8mol0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oiaSWonLHi`07onLHi`;o00000ooR7N800ol0
003o`cc3ol<l``09ol<l``03o`000?n7N8OoQgR700KoQgR700?o0000od6n@Om1_T402Om1_T400ol0
003o?/4nock1?P05ock1?P03o`000?l3o0?o0o`300Ko0o`300?o0000o`3o0?l0o`002?l0o`000ol0
003o5NXEoaGZ5@06oaGZ5@03o`000?l8m`So2?L800Co2?L800?o0000obo@;ol_d2l02Ol_d2l4o`00
00?oSW6>0ol0000@ofn@K`05o`000?o9=/WobCK9olTfbOl000002_nm@[d00ol0003oi1_Ton@Ki00:
on@Ki0Ko00000ooc3?<00ol0003om`Sgo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/01?ok1?/00ol0
003oiaSWonLHi`0:onLHi`04o`000?oR7N;ohQgRo`0000[o`cc300?o0000ohMhQon7N8L01on7N8L0
0ol0003o@Ki1od6n@@09od6n@@03o`000?ln`Cko?/4n00Co?/4n00?o0000o`?l0ol3o0<01ol3o0<0
0ol0003o0?l0o`3o0008o`3o00;o00001_lEjQD00ol0003o2?L8o`Sg2005o`Sg2003o`000?l_d2oo
;m0_00Wo;m0_00Co0000oc;=<_lbcC;o</db0ol0000Bofn@K`03o`000?o9=/WobCK900?obCK90_l0
0006oke2_@;o00003OoT6n@00ol0003on@KiooT6n@03ooT6n@Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003oiaSWonLHi`0<onLHi`;o00002_o3?<<00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?m1_T7o
@Ki100[o@Ki100?o0000ock1?_ln`Ch00_ln`Ch00ol0003o0o`3o`?l0`08o`?l0`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lEjQGo5NXE00;o5NXE00?o0000o`Sg2?l8m`P01_l8m`P0
0ol0003o;m0_obo@;`08obo@;`03o`000?lbcC;o</db00Co</db00?o0000ofn@Kom_T6l03om_T6l0
0ol0003obCK9olTfb@06olTfb@;o00000onm@[d00ol0003oi1_Ton@Ki00=on@Ki003o`000?oi1_Wo
n@Ki00Oon@Ki0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?oW6>OoiaSW
00koiaSW00?o0000ol<l`oo3?<<01oo3?<<00ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?m1_T7o@Ki1
00Wo@Ki100Go0000ock1?_ln`Cko?/4no`00000;o`?l0`03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lEjQGo5NXEoaGZ5Ol000002?l8m`P00ol0003o;m0_obo@;`08obo@;`03o`000?lb
cC;o</db00Go</db00?o0000ofn@Kom_T6l03_m_T6l00ol0003obCK9olTfb@08olTfb@03o`000?nm
@[go000000ooi1_T00?o0000ooT6nOoi1_T02?oi1_T01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?ok1?_on`Cko`00017oiaSW00?o0000ol<l`oo3?<<01_o3?<<00ol0003oQgR7
ohMhQ`0;ohMhQ`03o`000?m1_T7o@Ki100Wo@Ki100Co0000ock1?_ln`Cko00003?l3o0<00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5NXEo`000009o`Sg2003o`000?l_d2oo;m0_00So
;m0_00?o0000oc;=<_lbcC801OlbcC800ol0003oKi1_ofn@K`0=ofn@K`03o`000?o9=/WobCK900[o
bCK900?o0000on@Ki?oT6n@03_oT6n@00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BonLHi`03o`00
0?o3?<?o`cc300Co`cc300?o0000ohMhQon7N8L03?n7N8L00ol0003o@Ki1od6n@@0:od6n@@?o0000
3?l3o0<00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Sg2?l8m`P02?l8m`P00ol0003o;m0_
obo@;`07obo@;`03o`000?lbcC;o</db00Oo</db00?o0000ofn@Kom_T6l03?m_T6l00ol0003obCK9
olTfb@0;olTfb@;o00003_oT6n@00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003oiaSWonLHi`0?onLHi`?o00000oo3
?<<00ol0003oQgR7ohMhQ`0>ohMhQ`03o`000?m1_T7o@Ki100So@Ki100Co0000o`[e2_l:m@[o2_D:
0_l0000:o`?l0`?o00003Ol0o`000ol0003o2?L8o`Sg2008o`Sg2003o`000?l_d2oo;m0_00Oo;m0_
00?o0000oc;=<_lbcC801olbcC800ol0003oKi1_ofn@K`0;ofn@K`03o`000?o9=/WobCK900cobCK9
00?o0000oo8=l_l000000_l0000:on@Ki003o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@04ooT6n@03o`000?oW6>OoiaSW00coiaSW0_l0
0003omPWf003o`000?o3?<?o0000017oQgR700?o0000od6n@Om1_T401om1_T400ol0003o2_D:o`[e
2P04o`[e2P;o00002?l3o0<00ol0003o0?l0o`3o000>o`3o00;o00002?l8m`P00ol0003o;m0_obo@
;`06obo@;`03o`000?lbcC;o</db00Wo</db00?o0000ofn@Kom_T6l02Om_T6l00ol0003obCK9olTf
b@0=olTfb@03o`000?ob3O;olPgb00;olPgb0ol00007on@Ki003o`000?oi1_Won@Ki00Oon@Ki00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oW6>Oo
iaSW00WoiaSW0_l00006omPWf003o`000?n7N8OoQgR7013oQgR700?o0000od6n@Om1_T401_m1_T40
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l3o0?o0o`300Co0o`30ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol8m`P00ol0003o;m0_obo@;`06obo@;`03o`000?lbcC;o</db00[o</db00?o0000
ofn@Kom_T6l02?m_T6l00ol0003obCK9olTfb@0=olTfb@03o`000?ob3O;olPgb00GolPgb0ol00004
on@Ki003o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on@KiooT6n@06ooT6n@03o`000?oW6>OoiaSW00GoiaSW0ol00008omPWf003o`000?n7N8OoQgR7
017oQgR700Co0000od6n@Om1_T7o@Ki11?l0000;o`[e2P;o000000Co0o`3o`000?l0003o00000ol0
o`02o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2?L800?o0000obo@;ol_d2l01_l_
d2l00ol0003o</dboc;=<P0:oc;=<P03o`000?m_T6ooKi1_00OoKi1_00?o0000olTfbOo9=/T03_o9
=/T00ol0003olPgboo8=lP08oo8=lPCo00002_oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on@KiooT6n@07ooT6n@03o`000?oW6>OoiaSW00;oiaSW0_l0000<omPWf003o`000?n7N8Oo
QgR7013oQgR71?l00003ocG:=@03o`000?l:m@[o2_D:00_o2_D:00?o0000o`3o0?l0o`001_l0o`00
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>oc;=<P03o`000?m_T6oo
Ki1_00KoKi1_00?o0000olTfbOo9=/T03_o9=/T00ol0003olPgboo8=lP0;oo8=lP03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00Won@Ki00Co0000onLH
iol0003o00003_oH9mP00ol0003oQgR7ohMhQ`0?ohMhQ`03o`000?lebSGo=LXe00Ko=LXe00?o0000
o`[e2_l:m@X02_l:m@X00ol0003o0?l0o`3o0007o`3o00;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l[e2_o:m@[00So:m@[00?o0000oc;=<_lbcC803?lbcC800ol0003oKi1_ofn@K`05
ofn@K`03o`000?o9=/WobCK900oobCK90_l0000=oo8=lP03o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00[on@Ki00?o0000omPWf?oH9mP03_oH9mP00ol0
003oQgR7ohMhQ`0>ohMhQ`03o`000?lebSGo=LXe00Oo=LXe00?o0000o`[e2_l:m@X02_l:m@X00ol0
003o0?l0o`3o0009o`3o00;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l[e2_o:m@[
00Wo:m@[00?o0000oc;=<_lbcC802_lbcC84o`0000CoKi1_00?o0000olTfbOo9=/T04?o9=/T01?l0
003ol0o`o`000?l0000<oo8=lP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oi1_Won@Ki00[on@Ki00?o0000omPWf?oH9mP03ooH9mP@o`0000[o=LXe00?o0000o`[e
2_l:m@X02Ol:m@X00ol0003o0?l0o`00000<o`3o0005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o:m@[ob_D:`09ob_D:`03o`000?lbcC;o</db00Oo</db0ol00004ofRGJ0?o000000?oKi1_
o`000?o9=/T04Oo9=/T01?l0003ol0o`oo0?l?o`3o02o`0000_olPgb00?o0000ooT6nOoi1_T00ooi
1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003of2OHomPWf00?
omPWf003o`000?n3O8?oPgb300coPgb300?o0000ocG:=OlebSD02OlebSD00ol0003o2_D:o`[e2P07
o`[e2P04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l[e2_o:m@[00[o:m@[00?o0000oc;=<_lbcC800olbcC83o`0000[oJ9MX00?o0000olTfbOo9=/T0
4?o9=/T00ol0003ol0o`oo0?l004oo0?l0;o00002_ob3O800ol0003on@KiooT6n@04o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con@Ki00?o0000omPWf?oH9mP03ooH9mP00ol0003oPgb3oh=lP`0<oh=lP`03o`000?le
bSGo=LXe00Wo=LXe00?o0000o`[e2_l:m@X01_l:m@X00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l[
e2_o:m@[00[o:m@[00?o0000oc;=<_lbcC800ol0000=ofRGJ003o`000?o9=/WobCK9013obCK900?o
0000oo0?l?o`3o001_o`3o02o`0000WolPgb0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003of2OHomPWf00=omPWf0?o00003on3O8<0
0ol0003o=LXeocG:=@08ocG:=@03o`000?l:m@[o2_D:00Go2_D:00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o:m@[ob_D:`0;ob_D:`;o00004OmXUfP00ol0003obCK9olTfb@0?olTfb@03o`000?o`3o3o
l0o`00Sol0o`0_l00007oo8=lP03o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooT6nOoi1_T02?oi1_T00ol0003of2OHomPWf009omPWf0Go00000_nfBKH00ol0
003oPgb3oh=lP`0=oh=lP`03o`000?lebSGo=LXe00Wo=LXe00?o0000o`[e2_l:m@X01?l:m@X00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l[e2_o:m@[00_o:m@[00?o0000ofRGJ?mXUfP04?mXUfP00ol0
003obCK9olTfb@0?olTfb@03o`000?o`3o3ol0o`00[ol0o`0_l00004oo8=lP03o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on@KiooT6n@07ooT6n@03o`000?oH9mSof2OH00Cof2OH1Ol00007okI9]P03
o`000?n3O8?oPgb300goPgb300?o0000ocG:=OlebSD02OlebSD00ol0003o2_D:o`[e2P03o`[e2P03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ob_D:ol[e2/02ol[e2/00ol0003oJ9MXofRGJ00@ofRGJ003
o`000?o9=/WobCK900oobCK900?o0000oo0?l?o`3o003?o`3o02o`000003oo8=l_l0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000omPWf?l00000
1?l0000<okI9]P03o`000?n3O8?oPgb300koPgb300?o0000ocG:=OlebSD02?lebSD00ol0003o2_D:
o`[e2P02o`[e2P03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ob_D:ol[e2/02ol[e2/00ol0003oJ9MX
ofRGJ00AofRGJ003o`000?o9=/WobCK900gobCK900?o0000oo0?l?o`3o003oo`3o000ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooT6nOoi1_T01Ooi1_T3o`00017o]TVf00?o0000oh=lPon3O8<03_n3
O8<00ol0003o=LXeocG:=@09ocG:=@04o`000?l:m@[o2_D:o`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol[e2/00ol0003o
J9MXofRGJ00AofRGJ0?o00003Oo9=/T00ol0003ol0o`oo0?l00?oo0?l003o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oi1_T2o`0000;ojaC[00?o0000okI9]_nfBKH03onfBKH00ol0003o
Pgb3oh=lP`0>oh=lP`03o`000?lebSGo=LXe00So=LXe1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ob_D:`03o`000?mXUfSoJ9MX
017oJ9MX00?o0000ohQgR?n8MhP00ol0000:olTfb@Co00003Oo`3o000ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000oo/4nook1?_on`Ck0_l00005on/Dj`03o`000?nfBKKo]TVf00ko]TVf00?o0000oh=l
Pon3O8<03_n3O8<00ol0003o=LXeocG:=@07ocG:=@03o`000?l=lPgo3O8=00?o3O8=00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<ob_D
:`03o`000?mXUfSoJ9MX013oJ9MX00?o0000ohQgR?n8MhP01?n8MhP3o`0000KobCK900?o0000on/D
joo[5>/00_o[5>/5o`0000Sol0o`00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?o
n`Ck00?o0000on/Djoo[5>/01?o[5>/00ol0003o]TVfokI9]P0=okI9]P03o`000?n3O8?oPgb300oo
Pgb300?o0000ocG:=OlebSD01?lebSD2o`0000Oo3O8=00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ob_D:ol[e2/02?l[e2/3o`00013oJ9MX00?o0000ohQgR?n8MhP02?n8MhP3o`0000;o
bCK900?o0000on/Djoo[5>/02?o[5>/5o`0000?ol0o`00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?ok1?_on`Ck00Con`Ck00?o0000on/Djoo[5>/01Oo[5>/00ol0003o]TVfokI9]P0;okI9]PCo0000
3on3O8<00ol0003o=LXeocG:=@03ocG:=@03o`000?l=lPgo3O8=00So3O8=00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l[e2/2o`0000?o;m0_00?o0000ofRGJ?mXUfP03?mXUfP00ol0003oR7N8ohQgR00<ohQgR0;o0000
4?o[5>/3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?o[5>_ojaC[00KojaC[00?o
0000okI9]_nfBKH02OnfBKH00ol0003obCK9o`000002og^4N`?o00003?n3O8<01?l0003o=LXeocG:
=OlebSD2o`0000co3O8=00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o:m@[ob_D:`02ob_D:`03o`00
0?l_d2oo;m0_00Co;m0_0_l0000;ofRGJ003o`000?n8MhSoR7N800coR7N800?o0000olDjaOl00000
4_o[5>/00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?o[5>_ojaC[00OojaC[00?o
0000okI9]_nfBKH01_nfBKH2o`0000;obCK900?o0000og^4NomkQ7/00omkQ7/3o`0000[oPgb300?o
0000ocG:=Ol000003ol=lPd01?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o:m@[o`000?l00009obo@;`03o`000?mXUfSoJ9MX00Oo
J9MX00?o0000ohQgR?n8MhP03?n8MhP01?l0003oaC[5olDjaOl0000Con/Dj`03o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000oo/4nook1?/01ook1?/00ol0003ojaC[on/Dj`08on/Dj`03o`000?nfBKKo]TVf00Co
]TVf00?o0000olTfbOo9=/T00oo9=/T00ol0003oNhAkog^4N`05og^4N`?o00001_n3O8<4o`00013o
3O8=00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000obo@;ol_d2l02_l_d2l2o`0000KoJ9MX00?o0000ohQgR?n8MhP03?n8MhP00ol0003o
aC[5olDja@02olDja@03o`000?o[5>_ojaC[00oojaC[00?o0000ooT6nOl000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?o[5>_ojaC[00WojaC[00Co0000okI9]_nfBKKo
]TVf0_l00006olTfb@03o`000?mkQ7_oNhAk00SoNhAk0ol000000on3O8?o0000o`000004ocK9=P03
o`000?l=lPgo3O8=00go3O8=00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000obo@;ol_d2l03?l_d2l00ol0003oJ9MXofRGJ003o`0000ko
R7N800?o0000olDjaOo5>/D00oo5>/D00ol0003ojaC[on/Dj`0>on/Dj`05o`000?oi1_Won@KiooT6
nOl000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?o[5>_ojaC[00[o
jaC[00?o0000okI9]_l000002?o9=/T00ol0003oNhAkog^4N`0;og^4N`03o`000?lfbCKo=/Tf00Go
=/Tf00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo;m0_0_l00002ogn0O`03o`000?n8MhSoR7N800_o
R7N800?o0000olDjaOo5>/D01?o5>/D00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oi1_Won@Ki00?o
n@Ki00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo/4n`03o`000?o[5>_ojaC[00_ojaC[00?o0000olTfbOo9=/T0
1oo9=/T00ol0003oNhAkog^4N`0;og^4N`03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000o`gb3Ol=lPd0
2ol=lPd2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l5nPGo1OX5o`0000ko;m0_00?o0000ogn0OomoP7l00_moP7l00ol0003oR7N8ohQgR009ohQgR003
o`000?o5>/GoaC[500KoaC[500?o0000on/Djoo[5>/02oo[5>/00ol0003on@KiooT6n@05ooT6n@04
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son`Ck00?o0000on/Djoo[5>/02_o[5>/2o`0000Wo
bCK900?o0000og^4NomkQ7/02omkQ7/00ol0003o=/TfocK9=P07ocK9=P03o`000?l=lPgo3O8=00Wo
3O8=00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Gj1Ol5nPGo1OX5o`00000>obo@;`03o`000?moP7ooOh1o00?oOh1o00?o0000
ohQgR?n8MhP01on8MhP00ol0003oaC[5olDja@07olDja@03o`000?o[5>_ojaC[00[ojaC[00?o0000
ooT6nOoi1_T01ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006oo/4n`03o`000?o[5>_ojaC[
00WojaC[00Co0000onPGj?oX5nSo00002Oo9=/T00ol0003oNhAkog^4N`09og^4N`03o`000?lfbCKo
=/Tf00Wo=/Tf00?o0000o`gb3Ol=lPd01ol=lPd00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l5nPGo
1OX500?o1OX500?o0000obo@;ol_d2l02_l_d2l00ol0003oOh1oogn0O`05ogn0O`03o`000?n8MhSo
R7N800GoR7N800?o0000olDjaOo5>/D02?o5>/D00ol0003ojaC[on/Dj`09on/Dj`03o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_ok1?/3o`0000WojaC[00?o0000onPG
j?oX5nP00_oX5nP00ol0003obCK9olTfb@06olTfb@03o`000?mkQ7_oNhAk00WoNhAk00?o0000ocK9
=_lfbCH02_lfbCH00ol0003o3O8=o`gb3@05o`gb3@03o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o;m0_obo@;`0:obo@;`03o`000?moP7ooOh1o00KoOh1o00?o0000ohQg
R?n8MhP00on8MhP00ol0003oaC[5olDja@09olDja@03o`000?o[5>_ojaC[00SojaC[00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003ooH9mP?o00001Oo[5>/00ol0003o
j1OXonPGj003onPGj003o`000?o9=/WobCK900KobCK900?o0000og^4NomkQ7/02OmkQ7/00ol0003o
=/TfocK9=P0;ocK9=P03o`000?l=lPgo3O8=00?o3O8=00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1OX500?o0000obo@;ol_d2l02Ol_d2l00ol0003oOh1oogn0O`07ogn0O`05o`000?n8MhSoR7N8ohQg
R?l000003Oo5>/D00ol0003ojaC[on/Dj`06on/Dj`03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?of2OKomPWf00GomPWf0ol000000oo[5>_o0000onPGj006onPGj003
o`000?o9=/WobCK900GobCK900?o0000og^4NomkQ7/02OmkQ7/00ol0003o=/TfocK9=P0<ocK9=P05
o`000?l=lPgo3O8=o`gb3Ol000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olHiaSo0000o`Gj1@07o`Gj1@03o`000?l_d2oo;m0_
00So;m0_00?o0000ogn0OomoP7l02OmoP7l00ol0003oR7N8o`00000=olDja@Co00001Oo[5>/00ol0
003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9mP08ooH9mP03
o`000?oX5nSoj1OX00Ooj1OX00?o0000olTfbOo9=/T01?o9=/T00ol0003oNhAkog^4N`09og^4N`03
o`000?lfbCKo=/Tf00go=/Tf00?o0000o`gb3Ol000003?l0o`0:o`0000Oo0?l00ol00005oaSW6003
o`000?l5nPGo1OX500Ko1OX500?o0000obo@;ol_d2l01ol_d2l00ol0003oOh1oogn0O`0:ogn0O`03
o`000?o5>/GoaC[500_oaC[500?o0000ondBkOo]4^d00_o]4^d3o`000003on/Djol0003on@Ki00_o
n@Ki0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003oj1OXonPGj007onPGj003o`00
0?o9=/WobCK900GobCK900?o0000og^4NomkQ7/01omkQ7/00ol0003o=/TfocK9=P0?ocK9=P;o0000
2ol0o`000ol0003o3O8=o`gb3@07o`gb3@03o`000?l0o`3o0?l000;o0?l00ol00008oaSW6003o`00
0?l5nPGo1OX500Ko1OX500?o0000obo@;ol_d2l01ol_d2l00ol0003oOh1oogn0O`0:ogn0O`03o`00
0?o5>/GoaC[500[oaC[500?o0000ondBkOo]4^d01_o]4^d00ol0003on@KiooT6n@08ooT6n@?o0000
0_oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003oj1OXonPG
j008onPGj003o`000?o9=/WobCK900CobCK900?o0000og^4NomkQ7/01omkQ7/00ol0003o=/TfocK9
=P0>ocK9=P04o`000?l7n0Oo1oP7o`0000Wo0?l000?o0000o`gb3Ol=lPd02Ol=lPd01?l0003o0?l0
o`000?l0000<oaSW6003o`000?l5nPGo1OX500Ko1OX500?o0000obo@;ol_d2l01_l_d2l00ol0003o
Oh1oogn0O`0;ogn0O`03o`000?o5>/GoaC[500OoaC[50_l00009ondBk@03o`000?oi1_Won@Ki00Co
n@Ki1?l00006ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003omPWfooH9mP09ooH9mP03o`00
0?oX5nSoj1OX00Soj1OX00?o0000olTfbOo9=/T00oo9=/T>o`0000go=/Tf00?o0000o`Oh1ol7n0L0
0_l7n0L00ol0003o0?l0o`3o0005o`3o0003o`000?l=lPgo3O8=00_o3O8=00?o0000oaSW6?lHiaP0
3?lHiaP00ol0003o1OX5o`Gj1@06o`Gj1@03o`000?l_d2oo;m0_00Go;m0_00?o0000ogn0OomoP7l0
3?moP7l00ol0003oaC[5olDja@06olDja@03o`000?o]4^gokA;]00[okA;]00?o0000ooT6nOoi1_T0
0ol0000:ooX5nP?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onPGj?oX5nP02?oX
5nP01Ol0003obCK9olTfbOo9=/Wo000000_oT6n@00?o0000obgB;Ol]dRd00ol00009ocK9=P03o`00
0?l7n0Oo1oP700Co1oP700?o0000o`3o0?l0o`000ol0o`000ol0003o3O8=o`gb3@0<o`gb3@03o`00
0?lHiaSo6>LH00go6>LH00?o0000o`Gj1Ol5nPD01_l5nPD00ol0003o;m0_obo@;`03obo@;`?o0000
3OmoP7l00ol0003oaC[5olDja@05olDja@03o`000?o]4^gokA;]00cokA;]0_l0000=ooX5nP03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onPGj?oX5nP02?oX
5nP4o`0000coT6n@00?o0000obgB;Ol]dRd00ol]dRd3o`0000Go=/Tf00?o0000o`Oh1ol7n0L01_l7
n0L01Ol0003o0?l0o`3o0?l0o`3o000000oo3O8=00?o0000oaSW6?lHiaP03OlHiaP00ol0003o1OX5
o`Gj1@06o`Gj1@03o`000?l_d2oo;m0_00?o00000olebSD00ol0003oOh1oogn0O`0;ogn0O`03o`00
0?o5>/GoaC[500?oaC[500?o0000ondBkOo]4^d03Oo]4^d00ol0003onPGjooX5nP0;ooX5nP03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000ooH9m_of2OH02_of2OH3o`0000Koj1OX0ol0
0003om`Sg003o`000?n@Ki3oT6n@00[oT6n@00?o0000obgB;Ol]dRd01_l]dRd3o`000003ocK9=_l0
003o1oP700Wo1oP700?o0000o`3o0?l000004?l=lPd00ol0003o6>LHoaSW600=oaSW6003o`000?l5
nPGo1OX500Oo1OX50_l00007ocG:=@03o`000?moP7ooOh1o00[oOh1o00Co0000olDjaOo5>/GoaC[5
0ol0000?ondBk@03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooH9m_of2OH02_of
2OH01?l0003olPgboo8=l_ob3O82o`000004onPGj?l0003o0000o`0000Kog2?L00?o0000oi1_T?n@
Ki002_n@Ki000ol0003o;M8]obgB;@09obgB;@03o`000?l7n0Oo1oP700[o1oP700?o0000o`gb3Ol=
lPd03ol=lPd00ol0003o6>LHoaSW600>oaSW6003o`000?l5nPGo1OX500Ko1OX500?o0000ocG:=Ole
bSD01olebSD4o`0000SoOh1o00Co0000olDjaOo5>/Go00000ooM8]d2o`0000gokA;]00?o0000ooX5
n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003o
lPgboo8=lP04oo8=lP03o`000?oL8mcog2?L00Oog2?L00?o0000oi1_T?n@Ki002On@Ki000ol0003o
;M8]obgB;@0:obgB;@03o`000?l7n0Oo1oP700[o1oP700?o0000o`gb3Ol=lPd03ol=lPd00ol0003o
6>LHoaSW600>oaSW6003o`000?l5nPGo1OX500Go1OX500?o0000ocG:=OlebSD02?lebSD01?l0003o
Pgb3oh=lPon3O8<7o`0000;oOh1o0_l00006omdRg@;o00003?o]4^d00ol0003onPGjooX5nP09ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003omPWfooH9mP08ooH9mP03o`000?ob3O;olPgb00Go
lPgb00?o0000om`Sg?oL8m`02?oL8m`00ol0003oT6n@oi1_T008oi1_T003o`000?l]dRgo;M8]00[o
;M8]00?o0000o`Oh1ol7n0L02ol7n0L00ol0003o3O8=o`gb3@0>o`gb3@03o`000?lHiaSo6>LH00ko
6>LH1Ol00002o`Gj1@03o`000?lebSGo=LXe00Wo=LXe00?o0000oh=lPon3O8<02?n3O8<3o`0000Wo
gB;M0_l0000:ondBk@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?of2OKomPWf00SomPWf00?o0000oo8=l_ob3O801oob3O800ol0003og2?Lom`Sg007om`Sg003o`00
0?n@Ki3oT6n@00SoT6n@00?o0000obgB;Ol]dRd02_l]dRd00ol0003o1oP7o`Oh1`0:o`Oh1`;o0000
3_l=lPd3o`0000go6>LH0ol00005obkA;P;o00002olebSD00ol0003oPgb3oh=lP`0;oh=lP`;o0000
2_oM8]d2o`0000OokA;]0ol00009ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:oo8=lP03o`00
0?oL8mcog2?L00Oog2?L00?o0000oi1_T?n@Ki002?n@Ki0>o`0000Wo1oP70ol000000ol0o`3o0000
o`gb3@0:o`gb3@?o00000_lTfb@00ol0003o6>LHoaSW6009oaSW60;o00002Ol^dBh00ol0003o=LXe
ocG:=@09ocG:=@03o`000?n3O8?oPgb300_oPgb300?o0000oj]DZol000002ooM8]d2o`0000CokA;]
00Co0000oo<<looc3??ol`cc0_l00007ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002oom0_d00ol0003olPgb
oo8=lP09oo8=lP03o`000?oL8mcog2?L00Kog2?L00?o0000oi1_T?n@Ki002?n@Ki000ol0003o;m0_
obo@;`0:obo@;`03o`000?l7n0Oo1oP700Co1oP70ol00005o`3o0003o`000?l=lPgo3O8=00Co3O8=
1?l00006obCK9003o`000?lHiaSo6>LH00Ko6>LH0_l0000;obkA;P03o`000?lebSGo=LXe00Wo=LXe
00?o0000oh=lPon3O8<02_n3O8<01Ol0003oZeB[oj]DZon[E:_o000000cogB;M0_l000000oo]4^go
0000oo<<l`05oo<<l`03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?ob3O;olPgb00SolPgb00?o0000om`Sg?oL8m`01_oL8m`00ol0003oT6n@oi1_T007oi1_T003o`00
0?l_d2oo;m0_00_o;m0_00?o0000o`Oh1ol7n0L00_l7n0L2o`0000Wo0?l000?o0000o`gb3Ol=lPd0
0ol0000;obCK9003o`000?lHiaSo6>LH00;o6>LH0ol0000>obkA;P03o`000?lebSGo=LXe00Oo=LXe
00?o0000oh=lPon3O8<02on3O8<00ol0003oZeB[oj]DZ`02oj]DZ`03o`000?oM8]gogB;M00_ogB;M
00?o0000oo<<looc3?<01_oc3?<2o`0000?onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob
3O;olPgb00OolPgb00?o0000om`Sg?oL8m`01ooL8m`00ol0003oT6n@oi1_T005oi1_T0?o00003Ol_
d2l4o`0000_o0?l00ol0000?obCK9004o`000?lHiaSo0000o`00017o;]4^00?o0000ocG:=OlebSD0
1olebSD00ol0003oPgb3oh=lP`0:oh=lP`03o`000?n[E:_oZeB[00CoZeB[00?o0000omdRgOoM8]d0
1ooM8]d3o`0000_ol`cc1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O802?ob3O800ol0003og2?Lom`S
g006om`Sg003o`000?n@Ki3oT6n@00;oT6n@0ol00003ofbCK003o`000?l_d2oo;m0_00[o;m0_00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000AobCK9003o`000?l^dBko;]4^017o;]4^00?o
0000ocG:=OlebSD01olebSD00ol0003oPgb3oh=lP`0:oh=lP`03o`000?n[E:_oZeB[00GoZeB[00Co
0000omdRgOoM8]gogB;M1Ol00002on4Nh@03o`000?oc3??ol`cc00Wol`cc00Co0000ooh1o_on0Oko
oP7n0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000oo8=l_ob3O801oob3O800ol0003og2?Lom`Sg005om`Sg0?o0000
00?oT6n@o`000?l000001om/Tf`00ol0003o;m0_obo@;`08obo@;`?o00002_l0o`02o`0000;o0?l0
00?o0000obCK9?lTfb@03olTfb@00ol0003o;]4^obkA;P0AobkA;P03o`000?lebSGo=LXe00Oo=LXe
00?o0000oh=lPon3O8<02On3O8<00ol0003oZeB[oj]DZ`07oj]DZ`?o00001ooQ7^400ol0003ol`cc
oo<<l`09oo<<l`03o`000?on0OkooP7n00CooP7n0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000oo8=l_ob3O801oob
3O84o`0000;og2?L0_l00003olhacP03o`000?m/TfcoK9=/00SoK9=/0_l00006obo@;`;o00000olU
fRD00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000obCK9?lTfb@03_lT
fb@00ol0003o;]4^obkA;P0BobkA;P03o`000?lebSGo=LXe00Go=LXe00?o0000oh=lPon3O8<02On3
O8<00ol0003oZeB[oj]DZ`08oj]DZ`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo<<looc3?<02?oc
3?<00ol0003ooP7nooh1oP07ooh1oP;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?ob3O;olPgb00ColPgb0_l00004
oo0?l0;o00001Oo><Lh00ol0003oK9=/ofbCK00:ofbCK003o`000?l_d2oo;m0_00;o;m0_00?o0000
obGJ9OlUfRD01?lUfRD00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
obCK9?lTfb@03_lTfb@00ol0003o;]4^obkA;P0BobkA;P[o00002_n3O8<00ol0003oZeB[oj]DZ`08
oj]DZ`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo<<looc3?<02?oc3?<00ol0003ooP7nooh1oP09
ooh1oP?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003olPgboo8=l_ob3O82o`0000Ool0o`00?o0000olhac_o><Lh01?o><Lh0
0ol0003oK9=/ofbCK00:ofbCK004o`000?l_d2oo0000o`0000So9MXU00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lTfbCo9=/T00ko9=/T00?o0000obkA;_l^dBh04_l^dBh00ol0003oEZUF
oeJYEP07oeJYEP03o`000?n3O8?oPgb300KoPgb300?o0000oj]DZon[E:/02_n[E:/00ol0003ohAkQ
on4Nh@06on4Nh@03o`000?oc3??ol`cc00Sol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?ob
3O;o0000o`0000Wol0o`00?o0000olhac_o><Lh01?o><Lh00ol0003oK9=/ofbCK00;ofbCK003o`00
0?lUfRGo9MXU00Wo9MXU00?o0000o`3o0?l000002Ol0o`000ol0003o9=/TobCK900>obCK90;o0000
4_l^dBh00ol0003oEZUFoeJYEP09oeJYEP;o00001_n3O8<00ol0003oZeB[oj]DZ`0:oj]DZ`03o`00
0?oQ7^7ohAkQ00KohAkQ00?o0000oo<<looc3?<02?oc3?<00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000oo0?l?o`3o002Oo`3o000ol0003ocS7>olhacP05olhacP03o`000?m/TfcoK9=/00[oK9=/00?o
0000obGJ9OlUfRD02_lUfRD2o`0000Wo0?l000?o0000obCK9?lTfb@03_lTfb@00ol0003o7^4No`00
0002o`0000oo;]4^00?o0000oeJYE_mFZEH02omFZEH00ol0003oPgb3oh=lP`03o`0000goZeB[00?o
0000on4NhOoQ7^401_oQ7^400ol0003ol`ccoo<<l`07oo<<l`03o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003ol0o`oo0?l009oo0?l003o`000?o><LkocS7>00GocS7>00?o0000ofbCK?m/Tf`02Om/Tf`2
o`0000_o9MXU0_l0000;o`3o0003o`000?lTfbCo9=/T00co9=/T00?o0000oakQ7_lNhAh00olNhAh3
o`0000co;]4^00?o0000oeJYE_mFZEH03?mFZEH2o`0000;oZ5NX00?o0000oj]DZon[E:/03?n[E:/0
0ol0003ohAkQon4Nh@05on4Nh@03o`000?oc3??ol`cc00Ool`cc00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o`3o3ol0o`00[ol0o`00?o0000olhac_o><Lh01_o><Lh00ol0003oK9=/ofbCK007ofbC
K003o`000?mdRgCo000000[o9MXU00Co0000oakQ7_lNhAko00002_l0o`000ol0003o9=/TobCK900<
obCK9003o`000?lNhAko7^4N00Ko7^4N0_l00008obkA;P;o00003omFZEH00ol0003oZ5NXojQGZ002
ojQGZ003o`000?n[E:_oZeB[00_oZeB[00?o0000on4NhOoQ7^401OoQ7^400ol0003ol`ccoo<<l`07
oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003ol0o`oo0?l00:oo0?l003o`000?o><LkocS7>
00KocS7>00?o0000ofbCK?m/Tf`01_m/Tf`01Ol0003oM8]dogB;M?mdRgCo000000So9MXU00?o0000
oakQ7_lNhAh00_lNhAh00ol0003o0?l0o`3o0006o`3o00Co00003?lTfb@00ol0003o7^4NoakQ7P08
oakQ7P?o00000_l^dBh3o`000003od2o@?l0003oEZUF00goEZUF00?o0000ojQGZ?nXEjP01?nXEjP0
0ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?oQ7^7ohAkQ00GohAkQ00?o0000oo<<looc3?<01_oc3?<0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o002oo`3o000ol0003ocS7>olhacP07olha
cP03o`000?m/TfcoK9=/00?oK9=/0_l00005ogB;M003o`000?lUfRGo9MXU00Co9MXU00?o0000oakQ
7_lNhAh00olNhAh00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200;o0_d20ol00007obCK
90;o00003_lNhAh2o`0000Go@;m000?o0000oeJYE_mFZEH02_mFZEH00ol0003oZ5NXojQGZ005ojQG
Z003o`000?n[E:_oZeB[00_oZeB[00?o0000on4NhOoQ7^401?oQ7^400ol0003ol`ccoo<<l`06oo<<
l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003ol0o`oo0?l00;oo0?l003o`000?o><LkocS7>00Oo
cS7>00?o0000ofbCK?m/Tf`00_m/Tf`00ol0003oM8]dogB;M006ogB;M003o`000?lUfRGo9MXU00;o
9MXU00?o0000oakQ7_lNhAh01OlNhAh00ol0003o0?l0o`3o0002o`3o00;o00002?l2o@83o`0000;o
9=/T0_l000000ol5nPGo0000oakQ7P0=oakQ7P03o`000?m0_d3o@;m000Go@;m000?o0000oeJYE_mF
ZEH02?mFZEH00ol0003oZ5NXojQGZ007ojQGZ003o`000?n[E:_oZeB[00[oZeB[00?o0000on4NhOoQ
7^401?oQ7^400ol0003ol`ccoo<<l`06oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`
oo0?l00<oo0?l003o`000?o><LkocS7>00SocS7>00Co0000ofbCK?m/Tfco00002OmdRg@01Ol0003o
9MXUobGJ9OlUfRGo000000So7^4N00Go0000o`3o0?l0o`3o0?l0o`00000=o`;m0P;o00001?l5nPD0
0ol0003o7^4NoakQ7P0;oakQ7P03o`000?m0_d3o@;m000Ko@;m000?o0000oeJYE_mFZEH01omFZEH0
0ol0003oZ5NXojQGZ008ojQGZ0Co00002?n[E:/00ol0003ohAkQon4Nh@04on4Nh@03o`000?oc3??o
l`cc00Kol`cc00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?o`3o3ol0o`00_ol0o`0ol00009olha
cP03o`000?m/Tfco000000_oM8]d00?o0000obGJ9Ol000002_lNhAh00ol0003o0?l0o`00000?o`;m
0P03o`000?l5nPGo1OX500;o1OX500?o0000oakQ7_lNhAh02olNhAh00ol0003o@;m0od2o@006od2o
@003o`000?mFZEKoEZUF00KoEZUF00?o0000ojQGZ?nXEjP02OnXEjP01?l0003oc3?<ol`cc?o<<l`7
o`0000;oZeB[00?o0000on4NhOoQ7^400ooQ7^400ol0003ol`ccoo<<l`05oo<<l`03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?o`3o3ol0o`00Sol0o`0ol00003onl@k`03o`000?o><LkocS7>00OocS7>00?o0000ogB;
M?mdRg@02omdRg@00ol0003o7^4NoakQ7P0:oakQ7P03o`000?l2o@;o0_d200go0_d200?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o7^4NoakQ7P09oakQ7P03o`000?m0_d3o@;m000So@;m000?o0000oeJY
E_mFZEH00omFZEH2o`0000coZ5NX00?o0000ol`cc?o<<l`02?o<<l`<o`0000?ol`cc0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o001_o`3o03o`0000Ooka3_00?o0000olhac_o><Lh01_o><Lh00ol0003o
M8]dogB;M00;ogB;M003o`000?lNhAko7^4N00Wo7^4N0_l0000>o`;m0P03o`000?l5nPGo1OX500Go
1OX500?o0000oakQ7_lNhAh02OlNhAh00ol0003o@;m0od2o@009od2o@003o`000?mFZEKo000000;o
00000_nLHi`00ol0003oZ5NXojQGZ008ojQGZ003o`000?o<<lcoc3?<00coc3?<00?o0000onhAk_o^
4Nh01_o^4Nh3o`0000?oo@;m0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003ol0o`oo0?l003oo0?l0?o00002oo_4>l00ol0003ocS7>
olhacP04olhacP03o`000?mdRgCoM8]d00_oM8]d0ol00007oakQ7P?o000000?o4>l@o`000?l2o@80
3Ol2o@800ol0003o1OX5o`Gj1@06o`Gj1@03o`000?lNhAko7^4N00So7^4N00?o0000od2o@?m0_d00
2_m0_d000ol0003oW6>LoiaSW004oiaSW003o`000?nXEjSoZ5NX00OoZ5NX00?o0000ol`cc?o<<l`0
2oo<<l`00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00Coo@;m0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004oo0?l?l0
003o0000o`0000ooka3_00?o0000olhac_o><Lh00oo><Lh>o`0000?oGJ9M0_l00002oakQ7P?o0000
1Ol@ka000ol0003o0_d2o`;m0P0:o`;m0P03o`000?l5nPGo1OX500Oo1OX500?o0000oakQ7_lNhAh0
2?lNhAh00ol0003o@;m0od2o@00:od2o@003o`000?nLHicoW6>L00GoW6>L00?o0000ojQGZ?nXEjP0
1_nXEjP00ol0003oc3?<ol`cc00;ol`cc003o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d0
1oom0_d2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?ol0o`2o`0001;oka3_00?o0000olhac_o><Lh00_o><Lh00ol0003o`3o0ol0o
`00:ol0o`003o`000?mMXUgoGJ9M00?oGJ9M0_l00009oa3_4003o`000?l2o@;o0_d200Wo0_d200?o
0000o`Gj1Ol5nPD02?l5nPD2o`0000So7^4N00?o0000od2o@?m0_d002Om0_d000ol0003oW6>LoiaS
W007oiaSW003o`000?nXEjSoZ5NX00CoZ5NX00?o0000ol`cc?o<<l`02oo<<l`00ol0003okQ7^onhA
kP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oka3_onl@k`0?onl@k`?o000000?ocS7>
o`000?o0?l002oo0?l000ol0003oGJ9MoefRG@04oefRG@03o`000?l@ka3o4>l@00Wo4>l@00?o0000
o`;m0_l2o@801ol2o@800ol0003o1OX5o`Gj1@09o`Gj1@04o`000?lDjaCo0000o`0000Ko7^4N00?o
0000od2o@?m0_d002Om0_d000ol0003oW6>LoiaSW008oiaSW003o`000?nXEjSoZ5NX00?oZ5NX00?o
0000ol`cc?o<<l`02oo<<l`00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oka3_onl@k`0<onl@k`;o00000oo^4Nh2o`0000co`3o000?o0000oefRGOmMXUd01?mMXUd0
0ol0003o4>l@oa3_400:oa3_40Wo00002ol5nPD00ol0003o5>/DoaC[5002oaC[50?o00000_lNhAh0
0ol0003o@;m0od2o@00:od2o@003o`000?nLHicoW6>L00WoW6>L00?o0000ojQGZ?nXEjP00_nXEjP0
0ol0003oc3?<ol`cc00:ol`cc003o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o_4>l2o`0000GokQ7^00?o0000om4^dOl000002_o0?l000ol0003oGJ9MoefRG@06oefR
G@03o`000?l@ka3o4>l@00Wo4>l@00?o0000o`3o0?l0o`001Ol0o`000ol0003o1OX5o`Gj1@09o`Gj
1@03o`000?lDjaCo5>/D00Go5>/D0ol00009od2o@0?o00003OnLHi`01Ol0003oZ5NXojQGZ?nXEjSo
000000coc3?<00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@
koo_4>l01Oo_4>l2o`0000OokQ7^00Co0000om4^dOoA;]7o00002Oo0?l000ol0003oGJ9MoefRG@06
oefRG@03o`000?l@ka3o4>l@00So4>l@00?o0000o`3o0?l0o`001ol0o`000ol0003o1OX5o`Gj1@07
o`Gj1@03o`000?lDjaCo5>/D00So5>/D0ol00002od2o@0Go00000_n2OH800ol0003oW6>LoiaSW00<
oiaSW003o`000?nXEjSo000000coc3?<00?o0000onhAk_o^4Nh02_o^4Nh00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onl@koo_4>l00_o_4>l2o`0000SokQ7^00?o0000om4^dOoA;]400_oA;]45o`00
00Co`3o000?o0000oefRGOmMXUd01_mMXUd00ol0003o4>l@oa3_4008oa3_4003o`000?l0o`3o0?l0
00Oo0?l000?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o5>/DoaC[5008oaC[5003o`000?m5^TGoAKY5
00;o00002?n2OH800ol0003oW6>LoiaSW00<oiaSW0Co00002_o<<l`00ol0003okQ7^onhAkP0:onhA
kP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oka3_o`000?l0000:onhAkP03o`000?oA;]7odBkA
00;odBkA00?o0000oj=LXonSG:<00_nSG:<4o`0000WoGJ9M00?o0000oa3_4?l@ka002?l@ka000ol0
003o0?l0o`3o0008o`3o0003o`000?l5nPGo1OX500Go1OX500?o0000oaC[5?lDja@02?lDja@01Ol0
003oAKY5odFjAOm5^TGo000000[oPWf20ol0000;oiaSW004o`000?oT6nCoi1_Ton@Ki0Co00001Oo<
<l`00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003okQ7^onhAkP0:
onhAkP03o`000?oA;]7odBkA00?odBkA00?o0000oj=LXonSG:<01?nSG:<00ol0003oGJ9MoefRG@07
oefRG@03o`000?l@ka3o4>l@00Ko4>l@0_l0000;o`3o0003o`000?l5nPGo1OX500Go1OX500?o0000
oaC[5?lDja@02?lDja@00ol0003oAKY5odFjA@02odFjA@03o`000?n2OH;oPWf200OoPWf200?o0000
ol@ka?o4>l@01?l00006oiaSW003o`000?oT6nCoi1_T00Koi1_T0ol00002ol`cc003o`000?o^4Nko
kQ7^00_okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^4NkokQ7^00WokQ7^00?o0000om4^
dOoA;]401?oA;]400ol0003oXebSoj=LX`05oj=LX`03o`000?mMXUgoGJ9M00OoGJ9M00?o0000oa3_
4?l@ka000_l@ka03o`000003ob3O8?l0003o0?l000[o0?l000?o0000o`Gj1Ol5nPD01Ol5nPD00ol0
003o5>/DoaC[5007oaC[5003o`000?m5^TGoAKY500?oAKY500?o0000oh9mP_n2OH801on2OH800ol0
003oa3_4ol@ka004ol@ka0?o00000_nLHi`00ol0003oi1_Ton@Ki00:on@Ki0;o00003_o^4Nh00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003odBkAom4^d@04om4^d@03
o`000?nSG:?oXebS00KoXebS0_l00007oefRG@03o`000?l@ka3o000000;o00001OlPgb000ol0003o
0?l0o`3o0008o`3o00?o00001?l5nPD00ol0003o5>/DoaC[5008oaC[5003o`000?m5^TGoAKY500Co
AKY500?o0000oh9mP_n2OH801_n2OH800ol0003oa3_4ol@ka007ol@ka0;o00003_oT6n@00ol0003o
kQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^onhAkP08onhAkP03o`00
0?oA;]7odBkA00GodBkA00?o0000oj=LXonSG:<01?nSG:<00ol0003oVFJIoiUVV@03o`0000CoGJ9M
0_l00008ob3O8003o`000?l0o`3o0?l000Oo0?l000Co0000obOH9olWf2Oo9mPW0ol000000ol5nPGo
0000oaC[5009oaC[5003o`000?m5^TGoAKY500CoAKY500?o0000oh9mP_n2OH801On2OH800ol0003o
a3_4ol@ka009ol@ka003o`000?oT6nCoi1_T00goi1_T00?o0000onhAk_o^4Nh02_o^4Nh00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003odBkAom4^d@06om4^d@03o`00
0?nSG:?oXebS00?oXebS00?o0000oiUVVOnIIYT01?nIIYT2o`000003oefRGOl0003o8=lP00[o8=lP
00?o0000o`3o0?l0o`001Ol0o`000ol0003o9mPWobOH9`05obOH9`03o`000?lDjaCo5>/D00Oo5>/D
0ol00007odFjA@03o`000?n2OH;oPWf200CoPWf200?o0000ol@ka?o4>l@02Oo4>l@00ol0003oi1_T
on@Ki00=on@Ki003o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^
4NkokQ7^00GokQ7^0ol00009om4^d@05o`000?nSG:?oXebSoj=LXol000002OnIIYT00ol0003o8=lP
ob3O800;ob3O8003o`000?l0o`3o0?l000?o0?l000?o0000obOH9olWf2L01_lWf2L00ol0003o5>/D
oaC[5006oaC[5005o`000?m1_T7o@Ki1od6n@Ol000001om5^TD00ol0003oPWf2oh9mPP03oh9mPP03
o`000?o4>lCoa3_400Woa3_400?o0000on@Ki?oT6n@03_oT6n@00ol0003okQ7^onhAkP09onhAkP03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^o`000004o`0000;ol`cc00?o0000om4^dOoA;]40
1ooA;]401?l0003oXebSoj=LXol00009oiUVV@;o00003OlPgb000ol0003o0?l0o`3o0002o`3o0003
o`000?lWf2Oo9mPW00So9mPW00?o0000oaC[5?lDja@00olDja@2o`0000Go@Ki100?o0000odFjAOm5
^TD01?m5^TD00ol0003oPWf2oh9mPP03oh9mPP03o`000?o4>lCoa3_400Woa3_400?o0000on@Ki?oT
6n@03_oT6n@00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sol`cc
00?o0000om4^dOoA;]401_oA;]400ol0003oXebSo`000009oiUVV@04o`000?mYUVWoJIIYo`0000go
8=lP00Co0000o`3o0?l0o`3o00003?lWf2L01Ol0003o5>/DoaC[5?lDjaCo000000So@Ki10_l00005
odFjA@03o`000?n2OH;oPWf200;oPWf200?o0000ol@ka?o4>l@02Oo4>l@00ol0003oi1_Ton@Ki00>
on@Ki003o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oc3??ol`cc
00Ool`cc00?o0000om4^dOoA;]401ooA;]400ol0003oVFJIoiUVV@07oiUVV@03o`000?mYUVWoJIIY
00;oJIIY00?o0000ob3O8?lPgb002_lPgb000ol0003o0?l0o`00000>obOH9`03o`000?lDjaCo0000
00_o@Ki100?o0000odFjAOm5^TD00_m5^TD01Ol0003oPWf2oh9mP_n2OH;o000000coa3_400?o0000
on@Ki?oT6n@03_oT6n@3o`0000WokQ7^00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oc3??ol`cc
00Wol`cc00?o0000om4^dOoA;]401_oA;]400ol0003oVFJIoiUVV@06oiUVV@03o`000?mYUVWoJIIY
00?oJIIY00?o0000ob3O8?lPgb002olPgb000ol0003o9mPWobOH9`0>obOH9`03o`000?m1_T7o@Ki1
00_o@Ki10_l00003odFjA@04o`000?n2OH;oPWf2o`0000[oa3_40ol0000>on@Ki0;o00000oom0_d2
o`0000OokQ7^00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oc3??ol`cc00[ol`cc00?o0000om4^
dOoA;]401?oA;]400ol0003oVFJIoiUVV@06oiUVV@03o`000?mYUVWoJIIY00GoJIIY00?o0000ob3O
8?lPgb001olPgb03o`00017o9mPW00?o0000od6n@Om1_T403Om1_T401Ol0003oAKY5odFjAOl0003o
PWf200Co00000oo4>l@5o`0000;oka3_00?o0000on@Ki?oT6n@02_oT6n@2o`0000Ooo@;m0_l00004
onhAkP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oA;]7odBkA
00CodBkA00?o0000oiUVVOnIIYT01OnIIYT00ol0003oJIIYofVFJ@06ofVFJ@03o`000?lPgb3o8=lP
00Co8=lP0ol00002obGJ9@03o`000?lWf2Oo9mPW00oo9mPW0_l0000?od6n@@04o`000?m5^TGo0000
o`0000Co/Tfb0ol00008onl@k`03o`000?oT6nCoi1_T00Ooi1_T0_l0000;ood2o@;o00000_o^4Nh0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo<<looc3?<03?oc3?<6o`0000OoVFJI00?o0000ofVF
JOmYUVT02?mYUVT00ol0003o8=lPob3O8003o`0000Ko9MXU00?o0000obOH9olWf2L03OlWf2L01?l0
003oBKI9odVfBOl0000?od6n@@03o`000?nbCK;o/Tfb00Go/Tfb00?o0000onl@koo_4>l02?o_4>l0
0ol0003oi1_Ton@Ki005on@Ki003o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oc3?<00ol0003oeRWFomHYeP04omHY
eP03o`000?nIIYWoVFJI00?oVFJI00?o0000ofVFJOmYUVT02_mYUVT2o`0000[o9MXU00?o0000obOH
9olWf2L02olWf2L00ol0003oBKI9odVfB@02odVfB@03o`000?m1_T7o@Ki100_o@Ki10_l00007ok9=
/P03o`000?o_4>ooka3_00Woka3_00?o0000on@Ki?oT6n@00_oT6n@2o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo<<looc3?<02ooc3?<00ol0003oeRWFomHYeP06omHYeP05o`000?nIIYWoVFJIoiUV
VOl000003OmYUVT00ol0003o9MXUobGJ9@0:obGJ9@03o`000?lWf2Oo9mPW00Wo9mPW00?o0000odVf
BOm9]TT01?m9]TT00ol0003o@Ki1od6n@@08od6n@@;o000000?oK9=/o`000?nbCK801onbCK800ol0
003oka3_onl@k`09onl@k`04o`000?oT6nCo0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?oc3??ol`cc
00Wol`cc00?o0000omHYe_oF:MH02?oF:MH00ol0003oVFJIo`00000=ofVFJ@03o`000?lUfRGo9MXU
00_o9MXU00?o0000obOH9olWf2L02?lWf2L00ol0003oBKI9odVfB@06odVfB@03o`000?m1_T7o@Ki1
00Go@Ki10_l00003ofbCK003o`000?nbCK;o/Tfb00Ko/Tfb00?o0000onl@koo_4>l02_o_4>l00ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003ol`ccoo<<l`07oo<<l`03o`000?oF:MKoeRWF00[oeRWF00?o0000ofVFJOmY
UVT03?mYUVT00ol0003o9MXUobGJ9@0<obGJ9@03o`000?lWf2Oo9mPW00Ko9mPW00?o0000odVfBOm9
]TT02?m9]TT00ol0003o@Ki1od6n@@02od6n@@;o00001_m/Tf`00ol0003o/Tfbok9=/P05ok9=/P03
o`000?o_4>ooka3_00[oka3_00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oc3??ol`cc00Gol`cc
00?o0000omHYe_oF:MH03?oF:MH2o`0000coJIIY00?o0000obGJ9OlUfRD03OlUfRD00ol0003o9mPW
obOH9`04obOH9`03o`000?m9]TWoBKI900[oBKI900Co0000od6n@Ol0003o00002?m/Tf`00ol0003o
/Tfbok9=/P06ok9=/P03o`000?o_4>ooka3_00Woka3_00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_oc3?<00ol0003oeRWFomHYeP0=omHYeP03o`000?nEJYGo000000;o00002?mYUVT00ol0003o9MXU
obGJ9@0?obGJ9@Ko00003_m9]TT00ol0003oK9=/ofbCK008ofbCK003o`000?nbCK;o/Tfb00Ko/Tfb
00?o0000onl@koo_4>l02Oo_4>l00ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000ooD:mOoe2_Gom@[e
0_l0000?omHYeP03o`000?nEJYGoUFZE00?oUFZE0ol00005ofVFJ@;o00004?lUfRD01_l0003o9MXU
obGJ9Ol0003o7N8Mo`0000koBKI900?o0000ofbCK?m/Tf`02Om/Tf`00ol0003o/Tfbok9=/P05ok9=
/P03o`000?o_4>ooka3_00Woka3_00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003o
eRWFomHYeP0=omHYeP03o`000?nEJYGoUFZE00KoUFZE0ol000001?mYUVWo0000od:m@_m2_D83o`00
00co9MXU00Go0000obGJ9OlUfRGo9MXUo`000002oagR7@03o`000?m9]TWoBKI900_oBKI900?o0000
ofbCK?m/Tf`02Om/Tf`00ol0003o/Tfbok9=/P06ok9=/P03o`000?o_4>ooka3_00Soka3_0_l0000A
ood2o@?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003om@[eooD:m@04ooD:m@oo00003?nEJYD00ol0003o@[e2od:m@P04od:m
@P?o00002?lUfRD00ol0003o9MXUobGJ9@02obGJ9@05o`000?lMhQgo7N8MoagR7Ol000003?m9]TT0
0ol0003oK9=/ofbCK009ofbCK003o`000?nbCK;o/Tfb00Go/Tfb3?l00002ooP7n0;o00003Oom0_d2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003om@[eooD:m@05ooD:m@03o`000?oI9]WofBKI00_ofBKI00?o0000oiEZ
UOnEJYD02_nEJYD00ol0003o@[e2od:m@P07od:m@P;o00001OlUfRD00ol0003o9MXUobGJ9@03obGJ
9@03o`000?lMhQgo7N8M00;o7N8M00?o0000odVfBOm9]TT02Om9]TT00ol0003oK9=/ofbCK00:ofbC
K003o`000?nbCK;o/Tfb00?o/Tfb00?o0000onTFjOoY5^T02OoY5^T00ol0003on0OhooP7n002ooP7
n0;o00002Oom0_d2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003om@[eooD:m@06ooD:m@03o`000?oI9]WofBKI00[o
fBKI00?o0000oiEZUOnEJYD02onEJYD00ol0003o@[e2od:m@P09od:m@P?o000000?o9MXUo`000?lU
fRD01OlUfRD00ol0003o7N8MoagR7@03oagR7@03o`000?m9]TWoBKI900SoBKI93_l00003ok9=/P;o
00002ooY5^T00ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00?oo@;m0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000ooD:mOoe2_D01Ooe2_D00ol0003ohAkQo`00000;omTVf@03o`000?nEJYGoUFZE00[oUFZE
0_l0000>od:m@P03o`000?lUfRGo9MXU00Go9MXU00?o0000oagR7OlMhQd00olMhQd00ol0003oBKI9
odVfB@08odVfB@03o`000?n^DJko[U6^00_o[U6^00?o0000ok9=/_l000003OoY5^T00ol0003on0Oh
ooP7n006ooP7n0;o000000?oo@;mo`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oe2_Gom@[e00Kom@[e00Co
0000on4NhOoQ7^7o00002_oI9]T00ol0003oUFZEoiEZU@09oiEZU@03o`000?m`Sg3o000000ko@[e2
00?o0000obGJ9OlUfRD01OlUfRD00ol0003o7N8MoagR7@04oagR7@03o`000?m9]TWoBKI900KoBKI9
00?o0000ojiA[_n^DJh03On^DJh00ol0003ojAKYonTFj@0<onTFj@03o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?oe2_Gom@[e00Gom@[e00?o0000on4NhOoQ7^400_oQ
7^400ol0003ofBKIomTVf@06omTVf@03o`000?nEJYGoUFZE00SoUFZE0_l00003og2?L003o`000?m2
_D;o@[e200_o@[e200?o0000obGJ9OlUfRD01OlUfRD00ol0003o7N8MoagR7@05oagR7@03o`000?m9
]TWoBKI900GoBKI900?o0000ojiA[_n^DJh03On^DJh00ol0003ojAKYonTFj@0;onTFj@03o`000?oh
1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?oe2_Gom@[e00Kom@[e00?o0000
on4NhOoQ7^400ooQ7^400ol0003ofBKIomTVf@05omTVf@03o`000?nEJYGoUFZE00OoUFZE00?o0000
og2?L?m`Sg000om`Sg000ol0003o@[e2od:m@P0:od:m@P03o`000?lUfRGo9MXU00Ko9MXU00?o0000
oagR7OlMhQd01_lMhQd00ol0003oBKI9odVfB@04odVfB@03o`000?n^DJko[U6^00go[U6^3ol0000;
ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?oe2_Gom@[e00Kom@[e00?o0000on4NhOoQ7^401OoQ7^400ol0
003ofBKIomTVf@04omTVf@03o`000?nEJYGoUFZE00GoUFZE0_l00006og2?L003o`000?m2_D;o@[e2
00Wo@[e20_l00008obGJ9@03o`000?lMhQgo7N8M00Ko7N8M1Ol000000om9]TWo0000ojiA[P0?ojiA
[P03o`000?o/4ncok1?/00_ok1?/00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?oe2_Gom@[e00Kom@[e00?o0000on4NhOoQ7^401_oQ7^400ol0003o
fBKIomTVf@04o`0000KoUFZE00?o0000og2?L?m`Sg001om`Sg000ol0003o@[e2od:m@P05od:m@P?o
000000?o=lPgo`000?lUfRD01olUfRD00ol0003o7N8MoagR7@05oagR7@03o`000?mNXEkoGZ5N00?o
GZ5N0_l0000?ojiA[P;o00003Oo/4n`00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000Wom@[e00?o0000on4NhOoQ7^401ooQ7^42o`0000Co_4>l00Co0000oiEZUOnEJYGo
UFZE0_l0000:og2?L003o`000?m2_D;o@[e200;o@[e20ol00005ocO8=`03o`000?lUfRGo9MXU00Go
9MXU00?o0000oagR7OlMhQd01?lMhQd00ol0003oGZ5NoejQGP06oejQGP03o`000?n^DJko[U6^00[o
[U6^0_l00002om@[e003o`000?o/4ncok1?/00[ok1?/00?o0000ooP7n?oh1oP02?oh1oP00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000ooD:mOoe2_D01_oe2_D00ol0003ohAkQon4Nh@08on4Nh@03o`00
0?nl@kco_4>l00Co_4>l00?o0000oiEZUOl000003?m`Sg000ol0003o@[e2o`000002o`0000Wo=lPg
00?o0000obGJ9OlUfRD01?lUfRD00ol0003o7N8MoagR7@03oagR7@03o`000?mNXEkoGZ5N00SoGZ5N
1_l00004ojiA[P;o00001OoD:m@00ol0003ok1?/on`Ck009on`Ck003o`000?oh1oSon0Oh00Son0Oh
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oe2_Gom@[e00Gom@[e00?o0000on4NhOoQ7^401ooQ
7^400ol0003o_4>loka3_006oka3_003o`000?m`Sg3oL8m`00coL8m`00?o0000ocO8=olgb3L02_lg
b3L00ol0003o9MXUobGJ9@04obGJ9@04o`000?lMhQgo7N8MoagR7@;o00002omNXEh00ol0003o/dbc
ok=</`03ok=</`Co00002?oD:m@00ol0003ok1?/on`Ck008on`Ck003o`000?oh1oSon0Oh00Oon0Oh
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003ohAkQon4Nh@07on4Nh@03o`000?nl
@kco_4>l00Oo_4>l00?o0000og2?L?m`Sg003?m`Sg000ol0003o=lPgocO8=`0;ocO8=`03o`000?lU
fRGo9MXU00?o9MXU00Co0000oagR7OlMhQgo00003OmNXEh00ol0003o/dbcok=</`06ok=</`03o`00
0?oD:mCoe2_D00Ooe2_D00?o0000on`Ck?o/4n`01oo/4n`00ol0003on0OhooP7n006ooP7n004o`00
0?on0OkooP7nooh1oP;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oe2_Gom@[e00;om@[e00?o0000on4NhOoQ7^40
1_oQ7^400ol0003o_4>loka3_009oka3_003o`000?m`Sg3oL8m`00WoL8m`0_l0000>ocO8=`?o0000
0olUfRD00ol0003o7N8Mo`00000=oejQGP03o`000?ncC;?o/dbc00Oo/dbc00?o0000om@[e?oD:m@0
2?oD:m@:o`0000Kon0Oh0_l00006ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OohAkQ00?o
0000oka3_?nl@k`02_nl@k`00ol0003oL8m`og2?L006og2?L0;o000000?oJIIYo`000?lgb3L02olg
b3L2o`0000?oBKI91Ol0000>oejQGP03o`000?ncC;?o/dbc00Oo/dbc00?o0000om@[e?oD:m@02?oD
:m@00ol0003ol@kaoo4>l@06oo4>l@03o`000?oh1oSon0Oh00?on0Oh00?o0000ooh1o_on0Oh01oon
0Oh2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003okA;]ondBk@03ondBk@Co00000_oQ7^400ol0003o_4>loka3_00;
oka3_003o`000?m`Sg3oL8m`00?oL8m`0ol00004ofVFJ@03o`000?lgb3Oo=lPg00Oo=lPg0_l00008
odVfB@03o`000?mNXEkoGZ5N00goGZ5N00?o0000ok=</oncC;<02?ncC;<00ol0003oe2_Dom@[e007
om@[e003o`000?oa3_7ol@ka00Ool@ka0ol000000ooh1oSo0000ooh1oP0;ooh1oP;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o]4^gokA;]00OokA;]0_l0000?oka3_003o`000?m`Sg3oL8m`00;o00002?mYUVT00ol0
003o=lPgocO8=`05ocO8=`03o`000?m9]TWoBKI900SoBKI900?o0000oejQG_mNXEh03OmNXEh00ol0
003o/dbcok=</`08ok=</`03o`000?oD:mCoe2_D00Koe2_D00?o0000oo4>lOoa3_402?oa3_401?l0
003on@KiooT6nOl0000?ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003okA;]ondBk@09ondB
k@03o`000?nl@kco_4>l00ko_4>l0_l0000;ofVFJ@03o`000?lgb3Oo=lPg00;o=lPg0_l0000;odVf
B@03o`000?mNXEkoGZ5N00goGZ5N00?o0000ok=</oncC;<02?ncC;<00ol0003oe2_Dom@[e006om@[
e003o`000?oa3_7ol@ka00Ool@ka00Go0000ooT6nOoi1_Won@Kio`00000@ooh1oP;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003okA;]ondBk@0:ondBk@03o`000?nl@kco_4>l00go_4>l0_l0000<ofVFJ@04o`000?lgb3Oo0000
o`0000goBKI900?o0000oejQG_mNXEh03?mNXEh00ol0003o/dbcok=</`09ok=</`03o`000?oD:mCo
e2_D00Koe2_D00?o0000oo4>lOoa3_401_oa3_400ol0003on@KiooT6n@03ooT6n@03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003okA;]ondBk@0:ondBk@03o`000?nl@kco_4>l00co_4>l00Co0000okE:
]OneB[Go00003?mYUVT00ol0003oBKI9odVfB@0>odVfB@03o`000?mNXEkoGZ5N00SoGZ5N1?l0000;
ok=</`03o`000?oD:mCoe2_D00Koe2_D00?o0000oo4>lOoa3_401Ooa3_400ol0003on@KiooT6n@04
ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003okA;]ondBk@0;ondBk@03o`000?nl@kco_4>l
00_o_4>l00?o0000okE:]OneB[D00_neB[D00ol0003oJIIYofVFJ@09ofVFJ@03o`000?m9]TWoBKI9
00koBKI900Co0000oejQG_mNXEkoGZ5N1ol00003oh5nP@03o`000?ncC;?o/dbc00Wo/dbc00?o0000
om@[e?oD:m@01_oD:m@00ol0003ol@kaoo4>l@04oo4>l@03o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o]4^gokA;]00cokA;]00?o0000oka3_?nl@k`02_nl@k`00ol0
003o]DZeokE:]@03okE:]@03o`000?mYUVWoJIIY00SoJIIY00?o0000odVfBOm9]TT03_m9]TT4o`00
00_oPGj100?o0000ok=</oncC;<02?ncC;<00ol0003oe2_Dom@[e005om@[e003o`000?oa3_7ol@ka
00Gol@ka00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000ondBkOo]
4^d03?o]4^d7o`0000Go_4>l00?o0000okE:]OneB[D01OneB[D00ol0003oJIIYofVFJ@07ofVFJ@03
o`000?m9]TWoBKI900koBKI900?o0000oh5nPOn1OX403On1OX400ol0003o/dbcok=</`08ok=</`03
o`000?oD:mCoe2_D00Coe2_D00?o0000oo4>lOoa3_401?oa3_400ol0003on@KiooT6n@07ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003okA;]ondBk@0=ondBk@03o`000?oG:=OoebSG00CoebSG
1Ol00009okE:]@03o`000?mYUVWoJIIY00KoJIIY00?o0000odVfBOm9]TT03_m9]TT00ol0003oPGj1
oh5nP@0=oh5nP@03o`000?ncC;?o/dbc00So/dbc00Co0000om@[e?oD:mCoe2_D1Ol00004oo4>l@03
o`000?oi1_Won@Ki00Won@Ki1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=ondBk@03o`000?oG:=OoebSG00WoebSG
0_l00009okE:]@03o`000?mYUVWoJIIY00KoJIIY00?o0000odVfBOm9]TT03?m9]TT00ol0003oPGj1
oh5nP@0?oh5nP@Ko00001?ncC;<4o`0000GojaC[0_l000000ooa3_7o0000ooT6n@0;ooT6n@04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?of2OKomPWfooH9mP?o00002_o]4^d00ol0003o
ebSGomLXe`09omLXe`03o`000?o3?<?o000000;o00001oneB[D00ol0003oJIIYofVFJ@05ofVFJ@03
o`000?m9]TWoBKI900SoBKI91Ol0000Aoh5nP@03o`000?o1?/7o`Ck100?o`Ck11?l0000;on/Dj`03
o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000ooH9m_of2OH01Oof2OH2o`0000OokA;]
00?o0000omLXeooG:=L02_oG:=L00ol0003o`cc3ol<l``02ol<l``?o00001OneB[D00ol0003oJIIY
ofVFJ@04ofVFJ@04o`000?m9]TWoBKI9odVfB@Oo00001?mhQgP00ol0003oPGj1oh5nP@0>oh5nP@03
o`000?o1?/7o`Ck100Oo`Ck100?o0000on/Djoo[5>/02Oo[5>/00ol0003on@KiooT6n@09ooT6n@03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003omPWfooH9mP08ooH9mP;o00001?o]4^d00ol0003oebSG
omLXe`0;omLXe`03o`000?o3?<?o`cc300Go`cc30ol00003okE:]@04o`000?mYUVWoJIIYofVFJ@Ko
00003?mhQgP00ol0003oPGj1oh5nP@0=oh5nP@03o`000?o1?/7o`Ck100Oo`Ck100?o0000on/Djoo[
5>/02_o[5>/00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ooH9mP?o000000?okA;]o`000?oG:=L0
3?oG:=L00ol0003o`cc3ol<l``08ol<l``?o000000Co]DZeo`000?l0003o00000_ndBk@00ol0003o
N8MhogR7N00=ogR7N003o`000?n1OX7oPGj100coPGj100?o0000ol4n`Oo1?/402?o1?/400ol0003o
jaC[on/Dj`0;on/Dj`03o`000?oi1_Won@Ki00Kon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
mPWf00?o0000omLXeooG:=L03?oG:=L00ol0003o`cc3ol<l``0;ol<l``03o`000?ndBkCo]4^d00?o
]4^d00?o0000ogR7N?mhQgP03?mhQgP00ol0003oRWF:o`00000=oh5nP@03o`000?o1?/7o`Ck100So
`Ck100?o0000on/Djoo[5>/03?o[5>/3o`0000Gon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?of2OKomPWf00comPWf00?o0000omLXeooG:=L03?oG:=L00ol0003o`cc3ol<l``0:ol<l``03o`00
0?ndBkCo]4^d00Go]4^d00?o0000ogR7N?mhQgP02_mhQgP01?l0003oRWF:ohYeR_n:MHX2o`0000[o
PGj100?o0000ol4n`Oo1?/402Oo1?/400ol0003ojaC[on/Dj`0<on/Dj`03o`000?oj1O[onPGj00?o
000000?on@Kio`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000omLXeooG:=L0
3?oG:=L00ol0003o`cc3ol<l``09ol<l``03o`000?ndBkCo]4^d00Ko]4^d00?o0000ogR7N?mhQgP0
2OmhQgP00ol0003oRWF:ohYeRP02ohYeRP03o`000?nfBKKo000000;o00001on1OX400ol0003o`Ck1
ol4n`@09ol4n`@03o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000ooH9m_of2OH02oof2OH00ol0003oebSGomLXe`0;omLXe`03o`000?o3
?<?o`cc300So`cc300?o0000okA;]?ndBk@01ondBk@00ol0003oN8MhogR7N008ogR7N003o`000?n:
MH[oRWF:00?oRWF:00?o0000okI9]_nfBKH00_nfBKH2o`0000CoPGj100?o0000ol4n`Oo1?/402_o1
?/400ol0003ojaC[on/Dj`0:on/Dj`03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?of2OKomPWf00[omPWf0ol0000;omLXe`Ko00001?o3?<<00ol0003o]4^dokA;]008
okA;]003o`000?mhQgSoN8Mh00OoN8Mh00?o0000ohYeR_n:MHX00on:MHX00ol0003o]TVfokI9]P05
okI9]P?o000000?oPGj1o`000?o1?/402oo1?/400ol0003ojaC[on/Dj`09on/Dj`03o`000?oj1O[o
nPGj00OonPGj00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?of2OKomPWf00WomPWf00?o0000onhA
k_o^4Nh01?l00006omLXe`03o`000?oH9mSof2OH00Cof2OH1?l0000<okA;]003o`000?mhQgSoN8Mh
00GoN8Mh00?o0000ohYeR_n:MHX01?n:MHX00ol0003o]TVfokI9]P08okI9]P03o`000?o1?/7o`Ck1
00_o`Ck100?o0000on/Djoo[5>/02?o[5>/00ol0003onPGjooX5nP08ooX5nPGo00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?of2OKomPWf00OomPWf00?o0000onhAk_o^4Nh01Oo^4Nh3o`0000;oebSG00?o0000omPWf?oH
9mP02?oH9mP00ol0003o]4^dokA;]00:okA;]003o`000?mhQgSoN8Mh00CoN8Mh00?o0000ohYeR_n:
MHX01On:MHX00ol0003o]TVfokI9]P08okI9]P03o`000?o1?/7o`Ck100Wo`Ck11?l00008on/Dj`03
o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWf
ooH9mP05ooH9mP03o`000?o^4NkokQ7^00WokQ7^0_l0000<omPWf003o`000?ndBkCo]4^d00Wo]4^d
00?o0000ogR7N?mhQgP00omhQgP00ol0003oRWF:ohYeRP05ohYeRP03o`000?nfBKKo]TVf00[o]TVf
00?o0000ol4n`Oo1?/401?o1?/44o`0000CoiQWV00?o0000on/Djoo[5>/01?o[5>/00ol0003onPGj
ooX5nP0:ooX5nP03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?of2OKomPWf00?omPWf00?o0000onhAk_o^4Nh02oo^
4Nh00ol0003of2OHomPWf00:omPWf003o`000?ndBkCo]4^d00Wo]4^d00?o0000ogR7N?mhQgP00_mh
QgP00ol0003oRWF:ohYeRP06ohYeRP03o`000?nfBKKo]TVf00[o]TVf00?o0000ol4n`Oo1?/401?l0
0009onHIiPKo00003?oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000ooH9m_of2OKomPWf0_l0
000=onhAkP03o`000?oH9mSof2OH00[of2OH00?o0000okA;]?ndBk@02OndBk@01Ol0003oN8MhogR7
N?mhQgSo000000WoRWF:00?o0000okI9]_nfBKH02onfBKH2o`0000goiQWV00?o0000ooT6nOoi1_T0
0_oi1_T00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfo`00
0002oo`3o0;o00002oo^4Nh00ol0003of2OHomPWf00;omPWf003o`000?ndBkCo]4^d00Wo]4^d00?o
0000ogR7N?l000002On:MHX00ol0003o]TVfokI9]P0<okI9]P03o`000?oV6NKoiQWV00coiQWV00?o
0000ooT6nOoi1_T00ooi1_T00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003oo0?loo`3o003oo`3o0;o00002_o^4Nh00ol0003of2OHomPWf00:omPWf003o`000?ndBkCo
]4^d00So]4^d1Ol00008ohYeRP03o`000?nfBKKo]TVf00co]TVf00?o0000onHIi_oV6NH02ooV6NH0
0ol0003on@KiooT6n@05ooT6n@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001ool0o`2o`0000SokQ7^00?o0000omPWf?oH9mP02_oH9mP00ol0003o]4^dokA;]007okA;
]003o`000?njAK[o^TFj00?o^TFj0ol00005ohYeRP03o`000?nfBKKo]TVf00_o]TVf00?o0000onHI
i_oV6NH03?oV6NH00ol0003on@KiooT6n@06ooT6n@03o`000?oj1O[onPGj00OonPGj00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?on0Oko000000Woo0?l00?o0000onhAk_o^4Nh01Oo^4Nh2o`0000co
f2OH00?o0000okA;]?ndBk@01OndBk@00ol0003o^TFjokY5^P07okY5^P?o000000?oRWF:o`000?nf
BKH03OnfBKH00ol0003oiQWVonHIiP0<onHIiP03o`000?oi1_Won@Ki00Kon@Ki00?o0000ooX5n_oj
1OX01_oj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ooh1oP03o`000?ol0ocoo0?l00Ooo0?l
0_l00004onhAkP03o`000?oc3??ol`cc00;o00002_oH9mP00ol0003o]4^dokA;]003okA;]0;o0000
3OnjAKX2o`0000go]TVf0ol0000=onHIiP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooX5n_oj1OX0
1Ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00Soo0?l0_l0
00000oo^4Nko0000oo<<l`04oo<<l`03o`000?oH9mSof2OH00Oof2OH00Co0000okA;]?ndBkCo]4^d
0_l00002om`Sg003o`000?njAK[o^TFj00co^TFj3Ol00003onPGj003o`000?oV6NKoiQWV00[oiQWV
00?o0000ooT6nOoi1_T02?oi1_T01?l0003onPGjooX5n_oj1OX4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?on0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oc3??ol`cc00Gol`cc0_l00008omPWf003o`000?ndBkCo000000Gog2?L
00?o0000okY5^_njAKX02onjAKX00ol0003oaSW6olHiaP09olHiaP03o`000?oX5nSoj1OX00;oj1OX
0_l00009onHIiP03o`000?oi1_Won@Ki00[on@Ki0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ooh1
oP0:ooh1oP03o`000?ol0ocoo0?l00Soo0?l00?o0000oo<<looc3?<01ooc3?<4o`0000?of2OH0ol0
0007om`Sg003o`000?njAK[o^TFj00[o^TFj00?o0000olHia_o6>LH02Oo6>LH00ol0003oj1OXonPG
j004onPGj0;o00001ooV6NH00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo<<looc3?<02?oc3?<0
1?l0003olPgboo8=l_ob3O83o`0000;ojaC[00?o0000om`Sg?oL8m`01_oL8m`00ol0003o^TFjokY5
^P08okY5^P03o`000?o6>LKoaSW600[oaSW600?o0000onPGj?oX5nP01_oX5nP00ol0003oiQWVonHI
iP04onHIiP03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo`3o?ol0o`01Ool0o`00ol0003ol`ccoo<<l`08oo<<l`03o`000?ob3O;o
lPgb00ColPgb00Go0000on/Djoo[5>_ojaC[o`000008om`Sg003o`000?njAK[o^TFj00Oo^TFj00?o
0000olHia_o6>LH02_o6>LH00ol0003oj1OXonPGj007onPGj0;o00001?oV6NH00ol0003on@KiooT6
n@08ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`00ool0o`0
0ol0003ol`ccoo<<l`08oo<<l`03o`000?ob3O;olPgb00ColPgb00?o0000on/Djoo[5>/00_o[5>/0
0ol0003og2?Lom`Sg007om`Sg003o`000?njAK[o^TFj00Ko^TFj00?o0000olHia_o6>LH02_o6>LH0
0ol0003oj1OXonPGj009onPGj005o`000?oV6NKoiQWVonHIi_l000002Ooi1_T00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ol`cc00?o0000oo8=l_ob3O801?ob3O800ol0003ojaC[on/Dj`03
on/Dj`03o`000?oL8mcog2?L00Oog2?L00?o0000okY5^_njAKX01OnjAKX00ol0003oaSW6olHiaP0:
olHiaP03o`000?oX5nSoj1OX00Woj1OX1?l00009ooT6n@03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ol0ocoo0?l
oo`3o?l000002_oc3?<00ol0003olPgboo8=lP05oo8=lP03o`000?o[5>_ojaC[00?ojaC[00?o0000
om`Sg?oL8m`02?oL8m`00ol0003o^TFjokY5^P04okY5^P03o`000?o6>LKoaSW600WoaSW600?o0000
onPGj?oX5nP02?oX5nP2o`0000?on@Ki00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003ol`ccoo<<l`06oo<<l`03o`000?ob3O;olPgb
00GolPgb00?o0000on/Djoo[5>/01?o[5>/00ol0003og2?Lom`Sg009om`Sg003o`000?njAK[o^TFj
00;o^TFj00?o0000olHia_o6>LH02_o6>LH00ol0003oj1OXonPGj006onPGj0;o00001_oi1_T8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?oc3??ol`cc00Gol`cc00?o0000oo8=l_ob
3O801Oob3O800ol0003ojaC[on/Dj`05on/Dj`03o`000?oL8mcog2?L00Wog2?L00Go0000okY5^_nj
AK[o^TFjo`00000<olHiaP03o`000?oX5nSoj1OX00Coj1OX0_l00008ooT6n@03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo<<looc
3?<00ooc3?<00ol0003olPgboo8=lP06oo8=lP03o`000?o[5>_ojaC[00GojaC[00?o0000om`Sg?oL
8m`02_oL8m`00ol0003o^TFjo`000004o`0000WoaSW600?o0000onPGj?oX5nP00_oX5nP2o`0000[o
n@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o007oo`3o003o`00
0?oc3??ol`cc00;ol`cc00?o0000oo8=l_ob3O801_ob3O800ol0003ojaC[on/Dj`07on/Dj`;o0000
2ooL8m`00ol0003okA;]ondBk@03ondBk@Oo00000_o6>LH00ol0003oj1OXonPGj002o`0000_on@Ki
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`02Ool
0o`01Ol0003ol`ccoo<<looc3??o000000SolPgb00?o0000on/Djoo[5>/01oo[5>/00ol0003om@[e
o`000002o`0000Sog2?L00?o0000ondBkOo]4^d02_o]4^d5o`0000gon@Ki00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo`3o003o`000?oc3??o000000WolPgb00?o
0000on/Djoo[5>/01_o[5>/00ol0003om@[eooD:m@03ooD:m@?o00001?oL8m`00ol0003okA;]ondB
k@0=ondBk@03o`000?oi1_Won@Ki00gon@Ki00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000oon0Oh2o`0000_oo0?l00?o0000oo8=l_ob3O801oob3O800ol0003ojaC[on/Dj`07
on/Dj`03o`000?oe2_Gom@[e00Kom@[e0ol000000ooL8mco0000ondBk@0>ondBk@03o`000?oi1_Wo
n@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00KooP7n0_l00009oo`3
o003o`000?ob3O;olPgb00;olPgb1_l00008on/Dj`03o`000?oe2_Gom@[e00[om@[e00?o0000ondB
kOo]4^d03oo]4^d00ol0003on@KiooT6n@0:ooT6n@;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00So
oP7n0_l00007oo`3o0Go00001_oi1_T00ol0003ojaC[on/Dj`05on/Dj`03o`000?oe2_Gom@[e00[o
m@[e00?o0000ondBkOo]4^d03oo]4^d00ol0003on@KiooT6n@07ooT6n@?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?on0OkooP7n00[ooP7n0_l00005oo`3o003o`000?oi1_Won@Ki00Won@Ki00?o0000on/Djoo[
5>/00oo[5>/00ol0003om@[eooD:m@0;ooD:m@03o`000?o]4^gokA;]00ookA;]00?o0000ooT6nOoi
1_T01Ooi1_T2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1oP0<ooh1oP;o000000?oo0?lo`000?l00000
3Ooi1_T00ol0003ojaC[on/Dj`02on/Dj`03o`000?oe2_Gom@[e00_om@[e5?l00004ooT6n@;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ooh1o_on0Oh03_on0Oh00ol0003ooP7no`00000>ooT6n@04o`000?o[5>_ojaC[o`0000kom@[e
00?o0000ooX5n_oj1OX04?oj1OX00ol0003on@Kio`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003ooP7nooh1
oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000003_oi1_T00ol0003ojaC[o`00000>ooD:m@03o`00
0?oj1O[onPGj017onPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?on0OkooP7n00cooP7n00?o
0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@0=ooT6n@03o`000?oe2_Gom@[e00Wom@[e1Ol0
000BooX5nP;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003on@KiooT6n@0<ooT6n@03o`000?oe2_Gom@[e00;om@[e1ol00004ooh1oP03o`000?oj1O[o
nPGj00oonPGj00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1
oP03o`000?oi1_Won@Ki00con@Ki1?l0000<ooh1oP03o`000?oj1O[onPGj00conPGj0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00Oo
oP7n00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00kooP7n00?o0000ooX5n_oj
1OX02Ooj1OX2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?oj1O[onPGj00KonPGj0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ooh1o_l0003ooP7n00gooP7n3?l0
000Aooh1oP?o00001_oj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000ooj1OX2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ooX5n_l000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool02_l00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00[o003o0_ooo`06o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000co003o0_ooo`0:o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00co003o0_ooo`0:o`00o`;oool01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`001Ol00?lHoooo00;o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool01Ol00?lHoooo0003o`00ooooo`3oool000Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Coool0o`00ool00?oo003o
0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool01?l00?l2oooo00Go003o
00?oool0o`00ool00?l01?l00?l2oooo00?o003o00?oool0o`00ool00?l01?l00?l2oooo00Co003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Ko003o00?oool0o`00ool00?l00ol00?l2oooo00Co003o
00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00Oo003o
00?oool0o`00ool00?l00_l00?l2oooo00Go003o00?oool0o`00ool00?l00_l00?l2oooo00Co003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l0
0?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00?o003o0_ooo`05o`00o`;oool00ol0
0?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05
o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`00
0ol00?ooool0o`00o`02oooo00So003o00Coool0o`00ool00?oo003o0_ooo`06o`00o`04oooo0?l0
0?oo003oo`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl0
0?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`09o`00o`03oooo0?l0
0?oo003o00;oool01ol00?l00oooo`3o003oo`00o`02oooo00Co003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0G
o`00o`;oool02_l00?l01?ooo`3o003ooooo0?ooo`08o`00o`04oooo0?l00?ooool0oooo00Co003o
0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l0
0?l2oooo00Ko003o0_ooo`0Ho`00o`;oool02_l00?l01?ooo`3o003ooooo0?ooo`08o`00o`04oooo
0?l00?ooool0oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o
0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l0
2?l00?l3oooo00Wo003o0oooo`05o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00
Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Ooo
o`09o`00o`;oool02_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Ooo
ool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0To`00o`;oool02_l00?l2
oooo00Oo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(450) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.995 .005 .995 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.995 .005 .995 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.994 .006 .994 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.982 .018 .982 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.993 .007 .993 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.982 .018 .982 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.974 .026 .974 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.963 .037 .963 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.989 .011 .989 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.96 .04 .96 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.909 .091 .909 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.924 .076 .924 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.85 .15 .85 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.948 .052 .948 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.988 .012 .988 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.99 .01 .99 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.98 .02 .98 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.722 .278 .722 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.959 .041 .959 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.894 .106 .894 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.89 .11 .89 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.913 .087 .913 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.94 .06 .94 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.965 .035 .965 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.995 .005 .995 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.867 .133 .867 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.936 .064 .936 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.796 .204 .796 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.961 .039 .961 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.931 .069 .931 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.885 .115 .885 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.933 .067 .933 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.768 .232 .768 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.952 .048 .952 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.885 .115 .885 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.962 .038 .962 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.812 .188 .812 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.491 .509 .491 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.575 .425 .575 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.986 .014 .986 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.985 .015 .985 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.935 .065 .935 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.844 .156 .844 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.856 .144 .856 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.537 .463 .537 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.518 .482 .518 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.433 .567 .433 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.824 .176 .824 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.846 .154 .846 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.82 .18 .82 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.743 .257 .743 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.974 .026 .974 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.648 .352 .648 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.953 .047 .953 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.906 .094 .906 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.542 .458 .542 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.467 .533 .467 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.759 .241 .759 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.189 .811 .189 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.196 .804 .196 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.258 .742 .258 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.611 .389 .611 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.596 .404 .596 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.95 .05 .95 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.213 .787 .213 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.216 .784 .216 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.853 .147 .853 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.974 .026 .974 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.994 .006 .994 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.375 .625 .375 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.453 .547 .453 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.775 .225 .775 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.994 .006 .994 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.79 .21 .79 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.419 .581 .419 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.72 .28 .72 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.154 .846 .154 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.6 .4 .6 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.427 .573 .427 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.979 .021 .979 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.05 .95 .05 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.127 .873 .127 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.922 .078 .922 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.044 .956 .044 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.032 .968 .032 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.712 .288 .712 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.942 .058 .942 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.248 .752 .248 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
0 1 0 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.067 .933 .067 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.566 .434 .566 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.131 .869 .131 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.267 .733 .267 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.961 .039 .961 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.014 .986 .014 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.149 .851 .149 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.227 .773 .227 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.869 .131 .869 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.295 .705 .295 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.364 .636 .364 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.047 .953 .047 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.009 .991 .009 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.004 .996 .004 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.485 .515 .485 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.737 .263 .737 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.849 .151 .849 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.2 .8 .2 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.139 .861 .139 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.556 .444 .556 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.98 .02 .98 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.153 .847 .153 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.153 .847 .153 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.699 .301 .699 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.126 .874 .126 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.994 .006 .994 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.021 .979 .021 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.93 .07 .93 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.979 .021 .979 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.721 .279 .721 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.785 .215 .785 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.083 .917 .083 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.929 .071 .929 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.379 .621 .379 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.477 .523 .477 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.082 .918 .082 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.292 .708 .292 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.514 .486 .514 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.959 .041 .959 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.089 .911 .089 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.117 .883 .117 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.038 .962 .038 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.912 .088 .912 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.264 .736 .264 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.976 .024 .976 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.189 .811 .189 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.169 .831 .169 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.18 .82 .18 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.765 .235 .765 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.798 .202 .798 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.712 .288 .712 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.022 .978 .022 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.284 .716 .284 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.438 .562 .438 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.692 .308 .692 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.903 .097 .903 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.97 .03 .97 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.26 .74 .26 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.521 .479 .521 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.188 .812 .188 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.887 .113 .887 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.836 .164 .836 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.705 .295 .705 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.922 .078 .922 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.974 .026 .974 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.216 .784 .216 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.348 .652 .348 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.963 .037 .963 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.206 .794 .206 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.774 .226 .774 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.56 .44 .56 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.622 .378 .622 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.412 .588 .412 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.938 .062 .938 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.918 .082 .918 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.926 .074 .926 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.945 .055 .945 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.525 .475 .525 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.979 .021 .979 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.874 .126 .874 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.444 .556 .444 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.507 .493 .507 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.994 .006 .994 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.737 .263 .737 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.667 .333 .667 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.977 .023 .977 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.894 .106 .894 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.973 .027 .973 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.543 .457 .543 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.954 .046 .954 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.858 .142 .858 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.806 .194 .806 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.779 .221 .779 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.679 .321 .679 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.995 .005 .995 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.791 .209 .791 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.99 .01 .99 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.657 .343 .657 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.992 .008 .992 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.76 .24 .76 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.993 .007 .993 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.871 .129 .871 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.929 .071 .929 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.888 .112 .888 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.933 .067 .933 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.953 .047 .953 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.879 .121 .879 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.747 .253 .747 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.867 .133 .867 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.923 .077 .923 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.954 .046 .954 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.943 .057 .943 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.952 .048 .952 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.99 .01 .99 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.897 .103 .897 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.976 .024 .976 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.981 .019 .981 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.964 .036 .964 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.906 .094 .906 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.976 .024 .976 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.952 .048 .952 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.955 .045 .955 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.967 .033 .967 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.994 .006 .994 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.993 .007 .993 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.994 .006 .994 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ood2o@?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_om0_d2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0<ood2o@03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d03_om
0_d00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003on0OhooP7n?l0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ood2oOom0_d0
3_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?on0Oh03oon0Oh00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ooP7n?oh1oP00_oh1oP00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00?on0Oh00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?om0_goo@;m00ooo@;m00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ood2oOom0_d03oom0_d00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on0OhooP7n006ooP7n003
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo@;mood2o@0@ood2o@03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?on0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000ooP7n?oh1oP02?oh1oP00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ood2oOom0_d04?om0_d<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oj1O[o0000013ooP7n00?o0000ooh1o_on0Oh02?on
0Oh9o`0000con0Oh00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?om0_goo@;m00ooo@;m
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ooX5nP03o`000?on
0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003om@[eooD:m@05ooD:m@03o`000?oh
1oSon0Oh00_on0Oh0ol00003ooH9mP03o`000?on0OkooP7n00cooP7n0ol0000>ood2o@;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ooX5n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00002oon0Oh00ol0003om@[eooD:m@06
ooD:m@03o`000?oh1oSon0Oh00[on0Oh00?o0000ooH9m_of2OH01?of2OH00ol0003ooP7nooh1oP0:
ooh1oP04o`000?od2oCom0_doo@;m0;o00002_om0_d2o`000003oo<<lol0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?on0Oko
oP7n00WooP7n00?o0000ooX5n_l000002oon0Oh00ol0003om@[eooD:m@06ooD:m@03o`000?oh1oSo
n0Oh00Won0Oh00?o0000ooH9m_of2OH01_of2OH00ol0003ooP7nooh1oP08ooh1oP03o`000?od2oCo
m0_d00Com0_d0_l00005ood2o@?o00001?oc3?<00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00SooP7n0_l00008ooX5nP03o`000?on0OkooP7n00OooP7n0_l00003ooX5
nP03o`000?on0OkooP7n00OooP7n00?o0000ooD:mOoe2_D01ooe2_D00ol0003on0OhooP7n009ooP7
n003o`000?of2OKomPWf00OomPWf00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Wom0_d0_l000000oom
0_go0000o`000007oo<<l`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ooh1o_on0Oh02_on0Oh2o`0000SooP7n00?o0000ooX5n_oj
1OX02?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00?onPGj00?o0000ooh1o_on
0Oh01oon0Oh00ol0003om@[eooD:m@08ooD:m@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooH9m_of
2OH02Oof2OH00ol0003ooP7nooh1oP03ooh1oP03o`000?od2oCom0_d00_om0_d00?o0000oo<<looc
3?<01ooc3?<00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@Kio`000005ooh1oP;o00002ooj1OX2o`0000KooP7n
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?oe2_Gom@[e00Som@[e
00?o0000ooP7n?oh1oP01_oh1oP00ol0003omPWfooH9mP0;ooH9mP05o`000?on0OkooP7nooh1o_l0
00003_od2o@00ol0003ol`ccoo<<l`08oo<<l`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003ooP7nooh1oP0;ooh1oP05o`000?oi1_Won@KiooT6nOl0
00000oon0Oh00ol0003onPGjooX5nP0:ooX5nP04o`000?oa3_7ol@kao`0000?ooP7n0_l00008ooX5
nP03o`000?on0OkooP7n00KooP7n00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on0OhooP7n005ooP7
n003o`000?of2OKomPWf00comPWf00?o0000ooh1o_l000003ood2o@00ol0003ol`ccoo<<l`08oo<<
l`03o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6n@03ooT6n@03o`000?on0Oko000000_o
nPGj0_l00004oo4>l@03o`000?on0Oko000000_onPGj00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
m@[eooD:m@09ooD:m@03o`000?oh1oSon0Oh00Con0Oh00?o0000ooH9m_of2OH03_of2OH00ol0003o
m0_doo@;m00>oo@;m003o`000?oc3??ol`cc00Wol`cc00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000kooP7n00?o0000ooT6nOoi1_T0
1?oi1_T00ol0003onPGjooX5nP09ooX5nP03o`000?oa3_7ol@ka00Gol@ka00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003ooP7nooh1oP05ooh1oP03o`000?oe2_Gom@[e00[om@[e00?o0000ooP7n?oh1oP0
0ooh1oP00ol0003omPWfooH9mP0>ooH9mP03o`000?od2oCom0_d00gom0_d00?o0000oo<<looc3?<0
2_oc3?<00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@KiooT6
n@05ooT6n@03o`000?oj1O[onPGj00OonPGj0_l00008oo4>l@03o`000?oj1O[onPGj00_onPGj00?o
0000ooh1o_on0Oh01?on0Oh00ol0003om@[eooD:m@0:ooD:m@04o`000?oh1oSon0OhooP7n0?o0000
3oof2OH00ol0003om0_doo@;m00>oo@;m003o`000?oc3??ol`cc00[ol`cc00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_on0Oh00ol0003ooP7nooh1
oP09ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooX5n_oj1OX01?oj1OX2o`0000_ol@ka1?l0
0009ooX5nP03o`000?on0OkooP7n00?ooP7n00?o0000ooD:mOoe2_D02ooe2_D01?l0003on0Oho`00
0?l00003on<Lh`;o00003?of2OH2o`00013om0_d00?o0000oo<<looc3?<02ooc3?<00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh02?on0Oh00ol0003on@Ki
ooT6n@07ooT6n@03o`000?oj1O[onPGj00?onPGj00?o0000oo4>lOoa3_402ooa3_401?l0003ofBKI
omTVfOoI9]T5o`0000GonPGj00?o0000ooh1o_on0Oh00_on0Oh00ol0003om@[eooD:m@0<ooD:m@03
o`000?oS7>?ohacS00GohacS0_l00008ooH9mP;o00000_oO8=l00ol0003om0_doo@;m00=oo@;m003
o`000?oc3??ol`cc00_ol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000[ooP7n
00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@09ooT6n@03o`000?oj1O[onPGj00;o0000
3Ooa3_400ol0003ofBKIomTVf@07omTVf@Ko00000_on0Oh4o`0000gom@[e00?o0000on<LhooS7><0
1ooS7><2o`0000GomPWf00?o0000omlPgooO8=l00ooO8=l00ol0003om0_doo@;m00<oo@;m003o`00
0?oc3??ol`cc00col`cc00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o
0000ooX5n_l000003ooa3_400ol0003ofBKIomTVf@0<omTVf@?o00001?o]4^d3o`0000Wom@[e00?o
0000on<LhooS7><02_oS7><2o`000003ooH9m_l0003o000000Oogb3O00?o0000oo@;m?od2o@02ood
2o@00ol0003ol`ccoo<<l`0<oo<<l`03o`000?on0OkooP7n00KooP7n1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?on0OkooP7n00KooP7n00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000
oo4>lOoa3_403_oa3_400ol0003ofBKIomTVf@0=omTVf@03o`000?o]4^gokA;]00KokA;]0ol00005
ooD:m@03o`000?oS7>?ohacS00gohacS00?o0000omlPgooO8=l02?oO8=l00ol0003om0_doo@;m009
oo@;m003o`000?oc3??ol`cc00gol`cc00Co0000ooh1o_on0OkooP7n1Ol00003ooH9mP03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000
ooT6nOoi1_T02ooi1_T2o`0000ool@ka00?o0000omTVfOoI9]T03OoI9]T00ol0003okA;]ondBk@0:
ondBk@?o000000?om@[eo`000?oS7><03ooS7><00ol0003ogb3OomlPg`09omlPg`03o`000?od2oCo
m0_d00Som0_d00?o0000oo<<looc3?<03_oc3?<3o`0000SomPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00[ooP7n0_l00003ooh1oP03o`000?oi1_Won@Ki00Son@Ki0ol000000ooW
6>Oo0000oo4>l@0>oo4>l@03o`000?oI9]WofBKI00gofBKI00?o0000ondBkOo]4^d03Oo]4^d00ol0
003ohacSon<Lh`0?on<Lh`03o`000?oO8=oogb3O00[ogb3O2ol0000;oo<<l`Go00003?of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02_on0Oh01Ol0003omPWfo`000?on0Oko0000
00Son@Ki0ol00005onLHi`03o`000?oa3_7ol@ka00col@ka00?o0000omTVfOoI9]T03OoI9]T00ol0
003okA;]ondBk@0=ondBk@;o00004?oS7><00ol0003ogb3OomlPg`0:omlPg`03o`000?oK9=_ofbCK
00OofbCK00?o0000oo<<looc3?<00_oc3?<7o`0000CohAkQ00?o0000ooH9m_of2OH02_of2OH00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh01?l0003omPWfooH9m_of2OH2o`00
00Gon@Ki0ol00009onLHi`;o00002ooa3_400ol0003ofBKIomTVf@0=omTVf@03o`000?o]4^gokA;]
00gokA;]00Co0000ol`cc?o<<lco00003ooS7><00ol0003ogb3OomlPg`09omlPg`03o`000?oK9=_o
fbCK00WofbCK1?l0000;on4Nh@03o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1
oP03o`000?on0OkooP7n00SooP7n00?o0000ooH9m_of2OH01?of2OH00ol0003on@Kio`000002o`00
00coiaSW00Co0000olXeb_l0003o00002Ooa3_400ol0003ofBKIomTVf@0=omTVf@03o`000?o]4^go
kA;]00gokA;]00Go0000ol`cc?o<<lcoc3?<o`00000=on<Lh`03o`000?oO8=oogb3O00[ogb3O00?o
0000om/TfooK9=/02OoK9=/00ol0003ohAkQon4Nh@0<on4Nh@03o`000?of2OKomPWf00[omPWf00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooH9m_of2OH01_of2OH0
0ol0003oiaSWonLHi`0<onLHi`03o`000?o:=L[obSG:00;obSG:0_l00007oo4>l@03o`000?oI9]Wo
fBKI00cofBKI00?o0000ondBkOo]4^d03Oo]4^d00ol0003oc3?<ol`cc003ol`cc003o`000?oS7>?o
hacS00[ohacS00?o0000omlPgooO8=l02_oO8=l00ol0003ofbCKom/Tf`09om/Tf`03o`000?oQ7^7o
hAkQ00cohAkQ00?o0000ooH9m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1
o_on0Oh01_on0Oh00ol0003omPWfooH9mP06ooH9mP03o`000?oW6>OoiaSW00_oiaSW00?o0000olXe
b_o:=LX01Oo:=LX00ol0003ol@kaoo4>l@03oo4>l@03o`000?oI9]WofBKI00gofBKI00?o0000ondB
kOo]4^d03Oo]4^d00ol0003oc3?<ol`cc004ol`cc003o`000?oS7>?ohacS00WohacS00?o0000omlP
gooO8=l02OoO8=l00ol0003ofbCKom/Tf`0:om/Tf`03o`000?oQ7^7ohAkQ00cohAkQ00?o0000ooH9
m_of2OH02oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
mPWfooH9mP07ooH9mP03o`000?oW6>OoiaSW00_oiaSW00?o0000olXeb_o:=LX01_o:=LX2o`0000?o
l@ka00?o0000omTVfOoI9]T03OoI9]T00ol0003okA;]ondBk@0<ondBk@03o`000?o<<lcoc3?<00Ko
c3?<00?o0000on<LhooS7><02?oS7><00ol0003ogb3OomlPg`09omlPg`03o`000?oK9=_ofbCK00[o
fbCK00?o0000on4NhOoQ7^403?oQ7^400ol0003omPWfooH9mP0;ooH9mP03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ooh1oP03o`00
0?on0OkooP7n00CooP7n00?o0000ooH9m_of2OH02?of2OH00ol0003oiaSWonLHi`0:onLHi`03o`00
0?o:=L[obSG:00WobSG:0_l000000ooa3_7o0000omTVf@0<omTVf@?o00003_o]4^d00ol0003oc3?<
ol`cc007ol`cc003o`000?oS7>?ohacS00OohacS00?o0000omlPgooO8=l02OoO8=l00ol0003ofbCK
om/Tf`0;om/Tf`03o`000?oQ7^7ohAkQ00cohAkQ00?o0000ooH9m_of2OH02_of2OH00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ooh1o_on0Oh00ol0
0008ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000ooH9m_of2OH02_of2OH00ol0003oiaSWonLH
i`09onLHi`03o`000?o:=L[obSG:00_obSG:00?o0000omTVfOoI9]T02_oI9]T2o`0000?o/Tfb00?o
0000ondBkOo]4^d02_o]4^d00ol0003oc3?<ol`cc009ol`cc003o`000?oS7>?ohacS00KohacS00?o
0000omlPgooO8=l02?oO8=l00ol0003ofbCKom/Tf`0<om/Tf`03o`000?oQ7^7ohAkQ00cohAkQ00?o
0000ooH9m_of2OH02_of2OH00ol0003ooP7nooh1oP04ooh1oPCo00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP04ooh1oP?o00001Oon0Oh0
0ol0003ooP7nooh1oP02ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onLHiooW6>L02?oW6>L0
0ol0003obSG:olXebP0<olXebP03o`000?oI9]WofBKI00SofBKI0_l00006ok9=/P;o00002_o]4^d0
0ol0003oc3?<ol`cc00:ol`cc003o`000?oS7>?ohacS00GohacS00?o0000omlPgooO8=l02?oO8=l0
0ol0003ofbCKom/Tf`0<om/Tf`03o`000?oQ7^7ohAkQ00cohAkQ00?o0000ooH9m_of2OH02oof2OH0
0ol0003ooP7no`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh02?on0Oh3o`0000?ooP7n00Go0000ooh1o_on0OkooP7no`00000=
ooH9mP03o`000?oW6>OoiaSW00OoiaSW00?o0000olXeb_o:=LX03_o:=LX00ol0003ofBKIomTVf@04
omTVf@?o00002_nbCK800ol0003okA;]ondBk@07ondBk@03o`000?o<<lcoc3?<00_oc3?<00?o0000
on<LhooS7><00ooS7><00ol0003ogb3OomlPg`09omlPg`03o`000?oK9=_ofbCK00cofbCK00?o0000
on4NhOoQ7^403?oQ7^400ol0003omPWfooH9mP0;ooH9mP;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0<ooh1oPCo00000_on0Oh00ol0
003omPWfooH9mP0<ooH9mP03o`000?oW6>OoiaSW00OoiaSW00?o0000olXeb_o:=LX03oo:=LX01?l0
003ofBKIomTVfOoI9]T2o`0000ko/Tfb0_l00006ondBk@03o`000?o<<lcoc3?<00goc3?<00?o0000
on<LhooS7><00_oS7><00ol0003ogb3OomlPg`08omlPg`03o`000?oK9=_ofbCK00cofbCK0ol0000=
on4Nh@03o`000?of2OKomPWf00_omPWf00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?on0Oko0000
00oomPWf00?o0000onLHiooW6>L01_oW6>L00ol0003obSG:olXebP0@olXebPCo00004_nbCK800ol0
003okA;]ondBk@03ondBk@03o`000?o<<lcoc3?<00koc3?<00Go0000on<LhooS7>?ohacSo`000005
omlPg`Oo00003?oK9=/01Ol0003o`Sg2ol8m`_o2?L;o000000cohAkQ00?o0000ooH9m_of2OH02?of
2OH3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ooh1o_on0Oh04?on0Oh3o`0000oomPWf00?o0000onLHiooW6>L01_oW6>L00ol0003obSG:olXebP0=
olXebP?o000000CoVFJIo`000?l0003o00004onbCK82o`0000;okA;]00?o0000ol`cc?o<<l`04?o<
<l`00ol0003ohacSo`000006o`0000Oo_4>l00?o0000om/TfooK9=/02?oK9=/00ol0003o`Sg2ol8m
`P03ol8m`P;o00002?oQ7^43o`0000KomPWf1?l00002oo<<l`03o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh03oon0Oh0
1?l0003onPGjo`000?oR7N83o`0000gomPWf00?o0000onLHiooW6>L01?oW6>L00ol0003obSG:olXe
bP0;olXebP?o00000onIIYT01Ol0003oT6n@o`000?mMXUgo000001Co/Tfb00?o0000ondBkOl00000
4oo<<l`00ol0003o_4>loka3_00=oka3_003o`000?oK9=_ofbCK00GofbCK0_l00008ol8m`P03o`00
0?oQ7^7ohAkQ00Go00000ooM8]d00ol0003omPWfooH9mP03o`0000Ool`cc00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003ooP7nooh1
oP0>ooh1oP04o`000?oj1O[onPGjo`0000CohQgR0ol0000:ooH9mP03o`000?oW6>OoiaSW00?oiaSW
00?o0000olXeb_o:=LX02Oo:=LX3o`0000GoVFJI00Co0000oi1_T?n@Ki3o00000_mMXUd00ol0003o
/Tfbok9=/P0Bok9=/P03o`000?o<<lcoc3?<01;oc3?<00?o0000oka3_?nl@k`03_nl@k`00ol0003o
fbCKom/Tf`03om/Tf`03o`000?o2?L;o`Sg200Wo`Sg20_l00009omdRg@;o00002_oc3?<00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?on0OkooP7n00kooP7n00Go0000ooX5n_oj1O[onPGjo`000007on8MhP;o00001oof2OH5o`0000;o
iaSW00?o0000olXeb_o:=LX01_o:=LX3o`0000SoVFJI00Co0000oi1_T?n@Ki3o00000omMXUd00ol0
003o/Tfbok9=/P0Aok9=/P03o`000?o<<lcoc3?<017oc3?<00?o0000oka3_?nl@k`04?nl@k`01Ol0
003ofbCKom/TfooK9=_o000000co`Sg200?o0000omdRgOoM8]d02?oM8]d00ol0003ol`ccoo<<l`0:
oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ooh1o_on0Oh03?on0Oh2o`0000ConPGj00?o0000on8Mh_oR7N801ooR7N83o`00
0004ooH9m_l0003o0000o`0000GodBkA0_l00006olXebP?o00002_nIIYT01Ol0003oT6n@oi1_T?n@
Ki3o000000CoGJ9M00?o0000ok9=/_nbCK804?nbCK800ol0003oc3?<ol`cc00Aol`cc003o`000?nl
@kco_4>l017o_4>l00?o0000om/Tfol000003Oo2?L800ol0003ogB;MomdRg@08omdRg@03o`000?oc
3??ol`cc00[ol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00ConPGj00?o0000
on8Mh_oR7N802_oR7N800ol0003odBkAom4^d@08om4^d@03o`000?o:=L[obSG:00?o00003OnIIYT0
1Ol0003oT6n@oi1_T?n@Ki3o000000GoGJ9M00?o0000ok9=/_nbCK803onbCK800ol0003oc3?<ol`c
c00Aol`cc003o`000?nl@kco_4>l01;o_4>l00?o0000ol8m`_o2?L803?o2?L800ol0003ogB;MomdR
g@08omdRg@03o`000?oc3??ol`cc00_ol`cc00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_ooP7n00?o0000ooX5n_oj1OX01Ooj1OX0
0ol0003ohQgRon8MhP0:on8MhP03o`000?oA;]7odBkA00WodBkA0_l0000?oiUVV@03o`000?n@Ki3o
T6n@00;oT6n@00?o0000oefRGOmMXUd01?mMXUd00ol0003o/Tfbok9=/P0=ok9=/P?o00004Oo<<l`0
0ol0003o_4>loka3_00Coka3_003o`000?o2?L;o`Sg200_o`Sg200?o0000omdRgOoM8]d02OoM8]d0
0ol0003ol`ccoo<<l`0;oo<<l`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ooh1oP;o00002?oj1OX0
0ol0003ohQgRon8MhP0:on8MhP03o`000?oA;]7odBkA00WodBkA00?o0000oiUVVOnIIYT03OnIIYT0
0ol0003oT6n@oi1_T003oi1_T003o`000?mMXUgoGJ9M00GoGJ9M00?o0000ok9=/_nbCK802_nbCK82
o`0000?oNXEj00?o0000ol`cc?o<<l`03_o<<l`00ol0003o_4>loka3_00Coka3_003o`000?o2?L;o
`Sg200_o`Sg200?o0000omdRgOoM8]d02OoM8]d00ol0003ol`ccoo<<l`0;oo<<l`03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000GooP7n00?o0000ooX5n_oj1OX01ooj1OX2o`0000_ohQgR00?o0000om4^
dOoA;]402ooA;]400ol0003oVFJIoiUVV@0<oiUVV@03o`000?n@Ki3oT6n@00?oT6n@00?o0000oefR
GOmMXUd01_mMXUd00ol0003o/Tfbok9=/P07ok9=/P;o00001_mjQGX2o`0000koc3?<00?o0000oka3
_?nl@k`04onl@k`00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oM8]gogB;M00WogB;M00?o0000oo<<
looc3?<03?oc3?<00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ooh1o_on0OkooP7no`000009ooX5
nP03o`000?oe2_Go000000_ohQgR00?o0000om4^dOoA;]402ooA;]400ol0003oVFJIoiUVV@0;oiUV
V@03o`000?n@Ki3oT6n@00CoT6n@00?o0000oefRGOmMXUd01omMXUd00ol0003o/Tfbok9=/P05ok9=
/P03o`000?mjQG[oNXEj00SoNXEj00?o0000ol`cc?o<<l`02_o<<l`00ol0003o_4>loka3_00Doka3
_003o`000?o2?L;o`Sg200_o`Sg200?o0000omdRgOoM8]d02OoM8]d00ol0003ol`ccoo<<l`0<oo<<
l`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7no`000009ooX5nP04o`000?oe2_Gom@[eo`00
00_ohQgR00?o0000om4^dOoA;]402ooA;]400ol0003oVFJIoiUVV@0;oiUVV@03o`000?n@Ki3oT6n@
00CoT6n@00?o0000oefRGOmMXUd02?mMXUd00ol0003o/Tfbok9=/P02ok9=/P;o00003?mjQGX2o`00
00[oc3?<00?o0000oka3_?nl@k`05?nl@k`00ol0003o`Sg2ol8m`P0;ol8m`P03o`000?oM8]gogB;M
00WogB;M00?o0000oo<<looc3?<03Ooc3?<00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP07ooX5nP03
o`000?oe2_Gom@[e00;om@[e00?o0000on8Mh_oR7N802?oR7N800ol0003odBkAom4^d@0<om4^d@03
o`000?nIIYWoVFJI00WoVFJI00?o0000oi1_T?n@Ki001On@Ki000ol0003oGJ9MoefRG@09oefRG@04
o`000?nbCK;o0000o`00013oNXEj0_l00008ol`cc003o`000?nl@kco_4>l01Co_4>l0ol0000;ol8m
`P03o`000?oM8]gogB;M00WogB;M00?o0000oo<<looc3?<03Ooc3?<01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oe2_Gom@[e00?om@[e00?o0000on8M
h_oR7N802?oR7N800ol0003odBkAom4^d@0;om4^d@;o00002_nIIYT00ol0003oT6n@oi1_T006oi1_
T003o`000?mMXUgoGJ9M00[oGJ9M00?o0000ogZ5N_mjQGX04_mjQGX00ol0003oc3?<ol`cc004ol`c
c003o`000?nl@kco_4>l01Go_4>l00?o0000ojQGZ?nXEjP01Ol00005ol8m`P03o`000?oM8]gogB;M
00[ogB;M00?o0000oo<<looc3?<03_oc3?<3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP04ooX5nP03
o`000?oe2_Gom@[e00Com@[e00?o0000on8Mh_oR7N801ooR7N800ol0003odBkAom4^d@0;om4^d@04
o`000?n:MH[oRWF:o`0000WoVFJI00?o0000oi1_T?n@Ki001_n@Ki000ol0003oGJ9MoefRG@0:oefR
G@03o`000?mjQG[oNXEj01?oNXEj0_l00003ol`cc0Co00005?nl@k`00ol0003oZ5NXojQGZ006ojQG
Z0Co000000?o`Sg2o`000?oM8]d02ooM8]d00ol0003ol`ccoo<<l`0>oo<<l`03o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003onPGjooX5nP03ooX5nP03o`000?oe2_Gom@[e00Gom@[e00?o0000on8Mh_oR
7N801ooR7N800ol0003odBkAom4^d@09om4^d@;o00001?n:MHX00ol0003oVFJIoiUVV@05oiUVV@03
o`000?n@Ki3oT6n@00OoT6n@00?o0000oefRGOmMXUd02_mMXUd00ol0003oNXEjogZ5NP0EogZ5NP03
o`000?o<<lco000000CoSg2?0ol0000@oka3_003o`000?nXEjSoZ5NX00_oZ5NX0_l0000<omdRg@03
o`000?oc3??ol`cc00col`cc0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003om@[e
ooD:m@06ooD:m@03o`000?oR7N;ohQgR00OohQgR00?o0000om4^dOoA;]402?oA;]400ol0003oRWF:
ohYeRP05ohYeRP03o`000?nIIYWoVFJI00CoVFJI00?o0000oi1_T?n@Ki001on@Ki000ol0003oGJ9M
oefRG@0:oefRG@03o`000?mjQG[oNXEj01KoNXEj00?o0000ohm`Son?L8l01_n?L8l3o`0000co_4>l
00?o0000ojQGZ?nXEjP03OnXEjP00ol0003ogB;MomdRg@09omdRg@Go00002Ooc3?<2o`000003ooL8
mol0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ooX5n_l0003om@[e00Wom@[e00?o0000on8Mh_oR7N801_oR
7N800ol0003odBkAom4^d@07om4^d@03o`000?n:MH[oRWF:00OoRWF:00?o0000oiUVVOnIIYT00_nI
IYT00ol0003oT6n@oi1_T008oi1_T003o`000?mMXUgoGJ9M00WoGJ9M00?o0000ogZ5N_mjQGX05omj
QGX00ol0003oSg2?ohm`S`09ohm`S`?o00002Onl@k`00ol0003oZ5NXojQGZ00>ojQGZ0Ko00001?oM
8]d00ol0003oiaSWonLHi`03onLHi`Go00000_oc3?<2o`0000Com`Sg00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oe2_Gom@[eooD:mOl000002ooe2_D00ol0003ohQgRon8MhP06on8MhP03o`000?oA
;]7odBkA00GodBkA0_l0000;ohYeRP04o`000?nIIYWoVFJIo`0000_oT6n@00?o0000oefRGOmMXUd0
2OmMXUd00ol0003oNXEjogZ5NP0FogZ5NP03o`000?n?L8ooSg2?00goSg2?0ol00005oka3_003o`00
0?nXEjSoZ5NX00ooZ5NX00?o0000okm0_ono@;l00ono@;l4o`0000_oiaSW0_l00006ooL8m`03o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003om@[eooD:m@02ooD:m@ko00001_oR7N800ol0003odBkAom4^
d@05om4^d@03o`000?n:MH[oRWF:00coRWF:00?o0000oiUVVOl000002on@Ki000ol0003oGJ9MoefR
G@07oefRG@?o00006?mjQGX00ol0003oSg2?ohm`S`0@ohm`S`?o000000?o_4>lo`000?nXEjP04?nX
EjP00ol0003o_d2ookm0_`07okm0_`03o`000?oW6>OoiaSW00[oiaSW00?o0000ooL8moog2?L01Oog
2?L00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005ooD:m@03o`000?oT6nCoi1_T00_oi1_T0_l00004
on8MhP03o`000?oA;]7odBkA00?odBkA0_l0000@ohYeRP03o`000?n@Ki3oT6n@00[oT6n@00?o0000
oefRGOmMXUd00omMXUd4o`0000;o<l`c00?o0000ogZ5N_mjQGX05OmjQGX00ol0003oSg2?ohm`S`0D
ohm`S`03o`000?nXEjSoZ5NX013oZ5NX00?o0000okm0_ono@;l01ono@;l00ol0003oiaSWonLHi`0:
onLHi`03o`000?og2?Oom`Sg00Gom`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oe2_Gom@[e
00Gom@[e00?o0000on@Ki?oT6n@03OoT6n@6o`0000?odBkA00?o0000ohYeR_n:MHX04?n:MHX00ol0
003oT6n@oi1_T00:oi1_T003o`000?mMXUgo000000?o00001olcc3<00ol0003oNXEjogZ5NP0DogZ5
NP03o`000?n?L8ooSg2?01CoSg2?00?o0000ojQGZ?nXEjP03onXEjP00ol0003o_d2ookm0_`08okm0
_`03o`000?oW6>OoiaSW00[oiaSW00?o0000ooL8moog2?L01Oog2?L00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooD:mOoe2_D01_oe2_D00ol0003oi1_Ton@Ki00=on@Ki003o`000?o4>lCoa3_400?o
a3_400?o0000om4^dOl000004on:MHX4o`0000WoT6n@0_l0000<oc?<<`03o`000?mjQG[oNXEj01?o
NXEj00?o0000ohm`Son?L8l05On?L8l00ol0003oZ5NXojQGZ00>ojQGZ003o`000?no@;oo_d2o00So
_d2o00?o0000onLHiooW6>L02OoW6>L00ol0003om`SgooL8m`07ooL8m`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oe2_Gom@[e00Som@[e00?o0000on@Ki?oT6n@02ooT6n@00ol0003oa3_4ol@ka005ol@ka003o`00
0?n:MH[oRWF:01;oRWF:00Co0000oco0?olo`3oo?l0o1Ol00003oi1_T003o`000?lcc3?o<l`c00go
<l`c0ol0000@ogZ5NP;o00006?n?L8l00ol0003oZ5NXojQGZ00=ojQGZ003o`000?no@;oo_d2o00Wo
_d2o00?o0000onLHiooW6>L02OoW6>L00ol0003om`SgooL8m`07ooL8m`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ooh1o_on0Oh0
0_on0Oh6o`0000_om@[e00?o0000on@Ki?oT6n@02_oT6n@00ol0003oa3_4ol@ka006ol@ka003o`00
0?n:MH[oRWF:017oRWF:00?o0000oco0?olo`3l01olo`3l3o`00013o<l`c00?o0000oaGZ5OlEjQD0
1Ol00009ogZ5NP;o000000?o<<l`o`000?n?L8l05on?L8l00ol0003oZ5NXojQGZ00=ojQGZ003o`00
0?no@;oo_d2o00Wo_d2o00?o0000onLHiooW6>L02?oW6>L2o`0000[om`Sg00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003ooP7nooh1
oP03ooh1oP03o`000?ok1?_on`Ck00;on`Ck00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oi1_Ton@K
i00:on@Ki003o`000?o4>lCoa3_400Ooa3_400?o0000ohYeR_n:MHX03on:MHX00ol0003o?l0ooco0
?`0:oco0?`03o`000?lcc3?o<l`c00go<l`c00?o0000oaGZ5OlEjQD01_lEjQD4o`0000CoNXEj00?o
0000oc3?<?l`cc000_l`cc000ol0003oSg2?ohm`S`0Fohm`S`03o`000?nXEjSoZ5NX00_oZ5NX00?o
0000okm0_ono@;l02ono@;l00ol0003oiaSWonLHi`06onLHi`03o`000?od2oCo000000[om`Sg00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooD:mOoe2_D02?oe2_D=
o`0000[oa3_400?o0000ohYeR_n:MHX03on:MHX00ol0003o?l0ooco0?`0;oco0?`03o`000?lcc3?o
<l`c00co<l`c00?o0000oaGZ5OlEjQD02_lEjQD4o`0000Go<<l`00?o0000ohm`Son?L8l05_n?L8l0
0ol0003oZ5NXojQGZ00:ojQGZ003o`000?no@;oo_d2o00co_d2o00?o0000onLHiooW6>L01?oW6>L2
o`0000?om0_d00?o0000ooL8moog2?L02?og2?L00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4
nook1?/00ook1?/00ol0003om@[eooD:m@07ooD:m@03o`000?oS7>?ohacS00WohacS00?o0000ol@k
a?o4>l@02Oo4>l@00ol0003oRWF:ohYeRP0=ohYeRP03o`000?lo`3oo?l0o00co?l0o00?o0000oc?<
<olcc3<03?lcc3<00ol0003o5NXEoaGZ5@0;oaGZ5@03o`000?l9mPWo000000Ko<<l`00?o0000ohm`
Son?L8l05_n?L8l00ol0003oZ5NXojQGZ009ojQGZ003o`000?no@;oo_d2o00co_d2o00?o0000onLH
iooW6>L00ooW6>L00ol0003om0_doo@;m003oo@;m003o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Con`Ck00?o0000ooD:mOoe2_D01_oe2_D00ol0003o
hacSon<Lh`08on<Lh`03o`000?o4>lCoa3_400_oa3_400?o0000ohYeR_n:MHX02?n:MHX4o`0000oo
?l0o00?o0000oc?<<olcc3<02olcc3<00ol0003o5NXEoaGZ5@0;oaGZ5@04o`000?l9mPWo2OH9o`00
00Oo<<l`00?o0000ohm`Son?L8l05On?L8l00ol0003oZ5NXojQGZ008ojQGZ003o`000?no@;oo_d2o
00go_d2o00?o0000onLHiooW6>L00_oW6>L00ol0003om0_doo@;m005oo@;m003o`000?og2?Oom`Sg
00Oom`Sg00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooD:mOoe
2_D01Ooe2_D00ol0003ohacSon<Lh`08on<Lh`03o`000?o4>lCoa3_400_oa3_400?o0000ohYeR_n:
MHX00on:MHX5o`0000?o@[e200?o0000oco0?olo`3l03_lo`3l00ol0003o<l`coc?<<`0:oc?<<`03
o`000?lEjQGo5NXE00[o5NXE00Go0000o`Wf2Ol9mPWo2OH9o`000007oc3?<003o`000?n?L8ooSg2?
01GoSg2?00?o0000ojQGZ?nXEjP02?nXEjP00ol0003o_d2ookm0_`0=okm0_`03o`000?oW6>OoiaSW
00;o00002?od2o@00ol0003om`SgooL8m`08ooL8m`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?oe2_Gom@[e00Go
m@[e00?o0000on<LhooS7><02?oS7><00ol0003oa3_4ol@ka00<ol@ka0Go00002Om2_D800ol0003o
?l0ooco0?`0<oco0?`;o00003?lcc3<00ol0003o5NXEoaGZ5@0:oaGZ5@05o`000?l9mPWo2OH9o`Wf
2Ol000002?l`cc000ol0003oSg2?ohm`S`0Dohm`S`?o00001onXEjP00ol0003o_d2ookm0_`0>okm0
_`03o`000?oW6>Oo000000_om0_d00?o0000ooL8moog2?L01_og2?L00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00So
oP7n00?o0000oo/4nook1?/01Ook1?/00ol0003om@[eooD:m@04ooD:m@03o`000?oS7>?ohacS00Oo
hacS00?o0000ol@ka?o4>l@03?o4>l@01?l0003oRGJ9ohUfROl0000;od:m@P03o`000?lo`3oo?l0o
00_o?l0o00Co0000o`?l0ol3o0?o00002_lcc3<00ol0003o5NXEoaGZ5@0:oaGZ5@03o`000?l9mPWo
2OH900;o2OH900?o0000oc3?<?l`cc001_l`cc000ol0003oSg2?ohm`S`0Aohm`S`?o00000omaSW40
0ol0003oZ5NXojQGZ004ojQGZ003o`000?no@;oo_d2o00go_d2o1?l0000;oo@;m003o`000?og2?Oo
m`Sg00Gom`Sg00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00Co0000ooD:
mOoe2_Gom@[e1?l00008on<Lh`03o`000?o4>lCoa3_400_oa3_400?o0000ohUfROn9MXT00_n9MXT0
0ol0003o@[e2od:m@P08od:m@P03o`000?lo`3oo?l0o00[o?l0o00?o0000o`?l0ol3o0<00_l3o0<0
0ol0003o<l`coc?<<`03oc?<<`Go00002olEjQD00ol0003o2OH9o`Wf2@03o`Wf2@03o`000?l`cc3o
<<l`00Oo<<l`00?o0000ohm`Son?L8l03_n?L8l2o`0000OoLHia00?o0000ojQGZ?nXEjP00_nXEjP0
0ol0003o_d2ookm0_`0=okm0_`03o`000?oU6^GoiA[U00;oiA[U00?o0000oo@;m?od2o@02Ood2o@0
0ol0003om`SgooL8m`03ooL8m`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`07oo/4
n`?o00001?oX5nP00ol0003ohacSon<Lh`05on<Lh`03o`000?o4>lCoa3_400[oa3_400?o0000ohUf
ROn9MXT00on9MXT00ol0003o@[e2od:m@P09od:m@P03o`000?lo`3oo?l0o00So?l0o00?o0000o`?l
0ol3o0<01?l3o0<5o`0000Co0?l000?o0000oaGZ5OlEjQD02OlEjQD00ol0003o2OH9o`Wf2@03o`Wf
2@03o`000?l`cc3o<<l`00So<<l`00?o0000ohm`Son?L8l02_n?L8l3o`0000[oLHia00Go0000ojQG
Z?nXEjSoZ5NXo`00000>okm0_`03o`000?oU6^GoiA[U00CoiA[U0_l00009oo@;m003o`000?og2?Oo
m`Sg00;om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o0000onPG
j?oX5nP01OoX5nP00ol0003ohacSon<Lh`03on<Lh`03o`000?o4>lCoa3_400[oa3_400?o0000ohUf
ROn9MXT01?n9MXT00ol0003o@[e2od:m@P09od:m@P03o`000?lo`3oo?l0o00Oo?l0o00?o0000o`?l
0ol3o0<01Ol3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lEjQGo5NXE00Oo5NXE00?o0000o`Wf
2Ol9mPT01?l9mPT00ol0003o<<l`oc3?<008oc3?<003o`000?n?L8ooSg2?00SoSg2?0_l0000>og6>
L@Co00003?no@;l2o`0000WoiA[U00?o0000oo@;m?od2o@01ood2o@01?l0003om`SgooL8mol0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?on0OkooP7n
00[ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oj1OXonPGj007onPGj0;o00000ooS7><00ol0
003oa3_4ol@ka009ol@ka003o`000?n9MXWoRGJ900KoRGJ900?o0000od:m@_m2_D802Om2_D800ol0
003o?l0ooco0?`05oco0?`03o`000?l3o0?o0o`300Ko0o`300?o0000o`3o0?l0o`002?l0o`000ol0
003o5NXEoaGZ5@06oaGZ5@03o`000?l9mPWo2OH900Co2OH900?o0000oc3?<?l`cc002Ol`cc04o`00
00?oSg2?0ol0000@og6>L@05o`000?o:=L[obSG:olXeb_l000002_no@;l00ol0003oiA[UonDJi@0:
onDJi@Ko00000ood2o@00ol0003om`Sgo`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/01?ok1?/00ol0
003oj1OXonPGj00:onPGj004o`000?oS7>?ohacSo`0000[oa3_400?o0000ohUfROn9MXT01on9MXT0
0ol0003o@[e2od:m@P09od:m@P03o`000?lo`3oo?l0o00Co?l0o00?o0000o`?l0ol3o0<01ol3o0<0
0ol0003o0?l0o`3o0008o`3o00;o00001_lEjQD00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l`cc3o
<<l`00Wo<<l`00Co0000ocC;=?ldbcCo=</d0ol0000Bog6>L@03o`000?o:=L[obSG:00?obSG:0_l0
0006okm0_`;o00003OoU6^D00ol0003on@KiooT6n@03ooT6n@Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[ooP7n00?o0000oo/4nook1?/00ook1?/0
0ol0003oj1OXonPGj00<onPGj0;o00002_o4>l@00ol0003oRGJ9ohUfR@08ohUfR@03o`000?m2_D;o
@[e200[o@[e200?o0000oco0?olo`3l00_lo`3l00ol0003o0o`3o`?l0`08o`?l0`03o`000?l0o`3o
0?l000Ko0?l00_l00002o`3o0003o`000?lEjQGo5NXE00;o5NXE00?o0000o`Wf2Ol9mPT01_l9mPT0
0ol0003o<<l`oc3?<008oc3?<003o`000?ldbcCo=</d00Co=</d00?o0000og6>LOmaSW403omaSW40
0ol0003obSG:olXebP06olXebP;o00000ono@;l00ol0003oiA[UonDJi@0=onDJi@03o`000?oi1_Wo
n@Ki00Oon@Ki0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?on0OkooP7n00?o00001oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?oX5nSoj1OX
00koj1OX00?o0000ol@ka?o4>l@01oo4>l@00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?m2_D;o@[e2
00Wo@[e200Go0000oco0?olo`3oo?l0oo`00000;o`?l0`03o`000?l0o`3o0?l000Co0?l00_l00005
o`3o0005o`000?lEjQGo5NXEoaGZ5Ol000002?l9mPT00ol0003o<<l`oc3?<008oc3?<003o`000?ld
bcCo=</d00Go=</d00?o0000og6>LOmaSW403_maSW400ol0003obSG:olXebP08olXebP03o`000?no
@;oo000000ooiA[U00?o0000ooT6nOoi1_T02?oi1_T01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00CooP7n0ol0
0005ooh1oP04o`000?ok1?_on`Cko`00017oj1OX00?o0000ol@ka?o4>l@01_o4>l@00ol0003oRGJ9
ohUfR@0;ohUfR@03o`000?m2_D;o@[e200Wo@[e200Co0000oco0?olo`3oo00003?l3o0<00ol0003o
0?l0o`3o0002o`3o00;o00002?l0o`000ol0003o5NXEo`000009o`Wf2@03o`000?l`cc3o<<l`00So
<<l`00?o0000ocC;=?ldbc@01Oldbc@00ol0003oLHiaog6>L@0=og6>L@03o`000?o:=L[obSG:00[o
bSG:00?o0000onDJiOoU6^D03_oU6^D00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003ooP7nooh1oP08ooh1oP?o000000?ooP7no`000?l000000ol0000BonPGj003o`00
0?o4>lCoa3_400Coa3_400?o0000ohUfROn9MXT03?n9MXT00ol0003o@[e2od:m@P0:od:m@P?o0000
3?l3o0<00ol0003o0?l0o`3o0002o`0000_o0?l000?o0000o`Wf2Ol9mPT02?l9mPT00ol0003o<<l`
oc3?<007oc3?<003o`000?ldbcCo=</d00Oo=</d00?o0000og6>LOmaSW403?maSW400ol0003obSG:
olXebP0;olXebP;o00003_oU6^D00ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003oj1OXonPGj00?onPGj0?o00000oo4
>l@00ol0003oRGJ9ohUfR@0>ohUfR@03o`000?m2_D;o@[e200So@[e200Co0000o`_d2ol;m0_o2o@;
0_l0000:o`?l0`?o00003Ol0o`000ol0003o2OH9o`Wf2@08o`Wf2@03o`000?l`cc3o<<l`00Oo<<l`
00?o0000ocC;=?ldbc@01oldbc@00ol0003oLHiaog6>L@0;og6>L@03o`000?o:=L[obSG:00cobSG:
00?o0000oo<<lol000000_l0000:onDJi@03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@04ooT6n@03o`000?oX5nSoj1OX00coj1OX0_l0
0003omTVf@03o`000?o4>lCo0000017oRGJ900?o0000od:m@_m2_D801om2_D800ol0003o2o@;o`_d
2`04o`_d2`;o00002?l3o0<00ol0003o0?l0o`3o000>o`3o00;o00002?l9mPT00ol0003o<<l`oc3?
<006oc3?<003o`000?ldbcCo=</d00Wo=</d00?o0000og6>LOmaSW402OmaSW400ol0003obSG:olXe
bP0=olXebP03o`000?oc3??ol`cc00;ol`cc0ol00007onDJi@03o`000?oi1_Won@Ki00Oon@Ki00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?oX5nSo
j1OX00Woj1OX0_l00006omTVf@03o`000?n9MXWoRGJ9013oRGJ900?o0000od:m@_m2_D801_m2_D80
0ol0003o2o@;o`_d2`07o`_d2`03o`000?l3o0?o0o`300Co0o`30ol0000>o`3o0003o`000?l0o`3o
0?l000?o00001Ol9mPT00ol0003o<<l`oc3?<006oc3?<003o`000?ldbcCo=</d00[o=</d00?o0000
og6>LOmaSW402?maSW400ol0003obSG:olXebP0=olXebP03o`000?oc3??ol`cc00Gol`cc0ol00004
onDJi@03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on@KiooT6n@06ooT6n@03o`000?oX5nSoj1OX00Goj1OX0ol00008omTVf@03o`000?n9MXWoRGJ9
017oRGJ900Co0000od:m@_m2_D;o@[e21?l0000;o`_d2`;o000000Co0o`3o`000?l0003o00000ol0
o`02o`0000_o0?l000?o0000o`3o0?l0o`001?l0o`02o`0000?o2OH900?o0000oc3?<?l`cc001_l`
cc000ol0003o=</docC;=00:ocC;=003o`000?maSW7oLHia00OoLHia00?o0000olXeb_o:=LX03_o:
=LX00ol0003ol`ccoo<<l`08oo<<l`Co00002_oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003on@KiooT6n@07ooT6n@03o`000?oX5nSoj1OX00;oj1OX0_l0000<omTVf@03o`000?n9MXWo
RGJ9013oRGJ91?l00003ocK9=P03o`000?l;m0_o2o@;00_o2o@;00?o0000o`3o0?l0o`001_l0o`00
0ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Oo0?l03?l0000>ocC;=003o`000?maSW7o
LHia00KoLHia00?o0000olXeb_o:=LX03_o:=LX00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oi1_Wo
n@Ki00Oon@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00Won@Ki00Co0000onPG
j?l0003o00003_oI9]T00ol0003oRGJ9ohUfR@0?ohUfR@03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000
o`_d2ol;m0/02_l;m0/00ol0003o0?l0o`3o0007o`3o00;o00001_l0o`000ol0003o0?l0o`3o0008
o`3o0003o`000?l[e2_o:m@[00So:m@[00?o0000ocC;=?ldbc@03?ldbc@00ol0003oLHiaog6>L@05
og6>L@03o`000?o:=L[obSG:00oobSG:0_l0000=oo<<l`03o`000?oi1_Won@Ki00Kon@Ki00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00[on@Ki00?o0000omTVfOoI9]T03_oI9]T00ol0
003oRGJ9ohUfR@0>ohUfR@03o`000?lfbCKo=/Tf00Oo=/Tf00?o0000o`_d2ol;m0/02_l;m0/00ol0
003o0?l0o`3o0009o`3o00;o00000ol0o`000ol0003o0?l0o`3o0009o`3o0003o`000?l[e2_o:m@[
00Wo:m@[00?o0000ocC;=?ldbc@02_ldbc@4o`0000CoLHia00?o0000olXeb_o:=LX04?o:=LX01?l0
003ol@kao`000?l0000<oo<<l`03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?oi1_Won@Ki00[on@Ki00?o0000omTVfOoI9]T03ooI9]T@o`0000[o=/Tf00?o0000o`_d
2ol;m0/02Ol;m0/00ol0003o0?l0o`00000<o`3o0005o`000?l0o`3o0000o`3o0?l000002_l0o`00
0ol0003o:m@[ob_D:`09ob_D:`03o`000?ldbcCo=</d00Oo=</d0ol00004ofVFJ@?o000000?oLHia
o`000?o:=LX04Oo:=LX01?l0003ol@kaoo4>lOoa3_42o`0000_ol`cc00?o0000ooT6nOoi1_T00ooi
1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003ofBKIomTVf@0?
omTVf@03o`000?n4NhCoQ7^400coQ7^400?o0000ocK9=_lfbCH02OlfbCH00ol0003o2o@;o`_d2`07
o`_d2`04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`3o0003o`00
0?l[e2_o:m@[00[o:m@[00?o0000ocC;=?ldbc@00oldbc@3o`0000[oJIIY00?o0000olXeb_o:=LX0
4?o:=LX00ol0003ol@kaoo4>l@04oo4>l@;o00002_oc3?<00ol0003on@KiooT6n@04o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ooh1o_on0Oh02_on
0Oh3o`0000con@Ki00?o0000omTVfOoI9]T03ooI9]T00ol0003oQ7^4ohAkQ00<ohAkQ003o`000?lf
bCKo=/Tf00Wo=/Tf00?o0000o`_d2ol;m0/01_l;m0/00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0006o`3o0003o`000?l[
e2_o:m@[00[o:m@[00?o0000ocC;=?ldbc@00ol0000=ofVFJ@03o`000?o:=L[obSG:013obSG:00?o
0000oo4>lOoa3_401_oa3_42o`0000Wol`cc0_l00004ood2o@03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ooh1o_on0Oh01Oon0Oh4
o`0000;ooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003ofBKIomTVf@0=omTVf@?o00003on4Nh@0
0ol0003o=/TfocK9=P08ocK9=P03o`000?l;m0_o2o@;00Go2o@;00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`3o0?l0o`001Ol0o`00
0ol0003o:m@[ob_D:`0;ob_D:`;o00004OmYUVT00ol0003obSG:olXebP0?olXebP03o`000?oa3_7o
l@ka00Sol@ka0_l00007oo<<l`03o`000?om0_goo@;m00Coo@;m00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003ooP7nooh1oP04o`00
00OooP7n00?o0000ooT6nOoi1_T02?oi1_T00ol0003ofBKIomTVf@09omTVf@Go00000_nhAkP00ol0
003oQ7^4ohAkQ00=ohAkQ003o`000?lfbCKo=/Tf00Wo=/Tf00?o0000o`_d2ol;m0/01?l;m0/00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o0?l0o`3o0004o`3o0003o`000?l[e2_o:m@[00_o:m@[00?o0000ofVFJOmYUVT04?mYUVT00ol0
003obSG:olXebP0?olXebP03o`000?oa3_7ol@ka00[ol@ka0_l00004oo<<l`03o`000?om0_goo@;m
00Koo@;m0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?on0Oh00ol0003on@KiooT6n@07ooT6n@03o`000?oI9]WofBKI00CofBKI1Ol00007okQ7^003
o`000?n4NhCoQ7^400goQ7^400?o0000ocK9=_lfbCH02OlfbCH00ol0003o2o@;o`_d2`03o`_d2`03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l0o`3o0?l000?o0?l000?o0000ob_D:ol[e2/02ol[e2/00ol0003oJIIYofVFJ@0@ofVFJ@03
o`000?o:=L[obSG:00oobSG:00?o0000oo4>lOoa3_403?oa3_42o`000003oo<<lol0003oo@;m00[o
o@;m00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o0000omTVfOl00000
1?l0000<okQ7^003o`000?n4NhCoQ7^400koQ7^400?o0000ocK9=_lfbCH02?lfbCH00ol0003o2o@;
o`_d2`02o`_d2`03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l0o`3o0?l000;o0?l000?o0000ob_D:ol[e2/02ol[e2/00ol0003oJIIY
ofVFJ@0AofVFJ@03o`000?o:=L[obSG:00gobSG:00?o0000oo4>lOoa3_403ooa3_400ol0003oo@;m
ood2o@0;ood2o@;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on
0OkooP7n00cooP7n00?o0000ooT6nOoi1_T01Ooi1_T3o`00017o^4Nh00?o0000ohAkQ?n4Nh@03_n4
Nh@00ol0003o=/TfocK9=P09ocK9=P04o`000?l;m0_o2o@;o`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l0o`3o0?l0o`3o0?l000003Ol[e2/00ol0003o
JIIYofVFJ@0AofVFJ@?o00003Oo:=LX00ol0003ol@kaoo4>l@0?oo4>l@03o`000?om0_goo@;m00go
o@;m00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
oP7nooh1oP0=ooh1oP?o00000_oi1_T2o`0000;ok1?/00?o0000okQ7^?nhAkP03onhAkP00ol0003o
Q7^4ohAkQ00>ohAkQ003o`000?lfbCKo=/Tf00So=/Tf1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o0?l0o`3o0?l0000=ob_D:`03o`000?mYUVWoJIIY
017oJIIY00?o0000oh]dRon;M8/00ol0000:olXebPCo00003Ooa3_400ol0003oo@;mood2o@0?ood2
o@03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?on0OkooP7n00co
oP7n00Co0000oo/4nook1?_on`Ck0_l00005on`Ck003o`000?nhAkSo^4Nh00ko^4Nh00?o0000ohAk
Q?n4Nh@03_n4Nh@00ol0003o=/TfocK9=P07ocK9=P03o`000?l<l`co3?<<00?o3?<<00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<ob_D
:`03o`000?mYUVWoJIIY013oJIIY00?o0000oh]dRon;M8/01?n;M8/3o`0000KobSG:00?o0000on`C
k?o/4n`00_o/4n`5o`0000Sol@ka00?o0000ood2oOom0_d04?om0_d00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?o
n`Ck00?o0000on`Ck?o/4n`01?o/4n`00ol0003o^4NhokQ7^00=okQ7^003o`000?n4NhCoQ7^400oo
Q7^400?o0000ocK9=_lfbCH01?lfbCH2o`0000Oo3?<<00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
0?l000?o0000ob_D:ol[e2/02?l[e2/3o`00013oJIIY00?o0000oh]dRon;M8/02?n;M8/3o`0000;o
bSG:00?o0000on`Ck?o/4n`02?o/4n`5o`0000?ol@ka00?o0000ood2oOom0_d04?om0_d00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003ooP7nooh1oP0:ooh1oP03o`00
0?ok1?_on`Ck00Con`Ck00?o0000on`Ck?o/4n`01Oo/4n`00ol0003o^4NhokQ7^00;okQ7^0Co0000
3on4Nh@00ol0003o=/TfocK9=P03ocK9=P03o`000?l<l`co3?<<00So3?<<00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o00;o0000
1_l[e2/2o`0000?o<<l`00?o0000ofVFJOmYUVT03?mYUVT00ol0003oRgB;oh]dR`0<oh]dR`;o0000
4?o/4n`3o`0001?oo@;m00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?o/4ncok1?/00Kok1?/00?o
0000okQ7^?nhAkP02OnhAkP00ol0003obcC;o`000002ogf2O@?o00003?n4Nh@01?l0003o=/TfocK9
=_lfbCH2o`0000co3?<<00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o:m@[ob_D:`02ob_D:`03o`00
0?l`cc3o<<l`00Co<<l`0_l0000;ofVFJ@03o`000?n;M8_oRgB;00coRgB;00?o0000olLhaol00000
4_o/4n`00ol0003oo@;mood2o@0@ood2o@;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?o/4ncok1?/00Ook1?/00?o
0000okQ7^?nhAkP01_nhAkP2o`0000;obcC;00?o0000ogf2OOmmPWd00ommPWd3o`0000[oQ7^400?o
0000ocK9=_l000003ol<l``01?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`3o0?l0o`002?l0o`001?l0003o:m@[o`000?l00009oc3?<003o`000?mYUVWoJIIY00Oo
JIIY00?o0000oh]dRon;M8/03?n;M8/01?l0003oacS7olLhaol0000Con`Ck003o`000?om0_goo@;m
00coo@;m0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
oP7n00?o0000oo/4nook1?/01ook1?/00ol0003ok1?/on`Ck008on`Ck003o`000?nhAkSo^4Nh00Co
^4Nh00?o0000ol/dboo;=</00oo;=</00ol0003oOH9mogf2O@05ogf2O@?o00001_n4Nh@4o`00013o
3?<<00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Wo
0?l000?o0000oc3?<?l`cc002_l`cc02o`0000KoJIIY00?o0000oh]dRon;M8/03?n;M8/00ol0003o
acS7olLha`02olLha`03o`000?o/4ncok1?/00ook1?/00?o0000ooT6nOl000002oom0_d2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?o/4ncok1?/00Wok1?/00Co0000okQ7^?nhAkSo
^4Nh0_l00006ol/db`03o`000?mmPWgoOH9m00SoOH9m0ol000000on4NhCo0000o`000004ocO8=`03
o`000?l<l`co3?<<00go3?<<00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l0o`3o0?l000Wo0?l000?o0000oc3?<?l`cc003?l`cc000ol0003oJIIYofVFJ@03o`0000ko
RgB;00?o0000olLhaoo7><L00oo7><L00ol0003ok1?/on`Ck00>on`Ck005o`000?oi1_Won@KiooT6
nOl000002?om0_d2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?o/4ncok1?/00[o
k1?/00?o0000okQ7^?l000002?o;=</00ol0003oOH9mogf2O@0;ogf2O@03o`000?lgb3Oo=lPg00Go
=lPg00?o0000o`cc3?l<l``03?l<l``00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`3o0?l0o`002?l0o`02o`0000oo<<l`0_l00002oh5nP@03o`000?n;M8_oRgB;00_o
RgB;00?o0000olLhaoo7><L01?o7><L00ol0003ok1?/on`Ck00=on`Ck003o`000?oi1_Won@Ki00?o
n@Ki00?o0000ood2oOom0_d00_om0_d3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;oo/4n`03o`000?o/4ncok1?/00_ok1?/00?o0000ol/dboo;=</0
1oo;=</00ol0003oOH9mogf2O@0;ogf2O@03o`000?lgb3Oo=lPg00Ko=lPg00?o0000o`cc3?l<l``0
2ol<l``2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0007o`3o0004o`00
0?l5nPGo1OX5o`0000ko<<l`00?o0000oh5nPOn1OX400_n1OX400ol0003oRgB;oh]dR`09oh]dR`03
o`000?o7><OoacS700KoacS700?o0000on`Ck?o/4n`02oo/4n`00ol0003on@KiooT6n@05ooT6n@04
o`000?om0_go0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ooh1o_on0Oh00_on0Oh3o`0000Son`Ck00?o0000on`Ck?o/4n`02_o/4n`2o`0000Wo
bcC;00?o0000ogf2OOmmPWd02ommPWd00ol0003o=lPgocO8=`07ocO8=`03o`000?l<l`co3?<<00Wo
3?<<00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000Go0000o`Gj1Ol5nPGo1OX5o`00000>oc3?<003o`000?n1OX7oPGj100?oPGj100?o0000
oh]dRon;M8/01on;M8/00ol0003oacS7olLha`07olLha`03o`000?o/4ncok1?/00[ok1?/00?o0000
ooT6nOoi1_T01ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?on0OkooP7n00GooP7n0_l00006oo/4n`03o`000?o/4ncok1?/
00Wok1?/00Co0000onTFjOoY5^Wo00002Oo;=</00ol0003oOH9mogf2O@09ogf2O@03o`000?lgb3Oo
=lPg00Wo=lPg00?o0000o`cc3?l<l``01ol<l``00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l5nPGo
1OX500?o1OX500?o0000oc3?<?l`cc002_l`cc000ol0003oPGj1oh5nP@05oh5nP@03o`000?n;M8_o
RgB;00GoRgB;00?o0000olLhaoo7><L02?o7><L00ol0003ok1?/on`Ck009on`Ck003o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003ooP7nooh1oP07ooh1oP?o00000_ok1?/3o`0000Wok1?/00?o0000onTF
jOoY5^T00_oY5^T00ol0003obcC;ol/db`06ol/db`03o`000?mmPWgoOH9m00WoOH9m00?o0000ocO8
=olgb3L02_lgb3L00ol0003o3?<<o`cc3005o`cc3003o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o<<l`oc3?<00:oc3?<003o`000?n1OX7oPGj100KoPGj100?o0000oh]d
Ron;M8/00on;M8/00ol0003oacS7olLha`09olLha`03o`000?o/4ncok1?/00Sok1?/00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?on0OkooP7n00[ooP7n0_l00003ooH9mP?o00001Oo/4n`00ol0003o
jAKYonTFj@03onTFj@03o`000?o;=<_obcC;00KobcC;00?o0000ogf2OOmmPWd02OmmPWd00ol0003o
=lPgocO8=`0;ocO8=`03o`000?l<l`co3?<<00?o3?<<00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`3o0?l0o`000_l0o`02o`0000So
1OX500?o0000oc3?<?l`cc002Ol`cc000ol0003oPGj1oh5nP@07oh5nP@05o`000?n;M8_oRgB;oh]d
Rol000003Oo7><L00ol0003ok1?/on`Ck006on`Ck003o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
oP7nooh1oP0:ooh1oP03o`000?of2OKomPWf00GomPWf0ol000000oo/4nco0000onTFj@06onTFj@03
o`000?o;=<_obcC;00GobcC;00?o0000ogf2OOmmPWd02OmmPWd00ol0003o=lPgocO8=`0<ocO8=`05
o`000?l<l`co3?<<o`cc3?l000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`3o0?l000000_l000000olFjAKo0000o`Gj1@07o`Gj1@03o`000?l`cc3o<<l`
00So<<l`00?o0000oh5nPOn1OX402On1OX400ol0003oRgB;o`00000=olLha`Co00001Oo/4n`00ol0
003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003omPWfooH9mP08ooH9mP03
o`000?oY5^WojAKY00OojAKY00?o0000ol/dboo;=</01?o;=</00ol0003oOH9mogf2O@09ogf2O@03
o`000?lgb3Oo=lPg00go=lPg00?o0000o`cc3?l000003?l0o`0:o`0000Oo0?l00ol00005oaKY5P03
o`000?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001ol`cc000ol0003oPGj1oh5nP@0:oh5nP@03
o`000?o7><OoacS700_oacS700?o0000ondBkOo]4^d00_o]4^d3o`000003on`Ck?l0003on@Ki00_o
n@Ki0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003ojAKYonTFj@07onTFj@03o`00
0?o;=<_obcC;00GobcC;00?o0000ogf2OOmmPWd01ommPWd00ol0003o=lPgocO8=`0?ocO8=`;o0000
2ol0o`000ol0003o3?<<o`cc3007o`cc3003o`000?l0o`3o0?l000;o0?l00ol00008oaKY5P03o`00
0?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001ol`cc000ol0003oPGj1oh5nP@0:oh5nP@03o`00
0?o7><OoacS700[oacS700?o0000ondBkOo]4^d01_o]4^d00ol0003on@KiooT6n@08ooT6n@?o0000
0_ok1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?on0OkooP7n00[ooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003ojAKYonTF
j@08onTFj@03o`000?o;=<_obcC;00CobcC;00?o0000ogf2OOmmPWd01ommPWd00ol0003o=lPgocO8
=`0>ocO8=`04o`000?l8m`So2?L8o`0000Wo0?l000?o0000o`cc3?l<l``02Ol<l``01?l0003o0?l0
o`000?l0000<oaKY5P03o`000?l5nPGo1OX500Ko1OX500?o0000oc3?<?l`cc001_l`cc000ol0003o
PGj1oh5nP@0;oh5nP@03o`000?o7><OoacS700OoacS70_l00009ondBk@03o`000?oi1_Won@Ki00Co
n@Ki1?l00006oo/4n`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ooh1o_on0Oh02_on0Oh00ol0003omPWfooH9mP09ooH9mP03o`00
0?oY5^WojAKY00SojAKY00?o0000ol/dboo;=</00oo;=</>o`0000go=lPg00?o0000o`Sg2?l8m`P0
0_l8m`P00ol0003o0?l0o`3o0005o`3o0003o`000?l<l`co3?<<00_o3?<<00?o0000oaKY5_lFjAH0
3?lFjAH00ol0003o1OX5o`Gj1@06o`Gj1@03o`000?l`cc3o<<l`00Go<<l`00?o0000oh5nPOn1OX40
3?n1OX400ol0003oacS7olLha`06olLha`03o`000?o]4^gokA;]00[okA;]00?o0000ooT6nOoi1_T0
0ol0000:oo/4n`?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onTFjOoY5^T02?oY
5^T01Ol0003obcC;ol/dboo;=<_o000000_oTfbC00?o0000oc3?<?l`cc000ol00009ocO8=`03o`00
0?l8m`So2?L800Co2?L800?o0000o`3o0?l0o`000ol0o`000ol0003o3?<<o`cc300<o`cc3003o`00
0?lFjAKo5^TF00go5^TF00?o0000o`Gj1Ol5nPD01_l5nPD00ol0003o<<l`oc3?<003oc3?<0?o0000
3On1OX400ol0003oacS7olLha`05olLha`03o`000?o]4^gokA;]00cokA;]0_l0000=oo/4n`03o`00
0?on0OkooP7n00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?of2OKomPWf00_omPWf00?o0000onTFjOoY5^T02?oY
5^T4o`0000coTfbC00?o0000oc3?<?l`cc000ol`cc03o`0000Go=lPg00?o0000o`Sg2?l8m`P01_l8
m`P01Ol0003o0?l0o`3o0?l0o`3o000000oo3?<<00?o0000oaKY5_lFjAH03OlFjAH00ol0003o1OX5
o`Gj1@06o`Gj1@03o`000?l`cc3o<<l`00?o00000olgb3L00ol0003oPGj1oh5nP@0;oh5nP@03o`00
0?o7><OoacS700?oacS700?o0000ondBkOo]4^d03Oo]4^d00ol0003on`Ckoo/4n`0;oo/4n`03o`00
0?on0OkooP7n00CooP7n0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?on0OkooP7n00SooP7n00?o0000ooH9m_of2OH02_of2OH3o`0000KojAKY0ol0
0003omdRg@03o`000?nCK9?oTfbC00[oTfbC00?o0000oc3?<?l`cc001_l`cc03o`000003ocO8=ol0
003o2?L800Wo2?L800?o0000o`3o0?l000004?l<l``00ol0003o5^TFoaKY5P0=oaKY5P03o`000?l5
nPGo1OX500Oo1OX50_l00007ocO8=`03o`000?n1OX7oPGj100[oPGj100Co0000olLhaoo7><OoacS7
0ol0000?ondBk@03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01oon0Oh4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?on0OkooP7n00KooP7n00?o0000ooH9m_of2OH02_of
2OH01?l0003olPgboo8=l_ob3O82o`000004onTFjOl0003o0000o`0000KogB;M00?o0000oi=/TonC
K9<02_nCK9<00ol0003o<<l`oc3?<009oc3?<003o`000?l8m`So2?L800[o2?L800?o0000o`cc3?l<
l``03ol<l``00ol0003o5^TFoaKY5P0>oaKY5P03o`000?l5nPGo1OX500Ko1OX500?o0000ocO8=olg
b3L01olgb3L4o`0000SoPGj100Co0000olLhaoo7><Oo00000ooN8Mh2o`0000gokA;]00?o0000oo/4
nook1?/02_ok1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?on0OkooP7n00GooP7n00?o0000ooH9m_of2OH02Oof2OH00ol0003o
lPgboo8=lP04oo8=lP03o`000?oM8]gogB;M00OogB;M00?o0000oi=/TonCK9<02OnCK9<00ol0003o
<<l`oc3?<00:oc3?<003o`000?l8m`So2?L800[o2?L800?o0000o`cc3?l<l``03ol<l``00ol0003o
5^TFoaKY5P0>oaKY5P03o`000?l5nPGo1OX500Go1OX500?o0000ocO8=olgb3L02?lgb3L01?l0003o
QWV6ohIiQ_n6NHH7o`0000;oPGj10_l00006omhQgP;o00003?o]4^d00ol0003on`Ckoo/4n`09oo/4
n`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ooh1o_on0Oh01?on0Oh00ol0003omPWfooH9mP08ooH9mP03o`000?ob3O;olPgb00Go
lPgb00?o0000omdRgOoM8]d02?oM8]d00ol0003oTfbCoi=/T`08oi=/T`03o`000?l`cc3o<<l`00[o
<<l`00?o0000o`Sg2?l8m`P02ol8m`P00ol0003o3?<<o`cc300>o`cc3003o`000?lFjAKo5^TF00ko
5^TF1Ol00002o`Gj1@03o`000?lgb3Oo=lPg00Wo=lPg00?o0000ohIiQ_n6NHH02?n6NHH3o`0000Wo
gR7N0_l0000:ondBk@03o`000?ok1?_on`Ck00Son`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?of2OKomPWf00SomPWf00?o0000oo8=l_ob3O801oob3O800ol0003ogB;MomdRg@07omdRg@03o`00
0?nCK9?oTfbC00SoTfbC00?o0000oc3?<?l`cc002_l`cc000ol0003o2?L8o`Sg200:o`Sg20;o0000
3_l<l``3o`0000go5^TF0ol00005obkA;P;o00002olgb3L00ol0003oQWV6ohIiQP0;ohIiQP;o0000
2_oN8Mh2o`0000OokA;]0ol00009oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ooh1o_on0OkooP7n3?l0000:oo8=lP03o`00
0?oM8]gogB;M00OogB;M00?o0000oi=/TonCK9<02?nCK9<>o`0000Wo2?L80ol000000ol0o`3o0000
o`cc300:o`cc30?o00000_lSg2<00ol0003o5^TFoaKY5P09oaKY5P;o00002Ol^dBh00ol0003o=lPg
ocO8=`09ocO8=`03o`000?n6NHKoQWV600_oQWV600?o0000ojeB[Ol000002ooN8Mh2o`0000CokA;]
00Co0000oo@;m?od2oCom0_d0_l00007oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ooh1o_l000002oom0_d00ol0003olPgb
oo8=lP09oo8=lP03o`000?oM8]gogB;M00KogB;M00?o0000oi=/TonCK9<02?nCK9<00ol0003o</db
oc;=<P0:oc;=<P03o`000?l8m`So2?L800Co2?L80ol00005o`3o0003o`000?l<l`co3?<<00Co3?<<
1?l00006ob?L8`03o`000?lFjAKo5^TF00Ko5^TF0_l0000;obkA;P03o`000?lgb3Oo=lPg00Wo=lPg
00?o0000ohIiQ_n6NHH02_n6NHH01Ol0003o[E:]ojeB[On]DZgo000000cogR7N0_l000000oo]4^go
0000oo@;m005oo@;m003o`000?ok1?_on`Ck00?on`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?ob3O;olPgb00SolPgb00?o0000omdRgOoM8]d01_oM8]d00ol0003oTfbCoi=/T`07oi=/T`03o`00
0?lbcC;o</db00_o</db00?o0000o`Sg2?l8m`P00_l8m`P2o`0000Wo0?l000?o0000o`cc3?l<l``0
0ol0000;ob?L8`03o`000?lFjAKo5^TF00;o5^TF0ol0000>obkA;P03o`000?lgb3Oo=lPg00Oo=lPg
00?o0000ohIiQ_n6NHH02on6NHH00ol0003o[E:]ojeB[@02ojeB[@03o`000?oN8MkogR7N00_ogR7N
00?o0000oo@;m?od2o@01_od2o@2o`0000?on`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?ob
3O;olPgb00OolPgb00?o0000omdRgOoM8]d01ooM8]d00ol0003oTfbCoi=/T`05oi=/T`?o00003Olb
cC84o`0000_o0?l00ol0000?ob?L8`04o`000?lFjAKo0000o`00017o;]4^00?o0000ocO8=olgb3L0
1olgb3L00ol0003oQWV6ohIiQP0:ohIiQP03o`000?n]DZgo[E:]00Co[E:]00?o0000omhQg_oN8Mh0
1ooN8Mh3o`0000_om0_d1?l0000=ooh1oP03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O802?ob3O800ol0003ogB;MomdR
g@06omdRg@03o`000?nCK9?oTfbC00;oTfbC0ol00003ofjAKP03o`000?lbcC;o</db00[o</db00?o
0000o`3o0?l0o`002ol0o`000ol0003o0?l0o`00000Aob?L8`03o`000?l^dBko;]4^017o;]4^00?o
0000ocO8=olgb3L01olgb3L00ol0003oQWV6ohIiQP0:ohIiQP03o`000?n]DZgo[E:]00Go[E:]00Co
0000omhQg_oN8MkogR7N1Ol00002on<Lh`03o`000?od2oCom0_d00Wom0_d00Co0000ooh1o_on0Oko
oP7n0ol00009ooh1oP03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000oo8=l_ob3O801oob3O800ol0003ogB;MomdRg@05omdRg@?o0000
00?oTfbCo`000?l000001om^TFh00ol0003o</dboc;=<P08oc;=<P?o00002_l0o`02o`0000;o0?l0
00?o0000ob?L8olSg2<03olSg2<00ol0003o;]4^obkA;P0AobkA;P03o`000?lgb3Oo=lPg00Oo=lPg
00?o0000ohIiQ_n6NHH02On6NHH00ol0003o[E:]ojeB[@07ojeB[@?o00001ooS7><00ol0003om0_d
oo@;m009oo@;m003o`000?on0OkooP7n00CooP7n0_l00007ooh1oP03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000oo8=l_ob3O801oob
3O84o`0000;ogB;M0_l00003oll`c`03o`000?m^TFkoKY5^00SoKY5^0_l00006oc;=<P;o00000olW
f2L00ol0003o0?l0o`3o0006o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000ob?L8olSg2<03_lS
g2<00ol0003o;]4^obkA;P0BobkA;P03o`000?lgb3Oo=lPg00Go=lPg00?o0000ohIiQ_n6NHH02On6
NHH00ol0003o[E:]ojeB[@08ojeB[@03o`000?oS7>?ohacS00OohacS00?o0000oo@;m?od2o@02?od
2o@00ol0003ooP7nooh1oP07ooh1oP;o00001Oon0Oh00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?ob3O;olPgb00ColPgb0_l00004
oo0?l0;o00001Oo?<<l00ol0003oKY5^ofjAKP0:ofjAKP03o`000?lbcC;o</db00;o</db00?o0000
obOH9olWf2L01?lWf2L00ol0003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000Co0?l000?o0000
ob?L8olSg2<03_lSg2<00ol0003o;]4^obkA;P0BobkA;P[o00002_n6NHH00ol0003o[E:]ojeB[@08
ojeB[@03o`000?oS7>?ohacS00OohacS00?o0000oo@;m?od2o@02?od2o@00ol0003ooP7nooh1oP09
ooh1oP?o000000?ooP7no`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003olPgboo8=l_ob3O82o`0000Ool0o`00?o0000oll`coo?<<l01?o?<<l0
0ol0003oKY5^ofjAKP0:ofjAKP04o`000?lbcC;o0000o`0000So9mPW00Co0000o`3o0?l0o`3o0?l0
0_l00007o`3o0003o`000?lSg2?o8m`S00ko8m`S00?o0000obkA;_l^dBh04_l^dBh00ol0003oFJII
oeVVF@07oeVVF@03o`000?n6NHKoQWV600KoQWV600?o0000ojeB[On]DZd02_n]DZd00ol0003ohacS
on<Lh`06on<Lh`03o`000?od2oCom0_d00Som0_d00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?ob
3O;o0000o`0000Wol0o`00?o0000oll`coo?<<l01?o?<<l00ol0003oKY5^ofjAKP0;ofjAKP03o`00
0?lWf2Oo9mPW00Wo9mPW00?o0000o`3o0?l000002Ol0o`000ol0003o8m`Sob?L8`0>ob?L8`;o0000
4_l^dBh00ol0003oFJIIoeVVF@09oeVVF@;o00001_n6NHH00ol0003o[E:]ojeB[@0:ojeB[@03o`00
0?oS7>?ohacS00KohacS00?o0000oo@;m?od2o@02?od2o@00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000oo0?l?o`3o002Oo`3o000ol0003occ3?oll`c`05oll`c`03o`000?m^TFkoKY5^00[oKY5^00?o
0000obOH9olWf2L02_lWf2L2o`0000Wo0?l000?o0000ob?L8olSg2<03_lSg2<00ol0003o7N8Mo`00
0002o`0000oo;]4^00?o0000oeVVFOmIYUT02omIYUT00ol0003oQWV6ohIiQP03o`0000go[E:]00?o
0000on<LhooS7><01_oS7><00ol0003om0_doo@;m007oo@;m003o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003ol0o`oo0?l009oo0?l003o`000?o?<<oocc3?00Gocc3?00?o0000ofjAK_m^TFh02Om^TFh2
o`0000_o9mPW0_l0000;o`3o0003o`000?lSg2?o8m`S00co8m`S00?o0000oagR7OlMhQd00olMhQd3
o`0000co;]4^00?o0000oeVVFOmIYUT03?mIYUT2o`0000;oZUFZ00?o0000ojeB[On]DZd03?n]DZd0
0ol0003ohacSon<Lh`05on<Lh`03o`000?od2oCom0_d00Oom0_d00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o`3o3ol0o`00[ol0o`00?o0000oll`coo?<<l01_o?<<l00ol0003oKY5^ofjAKP07ofjA
KP03o`000?mgR7Oo000000[o9mPW00Co0000ob3O8?lPgb3o00002_l0o`000ol0003o8m`Sob?L8`0<
ob?L8`03o`000?lMhQgo7N8M00Ko7N8M0_l00008obkA;P;o00003omIYUT00ol0003oZUFZojYEZP02
ojYEZP03o`000?n]DZgo[E:]00_o[E:]00?o0000on<LhooS7><01OoS7><00ol0003om0_doo@;m007
oo@;m003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003ol0o`oo0?l00:oo0?l003o`000?o?<<oocc3?
00Kocc3?00?o0000ofjAK_m^TFh01_m^TFh01Ol0003oMhQgogN8MomgR7Oo000000So9mPW00?o0000
ob3O8?lPgb000_lPgb000ol0003o0?l0o`3o0006o`3o00Co00003?lSg2<00ol0003o7N8MoagR7@08
oagR7@?o00000_l^dBh3o`000003od:m@_l0003oFJII00goFJII00?o0000ojYEZ_nZEJX01?nZEJX0
0ol0003o[E:]ojeB[@0:ojeB[@03o`000?oS7>?ohacS00GohacS00?o0000oo@;m?od2o@01_od2o@0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o002oo`3o000ol0003occ3?oll`c`07oll`
c`03o`000?m^TFkoKY5^00?oKY5^0_l00005ogN8M`03o`000?lWf2Oo9mPW00Co9mPW00?o0000ob3O
8?lPgb000olPgb000ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200;o0_d20ol00007ob?L
8`;o00003_lMhQd2o`0000Go@[e200?o0000oeVVFOmIYUT02_mIYUT00ol0003oZUFZojYEZP05ojYE
ZP03o`000?n]DZgo[E:]00_o[E:]00?o0000on<LhooS7><01?oS7><00ol0003om0_doo@;m006oo@;
m003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003ol0o`oo0?l00;oo0?l003o`000?o?<<oocc3?00Oo
cc3?00?o0000ofjAK_m^TFh00_m^TFh00ol0003oMhQgogN8M`06ogN8M`03o`000?lWf2Oo9mPW00;o
9mPW00?o0000ob3O8?lPgb001OlPgb000ol0003o0?l0o`3o0002o`3o00;o00002?l2o@83o`0000;o
8m`S0_l000000ol5nPGo0000oagR7@0=oagR7@03o`000?m2_D;o@[e200Go@[e200?o0000oeVVFOmI
YUT02?mIYUT00ol0003oZUFZojYEZP07ojYEZP03o`000?n]DZgo[E:]00[o[E:]00?o0000on<LhooS
7><01?oS7><00ol0003om0_doo@;m006oo@;m003o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003ol0o`
oo0?l00<oo0?l003o`000?o?<<oocc3?00Socc3?00Co0000ofjAK_m^TFko00002OmgR7L01Ol0003o
9mPWobOH9olWf2Oo000000So8=lP00Go0000o`3o0?l0o`3o0?l0o`00000=o`;m0P;o00001?l5nPD0
0ol0003o7N8MoagR7@0;oagR7@03o`000?m2_D;o@[e200Ko@[e200?o0000oeVVFOmIYUT01omIYUT0
0ol0003oZUFZojYEZP08ojYEZPCo00002?n]DZd00ol0003ohacSon<Lh`04on<Lh`03o`000?od2oCo
m0_d00Kom0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?o`3o3ol0o`00_ol0o`0ol00009oll`
c`03o`000?m^TFko000000_oMhQg00?o0000obOH9ol000002_lPgb000ol0003o0?l0o`00000?o`;m
0P03o`000?l5nPGo1OX500;o1OX500?o0000oagR7OlMhQd02olMhQd00ol0003o@[e2od:m@P06od:m
@P03o`000?mIYUWoFJII00KoFJII00?o0000ojYEZ_nZEJX02OnZEJX01?l0003ocS7>olhac_o><Lh7
o`0000;o[E:]00?o0000on<LhooS7><00ooS7><00ol0003om0_doo@;m005oo@;m003o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?o`3o3ol0o`00Sol0o`0ol00003onl@k`03o`000?o?<<oocc3?00Oocc3?00?o0000ogN8
MomgR7L02omgR7L00ol0003o8=lPob3O800:ob3O8003o`000?l2o@;o0_d200go0_d200?o0000o`Gj
1Ol5nPD01?l5nPD00ol0003o7N8MoagR7@09oagR7@03o`000?m2_D;o@[e200So@[e200?o0000oeVV
FOmIYUT00omIYUT2o`0000coZUFZ00?o0000olhac_o><Lh02?o><Lh<o`0000?om0_d0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000oo0?l?o`3o001_o`3o03o`0000Ooka3_00?o0000oll`coo?<<l01_o?<<l00ol0003o
MhQgogN8M`0;ogN8M`03o`000?lPgb3o8=lP00Wo8=lP0_l0000>o`;m0P03o`000?l5nPGo1OX500Go
1OX500?o0000oagR7OlMhQd02OlMhQd00ol0003o@[e2od:m@P09od:m@P03o`000?mIYUWo000000;o
00000_nOH9l00ol0003oZUFZojYEZP08ojYEZP03o`000?o><LkocS7>00cocS7>00?o0000onhAk_o^
4Nh01_o^4Nh3o`0000?oo@;m0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003ol0o`oo0?l003oo0?l0?o00002oo_4>l00ol0003occ3?
oll`c`04oll`c`03o`000?mgR7OoMhQg00_oMhQg0ol00007ob3O80?o000000?o4NhAo`000?l2o@80
3Ol2o@800ol0003o1OX5o`Gj1@06o`Gj1@03o`000?lMhQgo7N8M00So7N8M00?o0000od:m@_m2_D80
2_m2_D800ol0003oWf2OoimPW`04oimPW`03o`000?nZEJ[oZUFZ00OoZUFZ00?o0000olhac_o><Lh0
2oo><Lh00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00Coo@;m0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004oo0?l?l0
003o0000o`0000ooka3_00?o0000oll`coo?<<l00oo?<<l>o`0000?oGimO0_l00002ob3O80?o0000
1OlAkQ400ol0003o0_d2o`;m0P0:o`;m0P03o`000?l5nPGo1OX500Oo1OX500?o0000oagR7OlMhQd0
2?lMhQd00ol0003o@[e2od:m@P0:od:m@P03o`000?nOH9ooWf2O00GoWf2O00?o0000ojYEZ_nZEJX0
1_nZEJX00ol0003ocS7>olhacP0;olhacP03o`000?o^4NkokQ7^00SokQ7^00?o0000ood2oOom0_d0
1oom0_d2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?ol0o`2o`0001;oka3_00?o0000oll`coo?<<l00_o?<<l00ol0003o`Sg2ol8m
`P0:ol8m`P03o`000?mOWeooGimO00?oGimO0_l00009oa7^4@03o`000?l2o@;o0_d200Wo0_d200?o
0000o`Gj1Ol5nPD02?l5nPD2o`0000So7N8M00?o0000od:m@_m2_D802Om2_D800ol0003oWf2OoimP
W`07oimPW`03o`000?nZEJ[oZUFZ00CoZUFZ00?o0000olhac_o><Lh02oo><Lh00ol0003okQ7^onhA
kP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000oo`3o?ol0o`01ool0o`00ol0003oka3_onl@k`0?onl@k`?o000000?occ3?
o`000?o2?L802oo2?L800ol0003oGimOoenOG`04oenOG`03o`000?lAkQ7o4NhA00Wo4NhA00?o0000
o`;m0_l2o@801ol2o@800ol0003o1OX5o`Gj1@09o`Gj1@04o`000?lDjaCo0000o`0000Ko7N8M00?o
0000od:m@_m2_D802Om2_D800ol0003oWf2OoimPW`08oimPW`03o`000?nZEJ[oZUFZ00?oZUFZ00?o
0000olhac_o><Lh02oo><Lh00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000oo`3o?ol0o`02?ol0o`0
0ol0003oka3_onl@k`0<onl@k`;o00000oo^4Nh2o`0000co`Sg200?o0000oenOGomOWel01?mOWel0
0ol0003o4NhAoa7^4@0:oa7^4@Wo00002ol5nPD00ol0003o5>/DoaC[5002oaC[50?o00000_lMhQd0
0ol0003o@[e2od:m@P0:od:m@P03o`000?nOH9ooWf2O00WoWf2O00?o0000ojYEZ_nZEJX00_nZEJX0
0ol0003ocS7>olhacP0:olhacP03o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02_om0_d0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o009oo`3
o0;o00002_o_4>l2o`0000GokQ7^00?o0000om8]d_l000002_o2?L800ol0003oGimOoenOG`06oenO
G`03o`000?lAkQ7o4NhA00Wo4NhA00?o0000o`7n0Ol1oP401Ol1oP400ol0003o1OX5o`Gj1@09o`Gj
1@03o`000?lDjaCo5>/D00Go5>/D0ol00009od:m@P?o00003OnOH9l01Ol0003oZUFZojYEZ_nZEJ[o
000000cocS7>00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0:ood2o@03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l00coo0?l00?o0000onl@
koo_4>l01Oo_4>l2o`0000OokQ7^00Co0000om8]d_oB;M;o00002Oo2?L800ol0003oGimOoenOG`06
oenOG`03o`000?lAkQ7o4NhA00So4NhA00?o0000o`7n0Ol1oP401ol1oP400ol0003o1OX5o`Gj1@07
o`Gj1@03o`000?lDjaCo5>/D00So5>/D0ol00002od:m@PGo00000_n5NXD00ol0003oWf2OoimPW`0<
oimPW`03o`000?nZEJ[o000000cocS7>00?o0000onhAk_o^4Nh02_o^4Nh00ol0003oo@;mood2o@0:
ood2o@03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?ol0ocoo0?l
00goo0?l00?o0000onl@koo_4>l00_o_4>l2o`0000SokQ7^00?o0000om8]d_oB;M800_oB;M85o`00
00Co`Sg200?o0000oenOGomOWel01_mOWel00ol0003o4NhAoa7^4@08oa7^4@03o`000?l1oP7o0Oh1
00Oo0Oh100?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o5>/DoaC[5008oaC[5003o`000?m8]dSoB;M8
00;o00002?n5NXD00ol0003oWf2OoimPW`0<oimPW`Co00002_o><Lh00ol0003okQ7^onhAkP0:onhA
kP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000oo`3o?ol0o`03_ol0o`01?l0003oka3_o`000?l0000:onhAkP03o`000?oB;M;odRgB
00;odRgB00?o0000ojEJYOnUFZD00_nUFZD4o`0000WoGimO00?o0000oa7^4OlAkQ402?lAkQ400ol0
003o0Oh1o`7n0@08o`7n0@03o`000?l5nPGo1OX500Go1OX500?o0000oaC[5?lDja@02?lDja@01Ol0
003oB;M8odRgB?m8]dSo000000[oQGZ50ol0000;oimPW`04o`000?oT6nCoi1_Ton@Ki0Co00001Oo>
<Lh00ol0003okQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00_oo@;m00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`03ool0o`00ol0003okQ7^onhAkP0:
onhAkP03o`000?oB;M;odRgB00?odRgB00?o0000ojEJYOnUFZD01?nUFZD00ol0003oGimOoenOG`07
oenOG`03o`000?lAkQ7o4NhA00Ko4NhA0_l0000;o`7n0@03o`000?l5nPGo1OX500Go1OX500?o0000
oaC[5?lDja@02?lDja@00ol0003oB;M8odRgB002odRgB003o`000?n5NXGoQGZ500OoQGZ500?o0000
olHia_o6>LH01?l00006oimPW`03o`000?oT6nCoi1_T00Koi1_T0ol00002olhacP03o`000?o^4Nko
kQ7^00_okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^4NkokQ7^00WokQ7^00?o0000om8]
d_oB;M801?oB;M800ol0003oYEZUojEJY@05ojEJY@03o`000?mOWeooGimO00OoGimO00?o0000oa7^
4OlAkQ400_lAkQ43o`000003ob7N8Ol0003o0Oh100[o0Oh100?o0000o`Gj1Ol5nPD01Ol5nPD00ol0
003o5>/DoaC[5007oaC[5003o`000?m8]dSoB;M800?oB;M800?o0000ohEjQOn5NXD01on5NXD00ol0
003oaSW6olHiaP04olHiaP?o00000_nOH9l00ol0003oi1_Ton@Ki00:on@Ki0;o00003_o^4Nh00ol0
003oo@;mood2o@0;ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003odRgBom8]dP04om8]dP03
o`000?nUFZGoYEZU00KoYEZU0_l00007oenOG`03o`000?lAkQ7o000000;o00001OlQgR400ol0003o
0Oh1o`7n0@08o`7n0@?o00001?l5nPD00ol0003o5>/DoaC[5008oaC[5003o`000?m8]dSoB;M800Co
B;M800?o0000ohEjQOn5NXD01_n5NXD00ol0003oaSW6olHiaP07olHiaP;o00003_oT6n@00ol0003o
kQ7^onhAkP0;onhAkP03o`000?om0_goo@;m00coo@;m00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^onhAkP08onhAkP03o`00
0?oB;M;odRgB00GodRgB00?o0000ojEJYOnUFZD01?nUFZD00ol0003oW6>LoiaSW003o`0000CoGimO
0_l00008ob7N8@03o`000?l1oP7o0Oh100Oo0Oh100Co0000obOH9olWf2Oo9mPW0ol000000ol5nPGo
0000oaC[5009oaC[5003o`000?m8]dSoB;M800CoB;M800?o0000ohEjQOn5NXD01On5NXD00ol0003o
aSW6olHiaP09olHiaP03o`000?oT6nCoi1_T00goi1_T00?o0000onhAk_o^4Nh02_o^4Nh00ol0003o
o@;mood2o@0<ood2o@03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?ol0ocoo0?l017oo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003odRgBom8]dP06om8]dP03o`00
0?nUFZGoYEZU00?oYEZU00?o0000oiaSW?nLHi`01?nLHi`2o`000003oenOGol0003o8MhQ00[o8MhQ
00?o0000o`7n0Ol1oP401Ol1oP400ol0003o9mPWobOH9`05obOH9`03o`000?lDjaCo5>/D00Oo5>/D
0ol00007odRgB003o`000?n5NXGoQGZ500CoQGZ500?o0000olHia_o6>LH02Oo6>LH00ol0003oi1_T
on@Ki00=on@Ki003o`000?o^4NkokQ7^00[okQ7^00?o0000ood2oOom0_d02oom0_d00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo0?loo`3o00@oo`3o003o`000?o^
4NkokQ7^00GokQ7^0ol00009om8]dP05o`000?nUFZGoYEZUojEJYOl000002OnLHi`00ol0003o8MhQ
ob7N8@0;ob7N8@03o`000?l1oP7o0Oh100?o0Oh100?o0000obOH9olWf2L01_lWf2L00ol0003o5>/D
oaC[5006oaC[5005o`000?m3_4?o@ka3od>l@ol000001om8]dP00ol0003oQGZ5ohEjQ@03ohEjQ@03
o`000?o6>LKoaSW600WoaSW600?o0000on@Ki?oT6n@03_oT6n@00ol0003okQ7^onhAkP09onhAkP03
o`000?om0_goo@;m00[oo@;m00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000oo`3o?ol0o`04Ool0o`00ol0003okQ7^o`000004o`0000;ol`cc00?o0000om8]d_oB;M80
1ooB;M801?l0003oYEZUojEJYOl00009oiaSW0;o00003OlQgR400ol0003o0Oh1o`7n0@02o`7n0@03
o`000?lWf2Oo9mPW00So9mPW00?o0000oaC[5?lDja@00olDja@2o`0000Go@ka300?o0000odRgB?m8
]dP01?m8]dP00ol0003oQGZ5ohEjQ@03ohEjQ@03o`000?o6>LKoaSW600WoaSW600?o0000on@Ki?oT
6n@03_oT6n@00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00Woo@;m00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000oo`3o?ol0o`04Ool0o`2o`0000Sol`cc
00?o0000om8]d_oB;M801_oB;M800ol0003oYEZUo`000009oiaSW004o`000?m[U6_oJiA[o`0000go
8MhQ00Co0000o`7n0Ol1oP7o00003?lWf2L01Ol0003o5>/DoaC[5?lDjaCo000000So@ka30_l00005
odRgB003o`000?n5NXGoQGZ500;oQGZ500?o0000olHia_o6>LH02Oo6>LH00ol0003oi1_Ton@Ki00>
on@Ki003o`000?o^4NkokQ7^00WokQ7^00?o0000ood2oOom0_d02Oom0_d00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00@oo`3o003o`000?oc3??ol`cc
00Ool`cc00?o0000om8]d_oB;M801ooB;M800ol0003oW6>LoiaSW007oiaSW003o`000?m[U6_oJiA[
00;oJiA[00?o0000ob7N8OlQgR402_lQgR400ol0003o0Oh1o`00000>obOH9`03o`000?lDjaCo0000
00_o@ka300?o0000odRgB?m8]dP00_m8]dP01Ol0003oQGZ5ohEjQOn5NXGo000000coaSW600?o0000
on@Ki?oT6n@03_oT6n@3o`0000WokQ7^00?o0000ood2oOom0_d02?om0_d00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oc3??ol`cc
00Wol`cc00?o0000om8]d_oB;M801_oB;M800ol0003oW6>LoiaSW006oiaSW003o`000?m[U6_oJiA[
00?oJiA[00?o0000ob7N8OlQgR402olQgR400ol0003o9mPWobOH9`0>obOH9`03o`000?m3_4?o@ka3
00_o@ka30_l00003odRgB004o`000?n5NXGoQGZ5o`0000[oaSW60ol0000>on@Ki0;o00000oom0_d2
o`0000OokQ7^00?o0000ood2oOom0_d01oom0_d00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo0?loo`3o00?oo`3o003o`000?oc3??ol`cc00[ol`cc00?o0000om8]
d_oB;M801?oB;M800ol0003oW6>LoiaSW006oiaSW003o`000?m[U6_oJiA[00GoJiA[00?o0000ob7N
8OlQgR401olQgR43o`00017o9mPW00?o0000od>l@om3_4<03Om3_4<01Ol0003oB;M8odRgB?l0003o
QGZ500Co00000oo6>LH5o`0000;ol0o`00?o0000on@Ki?oT6n@02_oT6n@2o`0000Ooo@;m0_l00004
onhAkP03o`000?om0_goo@;m00Soo@;m00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000oo`3o?ol0o`03_ol0o`00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oB;M;odRgB
00CodRgB00?o0000oiaSW?nLHi`01OnLHi`00ol0003oJiA[of^DJ`06of^DJ`03o`000?lQgR7o8MhQ
00Co8MhQ0ol00002obKI9P03o`000?lWf2Oo9mPW00oo9mPW0_l0000?od>l@`04o`000?m8]dSo0000
o`0000Co]4^d0ol00008oo0?l003o`000?oT6nCoi1_T00Ooi1_T0_l0000;ood2o@;o00000_o^4Nh0
0ol0003oo@;mood2o@07ood2o@03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?ol0ocoo0?l00goo0?l00?o0000oo<<looc3?<03?oc3?<6o`0000OoW6>L00?o0000of^D
Jom[U6/02?m[U6/00ol0003o8MhQob7N8@03o`0000Ko9]TV00?o0000obOH9olWf2L03OlWf2L01?l0
003oB[E:odZeB_l0000?od>l@`03o`000?ndBkCo]4^d00Go]4^d00?o0000oo0?l?o`3o002?o`3o00
0ol0003oi1_Ton@Ki005on@Ki003o`000?om0_goo@;m00goo@;m0ol00008ood2o@03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oc3?<00ol0003of2OHomPWf004omPW
f003o`000?nLHicoW6>L00?oW6>L00?o0000of^DJom[U6/02_m[U6/2o`0000[o9]TV00?o0000obOH
9olWf2L02olWf2L00ol0003oB[E:odZeBP02odZeBP03o`000?m3_4?o@ka300_o@ka30_l00007okA;
]003o`000?o`3o3ol0o`00Wol0o`00?o0000on@Ki?oT6n@00_oT6n@2o`0001;oo@;m00?o0000ood2
oOom0_d00oom0_d3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00co
o@;m00?o0000oo<<looc3?<02ooc3?<00ol0003of2OHomPWf006omPWf005o`000?nLHicoW6>LoiaS
W?l000003Om[U6/00ol0003o9]TVobKI9P0:obKI9P03o`000?lWf2Oo9mPW00Wo9mPW00?o0000odZe
B_m:]DX01?m:]DX00ol0003o@ka3od>l@`08od>l@`;o000000?oL8m`o`000?ndBk@01ondBk@00ol0
003ol0o`oo0?l009oo0?l004o`000?oT6nCo0000o`0001Coo@;m00?o0000ood2oOom0_d00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2o@03o`000?oc3??ol`cc
00Wol`cc00?o0000omPWf?oH9mP02?oH9mP00ol0003oW6>Lo`00000=of^DJ`03o`000?lVfBKo9]TV
00_o9]TV00?o0000obOH9olWf2L02?lWf2L00ol0003oB[E:odZeBP06odZeBP03o`000?m3_4?o@ka3
00Go@ka30_l00003og2?L003o`000?ndBkCo]4^d00Ko]4^d00?o0000oo0?l?o`3o002_o`3o000ol0
003oo@;mood2o@0Eood2o@;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ood2oOom
0_d03oom0_d00ol0003ol`ccoo<<l`07oo<<l`03o`000?oH9mSof2OH00[of2OH00?o0000of^DJom[
U6/03?m[U6/00ol0003o9]TVobKI9P0<obKI9P03o`000?lWf2Oo9mPW00Ko9mPW00?o0000odZeB_m:
]DX02?m:]DX00ol0003o@ka3od>l@`02od>l@`;o00001_m`Sg000ol0003o]4^dokA;]005okA;]003
o`000?o`3o3ol0o`00[ol0o`00?o0000ood2oOom0_d05Oom0_d00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oc3??ol`cc00Gol`cc
00?o0000omPWf?oH9mP03?oH9mP2o`0000coJiA[00?o0000obKI9_lVfBH03OlVfBH00ol0003o9mPW
obOH9`04obOH9`03o`000?m:]D[oB[E:00[oB[E:00Co0000od>l@ol0003o00002?m`Sg000ol0003o
]4^dokA;]006okA;]003o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d05Oom0_d00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0Aood2o@Co0000
0_oc3?<00ol0003of2OHomPWf00=omPWf003o`000?nHIiSo000000;o00002?m[U6/00ol0003o9]TV
obKI9P0?obKI9PKo00003_m:]DX00ol0003oL8m`og2?L008og2?L003o`000?ndBkCo]4^d00Ko]4^d
00?o0000oo0?l?o`3o002Oo`3o000ol0003oo@;mood2o@0Dood2o@03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m017oo@;m00Co0000ooH9m_of2OKomPWf
0_l0000?omPWf003o`000?nHIiSoV6NH00?oV6NH0ol00005of^DJ`;o00004?lVfBH01_l0003o9mPW
obOH9ol0003o8=lPo`0000koB[E:00?o0000og2?L?m`Sg002Om`Sg000ol0003o]4^dokA;]005okA;
]003o`000?o`3o3ol0o`00Wol0o`00?o0000ood2oOom0_d04oom0_d2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?om0_goo@;m00ooo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003o
f2OHomPWf00=omPWf003o`000?nHIiSoV6NH00KoV6NH0ol000001?m[U6_o0000odBkA?m4^d@3o`00
00co9]TV00Go0000obOH9olWf2Oo9mPWo`000002ob3O8003o`000?m:]D[oB[E:00_oB[E:00?o0000
og2?L?m`Sg002Om`Sg000ol0003o]4^dokA;]006okA;]003o`000?o`3o3ol0o`00Sol0o`0_l0000A
ood2o@?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03oom0_d00ol0003omPWfooH9mP04ooH9mPoo00003?nHIiP00ol0003oA;]4odBkA004odBk
A0?o00002?lVfBH00ol0003o9mPWobOH9`02obOH9`05o`000?lPgb3o8=lPob3O8?l000003?m:]DX0
0ol0003oL8m`og2?L009og2?L003o`000?ndBkCo]4^d00Go]4^d3?l00002ooT6n@;o00003Oom0_d2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ood2
oOom0_d03_om0_d00ol0003omPWfooH9mP05ooH9mP03o`000?oK9=_ofbCK00_ofbCK00?o0000oiQW
V?nHIiP02_nHIiP00ol0003oA;]4odBkA007odBkA0;o00001OlVfBH00ol0003o9mPWobOH9`03obOH
9`03o`000?lPgb3o8=lP00;o8=lP00?o0000odZeB_m:]DX02Om:]DX00ol0003oL8m`og2?L00:og2?
L003o`000?ndBkCo]4^d00?o]4^d00?o0000on/Djoo[5>/02Oo[5>/00ol0003on@KiooT6n@02ooT6
n@;o00002Oom0_d2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ood2oOom0_d03Oom0_d00ol0003omPWfooH9mP06ooH9mP03o`000?oK9=_ofbCK00[o
fbCK00?o0000oiQWV?nHIiP02onHIiP00ol0003oA;]4odBkA009odBkA0?o000000?o9]TVo`000?lW
f2L01OlWf2L00ol0003o8=lPob3O8003ob3O8003o`000?m:]D[oB[E:00SoB[E:3_l00003okA;]0;o
00002oo[5>/00ol0003on@KiooT6n@05ooT6n@03o`000?om0_goo@;m00?oo@;m0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00goo@;m
00?o0000ooH9m_of2OH01Oof2OH00ol0003ohQgRo`00000;om/Tf`03o`000?nHIiSoV6NH00[oV6NH
0_l0000>odBkA003o`000?lWf2Oo9mPW00Go9mPW00?o0000ob3O8?lPgb000olPgb000ol0003oB[E:
odZeBP08odZeBP03o`000?naC[7o/Dja00_o/Dja00?o0000okA;]?l000003Oo[5>/00ol0003on@Ki
ooT6n@06ooT6n@;o000000?oo@;mo`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?of2OKomPWf00KomPWf00Co
0000on8Mh_oR7N;o00002_oK9=/00ol0003oV6NHoiQWV009oiQWV003o`000?mcS7?o000000koA;]4
00?o0000obOH9olWf2L01OlWf2L00ol0003o8=lPob3O8004ob3O8003o`000?m:]D[oB[E:00KoB[E:
00?o0000ok5>/OnaC[403OnaC[400ol0003ojaC[on/Dj`0<on/Dj`03o`000?oi1_Won@Ki00Son@Ki
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00GomPWf00?o0000on8Mh_oR7N800_oR
7N800ol0003ofbCKom/Tf`06om/Tf`03o`000?nHIiSoV6NH00SoV6NH0_l00003og><L`03o`000?m4
^dCoA;]400_oA;]400?o0000obOH9olWf2L01OlWf2L00ol0003o8=lPob3O8005ob3O8003o`000?m:
]D[oB[E:00GoB[E:00?o0000ok5>/OnaC[403OnaC[400ol0003ojaC[on/Dj`0;on/Dj`03o`000?oi
1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?of2OKomPWf00KomPWf00?o0000
on8Mh_oR7N800ooR7N800ol0003ofbCKom/Tf`05om/Tf`03o`000?nHIiSoV6NH00OoV6NH00?o0000
og><LomcS7<00omcS7<00ol0003oA;]4odBkA00:odBkA003o`000?lWf2Oo9mPW00Ko9mPW00?o0000
ob3O8?lPgb001_lPgb000ol0003oB[E:odZeBP04odZeBP03o`000?naC[7o/Dja00go/Dja3ol0000;
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ood2o@03o`000?of2OKomPWf00KomPWf00?o0000on8Mh_oR7N801OoR7N800ol0
003ofbCKom/Tf`04om/Tf`03o`000?nHIiSoV6NH00GoV6NH0_l00006og><L`03o`000?m4^dCoA;]4
00WoA;]40_l00008obOH9`03o`000?lPgb3o8=lP00Ko8=lP1Ol000000om:]D[o0000ok5>/@0?ok5>
/@03o`000?o]4^gokA;]00_okA;]00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?om0_goo@;m00;o
o@;m1Ol00003ood2o@03o`000?of2OKomPWf00KomPWf00?o0000on8Mh_oR7N801_oR7N800ol0003o
fbCKom/Tf`04o`0000KoV6NH00?o0000og><LomcS7<01omcS7<00ol0003oA;]4odBkA005odBkA0?o
000000?o>/Djo`000?lWf2L01olWf2L00ol0003o8=lPob3O8005ob3O8003o`000?mQWV7oHIiQ00?o
HIiQ0_l0000?ok5>/@;o00003Oo]4^d00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ood2oOom0_d0
1oom0_d3o`0000WomPWf00?o0000on8Mh_oR7N801ooR7N82o`0000Co_T6n00Co0000oiQWV?nHIiSo
V6NH0_l0000:og><L`03o`000?m4^dCoA;]400;oA;]40ol00005oc[5>P03o`000?lWf2Oo9mPW00Go
9mPW00?o0000ob3O8?lPgb001?lPgb000ol0003oHIiQof6NH@06of6NH@03o`000?naC[7o/Dja00[o
/Dja0_l00002omHYeP03o`000?o]4^gokA;]00[okA;]00?o0000ooT6nOoi1_T02?oi1_T00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH01_of2OH00ol0003ohQgRon8MhP08on8MhP03o`00
0?nn@Kko_T6n00Co_T6n00?o0000oiQWV?l000003?mcS7<00ol0003oA;]4o`000002o`0000Wo>/Dj
00?o0000obOH9olWf2L01?lWf2L00ol0003o8=lPob3O8003ob3O8003o`000?mQWV7oHIiQ00SoHIiQ
1_l00004ok5>/@;o00001OoF:MH00ol0003okA;]ondBk@09ondBk@03o`000?oi1_Won@Ki00Son@Ki
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo@;mood2o@0:ood2o@03o`000?of2OKomPWf00GomPWf00?o0000on8Mh_oR7N801ooR
7N800ol0003o_T6noki1_P06oki1_P03o`000?mcS7?oLhac00coLhac00?o0000oc[5>_ljaCX02_lj
aCX00ol0003o9mPWobOH9`04obOH9`04o`000?lPgb3o8=lPob3O80;o00002omQWV400ol0003o]TVf
okI9]P03okI9]PCo00002?oF:MH00ol0003okA;]ondBk@08ondBk@03o`000?oi1_Won@Ki00Oon@Ki
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?om
0_goo@;m00_oo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003ohQgRon8MhP07on8MhP03o`000?nn
@Kko_T6n00Oo_T6n00?o0000og><LomcS7<03?mcS7<00ol0003o>/Djoc[5>P0;oc[5>P03o`000?lW
f2Oo9mPW00?o9mPW00Co0000ob3O8?lPgb3o00003OmQWV400ol0003o]TVfokI9]P06okI9]P03o`00
0?oF:MKoeRWF00OoeRWF00?o0000ondBkOo]4^d01oo]4^d00ol0003on@KiooT6n@06ooT6n@04o`00
0?on0OkooP7nooh1oP;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?of2OKomPWf00;omPWf00?o0000on8Mh_oR7N80
1_oR7N800ol0003o_T6noki1_P09oki1_P03o`000?mcS7?oLhac00WoLhac0_l0000>oc[5>P?o0000
0olWf2L00ol0003o8=lPo`00000=of6NH@03o`000?nfBKKo]TVf00Oo]TVf00?o0000omHYe_oF:MH0
2?oF:MH:o`0000Kon@Ki0_l00006ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ood2oOom0_d03Oom0_d6o`0000OohQgR00?o
0000oki1__nn@Kh02_nn@Kh00ol0003oLhacog><L`06og><L`;o000000?oKI9]o`000?ljaCX02olj
aCX2o`0000?oBkA;1Ol0000>of6NH@03o`000?nfBKKo]TVf00Oo]TVf00?o0000omHYe_oF:MH02?oF
:MH00ol0003ol@kaoo4>l@06oo4>l@03o`000?oi1_Won@Ki00?on@Ki00?o0000ooh1o_on0Oh01oon
0Oh2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ood2oOom0_d03Oom0_d00ol0003okQ7^onhAkP03onhAkPCo00000_oR7N800ol0003o_T6noki1_P0;
oki1_P03o`000?mcS7?oLhac00?oLhac0ol00004offBK@03o`000?ljaC[o>/Dj00Oo>/Dj0_l00008
od^dB`03o`000?mQWV7oHIiQ00goHIiQ00?o0000okI9]_nfBKH02?nfBKH00ol0003oeRWFomHYeP07
omHYeP03o`000?oa3_7ol@ka00Ool@ka0ol000000ooi1_Wo0000ooh1oP0;ooh1oP;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?o^4NkokQ7^00OokQ7^0_l0000?oki1_P03o`000?mcS7?oLhac00;o00002?m]TVd00ol0
003o>/Djoc[5>P05oc[5>P03o`000?m;]4_oBkA;00SoBkA;00?o0000of6NHOmQWV403OmQWV400ol0
003o]TVfokI9]P08okI9]P03o`000?oF:MKoeRWF00KoeRWF00?o0000oo4>lOoa3_402?oa3_401?l0
003onPGjooX5n_l0000?ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0003okQ7^onhAkP09onhA
kP03o`000?nn@Kko_T6n00ko_T6n0_l0000;offBK@03o`000?ljaC[o>/Dj00;o>/Dj0_l0000;od^d
B`03o`000?mQWV7oHIiQ00goHIiQ00?o0000okI9]_nfBKH02?nfBKH00ol0003oeRWFomHYeP06omHY
eP03o`000?oa3_7ol@ka00Ool@ka00Go0000ooX5n_oj1O[onPGjo`00000@ooh1oP;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2oOom0_d03Oom0_d00ol0
003okQ7^onhAkP0:onhAkP03o`000?nn@Kko_T6n00go_T6n0_l0000<offBK@04o`000?ljaC[o0000
o`0000goBkA;00?o0000of6NHOmQWV403?mQWV400ol0003o]TVfokI9]P09okI9]P03o`000?oF:MKo
eRWF00KoeRWF00?o0000oo4>lOoa3_401_oa3_400ol0003onPGjooX5nP03ooX5nP03o`000?on0Oko
oP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ood2
oOom0_d03Oom0_d00ol0003okQ7^onhAkP0:onhAkP03o`000?nn@Kko_T6n00co_T6n00Co0000okQ7
^?nhAkSo00003?m]TVd00ol0003oBkA;od^dB`0>od^dB`03o`000?mQWV7oHIiQ00SoHIiQ1?l0000;
okI9]P03o`000?oF:MKoeRWF00KoeRWF00?o0000oo4>lOoa3_401Ooa3_400ol0003onPGjooX5nP04
ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03?om0_d00ol0003okQ7^onhAkP0;onhAkP03o`000?nn@Kko_T6n
00_o_T6n00?o0000okQ7^?nhAkP00_nhAkP00ol0003oKI9]offBK@09offBK@03o`000?m;]4_oBkA;
00koBkA;00Co0000of6NHOmQWV7oHIiQ1ol00003oh=lP`03o`000?nfBKKo]TVf00Wo]TVf00?o0000
omHYe_oF:MH01_oF:MH00ol0003ol@kaoo4>l@04oo4>l@03o`000?oj1O[onPGj00KonPGj00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo@;mood2o@0<ood2o@03o`000?o^4NkokQ7^00cokQ7^00?o0000oki1__nn@Kh02_nn@Kh00ol0
003o^4NhokQ7^003okQ7^003o`000?m]TVgoKI9]00SoKI9]00?o0000od^dBom;]4/03_m;]4/4o`00
00_oPgb300?o0000okI9]_nfBKH02?nfBKH00ol0003oeRWFomHYeP05omHYeP03o`000?oa3_7ol@ka
00Gol@ka00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?om0_goo@;m00coo@;m00?o0000onhAk_o^
4Nh03?o^4Nh7o`0000Go_T6n00?o0000okQ7^?nhAkP01OnhAkP00ol0003oKI9]offBK@07offBK@03
o`000?m;]4_oBkA;00koBkA;00?o0000oh=lPon3O8<03On3O8<00ol0003o]TVfokI9]P08okI9]P03
o`000?oF:MKoeRWF00CoeRWF00?o0000oo4>lOoa3_401?oa3_400ol0003onPGjooX5nP07ooX5nP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ood2oOom0_d02_om0_d00ol0003okQ7^onhAkP0=onhAkP03o`000?oH9mSof2OH00Cof2OH
1Ol00009okQ7^003o`000?m]TVgoKI9]00KoKI9]00?o0000od^dBom;]4/03_m;]4/00ol0003oPgb3
oh=lP`0=oh=lP`03o`000?nfBKKo]TVf00So]TVf00Co0000omHYe_oF:MKoeRWF1Ol00004oo4>l@03
o`000?oj1O[onPGj00WonPGj1?l0000:ooh1oP03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?om0_goo@;m00Soo@;m0ol0000=onhAkP03o`000?oH9mSof2OH00Wof2OH
0_l00009okQ7^003o`000?m]TVgoKI9]00KoKI9]00?o0000od^dBom;]4/03?m;]4/00ol0003oPgb3
oh=lP`0?oh=lP`Ko00001?nfBKH4o`0000Gok1?/0_l000000ooa3_7o0000ooX5nP0;ooX5nP04o`00
0?on0OkooP7nooh1oPOo00000oon0Oh00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo@;mood2o@06ood2o@04o`000?og2?Oom`SgooL8m`?o00002_o^4Nh00ol0003o
f2OHomPWf009omPWf003o`000?o6>LKo000000;o00001onhAkP00ol0003oKI9]offBK@05offBK@03
o`000?m;]4_oBkA;00SoBkA;1Ol0000Aoh=lP`03o`000?o3?<?o`cc300?o`cc31?l0000;on`Ck003
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh02Oon0Oh3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?om0_goo@;m00Coo@;m00?o0000ooL8moog2?L01Oog2?L2o`0000OokQ7^
00?o0000omPWf?oH9mP02_oH9mP00ol0003oaSW6olHiaP02olHiaP?o00001OnhAkP00ol0003oKI9]
offBK@04offBK@04o`000?m;]4_oBkA;od^dB`Oo00001?mlPg`00ol0003oPgb3oh=lP`0>oh=lP`03
o`000?o3?<?o`cc300Oo`cc300?o0000on`Ck?o/4n`02Oo/4n`00ol0003onPGjooX5nP09ooX5nP03
o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ood2oOom0_d00_om0_d00ol0003om`SgooL8m`08ooL8m`;o00001?o^4Nh00ol0003of2OH
omPWf00;omPWf003o`000?o6>LKoaSW600GoaSW60ol00003okQ7^004o`000?m]TVgoKI9]offBK@Ko
00003?mlPg`00ol0003oPgb3oh=lP`0=oh=lP`03o`000?o3?<?o`cc300Oo`cc300?o0000on`Ck?o/
4n`02_o/4n`00ol0003onPGjooX5nP08ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ooL8m`?o000000?okQ7^o`000?oH9mP0
3?oH9mP00ol0003oaSW6olHiaP08olHiaP?o000000Co^4Nho`000?l0003o00000_nfBKH00ol0003o
O8=logb3O00=ogb3O003o`000?n3O8?oPgb300coPgb300?o0000ol<l`oo3?<<02?o3?<<00ol0003o
k1?/on`Ck00;on`Ck003o`000?oj1O[onPGj00KonPGj00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
m`Sg00?o0000omPWf?oH9mP03?oH9mP00ol0003oaSW6olHiaP0;olHiaP03o`000?nfBKKo]TVf00?o
]TVf00?o0000ogb3O?mlPg`03?mlPg`00ol0003oSW6>o`00000=oh=lP`03o`000?o3?<?o`cc300So
`cc300?o0000on`Ck?o/4n`03?o/4n`3o`0000GonPGj00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?og2?Oom`Sg00com`Sg00?o0000omPWf?oH9mP03?oH9mP00ol0003oaSW6olHiaP0:olHiaP03o`00
0?nfBKKo]TVf00Go]TVf00?o0000ogb3O?mlPg`02_mlPg`01?l0003oSW6>ohiaS_n>LHh2o`0000[o
Pgb300?o0000ol<l`oo3?<<02Oo3?<<00ol0003ok1?/on`Ck00<on`Ck003o`000?oj1O[onPGj00?o
000000?onPGjo`000?on0Oh03oon0Oh00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?og2?Oom`Sg00_om`Sg00?o0000omPWf?oH9mP0
3?oH9mP00ol0003oaSW6olHiaP09olHiaP03o`000?nfBKKo]TVf00Ko]TVf00?o0000ogb3O?mlPg`0
2OmlPg`00ol0003oSW6>ohiaSP02ohiaSP03o`000?nhAkSo000000;o00001on3O8<00ol0003o`cc3
ol<l``09ol<l``03o`000?o/4ncok1?/00_ok1?/00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000ooL8moog2?L02oog2?L00ol0003of2OHomPWf00;omPWf003o`000?o6
>LKoaSW600SoaSW600?o0000okI9]_nfBKH01onfBKH00ol0003oO8=logb3O008ogb3O003o`000?n>
LHkoSW6>00?oSW6>00?o0000okQ7^?nhAkP00_nhAkP2o`0000CoPgb300?o0000ol<l`oo3?<<02_o3
?<<00ol0003ok1?/on`Ck00:on`Ck003o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?og2?Oom`Sg00[om`Sg0ol0000;omPWf0Ko00001?o6>LH00ol0003o]TVfokI9]P08
okI9]P03o`000?mlPgcoO8=l00OoO8=l00?o0000ohiaS_n>LHh00on>LHh00ol0003o^4NhokQ7^005
okQ7^0?o000000?oPgb3o`000?o3?<<02oo3?<<00ol0003ok1?/on`Ck009on`Ck003o`000?oj1O[o
nPGj00OonPGj00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o0000onl@
koo_4>l01?l00006omPWf003o`000?oJ9M[ofRGJ00CofRGJ1?l0000<okI9]P03o`000?mlPgcoO8=l
00GoO8=l00?o0000ohiaS_n>LHh01?n>LHh00ol0003o^4NhokQ7^008okQ7^003o`000?o3?<?o`cc3
00_o`cc300?o0000on`Ck?o/4n`02?o/4n`00ol0003onPGjooX5nP08ooX5nPGo00002_on0Oh00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?og2?Oom`Sg00Oom`Sg00?o0000onl@koo_4>l01Oo_4>l3o`0000;of2OH00?o0000omXUf_oJ
9MX02?oJ9MX00ol0003o]TVfokI9]P0:okI9]P03o`000?mlPgcoO8=l00CoO8=l00?o0000ohiaS_n>
LHh01On>LHh00ol0003o^4NhokQ7^008okQ7^003o`000?o3?<?o`cc300Wo`cc31?l00008on`Ck003
o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh00_on0Oh7o`0000?ooP7n00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003om`Sg
ooL8m`05ooL8m`03o`000?o_4>ooka3_00Woka3_0_l0000<omXUfP03o`000?nfBKKo]TVf00Wo]TVf
00?o0000ogb3O?mlPg`00omlPg`00ol0003oSW6>ohiaSP05ohiaSP03o`000?nhAkSo^4Nh00[o^4Nh
00?o0000ol<l`oo3?<<01?o3?<<4o`0000CoiaSW00?o0000on`Ck?o/4n`01?o/4n`00ol0003onPGj
ooX5nP0:ooX5nP03o`000?on0OkooP7n00WooP7n0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?og2?Oom`Sg00?om`Sg00?o0000onl@koo_4>l02oo_
4>l00ol0003ofRGJomXUfP0:omXUfP03o`000?nfBKKo]TVf00Wo]TVf00?o0000ogb3O?mlPg`00_ml
Pg`00ol0003oSW6>ohiaSP06ohiaSP03o`000?nhAkSo^4Nh00[o^4Nh00?o0000ol<l`oo3?<<01?l0
0009onLHi`Ko00003?oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000ooL8moog2?Oom`Sg0_l0
000=onl@k`03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000okI9]_nfBKH02OnfBKH01Ol0003oO8=logb3
O?mlPgco000000WoSW6>00?o0000okQ7^?nhAkP02onhAkP2o`0000goiaSW00?o0000ooT6nOoi1_T0
0_oi1_T00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om`Sgo`00
0002oo`3o0;o00002oo_4>l00ol0003ofRGJomXUfP0;omXUfP03o`000?nfBKKo]TVf00Wo]TVf00?o
0000ogb3O?l000002On>LHh00ol0003o^4NhokQ7^00<okQ7^003o`000?oW6>OoiaSW00coiaSW00?o
0000ooT6nOoi1_T00ooi1_T00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00gooP7n00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003oo0?loo`3o003oo`3o0;o00002_o_4>l00ol0003ofRGJomXUfP0:omXUfP03o`000?nfBKKo
]TVf00So]TVf1Ol00008ohiaSP03o`000?nhAkSo^4Nh00co^4Nh00?o0000onLHiooW6>L02ooW6>L0
0ol0003on@KiooT6n@05ooT6n@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001ool0o`2o`0000Soka3_00?o0000omXUf_oJ9MX02_oJ9MX00ol0003o]TVfokI9]P07okI9
]P03o`000?nl@kco_4>l00?o_4>l0ol00005ohiaSP03o`000?nhAkSo^4Nh00_o^4Nh00?o0000onLH
iooW6>L03?oW6>L00ol0003on@KiooT6n@06ooT6n@03o`000?oj1O[onPGj00OonPGj00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?on0Oko000000Woo0?l00?o0000onl@koo_4>l01Oo_4>l2o`0000co
fRGJ00?o0000okI9]_nfBKH01OnfBKH00ol0003o_4>loka3_007oka3_0?o000000?oSW6>o`000?nh
AkP03OnhAkP00ol0003oiaSWonLHi`0<onLHi`03o`000?oi1_Won@Ki00Kon@Ki00?o0000ooX5n_oj
1OX01_oj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ooh1oP03o`000?ol0ocoo0?l00Ooo0?l
0_l00004onl@k`03o`000?oc3??ol`cc00;o00002_oJ9MX00ol0003o]TVfokI9]P03okI9]P;o0000
3Onl@k`2o`0000go^4Nh0ol0000=onLHi`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooX5n_oj1OX0
1Ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00Soo0?l0_l0
00000oo_4>oo0000oo<<l`04oo<<l`03o`000?oJ9M[ofRGJ00OofRGJ00Co0000okI9]_nfBKKo]TVf
0_l00002omhQgP03o`000?nl@kco_4>l00co_4>l3Ol00003onTFj@03o`000?oW6>OoiaSW00[oiaSW
00?o0000ooT6nOoi1_T02?oi1_T01?l0003onPGjooX5n_oj1OX4o`0000kooP7n00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?on0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oc3??ol`cc00Gol`cc0_l00008omXUfP03o`000?nfBKKo000000GogR7N
00?o0000oka3_?nl@k`02onl@k`00ol0003ob3O8olPgb009olPgb003o`000?oY5^WojAKY00;ojAKY
0_l00009onLHi`03o`000?oi1_Won@Ki00[on@Ki0ol00004ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ooh1
oP0:ooh1oP03o`000?ol0ocoo0?l00Soo0?l00?o0000oo<<looc3?<01ooc3?<4o`0000?ofRGJ0ol0
0007omhQgP03o`000?nl@kco_4>l00[o_4>l00?o0000olPgb?o8=lP02Oo8=lP00ol0003ojAKYonTF
j@04onTFj@;o00001ooW6>L00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00GooP7n00?o
0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo<<looc3?<02?oc3?<0
1?l0003ol`ccoo<<looc3?<3o`0000;ok1?/00?o0000omhQg_oN8Mh01_oN8Mh00ol0003o_4>loka3
_008oka3_003o`000?o8=lSob3O800[ob3O800?o0000onTFjOoY5^T01_oY5^T00ol0003oiaSWonLH
i`04onLHi`03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1
oP07ooh1oP03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?on0Oko
oP7n00_ooP7n00?o0000oo`3o?ol0o`01Ool0o`00ol0003ol`ccoo<<l`08oo<<l`03o`000?oc3??o
l`cc00Col`cc00Go0000on`Ck?o/4ncok1?/o`000008omhQgP03o`000?nl@kco_4>l00Oo_4>l00?o
0000olPgb?o8=lP02_o8=lP00ol0003ojAKYonTFj@07onTFj@;o00001?oW6>L00ol0003on@KiooT6
n@08ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`00ool0o`0
0ol0003ol`ccoo<<l`08oo<<l`03o`000?oc3??ol`cc00Col`cc00?o0000on`Ck?o/4n`00_o/4n`0
0ol0003ogR7NomhQgP07omhQgP03o`000?nl@kco_4>l00Ko_4>l00?o0000olPgb?o8=lP02_o8=lP0
0ol0003ojAKYonTFj@09onTFj@05o`000?oW6>OoiaSWonLHiol000002Ooi1_T00ol0003ooP7nooh1
oP0;ooh1oP03o`000?on0OkooP7n00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ooh1o_on0Oh03Oon0Oh5o`0000_ol`cc00?o0000oo<<looc3?<01?oc3?<00ol0003ok1?/on`Ck003
on`Ck003o`000?oN8MkogR7N00OogR7N00?o0000oka3_?nl@k`01Onl@k`00ol0003ob3O8olPgb00:
olPgb003o`000?oY5^WojAKY00WojAKY1?l00009ooT6n@03o`000?on0OkooP7n00gooP7n0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003ooP7nooh1oP0<ooh1oP05o`000?ol0ocoo0?l
oo`3o?l000002_oc3?<00ol0003ol`ccoo<<l`05oo<<l`03o`000?o/4ncok1?/00?ok1?/00?o0000
omhQg_oN8Mh02?oN8Mh00ol0003o_4>loka3_004oka3_003o`000?o8=lSob3O800Wob3O800?o0000
onTFjOoY5^T02?oY5^T2o`0000?on@Ki00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0>
ooh1oP03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?on0OkooP7n
00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003ol`ccoo<<l`06oo<<l`03o`000?oc3??ol`cc
00Gol`cc00?o0000on`Ck?o/4n`01?o/4n`00ol0003ogR7NomhQgP09omhQgP03o`000?nl@kco_4>l
00;o_4>l00?o0000olPgb?o8=lP02_o8=lP00ol0003ojAKYonTFj@06onTFj@;o00001_oi1_T8o`00
017ooP7n00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ooh1o_on
0Oh02_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?oc3??ol`cc00Gol`cc00?o0000oo<<looc
3?<01Ooc3?<00ol0003ok1?/on`Ck005on`Ck003o`000?oN8MkogR7N00WogR7N00Go0000oka3_?nl
@kco_4>lo`00000<olPgb003o`000?oY5^WojAKY00CojAKY0_l00008ooT6n@03o`000?on0OkooP7n
00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo<<looc
3?<00ooc3?<00ol0003ol`ccoo<<l`06oo<<l`03o`000?o/4ncok1?/00Gok1?/00?o0000omhQg_oN
8Mh02_oN8Mh00ol0003o_4>lo`000004o`0000Wob3O800?o0000onTFjOoY5^T00_oY5^T2o`0000[o
n@Ki00?o0000ooh1o_on0Oh01Oon0Oh00ol0003ooP7nooh1oP0<ooh1oP;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o007oo`3o003o`00
0?oc3??ol`cc00;ol`cc00?o0000oo<<looc3?<01_oc3?<00ol0003ok1?/on`Ck007on`Ck0;o0000
2ooN8Mh00ol0003okQ7^onhAkP03onhAkPOo00000_o8=lP00ol0003ojAKYonTFj@02o`0000_on@Ki
00?o0000ooh1o_on0Oh01oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`02Ool
0o`01Ol0003ol`ccoo<<looc3??o000000Sol`cc00?o0000on`Ck?o/4n`01oo/4n`00ol0003omPWf
o`000002o`0000SogR7N00?o0000onhAk_o^4Nh02_o^4Nh5o`0000gon@Ki00?o0000ooh1o_on0Oh0
2?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?on0OkooP7n00?ooP7n0ol0000<oo`3o003o`000?oc3??o000000Wol`cc00?o
0000on`Ck?o/4n`01_o/4n`00ol0003omPWfooH9mP03ooH9mP?o00001?oN8Mh00ol0003okQ7^onhA
kP0=onhAkP03o`000?oi1_Won@Ki00gon@Ki00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1
oP06ooh1oP03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?on0Oko
000000;o00000ooo0?l2o`0000_oo0?l00?o0000oo<<looc3?<01ooc3?<00ol0003ok1?/on`Ck007
on`Ck003o`000?of2OKomPWf00KomPWf0ol000000ooN8Mko0000onhAkP0>onhAkP03o`000?oi1_Wo
n@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009oo`3
o003o`000?oc3??ol`cc00;ol`cc1_l00008on`Ck003o`000?of2OKomPWf00[omPWf00?o0000onhA
k_o^4Nh03oo^4Nh00ol0003on@KiooT6n@0:ooT6n@;o00003Oon0Oh00ol0003ooP7nooh1oP03ooh1
oP03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007oo`3o0Go00001_oi1_T00ol0003ok1?/on`Ck005on`Ck003o`000?of2OKomPWf00[o
mPWf00?o0000onhAk_o^4Nh03oo^4Nh00ol0003on@KiooT6n@07ooT6n@?o000000?ooP7no`000?on
0Oh03Oon0Oh01Ol0003ooP7nooh1o_on0Oko000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005oo`3o003o`000?oi1_Won@Ki00Won@Ki00?o0000on`Ck?o/
4n`00oo/4n`00ol0003omPWfooH9mP0;ooH9mP03o`000?o^4NkokQ7^00ookQ7^00?o0000ooT6nOoi
1_T01Ooi1_T2o`0000GooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7no`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo0?lo`000?l00000
3Ooi1_T00ol0003ok1?/on`Ck002on`Ck003o`000?of2OKomPWf00_omPWf5?l00004ooT6n@;o0000
2?on0Oh00ol0003ooP7nooh1oP0;ooh1oP;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003ooP7no`00000>ooT6n@04o`000?o/4ncok1?/o`0000komPWf
00?o0000ooX5n_oj1OX04?oj1OX00ol0003on@Kio`000002o`0000[ooP7n00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?on0OkooP7nooh1o_l000003_oi1_T00ol0003ok1?/o`00000>ooH9mP03o`00
0?oj1O[onPGj017onPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@0=ooT6n@03o`000?of2OKomPWf00WomPWf1Ol0
000BooX5nP;o00003oon0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh01?on0Oh0
0ol0003on@KiooT6n@0<ooT6n@03o`000?of2OKomPWf00;omPWf1ol00004ooh1oP03o`000?oj1O[o
nPGj00oonPGj00?o0000ooh1o_l000004?on0Oh00ol0003ooP7nooh1oP03ooh1oP;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1
oP03o`000?oi1_Won@Ki00con@Ki1?l0000<ooh1oP03o`000?oj1O[onPGj00conPGj0_l00003ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1oP04o`000?on0OkooP7no`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00kooP7n00?o0000ooX5n_oj
1OX02Ooj1OX2o`0000OooP7n00?o0000ooh1o_on0Oh03Oon0Oh3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000ooT6nOoi1_T02_oi1_T00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?oj1O[onPGj00KonPGj0_l0000:ooh1oP03o`000?on0OkooP7n00_ooP7n
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003ooP7n00gooP7n3?l0
000Aooh1oP?o00001_oj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00WooP7n0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000ooj1OX2o`0000kooP7n00?o
0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?on0Oko
oP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ooX5n_l000004Oon0Oh00ol0003ooP7nooh1oP04ooh1oP;o0000V?l00?l1
ooooo`00A_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1
o_on0Oh00oon0Oh00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?on0OkooP7n00[o
oP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ooh1oP03o`00
0?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000OooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ooh1
oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0<o`00o`;oool01?l00?l6oooo00Wo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`003?l00?l2oooo00Co003o0oooo`03o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000<o`00o`;oool02ol00?l2oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000<o`00o`;oool03?l00?l00oooo`3o003oo`00o`02o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo0005o`00o`coool02Ol00?l2oooo00?o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
1Ol00?l<oooo00Wo003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool01Ol00?l00oooo`3o003oo`00o`04o`00o`;oool0
3?l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00Ko003o00?oool0o`00ool00?l0
0ol00?l2oooo00_o003o0oooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`07o`00o`03oooo
0?l00?oo003o00;o003o0_ooo`0:o`00o`?oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_ooo`000ol00?ooool0oooo
0007o`00o`;oool00ol00?l2oooo00So003o1Oooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3
oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`08o`00o`04oooo0?l00?oo
003oo`00o`;oool01Ol00?l6oooo00Go003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02Ol00?l0
0oooo`3o003oo`00o`02oooo00Go003o1?ooo`07o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1W
o`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo
00[o003o00Coool0o`00ooooo`3oool01_l00?l00oooo`3o003oo`00o`07o`00o`;oool01_l00?l0
0oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00
o`;oool06?l00?l2oooo00[o003o00Coool0o`00ooooo`3oool01_l00?l00oooo`3o003oo`00o`08
o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo
00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00So003o0oooo`06o`00
o`03oooo0?l00?oo003o00So003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo001Wo`00
o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Wo
003o0_ooo`07o`00o`Koool01Ol00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol00?l1ooooo`00
I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo02Co003o0_ooo`07o`00o`Ooool0
1Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(460) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.982 .018 .982 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.983 .017 .983 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.975 .025 .975 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.964 .036 .964 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.989 .011 .989 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.961 .039 .961 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.912 .088 .912 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.927 .073 .927 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.854 .146 .854 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.95 .05 .95 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.988 .012 .988 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.991 .009 .991 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.981 .019 .981 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.73 .27 .73 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.961 .039 .961 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.899 .101 .899 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.895 .105 .895 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.917 .083 .917 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.942 .058 .942 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.966 .034 .966 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.873 .127 .873 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.939 .061 .939 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.804 .196 .804 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.963 .037 .963 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.934 .066 .934 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.889 .111 .889 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.935 .065 .935 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.773 .227 .773 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.953 .047 .953 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.89 .11 .89 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.964 .036 .964 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.818 .182 .818 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.501 .499 .501 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.585 .415 .585 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.987 .013 .987 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.986 .014 .986 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.938 .062 .938 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.849 .151 .849 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.862 .138 .862 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.544 .456 .544 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.524 .476 .524 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.444 .556 .444 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.83 .17 .83 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.851 .149 .851 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.995 .005 .995 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.825 .175 .825 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.75 .25 .75 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.976 .024 .976 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.657 .343 .657 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.955 .045 .955 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.91 .09 .91 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.55 .45 .55 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.478 .522 .478 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.766 .234 .766 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.199 .801 .199 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.206 .794 .206 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.264 .736 .264 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.622 .378 .622 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.606 .394 .606 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.952 .048 .952 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.218 .782 .218 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.22 .78 .22 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.859 .141 .859 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.975 .025 .975 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.994 .006 .994 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.386 .614 .386 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.465 .535 .465 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.785 .215 .785 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.994 .006 .994 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.795 .205 .795 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.428 .572 .428 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.731 .269 .731 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.162 .838 .162 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.61 .39 .61 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.44 .56 .44 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.98 .02 .98 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.049 .951 .049 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.135 .865 .135 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.926 .074 .926 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.047 .953 .047 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.035 .965 .035 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.721 .279 .721 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.944 .056 .944 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.253 .747 .253 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.003 .997 .003 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.071 .929 .071 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.576 .424 .576 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.135 .865 .135 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.276 .724 .276 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.963 .037 .963 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.017 .983 .017 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
0 1 0 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.154 .846 .154 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.239 .761 .239 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.874 .126 .874 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.303 .697 .303 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.372 .628 .372 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.042 .958 .042 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.009 .991 .009 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.007 .993 .007 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.498 .502 .498 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.747 .253 .747 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.853 .147 .853 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.205 .795 .205 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.134 .866 .134 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.571 .429 .571 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.981 .019 .981 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.162 .838 .162 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.154 .846 .154 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.705 .295 .705 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.135 .865 .135 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.021 .979 .021 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.934 .066 .934 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.98 .02 .98 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.73 .27 .73 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.793 .207 .793 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.084 .916 .084 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.931 .069 .931 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.387 .613 .387 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.478 .522 .478 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.085 .915 .085 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.298 .702 .298 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.525 .475 .525 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.96 .04 .96 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.084 .916 .084 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.117 .883 .117 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.042 .958 .042 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.917 .083 .917 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.272 .728 .272 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.977 .023 .977 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.191 .809 .191 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.167 .833 .167 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.178 .822 .178 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.773 .227 .773 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.802 .198 .802 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.72 .28 .72 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.025 .975 .025 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.295 .705 .295 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.45 .55 .45 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.702 .298 .702 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.907 .093 .907 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.971 .029 .971 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.267 .733 .267 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.532 .468 .532 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.19 .81 .19 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.89 .11 .89 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.843 .157 .843 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.714 .286 .714 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.925 .075 .925 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.975 .025 .975 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.225 .775 .225 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.357 .643 .357 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.964 .036 .964 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.213 .787 .213 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.782 .218 .782 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.562 .438 .562 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.632 .368 .632 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.417 .583 .417 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.94 .06 .94 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.921 .079 .921 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.93 .07 .93 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.948 .052 .948 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.535 .465 .535 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.98 .02 .98 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.878 .122 .878 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.452 .548 .452 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.516 .484 .516 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.741 .259 .741 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.677 .323 .677 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.978 .022 .978 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.897 .103 .897 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.974 .026 .974 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.554 .446 .554 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.956 .044 .956 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.862 .138 .862 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.812 .188 .812 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.786 .214 .786 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.688 .312 .688 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.995 .005 .995 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.794 .206 .794 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.99 .01 .99 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.663 .337 .663 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.992 .008 .992 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.769 .231 .769 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.993 .007 .993 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.877 .123 .877 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.932 .068 .932 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.893 .107 .893 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.935 .065 .935 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.954 .046 .954 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.884 .116 .884 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.753 .247 .753 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.871 .129 .871 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.925 .075 .925 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.956 .044 .956 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.945 .055 .945 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.954 .046 .954 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.991 .009 .991 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.901 .099 .901 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.977 .023 .977 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.982 .018 .982 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.965 .035 .965 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.911 .089 .911 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.977 .023 .977 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.954 .046 .954 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.957 .043 .957 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.969 .031 .969 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.994 .006 .994 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.993 .007 .993 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.994 .006 .994 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(470) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.983 .017 .983 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.984 .016 .984 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.976 .024 .976 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.965 .035 .965 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.989 .011 .989 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.963 .037 .963 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.915 .085 .915 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.93 .07 .93 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.859 .141 .859 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.953 .047 .953 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.988 .012 .988 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.991 .009 .991 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.982 .018 .982 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.738 .262 .738 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.963 .037 .963 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.904 .096 .904 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.9 .1 .9 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.921 .079 .921 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.944 .056 .944 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.968 .032 .968 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.878 .122 .878 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.941 .059 .941 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.811 .189 .811 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.964 .036 .964 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.936 .064 .936 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.893 .107 .893 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.938 .062 .938 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.779 .221 .779 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.955 .045 .955 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.894 .106 .894 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.965 .035 .965 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.824 .176 .824 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.51 .49 .51 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.595 .405 .595 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.987 .013 .987 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.987 .013 .987 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.941 .059 .941 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.854 .146 .854 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.867 .133 .867 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.552 .448 .552 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.531 .469 .531 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.454 .546 .454 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.836 .164 .836 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.856 .144 .856 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.83 .17 .83 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.757 .243 .757 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.977 .023 .977 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.665 .335 .665 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.958 .042 .958 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.913 .087 .913 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.558 .442 .558 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.489 .511 .489 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.774 .226 .774 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.21 .79 .21 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.215 .785 .215 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.269 .731 .269 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.631 .369 .631 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.616 .384 .616 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.955 .045 .955 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.224 .776 .224 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.224 .776 .224 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.864 .136 .864 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.976 .024 .976 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.994 .006 .994 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.396 .604 .396 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.477 .523 .477 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.794 .206 .794 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.994 .006 .994 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.801 .199 .801 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.436 .564 .436 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.742 .258 .742 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.169 .831 .169 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.62 .38 .62 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.453 .547 .453 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.981 .019 .981 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.049 .951 .049 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.143 .857 .143 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.929 .071 .929 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.051 .949 .051 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.039 .961 .039 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.729 .271 .729 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.946 .054 .946 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.258 .742 .258 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.008 .992 .008 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.076 .924 .076 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.585 .415 .585 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.141 .859 .141 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.286 .714 .286 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.964 .036 .964 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.021 .979 .021 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.004 .996 .004 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.158 .842 .158 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.251 .749 .251 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.88 .12 .88 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.311 .689 .311 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.38 .62 .38 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.038 .962 .038 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.01 .99 .01 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.009 .991 .009 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.511 .489 .511 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.755 .245 .755 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.857 .143 .857 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.211 .789 .211 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.129 .871 .129 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.585 .415 .585 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.982 .018 .982 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.17 .83 .17 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.155 .845 .155 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.71 .29 .71 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.145 .855 .145 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.021 .979 .021 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.937 .063 .937 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.981 .019 .981 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.738 .262 .738 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.801 .199 .801 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.086 .914 .086 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.933 .067 .933 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.396 .604 .396 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.48 .52 .48 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.088 .912 .088 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.305 .695 .305 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.535 .465 .535 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.961 .039 .961 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.079 .921 .079 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.117 .883 .117 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.046 .954 .046 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.921 .079 .921 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.279 .721 .279 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.978 .022 .978 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.193 .807 .193 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.166 .834 .166 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.177 .823 .177 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.78 .22 .78 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.805 .195 .805 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.729 .271 .729 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.027 .973 .027 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.305 .695 .305 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.462 .538 .462 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.71 .29 .71 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.91 .09 .91 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.972 .028 .972 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.275 .725 .275 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.544 .456 .544 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.193 .807 .193 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.893 .107 .893 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.849 .151 .849 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.722 .278 .722 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.928 .072 .928 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.976 .024 .976 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.234 .766 .234 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.366 .634 .366 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.965 .035 .965 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.22 .78 .22 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.789 .211 .789 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.564 .436 .564 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.642 .358 .642 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.423 .577 .423 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.943 .057 .943 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.925 .075 .925 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.933 .067 .933 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.95 .05 .95 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.546 .454 .546 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.981 .019 .981 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.882 .118 .882 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.46 .54 .46 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.524 .476 .524 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.746 .254 .746 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.687 .313 .687 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.979 .021 .979 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.9 .1 .9 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.975 .025 .975 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.565 .435 .565 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.957 .043 .957 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.867 .133 .867 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.819 .181 .819 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.792 .208 .792 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.696 .304 .696 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.995 .005 .995 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.797 .203 .797 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.99 .01 .99 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.669 .331 .669 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.777 .223 .777 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.882 .118 .882 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.935 .065 .935 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.897 .103 .897 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.936 .064 .936 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.956 .044 .956 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.888 .112 .888 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.759 .241 .759 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.875 .125 .875 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.928 .072 .928 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.958 .042 .958 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.947 .053 .947 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.956 .044 .956 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.991 .009 .991 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.905 .095 .905 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.978 .022 .978 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.983 .017 .983 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.967 .033 .967 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.914 .086 .914 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.978 .022 .978 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.955 .045 .955 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.959 .041 .959 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.97 .03 .97 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.993 .007 .993 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.994 .006 .994 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(480) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.995 .005 .995 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.984 .016 .984 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.985 .015 .985 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.977 .023 .977 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.967 .033 .967 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.99 .01 .99 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.965 .035 .965 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.918 .082 .918 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.933 .067 .933 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.991 .009 .991 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.863 .137 .863 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.955 .045 .955 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.988 .012 .988 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.991 .009 .991 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.983 .017 .983 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.746 .254 .746 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.965 .035 .965 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.908 .092 .908 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.904 .096 .904 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.924 .076 .924 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.946 .054 .946 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.969 .031 .969 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.883 .117 .883 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.944 .056 .944 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.818 .182 .818 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.966 .034 .966 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.938 .062 .938 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.897 .103 .897 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.94 .06 .94 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.784 .216 .784 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.957 .043 .957 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.899 .101 .899 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.966 .034 .966 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.829 .171 .829 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.52 .48 .52 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.604 .396 .604 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.988 .012 .988 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.987 .013 .987 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.944 .056 .944 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.995 .005 .995 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.859 .141 .859 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.872 .128 .872 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.56 .44 .56 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.537 .463 .537 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.464 .536 .464 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.841 .159 .841 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.861 .139 .861 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.835 .165 .835 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.763 .237 .763 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.978 .022 .978 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.673 .327 .673 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.96 .04 .96 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.916 .084 .916 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.566 .434 .566 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.499 .501 .499 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.781 .219 .781 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.22 .78 .22 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.224 .776 .224 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.275 .725 .275 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.641 .359 .641 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.626 .374 .626 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.957 .043 .957 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.23 .77 .23 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.228 .772 .228 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.869 .131 .869 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.977 .023 .977 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.406 .594 .406 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.489 .511 .489 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.803 .197 .803 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.994 .006 .994 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.806 .194 .806 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.445 .555 .445 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.751 .249 .751 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.177 .823 .177 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.63 .37 .63 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.466 .534 .466 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.982 .018 .982 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.048 .952 .048 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.151 .849 .151 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.932 .068 .932 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.054 .946 .054 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.042 .958 .042 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.736 .264 .736 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.947 .053 .947 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.264 .736 .264 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.013 .987 .013 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.08 .92 .08 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.594 .406 .594 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.146 .854 .146 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.295 .705 .295 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.966 .034 .966 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.024 .976 .024 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.008 .992 .008 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.164 .836 .164 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.263 .737 .263 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.885 .115 .885 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.319 .681 .319 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.388 .612 .388 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.034 .966 .034 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.011 .989 .011 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.012 .988 .012 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.524 .476 .524 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.764 .236 .764 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.86 .14 .86 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.217 .783 .217 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.124 .876 .124 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.599 .401 .599 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.983 .017 .983 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.179 .821 .179 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.156 .844 .156 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.716 .284 .716 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.155 .845 .155 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.022 .978 .022 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.939 .061 .939 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.982 .018 .982 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.746 .254 .746 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.809 .191 .809 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.088 .912 .088 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.935 .065 .935 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.405 .595 .405 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.481 .519 .481 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.092 .908 .092 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.311 .689 .311 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.545 .455 .545 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.994 .006 .994 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.963 .037 .963 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.075 .925 .075 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.117 .883 .117 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.05 .95 .05 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.924 .076 .924 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.287 .713 .287 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.979 .021 .979 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.197 .803 .197 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.166 .834 .166 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.176 .824 .176 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.787 .213 .787 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.808 .192 .808 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.737 .263 .737 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.03 .97 .03 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.315 .685 .315 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.473 .527 .473 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.719 .281 .719 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.914 .086 .914 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.973 .027 .973 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.282 .718 .282 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.555 .445 .555 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.196 .804 .196 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.896 .104 .896 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.855 .145 .855 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.73 .27 .73 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.93 .07 .93 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.977 .023 .977 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.243 .757 .243 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.376 .624 .376 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.967 .033 .967 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.227 .773 .227 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.795 .205 .795 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.567 .433 .567 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.652 .348 .652 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.428 .572 .428 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.945 .055 .945 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.928 .072 .928 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.936 .064 .936 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.953 .047 .953 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.556 .444 .556 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.982 .018 .982 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.886 .114 .886 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.468 .532 .468 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.533 .467 .533 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.75 .25 .75 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.696 .304 .696 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.98 .02 .98 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.903 .097 .903 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.976 .024 .976 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.576 .424 .576 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.959 .041 .959 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.871 .129 .871 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.825 .175 .825 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.799 .201 .799 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.705 .295 .705 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.8 .2 .8 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.991 .009 .991 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.675 .325 .675 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.785 .215 .785 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.887 .113 .887 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.938 .062 .938 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.902 .098 .902 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.938 .062 .938 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.957 .043 .957 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.892 .108 .892 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.764 .236 .764 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.879 .121 .879 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.93 .07 .93 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.959 .041 .959 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.95 .05 .95 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.958 .042 .958 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.991 .009 .991 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.909 .091 .909 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.979 .021 .979 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.983 .017 .983 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.968 .032 .968 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.918 .082 .918 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.979 .021 .979 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.956 .044 .956 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.961 .039 .961 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.993 .007 .993 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.971 .029 .971 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(490) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.985 .015 .985 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.985 .015 .985 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.978 .022 .978 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.968 .032 .968 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.99 .01 .99 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.966 .034 .966 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.921 .079 .921 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.936 .064 .936 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.868 .132 .868 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.957 .043 .957 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.989 .011 .989 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.991 .009 .991 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.984 .016 .984 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.754 .246 .754 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.966 .034 .966 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.913 .087 .913 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.909 .091 .909 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.927 .073 .927 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.947 .053 .947 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.97 .03 .97 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.887 .113 .887 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.946 .054 .946 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.825 .175 .825 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.967 .033 .967 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.94 .06 .94 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.9 .1 .9 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.942 .058 .942 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.789 .211 .789 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.958 .042 .958 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.903 .097 .903 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.967 .033 .967 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.835 .165 .835 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.53 .47 .53 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.613 .387 .613 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.988 .012 .988 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.988 .012 .988 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.946 .054 .946 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.864 .136 .864 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.877 .123 .877 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.567 .433 .567 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.543 .457 .543 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.474 .526 .474 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.846 .154 .846 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.865 .135 .865 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.84 .16 .84 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.769 .231 .769 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.979 .021 .979 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.681 .319 .681 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.962 .038 .962 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.92 .08 .92 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.574 .426 .574 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.509 .491 .509 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.787 .213 .787 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.23 .77 .23 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.233 .767 .233 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.281 .719 .281 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.65 .35 .65 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.635 .365 .635 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.959 .041 .959 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.237 .763 .237 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.233 .767 .233 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.874 .126 .874 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.978 .022 .978 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.416 .584 .416 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.5 .5 .5 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.811 .189 .811 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.994 .006 .994 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.812 .188 .812 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.453 .547 .453 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.761 .239 .761 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.184 .816 .184 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.639 .361 .639 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.478 .522 .478 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.983 .017 .983 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.048 .952 .048 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.158 .842 .158 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.935 .065 .935 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.058 .942 .058 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.046 .954 .046 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.744 .256 .744 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.949 .051 .949 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.269 .731 .269 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.018 .982 .018 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.085 .915 .085 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.603 .397 .603 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.152 .848 .152 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.305 .695 .305 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.967 .033 .967 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.028 .972 .028 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.012 .988 .012 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.169 .831 .169 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.275 .725 .275 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.889 .111 .889 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.328 .672 .328 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.396 .604 .396 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.031 .969 .031 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.013 .987 .013 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.016 .984 .016 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.536 .464 .536 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.772 .228 .772 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.994 .006 .994 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.864 .136 .864 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.223 .777 .223 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.12 .88 .12 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.612 .388 .612 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.983 .017 .983 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.188 .812 .188 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.157 .843 .157 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.722 .278 .722 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.164 .836 .164 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.022 .978 .022 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.942 .058 .942 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.982 .018 .982 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.753 .247 .753 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.816 .184 .816 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.09 .91 .09 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.937 .063 .937 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.413 .587 .413 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.483 .517 .483 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.096 .904 .096 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.318 .682 .318 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.555 .445 .555 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.964 .036 .964 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.071 .929 .071 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.118 .882 .118 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.055 .945 .055 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.928 .072 .928 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.294 .706 .294 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.98 .02 .98 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.2 .8 .2 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.166 .834 .166 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.175 .825 .175 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.794 .206 .794 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.811 .189 .811 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.745 .255 .745 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.034 .966 .034 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.325 .675 .325 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.484 .516 .484 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.727 .273 .727 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.917 .083 .917 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.974 .026 .974 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.289 .711 .289 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.565 .435 .565 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.199 .801 .199 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.899 .101 .899 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.86 .14 .86 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.994 .006 .994 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.737 .263 .737 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.933 .067 .933 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.978 .022 .978 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.252 .748 .252 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.385 .615 .385 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.968 .032 .968 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.236 .764 .236 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.802 .198 .802 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.569 .431 .569 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.661 .339 .661 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.434 .566 .434 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.947 .053 .947 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.93 .07 .93 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.938 .062 .938 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.955 .045 .955 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.566 .434 .566 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.983 .017 .983 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.89 .11 .89 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.477 .523 .477 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.541 .459 .541 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.754 .246 .754 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.705 .295 .705 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.981 .019 .981 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.906 .094 .906 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.977 .023 .977 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.587 .413 .587 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.96 .04 .96 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.875 .125 .875 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.83 .17 .83 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.995 .005 .995 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.805 .195 .805 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.713 .287 .713 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.803 .197 .803 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.991 .009 .991 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.681 .319 .681 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.792 .208 .792 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.892 .108 .892 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.94 .06 .94 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.906 .094 .906 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.94 .06 .94 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.958 .042 .958 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.895 .105 .895 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.769 .231 .769 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.883 .117 .883 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.932 .068 .932 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.96 .04 .96 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.952 .048 .952 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.959 .041 .959 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.991 .009 .991 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.913 .087 .913 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.98 .02 .98 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.984 .016 .984 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.969 .031 .969 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.922 .078 .922 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.98 .02 .98 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.958 .042 .958 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.963 .037 .963 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.972 .028 .972 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.993 .007 .993 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(500) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.985 .015 .985 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.986 .014 .986 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.979 .021 .979 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.969 .031 .969 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.99 .01 .99 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.968 .032 .968 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.995 .005 .995 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.924 .076 .924 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.938 .062 .938 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.872 .128 .872 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.958 .042 .958 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.989 .011 .989 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.991 .009 .991 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.985 .015 .985 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.761 .239 .761 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.968 .032 .968 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.916 .084 .916 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.913 .087 .913 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.931 .069 .931 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.949 .051 .949 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.971 .029 .971 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.892 .108 .892 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.948 .052 .948 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.831 .169 .831 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.968 .032 .968 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.942 .058 .942 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.903 .097 .903 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.945 .055 .945 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.794 .206 .794 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.96 .04 .96 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.906 .094 .906 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.968 .032 .968 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.84 .16 .84 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.539 .461 .539 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.622 .378 .622 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.989 .011 .989 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.989 .011 .989 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.949 .051 .949 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.868 .132 .868 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.881 .119 .881 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.575 .425 .575 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.55 .45 .55 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.483 .517 .483 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.851 .149 .851 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.87 .13 .87 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.844 .156 .844 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.775 .225 .775 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.98 .02 .98 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.688 .312 .688 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.964 .036 .964 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.923 .077 .923 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.581 .419 .581 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.518 .482 .518 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.793 .207 .793 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.239 .761 .239 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.242 .758 .242 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.288 .712 .288 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.658 .342 .658 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.644 .356 .644 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.961 .039 .961 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.243 .757 .243 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.238 .762 .238 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.878 .122 .878 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.979 .021 .979 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.425 .575 .425 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.512 .488 .512 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.818 .182 .818 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.817 .183 .817 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.461 .539 .461 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.769 .231 .769 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.192 .808 .192 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.648 .352 .648 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.49 .51 .49 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.983 .017 .983 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.049 .951 .049 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.166 .834 .166 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.938 .062 .938 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.062 .938 .062 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.051 .949 .051 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.751 .249 .751 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.951 .049 .951 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.275 .725 .275 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.023 .977 .023 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.089 .911 .089 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.612 .388 .612 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.157 .843 .157 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.314 .686 .314 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.969 .031 .969 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.032 .968 .032 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.016 .984 .016 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.174 .826 .174 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.287 .713 .287 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.894 .106 .894 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.337 .663 .337 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.405 .595 .405 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.028 .972 .028 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.014 .986 .014 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.019 .981 .019 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.548 .452 .548 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.78 .22 .78 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.867 .133 .867 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.229 .771 .229 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.116 .884 .116 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.624 .376 .624 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.984 .016 .984 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.006 .994 .006 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.197 .803 .197 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.159 .841 .159 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.727 .273 .727 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.174 .826 .174 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.024 .976 .024 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.945 .055 .945 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.983 .017 .983 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.761 .239 .761 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.823 .177 .823 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.093 .907 .093 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.939 .061 .939 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.422 .578 .422 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.486 .514 .486 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.1 .9 .1 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.325 .675 .325 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.564 .436 .564 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.965 .035 .965 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.067 .933 .067 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.119 .881 .119 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.06 .94 .06 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.931 .069 .931 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.302 .698 .302 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.981 .019 .981 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.204 .796 .204 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.167 .833 .167 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.175 .825 .175 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.801 .199 .801 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.814 .186 .814 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.753 .247 .753 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.037 .963 .037 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.335 .665 .335 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.495 .505 .495 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.734 .266 .734 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.92 .08 .92 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.995 .005 .995 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.975 .025 .975 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.297 .703 .297 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.575 .425 .575 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.203 .797 .203 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.902 .098 .902 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.865 .135 .865 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.744 .256 .744 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.936 .064 .936 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.979 .021 .979 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.261 .739 .261 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.394 .606 .394 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.969 .031 .969 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.244 .756 .244 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.808 .192 .808 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.572 .428 .572 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.67 .33 .67 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.44 .56 .44 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.949 .051 .949 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.933 .067 .933 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.94 .06 .94 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.957 .043 .957 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.576 .424 .576 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.983 .017 .983 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.894 .106 .894 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.485 .515 .485 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.55 .45 .55 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.758 .242 .758 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.714 .286 .714 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.994 .006 .994 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.981 .019 .981 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.908 .092 .908 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.978 .022 .978 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.597 .403 .597 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.961 .039 .961 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.879 .121 .879 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.836 .164 .836 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.81 .19 .81 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.72 .28 .72 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.806 .194 .806 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.991 .009 .991 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.996 .004 .996 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.687 .313 .687 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.8 .2 .8 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.897 .103 .897 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.943 .057 .943 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.91 .09 .91 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.941 .059 .941 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.96 .04 .96 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.899 .101 .899 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.775 .225 .775 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.887 .113 .887 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.934 .066 .934 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.962 .038 .962 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.953 .047 .953 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.961 .039 .961 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.991 .009 .991 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.916 .084 .916 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.981 .019 .981 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.993 .007 .993 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.985 .015 .985 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.97 .03 .97 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.925 .075 .925 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.981 .019 .981 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.959 .041 .959 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.965 .035 .965 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.973 .027 .973 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.994 .006 .994 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(510) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.995 .005 .995 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.986 .014 .986 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.994 .006 .994 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.987 .013 .987 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.98 .02 .98 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.97 .03 .97 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.99 .01 .99 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.969 .031 .969 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.926 .074 .926 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.941 .059 .941 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.876 .124 .876 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.96 .04 .96 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.989 .011 .989 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.985 .015 .985 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.768 .232 .768 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.969 .031 .969 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.92 .08 .92 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.916 .084 .916 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.933 .067 .933 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.951 .049 .951 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.972 .028 .972 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.896 .104 .896 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.95 .05 .95 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.837 .163 .837 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.969 .031 .969 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.944 .056 .944 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.907 .093 .907 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.947 .053 .947 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.799 .201 .799 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.961 .039 .961 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.91 .09 .91 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.969 .031 .969 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.844 .156 .844 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.548 .452 .548 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.63 .37 .63 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.989 .011 .989 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.989 .011 .989 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.951 .049 .951 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.873 .127 .873 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.885 .115 .885 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.582 .418 .582 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.556 .444 .556 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.493 .507 .493 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.856 .144 .856 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.874 .126 .874 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.849 .151 .849 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.781 .219 .781 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.98 .02 .98 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.695 .305 .695 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.965 .035 .965 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.925 .075 .925 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.589 .411 .589 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.527 .473 .527 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.799 .201 .799 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.249 .751 .249 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.251 .749 .251 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.294 .706 .294 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.666 .334 .666 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.653 .347 .653 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.963 .037 .963 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.25 .75 .25 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.243 .757 .243 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.883 .117 .883 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.98 .02 .98 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.434 .566 .434 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.522 .478 .522 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.825 .175 .825 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.822 .178 .822 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.469 .531 .469 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.777 .223 .777 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.199 .801 .199 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.658 .342 .658 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.502 .498 .502 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.984 .016 .984 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.049 .951 .049 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.173 .827 .173 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.941 .059 .941 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.067 .933 .067 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.055 .945 .055 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.758 .242 .758 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.952 .048 .952 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.282 .718 .282 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.028 .972 .028 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.094 .906 .094 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.62 .38 .62 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.163 .837 .163 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.324 .676 .324 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.97 .03 .97 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.037 .963 .037 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.02 .98 .02 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.18 .82 .18 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.298 .702 .298 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.898 .102 .898 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.345 .655 .345 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.413 .587 .413 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.025 .975 .025 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.016 .984 .016 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.023 .977 .023 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.559 .441 .559 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.787 .213 .787 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.871 .129 .871 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.236 .764 .236 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.113 .887 .113 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.636 .364 .636 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.985 .015 .985 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.013 .987 .013 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.205 .795 .205 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.161 .839 .161 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.732 .268 .732 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.183 .817 .183 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.025 .975 .025 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.947 .053 .947 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.984 .016 .984 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.768 .232 .768 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.829 .171 .829 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.096 .904 .096 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.94 .06 .94 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.431 .569 .431 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.488 .512 .488 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.104 .896 .104 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.332 .668 .332 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.574 .426 .574 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.966 .034 .966 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.064 .936 .064 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.12 .88 .12 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.066 .934 .066 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.934 .066 .934 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.31 .69 .31 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.982 .018 .982 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.209 .791 .209 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.168 .832 .168 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.175 .825 .175 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.808 .192 .808 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.817 .183 .817 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.76 .24 .76 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.041 .959 .041 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.345 .655 .345 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.505 .495 .505 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.742 .258 .742 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.923 .077 .923 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.976 .024 .976 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.305 .695 .305 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.585 .415 .585 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.207 .793 .207 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.905 .095 .905 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.87 .13 .87 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.751 .249 .751 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.938 .062 .938 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.98 .02 .98 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.27 .73 .27 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.404 .596 .404 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.97 .03 .97 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.253 .747 .253 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.814 .186 .814 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.575 .425 .575 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.678 .322 .678 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.446 .554 .446 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.951 .049 .951 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.935 .065 .935 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.943 .057 .943 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.959 .041 .959 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.586 .414 .586 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.984 .016 .984 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.897 .103 .897 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.494 .506 .494 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.558 .442 .558 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.995 .005 .995 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.762 .238 .762 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.722 .278 .722 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.982 .018 .982 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.911 .089 .911 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.979 .021 .979 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.607 .393 .607 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.963 .037 .963 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.883 .117 .883 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.841 .159 .841 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.816 .184 .816 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.728 .272 .728 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.809 .191 .809 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.991 .009 .991 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.693 .307 .693 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.807 .193 .807 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.901 .099 .901 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.945 .055 .945 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.914 .086 .914 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.942 .058 .942 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.961 .039 .961 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.902 .098 .902 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.78 .22 .78 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.891 .109 .891 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.936 .064 .936 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.963 .037 .963 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.955 .045 .955 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.963 .037 .963 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.92 .08 .92 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.982 .018 .982 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.985 .015 .985 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.971 .029 .971 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.928 .072 .928 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.981 .019 .981 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.96 .04 .96 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.967 .033 .967 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.974 .026 .974 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(520) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.996 .004 .996 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.996 .004 .996 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.987 .013 .987 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.987 .013 .987 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.98 .02 .98 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.971 .029 .971 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.99 .01 .99 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.97 .03 .97 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.929 .071 .929 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.943 .057 .943 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.88 .12 .88 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.962 .038 .962 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.989 .011 .989 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.986 .014 .986 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.775 .225 .775 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.924 .076 .924 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.92 .08 .92 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.936 .064 .936 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.952 .048 .952 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.973 .027 .973 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.9 .1 .9 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.952 .048 .952 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.843 .157 .843 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.97 .03 .97 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.946 .054 .946 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.91 .09 .91 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.948 .052 .948 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.804 .196 .804 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.963 .037 .963 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.913 .087 .913 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.97 .03 .97 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.849 .151 .849 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.557 .443 .557 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.638 .362 .638 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.99 .01 .99 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.953 .047 .953 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.877 .123 .877 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.889 .111 .889 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.589 .411 .589 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.562 .438 .562 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.502 .498 .502 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.86 .14 .86 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.878 .122 .878 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.853 .147 .853 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.787 .213 .787 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.981 .019 .981 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.701 .299 .701 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.967 .033 .967 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.928 .072 .928 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.597 .403 .597 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.536 .464 .536 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.804 .196 .804 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.258 .742 .258 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.259 .741 .259 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.301 .699 .301 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.674 .326 .674 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.661 .339 .661 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.964 .036 .964 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.257 .743 .257 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.248 .752 .248 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.887 .113 .887 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.981 .019 .981 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.443 .557 .443 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.533 .467 .533 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.832 .168 .832 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.826 .174 .826 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.477 .523 .477 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.785 .215 .785 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.206 .794 .206 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.666 .334 .666 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.514 .486 .514 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.985 .015 .985 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.05 .95 .05 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.18 .82 .18 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.944 .056 .944 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.072 .928 .072 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.059 .941 .059 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.765 .235 .765 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.954 .046 .954 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.288 .712 .288 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.033 .967 .033 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.099 .901 .099 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.629 .371 .629 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.169 .831 .169 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.333 .667 .333 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.971 .029 .971 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.041 .959 .041 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.025 .975 .025 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.186 .814 .186 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.309 .691 .309 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.902 .098 .902 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.354 .646 .354 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.422 .578 .422 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.022 .978 .022 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.018 .982 .018 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.026 .974 .026 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.571 .429 .571 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.795 .205 .795 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.874 .126 .874 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.243 .757 .243 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.11 .89 .11 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.648 .352 .648 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.985 .015 .985 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.02 .98 .02 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.214 .786 .214 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.163 .837 .163 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.738 .262 .738 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.193 .807 .193 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.995 .005 .995 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.027 .973 .027 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.949 .051 .949 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.984 .016 .984 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.775 .225 .775 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.836 .164 .836 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.1 .9 .1 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.942 .058 .942 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.439 .561 .439 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.491 .509 .491 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.109 .891 .109 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.339 .661 .339 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.583 .417 .583 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.967 .033 .967 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.061 .939 .061 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.121 .879 .121 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.072 .928 .072 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.937 .063 .937 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.317 .683 .317 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.983 .017 .983 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.214 .786 .214 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.169 .831 .169 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.175 .825 .175 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.814 .186 .814 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.82 .18 .82 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.767 .233 .767 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.046 .954 .046 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.354 .646 .354 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.515 .485 .515 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.749 .251 .749 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.926 .074 .926 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.977 .023 .977 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.312 .688 .312 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.594 .406 .594 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.212 .788 .212 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.908 .092 .908 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.875 .125 .875 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.758 .242 .758 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.94 .06 .94 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.981 .019 .981 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.279 .721 .279 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.413 .587 .413 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.971 .029 .971 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.261 .739 .261 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.819 .181 .819 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.578 .422 .578 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.686 .314 .686 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.452 .548 .452 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.952 .048 .952 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.937 .063 .937 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.945 .055 .945 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.96 .04 .96 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.595 .405 .595 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.985 .015 .985 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.901 .099 .901 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.502 .498 .502 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.566 .434 .566 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.767 .233 .767 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.73 .27 .73 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.983 .017 .983 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.913 .087 .913 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.979 .021 .979 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.617 .383 .617 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.964 .036 .964 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.887 .113 .887 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.846 .154 .846 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.822 .178 .822 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.735 .265 .735 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.812 .188 .812 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.991 .009 .991 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.698 .302 .698 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.993 .007 .993 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.814 .186 .814 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.994 .006 .994 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.905 .095 .905 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.947 .053 .947 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.917 .083 .917 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.944 .056 .944 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.962 .038 .962 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.906 .094 .906 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.785 .215 .785 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.895 .105 .895 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.938 .062 .938 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.964 .036 .964 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.957 .043 .957 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.964 .036 .964 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.923 .077 .923 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.983 .017 .983 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.986 .014 .986 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.972 .028 .972 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.931 .069 .931 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.982 .018 .982 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.961 .039 .961 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.968 .032 .968 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.975 .025 .975 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(530) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.987 .013 .987 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.988 .012 .988 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.981 .019 .981 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.972 .028 .972 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.971 .029 .971 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.931 .069 .931 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.945 .055 .945 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.992 .008 .992 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.883 .117 .883 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.963 .037 .963 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.989 .011 .989 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.987 .013 .987 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.781 .219 .781 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.971 .029 .971 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.927 .073 .927 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.923 .077 .923 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.939 .061 .939 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.954 .046 .954 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.974 .026 .974 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.996 .004 .996 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.903 .097 .903 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.954 .046 .954 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.848 .152 .848 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.972 .028 .972 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.948 .052 .948 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.913 .087 .913 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.95 .05 .95 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.808 .192 .808 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.964 .036 .964 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.916 .084 .916 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.997 .003 .997 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.971 .029 .971 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.854 .146 .854 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.566 .434 .566 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.646 .354 .646 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.99 .01 .99 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.955 .045 .955 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.88 .12 .88 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.893 .107 .893 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.597 .403 .597 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.568 .432 .568 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.511 .489 .511 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.865 .135 .865 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.882 .118 .882 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.996 .004 .996 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.857 .143 .857 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.793 .207 .793 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.982 .018 .982 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.707 .293 .707 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.968 .032 .968 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.931 .069 .931 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.604 .396 .604 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.545 .455 .545 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.809 .191 .809 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.267 .733 .267 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.268 .732 .268 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.308 .692 .308 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.682 .318 .682 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.67 .33 .67 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.966 .034 .966 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.264 .736 .264 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.254 .746 .254 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.891 .109 .891 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.981 .019 .981 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.452 .548 .452 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.543 .457 .543 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.838 .162 .838 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.831 .169 .831 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.485 .515 .485 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.792 .208 .792 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.213 .787 .213 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.675 .325 .675 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.525 .475 .525 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.986 .014 .986 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.052 .948 .052 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.187 .813 .187 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.946 .054 .946 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.077 .923 .077 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.064 .936 .064 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.772 .228 .772 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.955 .045 .955 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.295 .705 .295 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.038 .962 .038 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.104 .896 .104 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.637 .363 .637 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.175 .825 .175 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.342 .658 .342 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.973 .027 .973 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.046 .954 .046 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.029 .971 .029 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.192 .808 .192 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.321 .679 .321 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.906 .094 .906 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.363 .637 .363 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.43 .57 .43 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.02 .98 .02 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.021 .979 .021 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.03 .97 .03 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.582 .418 .582 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.801 .199 .801 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.877 .123 .877 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.25 .75 .25 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.107 .893 .107 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.659 .341 .659 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.986 .014 .986 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.028 .972 .028 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.223 .777 .223 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.166 .834 .166 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.743 .257 .743 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.202 .798 .202 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.029 .971 .029 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.951 .049 .951 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.985 .015 .985 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.782 .218 .782 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.842 .158 .842 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.104 .896 .104 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.944 .056 .944 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.448 .552 .448 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.494 .506 .494 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.113 .887 .113 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.346 .654 .346 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.592 .408 .592 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.968 .032 .968 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.058 .942 .058 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.123 .877 .123 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.078 .922 .078 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.94 .06 .94 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.325 .675 .325 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.983 .017 .983 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.219 .781 .219 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.171 .829 .171 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.176 .824 .176 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.82 .18 .82 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.823 .177 .823 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.774 .226 .774 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.05 .95 .05 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.363 .637 .363 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.525 .475 .525 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.756 .244 .756 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.929 .071 .929 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.978 .022 .978 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.32 .68 .32 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.603 .397 .603 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.216 .784 .216 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.911 .089 .911 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.88 .12 .88 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.764 .236 .764 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.942 .058 .942 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.982 .018 .982 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.288 .712 .288 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.422 .578 .422 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.972 .028 .972 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.271 .729 .271 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.825 .175 .825 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.582 .418 .582 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.694 .306 .694 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.458 .542 .458 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.954 .046 .954 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.939 .061 .939 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.947 .053 .947 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.962 .038 .962 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.604 .396 .604 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.985 .015 .985 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.904 .096 .904 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.511 .489 .511 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.574 .426 .574 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.771 .229 .771 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.738 .262 .738 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.984 .016 .984 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.916 .084 .916 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.98 .02 .98 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.627 .373 .627 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.965 .035 .965 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.89 .11 .89 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.851 .149 .851 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.827 .173 .827 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.742 .258 .742 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.815 .185 .815 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.704 .296 .704 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.82 .18 .82 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.908 .092 .908 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.949 .051 .949 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.921 .079 .921 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.945 .055 .945 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.963 .037 .963 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.909 .091 .909 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.79 .21 .79 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.898 .102 .898 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.94 .06 .94 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.966 .034 .966 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.959 .041 .959 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.965 .035 .965 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.926 .074 .926 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.983 .017 .983 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.987 .013 .987 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.973 .027 .973 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.934 .066 .934 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.983 .017 .983 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.962 .038 .962 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.97 .03 .97 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.976 .024 .976 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.995 .005 .995 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.994 .006 .994 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.995 .005 .995 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(540) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.988 .012 .988 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.988 .012 .988 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.982 .018 .982 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.973 .027 .973 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.973 .027 .973 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.933 .067 .933 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.947 .053 .947 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.887 .113 .887 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.965 .035 .965 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.987 .013 .987 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.787 .213 .787 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.972 .028 .972 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.93 .07 .93 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.926 .074 .926 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.941 .059 .941 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.955 .045 .955 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.975 .025 .975 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.907 .093 .907 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.955 .045 .955 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.853 .147 .853 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.973 .027 .973 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.95 .05 .95 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.916 .084 .916 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.952 .048 .952 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.813 .187 .813 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.965 .035 .965 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.919 .081 .919 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.972 .028 .972 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.858 .142 .858 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.575 .425 .575 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.654 .346 .654 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.991 .009 .991 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.99 .01 .99 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.957 .043 .957 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.884 .116 .884 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.896 .104 .896 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.604 .396 .604 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.575 .425 .575 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.519 .481 .519 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.868 .132 .868 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.886 .114 .886 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.861 .139 .861 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.798 .202 .798 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.983 .017 .983 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.712 .288 .712 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.97 .03 .97 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.933 .067 .933 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.612 .388 .612 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.553 .447 .553 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.813 .187 .813 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.276 .724 .276 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.276 .724 .276 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.315 .685 .315 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.689 .311 .689 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.677 .323 .677 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.967 .033 .967 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.271 .729 .271 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.26 .74 .26 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.895 .105 .895 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.982 .018 .982 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.995 .005 .995 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.46 .54 .46 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.553 .447 .553 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.844 .156 .844 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.835 .165 .835 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.493 .507 .493 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.799 .201 .799 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.221 .779 .221 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.683 .317 .683 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.536 .464 .536 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.986 .014 .986 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.053 .947 .053 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.194 .806 .194 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.948 .052 .948 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.082 .918 .082 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.069 .931 .069 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.778 .222 .778 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.957 .043 .957 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.301 .699 .301 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.043 .957 .043 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.109 .891 .109 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.645 .355 .645 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.181 .819 .181 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.351 .649 .351 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.974 .026 .974 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.051 .949 .051 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.034 .966 .034 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.198 .802 .198 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.332 .668 .332 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.91 .09 .91 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.372 .628 .372 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.439 .561 .439 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.018 .982 .018 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.023 .977 .023 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.034 .966 .034 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.592 .408 .592 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.808 .192 .808 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.88 .12 .88 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.257 .743 .257 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.104 .896 .104 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.67 .33 .67 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.986 .014 .986 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.035 .965 .035 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.232 .768 .232 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.169 .831 .169 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.748 .252 .748 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.212 .788 .212 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.031 .969 .031 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.953 .047 .953 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.986 .014 .986 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.788 .212 .788 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.847 .153 .847 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.108 .892 .108 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.945 .055 .945 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.456 .544 .456 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.497 .503 .497 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.118 .882 .118 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.353 .647 .353 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.601 .399 .601 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.995 .005 .995 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.969 .031 .969 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.055 .945 .055 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.125 .875 .125 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.084 .916 .084 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.942 .058 .942 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.332 .668 .332 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.984 .016 .984 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.224 .776 .224 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.173 .827 .173 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.177 .823 .177 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.826 .174 .826 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.826 .174 .826 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.78 .22 .78 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.054 .946 .054 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.372 .628 .372 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.534 .466 .534 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.762 .238 .762 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.932 .068 .932 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.979 .021 .979 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.327 .673 .327 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.612 .388 .612 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.221 .779 .221 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.913 .087 .913 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.884 .116 .884 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.77 .23 .77 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.945 .055 .945 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.982 .018 .982 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.297 .703 .297 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.431 .569 .431 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.973 .027 .973 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.28 .72 .28 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.83 .17 .83 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.585 .415 .585 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.702 .298 .702 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.465 .535 .465 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.956 .044 .956 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.941 .059 .941 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.948 .052 .948 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.964 .036 .964 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.613 .387 .613 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.986 .014 .986 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.907 .093 .907 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.519 .481 .519 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.582 .418 .582 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.775 .225 .775 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.745 .255 .745 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.984 .016 .984 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.918 .082 .918 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.981 .019 .981 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.636 .364 .636 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.966 .034 .966 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.894 .106 .894 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.856 .144 .856 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.832 .168 .832 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.749 .251 .749 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.818 .182 .818 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.71 .29 .71 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.827 .173 .827 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.912 .088 .912 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.951 .049 .951 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.924 .076 .924 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.947 .053 .947 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.965 .035 .965 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.912 .088 .912 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.795 .205 .795 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.901 .099 .901 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.942 .058 .942 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.967 .033 .967 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.96 .04 .96 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.967 .033 .967 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.929 .071 .929 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.987 .013 .987 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.973 .027 .973 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.937 .063 .937 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.984 .016 .984 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.964 .036 .964 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.971 .029 .971 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.994 .006 .994 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.977 .023 .977 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(550) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.988 .012 .988 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.989 .011 .989 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.982 .018 .982 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.974 .026 .974 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.974 .026 .974 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.936 .064 .936 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.949 .051 .949 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.89 .11 .89 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.966 .034 .966 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.988 .012 .988 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.793 .207 .793 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.973 .027 .973 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.932 .068 .932 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.929 .071 .929 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.943 .057 .943 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.957 .043 .957 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.976 .024 .976 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.91 .09 .91 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.957 .043 .957 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.858 .142 .858 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.974 .026 .974 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.951 .049 .951 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.918 .082 .918 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.953 .047 .953 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.817 .183 .817 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.966 .034 .966 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.922 .078 .922 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.973 .027 .973 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.862 .138 .862 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.583 .417 .583 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.662 .338 .662 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.991 .009 .991 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.959 .041 .959 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.887 .113 .887 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.899 .101 .899 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.611 .389 .611 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.581 .419 .581 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.527 .473 .527 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.872 .128 .872 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.889 .111 .889 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.865 .135 .865 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.803 .197 .803 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.983 .017 .983 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.717 .283 .717 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.971 .029 .971 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.936 .064 .936 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.619 .381 .619 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.561 .439 .561 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.818 .182 .818 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.285 .715 .285 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.284 .716 .284 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.323 .677 .323 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.695 .305 .695 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.685 .315 .685 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.969 .031 .969 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.279 .721 .279 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.265 .735 .265 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.899 .101 .899 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.983 .017 .983 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.468 .532 .468 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.563 .437 .563 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.85 .15 .85 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.84 .16 .84 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.501 .499 .501 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.805 .195 .805 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.227 .773 .227 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.691 .309 .691 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.547 .453 .547 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.987 .013 .987 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.055 .945 .055 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.201 .799 .201 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.95 .05 .95 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.087 .913 .087 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.073 .927 .073 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.784 .216 .784 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.958 .042 .958 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.308 .692 .308 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.049 .951 .049 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.114 .886 .114 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.653 .347 .653 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.186 .814 .186 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.36 .64 .36 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.975 .025 .975 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.057 .943 .057 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.038 .962 .038 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.204 .796 .204 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.342 .658 .342 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.913 .087 .913 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.38 .62 .38 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.447 .553 .447 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.017 .983 .017 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.026 .974 .026 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.038 .962 .038 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.603 .397 .603 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.814 .186 .814 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.995 .005 .995 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.883 .117 .883 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.264 .736 .264 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.102 .898 .102 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.68 .32 .68 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.987 .013 .987 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.042 .958 .042 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.241 .759 .241 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.172 .828 .172 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.753 .247 .753 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.221 .779 .221 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.033 .967 .033 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.955 .045 .955 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.986 .014 .986 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.794 .206 .794 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.853 .147 .853 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.112 .888 .112 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.947 .053 .947 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.465 .535 .465 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.5 .5 .5 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.122 .878 .122 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.36 .64 .36 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.61 .39 .61 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.97 .03 .97 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.053 .947 .053 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.127 .873 .127 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.091 .909 .091 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.945 .055 .945 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.34 .66 .34 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.985 .015 .985 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.23 .77 .23 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.175 .825 .175 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.178 .822 .178 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.831 .169 .831 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.829 .171 .829 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.787 .213 .787 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.059 .941 .059 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.381 .619 .381 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.543 .457 .543 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.769 .231 .769 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.934 .066 .934 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.98 .02 .98 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.335 .665 .335 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.62 .38 .62 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.226 .774 .226 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.916 .084 .916 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.888 .112 .888 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.776 .224 .776 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.947 .053 .947 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.983 .017 .983 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.307 .693 .307 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.44 .56 .44 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.974 .026 .974 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.289 .711 .289 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.835 .165 .835 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.589 .411 .589 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.709 .291 .709 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.471 .529 .471 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.957 .043 .957 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.943 .057 .943 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.95 .05 .95 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.965 .035 .965 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.622 .378 .622 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.987 .013 .987 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.91 .09 .91 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.528 .472 .528 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.59 .41 .59 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.778 .222 .778 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.752 .248 .752 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.985 .015 .985 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.92 .08 .92 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.982 .018 .982 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.645 .355 .645 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.967 .033 .967 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.897 .103 .897 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.861 .139 .861 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.837 .163 .837 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.756 .244 .756 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.996 .004 .996 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.821 .179 .821 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.715 .285 .715 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.833 .167 .833 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.915 .085 .915 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.953 .047 .953 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.927 .073 .927 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.948 .052 .948 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.966 .034 .966 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.915 .085 .915 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.799 .201 .799 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.905 .095 .905 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.943 .057 .943 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.968 .032 .968 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.961 .039 .961 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.968 .032 .968 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.931 .069 .931 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.985 .015 .985 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.988 .012 .988 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.974 .026 .974 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.939 .061 .939 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.984 .016 .984 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.965 .035 .965 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.972 .028 .972 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.978 .022 .978 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.994 .006 .994 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(560) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.996 .004 .996 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.989 .011 .989 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.989 .011 .989 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.983 .017 .983 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.975 .025 .975 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.975 .025 .975 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.938 .062 .938 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.951 .049 .951 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.893 .107 .893 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.967 .033 .967 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.992 .008 .992 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.988 .012 .988 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.799 .201 .799 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.974 .026 .974 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.935 .065 .935 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.932 .068 .932 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.945 .055 .945 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.958 .042 .958 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.977 .023 .977 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.913 .087 .913 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.958 .042 .958 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.862 .138 .862 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.974 .026 .974 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.953 .047 .953 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.921 .079 .921 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.955 .045 .955 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.822 .178 .822 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.967 .033 .967 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.925 .075 .925 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.974 .026 .974 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.866 .134 .866 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.591 .409 .591 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.669 .331 .669 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.991 .009 .991 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.96 .04 .96 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.996 .004 .996 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.89 .11 .89 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.902 .098 .902 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.618 .382 .618 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.587 .413 .587 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.535 .465 .535 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.876 .124 .876 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.893 .107 .893 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.869 .131 .869 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.808 .192 .808 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.984 .016 .984 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.722 .278 .722 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.972 .028 .972 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.938 .062 .938 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.626 .374 .626 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.568 .432 .568 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.822 .178 .822 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.293 .707 .293 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.292 .708 .292 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.33 .67 .33 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.702 .298 .702 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.692 .308 .692 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.97 .03 .97 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.286 .714 .286 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.271 .729 .271 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.902 .098 .902 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.983 .017 .983 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.476 .524 .476 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.572 .428 .572 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.855 .145 .855 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.995 .005 .995 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.844 .156 .844 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.508 .492 .508 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.811 .189 .811 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.234 .766 .234 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.699 .301 .699 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.557 .443 .557 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.987 .013 .987 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.057 .943 .057 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.207 .793 .207 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.953 .047 .953 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.093 .907 .093 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.078 .922 .078 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.79 .21 .79 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.96 .04 .96 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.315 .685 .315 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.054 .946 .054 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.119 .881 .119 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.661 .339 .661 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.192 .808 .192 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.369 .631 .369 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.976 .024 .976 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.062 .938 .062 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.042 .958 .042 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.21 .79 .21 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.353 .647 .353 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.917 .083 .917 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.389 .611 .389 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.456 .544 .456 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.015 .985 .015 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.028 .972 .028 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.042 .958 .042 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.613 .387 .613 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.82 .18 .82 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.886 .114 .886 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.272 .728 .272 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.1 .9 .1 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.689 .311 .689 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.987 .013 .987 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.049 .951 .049 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.25 .75 .25 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.175 .825 .175 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.758 .242 .758 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.23 .77 .23 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.035 .965 .035 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.957 .043 .957 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.987 .013 .987 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.8 .2 .8 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.858 .142 .858 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.117 .883 .117 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.948 .052 .948 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.473 .527 .473 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.503 .497 .503 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.127 .873 .127 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.367 .633 .367 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.618 .382 .618 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.995 .005 .995 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.971 .029 .971 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.052 .948 .052 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.129 .871 .129 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.097 .903 .097 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.947 .053 .947 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.347 .653 .347 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.985 .015 .985 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.236 .764 .236 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.177 .823 .177 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.179 .821 .179 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.836 .164 .836 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.831 .169 .831 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.793 .207 .793 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.064 .936 .064 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.389 .611 .389 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.551 .449 .551 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.775 .225 .775 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.936 .064 .936 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.981 .019 .981 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.342 .658 .342 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.627 .373 .627 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.231 .769 .231 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.918 .082 .918 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.892 .108 .892 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.995 .005 .995 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.781 .219 .781 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.948 .052 .948 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.984 .016 .984 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.316 .684 .316 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.448 .552 .448 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.975 .025 .975 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.299 .701 .299 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.839 .161 .839 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.592 .408 .592 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.716 .284 .716 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.478 .522 .478 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.959 .041 .959 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.945 .055 .945 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.951 .049 .951 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.966 .034 .966 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.631 .369 .631 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.987 .013 .987 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.913 .087 .913 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.536 .464 .536 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.598 .402 .598 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.782 .218 .782 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.759 .241 .759 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.986 .014 .986 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.922 .078 .922 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.982 .018 .982 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.654 .346 .654 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.968 .032 .968 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.9 .1 .9 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.865 .135 .865 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.996 .004 .996 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.842 .158 .842 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.762 .238 .762 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.824 .176 .824 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.721 .279 .721 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.838 .162 .838 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.918 .082 .918 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.955 .045 .955 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.93 .07 .93 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.949 .051 .949 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.967 .033 .967 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.918 .082 .918 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.804 .196 .804 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.908 .092 .908 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.945 .055 .945 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.969 .031 .969 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.963 .037 .963 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.969 .031 .969 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.992 .008 .992 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.934 .066 .934 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.985 .015 .985 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.994 .006 .994 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.988 .012 .988 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.975 .025 .975 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.942 .058 .942 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.985 .015 .985 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.966 .034 .966 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.974 .026 .974 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.979 .021 .979 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(570) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.989 .011 .989 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.99 .01 .99 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.984 .016 .984 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.976 .024 .976 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.976 .024 .976 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.94 .06 .94 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.953 .047 .953 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.897 .103 .897 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.968 .032 .968 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.989 .011 .989 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.805 .195 .805 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.974 .026 .974 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.938 .062 .938 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.934 .066 .934 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.947 .053 .947 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.959 .041 .959 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.978 .022 .978 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.916 .084 .916 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.96 .04 .96 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.866 .134 .866 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.975 .025 .975 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.954 .046 .954 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.923 .077 .923 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.956 .044 .956 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.826 .174 .826 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.968 .032 .968 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.927 .073 .927 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.975 .025 .975 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.869 .131 .869 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.599 .401 .599 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.676 .324 .676 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.992 .008 .992 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.962 .038 .962 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.893 .107 .893 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.905 .095 .905 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.625 .375 .625 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.593 .407 .593 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.543 .457 .543 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.879 .121 .879 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.896 .104 .896 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.873 .127 .873 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.813 .187 .813 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.985 .015 .985 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.726 .274 .726 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.973 .027 .973 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.94 .06 .94 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.634 .366 .634 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.576 .424 .576 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.826 .174 .826 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.301 .699 .301 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.299 .701 .299 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.337 .663 .337 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.708 .292 .708 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.699 .301 .699 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.971 .029 .971 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.293 .707 .293 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.277 .723 .277 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.905 .095 .905 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.984 .016 .984 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.483 .517 .483 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.581 .419 .581 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.86 .14 .86 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.848 .152 .848 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.515 .485 .515 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.816 .184 .816 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.241 .759 .241 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.707 .293 .707 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.567 .433 .567 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.988 .012 .988 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.059 .941 .059 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.214 .786 .214 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.954 .046 .954 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.098 .902 .098 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.083 .917 .083 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.796 .204 .796 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.961 .039 .961 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.322 .678 .322 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.059 .941 .059 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.123 .877 .123 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.668 .332 .668 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.198 .802 .198 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.378 .622 .378 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.977 .023 .977 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.068 .932 .068 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.047 .953 .047 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.216 .784 .216 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.363 .637 .363 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.92 .08 .92 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.398 .602 .398 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.464 .536 .464 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.014 .986 .014 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.031 .969 .031 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.046 .954 .046 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.622 .378 .622 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.826 .174 .826 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.889 .111 .889 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.279 .721 .279 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.098 .902 .098 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.698 .302 .698 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.056 .944 .056 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.259 .741 .259 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.178 .822 .178 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.763 .237 .763 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.238 .762 .238 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.038 .962 .038 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.959 .041 .959 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.987 .013 .987 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.806 .194 .806 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.863 .137 .863 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.121 .879 .121 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.949 .051 .949 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.481 .519 .481 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.507 .493 .507 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.132 .868 .132 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.374 .626 .374 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.627 .373 .627 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
0 1 0 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.972 .028 .972 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.05 .95 .05 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.131 .869 .131 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.104 .896 .104 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.949 .051 .949 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.354 .646 .354 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.986 .014 .986 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.242 .758 .242 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.18 .82 .18 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.181 .819 .181 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.841 .159 .841 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.834 .166 .834 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.799 .201 .799 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.069 .931 .069 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.397 .603 .397 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.559 .441 .559 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.78 .22 .78 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.939 .061 .939 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.981 .019 .981 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.35 .65 .35 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.635 .365 .635 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.237 .763 .237 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.921 .079 .921 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.895 .105 .895 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.786 .214 .786 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.95 .05 .95 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.985 .015 .985 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.325 .675 .325 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.457 .543 .457 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.976 .024 .976 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.308 .692 .308 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.844 .156 .844 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.596 .404 .596 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.723 .277 .723 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.484 .516 .484 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.96 .04 .96 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.946 .054 .946 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.953 .047 .953 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.968 .032 .968 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.639 .361 .639 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.988 .012 .988 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.916 .084 .916 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.544 .456 .544 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.606 .394 .606 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.786 .214 .786 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.766 .234 .766 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.995 .005 .995 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.986 .014 .986 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.924 .076 .924 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.983 .017 .983 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.663 .337 .663 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.969 .031 .969 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.903 .097 .903 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.869 .131 .869 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.846 .154 .846 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.769 .231 .769 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.827 .173 .827 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.726 .274 .726 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.844 .156 .844 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.921 .079 .921 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.957 .043 .957 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.932 .068 .932 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.95 .05 .95 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.968 .032 .968 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.921 .079 .921 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.808 .192 .808 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.911 .089 .911 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.947 .053 .947 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.97 .03 .97 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.964 .036 .964 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.97 .03 .97 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.936 .064 .936 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.986 .014 .986 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.989 .011 .989 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.976 .024 .976 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.944 .056 .944 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.985 .015 .985 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.967 .033 .967 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.975 .025 .975 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.98 .02 .98 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.995 .005 .995 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(580) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.99 .01 .99 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.995 .005 .995 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.99 .01 .99 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.984 .016 .984 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.977 .023 .977 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.991 .009 .991 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.976 .024 .976 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.996 .004 .996 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.942 .058 .942 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.954 .046 .954 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.9 .1 .9 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.97 .03 .97 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.989 .011 .989 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.81 .19 .81 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.975 .025 .975 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.94 .06 .94 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.937 .063 .937 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.949 .051 .949 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.96 .04 .96 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.979 .021 .979 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.919 .081 .919 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.961 .039 .961 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.87 .13 .87 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.976 .024 .976 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.956 .044 .956 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.926 .074 .926 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.958 .042 .958 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.83 .17 .83 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.969 .031 .969 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.929 .071 .929 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.976 .024 .976 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.873 .127 .873 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.607 .393 .607 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.683 .317 .683 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.992 .008 .992 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.963 .037 .963 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.896 .104 .896 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.907 .093 .907 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.631 .369 .631 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.599 .401 .599 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.55 .45 .55 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.882 .118 .882 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.899 .101 .899 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.876 .124 .876 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.818 .182 .818 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.985 .015 .985 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.731 .269 .731 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.974 .026 .974 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.942 .058 .942 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.64 .36 .64 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.582 .418 .582 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.829 .171 .829 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.309 .691 .309 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.307 .693 .307 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.344 .656 .344 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.714 .286 .714 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.706 .294 .706 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.973 .027 .973 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.301 .699 .301 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.283 .717 .283 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.909 .091 .909 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.985 .015 .985 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.49 .51 .49 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.59 .41 .59 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.864 .136 .864 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.852 .148 .852 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.522 .478 .522 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.821 .179 .821 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.247 .753 .247 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.714 .286 .714 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.576 .424 .576 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.988 .012 .988 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.062 .938 .062 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.22 .78 .22 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.956 .044 .956 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.104 .896 .104 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.087 .913 .087 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.802 .198 .802 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.962 .038 .962 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.329 .671 .329 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.063 .937 .063 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.128 .872 .128 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.676 .324 .676 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.204 .796 .204 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.386 .614 .386 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.978 .022 .978 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.073 .927 .073 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.051 .949 .051 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.222 .778 .222 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.373 .627 .373 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.923 .077 .923 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.406 .594 .406 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.473 .527 .473 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.013 .987 .013 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.034 .966 .034 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.05 .95 .05 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.632 .368 .632 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.832 .168 .832 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.892 .108 .892 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.287 .713 .287 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.096 .904 .096 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.707 .293 .707 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.063 .937 .063 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.267 .733 .267 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.181 .819 .181 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.767 .233 .767 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.247 .753 .247 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.041 .959 .041 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.96 .04 .96 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.988 .012 .988 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.812 .188 .812 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.867 .133 .867 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.126 .874 .126 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.951 .049 .951 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.489 .511 .489 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.51 .49 .51 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.137 .863 .137 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.381 .619 .381 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.635 .365 .635 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.005 .995 .005 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.973 .027 .973 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.049 .951 .049 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.134 .866 .134 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.111 .889 .111 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.951 .049 .951 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.361 .639 .361 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.986 .014 .986 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.249 .751 .249 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.183 .817 .183 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.182 .818 .182 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.846 .154 .846 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.837 .163 .837 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.804 .196 .804 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.074 .926 .074 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.405 .595 .405 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.567 .433 .567 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.786 .214 .786 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.941 .059 .941 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.996 .004 .996 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.982 .018 .982 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.357 .643 .357 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.642 .358 .642 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.242 .758 .242 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.923 .077 .923 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.899 .101 .899 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.791 .209 .791 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.952 .048 .952 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.985 .015 .985 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.333 .667 .333 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.465 .535 .465 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.977 .023 .977 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.318 .682 .318 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.848 .152 .848 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.6 .4 .6 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.73 .27 .73 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.491 .509 .491 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.961 .039 .961 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.948 .052 .948 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.954 .046 .954 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.969 .031 .969 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.647 .353 .647 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.988 .012 .988 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.919 .081 .919 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.553 .447 .553 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.613 .387 .613 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.79 .21 .79 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.772 .228 .772 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.987 .013 .987 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.926 .074 .926 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.983 .017 .983 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.671 .329 .671 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.97 .03 .97 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.906 .094 .906 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.873 .127 .873 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.851 .149 .851 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.775 .225 .775 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.829 .171 .829 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.992 .008 .992 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.731 .269 .731 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.994 .006 .994 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.849 .151 .849 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.924 .076 .924 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.958 .042 .958 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.935 .065 .935 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.952 .048 .952 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.969 .031 .969 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.924 .076 .924 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.813 .187 .813 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.913 .087 .913 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.948 .052 .948 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.971 .029 .971 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.965 .035 .965 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.971 .029 .971 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.939 .061 .939 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.987 .013 .987 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.989 .011 .989 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.946 .054 .946 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.986 .014 .986 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.968 .032 .968 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.976 .024 .976 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.981 .019 .981 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(590) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.99 .01 .99 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.99 .01 .99 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.985 .015 .985 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.978 .022 .978 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.977 .023 .977 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.944 .056 .944 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.956 .044 .956 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.903 .097 .903 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.971 .029 .971 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.99 .01 .99 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.99 .01 .99 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.815 .185 .815 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.976 .024 .976 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.942 .058 .942 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.939 .061 .939 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.951 .049 .951 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.962 .038 .962 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.98 .02 .98 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.921 .079 .921 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.962 .038 .962 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.874 .126 .874 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.977 .023 .977 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.957 .043 .957 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.928 .072 .928 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.959 .041 .959 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.834 .166 .834 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.97 .03 .97 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.931 .069 .931 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.977 .023 .977 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.876 .124 .876 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.615 .385 .615 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.689 .311 .689 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.992 .008 .992 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.992 .008 .992 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.965 .035 .965 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.899 .101 .899 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.91 .09 .91 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.638 .362 .638 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.605 .395 .605 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.558 .442 .558 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.885 .115 .885 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.902 .098 .902 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.88 .12 .88 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.822 .178 .822 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.986 .014 .986 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.735 .265 .735 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.975 .025 .975 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.944 .056 .944 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.647 .353 .647 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.589 .411 .589 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.833 .167 .833 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.317 .683 .317 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.314 .686 .314 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.352 .648 .352 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.719 .281 .719 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.712 .288 .712 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.974 .026 .974 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.308 .692 .308 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.289 .711 .289 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.912 .088 .912 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.985 .015 .985 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.497 .503 .497 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.599 .401 .599 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.869 .131 .869 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.856 .144 .856 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.529 .471 .529 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.826 .174 .826 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.254 .746 .254 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.722 .278 .722 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.586 .414 .586 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.064 .936 .064 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.226 .774 .226 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.958 .042 .958 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.11 .89 .11 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.092 .908 .092 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.807 .193 .807 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.963 .037 .963 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.337 .663 .337 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.068 .932 .068 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.133 .867 .133 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.683 .317 .683 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.21 .79 .21 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.395 .605 .395 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.979 .021 .979 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.079 .921 .079 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.055 .945 .055 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.228 .772 .228 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.383 .617 .383 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.926 .074 .926 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.415 .585 .415 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.481 .519 .481 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.012 .988 .012 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.037 .963 .037 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.054 .946 .054 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.641 .359 .641 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.837 .163 .837 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.895 .105 .895 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.295 .705 .295 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.095 .905 .095 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.715 .285 .715 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.07 .93 .07 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.276 .724 .276 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.004 .996 .004 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.185 .815 .185 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.772 .228 .772 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.256 .744 .256 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.043 .957 .043 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.962 .038 .962 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.988 .012 .988 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.817 .183 .817 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.872 .128 .872 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.131 .869 .131 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.952 .048 .952 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.497 .503 .497 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.514 .486 .514 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
0 1 0 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.142 .858 .142 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.388 .612 .388 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.643 .357 .643 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.009 .991 .009 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.974 .026 .974 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.047 .953 .047 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.137 .863 .137 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.118 .882 .118 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.952 .048 .952 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.368 .632 .368 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.987 .013 .987 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.255 .745 .255 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.187 .813 .187 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.184 .816 .184 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.851 .149 .851 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.84 .16 .84 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.81 .19 .81 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.079 .921 .079 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.413 .587 .413 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.575 .425 .575 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.791 .209 .791 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.943 .057 .943 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.983 .017 .983 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.364 .636 .364 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.649 .351 .649 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.248 .752 .248 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.925 .075 .925 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.902 .098 .902 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.796 .204 .796 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.954 .046 .954 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.986 .014 .986 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.342 .658 .342 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.474 .526 .474 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.978 .022 .978 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.328 .672 .328 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.852 .148 .852 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.603 .397 .603 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.736 .264 .736 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.497 .503 .497 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.962 .038 .962 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.949 .051 .949 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.955 .045 .955 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.97 .03 .97 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.655 .345 .655 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.989 .011 .989 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.922 .078 .922 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.561 .439 .561 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.62 .38 .62 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.996 .004 .996 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.794 .206 .794 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.778 .222 .778 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.987 .013 .987 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.928 .072 .928 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.984 .016 .984 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.679 .321 .679 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.971 .029 .971 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.909 .091 .909 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.877 .123 .877 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.855 .145 .855 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.78 .22 .78 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.832 .168 .832 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.737 .263 .737 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.855 .145 .855 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.926 .074 .926 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.96 .04 .96 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.937 .063 .937 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.953 .047 .953 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.97 .03 .97 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.926 .074 .926 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.817 .183 .817 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.916 .084 .916 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.95 .05 .95 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.972 .028 .972 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.967 .033 .967 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.972 .028 .972 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.941 .059 .941 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.987 .013 .987 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.99 .01 .99 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.977 .023 .977 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.948 .052 .948 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.986 .014 .986 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.969 .031 .969 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.977 .023 .977 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.981 .019 .981 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(600) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.996 .004 .996 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.99 .01 .99 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.991 .009 .991 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.985 .015 .985 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.979 .021 .979 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.978 .022 .978 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.945 .055 .945 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.957 .043 .957 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.993 .007 .993 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.905 .095 .905 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.972 .028 .972 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.99 .01 .99 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.82 .18 .82 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.976 .024 .976 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.944 .056 .944 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.941 .059 .941 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.952 .048 .952 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.963 .037 .963 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.98 .02 .98 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.924 .076 .924 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.964 .036 .964 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.878 .122 .878 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.978 .022 .978 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.958 .042 .958 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.93 .07 .93 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.96 .04 .96 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.838 .162 .838 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.971 .029 .971 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.933 .067 .933 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.977 .023 .977 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.88 .12 .88 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.622 .378 .622 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.696 .304 .696 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.993 .007 .993 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.966 .034 .966 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.901 .099 .901 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.912 .088 .912 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.644 .356 .644 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.611 .389 .611 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.565 .435 .565 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.888 .112 .888 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.905 .095 .905 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.883 .117 .883 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.826 .174 .826 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.986 .014 .986 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.738 .262 .738 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.976 .024 .976 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.946 .054 .946 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.654 .346 .654 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.595 .405 .595 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.836 .164 .836 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.324 .676 .324 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.321 .679 .321 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.359 .641 .359 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.724 .276 .724 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.719 .281 .719 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.975 .025 .975 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.315 .685 .315 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.295 .705 .295 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.915 .085 .915 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.986 .014 .986 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.504 .496 .504 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.607 .393 .607 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.873 .127 .873 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.86 .14 .86 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.536 .464 .536 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.831 .169 .831 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.26 .74 .26 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.729 .271 .729 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.595 .405 .595 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.067 .933 .067 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.231 .769 .231 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.96 .04 .96 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.115 .885 .115 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.097 .903 .097 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.812 .188 .812 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.964 .036 .964 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.344 .656 .344 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.073 .927 .073 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.138 .862 .138 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.69 .31 .69 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.216 .784 .216 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.403 .597 .403 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.979 .021 .979 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.085 .915 .085 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.06 .94 .06 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.235 .765 .235 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.392 .608 .392 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.928 .072 .928 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.423 .577 .423 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.49 .51 .49 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.012 .988 .012 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.04 .96 .04 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.059 .941 .059 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.649 .351 .649 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.842 .158 .842 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.897 .103 .897 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.302 .698 .302 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.094 .906 .094 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.723 .277 .723 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.989 .011 .989 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.078 .922 .078 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.284 .716 .284 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.008 .992 .008 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.188 .812 .188 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.777 .223 .777 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.264 .736 .264 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.046 .954 .046 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.963 .037 .963 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.989 .011 .989 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.822 .178 .822 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.876 .124 .876 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.137 .863 .137 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.953 .047 .953 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.505 .495 .505 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.517 .483 .517 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.001 .999 .001 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.147 .853 .147 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.394 .606 .394 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.65 .35 .65 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.014 .986 .014 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.975 .025 .975 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.047 .953 .047 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.139 .861 .139 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.125 .875 .125 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.954 .046 .954 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.375 .625 .375 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.987 .013 .987 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.262 .738 .262 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.19 .81 .19 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.186 .814 .186 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.855 .145 .855 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.842 .158 .842 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.815 .185 .815 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.084 .916 .084 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.42 .58 .42 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.582 .418 .582 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.796 .204 .796 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.945 .055 .945 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.983 .017 .983 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.372 .628 .372 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.655 .345 .655 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.254 .746 .254 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.927 .073 .927 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.905 .095 .905 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.8 .2 .8 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.955 .045 .955 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.986 .014 .986 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.996 .004 .996 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.351 .649 .351 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.482 .518 .482 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.978 .022 .978 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.337 .663 .337 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.856 .144 .856 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.607 .393 .607 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.742 .258 .742 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.504 .496 .504 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.964 .036 .964 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.95 .05 .95 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.956 .044 .956 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.971 .029 .971 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.662 .338 .662 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.989 .011 .989 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.924 .076 .924 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.569 .431 .569 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.627 .373 .627 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.797 .203 .797 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.784 .216 .784 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.988 .012 .988 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.93 .07 .93 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.985 .015 .985 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.687 .313 .687 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.972 .028 .972 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.912 .088 .912 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.881 .119 .881 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.859 .141 .859 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.786 .214 .786 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.835 .165 .835 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.742 .258 .742 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.86 .14 .86 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.995 .005 .995 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.928 .072 .928 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.961 .039 .961 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.94 .06 .94 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.954 .046 .954 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.971 .029 .971 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.929 .071 .929 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.821 .179 .821 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.919 .081 .919 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.951 .049 .951 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.973 .027 .973 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.968 .032 .968 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.973 .027 .973 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.943 .057 .943 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.988 .012 .988 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.99 .01 .99 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.978 .022 .978 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.95 .05 .95 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.987 .013 .987 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.969 .031 .969 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.977 .023 .977 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.982 .018 .982 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(610) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.991 .009 .991 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.991 .009 .991 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.986 .014 .986 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.979 .021 .979 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.979 .021 .979 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.947 .053 .947 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.959 .041 .959 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.908 .092 .908 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.973 .027 .973 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.99 .01 .99 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.825 .175 .825 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.977 .023 .977 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.946 .054 .946 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.943 .057 .943 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.954 .046 .954 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.964 .036 .964 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.981 .019 .981 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.926 .074 .926 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.965 .035 .965 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.881 .119 .881 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.978 .022 .978 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.96 .04 .96 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.933 .067 .933 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.961 .039 .961 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.841 .159 .841 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.972 .028 .972 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.935 .065 .935 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.978 .022 .978 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.883 .117 .883 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.629 .371 .629 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.702 .298 .702 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.993 .007 .993 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.967 .033 .967 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.904 .096 .904 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.914 .086 .914 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.651 .349 .651 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.617 .383 .617 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.571 .429 .571 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.891 .109 .891 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.908 .092 .908 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.886 .114 .886 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.831 .169 .831 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.987 .013 .987 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.742 .258 .742 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.977 .023 .977 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.948 .052 .948 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.661 .339 .661 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.601 .399 .601 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.839 .161 .839 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.331 .669 .331 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.327 .673 .327 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.367 .633 .367 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.729 .271 .729 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.724 .276 .724 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.976 .024 .976 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.323 .677 .323 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.301 .699 .301 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.917 .083 .917 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.986 .014 .986 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.51 .49 .51 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.614 .386 .614 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.876 .124 .876 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.863 .137 .863 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.542 .458 .542 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.835 .165 .835 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.266 .734 .266 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.735 .265 .735 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.603 .397 .603 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.07 .93 .07 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.237 .763 .237 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.961 .039 .961 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.121 .879 .121 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.102 .898 .102 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.817 .183 .817 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.965 .035 .965 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.351 .649 .351 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.078 .922 .078 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.143 .857 .143 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.697 .303 .697 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.221 .779 .221 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.411 .589 .411 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.98 .02 .98 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.091 .909 .091 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.064 .936 .064 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.241 .759 .241 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.401 .599 .401 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.931 .069 .931 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.431 .569 .431 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.498 .502 .498 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.011 .989 .011 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.043 .957 .043 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.063 .937 .063 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.658 .342 .658 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.847 .153 .847 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.9 .1 .9 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.31 .69 .31 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.093 .907 .093 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.731 .269 .731 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.989 .011 .989 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.084 .916 .084 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.292 .708 .292 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.012 .988 .012 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.192 .808 .192 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.781 .219 .781 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.272 .728 .272 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.049 .951 .049 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.965 .035 .965 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.989 .011 .989 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.827 .173 .827 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.88 .12 .88 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.142 .858 .142 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.954 .046 .954 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.512 .488 .512 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.521 .479 .521 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.006 .994 .006 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.152 .848 .152 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.401 .599 .401 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.658 .342 .658 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.018 .982 .018 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.975 .025 .975 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.046 .954 .046 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.142 .858 .142 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.133 .867 .133 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.956 .044 .956 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.382 .618 .382 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.269 .731 .269 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.194 .806 .194 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.188 .812 .188 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.86 .14 .86 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.845 .155 .845 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.82 .18 .82 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.089 .911 .089 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.427 .573 .427 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.589 .411 .589 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.801 .199 .801 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.947 .053 .947 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.984 .016 .984 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.379 .621 .379 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.661 .339 .661 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.259 .741 .259 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.929 .071 .929 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.908 .092 .908 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.805 .195 .805 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.957 .043 .957 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.987 .013 .987 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.359 .641 .359 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.49 .51 .49 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.979 .021 .979 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.347 .653 .347 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.859 .141 .859 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.611 .389 .611 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.748 .252 .748 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.51 .49 .51 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.965 .035 .965 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.951 .049 .951 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.957 .043 .957 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.972 .028 .972 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.67 .33 .67 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.99 .01 .99 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.927 .073 .927 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.577 .423 .577 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.634 .366 .634 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.801 .199 .801 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.79 .21 .79 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.988 .012 .988 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.932 .068 .932 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.985 .015 .985 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.695 .305 .695 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.973 .027 .973 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.915 .085 .915 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.884 .116 .884 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.863 .137 .863 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.792 .208 .792 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.837 .163 .837 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.997 .003 .997 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.747 .253 .747 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.864 .136 .864 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.931 .069 .931 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.963 .037 .963 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.942 .058 .942 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.955 .045 .955 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.972 .028 .972 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.931 .069 .931 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.825 .175 .825 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.921 .079 .921 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.953 .047 .953 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.974 .026 .974 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.969 .031 .969 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.974 .026 .974 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.945 .055 .945 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.988 .012 .988 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.99 .01 .99 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.979 .021 .979 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.952 .048 .952 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.987 .013 .987 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.97 .03 .97 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.978 .022 .978 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.983 .017 .983 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.996 .004 .996 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.995 .005 .995 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooh1oP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_on0Oh2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0<ooh1oP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?on0OkooP7nooh1o_l000004Oon
0Oh01?l0003on`Ckoo/4nol0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh0
3_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?on0Oh03oon0Oh00ol0003ooP7nooh1oP02ooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000
ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00oooP7n00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n
00[ooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`06oo/4n`03
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0@ooh1oP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?on0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?on0OkooP7n00OooP7n
00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ooh1o_on0Oh04?on0Oh<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go0000013ooP7n00?o0000ooh1o_on0Oh02?on
0Oh9o`0000con`Ck00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?on0OkooP7n00oooP7n
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ood2o@03o`000?on
0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on@KiooT6n@05ooT6n@03o`000?ok
1?_on`Ck00_on`Ck0ol00003ooX5nP03o`000?on0OkooP7n00cooP7n0ol0000>ooh1oP;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ood2oOom0_d00oom0_d00ol0003ooP7nooh1oP0;ooh1oP;o00002oon0Oh00ol0003on@KiooT6n@06
ooT6n@03o`000?ok1?_on`Ck00[on`Ck00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oi1_Won@KiooT6n@;o00002_on0Oh2o`000003ooP7n?l0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@05ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOl000002oon0Oh00ol0003on@KiooT6n@06ooT6n@03o`000?ok1?_o
n`Ck00Won`Ck00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Wo
n@Ki00Con@Ki0_l00005ooh1oP?o00001?oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?on0OkooP7n00SooP7n0_l00008ood2o@03o`000?on0OkooP7n00OooP7n0_l00003ood2
o@03o`000?on0OkooP7n00OooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Won@Ki0_l000000oon
0Oko0000o`000007ooP7n003o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000SooP7n00?o0000ood2oOom
0_d02?om0_d00ol0003ooP7nooh1oP06ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000ooh1o_on
0Oh01oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?ok1?_on`Ck00Oon`Ck00?o0000ooX5n_oj
1OX02Ooj1OX00ol0003ooP7nooh1oP03ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000ooP7n?oh
1oP01ooh1oP00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?lo`000005ooh1oP;o00002oom0_d2o`0000KooP7n
00?o0000ood2oOom0_d01Oom0_d00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Son@Ki
00?o0000oo/4nook1?/01_ok1?/00ol0003onPGjooX5nP0;ooX5nP05o`000?on0OkooP7nooh1o_l0
00003_oi1_T00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?ol0ocoo0?loo`3o?l0
00000oon0Oh00ol0003oo@;mood2o@0:ood2o@04o`000?og2?Oom`Sgo`0000?ooP7n0_l00008ood2
o@03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003on`Ckoo/4n`05oo/4
n`03o`000?oj1O[onPGj00conPGj00?o0000ooh1o_l000003ooi1_T00ol0003on0OhooP7n008ooP7
n003o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o003oo`3o003o`000?on0Oko000000_o
o@;m0_l00004ooL8m`03o`000?on0Oko000000_oo@;m00?o0000ooh1o_on0Oh01Oon0Oh00ol0003o
n@KiooT6n@09ooT6n@03o`000?ok1?_on`Ck00Con`Ck00?o0000ooX5n_oj1OX03_oj1OX00ol0003o
n@KiooT6n@0>ooT6n@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d0
2_om0_d00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00[on@Ki00?o0000oo/4nook1?/0
0ook1?/00ol0003onPGjooX5nP0>ooX5nP03o`000?oi1_Won@Ki00gon@Ki00?o0000ooP7n?oh1oP0
2_oh1oP00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3
o005oo`3o003o`000?om0_goo@;m00Ooo@;m0_l00008ooL8m`03o`000?om0_goo@;m00_oo@;m00?o
0000ooh1o_on0Oh01?on0Oh00ol0003on@KiooT6n@0:ooT6n@04o`000?ok1?_on`Ckoo/4n`?o0000
3ooj1OX00ol0003on@KiooT6n@0>ooT6n@03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d01?om0_d2o`0000_om`Sg1?l0
0009ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ooT6nOoi1_T02ooi1_T01?l0003on`Cko`00
0?l00003ondBk@;o00003?oj1OX2o`00013on@Ki00?o0000ooP7n?oh1oP02ooh1oP00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?on0OkooP7nooh1oP?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo0?l
oo`3o007oo`3o003o`000?om0_goo@;m00?oo@;m00?o0000ooL8moog2?L02oog2?L01?l0003oiQWV
onHIi_oV6NH5o`0000Goo@;m00?o0000ooh1o_on0Oh00_on0Oh00ol0003on@KiooT6n@0<ooT6n@03
o`000?o]4^gokA;]00GokA;]0_l00008ooX5nP;o00000_o]4^d00ol0003on@KiooT6n@0=ooT6n@03
o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP05ooh1oP?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o009oo`3o003o`000?om0_goo@;m00;o0000
3Oog2?L00ol0003oiQWVonHIiP07onHIiPKo00000_on0Oh4o`0000gon@Ki00?o0000ondBkOo]4^d0
1oo]4^d2o`0000GonPGj00?o0000ondBkOo]4^d00oo]4^d00ol0003on@KiooT6n@0<ooT6n@03o`00
0?oh1oSon0Oh00con0Oh00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Woo0?l00?o
0000ood2oOl000003oog2?L00ol0003oiQWVonHIiP0<onHIiP?o00001?od2o@3o`0000Won@Ki00?o
0000ondBkOo]4^d02_o]4^d2o`000003ooX5n_l0003o000000OokA;]00?o0000ooT6nOoi1_T02ooi
1_T00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00KooP7n1?l0000<ooh1oP03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000
ooL8moog2?L03_og2?L00ol0003oiQWVonHIiP0=onHIiP03o`000?od2oCom0_d00Kom0_d0ol00005
ooT6n@03o`000?o]4^gokA;]00gokA;]00?o0000ondBkOo]4^d02?o]4^d00ol0003on@KiooT6n@09
ooT6n@03o`000?oh1oSon0Oh00gon0Oh00Co0000ooh1o_on0OkooP7n1Ol00003ooX5nP03o`000?on
0OkooP7n00_ooP7n00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
oo`3o?ol0o`02ool0o`2o`0000oom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0003om0_doo@;m00:
oo@;m0?o000000?on@Kio`000?o]4^d03oo]4^d00ol0003okA;]ondBk@09ondBk@03o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooP7n?oh1oP03_oh1oP3o`0000SonPGj00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?ol0ocoo0?l00Soo0?l0ol000000oob
3O;o0000ooL8m`0>ooL8m`03o`000?oV6NKoiQWV00goiQWV00?o0000oo@;m?od2o@03Ood2o@00ol0
003okA;]ondBk@0?ondBk@03o`000?o]4^gokA;]00[okA;]2ol0000;ooP7n0Go00003?oj1OX00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003onPGjo`000?oo0?oo0000
00Soo0?l0ol00005oo8=lP03o`000?og2?Oom`Sg00com`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0
003om0_doo@;m00=oo@;m0;o00004?o]4^d00ol0003okA;]ondBk@0:ondBk@03o`000?oZ5N[ojQGZ
00OojQGZ00?o0000ooP7n?oh1oP00_oh1oP7o`0000CokQ7^00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003onPGjooX5n_oj1OX2o`00
00Goo0?l0ol00009oo8=lP;o00002oog2?L00ol0003oiQWVonHIiP0=onHIiP03o`000?od2oCom0_d
00gom0_d00Co0000omPWf?oH9mSo00003oo]4^d00ol0003okA;]ondBk@09ondBk@03o`000?oZ5N[o
jQGZ00WojQGZ1?l0000;onhAkP03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oo0?lo`000002o`00
00colPgb00Co0000om`Sg?l0003o00002Oog2?L00ol0003oiQWVonHIiP0=onHIiP03o`000?od2oCo
m0_d00gom0_d00Go0000omPWf?oH9mSof2OHo`00000=ondBk@03o`000?o]4^gokA;]00[okA;]00?o
0000onXEj_oZ5NX02OoZ5NX00ol0003okQ7^onhAkP0<onhAkP03o`000?oj1O[onPGj00[onPGj00?o
0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01_oj1OX0
0ol0003olPgboo8=lP0<oo8=lP03o`000?oL8mcog2?L00;og2?L0_l00007ooL8m`03o`000?oV6NKo
iQWV00coiQWV00?o0000oo@;m?od2o@03Ood2o@00ol0003of2OHomPWf003omPWf003o`000?o]4^go
kA;]00[okA;]00?o0000ondBkOo]4^d02_o]4^d00ol0003ojQGZonXEjP09onXEjP03o`000?o^4Nko
kQ7^00cokQ7^00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?ob3O;olPgb00_olPgb00?o0000om`S
g?oL8m`01OoL8m`00ol0003om`SgooL8m`03ooL8m`03o`000?oV6NKoiQWV00goiQWV00?o0000oo@;
m?od2o@03Ood2o@00ol0003of2OHomPWf004omPWf003o`000?o]4^gokA;]00WokA;]00?o0000ondB
kOo]4^d02Oo]4^d00ol0003ojQGZonXEjP0:onXEjP03o`000?o^4NkokQ7^00cokQ7^00?o0000ooX5
n_oj1OX02ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP07ooX5nP03o`000?ob3O;olPgb00_olPgb00?o0000om`Sg?oL8m`01_oL8m`2o`0000?o
m`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0003om0_doo@;m00<oo@;m003o`000?oH9mSof2OH00Ko
f2OH00?o0000ondBkOo]4^d02?o]4^d00ol0003okA;]ondBk@09ondBk@03o`000?oZ5N[ojQGZ00[o
jQGZ00?o0000onhAk_o^4Nh03?o^4Nh00ol0003onPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00[o
oP7n00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ooX5n_oj1OX02?oj1OX00ol0003olPgboo8=lP0:oo8=lP03o`00
0?oL8mcog2?L00Wog2?L0_l000000oog2?Oo0000onHIiP0<onHIiP?o00003_od2o@00ol0003of2OH
omPWf007omPWf003o`000?o]4^gokA;]00OokA;]00?o0000ondBkOo]4^d02Oo]4^d00ol0003ojQGZ
onXEjP0;onXEjP03o`000?o^4NkokQ7^00cokQ7^00?o0000ooX5n_oj1OX02_oj1OX00ol0003ooP7n
ooh1oP08ooh1oP?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02_oj1OX00ol0003olPgboo8=
lP09oo8=lP03o`000?oL8mcog2?L00_og2?L00?o0000onHIi_oV6NH02_oV6NH2o`0000?oacS700?o
0000oo@;m?od2o@02_od2o@00ol0003of2OHomPWf009omPWf003o`000?o]4^gokA;]00KokA;]00?o
0000ondBkOo]4^d02?o]4^d00ol0003ojQGZonXEjP0<onXEjP03o`000?o^4NkokQ7^00cokQ7^00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ooP7nooh1oP04ooh1oPCo00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?oj1O[onPGj00_onPGj00?o0000oo8=l_ob3O802?ob3O80
0ol0003og2?Lom`Sg00<om`Sg003o`000?oV6NKoiQWV00SoiQWV0_l00006olLha`;o00002_od2o@0
0ol0003of2OHomPWf00:omPWf003o`000?o]4^gokA;]00GokA;]00?o0000ondBkOo]4^d02?o]4^d0
0ol0003ojQGZonXEjP0<onXEjP03o`000?o^4NkokQ7^00cokQ7^00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7no`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ooX5nP03o`000?ob3O;olPgb00OolPgb00?o0000om`Sg?oL8m`03_oL8m`00ol0003oiQWVonHIiP04
onHIiP?o00002_o7><L00ol0003om0_doo@;m007oo@;m003o`000?oH9mSof2OH00_of2OH00?o0000
ondBkOo]4^d00oo]4^d00ol0003okA;]ondBk@09ondBk@03o`000?oZ5N[ojQGZ00cojQGZ00?o0000
onhAk_o^4Nh03?o^4Nh00ol0003onPGjooX5nP0;ooX5nP;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?ob3O;olPgb00OolPgb00?o0000om`Sg?oL8m`03ooL8m`01?l0
003oiQWVonHIi_oV6NH2o`0000koacS70_l00006oo@;m003o`000?oH9mSof2OH00gof2OH00?o0000
ondBkOo]4^d00_o]4^d00ol0003okA;]ondBk@08ondBk@03o`000?oZ5N[ojQGZ00cojQGZ0ol0000=
onhAkP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00oonPGj00?o0000oo8=l_ob3O801_ob3O800ol0003og2?Lom`Sg00@om`Sg0Co00004_o7><L00ol0
003om0_doo@;m003oo@;m003o`000?oH9mSof2OH00kof2OH00Go0000ondBkOo]4^gokA;]o`000005
ondBk@Oo00003?oZ5NX01Ol0003ogB;MomdRgOoM8]go000000cokQ7^00?o0000ooX5n_oj1OX02?oj
1OX3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000oonPGj00?o0000oo8=l_ob3O801_ob3O800ol0003og2?Lom`Sg00=
om`Sg0?o000000Co_4>lo`000?l0003o00004oo7><L2o`0000;om0_d00?o0000omPWf?oH9mP04?oH
9mP00ol0003okA;]o`000006o`0000OocC;=00?o0000onXEj_oZ5NX02?oZ5NX00ol0003ogB;MomdR
g@03omdRg@;o00002?o^4Nh3o`0000KonPGj1?l00002ooP7n003o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003oo@;mo`000?o^4Nh3o`0000gonPGj00?o0000oo8=l_ob3O801?ob3O800ol0003og2?Lom`S
g00;om`Sg0?o00000onl@k`01Ol0003o/Tfbo`000?moP7oo000001CoacS700?o0000oo@;m?l00000
4ooH9mP00ol0003ocC;=oldbc@0=oldbc@03o`000?oZ5N[ojQGZ00GojQGZ0_l00008omdRg@03o`00
0?o^4NkokQ7^00Go00000oo[5>/00ol0003onPGjooX5nP03o`0000Oon0Oh00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?om0_goo@;mo`0000CokQ7^0ol0000:ooX5nP03o`000?ob3O;olPgb00?olPgb
00?o0000om`Sg?oL8m`02OoL8m`3o`0000Go_4>l00Co0000ok9=/_nbCK;o00000_moP7l00ol0003o
acS7olLha`0BolLha`03o`000?oH9mSof2OH01;of2OH00?o0000oldbcOo=</d03_o=</d00ol0003o
jQGZonXEjP03onXEjP03o`000?oM8]gogB;M00WogB;M0_l00009on/Dj`;o00002_oh1oP00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ood2oOom0_goo@;mo`000007onhAkP;o00001ooj1OX5o`0000;o
lPgb00?o0000om`Sg?oL8m`01_oL8m`3o`0000So_4>l00Co0000ok9=/_nbCK;o00000omoP7l00ol0
003oacS7olLha`0AolLha`03o`000?oH9mSof2OH017of2OH00?o0000oldbcOo=</d04?o=</d01Ol0
003ojQGZonXEj_oZ5N[o000000cogB;M00?o0000on/Djoo[5>/02?o[5>/00ol0003on0OhooP7n00:
ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000Coo@;m00?o0000onhAk_o^4Nh01oo^4Nh3o`00
0004ooX5n_l0003o0000o`0000GohQgR0_l00006om`Sg0?o00002_nl@k`01Ol0003o/Tfbok9=/_nb
CK;o000000CoOh1o00?o0000olLhaoo7><L04?o7><L00ol0003of2OHomPWf00AomPWf003o`000?o=
</gocC;=017ocC;=00?o0000onXEj_l000003OoM8]d00ol0003ojaC[on/Dj`08on/Dj`03o`000?oh
1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000
onhAk_o^4Nh02_o^4Nh00ol0003ohQgRon8MhP08on8MhP03o`000?oL8mcog2?L00?o00003Onl@k`0
1Ol0003o/Tfbok9=/_nbCK;o000000GoOh1o00?o0000olLhaoo7><L03oo7><L00ol0003of2OHomPW
f00AomPWf003o`000?o=</gocC;=01;ocC;=00?o0000omdRgOoM8]d03?oM8]d00ol0003ojaC[on/D
j`08on/Dj`03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ood2oOom0_d01Oom0_d0
0ol0003okQ7^onhAkP0:onhAkP03o`000?oR7N;ohQgR00WohQgR0_l0000?oka3_003o`000?nbCK;o
/Tfb00;o/Tfb00?o0000ogn0OomoP7l01?moP7l00ol0003oacS7olLha`0=olLha`?o00004OoH9mP0
0ol0003ocC;=oldbc@0Coldbc@03o`000?oM8]gogB;M00_ogB;M00?o0000on/Djoo[5>/02Oo[5>/0
0ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ool0o`;o00002?om0_d0
0ol0003okQ7^onhAkP0:onhAkP03o`000?oR7N;ohQgR00WohQgR00?o0000oka3_?nl@k`03Onl@k`0
0ol0003o/Tfbok9=/P03ok9=/P03o`000?moP7ooOh1o00GoOh1o00?o0000olLhaoo7><L02_o7><L2
o`0000?oQGZ500?o0000omPWf?oH9mP03_oH9mP00ol0003ocC;=oldbc@0Coldbc@03o`000?oM8]go
gB;M00_ogB;M00?o0000on/Djoo[5>/02Oo[5>/00ol0003on0OhooP7n00;ooP7n003o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000Goo`3o00?o0000ood2oOom0_d01oom0_d2o`0000_okQ7^00?o0000on8M
h_oR7N802ooR7N800ol0003o_4>loka3_00<oka3_003o`000?nbCK;o/Tfb00?o/Tfb00?o0000ogn0
OomoP7l01_moP7l00ol0003oacS7olLha`07olLha`;o00001_n5NXD2o`0000kof2OH00?o0000oldb
cOo=</d04oo=</d00ol0003ogB;MomdRg@0;omdRg@03o`000?o[5>_ojaC[00WojaC[00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ool0oooo0?ooo`3oo`000009ood2
o@03o`000?oj1O[o000000_okQ7^00?o0000on8Mh_oR7N802ooR7N800ol0003o_4>loka3_00;oka3
_003o`000?nbCK;o/Tfb00Co/Tfb00?o0000ogn0OomoP7l01omoP7l00ol0003oacS7olLha`05olLh
a`03o`000?n5NXGoQGZ500SoQGZ500?o0000omPWf?oH9mP02_oH9mP00ol0003ocC;=oldbc@0Doldb
c@03o`000?oM8]gogB;M00_ogB;M00?o0000on/Djoo[5>/02Oo[5>/00ol0003on0OhooP7n00<ooP7
n003o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oo`000009ood2o@04o`000?oj1O[onPGjo`00
00_okQ7^00?o0000on8Mh_oR7N802ooR7N800ol0003o_4>loka3_00;oka3_003o`000?nbCK;o/Tfb
00Co/Tfb00?o0000ogn0OomoP7l02?moP7l00ol0003oacS7olLha`02olLha`;o00003?n5NXD2o`00
00[of2OH00?o0000oldbcOo=</d05?o=</d00ol0003ogB;MomdRg@0;omdRg@03o`000?o[5>_ojaC[
00WojaC[00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03
o`000?oj1O[onPGj00;onPGj00?o0000onhAk_o^4Nh02?o^4Nh00ol0003ohQgRon8MhP0<on8MhP03
o`000?nl@kco_4>l00Wo_4>l00?o0000ok9=/_nbCK801OnbCK800ol0003oOh1oogn0O`09ogn0O`04
o`000?o7><Oo0000o`00013oQGZ50_l00008omPWf003o`000?o=</gocC;=01CocC;=0ol0000;omdR
g@03o`000?o[5>_ojaC[00WojaC[00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000onhA
k_o^4Nh02?o^4Nh00ol0003ohQgRon8MhP0;on8MhP;o00002_nl@k`00ol0003o/Tfbok9=/P06ok9=
/P03o`000?moP7ooOh1o00[oOh1o00?o0000ohEjQOn5NXD04_n5NXD00ol0003of2OHomPWf004omPW
f003o`000?o=</gocC;=01GocC;=00?o0000okm0_ono@;l01Ol00005omdRg@03o`000?o[5>_ojaC[
00[ojaC[00?o0000ooP7n?oh1oP03_oh1oP3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@04ood2o@03
o`000?oj1O[onPGj00ConPGj00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ohQgRon8MhP0;on8MhP04
o`000?nYEZWoZEJYo`0000Wo_4>l00?o0000ok9=/_nbCK801_nbCK800ol0003oOh1oogn0O`0:ogn0
O`03o`000?n5NXGoQGZ501?oQGZ50_l00003omPWf0Co00005?o=</d00ol0003o_d2ookm0_`06okm0
_`Co000000?ogB;Mo`000?o[5>/02oo[5>/00ol0003on0OhooP7n00>ooP7n003o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003oo@;mood2o@03ood2o@03o`000?oj1O[onPGj00GonPGj00?o0000onhAk_o^
4Nh01oo^4Nh00ol0003ohQgRon8MhP09on8MhP;o00001?nYEZT00ol0003o_4>loka3_005oka3_003
o`000?nbCK;o/Tfb00Oo/Tfb00?o0000ogn0OomoP7l02_moP7l00ol0003oQGZ5ohEjQ@0EohEjQ@03
o`000?oH9mSo000000CoW6>L0ol0000@oldbc@03o`000?no@;oo_d2o00_o_d2o0_l0000<on/Dj`03
o`000?oh1oSon0Oh00con0Oh0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ood2oOom0_d00_om0_d00ol0003onPGj
ooX5nP06ooX5nP03o`000?o^4NkokQ7^00OokQ7^00?o0000on8Mh_oR7N802?oR7N800ol0003oZEJY
ojUFZ@05ojUFZ@03o`000?nl@kco_4>l00Co_4>l00?o0000ok9=/_nbCK801onbCK800ol0003oOh1o
ogn0O`0:ogn0O`03o`000?n5NXGoQGZ501KoQGZ500?o0000oiaSW?nLHi`01_nLHi`3o`0000cocC;=
00?o0000okm0_ono@;l03Ono@;l00ol0003ojaC[on/Dj`09on/Dj`Go00002Ooh1oP2o`000003oo/4
nol0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ood2oOl0003onPGj00WonPGj00?o0000onhAk_o^4Nh01_o^
4Nh00ol0003ohQgRon8MhP07on8MhP03o`000?nYEZWoZEJY00OoZEJY00?o0000oka3_?nl@k`00_nl
@k`00ol0003o/Tfbok9=/P08ok9=/P03o`000?moP7ooOh1o00WoOh1o00?o0000ohEjQOn5NXD05on5
NXD00ol0003oW6>LoiaSW009oiaSW0?o00002Oo=</d00ol0003o_d2ookm0_`0>okm0_`Ko00001?o[
5>/00ol0003ol`ccoo<<l`03oo<<l`Go00000_oh1oP2o`0000Con`Ck00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oj1O[onPGjooX5n_l000002ooj1OX00ol0003okQ7^onhAkP06onhAkP03o`000?oR
7N;ohQgR00GohQgR0_l0000;ojUFZ@04o`000?nl@kco_4>lo`0000_o/Tfb00?o0000ogn0OomoP7l0
2OmoP7l00ol0003oQGZ5ohEjQ@0FohEjQ@03o`000?nLHicoW6>L00goW6>L0ol00005oldbc@03o`00
0?no@;oo_d2o00oo_d2o00?o0000om</dooC;=<00ooC;=<4o`0000_ol`cc0_l00006oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP02ooX5nPko00001_o^4Nh00ol0003ohQgRon8M
hP05on8MhP03o`000?nYEZWoZEJY00coZEJY00?o0000oka3_?l000002onbCK800ol0003oOh1oogn0
O`07ogn0O`?o00006?n5NXD00ol0003oW6>LoiaSW00@oiaSW0?o000000?ocC;=o`000?no@;l04?no
@;l00ol0003odbcCom</d`07om</d`03o`000?oc3??ol`cc00[ol`cc00?o0000oo/4nook1?/01Ook
1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005ooX5nP03o`000?ob3O;olPgb00_olPgb0_l00004
onhAkP03o`000?oR7N;ohQgR00?ohQgR0_l0000@ojUFZ@03o`000?nbCK;o/Tfb00[o/Tfb00?o0000
ogn0OomoP7l00omoP7l4o`0000;oCk1?00?o0000ohEjQOn5NXD05On5NXD00ol0003oW6>LoiaSW00D
oiaSW003o`000?no@;oo_d2o013o_d2o00?o0000om</dooC;=<01ooC;=<00ol0003ol`ccoo<<l`0:
oo<<l`03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj
00GonPGj00?o0000oo8=l_ob3O803Oob3O86o`0000?ohQgR00?o0000ojUFZOnYEZT04?nYEZT00ol0
003o/Tfbok9=/P0:ok9=/P03o`000?moP7oo000000?o00001om?/4l00ol0003oQGZ5ohEjQ@0DohEj
Q@03o`000?nLHicoW6>L01CoW6>L00?o0000okm0_ono@;l03ono@;l00ol0003odbcCom</d`08om</
d`03o`000?oc3??ol`cc00[ol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX00ol0003olPgboo8=lP0=oo8=lP03o`000?oG:=OoebSG00?o
ebSG00?o0000on8Mh_l000004onYEZT4o`0000Wo/Tfb0_l0000<odn`C`03o`000?n5NXGoQGZ501?o
QGZ500?o0000oiaSW?nLHi`05OnLHi`00ol0003o_d2ookm0_`0>okm0_`03o`000?oC;=?odbcC00So
dbcC00?o0000oo<<looc3?<02Ooc3?<00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oj1O[onPGj00SonPGj00?o0000oo8=l_ob3O802oob3O800ol0003oebSGomLXe`05omLXe`03o`00
0?nYEZWoZEJY01;oZEJY00Co0000oeVVFOmIYUWoFJII1Ol00003ok9=/P03o`000?m?/4ooCk1?00go
Ck1?0ol0000@ohEjQ@;o00006?nLHi`00ol0003o_d2ookm0_`0=okm0_`03o`000?oC;=?odbcC00Wo
dbcC00?o0000oo<<looc3?<02Ooc3?<00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_onPGj00?o0000oo8=l_ob3O802_ob3O800ol0003oebSGomLXe`06omLXe`03o`00
0?nYEZWoZEJY017oZEJY00?o0000oeVVFOmIYUT01omIYUT3o`00013oCk1?00?o0000obCK9?lTfb@0
1Ol00009ohEjQ@;o000000?oA;]4o`000?nLHi`05onLHi`00ol0003o_d2ookm0_`0=okm0_`03o`00
0?oC;=?odbcC00WodbcC00?o0000oo<<looc3?<02?oc3?<2o`0000[on`Ck00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ooX5n_oj1OX02Ooj1OX00ol0003olPgboo8=
lP0:oo8=lP03o`000?oG:=OoebSG00OoebSG00?o0000ojUFZOnYEZT03onYEZT00ol0003oFJIIoeVV
F@0:oeVVF@03o`000?m?/4ooCk1?00goCk1?00?o0000obCK9?lTfb@01_lTfb@4o`0000CoQGZ500?o
0000odBkA?m4^d@00_m4^d@00ol0003oW6>LoiaSW00FoiaSW003o`000?no@;oo_d2o00_o_d2o00?o
0000om</dooC;=<02ooC;=<00ol0003ol`ccoo<<l`06oo<<l`03o`000?oj1O[o000000[on`Ck00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ooX5n_oj1OX02?oj1OX=
o`0000[oebSG00?o0000ojUFZOnYEZT03onYEZT00ol0003oFJIIoeVVF@0;oeVVF@03o`000?m?/4oo
Ck1?00coCk1?00?o0000obCK9?lTfb@02_lTfb@4o`0000GoA;]400?o0000oiaSW?nLHi`05_nLHi`0
0ol0003o_d2ookm0_`0:okm0_`03o`000?oC;=?odbcC00codbcC00?o0000oo<<looc3?<01?oc3?<2
o`0000?onPGj00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d00oom0_d00ol0003onPGjooX5nP07ooX5nP03o`000?oa3_7ol@ka00Wol@ka00?o0000omLX
eooG:=L02OoG:=L00ol0003oZEJYojUFZ@0=ojUFZ@03o`000?mIYUWoFJII00coFJII00?o0000odn`
Com?/4l03?m?/4l00ol0003o9=/TobCK900;obCK9003o`000?lRgB;o000000KoA;]400?o0000oiaS
W?nLHi`05_nLHi`00ol0003o_d2ookm0_`09okm0_`03o`000?oC;=?odbcC00codbcC00?o0000oo<<
looc3?<00ooc3?<00ol0003onPGjooX5nP03ooX5nP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003o
l@kaoo4>l@08oo4>l@03o`000?oG:=OoebSG00_oebSG00?o0000ojUFZOnYEZT02?nYEZT4o`0000oo
FJII00?o0000odn`Com?/4l02om?/4l00ol0003o9=/TobCK900;obCK9004o`000?lRgB;o8]dRo`00
00OoA;]400?o0000oiaSW?nLHi`05OnLHi`00ol0003o_d2ookm0_`08okm0_`03o`000?oC;=?odbcC
00godbcC00?o0000oo<<looc3?<00_oc3?<00ol0003onPGjooX5nP05ooX5nP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Goo@;m00?o0000ooX5n_oj
1OX01Ooj1OX00ol0003ol@kaoo4>l@08oo4>l@03o`000?oG:=OoebSG00_oebSG00?o0000ojUFZOnY
EZT00onYEZT5o`0000?oGJ9M00?o0000oeVVFOmIYUT03_mIYUT00ol0003oCk1?odn`C`0:odn`C`03
o`000?lTfbCo9=/T00[o9=/T00Go0000ob;M8_lRgB;o8]dRo`000007odBkA003o`000?nLHicoW6>L
01GoW6>L00?o0000okm0_ono@;l02?no@;l00ol0003odbcCom</d`0=om</d`03o`000?oc3??ol`cc
00;o00002?oj1OX00ol0003on`Ckoo/4n`08oo/4n`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oj1O[onPGj00Go
nPGj00?o0000oo4>lOoa3_402?oa3_400ol0003oebSGomLXe`0<omLXe`Go00002OmMXUd00ol0003o
FJIIoeVVF@0<oeVVF@;o00003?m?/4l00ol0003o9=/TobCK900:obCK9005o`000?lRgB;o8]dRob;M
8_l000002?m4^d@00ol0003oW6>LoiaSW00DoiaSW0?o00001ono@;l00ol0003odbcCom</d`0>om</
d`03o`000?oc3??o000000_onPGj00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP06ooh1
oP03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ood2oOom0_d01Oom0_d00ol0003onPGjooX5nP04ooX5nP03o`000?oa3_7ol@ka00Oo
l@ka00?o0000omLXeooG:=L03?oG:=L01?l0003oYUVVojIIY_l0000;oefRG@03o`000?mIYUWoFJII
00_oFJII00Co0000oaOX5olGj1Oo00002_m?/4l00ol0003o9=/TobCK900:obCK9003o`000?lRgB;o
8]dR00;o8]dR00?o0000odBkA?m4^d@01_m4^d@00ol0003oW6>LoiaSW00AoiaSW0?o00000onCK9<0
0ol0003o_d2ookm0_`04okm0_`03o`000?oC;=?odbcC00godbcC1?l0000;ooX5nP03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Koo@;m00Co0000ooX5
n_oj1O[onPGj1?l00008oo4>l@03o`000?oG:=OoebSG00_oebSG00?o0000ojIIY_nVFJH00_nVFJH0
0ol0003oGJ9MoefRG@08oefRG@03o`000?mIYUWoFJII00[oFJII00?o0000oaOX5olGj1L00_lGj1L0
0ol0003oCk1?odn`C`03odn`C`Go00002olTfb@00ol0003o8]dRob;M8P03ob;M8P03o`000?m4^dCo
A;]400OoA;]400?o0000oiaSW?nLHi`03_nLHi`2o`0000OoTfbC00?o0000okm0_ono@;l00_no@;l0
0ol0003odbcCom</d`0=om</d`03o`000?oa3_7ol@ka00;ol@ka00?o0000ooX5n_oj1OX02Ooj1OX0
0ol0003on`Ckoo/4n`03oo/4n`03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@07ood2
o@?o00001?ob3O800ol0003ol@kaoo4>l@05oo4>l@03o`000?oG:=OoebSG00[oebSG00?o0000ojII
Y_nVFJH00onVFJH00ol0003oGJ9MoefRG@09oefRG@03o`000?mIYUWoFJII00SoFJII00?o0000oaOX
5olGj1L01?lGj1L5o`0000Co5NXE00?o0000obCK9?lTfb@02OlTfb@00ol0003o8]dRob;M8P03ob;M
8P03o`000?m4^dCoA;]400SoA;]400?o0000oiaSW?nLHi`02_nLHi`3o`0000[oTfbC00Go0000okm0
_ono@;oo_d2oo`00000>om</d`03o`000?oa3_7ol@ka00Col@ka0_l00009ooX5nP03o`000?ok1?_o
n`Ck00;on`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo8=
l_ob3O801Oob3O800ol0003ol@kaoo4>l@03oo4>l@03o`000?oG:=OoebSG00[oebSG00?o0000ojII
Y_nVFJH01?nVFJH00ol0003oGJ9MoefRG@09oefRG@03o`000?mIYUWoFJII00OoFJII00?o0000oaOX
5olGj1L01OlGj1L00ol0003o5NXEoaGZ5@07oaGZ5@03o`000?lTfbCo9=/T00Oo9=/T00?o0000ob;M
8_lRgB801?lRgB800ol0003oA;]4odBkA008odBkA003o`000?nLHicoW6>L00SoW6>L0_l0000>oi=/
T`Co00003?oC;=<2o`0000Wol@ka00?o0000ooX5n_oj1OX01ooj1OX01?l0003on`Ckoo/4nol0000?
ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003olPgboo8=lP07oo8=lP;o00000ooa3_400ol0
003oebSGomLXe`09omLXe`03o`000?nVFJKoYUVV00KoYUVV00?o0000oefRGOmMXUd02OmMXUd00ol0
003oFJIIoeVVF@05oeVVF@03o`000?lGj1Oo5nPG00Ko5nPG00?o0000oaGZ5OlEjQD02?lEjQD00ol0
003o9=/TobCK9006obCK9003o`000?lRgB;o8]dR00Co8]dR00?o0000odBkA?m4^d@02Om4^d@4o`00
00?oW6>L0ol0000@oi=/T`05o`000?oF:MKoeRWFomHYe_l000002_oC;=<00ol0003ol@kaoo4>l@0:
oo4>l@Ko00000ooj1OX00ol0003on`Cko`00000@ooh1oP03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ood2oOom0_d01?om0_d00ol0
003olPgboo8=lP0:oo8=lP04o`000?oa3_7ol@kao`0000[oebSG00?o0000ojIIY_nVFJH01onVFJH0
0ol0003oGJ9MoefRG@09oefRG@03o`000?mIYUWoFJII00CoFJII00?o0000oaOX5olGj1L01olGj1L0
0ol0003o5NXEoaGZ5@08oaGZ5@;o00001_lTfb@00ol0003o8]dRob;M8P05ob;M8P03o`000?m4^dCo
A;]400WoA;]400Co0000oeRWF?mHYeSoF:MH0ol0000Boi=/T`03o`000?oF:MKoeRWF00?oeRWF0_l0
0006om</d`;o00003Ooa3_400ol0003oo0?loo`3o003oo`3o0Go00004Oon0Oh00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ood2oOom0_d00oom0_d0
0ol0003olPgboo8=lP0<oo8=lP;o00002_oG:=L00ol0003oYUVVojIIYP08ojIIYP03o`000?mMXUgo
GJ9M00[oGJ9M00?o0000oeVVFOmIYUT00_mIYUT00ol0003o5nPGoaOX5`08oaOX5`03o`000?lEjQGo
5NXE00Ko5NXE0_l00002o`?l0`03o`000?lTfbCo9=/T00;o9=/T00?o0000ob;M8_lRgB801_lRgB80
0ol0003oA;]4odBkA008odBkA003o`000?mHYeSoF:MH00CoF:MH00?o0000oi=/TonCK9<03onCK9<0
0ol0003oeRWFomHYeP06omHYeP;o00000ooC;=<00ol0003ol@kaoo4>l@0=oo4>l@03o`000?ol0oco
o0?l00Ooo0?l0_l0000@ooh1oP03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003oo@;mood2o@02ood2o@03o`000?ob3O;olPgb
00kolPgb00?o0000omLXeooG:=L01ooG:=L00ol0003oYUVVojIIYP0:ojIIYP03o`000?mMXUgoGJ9M
00WoGJ9M00Go0000oeVVFOmIYUWoFJIIo`00000;oaOX5`03o`000?lEjQGo5NXE00Co5NXE0_l00005
o`?l0`05o`000?lTfbCo9=/TobCK9?l000002?lRgB800ol0003oA;]4odBkA008odBkA003o`000?mH
YeSoF:MH00GoF:MH00?o0000oi=/TonCK9<03_nCK9<00ol0003oeRWFomHYeP08omHYeP03o`000?oC
;=?o000000ool@ka00?o0000oo`3o?ol0o`02?ol0o`01?l0003ooP7no`000?l0000>ooh1oP03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?om0_goo@;mo`00017olPgb00?o0000omLXeooG:=L01_oG:=L00ol0003oYUVV
ojIIYP0;ojIIYP03o`000?mMXUgoGJ9M00WoGJ9M00Co0000oeVVFOmIYUWo00003?lGj1L00ol0003o
5NXEoaGZ5@02oaGZ5@;o00002?l3o0<00ol0003o9=/To`000009ob;M8P03o`000?m4^dCoA;]400So
A;]400?o0000oeRWF?mHYeP01OmHYeP00ol0003oTfbCoi=/T`0=oi=/T`03o`000?oF:MKoeRWF00[o
eRWF00?o0000oo4>lOoa3_403_oa3_400ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00;o
oP7n00?o0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000Boo8=lP03o`00
0?oG:=OoebSG00CoebSG00?o0000ojIIY_nVFJH03?nVFJH00ol0003oGJ9MoefRG@0:oefRG@?o0000
3?lGj1L00ol0003o5NXEoaGZ5@02o`0000_o0o`300?o0000ob;M8_lRgB802?lRgB800ol0003oA;]4
odBkA007odBkA003o`000?mHYeSoF:MH00OoF:MH00?o0000oi=/TonCK9<03?nCK9<00ol0003oeRWF
omHYeP0;omHYeP;o00003_oa3_400ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00?ooP7n
0_l0000:ooh1oP03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003olPgboo8=lP0?oo8=lP?o00000ooG
:=L00ol0003oYUVVojIIYP0>ojIIYP03o`000?mMXUgoGJ9M00SoGJ9M00Co0000oakQ7_lNhAko7^4N
0_l0000:oaOX5`?o00003Ol3o0<00ol0003o8]dRob;M8P08ob;M8P03o`000?m4^dCoA;]400OoA;]4
00?o0000oeRWF?mHYeP01omHYeP00ol0003oTfbCoi=/T`0;oi=/T`03o`000?oF:MKoeRWF00coeRWF
00?o0000ooT6nOl000000_l0000:oo4>l@03o`000?ol0ocoo0?l00Soo0?l00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000SooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o004oo`3o003o`000?ob3O;olPgb00colPgb0_l0
0003onPGj003o`000?oG:=Oo0000017oYUVV00?o0000oefRGOmMXUd01omMXUd00ol0003o7^4NoakQ
7P04oakQ7P;o00002?lGj1L00ol0003o0o`3o`?l0`0>o`?l0`;o00002?lRgB800ol0003oA;]4odBk
A006odBkA003o`000?mHYeSoF:MH00WoF:MH00?o0000oi=/TonCK9<02OnCK9<00ol0003oeRWFomHY
eP0=omHYeP03o`000?oi1_Won@Ki00;on@Ki0ol00007oo4>l@03o`000?ol0ocoo0?l00Ooo0?l00?o
0000ooh1o_on0Oh02?on0Oh2o`0000KooP7n00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?ob3O;o
lPgb00WolPgb0_l00006onPGj003o`000?nVFJKoYUVV013oYUVV00?o0000oefRGOmMXUd01_mMXUd0
0ol0003o7^4NoakQ7P07oakQ7P03o`000?lGj1Oo5nPG00Co5nPG0ol0000>o`?l0`03o`000?l1oP7o
0Oh100?o00001OlRgB800ol0003oA;]4odBkA006odBkA003o`000?mHYeSoF:MH00[oF:MH00?o0000
oi=/TonCK9<02?nCK9<00ol0003oeRWFomHYeP0=omHYeP03o`000?oi1_Won@Ki00Gon@Ki0ol00004
oo4>l@03o`000?ol0ocoo0?l00Ooo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP02
ooh1oP;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo0?loo`3o006oo`3o003o`000?ob3O;olPgb00GolPgb0ol00008onPGj003o`000?nVFJKoYUVV
017oYUVV00Co0000oefRGOmMXUgoGJ9M1?l0000;oakQ7P;o000000Co5nPGo`000?l0003o00000ol0
o`02o`0000_o0o`300?o0000o`7n0Ol1oP401?l1oP42o`0000?o8]dR00?o0000odBkA?m4^d@01_m4
^d@00ol0003oF:MHoeRWF00:oeRWF003o`000?nCK9?oTfbC00OoTfbC00?o0000omHYe_oF:MH03_oF
:MH00ol0003on@KiooT6n@08ooT6n@Co00002_ol0o`00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
oP7no`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo0?loo`3o007oo`3o003o`000?ob3O;olPgb00;olPgb0_l0000<onPGj003o`000?nVFJKo
YUVV013oYUVV1?l00003oe:]DP03o`000?lNhAko7^4N00_o7^4N00?o0000o`3o0?l0o`001_l0o`00
0ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh100Oo0Oh13?l0000>oeRWF003o`000?nCK9?o
TfbC00KoTfbC00?o0000omHYe_oF:MH03_oF:MH00ol0003on@KiooT6n@0;ooT6n@03o`000?ol0oco
o0?l00Ooo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00Woo0?l00Co0000oo8=
l_l0003o00003_oX5nP00ol0003oYUVVojIIYP0?ojIIYP03o`000?mB[E;oDZeB00KoDZeB00?o0000
oakQ7_lNhAh02_lNhAh00ol0003o0?l0o`3o0007o`3o00;o00001_l3o0<00ol0003o0Oh1o`7n0@08
o`7n0@03o`000?lacS7o<Lha00So<Lha00?o0000oeRWF?mHYeP03?mHYeP00ol0003oTfbCoi=/T`05
oi=/T`03o`000?oF:MKoeRWF00ooeRWF0_l0000=ooT6n@03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onPGj?oX5nP03_oX5nP00ol0
003oYUVVojIIYP0>ojIIYP03o`000?mB[E;oDZeB00OoDZeB00?o0000oakQ7_lNhAh02_lNhAh00ol0
003o0?l0o`3o0009o`3o00;o00000ol3o0<00ol0003o0Oh1o`7n0@09o`7n0@03o`000?lacS7o<Lha
00Wo<Lha00?o0000oeRWF?mHYeP02_mHYeP4o`0000CoTfbC00?o0000omHYe_oF:MH04?oF:MH01?l0
003on0Oho`000?l0000<ooT6n@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onPGj?oX5nP03ooX5nP@o`0000[oDZeB00?o0000oakQ
7_lNhAh02OlNhAh00ol0003o0?l0o`00000<o`3o0005o`000?l3o0?o0000o`3o0?l000002_l1oP40
0ol0003o<Lhaoc7><@09oc7><@03o`000?mHYeSoF:MH00OoF:MH0ol00004oh9mPP?o000000?oTfbC
o`000?oF:MH04OoF:MH01?l0003on0OhooP7n?oh1oP2o`0000_on@Ki00?o0000oo`3o?ol0o`00ool
0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oj1OXonPGj00?
onPGj003o`000?nMHYgoWF:M00coWF:M00?o0000oe:]D_mB[E802OmB[E800ol0003o7^4NoakQ7P07
oakQ7P04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`7n0@03o`00
0?lacS7o<Lha00[o<Lha00?o0000oeRWF?mHYeP00omHYeP3o`0000[oPWf200?o0000omHYe_oF:MH0
4?oF:MH00ol0003on0OhooP7n004ooP7n0;o00002_oi1_T00ol0003oo0?loo`3o004o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo0?l00?o0000onPGj?oX5nP03ooX5nP00ol0003oWF:MoieRW@0<oieRW@03o`000?mB
[E;oDZeB00WoDZeB00?o0000oakQ7_lNhAh01_lNhAh00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o0Oh1o`7n0@06o`7n0@03o`000?la
cS7o<Lha00[o<Lha00?o0000oeRWF?mHYeP00ol0000=oh9mPP03o`000?oF:MKoeRWF013oeRWF00?o
0000ooP7n?oh1oP01_oh1oP2o`0000Won@Ki0_l00004ooh1oP03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003oj1OXonPGj00=onPGj0?o00003onMHYd0
0ol0003oDZeBoe:]DP08oe:]DP03o`000?lNhAko7^4N00Go7^4N00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`7n0Ol1oP401Ol1oP40
0ol0003o<Lhaoc7><@0;oc7><@;o00004On2OH800ol0003oeRWFomHYeP0?omHYeP03o`000?oh1oSo
n0Oh00Son0Oh0_l00007ooT6n@03o`000?on0OkooP7n00CooP7n00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003oj1OXonPGj009onPGj0Go00000_oC;=<00ol0
003oWF:MoieRW@0=oieRW@03o`000?mB[E;oDZeB00WoDZeB00?o0000oakQ7_lNhAh01?lNhAh00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o0Oh1o`7n0@04o`7n0@03o`000?lacS7o<Lha00_o<Lha00?o0000oh9mP_n2OH804?n2OH800ol0
003oeRWFomHYeP0?omHYeP03o`000?oh1oSon0Oh00[on0Oh0_l00004ooT6n@03o`000?on0OkooP7n
00KooP7n0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo0?loo`3o007oo`3o003o`000?oX5nSoj1OX00Coj1OX1Ol00007om</d`03
o`000?nMHYgoWF:M00goWF:M00?o0000oe:]D_mB[E802OmB[E800ol0003o7^4NoakQ7P03oakQ7P03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l1oP7o0Oh100?o0Oh100?o0000oc7><OlacS402olacS400ol0003oPWf2oh9mPP0@oh9mPP03
o`000?oF:MKoeRWF00ooeRWF00?o0000ooP7n?oh1oP03?oh1oP2o`000003ooT6nOl0003ooP7n00[o
oP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000onPGj?l00000
1?l0000<om</d`03o`000?nMHYgoWF:M00koWF:M00?o0000oe:]D_mB[E802?mB[E800ol0003o7^4N
oakQ7P02oakQ7P03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l1oP7o0Oh100;o0Oh100?o0000oc7><OlacS402olacS400ol0003oPWf2
oh9mPP0Aoh9mPP03o`000?oF:MKoeRWF00goeRWF00?o0000ooP7n?oh1oP03ooh1oP00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01Ool0o`3o`00017odbcC00?o0000oieRWOnMHYd03_nM
HYd00ol0003oDZeBoe:]DP09oe:]DP04o`000?lNhAko7^4No`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l1oP7o0Oh1o`7n0Ol000003OlacS400ol0003o
PWf2oh9mPP0Aoh9mPP?o00003OoF:MH00ol0003on0OhooP7n00?ooP7n003o`000?on0OkooP7n00go
oP7n00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_ol0o`2o`0000;om@[e00?o0000om</dooC;=<03ooC;=<00ol0003o
WF:MoieRW@0>oieRW@03o`000?mB[E;oDZeB00SoDZeB1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o0Oh1o`7n0Ol0000=oc7><@03o`000?n2OH;oPWf2
017oPWf200?o0000ok5>/OnaC[400ol0000:omHYePCo00003Ooh1oP00ol0003ooP7nooh1oP0?ooh1
oP03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ood2oOom0_goo@;m0_l00005ooD:m@03o`000?oC;=?odbcC00kodbcC00?o0000oieR
WOnMHYd03_nMHYd00ol0003oDZeBoe:]DP07oe:]DP03o`000?lAkQ7o4NhA00?o4NhA00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<oc7>
<@03o`000?n2OH;oPWf2013oPWf200?o0000ok5>/OnaC[401?naC[43o`0000KoeRWF00?o0000oo<<
looc3?<00_oc3?<5o`0000Son0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?o
o@;m00?o0000ooD:mOoe2_D01?oe2_D00ol0003odbcCom</d`0=om</d`03o`000?nMHYgoWF:M00oo
WF:M00?o0000oe:]D_mB[E801?mB[E82o`0000Oo4NhA00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
1?/400?o0000oc7><OlacS402?lacS43o`00013oPWf200?o0000ok5>/OnaC[402?naC[43o`0000;o
eRWF00?o0000oo<<looc3?<02?oc3?<5o`0000?on0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?om0_goo@;m00Coo@;m00?o0000ooD:mOoe2_D01Ooe2_D00ol0003odbcCom</d`0;om</d`Co0000
3onMHYd00ol0003oDZeBoe:]DP03oe:]DP03o`000?lAkQ7o4NhA00So4NhA00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o1?/4o`Ck1005o`Ck10;o0000
1_lacS42o`0000?o@[e200?o0000oh9mP_n2OH803?n2OH800ol0003o/Djaok5>/@0<ok5>/@;o0000
4?oc3?<3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oe2_Gom@[e00Kom@[e00?o
0000om</dooC;=<02OoC;=<00ol0003ohAkQo`000002oj5NX@?o00003?nMHYd01?l0003oDZeBoe:]
D_mB[E82o`0000co4NhA00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`Ck1?l4n`@01ol4n`@00ol0003o<Lhaoc7><@02oc7><@03o`00
0?m2_D;o@[e200Co@[e20_l0000;oh9mPP03o`000?naC[7o/Dja00co/Dja00?o0000om`Sg?l00000
4_oc3?<00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oe2_Gom@[e00Oom@[e00?o
0000om</dooC;=<01_oC;=<2o`0000;ohAkQ00?o0000oj5NXOnQGZ400onQGZ43o`0000[oWF:M00?o
0000oe:]D_l000003olAkQ401?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`Ck1?l4n`@02?l4n`@01?l0003o<Lhao`000?l00009od:m@P03o`000?n2OH;oPWf200Oo
PWf200?o0000ok5>/OnaC[403?naC[401?l0003og2?Lom`Sg?l0000Coo<<l`03o`000?on0OkooP7n
00cooP7n0ol000000oon0Oko0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ood2oOom0_d01oom0_d00ol0003om@[eooD:m@08ooD:m@03o`000?oC;=?odbcC00Co
dbcC00?o0000on4NhOoQ7^400ooQ7^400ol0003oXEjQoj5NX@05oj5NX@?o00001_nMHYd4o`00013o
4NhA00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l4n`Co1?/400Wo
1?/400?o0000od:m@_m2_D802_m2_D82o`0000KoPWf200?o0000ok5>/OnaC[403?naC[400ol0003o
g2?Lom`Sg002om`Sg003o`000?oc3??ol`cc00ool`cc00?o0000oo`3o?l000002oon0Oh2o`0000Co
oP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?oe2_Gom@[e00Wom@[e00Co0000om</dooC;=?o
dbcC0_l00006on4Nh@03o`000?nQGZ7oXEjQ00SoXEjQ0ol000000onMHYgo0000o`000004odfbC@03
o`000?lAkQ7o4NhA00go4NhA00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l4n`Co1?/400Wo1?/400?o0000od:m@_m2_D803?m2_D800ol0003oPWf2oh9mPP03o`0000ko
/Dja00?o0000om`Sg?oL8m`00ooL8m`00ol0003ol`ccoo<<l`0>oo<<l`05o`000?ol0ocoo0?loo`3
o?l000002?on0Oh2o`0000OooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@09ood2o@03o`000?oe2_Gom@[e00[o
m@[e00?o0000om</dol000002?oQ7^400ol0003oXEjQoj5NX@0;oj5NX@03o`000?m=/TgoCK9=00Go
CK9=00?o0000oa7^4OlAkQ403?lAkQ400ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`Ck1?l4n`@02?l4n`@2o`0000oo@[e20_l00002oj9MXP03o`000?naC[7o/Dja00_o
/Dja00?o0000om`Sg?oL8m`01?oL8m`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l00?o
o0?l00?o0000ooh1o_on0Oh00_on0Oh3o`0000WooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ood2o@03o`000?oe2_Gom@[e00_om@[e00?o0000on4NhOoQ7^40
1ooQ7^400ol0003oXEjQoj5NX@0;oj5NX@03o`000?m=/TgoCK9=00KoCK9=00?o0000oa7^4OlAkQ40
2olAkQ42o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o1?/4o`Ck1007o`Ck1004o`00
0?lFjAKo5^TFo`0000ko@[e200?o0000oj9MX_nRGJ800_nRGJ800ol0003o/Djaok5>/@09ok5>/@03
o`000?oL8mcog2?L00Kog2?L00?o0000oo<<looc3?<02ooc3?<00ol0003oo0?loo`3o005oo`3o004
o`000?on0Oko0000o`0000cooP7n00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000Soo@;m00?o0000ooD:mOoe2_D02_oe2_D2o`0000Wo
hAkQ00?o0000oj5NXOnQGZ402onQGZ400ol0003oCK9=odfbC@07odfbC@03o`000?lAkQ7o4NhA00Wo
4NhA00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l4n`Co1?/4
00Ko1?/400Go0000oaKY5_lFjAKo5^TFo`00000>od:m@P03o`000?nRGJ;oXUfR00?oXUfR00?o0000
ok5>/OnaC[401onaC[400ol0003og2?Lom`Sg007om`Sg003o`000?oc3??ol`cc00[ol`cc00?o0000
oo`3o?ol0o`01ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ood2o@03o`000?oe2_Gom@[e
00Wom@[e00Co0000oo@;m?od2oCo00002OoQ7^400ol0003oXEjQoj5NX@09oj5NX@03o`000?m=/Tgo
CK9=00WoCK9=00?o0000oa7^4OlAkQ401olAkQ400ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o1?/4o`Ck1005o`Ck1003o`000?lFjAKo
5^TF00?o5^TF00?o0000od:m@_m2_D802_m2_D800ol0003oXUfRoj9MXP05oj9MXP03o`000?naC[7o
/Dja00Go/Dja00?o0000om`Sg?oL8m`02?oL8m`00ol0003ol`ccoo<<l`09oo<<l`03o`000?ol0oco
o0?l00Soo0?l00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_om0_d3o`0000Wom@[e00?o0000oo@;
m?od2o@00_od2o@00ol0003ohAkQon4Nh@06on4Nh@03o`000?nQGZ7oXEjQ00WoXEjQ00?o0000odfb
COm=/Td02_m=/Td00ol0003o4NhAoa7^4@05oa7^4@03o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l4n`Co1?/400Co1?/400?o0000oaKY
5_lFjAH01?lFjAH00ol0003o@[e2od:m@P0:od:m@P03o`000?nRGJ;oXUfR00KoXUfR00?o0000ok5>
/OnaC[400onaC[400ol0003og2?Lom`Sg009om`Sg003o`000?oc3??ol`cc00Sol`cc00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ooX5nP?o00001Ooe2_D00ol0003o
m0_doo@;m003oo@;m003o`000?oQ7^7ohAkQ00KohAkQ00?o0000oj5NXOnQGZ402OnQGZ400ol0003o
CK9=odfbC@0;odfbC@03o`000?lAkQ7o4NhA00?o4NhA00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`Ck1?l4n`@00_l4n`@2o`0000So
5^TF00?o0000od:m@_m2_D802Om2_D800ol0003oXUfRoj9MXP07oj9MXP05o`000?naC[7o/Djaok5>
/Ol000003OoL8m`00ol0003ol`ccoo<<l`06oo<<l`03o`000?ol0ocoo0?l00[oo0?l00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oj1O[onPGj00GonPGj0ol000000ooe2_Go0000oo@;m006oo@;m003
o`000?oQ7^7ohAkQ00GohAkQ00?o0000oj5NXOnQGZ402OnQGZ400ol0003oCK9=odfbC@0<odfbC@05
o`000?lAkQ7o4NhAoa7^4Ol000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`Ck1?l000000_l000000ol;m0_o0000oaKY5P07oaKY5P03o`000?m2_D;o@[e2
00So@[e200?o0000oj9MX_nRGJ802OnRGJ800ol0003o/Djao`00000=om`Sg0Co00001Ooc3?<00ol0
003oo0?loo`3o00;oo`3o003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003onPGjooX5nP08ooX5nP03
o`000?od2oCom0_d00Oom0_d00?o0000on4NhOoQ7^401?oQ7^400ol0003oXEjQoj5NX@09oj5NX@03
o`000?m=/TgoCK9=00goCK9=00?o0000oa7^4Ol000003?l0o`0:o`0000Oo0?l00ol00005o`_d2`03
o`000?lFjAKo5^TF00Ko5^TF00?o0000od:m@_m2_D801om2_D800ol0003oXUfRoj9MXP0:oj9MXP03
o`000?oL8mcog2?L00_og2?L00?o0000ooH9m_of2OH00_of2OH3o`000003oo<<lol0003oo0?l00_o
o0?l0ol0000>ooh1oP03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003om0_doo@;m007oo@;m003o`00
0?oQ7^7ohAkQ00GohAkQ00?o0000oj5NXOnQGZ401onQGZ400ol0003oCK9=odfbC@0?odfbC@;o0000
2ol0o`000ol0003o0_d2o`;m0P07o`;m0P03o`000?l0o`3o0?l000;o0?l00ol00008o`_d2`03o`00
0?lFjAKo5^TF00Ko5^TF00?o0000od:m@_m2_D801om2_D800ol0003oXUfRoj9MXP0:oj9MXP03o`00
0?oL8mcog2?L00[og2?L00?o0000ooH9m_of2OH01_of2OH00ol0003oo0?loo`3o008oo`3o0?o0000
0_om0_d00ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003om0_doo@;
m008oo@;m003o`000?oQ7^7ohAkQ00CohAkQ00?o0000oj5NXOnQGZ401onQGZ400ol0003oCK9=odfb
C@0>odfbC@04o`000?lJiA[o6^DJo`0000Wo0?l000?o0000o`;m0_l2o@802Ol2o@801?l0003o0?l0
o`000?l0000<o`_d2`03o`000?lFjAKo5^TF00Ko5^TF00?o0000od:m@_m2_D801_m2_D800ol0003o
XUfRoj9MXP0;oj9MXP03o`000?oL8mcog2?L00Oog2?L0_l00009ooH9mP03o`000?ol0ocoo0?l00Co
o0?l1?l00006ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003onPGjooX5nP09ooX5nP03o`00
0?od2oCom0_d00Som0_d00?o0000on4NhOoQ7^400ooQ7^4>o`0000goCK9=00?o0000oa[U6_lJiAX0
0_lJiAX00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200_o0_d200?o0000o`_d2ol;m0/0
3?l;m0/00ol0003o5^TFoaKY5P06oaKY5P03o`000?m2_D;o@[e200Go@[e200?o0000oj9MX_nRGJ80
3?nRGJ800ol0003og2?Lom`Sg006om`Sg003o`000?of2OKomPWf00[omPWf00?o0000oo`3o?ol0o`0
0ol0000:ood2o@?o00002_on0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oj1O[onPGj00_onPGj00?o0000oo@;m?od2o@02?od
2o@01Ol0003ohAkQon4NhOoQ7^7o000000_o/dbc00?o0000oeB[E?mDZe@00ol00009odfbC@03o`00
0?lJiA[o6^DJ00Co6^DJ00?o0000o`3o0?l0o`000ol0o`000ol0003o0_d2o`;m0P0<o`;m0P03o`00
0?l;m0_o2o@;00go2o@;00?o0000oaKY5_lFjAH01_lFjAH00ol0003o@[e2od:m@P03od:m@P?o0000
3OnRGJ800ol0003og2?Lom`Sg005om`Sg003o`000?of2OKomPWf00comPWf0_l0000=ood2o@03o`00
0?oo0?ooo`3o00?o00001oon0Oh00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oj1O[onPGj00_onPGj00?o0000oo@;m?od2o@02?od
2o@4o`0000co/dbc00?o0000oeB[E?mDZe@00omDZe@3o`0000GoCK9=00?o0000oa[U6_lJiAX01_lJ
iAX01Ol0003o0?l0o`3o0?l0o`3o000000oo0_d200?o0000o`_d2ol;m0/03Ol;m0/00ol0003o5^TF
oaKY5P06oaKY5P03o`000?m2_D;o@[e200?o00000omKY5/00ol0003oXUfRoj9MXP0;oj9MXP03o`00
0?oL8mcog2?L00?og2?L00?o0000ooH9m_of2OH03Oof2OH00ol0003oo@;mood2o@0;ood2o@03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ooh1oP03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooX5n_oj1OX02_oj1OX3o`0000Kom0_d0ol0
0003ondBk@03o`000?ncC;?o/dbc00[o/dbc00?o0000oeB[E?mDZe@01_mDZe@3o`000003odfbCOl0
003o6^DJ00Wo6^DJ00?o0000o`3o0?l000004?l2o@800ol0003o2o@;o`_d2`0=o`_d2`03o`000?lF
jAKo5^TF00Oo5^TF0_l00007oe^TF`03o`000?nRGJ;oXUfR00[oXUfR00Co0000om`Sg?oL8mcog2?L
0ol0000?ooH9mP03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooX5n_oj1OX02_oj
1OX01?l0003on@KiooT6nOoi1_T2o`000004oo@;m?l0003o0000o`0000KokA;]00?o0000ok=</onc
C;<02_ncC;<00ol0003oE:]DoeB[E009oeB[E003o`000?lJiA[o6^DJ00[o6^DJ00?o0000o`;m0_l2
o@803ol2o@800ol0003o2o@;o`_d2`0>o`_d2`03o`000?lFjAKo5^TF00Ko5^TF00?o0000oe^TFomK
Y5/01omKY5/4o`0000SoXUfR00Co0000om`Sg?oL8mco00000oo^4Nh2o`0000gomPWf00?o0000ood2
oOom0_d02_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003o
n@KiooT6n@04ooT6n@03o`000?o]4^gokA;]00OokA;]00?o0000ok=</oncC;<02OncC;<00ol0003o
E:]DoeB[E00:oeB[E003o`000?lJiA[o6^DJ00[o6^DJ00?o0000o`;m0_l2o@803ol2o@800ol0003o
2o@;o`_d2`0>o`_d2`03o`000?lFjAKo5^TF00Go5^TF00?o0000oe^TFomKY5/02?mKY5/01?l0003o
ZeB[oj]DZon[E:/7o`0000;oXUfR0_l00006onhAkP;o00003?of2OH00ol0003oo@;mood2o@09ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003onPGjooX5nP08ooX5nP03o`000?oi1_Won@Ki00Go
n@Ki00?o0000ondBkOo]4^d02?o]4^d00ol0003o/dbcok=</`08ok=</`03o`000?mDZeCoE:]D00[o
E:]D00?o0000oa[U6_lJiAX02olJiAX00ol0003o0_d2o`;m0P0>o`;m0P03o`000?l;m0_o2o@;00ko
2o@;1Ol00002oaKY5P03o`000?mKY5_oFjAK00WoFjAK00?o0000oj]DZon[E:/02?n[E:/3o`0000Wo
kQ7^0_l0000:ooH9mP03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oj1O[onPGj00SonPGj00?o0000ooT6nOoi1_T01ooi1_T00ol0003okA;]ondBk@07ondBk@03o`00
0?ncC;?o/dbc00So/dbc00?o0000oeB[E?mDZe@02_mDZe@00ol0003o6^DJoa[U6P0:oa[U6P;o0000
3_l2o@83o`0000go2o@;0ol00005oc3?<0;o00002omKY5/00ol0003oZeB[oj]DZ`0;oj]DZ`;o0000
2_o^4Nh2o`0000OomPWf0ol00009ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:ooT6n@03o`00
0?o]4^gokA;]00OokA;]00?o0000ok=</oncC;<02?ncC;<>o`0000Wo6^DJ0ol000000olCk1?o0000
o`;m0P0:o`;m0P?o00000_lGj1L00ol0003o2o@;o`_d2`09o`_d2`;o00002Ol`cc000ol0003oFjAK
oe^TF`09oe^TF`03o`000?n[E:_oZeB[00_oZeB[00?o0000olXeb_l000002oo^4Nh2o`0000ComPWf
00Co0000ooT6nOoi1_Won@Ki0_l00007ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oom0_d00ol0003on@Ki
ooT6n@09ooT6n@03o`000?o]4^gokA;]00KokA;]00?o0000ok=</oncC;<02?ncC;<00ol0003oDjaC
oe>/D`0:oe>/D`03o`000?lJiA[o6^DJ00Co6^DJ0ol00005oa?/4`03o`000?l2o@;o0_d200Co0_d2
1?l00006oaOX5`03o`000?l;m0_o2o@;00Ko2o@;0_l0000;oc3?<003o`000?mKY5_oFjAK00WoFjAK
00?o0000oj]DZon[E:/02_n[E:/01Ol0003obSG:olXeb_o:=L[o000000cokQ7^0_l000000oof2OKo
0000ooT6n@05ooT6n@03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000ondBkOo]4^d01_o]4^d00ol0003o/dbcok=</`07ok=</`03o`00
0?mC[5?oDjaC00_oDjaC00?o0000oa[U6_lJiAX00_lJiAX2o`0000Wo4n`C00?o0000o`;m0_l2o@80
0ol0000;oaOX5`03o`000?l;m0_o2o@;00;o2o@;0ol0000>oc3?<003o`000?mKY5_oFjAK00OoFjAK
00?o0000oj]DZon[E:/02on[E:/00ol0003obSG:olXebP02olXebP03o`000?o^4NkokQ7^00_okQ7^
00?o0000ooT6nOoi1_T01_oi1_T2o`0000?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oi
1_Won@Ki00Oon@Ki00?o0000ondBkOo]4^d01oo]4^d00ol0003o/dbcok=</`05ok=</`?o00003OmC
[5<4o`0000_o4n`C0ol0000?oaOX5`04o`000?l;m0_o0000o`00017o<<l`00?o0000oe^TFomKY5/0
1omKY5/00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?o:=L[obSG:00CobSG:00?o0000onhAk_o^4Nh0
1oo^4Nh3o`0000_on@Ki1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooT6nOoi1_T02?oi1_T00ol0003okA;]ondB
k@06ondBk@03o`000?ncC;?o/dbc00;o/dbc0ol00003oi9]TP03o`000?mC[5?oDjaC00[oDjaC00?o
0000oa?/4olCk1<02olCk1<00ol0003o4>l@o`00000AoaOX5`03o`000?l`cc3o<<l`017o<<l`00?o
0000oe^TFomKY5/01omKY5/00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?o:=L[obSG:00GobSG:00Co
0000onhAk_o^4NkokQ7^1Ol00002oo4>l@03o`000?oi1_Won@Ki00Won@Ki00Co0000ooh1o_on0Oko
oP7n0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi1_T00ol0003okA;]ondBk@05ondBk@?o0000
00?o/dbco`000?l000001onBKI800ol0003oDjaCoe>/D`08oe>/D`?o00002_lCk1<2o`0000;o4>l@
00?o0000oaOX5olGj1L03olGj1L00ol0003o<<l`oc3?<00Aoc3?<003o`000?mKY5_oFjAK00OoFjAK
00?o0000oj]DZon[E:/02On[E:/00ol0003obSG:olXebP07olXebP?o00001ooa3_400ol0003on@Ki
ooT6n@09ooT6n@03o`000?on0OkooP7n00CooP7n0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi
1_T4o`0000;okA;]0_l00003on8MhP03o`000?nBKI;oTVfB00SoTVfB0_l00006oe>/D`;o00000om4
^d@00ol0003o4n`Coa?/4`06oa?/4`03o`000?l@ka3o4>l@00?o4>l@00?o0000oaOX5olGj1L03_lG
j1L00ol0003o<<l`oc3?<00Boc3?<003o`000?mKY5_oFjAK00GoFjAK00?o0000oj]DZon[E:/02On[
E:/00ol0003obSG:olXebP08olXebP03o`000?oa3_7ol@ka00Ool@ka00?o0000ooT6nOoi1_T02?oi
1_T00ol0003ooP7nooh1oP07ooh1oP;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki00Con@Ki0_l00004
ooH9mP;o00001OoR7N800ol0003oTVfBoi9]TP0:oi9]TP03o`000?mC[5?oDjaC00;oDjaC00?o0000
odBkA?m4^d@01?m4^d@00ol0003o4n`Coa?/4`04oa?/4`03o`000?l@ka3o4>l@00Co4>l@00?o0000
oaOX5olGj1L03_lGj1L00ol0003o<<l`oc3?<00Boc3?<0[o00002_n[E:/00ol0003obSG:olXebP08
olXebP03o`000?oa3_7ol@ka00Ool@ka00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP09
ooh1oP?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003on@KiooT6nOoi1_T2o`0000OomPWf00?o0000on8Mh_oR7N801?oR7N80
0ol0003oTVfBoi9]TP0:oi9]TP04o`000?mC[5?o0000o`0000SoA;]400Co0000oa?/4olCk1?o4n`C
0_l00007oa3_4003o`000?lGj1Oo5nPG00ko5nPG00?o0000oc3?<?l`cc004_l`cc000ol0003oOH9m
ogf2O@07ogf2O@03o`000?n[E:_oZeB[00KoZeB[00?o0000olXeb_o:=LX02_o:=LX00ol0003ol@ka
oo4>l@06oo4>l@03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?oi
1_Wo0000o`0000WomPWf00?o0000on8Mh_oR7N801?oR7N800ol0003oTVfBoi9]TP0;oi9]TP03o`00
0?m4^dCoA;]400WoA;]400?o0000oa?/4ol000002Ol@ka000ol0003o5nPGoaOX5`0>oaOX5`;o0000
4_l`cc000ol0003oOH9mogf2O@09ogf2O@;o00001_n[E:/00ol0003obSG:olXebP0:olXebP03o`00
0?oa3_7ol@ka00Kol@ka00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000ooH9m_of2OH02Oof2OH00ol0003ohQgRon8MhP05on8MhP03o`000?nBKI;oTVfB00[oTVfB00?o
0000odBkA?m4^d@02_m4^d@2o`0000Wo4>l@00?o0000oaOX5olGj1L03_lGj1L00ol0003o9=/To`00
0002o`0000oo<<l`00?o0000ogf2OOmmPWd02ommPWd00ol0003oZeB[oj]DZ`03o`0000gobSG:00?o
0000oo4>lOoa3_401_oa3_400ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003omPWfooH9mP09ooH9mP03o`000?oR7N;ohQgR00GohQgR00?o0000oi9]T_nBKI802OnBKI82
o`0000_oA;]40_l0000;oa3_4003o`000?lGj1Oo5nPG00co5nPG00?o0000obCK9?lTfb@00olTfb@3
o`0000co<<l`00?o0000ogf2OOmmPWd03?mmPWd2o`0000;obSG:00?o0000olXeb_o:=LX03?o:=LX0
0ol0003ol@kaoo4>l@05oo4>l@03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?of2OKomPWf00[omPWf00?o0000on8Mh_oR7N801_oR7N800ol0003oTVfBoi9]TP07oi9]
TP03o`000?nIIYWo000000[oA;]400Co0000occ3??ll`cco00002_l@ka000ol0003o5nPGoaOX5`0<
oaOX5`03o`000?lTfbCo9=/T00Ko9=/T0_l00008oc3?<0;o00003ommPWd00ol0003obSG:olXebP02
olXebP03o`000?o:=L[obSG:00_obSG:00?o0000oo4>lOoa3_401Ooa3_400ol0003on@KiooT6n@07
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003omPWfooH9mP0:ooH9mP03o`000?oR7N;ohQgR
00KohQgR00?o0000oi9]T_nBKI801_nBKI801Ol0003oVFJIoiUVVOnIIYWo000000SoA;]400?o0000
occ3??ll`c`00_ll`c`00ol0003o4>l@oa3_4006oa3_40Co00003?lGj1L00ol0003o9=/TobCK9008
obCK90?o00000_l`cc03o`000003of6NHOl0003oOH9m00goOH9m00?o0000olXeb_o:=LX01?o:=LX0
0ol0003obSG:olXebP0:olXebP03o`000?oa3_7ol@ka00Gol@ka00?o0000ooT6nOoi1_T01_oi1_T0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000ooH9m_of2OH02oof2OH00ol0003ohQgRon8MhP07on8M
hP03o`000?nBKI;oTVfB00?oTVfB0_l00005oiUVV@03o`000?m4^dCoA;]400CoA;]400?o0000occ3
??ll`c`00oll`c`00ol0003o4>l@oa3_4005oa3_4003o`000?l;m0_o2o@;00;o2o@;0ol00007oaOX
5`;o00003_lTfb@2o`0000GoHIiQ00?o0000ogf2OOmmPWd02_mmPWd00ol0003obSG:olXebP05olXe
bP03o`000?o:=L[obSG:00_obSG:00?o0000oo4>lOoa3_401?oa3_400ol0003on@KiooT6n@06ooT6
n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003omPWfooH9mP0;ooH9mP03o`000?oR7N;ohQgR00Oo
hQgR00?o0000oi9]T_nBKI800_nBKI800ol0003oVFJIoiUVV@06oiUVV@03o`000?m4^dCoA;]400;o
A;]400?o0000occ3??ll`c`01Oll`c`00ol0003o4>l@oa3_4002oa3_40;o00002?l;m0/3o`0000;o
5nPG0_l000000ol<l`co0000obCK900=obCK9003o`000?mQWV7oHIiQ00GoHIiQ00?o0000ogf2OOmm
PWd02?mmPWd00ol0003obSG:olXebP07olXebP03o`000?o:=L[obSG:00[obSG:00?o0000oo4>lOoa
3_401?oa3_400ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003omPWf
ooH9mP0<ooH9mP03o`000?oR7N;ohQgR00SohQgR00Co0000oi9]T_nBKI;o00002OnIIYT01Ol0003o
A;]4odBkA?m4^dCo000000So?<<l00Go0000oa3_4?l@ka3o4>l@o`00000=o`_d2`;o00001?l<l``0
0ol0003o9=/TobCK900;obCK9003o`000?mQWV7oHIiQ00KoHIiQ00?o0000ogf2OOmmPWd01ommPWd0
0ol0003obSG:olXebP08olXebPCo00002?o:=LX00ol0003ol@kaoo4>l@04oo4>l@03o`000?oi1_Wo
n@Ki00Kon@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?of2OKomPWf00_omPWf0ol00009on8M
hP03o`000?nBKI;o000000_oVFJI00?o0000odBkA?l000002_ll`c`00ol0003o4>l@o`00000?o`_d
2`03o`000?l<l`co3?<<00;o3?<<00?o0000obCK9?lTfb@02olTfb@00ol0003oHIiQof6NH@06of6N
H@03o`000?mmPWgoOH9m00KoOH9m00?o0000olXeb_o:=LX02Oo:=LX01?l0003ohQgRon8Mh_oR7N87
o`0000;obSG:00?o0000oo4>lOoa3_400ooa3_400ol0003on@KiooT6n@05ooT6n@03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?of2OKomPWf00SomPWf0ol00003ooL8m`03o`000?oR7N;ohQgR00OohQgR00?o0000oiUV
VOnIIYT02onIIYT00ol0003o?<<locc3?00:occ3?003o`000?l;m0_o2o@;00go2o@;00?o0000o`cc
3?l<l``01?l<l``00ol0003o9=/TobCK9009obCK9003o`000?mQWV7oHIiQ00SoHIiQ00?o0000ogf2
OOmmPWd00ommPWd2o`0000cobSG:00?o0000on8Mh_oR7N802?oR7N8<o`0000?on@Ki0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000ooH9m_of2OH01_of2OH3o`0000Oom`Sg00?o0000on8Mh_oR7N801_oR7N800ol0003o
VFJIoiUVV@0;oiUVV@03o`000?ll`cco?<<l00Wo?<<l0_l0000>o`_d2`03o`000?l<l`co3?<<00Go
3?<<00?o0000obCK9?lTfb@02OlTfb@00ol0003oHIiQof6NH@09of6NH@03o`000?mmPWgo000000;o
00000_no@;l00ol0003obSG:olXebP08olXebP03o`000?oR7N;ohQgR00cohQgR00?o0000oo@;m?od
2o@01_od2o@3o`0000?ooP7n0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003omPWfooH9mP03ooH9mP?o00002oog2?L00ol0003ohQgR
on8MhP04on8MhP03o`000?nIIYWoVFJI00_oVFJI0ol00007occ3?0?o000000?o9=/To`000?l;m0/0
3Ol;m0/00ol0003o3?<<o`cc3006o`cc3003o`000?lTfbCo9=/T00So9=/T00?o0000of6NHOmQWV40
2_mQWV400ol0003o_d2ookm0_`04okm0_`03o`000?o:=L[obSG:00OobSG:00?o0000on8Mh_oR7N80
2ooR7N800ol0003om0_doo@;m008oo@;m003o`000?on0OkooP7n00CooP7n0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004ooH9m_l0
003o0000o`0000oom`Sg00?o0000on8Mh_oR7N800ooR7N8>o`0000?oPWf20_l00002occ3?0?o0000
1OlTfb@00ol0003o2o@;o`_d2`0:o`_d2`03o`000?l<l`co3?<<00Oo3?<<00?o0000obCK9?lTfb@0
2?lTfb@00ol0003oHIiQof6NH@0:of6NH@03o`000?no@;oo_d2o00Go_d2o00?o0000olXeb_o:=LX0
1_o:=LX00ol0003ohQgRon8MhP0;on8MhP03o`000?od2oCom0_d00Som0_d00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?om0_d2o`0001;om`Sg00?o0000on8Mh_oR7N800_oR7N800ol0003oeRWFomHY
eP0:omHYeP03o`000?n2OH;oPWf200?oPWf20_l00009obCK9003o`000?l;m0_o2o@;00Wo2o@;00?o
0000o`cc3?l<l``02?l<l``2o`0000So9=/T00?o0000of6NHOmQWV402OmQWV400ol0003o_d2ookm0
_`07okm0_`03o`000?o:=L[obSG:00CobSG:00?o0000on8Mh_oR7N802ooR7N800ol0003om0_doo@;
m009oo@;m003o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ood2oOom0_d01oom0_d00ol0003om`SgooL8m`0?ooL8m`?o000000?ohQgR
o`000?oF:MH02ooF:MH00ol0003oPWf2oh9mPP04oh9mPP03o`000?lTfbCo9=/T00Wo9=/T00?o0000
o`_d2ol;m0/01ol;m0/00ol0003o3?<<o`cc3009o`cc3004o`000?lVfBKo0000o`0000Ko9=/T00?o
0000of6NHOmQWV402OmQWV400ol0003o_d2ookm0_`08okm0_`03o`000?o:=L[obSG:00?obSG:00?o
0000on8Mh_oR7N802ooR7N800ol0003om0_doo@;m009oo@;m003o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ood2oOom0_d02?om0_d0
0ol0003om`SgooL8m`0<ooL8m`;o00000oof2OH2o`0000coeRWF00?o0000oh9mP_n2OH801?n2OH80
0ol0003o9=/TobCK900:obCK90Wo00002ol<l``00ol0003o9]TVobKI9P02obKI9P?o00000_lTfb@0
0ol0003oHIiQof6NH@0:of6NH@03o`000?no@;oo_d2o00Wo_d2o00?o0000olXeb_o:=LX00_o:=LX0
0ol0003ohQgRon8MhP0:on8MhP03o`000?od2oCom0_d00Wom0_d00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@09ood2
o@;o00002_og2?L2o`0000GomPWf00?o0000on@Ki?l000002_oF:MH00ol0003oPWf2oh9mPP06oh9m
PP03o`000?lTfbCo9=/T00Wo9=/T00?o0000oa3_4?l@ka001Ol@ka000ol0003o3?<<o`cc3009o`cc
3003o`000?lVfBKo9]TV00Go9]TV0ol00009of6NH@?o00003Ono@;l01Ol0003obSG:olXeb_o:=L[o
000000cohQgR00?o0000oo@;m?od2o@02Ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8
moog2?L01Oog2?L2o`0000OomPWf00Co0000on@Ki?oT6nCo00002OoF:MH00ol0003oPWf2oh9mPP06
oh9mPP03o`000?lTfbCo9=/T00So9=/T00?o0000oa3_4?l@ka001ol@ka000ol0003o3?<<o`cc3007
o`cc3003o`000?lVfBKo9]TV00So9]TV0ol00002of6NH@Go00000_nYEZT00ol0003o_d2ookm0_`0<
okm0_`03o`000?o:=L[o000000cohQgR00?o0000oo@;m?od2o@02_od2o@00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m
00goo@;m00?o0000ooL8moog2?L00_og2?L2o`0000SomPWf00?o0000on@Ki?oT6n@00_oT6n@5o`00
00CoeRWF00?o0000oh9mP_n2OH801_n2OH800ol0003o9=/TobCK9008obCK9003o`000?l@ka3o4>l@
00Oo4>l@00?o0000o`cc3?l<l``01ol<l``00ol0003o9]TVobKI9P08obKI9P03o`000?m]TVgoKI9]
00;o00002?nYEZT00ol0003o_d2ookm0_`0<okm0_`Co00002_oR7N800ol0003om0_doo@;m00:oo@;
m003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ood2oOom0_d03_om0_d01?l0003om`Sgo`000?l0000:ooH9mP03o`000?oT6nCoi1_T
00;oi1_T00?o0000oke2_Onm@[d00_nm@[d4o`0000WoPWf200?o0000obCK9?lTfb@02?lTfb@00ol0
003o4>l@oa3_4008oa3_4003o`000?l<l`co3?<<00Go3?<<00?o0000obKI9_lVfBH02?lVfBH01Ol0
003oKI9]offBKOm]TVgo000000[oZEJY0ol0000;okm0_`04o`000?o^4NkokQ7^onhAkPCo00001OoR
7N800ol0003om0_doo@;m00;oo@;m003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ood2oOom0_d03oom0_d00ol0003omPWfooH9mP0:
ooH9mP03o`000?oT6nCoi1_T00?oi1_T00?o0000oke2_Onm@[d01?nm@[d00ol0003oPWf2oh9mPP07
oh9mPP03o`000?lTfbCo9=/T00Ko9=/T0_l0000;oa3_4003o`000?l<l`co3?<<00Go3?<<00?o0000
obKI9_lVfBH02?lVfBH00ol0003oKI9]offBK@02offBK@03o`000?nYEZWoZEJY00OoZEJY00?o0000
om/TfooK9=/01?l00006okm0_`03o`000?o^4NkokQ7^00KokQ7^0ol00002on8MhP03o`000?od2oCo
m0_d00_om0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of2OKomPWf00WomPWf00?o0000on@K
i?oT6n@01?oT6n@00ol0003o_D:moke2_@05oke2_@03o`000?n2OH;oPWf200OoPWf200?o0000obCK
9?lTfb@00_lTfb@3o`000003ocS7>?l0003o4>l@00[o4>l@00?o0000o`cc3?l<l``01Ol<l``00ol0
003o9]TVobKI9P07obKI9P03o`000?m]TVgoKI9]00?oKI9]00?o0000ojUFZOnYEZT01onYEZT00ol0
003ofbCKom/Tf`04om/Tf`?o00000_no@;l00ol0003okQ7^onhAkP0:onhAkP;o00003_od2o@00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?om0_goo@;m013oo@;m00?o0000ooH9m_of2OH02Oof2OH00ol0003oi1_Ton@Ki004on@Ki003
o`000?nm@[go_D:m00Ko_D:m0_l00007oh9mPP03o`000?lTfbCo000000;o00001OlhacP00ol0003o
4>l@oa3_4008oa3_40?o00001?l<l``00ol0003o9]TVobKI9P08obKI9P03o`000?m]TVgoKI9]00Co
KI9]00?o0000ojUFZOnYEZT01_nYEZT00ol0003ofbCKom/Tf`07om/Tf`;o00003_o^4Nh00ol0003o
m0_doo@;m00;oo@;m003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfooH9mP08ooH9mP03o`00
0?oT6nCoi1_T00Goi1_T00?o0000oke2_Onm@[d01?nm@[d00ol0003o^TFjokY5^P03o`0000CoPWf2
0_l00008ocS7>003o`000?l@ka3o4>l@00Oo4>l@00Co0000oc7><OlacS7o<Lha0ol000000ol<l`co
0000obKI9P09obKI9P03o`000?m]TVgoKI9]00CoKI9]00?o0000ojUFZOnYEZT01OnYEZT00ol0003o
fbCKom/Tf`09om/Tf`03o`000?o^4NkokQ7^00gokQ7^00?o0000oo@;m?od2o@02_od2o@00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?om0_goo@;m017oo@;m00?o0000ooH9m_of2OH01oof2OH00ol0003oi1_Ton@Ki006on@Ki003o`00
0?nm@[go_D:m00?o_D:m00?o0000okY5^_njAKX01?njAKX2o`000003oh9mP_l0003o><Lh00[o><Lh
00?o0000oa3_4?l@ka001Ol@ka000ol0003o<Lhaoc7><@05oc7><@03o`000?lVfBKo9]TV00Oo9]TV
0ol00007offBK@03o`000?nYEZWoZEJY00CoZEJY00?o0000om/TfooK9=/02OoK9=/00ol0003okQ7^
onhAkP0=onhAkP03o`000?od2oCom0_d00[om0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of
2OKomPWf00GomPWf0ol00009on@Ki005o`000?nm@[go_D:moke2_Ol000002OnjAKX00ol0003o><Lh
ocS7>00;ocS7>003o`000?l@ka3o4>l@00?o4>l@00?o0000oc7><OlacS401_lacS400ol0003o9]TV
obKI9P06obKI9P05o`000?mQWV7oHIiQof6NHOl000001om]TVd00ol0003oZEJYojUFZ@03ojUFZ@03
o`000?oK9=_ofbCK00WofbCK00?o0000onhAk_o^4Nh03_o^4Nh00ol0003om0_doo@;m009oo@;m003
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfo`000004o`0000;on0Oh00?o0000on@Ki?oT6n@0
1ooT6n@01?l0003o_D:moke2_Ol00009okY5^P;o00003OlhacP00ol0003o4>l@oa3_4002oa3_4003
o`000?lacS7o<Lha00So<Lha00?o0000obKI9_lVfBH00olVfBH2o`0000GoHIiQ00?o0000offBKOm]
TVd01?m]TVd00ol0003oZEJYojUFZ@03ojUFZ@03o`000?oK9=_ofbCK00WofbCK00?o0000onhAk_o^
4Nh03_o^4Nh00ol0003om0_doo@;m009oo@;m003o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ood2oOom0_d04Oom0_d2o`0000Son0Oh
00?o0000on@Ki?oT6n@01_oT6n@00ol0003o_D:mo`000009okY5^P04o`000?n:MH[oRWF:o`0000go
><Lh00Co0000oa3_4?l@ka3o00003?lacS401Ol0003o9]TVobKI9_lVfBKo000000SoHIiQ0_l00005
offBK@03o`000?nYEZWoZEJY00;oZEJY00?o0000om/TfooK9=/02OoK9=/00ol0003okQ7^onhAkP0>
onhAkP03o`000?od2oCom0_d00Wom0_d00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oh1oSon0Oh
00Oon0Oh00?o0000on@Ki?oT6n@01ooT6n@00ol0003o^TFjokY5^P07okY5^P03o`000?n:MH[oRWF:
00;oRWF:00?o0000ocS7>?lhacP02_lhacP00ol0003o4>l@o`00000>oc7><@03o`000?lVfBKo0000
00_oHIiQ00?o0000offBKOm]TVd00_m]TVd01Ol0003oZEJYojUFZOnYEZWo000000cofbCK00?o0000
onhAk_o^4Nh03_o^4Nh3o`0000Wom0_d00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oh1oSon0Oh
00Won0Oh00?o0000on@Ki?oT6n@01_oT6n@00ol0003o^TFjokY5^P06okY5^P03o`000?n:MH[oRWF:
00?oRWF:00?o0000ocS7>?lhacP02olhacP00ol0003o<Lhaoc7><@0>oc7><@03o`000?mQWV7oHIiQ
00_oHIiQ0_l00003offBK@04o`000?nYEZWoZEJYo`0000[ofbCK0ol0000>onhAkP;o00000oon0Oh2
o`0000Oom0_d00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oh1oSon0Oh00[on0Oh00?o0000on@K
i?oT6n@01?oT6n@00ol0003o^TFjokY5^P06okY5^P03o`000?n:MH[oRWF:00GoRWF:00?o0000ocS7
>?lhacP01olhacP3o`00017o<Lha00?o0000of6NHOmQWV403OmQWV401Ol0003oKI9]offBKOl0003o
ZEJY00Co00000ooK9=/5o`0000;om`Sg00?o0000onhAk_o^4Nh02_o^4Nh2o`0000OooP7n0_l00004
oo@;m003o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03_om0_d00ol0003on0OhooP7n00;ooP7n003o`000?oT6nCoi1_T
00Coi1_T00?o0000okY5^_njAKX01OnjAKX00ol0003oRWF:ohYeRP06ohYeRP03o`000?lhacSo><Lh
00Co><Lh0ol00002ocg2?@03o`000?lacS7o<Lha00oo<Lha0_l0000?of6NH@04o`000?m]TVgo0000
o`0000CocS7>0ol00008ooL8m`03o`000?o^4NkokQ7^00OokQ7^0_l0000;ooh1oP;o00000_od2o@0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?om0_goo@;m00goo@;m00?o0000ooP7n?oh1oP03?oh1oP6o`0000Oo^TFj00?o0000ohYe
R_n:MHX02?n:MHX00ol0003o><LhocS7>003o`0000Ko?L8m00?o0000oc7><OlacS403OlacS401?l0
003oIYUVofJII_l0000?of6NH@03o`000?o><LkocS7>00GocS7>00?o0000ooL8moog2?L02?og2?L0
0ol0003okQ7^onhAkP05onhAkP03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oh1oP00ol0003oiaSWonLHi`04onLH
i`03o`000?njAK[o^TFj00?o^TFj00?o0000ohYeR_n:MHX02_n:MHX2o`0000[o?L8m00?o0000oc7>
<OlacS402olacS400ol0003oIYUVofJIIP02ofJIIP03o`000?mQWV7oHIiQ00_oHIiQ0_l00007olha
cP03o`000?og2?Oom`Sg00Wom`Sg00?o0000onhAk_o^4Nh00_o^4Nh2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003oiaSWonLHi`06onLHi`05o`000?njAK[o^TFjokY5
^_l000003On:MHX00ol0003o?L8mocg2?@0:ocg2?@03o`000?lacS7o<Lha00Wo<Lha00?o0000ofJI
I_mVVFH01?mVVFH00ol0003oHIiQof6NH@08of6NH@;o000000?oUVVFo`000?o><Lh01oo><Lh00ol0
003om`SgooL8m`09ooL8m`04o`000?o^4Nko0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onLHiooW6>L02?oW6>L00ol0003o^TFjo`00000=ohYeRP03o`000?lm`Sgo?L8m
00_o?L8m00?o0000oc7><OlacS402?lacS400ol0003oIYUVofJIIP06ofJIIP03o`000?mQWV7oHIiQ
00GoHIiQ0_l00003oiIYUP03o`000?o><LkocS7>00KocS7>00?o0000ooL8moog2?L02_og2?L00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on0OhooP7n007ooP7n003o`000?oW6>OoiaSW00[oiaSW00?o0000ohYeR_n:
MHX03?n:MHX00ol0003o?L8mocg2?@0<ocg2?@03o`000?lacS7o<Lha00Ko<Lha00?o0000ofJII_mV
VFH02?mVVFH00ol0003oHIiQof6NH@02of6NH@;o00001_nFJIH00ol0003ocS7>olhacP05olhacP03
o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oh1oSon0Oh00Gon0Oh
00?o0000onLHiooW6>L03?oW6>L2o`0000coRWF:00?o0000ocg2?Olm`Sd03Olm`Sd00ol0003o<Lha
oc7><@04oc7><@03o`000?mVVFKoIYUV00[oIYUV00Co0000of6NHOl0003o00002?nFJIH00ol0003o
cS7>olhacP06olhacP03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_oh1oP00ol0003oiaSWonLHi`0=onLHi`03o`000?niA[Wo000000;o00002?n:MHX00ol0003o?L8m
ocg2?@0?ocg2?@Ko00003_mVVFH00ol0003oUVVFoiIYUP08oiIYUP03o`000?o><LkocS7>00KocS7>
00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000ooX5n_oj1O[onPGj
0_l0000?onLHi`03o`000?niA[Wo^DJi00?o^DJi0ol00005ohYeRP;o00004?lm`Sd01_l0003oB[E:
odZeB_l0003oAKY5o`0000koIYUV00?o0000oiIYU_nFJIH02OnFJIH00ol0003ocS7>olhacP05olha
cP03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003o
iaSWonLHi`0=onLHi`03o`000?niA[Wo^DJi00Ko^DJi0ol000001?n:MH[o0000ofVFJOmYUVT3o`00
00co?L8m00Go0000odZeB_m:]D[oB[E:o`000002odFjA@03o`000?mVVFKoIYUV00_oIYUV00?o0000
oiIYU_nFJIH02OnFJIH00ol0003ocS7>olhacP06olhacP03o`000?og2?Oom`Sg00Som`Sg0_l0000A
ooh1oP?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003onPGjooX5nP04ooX5nPoo00003?niA[T00ol0003oJIIYofVFJ@04ofVF
J@?o00002?lm`Sd00ol0003oB[E:odZeBP02odZeBP05o`000?m5^TGoAKY5odFjAOl000003?mVVFH0
0ol0003oUVVFoiIYUP09oiIYUP03o`000?o><LkocS7>00GocS7>3?l00002oo`3o0;o00003Oon0Oh2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?oY5^WojAKY00_ojAKY00?o0000okU6
^OniA[T02_niA[T00ol0003oJIIYofVFJ@07ofVFJ@;o00001Olm`Sd00ol0003oB[E:odZeBP03odZe
BP03o`000?m5^TGoAKY500;oAKY500?o0000ofJII_mVVFH02OmVVFH00ol0003oUVVFoiIYUP0:oiIY
UP03o`000?o><LkocS7>00?ocS7>00?o0000oo<<looc3?<02Ooc3?<00ol0003oo0?loo`3o002oo`3
o0;o00002Oon0Oh2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oY5^WojAKY00[o
jAKY00?o0000okU6^OniA[T02oniA[T00ol0003oJIIYofVFJ@09ofVFJ@?o000000?o?L8mo`000?m:
]DX01Om:]DX00ol0003oAKY5odFjA@03odFjA@03o`000?mVVFKoIYUV00SoIYUV3_l00003olhacP;o
00002ooc3?<00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oka3_o`00000;onTFj@03o`000?niA[Wo^DJi00[o^DJi
0_l0000>ofVFJ@03o`000?m:]D[oB[E:00GoB[E:00?o0000odFjAOm5^TD00om5^TD00ol0003oIYUV
ofJIIP08ofJIIP03o`000?o=</gocC;=00_ocC;=00?o0000olhac_l000003Ooc3?<00ol0003oo0?l
oo`3o006oo`3o0;o000000?ooP7no`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00KonPGj00Co
0000onl@koo_4>oo00002_oY5^T00ol0003o^DJiokU6^@09okU6^@03o`000?nMHYgo000000koJIIY
00?o0000odZeB_m:]DX01Om:]DX00ol0003oAKY5odFjA@04odFjA@03o`000?mVVFKoIYUV00KoIYUV
00?o0000oldbcOo=</d03Oo=</d00ol0003ol`ccoo<<l`0<oo<<l`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000onl@koo_4>l00_o_
4>l00ol0003ojAKYonTFj@06onTFj@03o`000?niA[Wo^DJi00So^DJi0_l00003oieRW@03o`000?mY
UVWoJIIY00_oJIIY00?o0000odZeB_m:]DX01Om:]DX00ol0003oAKY5odFjA@05odFjA@03o`000?mV
VFKoIYUV00GoIYUV00?o0000oldbcOo=</d03Oo=</d00ol0003ol`ccoo<<l`0;oo<<l`03o`000?ol
0ocoo0?l00Woo0?l00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000
onl@koo_4>l00oo_4>l00ol0003ojAKYonTFj@05onTFj@03o`000?niA[Wo^DJi00Oo^DJi00?o0000
oieRWOnMHYd00onMHYd00ol0003oJIIYofVFJ@0:ofVFJ@03o`000?m:]D[oB[E:00KoB[E:00?o0000
odFjAOm5^TD01_m5^TD00ol0003oIYUVofJIIP04ofJIIP03o`000?o=</gocC;=00gocC;=3ol0000;
oo`3o003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000onl@koo_4>l01Oo_4>l00ol0
003ojAKYonTFj@04onTFj@03o`000?niA[Wo^DJi00Go^DJi0_l00006oieRW@03o`000?mYUVWoJIIY
00WoJIIY0_l00008odZeBP03o`000?m5^TGoAKY500KoAKY51Ol000000omVVFKo0000oldbc@0?oldb
c@03o`000?od2oCom0_d00_om0_d00?o0000oo`3o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000onl@koo_4>l01_o_4>l00ol0003o
jAKYonTFj@04o`0000Ko^DJi00?o0000oieRWOnMHYd01onMHYd00ol0003oJIIYofVFJ@05ofVFJ@?o
000000?oIYUVo`000?m:]DX01om:]DX00ol0003oAKY5odFjA@05odFjA@03o`000?n3O8?oPgb300?o
Pgb30_l0000?oldbc@;o00003Ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000WonPGj00?o0000onl@koo_4>l01oo_4>l2o`0000Coe2_D00Co0000okU6^OniA[Wo
^DJi0_l0000:oieRW@03o`000?mYUVWoJIIY00;oJIIY0ol00005ofJIIP03o`000?m:]D[oB[E:00Go
B[E:00?o0000odFjAOm5^TD01?m5^TD00ol0003oPgb3oh=lP`06oh=lP`03o`000?o=</gocC;=00[o
cC;=0_l00002onPGj003o`000?od2oCom0_d00[om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01_oj1OX00ol0003oka3_onl@k`08onl@k`03o`00
0?oD:mCoe2_D00Coe2_D00?o0000okU6^Ol000003?nMHYd00ol0003oJIIYo`000002o`0000WoIYUV
00?o0000odZeB_m:]DX01?m:]DX00ol0003oAKY5odFjA@03odFjA@03o`000?n3O8?oPgb300SoPgb3
1_l00004oldbc@;o00001OoX5nP00ol0003om0_doo@;m009oo@;m003o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000onl@koo_4>l01oo_
4>l00ol0003oe2_Dom@[e006om@[e003o`000?nMHYgoWF:M00coWF:M00?o0000ofJII_mVVFH02_mV
VFH00ol0003oB[E:odZeBP04odZeBP04o`000?m5^TGoAKY5odFjA@;o00002on3O8<00ol0003odBkA
om4^d@03om4^d@Co00002?oX5nP00ol0003om0_doo@;m008oo@;m003o`000?ol0ocoo0?l00Ooo0?l
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003oka3_onl@k`07onl@k`03o`000?oD
:mCoe2_D00Ooe2_D00?o0000oieRWOnMHYd03?nMHYd00ol0003oIYUVofJIIP0;ofJIIP03o`000?m:
]D[oB[E:00?oB[E:00Co0000odFjAOm5^TGo00003On3O8<00ol0003odBkAom4^d@06om4^d@03o`00
0?oX5nSoj1OX00Ooj1OX00?o0000oo@;m?od2o@01ood2o@00ol0003oo0?loo`3o006oo`3o004o`00
0?oo0?ooo`3oool0o`;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000onl@koo_4>l0
1_o_4>l00ol0003oe2_Dom@[e009om@[e003o`000?nMHYgoWF:M00WoWF:M0_l0000>ofJIIP?o0000
0om:]DX00ol0003oAKY5o`00000=oh=lP`03o`000?oA;]7odBkA00OodBkA00?o0000onPGj?oX5nP0
2?oX5nP:o`0000Koo0?l0_l00006ool0o`03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Ooka3_00?o
0000om@[e?oD:m@02_oD:m@00ol0003oWF:MoieRW@06oieRW@;o000000?oVVFJo`000?mVVFH02omV
VFH2o`0000?oKY5^1Ol0000>oh=lP`03o`000?oA;]7odBkA00OodBkA00?o0000onPGj?oX5nP02?oX
5nP00ol0003on0OhooP7n006ooP7n003o`000?ol0ocoo0?l00?oo0?l00?o0000ool0oooo0?l01ooo
0?l2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003om@[eooD:m@03ooD:m@Co00000_o_4>l00ol0003oe2_Dom@[e00;
om@[e003o`000?nMHYgoWF:M00?oWF:M0ol00004oiYUVP03o`000?mVVFKoIYUV00OoIYUV0_l00008
ofjAKP03o`000?n3O8?oPgb300goPgb300?o0000om4^dOoA;]402?oA;]400ol0003oj1OXonPGj007
onPGj003o`000?oh1oSon0Oh00Oon0Oh0ol000000ool0oco0000ool0o`0;ool0o`;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oe2_Gom@[e00Oom@[e0_l0000?om@[e003o`000?nMHYgoWF:M00;o00002?nJIIX00ol0
003oIYUVofJIIP05ofJIIP03o`000?m^TFkoKY5^00SoKY5^00?o0000oh=lPon3O8<03On3O8<00ol0
003odBkAom4^d@08om4^d@03o`000?oX5nSoj1OX00Koj1OX00?o0000ooP7n?oh1oP02?oh1oP01?l0
003oo0?loo`3o?l0000?ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om@[eooD:m@09ooD:
m@03o`000?oD:mCoe2_D00koe2_D0_l0000;oiYUVP03o`000?mVVFKoIYUV00;oIYUV0_l0000;ofjA
KP03o`000?n3O8?oPgb300goPgb300?o0000om4^dOoA;]402?oA;]400ol0003oj1OXonPGj006onPG
j003o`000?oh1oSon0Oh00Oon0Oh00Go0000oo`3o?ol0ocoo0?lo`00000@ool0o`;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om@[eooD:m@0:ooD:m@03o`000?oD:mCoe2_D00goe2_D0_l0000<oiYUVP04o`000?mVVFKo0000
o`0000goKY5^00?o0000oh=lPon3O8<03?n3O8<00ol0003odBkAom4^d@09om4^d@03o`000?oX5nSo
j1OX00Koj1OX00?o0000ooP7n?oh1oP01_oh1oP00ol0003oo0?loo`3o003oo`3o003o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003om@[eooD:m@0:ooD:m@03o`000?oD:mCoe2_D00coe2_D00Co0000omDZ
eOoE:]Go00003?nJIIX00ol0003oKY5^ofjAKP0>ofjAKP03o`000?n3O8?oPgb300SoPgb31?l0000;
om4^d@03o`000?oX5nSoj1OX00Koj1OX00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo0?loo`3o004
oo`3o003o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003om@[eooD:m@0;ooD:m@03o`000?oD:mCoe2_D
00_oe2_D00?o0000omDZeOoE:]D00_oE:]D00ol0003oVVFJoiYUVP09oiYUVP03o`000?m^TFkoKY5^
00koKY5^00Co0000oh=lPon3O8?oPgb31ol00003ojQGZ003o`000?oA;]7odBkA00WodBkA00?o0000
onPGj?oX5nP01_oX5nP00ol0003on0OhooP7n004ooP7n003o`000?ol0ocoo0?l00Koo0?l00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oe2_Gom@[e00com@[e00?o0000om@[e?oD:m@02_oD:m@00ol0
003oeB[EomDZe@03omDZe@03o`000?nJII[oVVFJ00SoVVFJ00?o0000ofjAK_m^TFh03_m^TFh4o`00
00_oZ5NX00?o0000om4^dOoA;]402?oA;]400ol0003oj1OXonPGj005onPGj003o`000?oh1oSon0Oh
00Gon0Oh00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooD:mOoe
2_D03?oe2_D7o`0000Goe2_D00?o0000omDZeOoE:]D01OoE:]D00ol0003oVVFJoiYUVP07oiYUVP03
o`000?m^TFkoKY5^00koKY5^00?o0000ojQGZ?nXEjP03OnXEjP00ol0003odBkAom4^d@08om4^d@03
o`000?oX5nSoj1OX00Coj1OX00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo0?loo`3o007oo`3o003
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003om@[eooD:m@0=ooD:m@03o`000?oX5nSoj1OX00Coj1OX
1Ol00009omDZe@03o`000?nJII[oVVFJ00KoVVFJ00?o0000ofjAK_m^TFh03_m^TFh00ol0003oZ5NX
ojQGZ00=ojQGZ003o`000?oA;]7odBkA00SodBkA00Co0000onPGj?oX5nSoj1OX1Ol00004ooP7n003
o`000?ol0ocoo0?l00Woo0?l1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooD:m@03o`000?oX5nSoj1OX00Woj1OX
0_l00009omDZe@03o`000?nJII[oVVFJ00KoVVFJ00?o0000ofjAK_m^TFh03?m^TFh00ol0003oZ5NX
ojQGZ00?ojQGZ0Ko00001?oA;]44o`0000Gom0_d0_l000000ooh1oSo0000oo`3o00;oo`3o004o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?ok1?_on`Ckoo/4n`?o00002_oe2_D00ol0003o
j1OXonPGj009onPGj003o`000?oP7n3o000000;o00001ooE:]D00ol0003oVVFJoiYUVP05oiYUVP03
o`000?m^TFkoKY5^00SoKY5^1Ol0000AojQGZ003o`000?oL8mcog2?L00?og2?L1?l0000;oo@;m003
o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000Oom@[e
00?o0000onPGj?oX5nP02_oX5nP00ol0003oh1oPon0Oh002on0Oh0?o00001OoE:]D00ol0003oVVFJ
oiYUVP04oiYUVP04o`000?m^TFkoKY5^ofjAKPOo00001?nXEjP00ol0003oZ5NXojQGZ00>ojQGZ003
o`000?oL8mcog2?L00Oog2?L00?o0000oo@;m?od2o@02Ood2o@00ol0003oo0?loo`3o009oo`3o003
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`08oo/4n`;o00001?oe2_D00ol0003oj1OX
onPGj00;onPGj003o`000?oP7n3oh1oP00Goh1oP0ol00003omDZe@04o`000?nJII[oVVFJoiYUVPKo
00003?nXEjP00ol0003oZ5NXojQGZ00=ojQGZ003o`000?oL8mcog2?L00Oog2?L00?o0000oo@;m?od
2o@02_od2o@00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo/4n`?o000000?om@[eo`000?oX5nP0
3?oX5nP00ol0003oh1oPon0Oh008on0Oh0?o000000CoeB[Eo`000?l0003o00000_oA;]400ol0003o
Z5NXojQGZ00=ojQGZ003o`000?nXEjSoZ5NX00coZ5NX00?o0000om`Sg?oL8m`02?oL8m`00ol0003o
m0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00Koo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
n`Ck00?o0000onPGj?oX5nP03?oX5nP00ol0003oh1oPon0Oh00;on0Oh003o`000?oA;]7odBkA00?o
dBkA00?o0000ojQGZ?nXEjP03?nXEjP00ol0003o^dBko`00000=ojQGZ003o`000?oL8mcog2?L00So
g2?L00?o0000oo@;m?od2o@03?od2o@3o`0000Goo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ok1?_on`Ck00con`Ck00?o0000onPGj?oX5nP03?oX5nP00ol0003oh1oPon0Oh00:on0Oh003o`00
0?oA;]7odBkA00GodBkA00?o0000ojQGZ?nXEjP02_nXEjP01?l0003o^dBkok]4^onkA;/2o`0000[o
Z5NX00?o0000om`Sg?oL8m`02OoL8m`00ol0003om0_doo@;m00<oo@;m003o`000?om0_goo@;m00?o
000000?oo0?lo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onPGj?oX5nP0
3?oX5nP00ol0003oh1oPon0Oh009on0Oh003o`000?oA;]7odBkA00KodBkA00?o0000ojQGZ?nXEjP0
2OnXEjP00ol0003o^dBkok]4^`02ok]4^`03o`000?oC;=?o000000;o00001onXEjP00ol0003og2?L
om`Sg009om`Sg003o`000?od2oCom0_d00_om0_d00?o0000ood2oOom0_d01?om0_d00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oj1OXonPGj00;onPGj003o`000?oP
7n3oh1oP00Soh1oP00?o0000om4^dOoA;]401ooA;]400ol0003oZ5NXojQGZ008ojQGZ003o`000?nk
A;_o^dBk00?o^dBk00?o0000om</dooC;=<00_oC;=<2o`0000CoZ5NX00?o0000om`Sg?oL8m`02_oL
8m`00ol0003om0_doo@;m00:oo@;m003o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?ok1?_on`Ck00[on`Ck0ol0000;onPGj0Ko00001?oP7n000ol0003odBkAom4^d@08
om4^d@03o`000?nXEjSoZ5NX00OoZ5NX00?o0000ok]4^onkA;/00onkA;/00ol0003odbcCom</d`05
om</d`?o000000?oZ5NXo`000?oL8m`02ooL8m`00ol0003om0_doo@;m009oo@;m003o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8
moog2?L01?l00006onPGj003o`000?oZ5N[ojQGZ00CojQGZ1?l0000<om4^d@03o`000?nXEjSoZ5NX
00GoZ5NX00?o0000ok]4^onkA;/01?nkA;/00ol0003odbcCom</d`08om</d`03o`000?oL8mcog2?L
00_og2?L00?o0000oo@;m?od2o@02?od2o@00ol0003oo@;mood2o@08ood2o@Go00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?ok1?_on`Ck00Oon`Ck00?o0000ooL8moog2?L01Oog2?L3o`0000;oj1OX00?o0000onXEj_oZ
5NX02?oZ5NX00ol0003odBkAom4^d@0:om4^d@03o`000?nXEjSoZ5NX00CoZ5NX00?o0000ok]4^onk
A;/01OnkA;/00ol0003odbcCom</d`08om</d`03o`000?oL8mcog2?L00Wog2?L1?l00008oo@;m003
o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`05oo/4n`03o`000?og2?Oom`Sg00Wom`Sg0_l0000<onXEjP03o`000?oA;]7odBkA00WodBkA
00?o0000ojQGZ?nXEjP00onXEjP00ol0003o^dBkok]4^`05ok]4^`03o`000?oC;=?odbcC00[odbcC
00?o0000om`Sg?oL8m`01?oL8m`4o`0000ColPgb00?o0000oo@;m?od2o@01?od2o@00ol0003oo@;m
ood2o@0:ood2o@03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooL8moog2?L02oog
2?L00ol0003ojQGZonXEjP0:onXEjP03o`000?oA;]7odBkA00WodBkA00?o0000ojQGZ?nXEjP00_nX
EjP00ol0003o^dBkok]4^`06ok]4^`03o`000?oC;=?odbcC00[odbcC00?o0000om`Sg?oL8m`01?l0
0009oo8=lPKo00003?om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000oo/4nook1?_on`Ck0_l0
000=ooL8m`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000om4^dOoA;]402OoA;]401Ol0003oZ5NXojQG
Z?nXEjSo000000Wo^dBk00?o0000om</dooC;=<02ooC;=<2o`0000golPgb00?o0000oo`3o?ol0o`0
0_ol0o`00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Cko`00
0002ooh1oP;o00002oog2?L00ol0003ojQGZonXEjP0;onXEjP03o`000?oA;]7odBkA00WodBkA00?o
0000ojQGZ?l000002OnkA;/00ol0003odbcCom</d`0<om</d`03o`000?ob3O;olPgb00colPgb00?o
0000oo`3o?ol0o`00ool0o`00ol0003oo@;mood2o@09ood2o@03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP03ooh1oP;o00002_og2?L00ol0003ojQGZonXEjP0:onXEjP03o`000?oA;]7o
dBkA00SodBkA1Ol00008ok]4^`03o`000?oC;=?odbcC00codbcC00?o0000oo8=l_ob3O802oob3O80
0ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001oon0Oh2o`0000Som`Sg00?o0000onXEj_oZ5NX02_oZ5NX00ol0003odBkAom4^d@07om4^
d@03o`000?oH9mSof2OH00?of2OH0ol00005ok]4^`03o`000?oC;=?odbcC00_odbcC00?o0000oo8=
l_ob3O803?ob3O800ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?oo0?oo000000WooP7n00?o0000ooL8moog2?L01Oog2?L2o`0000co
jQGZ00?o0000om4^dOoA;]401OoA;]400ol0003of2OHomPWf007omPWf0?o000000?o^dBko`000?oC
;=<03OoC;=<00ol0003olPgboo8=lP0<oo8=lP03o`000?ol0ocoo0?l00Koo0?l00?o0000ood2oOom
0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooL8m`03o`000?oj1O[onPGj00;o00002_oZ5NX00ol0003odBkAom4^d@03om4^d@;o0000
3OoH9mP2o`0000godbcC0ol0000=oo8=lP03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d0
1Oom0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000oog2?Oo0000ooX5nP04ooX5nP03o`000?oZ5N[ojQGZ00OojQGZ00Co0000om4^dOoA;]7odBkA
0_l00002onhAkP03o`000?oH9mSof2OH00cof2OH3Ol00003oo@;m003o`000?ob3O;olPgb00[olPgb
00?o0000oo`3o?ol0o`02?ol0o`01?l0003oo@;mood2oOom0_d4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj0_l00008onXEjP03o`000?oA;]7o000000GokQ7^
00?o0000omPWf?oH9mP02ooH9mP00ol0003ohAkQon4Nh@09on4Nh@03o`000?od2oCom0_d00;om0_d
0_l00009oo8=lP03o`000?ol0ocoo0?l00[oo0?l0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX01ooj1OX4o`0000?ojQGZ0ol0
0007onhAkP03o`000?oH9mSof2OH00[of2OH00?o0000on4NhOoQ7^402OoQ7^400ol0003om0_doo@;
m004oo@;m0;o00001oob3O800ol0003oo0?loo`3o00:oo`3o003o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj1OX02?oj1OX0
1?l0003on@KiooT6nOoi1_T3o`0000;omPWf00?o0000onhAk_o^4Nh01_o^4Nh00ol0003of2OHomPW
f008omPWf003o`000?oQ7^7ohAkQ00[ohAkQ00?o0000oo@;m?od2o@01_od2o@00ol0003olPgboo8=
lP04oo8=lP03o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oi1_Wo
n@Ki00Con@Ki00Go0000ooH9m_of2OKomPWfo`000008onhAkP03o`000?oH9mSof2OH00Oof2OH00?o
0000on4NhOoQ7^402_oQ7^400ol0003om0_doo@;m007oo@;m0;o00001?ob3O800ol0003oo0?loo`3
o008oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP08ooX5nP03o`000?oi1_Won@Ki00Con@Ki00?o0000ooH9m_of2OH00_of2OH0
0ol0003okQ7^onhAkP07onhAkP03o`000?oH9mSof2OH00Kof2OH00?o0000on4NhOoQ7^402_oQ7^40
0ol0003om0_doo@;m009oo@;m005o`000?ob3O;olPgboo8=l_l000002Ool0o`00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_onPGj00?o0000ooT6nOoi1_T01?oi1_T00ol0003omPWfooH9mP03
ooH9mP03o`000?o^4NkokQ7^00OokQ7^00?o0000omPWf?oH9mP01OoH9mP00ol0003ohAkQon4Nh@0:
on4Nh@03o`000?od2oCom0_d00Wom0_d1?l00009oo`3o003o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_oj1OX00ol0003on@KiooT6n@05ooT6n@03o`000?of2OKomPWf00?omPWf00?o0000
onhAk_o^4Nh02?o^4Nh00ol0003of2OHomPWf004omPWf003o`000?oQ7^7ohAkQ00WohAkQ00?o0000
oo@;m?od2o@02?od2o@2o`0000?oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oi1_Won@Ki
00Gon@Ki00?o0000ooH9m_of2OH01?of2OH00ol0003okQ7^onhAkP09onhAkP03o`000?oH9mSof2OH
00;of2OH00?o0000on4NhOoQ7^402_oQ7^400ol0003om0_doo@;m006oo@;m0;o00001_ol0o`8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooT6nOoi
1_T01Ooi1_T00ol0003omPWfooH9mP05ooH9mP03o`000?o^4NkokQ7^00WokQ7^00Go0000omPWf?oH
9mSof2OHo`00000<on4Nh@03o`000?od2oCom0_d00Com0_d0_l00008oo`3o003o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003on@KiooT6n@06ooT6n@03o`000?of2OKomPWf00GomPWf00?o0000onhAk_o^
4Nh02_o^4Nh00ol0003of2OHo`000004o`0000WohAkQ00?o0000oo@;m?od2o@00_od2o@2o`0000[o
o0?l00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?oj1O[onPGj00;onPGj00?o0000ooT6nOoi1_T01_oi1_T00ol0003omPWfooH9mP07ooH9mP;o0000
2oo^4Nh00ol0003om`SgooL8m`03ooL8m`Oo00000_oQ7^400ol0003om0_doo@;m002o`0000_oo0?l
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003onPGjooX5n_oj1O[o000000Son@Ki00?o0000ooH9m_of2OH01oof2OH00ol0003onPGj
o`000002o`0000SokQ7^00?o0000ooL8moog2?L02_og2?L5o`0000goo0?l00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?oj1O[o000000Won@Ki00?o
0000ooH9m_of2OH01_of2OH00ol0003onPGjooX5nP03ooX5nP?o00001?o^4Nh00ol0003om`SgooL8
m`0=ooL8m`03o`000?ol0ocoo0?l00goo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003omPWfooH9mP07
ooH9mP03o`000?oj1O[onPGj00KonPGj0ol000000oo^4Nko0000ooL8m`0>ooL8m`03o`000?ol0oco
o0?l00coo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?oi1_Won@Ki00;on@Ki1_l00008ooH9mP03o`000?oj1O[onPGj00[onPGj00?o0000ooL8
moog2?L03oog2?L00ol0003oo0?loo`3o00:oo`3o0;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_ol0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oj1O[onPGj00[o
nPGj00?o0000ooL8moog2?L03oog2?L00ol0003oo0?loo`3o007oo`3o0?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?ol0ocoo0?l00Woo0?l00?o0000ooH9m_of
2OH00oof2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?og2?Oom`Sg00oom`Sg00?o0000oo`3o?ol
0o`01Ool0o`2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Ool0o`00ol0003omPWfooH9mP02ooH9mP03o`000?oj1O[onPGj00_onPGj5?l00004oo`3o0;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>oo`3o004o`000?of2OKomPWfo`0000konPGj
00?o0000ood2oOom0_d04?om0_d00ol0003oo0?lo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_ol0o`00ol0003omPWfo`00000>ooX5nP03o`00
0?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?oj1O[onPGj00WonPGj1Ol0
000Bood2o@;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00;onPGj1ol00004ooh1oP03o`000?om0_go
o@;m00ooo@;m00?o0000ooh1o_l000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?ol0ocoo0?l00coo0?l1?l0000<ooh1oP03o`000?om0_goo@;m00coo@;m0_l00003ooh1
oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00_o
o@;m00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?on0OkooP7n00kooP7n00?o0000ood2oOom
0_d02Oom0_d2o`0000OooP7n00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?om0_goo@;m00Koo@;m0_l0000:ooh1oP03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aooh1oP?o00001_om0_d00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000oom0_d2o`0000kooP7n00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ood2oOl000004Oon0Oh00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Oon0Oh00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003ooP7nooh1oP0>ooh1oP04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0<ooh1oPCo00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?on0Oh3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ooh1oP?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool01ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l2oooo00?o003o0_ooo`07o`00o`;oool02?l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0007o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool01ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Oo003o0_ooo`05o`00o`;oool01_l00?l2oooo
00Oo003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Oo
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00Ko003o0_ooo`05o`00o`?oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00Ko003o0oooo`03o`00o`?oool01ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`001_l00?l2oooo0003o`00ooooo`3oool000?oool02?l00?l2oooo00Ko003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00Oo003o00?oool0o`00ool00?l03?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2
oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00
o`;oool01ol00?l2oooo00go003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00So
003o00?oool0o`00ool00?l02ol00?l2oooo00Ko003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool0
2?l00?l2oooo00co003o0_ooo`07o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo
001Xo`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l0
0?oo003o00Ko003o0_ooo`0;o`00o`;oool01ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool02?l00?l2oooo00Oo003o1?ooo`08o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1W
o`00o`7ooooo001Vo`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool09Ol00?l3oooo
00Ko003o0_ooo`09o`00o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o
0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(620) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.991 .009 .991 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.991 .009 .991 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.986 .014 .986 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.98 .02 .98 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.98 .02 .98 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.949 .051 .949 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.96 .04 .96 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.911 .089 .911 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.974 .026 .974 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.991 .009 .991 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.829 .171 .829 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.977 .023 .977 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.948 .052 .948 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.945 .055 .945 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.955 .045 .955 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.965 .035 .965 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.982 .018 .982 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.928 .072 .928 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.966 .034 .966 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.884 .116 .884 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.979 .021 .979 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.961 .039 .961 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.935 .065 .935 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.962 .038 .962 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.845 .155 .845 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.973 .027 .973 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.937 .063 .937 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.979 .021 .979 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.886 .114 .886 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.636 .364 .636 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.707 .293 .707 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.993 .007 .993 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.968 .032 .968 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.906 .094 .906 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.916 .084 .916 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.657 .343 .657 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.622 .378 .622 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.578 .422 .578 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.893 .107 .893 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.91 .09 .91 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.889 .111 .889 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.835 .165 .835 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.987 .013 .987 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.745 .255 .745 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.978 .022 .978 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.95 .05 .95 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.667 .333 .667 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.607 .393 .607 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.842 .158 .842 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.338 .662 .338 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.334 .666 .334 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.374 .626 .374 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.734 .266 .734 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.73 .27 .73 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.977 .023 .977 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.33 .67 .33 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.306 .694 .306 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.92 .08 .92 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.987 .013 .987 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.996 .004 .996 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.516 .484 .516 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.622 .378 .622 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.88 .12 .88 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.867 .133 .867 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.549 .451 .549 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.839 .161 .839 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.272 .728 .272 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.742 .258 .742 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.611 .389 .611 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.073 .927 .073 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.242 .758 .242 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.962 .038 .962 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.127 .873 .127 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.106 .894 .106 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.822 .178 .822 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.966 .034 .966 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.358 .642 .358 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.082 .918 .082 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.147 .853 .147 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.703 .297 .703 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.227 .773 .227 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.418 .582 .418 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.981 .019 .981 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.097 .903 .097 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.068 .932 .068 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.247 .753 .247 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.41 .59 .41 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.933 .067 .933 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.439 .561 .439 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.506 .494 .506 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.011 .989 .011 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.046 .954 .046 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.067 .933 .067 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.666 .334 .666 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.851 .149 .851 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.902 .098 .902 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.318 .682 .318 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.092 .908 .092 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.738 .262 .738 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.989 .011 .989 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.091 .909 .091 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.3 .7 .3 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.017 .983 .017 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.195 .805 .195 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.785 .215 .785 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.28 .72 .28 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.996 .004 .996 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.052 .948 .052 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.966 .034 .966 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.99 .01 .99 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.832 .168 .832 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.884 .116 .884 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.148 .852 .148 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.956 .044 .956 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.52 .48 .52 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.525 .475 .525 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.012 .988 .012 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.157 .843 .157 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.408 .592 .408 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.665 .335 .665 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.023 .977 .023 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.976 .024 .976 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.145 .855 .145 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.14 .86 .14 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.957 .043 .957 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.389 .611 .389 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.276 .724 .276 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.198 .802 .198 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.191 .809 .191 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.864 .136 .864 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.847 .153 .847 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.824 .176 .824 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.095 .905 .095 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.434 .566 .434 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.595 .405 .595 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.806 .194 .806 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.949 .051 .949 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.984 .016 .984 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.385 .615 .385 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.667 .333 .667 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.265 .735 .265 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.931 .069 .931 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.911 .089 .911 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.809 .191 .809 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.958 .042 .958 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.987 .013 .987 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.368 .632 .368 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.497 .503 .497 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.98 .02 .98 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.357 .643 .357 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.863 .137 .863 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.615 .385 .615 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.753 .247 .753 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.517 .483 .517 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.966 .034 .966 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.952 .048 .952 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.958 .042 .958 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.973 .027 .973 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.677 .323 .677 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.99 .01 .99 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.929 .071 .929 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.585 .415 .585 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.641 .359 .641 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.804 .196 .804 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.795 .205 .795 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.989 .011 .989 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.934 .066 .934 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.986 .014 .986 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.702 .298 .702 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.974 .026 .974 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.917 .083 .917 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.888 .112 .888 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.867 .133 .867 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.797 .203 .797 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.84 .16 .84 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.752 .248 .752 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.869 .131 .869 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.933 .067 .933 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.964 .036 .964 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.944 .056 .944 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.956 .044 .956 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.972 .028 .972 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.933 .067 .933 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.829 .171 .829 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.924 .076 .924 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.954 .046 .954 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.974 .026 .974 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.97 .03 .97 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.975 .025 .975 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.947 .053 .947 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.988 .012 .988 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.991 .009 .991 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.979 .021 .979 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.954 .046 .954 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.988 .012 .988 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.971 .029 .971 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.979 .021 .979 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.995 .005 .995 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.983 .017 .983 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.995 .005 .995 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.996 .004 .996 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(630) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.991 .009 .991 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.992 .008 .992 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.987 .013 .987 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.981 .019 .981 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.98 .02 .98 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.95 .05 .95 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.961 .039 .961 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.913 .087 .913 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.974 .026 .974 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.993 .007 .993 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.991 .009 .991 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.833 .167 .833 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.978 .022 .978 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.949 .051 .949 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.947 .053 .947 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.957 .043 .957 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.966 .034 .966 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.982 .018 .982 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.997 .003 .997 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.93 .07 .93 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.967 .033 .967 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.887 .113 .887 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.979 .021 .979 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.962 .038 .962 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.937 .063 .937 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.963 .037 .963 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.849 .151 .849 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.974 .026 .974 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.939 .061 .939 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.979 .021 .979 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.888 .112 .888 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.643 .357 .643 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.713 .287 .713 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.993 .007 .993 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.993 .007 .993 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.969 .031 .969 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.908 .092 .908 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.918 .082 .918 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.663 .337 .663 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.628 .372 .628 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.584 .416 .584 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.896 .104 .896 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.913 .087 .913 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.892 .108 .892 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.839 .161 .839 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.748 .252 .748 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.979 .021 .979 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.952 .048 .952 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.673 .327 .673 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.613 .387 .613 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.844 .156 .844 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.344 .656 .344 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.34 .66 .34 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.381 .619 .381 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.738 .262 .738 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.736 .264 .736 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.978 .022 .978 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.337 .663 .337 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.312 .688 .312 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.923 .077 .923 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.987 .013 .987 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.522 .478 .522 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.629 .371 .629 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.883 .117 .883 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.87 .13 .87 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.555 .445 .555 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.842 .158 .842 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.277 .723 .277 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.748 .252 .748 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.619 .381 .619 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.99 .01 .99 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.076 .924 .076 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.248 .752 .248 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.964 .036 .964 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.133 .867 .133 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.111 .889 .111 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.827 .173 .827 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.967 .033 .967 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.365 .635 .365 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.087 .913 .087 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.152 .848 .152 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.71 .29 .71 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.232 .768 .232 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.426 .574 .426 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.103 .897 .103 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.072 .928 .072 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.253 .747 .253 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.419 .581 .419 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.936 .064 .936 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.447 .553 .447 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.514 .486 .514 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.011 .989 .011 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.049 .951 .049 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.071 .929 .071 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.673 .327 .673 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.856 .144 .856 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.905 .095 .905 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.325 .675 .325 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.091 .909 .091 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.745 .255 .745 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.99 .01 .99 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.098 .902 .098 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.308 .692 .308 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.021 .979 .021 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.199 .801 .199 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.79 .21 .79 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.287 .713 .287 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.055 .945 .055 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.967 .033 .967 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.99 .01 .99 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.836 .164 .836 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.888 .112 .888 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.153 .847 .153 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.957 .043 .957 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.527 .473 .527 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.529 .471 .529 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.017 .983 .017 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.161 .839 .161 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.414 .586 .414 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.672 .328 .672 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.996 .004 .996 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.028 .972 .028 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.977 .023 .977 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.148 .852 .148 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.147 .853 .147 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.959 .041 .959 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.395 .605 .395 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.989 .011 .989 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.283 .717 .283 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.202 .798 .202 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.193 .807 .193 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.868 .132 .868 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.85 .15 .85 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.829 .171 .829 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.1 .9 .1 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.441 .559 .441 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.601 .399 .601 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.81 .19 .81 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.95 .05 .95 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.985 .015 .985 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.392 .608 .392 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.672 .328 .672 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.271 .729 .271 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.933 .067 .933 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.913 .087 .913 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.813 .187 .813 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.96 .04 .96 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.988 .012 .988 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.376 .624 .376 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.505 .495 .505 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.981 .019 .981 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.366 .634 .366 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.866 .134 .866 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.619 .381 .619 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.758 .242 .758 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.523 .477 .523 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.967 .033 .967 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.953 .047 .953 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.959 .041 .959 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.974 .026 .974 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.684 .316 .684 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.99 .01 .99 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.931 .069 .931 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.593 .407 .593 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.648 .352 .648 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.808 .192 .808 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.8 .2 .8 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.989 .011 .989 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.935 .065 .935 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.986 .014 .986 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.709 .291 .709 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.975 .025 .975 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.92 .08 .92 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.891 .109 .891 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.87 .13 .87 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.802 .198 .802 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.843 .157 .843 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.757 .243 .757 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.873 .127 .873 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.935 .065 .935 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.965 .035 .965 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.945 .055 .945 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.957 .043 .957 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.973 .027 .973 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.936 .064 .936 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.833 .167 .833 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.926 .074 .926 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.955 .045 .955 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.975 .025 .975 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.971 .029 .971 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.976 .024 .976 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.993 .007 .993 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.949 .051 .949 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.989 .011 .989 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.991 .009 .991 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.98 .02 .98 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.956 .044 .956 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.988 .012 .988 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.972 .028 .972 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.98 .02 .98 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.984 .016 .984 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooh1oP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_on0Oh2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0<ooh1oP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?oo0?ooo`3oool0ool000004Oon
0Oh01?l0003oo0?loo`3o?l0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh0
3_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?on0Oh03oon0Oh00ol0003oo`3oool0o`02ool0o`03o`000?on
0OkooP7n00gooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000
ool0oooo0?l01?oo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00?oo0?l00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00oooP7n00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n
00[ooP7n00?o0000oo`3o?ol0o`01Ool0o`00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o006oo`3o003
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0@ooh1oP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?on0Oh00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n
00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ooh1o_on0Oh04?on0Oh<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go0000013ooP7n00?o0000ool0oooo0?l02?oo
0?l9o`0000coo0?l00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?on0OkooP7n00oooP7n
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ood2o@03o`000?on
0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003onPGjooX5nP05ooX5nP03o`000?ol
0ocoo0?l00_oo0?l0ol00003oo/4n`03o`000?on0OkooP7n00cooP7n0ol0000>ooh1oP;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ood2oOom0_d00oom0_d00ol0003ooP7nooh1oP0;ooh1oP;o00002ooo0?l00ol0003onPGjooX5nP06
ooX5nP03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oi1_Won@KiooT6n@;o00002_on0Oh2o`000003ooT6nOl0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@05ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOl000002ooo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Wo
n@Ki00Con@Ki0_l00005ooh1oP?o00001?oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?on0OkooP7n00SooP7n0_l00008ood2o@03o`000?on0OkooP7n00OooP7n0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00Oon`Ck00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Won@Ki0_l000000oon
0Oko0000o`000007ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000SooP7n00?o0000ood2oOom
0_d02?om0_d00ol0003ooP7nooh1oP06ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003onPGjooX5nP08ooX5nP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?lo`000005ooh1oP;o00002oom0_d2o`0000KooP7n
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oj1O[onPGj00SonPGj
00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`0;oo/4n`05o`000?on0OkooP7nooh1o_l0
00003_oi1_T00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?ol0ocoo0?loo`3o?l0
00000oon0Oh00ol0003oo@;mood2o@0:ood2o@04o`000?og2?Oom`Sgo`0000?ooP7n0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo0?loo`3o005oo`3
o003o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_l000003ooi1_T00ol0003on@KiooT6n@08ooT6
n@03o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o003oo`3o003o`000?on0Oko000000_o
o@;m0_l00004ooL8m`03o`000?on0Oko000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP09ooX5nP03o`000?ol0ocoo0?l00Coo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003o
n@KiooT6n@0>ooT6n@03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oj1O[onPGj00[onPGj00?o0000oo`3o?ol0o`0
0ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oi1_Won@Ki00gon@Ki00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3
o005oo`3o003o`000?om0_goo@;m00Ooo@;m0_l00008ooL8m`03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003onPGjooX5nP0:ooX5nP04o`000?ol0ocoo0?loo`3o0?o0000
3ook1?/00ol0003on@KiooT6n@0>ooT6n@03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d01?om0_d2o`0000_om`Sg1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02ooj1OX01?l0003oo0?lo`00
0?l00003onhAkP;o00003?ok1?/2o`00013on@Ki00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo0?l
oo`3o007oo`3o003o`000?om0_goo@;m00?oo@;m00?o0000ooL8moog2?L02oog2?L01?l0003oiaSW
onLHiooW6>L5o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003onPGjooX5nP0<ooX5nP03
o`000?o^4NkokQ7^00GokQ7^0_l00008oo/4n`;o00000_o^4Nh00ol0003on@KiooT6n@0=ooT6n@03
o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o009oo`3o003o`000?om0_goo@;m00;o0000
3Oog2?L00ol0003oiaSWonLHi`07onLHi`Ko00000_oo0?l4o`0000gonPGj00?o0000onhAk_o^4Nh0
1oo^4Nh2o`0000Gon`Ck00?o0000onhAk_o^4Nh00oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`00
0?oi1_Won@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Woo0?l00?o
0000ood2oOl000003oog2?L00ol0003oiaSWonLHi`0<onLHi`?o00001?od2o@3o`0000WonPGj00?o
0000onhAk_o^4Nh02_o^4Nh2o`000003oo/4nol0003o000000OokQ7^00?o0000ooT6nOoi1_T02ooi
1_T00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00KooP7n1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000
ooL8moog2?L03_og2?L00ol0003oiaSWonLHi`0=onLHi`03o`000?od2oCom0_d00Kom0_d0ol00005
ooX5nP03o`000?o^4NkokQ7^00gokQ7^00?o0000onhAk_o^4Nh02?o^4Nh00ol0003on@KiooT6n@09
ooT6n@03o`000?oi1_Won@Ki00gon@Ki00Co0000ooh1o_on0OkooP7n1Ol00003ooX5nP03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
oo`3o?ol0o`02ool0o`2o`0000oom`Sg00?o0000onLHiooW6>L03OoW6>L00ol0003om0_doo@;m00:
oo@;m0?o000000?onPGjo`000?o^4Nh03oo^4Nh00ol0003okQ7^onhAkP09onhAkP03o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooT6nOoi1_T03_oi1_T3o`0000SonPGj00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?ol0ocoo0?l00Soo0?l0ol000000ooc
3??o0000ooL8m`0>ooL8m`03o`000?oW6>OoiaSW00goiaSW00?o0000oo@;m?od2o@03Ood2o@00ol0
003okQ7^onhAkP0?onhAkP03o`000?o^4NkokQ7^00[okQ7^2ol0000;ooT6n@Go00003?oj1OX00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003onPGjo`000?oo0?oo0000
00Soo0?l0ol00005oo<<l`03o`000?og2?Oom`Sg00com`Sg00?o0000onLHiooW6>L03OoW6>L00ol0
003om0_doo@;m00=oo@;m0;o00004?o^4Nh00ol0003okQ7^onhAkP0:onhAkP03o`000?o[5>_ojaC[
00OojaC[00?o0000ooT6nOoi1_T00_oi1_T7o`0000Coka3_00?o0000ooX5n_oj1OX02_oj1OX00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003onPGjooX5n_oj1OX2o`00
00Goo0?l0ol00009oo<<l`;o00002oog2?L00ol0003oiaSWonLHi`0=onLHi`03o`000?od2oCom0_d
00gom0_d00Co0000omTVfOoI9]Wo00003oo^4Nh00ol0003okQ7^onhAkP09onhAkP03o`000?o[5>_o
jaC[00WojaC[1?l0000;onl@k`03o`000?oj1O[onPGj00[onPGj00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oo0?lo`000002o`00
00col`cc00Co0000omhQg_l0003o00002Oog2?L00ol0003oiaSWonLHi`0=onLHi`03o`000?od2oCo
m0_d00gom0_d00Go0000omTVfOoI9]WofBKIo`00000=onhAkP03o`000?o^4NkokQ7^00[okQ7^00?o
0000on/Djoo[5>/02Oo[5>/00ol0003oka3_onl@k`0<onl@k`03o`000?oj1O[onPGj00[onPGj00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01_oj1OX0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?oN8MkogR7N00;ogR7N0_l00007ooL8m`03o`000?oW6>Oo
iaSW00coiaSW00?o0000oo@;m?od2o@03Ood2o@00ol0003ofBKIomTVf@03omTVf@03o`000?o^4Nko
kQ7^00[okQ7^00?o0000onhAk_o^4Nh02_o^4Nh00ol0003ojaC[on/Dj`09on/Dj`03o`000?o_4>oo
ka3_00coka3_00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?oc3??ol`cc00_ol`cc00?o0000omhQ
g_oN8Mh01OoN8Mh00ol0003om`SgooL8m`03ooL8m`03o`000?oW6>OoiaSW00goiaSW00?o0000oo@;
m?od2o@03Ood2o@00ol0003ofBKIomTVf@04omTVf@03o`000?o^4NkokQ7^00WokQ7^00?o0000onhA
k_o^4Nh02Oo^4Nh00ol0003ojaC[on/Dj`0:on/Dj`03o`000?o_4>ooka3_00coka3_00?o0000ooX5
n_oj1OX02ooj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP07ooX5nP03o`000?oc3??ol`cc00_ol`cc00?o0000omhQg_oN8Mh01_oN8Mh2o`0000?o
m`Sg00?o0000onLHiooW6>L03OoW6>L00ol0003om0_doo@;m00<oo@;m003o`000?oI9]WofBKI00Ko
fBKI00?o0000onhAk_o^4Nh02?o^4Nh00ol0003okQ7^onhAkP09onhAkP03o`000?o[5>_ojaC[00[o
jaC[00?o0000onl@koo_4>l03?o_4>l00ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ol`ccoo<<l`0:oo<<l`03o`00
0?oN8MkogR7N00WogR7N0_l000000oog2?Oo0000onLHi`0<onLHi`?o00003_od2o@00ol0003ofBKI
omTVf@07omTVf@03o`000?o^4NkokQ7^00OokQ7^00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003ojaC[
on/Dj`0;on/Dj`03o`000?o_4>ooka3_00coka3_00?o0000ooX5n_oj1OX02_oj1OX00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02_oj1OX00ol0003ol`ccoo<<
l`09oo<<l`03o`000?oN8MkogR7N00_ogR7N00?o0000onLHiooW6>L02_oW6>L2o`0000?obSG:00?o
0000oo@;m?od2o@02_od2o@00ol0003ofBKIomTVf@09omTVf@03o`000?o^4NkokQ7^00KokQ7^00?o
0000onhAk_o^4Nh02?o^4Nh00ol0003ojaC[on/Dj`0<on/Dj`03o`000?o_4>ooka3_00coka3_00?o
0000ooX5n_oj1OX02_oj1OX00ol0003oo`3oool0o`04ool0o`Co00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?oj1O[onPGj00_onPGj00?o0000oo<<looc3?<02?oc3?<0
0ol0003ogR7NomhQgP0<omhQgP03o`000?oW6>OoiaSW00SoiaSW0_l00006olXebP;o00002_od2o@0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o^4NkokQ7^00GokQ7^00?o0000onhAk_o^4Nh02?o^4Nh0
0ol0003ojaC[on/Dj`0<on/Dj`03o`000?o_4>ooka3_00coka3_00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo`3oo`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ooX5nP03o`000?oc3??ol`cc00Ool`cc00?o0000omhQg_oN8Mh03_oN8Mh00ol0003oiaSWonLHi`04
onLHi`?o00002_o:=LX00ol0003om0_doo@;m007oo@;m003o`000?oI9]WofBKI00_ofBKI00?o0000
onhAk_o^4Nh00oo^4Nh00ol0003okQ7^onhAkP09onhAkP03o`000?o[5>_ojaC[00cojaC[00?o0000
onl@koo_4>l03?o_4>l00ol0003onPGjooX5nP0;ooX5nP;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oc3??ol`cc00Ool`cc00?o0000omhQg_oN8Mh03ooN8Mh01?l0
003oiaSWonLHiooW6>L2o`0000kobSG:0_l00006oo@;m003o`000?oI9]WofBKI00gofBKI00?o0000
onhAk_o^4Nh00_o^4Nh00ol0003okQ7^onhAkP08onhAkP03o`000?o[5>_ojaC[00cojaC[0ol0000=
onl@k`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00oonPGj00?o0000oo<<looc3?<01_oc3?<00ol0003ogR7NomhQgP0@omhQgPCo00004_o:=LX00ol0
003om0_doo@;m003oo@;m003o`000?oI9]WofBKI00kofBKI00Go0000onhAk_o^4NkokQ7^o`000005
onhAkPOo00003?o[5>/01Ol0003ogb3OomlPgooO8=oo000000coka3_00?o0000ooX5n_oj1OX02?oj
1OX3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000oonPGj00?o0000oo<<looc3?<01_oc3?<00ol0003ogR7NomhQgP0=
omhQgP?o000000Co_d2oo`000?l0003o00004oo:=LX2o`0000;om0_d00?o0000omTVfOoI9]T04?oI
9]T00ol0003okQ7^o`000006o`0000OocS7>00?o0000on/Djoo[5>/02?o[5>/00ol0003ogb3OomlP
g`03omlPg`;o00002?o_4>l3o`0000KonPGj1?l00002ooP7n003o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003oo@;mo`000?o_4>l3o`0000gonPGj00?o0000oo<<looc3?<01?oc3?<00ol0003ogR7NomhQ
gP0;omhQgP?o00000ono@;l01Ol0003o]DZeo`000?n3O8?o000001CobSG:00?o0000oo@;m?l00000
4ooI9]T00ol0003ocS7>olhacP0=olhacP03o`000?o[5>_ojaC[00GojaC[0_l00008omlPg`03o`00
0?o_4>ooka3_00Go00000oo]4^d00ol0003onPGjooX5nP03o`0000Oon0Oh00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?om0_goo@;mo`0000Coka3_0ol0000:ooX5nP03o`000?oc3??ol`cc00?ol`cc
00?o0000omhQg_oN8Mh02OoN8Mh3o`0000Go_d2o00Co0000okE:]OneB[Go00000_n3O8<00ol0003o
bSG:olXebP0BolXebP03o`000?oI9]WofBKI01;ofBKI00?o0000olhac_o><Lh03_o><Lh00ol0003o
jaC[on/Dj`03on/Dj`03o`000?oO8=oogb3O00Wogb3O0_l00009ondBk@;o00002_oh1oP00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ood2oOom0_goo@;mo`000007onl@k`;o00001ooj1OX5o`0000;o
l`cc00?o0000omhQg_oN8Mh01_oN8Mh3o`0000So_d2o00Co0000okE:]OneB[Go00000on3O8<00ol0
003obSG:olXebP0AolXebP03o`000?oI9]WofBKI017ofBKI00?o0000olhac_o><Lh04?o><Lh01Ol0
003ojaC[on/Djoo[5>_o000000cogb3O00?o0000ondBkOo]4^d02?o]4^d00ol0003on0OhooP7n00:
ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000Coo@;m00?o0000onl@koo_4>l01oo_4>l3o`00
0004ooX5n_l0003o0000o`0000Goi1_T0_l00006omhQgP?o00002_no@;l01Ol0003o]DZeokE:]One
B[Go000000CoPgb300?o0000olXeb_o:=LX04?o:=LX00ol0003ofBKIomTVf@0AomTVf@03o`000?o>
<LkocS7>017ocS7>00?o0000on/Djol000003OoO8=l00ol0003okA;]ondBk@08ondBk@03o`000?oh
1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000
onl@koo_4>l02_o_4>l00ol0003oi1_Ton@Ki008on@Ki003o`000?oN8MkogR7N00?o00003Ono@;l0
1Ol0003o]DZeokE:]OneB[Go000000GoPgb300?o0000olXeb_o:=LX03oo:=LX00ol0003ofBKIomTV
f@0AomTVf@03o`000?o><LkocS7>01;ocS7>00?o0000omlPgooO8=l03?oO8=l00ol0003okA;]ondB
k@08ondBk@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ood2oOom0_d01Oom0_d0
0ol0003oka3_onl@k`0:onl@k`03o`000?oT6nCoi1_T00Woi1_T0_l0000?okm0_`03o`000?neB[Go
]DZe00;o]DZe00?o0000oh=lPon3O8<01?n3O8<00ol0003obSG:olXebP0=olXebP?o00004OoI9]T0
0ol0003ocS7>olhacP0ColhacP03o`000?oO8=oogb3O00_ogb3O00?o0000ondBkOo]4^d02Oo]4^d0
0ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ool0o`;o00002?om0_d0
0ol0003oka3_onl@k`0:onl@k`03o`000?oT6nCoi1_T00Woi1_T00?o0000okm0_ono@;l03Ono@;l0
0ol0003o]DZeokE:]@03okE:]@03o`000?n3O8?oPgb300GoPgb300?o0000olXeb_o:=LX02_o:=LX2
o`0000?oQgR700?o0000omTVfOoI9]T03_oI9]T00ol0003ocS7>olhacP0ColhacP03o`000?oO8=oo
gb3O00_ogb3O00?o0000ondBkOo]4^d02Oo]4^d00ol0003on0OhooP7n00;ooP7n003o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000Goo`3o00?o0000ood2oOom0_d01oom0_d2o`0000_oka3_00?o0000on@K
i?oT6n@02ooT6n@00ol0003o_d2ookm0_`0<okm0_`03o`000?neB[Go]DZe00?o]DZe00?o0000oh=l
Pon3O8<01_n3O8<00ol0003obSG:olXebP07olXebP;o00001_n7N8L2o`0000kofBKI00?o0000olha
c_o><Lh04oo><Lh00ol0003ogb3OomlPg`0;omlPg`03o`000?o]4^gokA;]00WokA;]00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ool0oooo0?ooo`3oo`000009ood2
o@03o`000?oj1O[o000000_oka3_00?o0000on@Ki?oT6n@02ooT6n@00ol0003o_d2ookm0_`0;okm0
_`03o`000?neB[Go]DZe00Co]DZe00?o0000oh=lPon3O8<01on3O8<00ol0003obSG:olXebP05olXe
bP03o`000?n7N8OoQgR700SoQgR700?o0000omTVfOoI9]T02_oI9]T00ol0003ocS7>olhacP0Dolha
cP03o`000?oO8=oogb3O00_ogb3O00?o0000ondBkOo]4^d02Oo]4^d00ol0003on0OhooP7n00<ooP7
n003o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oo`000009ood2o@04o`000?oj1O[onPGjo`00
00_oka3_00?o0000on@Ki?oT6n@02ooT6n@00ol0003o_d2ookm0_`0;okm0_`03o`000?neB[Go]DZe
00Co]DZe00?o0000oh=lPon3O8<02?n3O8<00ol0003obSG:olXebP02olXebP;o00003?n7N8L2o`00
00[ofBKI00?o0000olhac_o><Lh05?o><Lh00ol0003ogb3OomlPg`0;omlPg`03o`000?o]4^gokA;]
00WokA;]00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03
o`000?oj1O[onPGj00;onPGj00?o0000onl@koo_4>l02?o_4>l00ol0003oi1_Ton@Ki00<on@Ki003
o`000?no@;oo_d2o00Wo_d2o00?o0000okE:]OneB[D01OneB[D00ol0003oPgb3oh=lP`09oh=lP`04
o`000?o:=L[o0000o`00013oQgR70_l00008omTVf@03o`000?o><LkocS7>01CocS7>0ol0000;omlP
g`03o`000?o]4^gokA;]00WokA;]00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000onl@
koo_4>l02?o_4>l00ol0003oi1_Ton@Ki00;on@Ki0;o00002_no@;l00ol0003o]DZeokE:]@06okE:
]@03o`000?n3O8?oPgb300[oPgb300?o0000ohMhQon7N8L04_n7N8L00ol0003ofBKIomTVf@04omTV
f@03o`000?o><LkocS7>01GocS7>00?o0000ol4n`Oo1?/401Ol00005omlPg`03o`000?o]4^gokA;]
00[okA;]00?o0000ooP7n?oh1oP03_oh1oP3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@04ood2o@03
o`000?oj1O[onPGj00ConPGj00?o0000onl@koo_4>l01oo_4>l00ol0003oi1_Ton@Ki00;on@Ki004
o`000?n/Djco[5>/o`0000Wo_d2o00?o0000okE:]OneB[D01_neB[D00ol0003oPgb3oh=lP`0:oh=l
P`03o`000?n7N8OoQgR701?oQgR70_l00003omTVf@Co00005?o><Lh00ol0003o`Ck1ol4n`@06ol4n
`@Co000000?ogb3Oo`000?o]4^d02oo]4^d00ol0003on0OhooP7n00>ooP7n003o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003oo@;mood2o@03ood2o@03o`000?oj1O[onPGj00GonPGj00?o0000onl@koo_
4>l01oo_4>l00ol0003oi1_Ton@Ki009on@Ki0;o00001?n/Dj`00ol0003o_d2ookm0_`05okm0_`03
o`000?neB[Go]DZe00Oo]DZe00?o0000oh=lPon3O8<02_n3O8<00ol0003oQgR7ohMhQ`0EohMhQ`03
o`000?oI9]Wo000000CoWV6N0ol0000@olhacP03o`000?o1?/7o`Ck100_o`Ck10_l0000<ondBk@03
o`000?oh1oSon0Oh00con0Oh0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ood2oOom0_d00_om0_d00ol0003onPGj
ooX5nP06ooX5nP03o`000?o_4>ooka3_00Ooka3_00?o0000on@Ki?oT6n@02?oT6n@00ol0003o[5>/
ojaC[005ojaC[003o`000?no@;oo_d2o00Co_d2o00?o0000okE:]OneB[D01oneB[D00ol0003oPgb3
oh=lP`0:oh=lP`03o`000?n7N8OoQgR701KoQgR700?o0000oiiQW_nNHIh01_nNHIh3o`0000cocS7>
00?o0000ol4n`Oo1?/403Oo1?/400ol0003okA;]ondBk@09ondBk@Go00002Ooh1oP2o`000003oo/4
nol0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ood2oOl0003onPGj00WonPGj00?o0000onl@koo_4>l01_o_
4>l00ol0003oi1_Ton@Ki007on@Ki003o`000?n/Djco[5>/00Oo[5>/00?o0000okm0_ono@;l00_no
@;l00ol0003o]DZeokE:]@08okE:]@03o`000?n3O8?oPgb300WoPgb300?o0000ohMhQon7N8L05on7
N8L00ol0003oWV6NoiiQWP09oiiQWP?o00002Oo><Lh00ol0003o`Ck1ol4n`@0>ol4n`@Ko00001?o]
4^d00ol0003om0_doo@;m003oo@;m0Go00000_oh1oP2o`0000Con`Ck00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?oj1O[onPGjooX5n_l000002ooj1OX00ol0003oka3_onl@k`06onl@k`03o`000?oT
6nCoi1_T00Goi1_T0_l0000;ojaC[004o`000?no@;oo_d2oo`0000_o]DZe00?o0000oh=lPon3O8<0
2On3O8<00ol0003oQgR7ohMhQ`0FohMhQ`03o`000?nNHIkoWV6N00goWV6N0ol00005olhacP03o`00
0?o1?/7o`Ck100oo`Ck100?o0000omDZeOoE:]D00ooE:]D4o`0000_om0_d0_l00006oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP02ooX5nPko00001_o_4>l00ol0003oi1_Ton@K
i005on@Ki003o`000?n/Djco[5>/00co[5>/00?o0000okm0_ol000002oneB[D00ol0003oPgb3oh=l
P`07oh=lP`?o00006?n7N8L00ol0003oWV6NoiiQWP0@oiiQWP?o000000?ocS7>o`000?o1?/404?o1
?/400ol0003oeB[EomDZe@07omDZe@03o`000?od2oCom0_d00[om0_d00?o0000oo/4nook1?/01Ook
1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005ooX5nP03o`000?ob3O;olPgb00_olPgb0_l00004
onl@k`03o`000?oT6nCoi1_T00?oi1_T0_l0000@ojaC[003o`000?neB[Go]DZe00[o]DZe00?o0000
oh=lPon3O8<00on3O8<4o`0000;oDjaC00?o0000ohMhQon7N8L05On7N8L00ol0003oWV6NoiiQWP0D
oiiQWP03o`000?o1?/7o`Ck1013o`Ck100?o0000omDZeOoE:]D01ooE:]D00ol0003om0_doo@;m00:
oo@;m003o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj
00GonPGj00?o0000oo8=l_ob3O803Oob3O86o`0000?oi1_T00?o0000ojaC[?n/Dj`04?n/Dj`00ol0
003o]DZeokE:]@0:okE:]@03o`000?n3O8?o000000?o00001omC[5<00ol0003oQgR7ohMhQ`0DohMh
Q`03o`000?nNHIkoWV6N01CoWV6N00?o0000ol4n`Oo1?/403oo1?/400ol0003oeB[EomDZe@08omDZ
e@03o`000?od2oCom0_d00[om0_d00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX00ol0003olPgboo8=lP0=oo8=lP03o`000?oI9]WofBKI00?o
fBKI00?o0000on@Ki?l000004on/Dj`4o`0000Wo]DZe0_l0000<oe>/D`03o`000?n7N8OoQgR701?o
QgR700?o0000oiiQW_nNHIh05OnNHIh00ol0003o`Ck1ol4n`@0>ol4n`@03o`000?oE:]GoeB[E00So
eB[E00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?oj1O[onPGj00SonPGj00?o0000oo8=l_ob3O802oob3O800ol0003ofBKIomTVf@05omTVf@03o`00
0?n/Djco[5>/01;o[5>/00Co0000oefRGOmMXUgoGJ9M1Ol00003okE:]@03o`000?mC[5?oDjaC00go
DjaC0ol0000@ohMhQ`;o00006?nNHIh00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oE:]GoeB[E00Wo
eB[E00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_onPGj00?o0000oo8=l_ob3O802_ob3O800ol0003ofBKIomTVf@06omTVf@03o`00
0?n/Djco[5>/017o[5>/00?o0000oefRGOmMXUd01omMXUd3o`00013oDjaC00?o0000obOH9olWf2L0
1Ol00009ohMhQ`;o000000?oB;M8o`000?nNHIh05onNHIh00ol0003o`Ck1ol4n`@0=ol4n`@03o`00
0?oE:]GoeB[E00WoeB[E00?o0000oo@;m?od2o@02?od2o@2o`0000[on`Ck00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ooX5n_oj1OX02Ooj1OX00ol0003olPgboo8=
lP0:oo8=lP03o`000?oI9]WofBKI00OofBKI00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oGJ9MoefR
G@0:oefRG@03o`000?mC[5?oDjaC00goDjaC00?o0000obOH9olWf2L01_lWf2L4o`0000CoQgR700?o
0000odRgB?m8]dP00_m8]dP00ol0003oWV6NoiiQWP0FoiiQWP03o`000?o1?/7o`Ck100_o`Ck100?o
0000omDZeOoE:]D02ooE:]D00ol0003om0_doo@;m006oo@;m003o`000?oj1O[o000000[on`Ck00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ooX5n_oj1OX02?oj1OX=
o`0000[ofBKI00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oGJ9MoefRG@0;oefRG@03o`000?mC[5?o
DjaC00coDjaC00?o0000obOH9olWf2L02_lWf2L4o`0000GoB;M800?o0000oiiQW_nNHIh05_nNHIh0
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?oE:]GoeB[E00coeB[E00?o0000oo@;m?od2o@01?od2o@2
o`0000?onPGj00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d00oom0_d00ol0003onPGjooX5nP07ooX5nP03o`000?ob3O;olPgb00WolPgb00?o0000omTV
fOoI9]T02OoI9]T00ol0003o[5>/ojaC[00=ojaC[003o`000?mMXUgoGJ9M00coGJ9M00?o0000oe>/
DomC[5<03?mC[5<00ol0003o9mPWobOH9`0;obOH9`03o`000?lUfRGo000000KoB;M800?o0000oiiQ
W_nNHIh05_nNHIh00ol0003o`Ck1ol4n`@09ol4n`@03o`000?oE:]GoeB[E00coeB[E00?o0000oo@;
m?od2o@00ood2o@00ol0003onPGjooX5nP03ooX5nP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003o
lPgboo8=lP08oo8=lP03o`000?oI9]WofBKI00_ofBKI00?o0000ojaC[?n/Dj`02?n/Dj`4o`0000oo
GJ9M00?o0000oe>/DomC[5<02omC[5<00ol0003o9mPWobOH9`0;obOH9`04o`000?lUfRGo9MXUo`00
00OoB;M800?o0000oiiQW_nNHIh05OnNHIh00ol0003o`Ck1ol4n`@08ol4n`@03o`000?oE:]GoeB[E
00goeB[E00?o0000oo@;m?od2o@00_od2o@00ol0003onPGjooX5nP05ooX5nP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Goo@;m00?o0000ooX5n_oj
1OX01Ooj1OX00ol0003olPgboo8=lP08oo8=lP03o`000?oI9]WofBKI00_ofBKI00?o0000ojaC[?n/
Dj`00on/Dj`5o`0000?oHIiQ00?o0000oefRGOmMXUd03_mMXUd00ol0003oDjaCoe>/D`0:oe>/D`03
o`000?lWf2Oo9mPW00[o9mPW00Go0000obGJ9OlUfRGo9MXUo`000007odRgB003o`000?nNHIkoWV6N
01GoWV6N00?o0000ol4n`Oo1?/402?o1?/400ol0003oeB[EomDZe@0=omDZe@03o`000?od2oCom0_d
00;o00002?oj1OX00ol0003on`Ckoo/4n`08oo/4n`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oj1O[onPGj00Go
nPGj00?o0000oo8=l_ob3O802?ob3O800ol0003ofBKIomTVf@0<omTVf@Go00002OmQWV400ol0003o
GJ9MoefRG@0<oefRG@;o00003?mC[5<00ol0003o9mPWobOH9`0:obOH9`05o`000?lUfRGo9MXUobGJ
9Ol000002?m8]dP00ol0003oWV6NoiiQWP0DoiiQWP?o00001oo1?/400ol0003oeB[EomDZe@0>omDZ
e@03o`000?od2oCo000000_onPGj00?o0000oo/4nook1?/01_ok1?/00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ood2oOom0_d01Oom0_d00ol0003onPGjooX5nP04ooX5nP03o`000?ob3O;olPgb00Oo
lPgb00?o0000omTVfOoI9]T03?oI9]T01?l0003oZEJYojUFZOl0000;of6NH@03o`000?mMXUgoGJ9M
00_oGJ9M00Co0000oa[U6_lJiA[o00002_mC[5<00ol0003o9mPWobOH9`0:obOH9`03o`000?lUfRGo
9MXU00;o9MXU00?o0000odRgB?m8]dP01_m8]dP00ol0003oWV6NoiiQWP0AoiiQWP?o00000onGJ9L0
0ol0003o`Ck1ol4n`@04ol4n`@03o`000?oE:]GoeB[E00goeB[E1?l0000;ooX5nP03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Koo@;m00Co0000ooX5
n_oj1O[onPGj1?l00008oo8=lP03o`000?oI9]WofBKI00_ofBKI00?o0000ojUFZOnYEZT00_nYEZT0
0ol0003oHIiQof6NH@08of6NH@03o`000?mMXUgoGJ9M00[oGJ9M00?o0000oa[U6_lJiAX00_lJiAX0
0ol0003oDjaCoe>/D`03oe>/D`Go00002olWf2L00ol0003o9MXUobGJ9@03obGJ9@03o`000?m8]dSo
B;M800OoB;M800?o0000oiiQW_nNHIh03_nNHIh2o`0000OoUfRG00?o0000ol4n`Oo1?/400_o1?/40
0ol0003oeB[EomDZe@0=omDZe@03o`000?ob3O;olPgb00;olPgb00?o0000ooX5n_oj1OX02Ooj1OX0
0ol0003on`Ckoo/4n`03oo/4n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@07ood2
o@?o00001?oc3?<00ol0003olPgboo8=lP05oo8=lP03o`000?oI9]WofBKI00[ofBKI00?o0000ojUF
ZOnYEZT00onYEZT00ol0003oHIiQof6NH@09of6NH@03o`000?mMXUgoGJ9M00SoGJ9M00?o0000oa[U
6_lJiAX01?lJiAX5o`0000Co6NHI00?o0000obOH9olWf2L02OlWf2L00ol0003o9MXUobGJ9@03obGJ
9@03o`000?m8]dSoB;M800SoB;M800?o0000oiiQW_nNHIh02_nNHIh3o`0000[oUfRG00Go0000ol4n
`Oo1?/7o`Ck1o`00000>omDZe@03o`000?ob3O;olPgb00ColPgb0_l00009ooX5nP03o`000?ok1?_o
n`Ck00;on`Ck00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo<<
looc3?<01Ooc3?<00ol0003olPgboo8=lP03oo8=lP03o`000?oI9]WofBKI00[ofBKI00?o0000ojUF
ZOnYEZT01?nYEZT00ol0003oHIiQof6NH@09of6NH@03o`000?mMXUgoGJ9M00OoGJ9M00?o0000oa[U
6_lJiAX01OlJiAX00ol0003o6NHIoaWV6@07oaWV6@03o`000?lWf2Oo9mPW00Oo9mPW00?o0000obGJ
9OlUfRD01?lUfRD00ol0003oB;M8odRgB008odRgB003o`000?nNHIkoWV6N00SoWV6N0_l0000>oiMX
U`Co00003?oE:]D2o`0000WolPgb00?o0000ooX5n_oj1OX01ooj1OX01?l0003on`Ckoo/4nol0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003ol`ccoo<<l`07oo<<l`;o00000oob3O800ol0
003ofBKIomTVf@09omTVf@03o`000?nYEZWoZEJY00KoZEJY00?o0000of6NHOmQWV402OmQWV400ol0
003oGJ9MoefRG@05oefRG@03o`000?lJiA[o6^DJ00Ko6^DJ00?o0000oaWV6OlIiQT02?lIiQT00ol0
003o9mPWobOH9`06obOH9`03o`000?lUfRGo9MXU00Co9MXU00?o0000odRgB?m8]dP02Om8]dP4o`00
00?oWV6N0ol0000@oiMXU`05o`000?oG:=OoebSGomLXeol000002_oE:]D00ol0003olPgboo8=lP0:
oo8=lPKo00000ooj1OX00ol0003on`Cko`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ood2oOom0_d01?om0_d00ol0
003ol`ccoo<<l`0:oo<<l`04o`000?ob3O;olPgbo`0000[ofBKI00?o0000ojUFZOnYEZT01onYEZT0
0ol0003oHIiQof6NH@09of6NH@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oa[U6_lJiAX01olJiAX0
0ol0003o6NHIoaWV6@08oaWV6@;o00001_lWf2L00ol0003o9MXUobGJ9@05obGJ9@03o`000?m8]dSo
B;M800WoB;M800Co0000oefRGOmMXUgoGJ9M0ol0000BoiMXU`03o`000?oG:=OoebSG00?oebSG0_l0
0006omDZe@;o00003Oob3O800ol0003oo0?loo`3o003oo`3o0Go00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ood2oOom0_d00oom0_d0
0ol0003ol`ccoo<<l`0<oo<<l`;o00002_oI9]T00ol0003oZEJYojUFZ@08ojUFZ@03o`000?mQWV7o
HIiQ00[oHIiQ00?o0000oefRGOmMXUd00_mMXUd00ol0003o6^DJoa[U6P08oa[U6P03o`000?lIiQWo
6NHI00Ko6NHI0_l00002o`Gj1@03o`000?lWf2Oo9mPW00;o9mPW00?o0000obGJ9OlUfRD01_lUfRD0
0ol0003oB;M8odRgB008odRgB003o`000?mMXUgoGJ9M00CoGJ9M00?o0000oiMXUonGJ9L03onGJ9L0
0ol0003oebSGomLXe`06omLXe`;o00000ooE:]D00ol0003olPgboo8=lP0=oo8=lP03o`000?ol0oco
o0?l00Ooo0?l0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003oo@;mood2o@02ood2o@03o`000?oc3??ol`cc
00kol`cc00?o0000omTVfOoI9]T01ooI9]T00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?mQWV7oHIiQ
00WoHIiQ00Go0000oefRGOmMXUgoGJ9Mo`00000;oa[U6P03o`000?lIiQWo6NHI00Co6NHI0_l00005
o`Gj1@05o`000?lWf2Oo9mPWobOH9ol000002?lUfRD00ol0003oB;M8odRgB008odRgB003o`000?mM
XUgoGJ9M00GoGJ9M00?o0000oiMXUonGJ9L03_nGJ9L00ol0003oebSGomLXe`08omLXe`03o`000?oE
:]Go000000oolPgb00?o0000oo`3o?ol0o`02?ol0o`01?l0003ooP7no`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?om0_goo@;mo`00017ol`cc00?o0000omTVfOoI9]T01_oI9]T00ol0003oZEJY
ojUFZ@0;ojUFZ@03o`000?mQWV7oHIiQ00WoHIiQ00Co0000oefRGOmMXUgo00003?lJiAX00ol0003o
6NHIoaWV6@02oaWV6@;o00002?l5nPD00ol0003o9mPWo`000009obGJ9@03o`000?m8]dSoB;M800So
B;M800?o0000oefRGOmMXUd01OmMXUd00ol0003oUfRGoiMXU`0=oiMXU`03o`000?oG:=OoebSG00[o
ebSG00?o0000oo8=l_ob3O803_ob3O800ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00;o
oP7n00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000Boo<<l`03o`00
0?oI9]WofBKI00CofBKI00?o0000ojUFZOnYEZT03?nYEZT00ol0003oHIiQof6NH@0:of6NH@?o0000
3?lJiAX00ol0003o6NHIoaWV6@02o`0000_o1OX500?o0000obGJ9OlUfRD02?lUfRD00ol0003oB;M8
odRgB007odRgB003o`000?mMXUgoGJ9M00OoGJ9M00?o0000oiMXUonGJ9L03?nGJ9L00ol0003oebSG
omLXe`0;omLXe`;o00003_ob3O800ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00?ooP7n
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003ol`ccoo<<l`0?oo<<l`?o00000ooI
9]T00ol0003oZEJYojUFZ@0>ojUFZ@03o`000?mQWV7oHIiQ00SoHIiQ00Co0000ob;M8_lRgB;o8]dR
0_l0000:oa[U6P?o00003Ol5nPD00ol0003o9MXUobGJ9@08obGJ9@03o`000?m8]dSoB;M800OoB;M8
00?o0000oefRGOmMXUd01omMXUd00ol0003oUfRGoiMXU`0;oiMXU`03o`000?oG:=OoebSG00coebSG
00?o0000ooT6nOl000000_l0000:oo8=lP03o`000?ol0ocoo0?l00Soo0?l00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o004oo`3o003o`000?oc3??ol`cc00col`cc0_l0
0003onTFj@03o`000?oI9]Wo0000017oZEJY00?o0000of6NHOmQWV401omQWV400ol0003o8]dRob;M
8P04ob;M8P;o00002?lJiAX00ol0003o1OX5o`Gj1@0>o`Gj1@;o00002?lUfRD00ol0003oB;M8odRg
B006odRgB003o`000?mMXUgoGJ9M00WoGJ9M00?o0000oiMXUonGJ9L02OnGJ9L00ol0003oebSGomLX
e`0=omLXe`03o`000?oi1_Won@Ki00;on@Ki0ol00007oo8=lP03o`000?ol0ocoo0?l00Ooo0?l00?o
0000ooh1o_on0Oh02?on0Oh2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?oc3??o
l`cc00Wol`cc0_l00006onTFj@03o`000?nYEZWoZEJY013oZEJY00?o0000of6NHOmQWV401_mQWV40
0ol0003o8]dRob;M8P07ob;M8P03o`000?lJiA[o6^DJ00Co6^DJ0ol0000>o`Gj1@03o`000?l4n`Co
1?/400?o00001OlUfRD00ol0003oB;M8odRgB006odRgB003o`000?mMXUgoGJ9M00[oGJ9M00?o0000
oiMXUonGJ9L02?nGJ9L00ol0003oebSGomLXe`0=omLXe`03o`000?oi1_Won@Ki00Gon@Ki0ol00004
oo8=lP03o`000?ol0ocoo0?l00Ooo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo0?loo`3o006oo`3o003o`000?oc3??ol`cc00Gol`cc0ol00008onTFj@03o`000?nYEZWoZEJY
017oZEJY00Co0000of6NHOmQWV7oHIiQ1?l0000;ob;M8P;o000000Co6^DJo`000?l0003o00000ol0
o`02o`0000_o1OX500?o0000o`Ck1?l4n`@01?l4n`@2o`0000?o9MXU00?o0000odRgB?m8]dP01_m8
]dP00ol0003oGJ9MoefRG@0:oefRG@03o`000?nGJ9OoUfRG00OoUfRG00?o0000omLXeooG:=L03_oG
:=L00ol0003on@KiooT6n@08ooT6n@Co00002_ol0o`00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo0?loo`3o007oo`3o003o`000?oc3??ol`cc00;ol`cc0_l0000<onTFj@03o`000?nYEZWo
ZEJY013oZEJY1?l00003oeJYEP03o`000?lRgB;o8]dR00_o8]dR00?o0000o`3o0?l0o`001_l0o`00
0ol0003o1OX5o`Gj1@07o`Gj1@03o`000?l4n`Co1?/400Oo1?/43?l0000>oefRG@03o`000?nGJ9Oo
UfRG00KoUfRG00?o0000omLXeooG:=L03_oG:=L00ol0003on@KiooT6n@0;ooT6n@03o`000?ol0oco
o0?l00Ooo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00Woo0?l00Co0000oo<<
lol0003o00003_oY5^T00ol0003oZEJYojUFZ@0?ojUFZ@03o`000?mFZEKoEZUF00KoEZUF00?o0000
ob;M8_lRgB802_lRgB800ol0003o0?l0o`3o0007o`3o00;o00001_l5nPD00ol0003o1?/4o`Ck1008
o`Ck1003o`000?lcc3?o<l`c00So<l`c00?o0000oefRGOmMXUd03?mMXUd00ol0003oUfRGoiMXU`05
oiMXU`03o`000?oG:=OoebSG00ooebSG0_l0000=ooT6n@03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onTFjOoY5^T03_oY5^T00ol0
003oZEJYojUFZ@0>ojUFZ@03o`000?mFZEKoEZUF00OoEZUF00?o0000ob;M8_lRgB802_lRgB800ol0
003o0?l0o`3o0009o`3o00;o00000ol5nPD00ol0003o1?/4o`Ck1009o`Ck1003o`000?lcc3?o<l`c
00Wo<l`c00?o0000oefRGOmMXUd02_mMXUd4o`0000CoUfRG00?o0000omLXeooG:=L04?oG:=L01?l0
003on0Oho`000?l0000<ooT6n@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onTFjOoY5^T03ooY5^T@o`0000[oEZUF00?o0000ob;M
8_lRgB802OlRgB800ol0003o0?l0o`00000<o`3o0005o`000?l5nPGo0000o`3o0?l000002_l4n`@0
0ol0003o<l`coc?<<`09oc?<<`03o`000?mMXUgoGJ9M00OoGJ9M0ol00004ohEjQ@?o000000?oUfRG
o`000?oG:=L04OoG:=L01?l0003on0OhooP7n?oh1oP2o`0000_on@Ki00?o0000oo`3o?ol0o`00ool
0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ojAKYonTFj@0?
onTFj@03o`000?nPGj3oX5nP00coX5nP00?o0000oeJYE_mFZEH02OmFZEH00ol0003o8]dRob;M8P07
ob;M8P04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`Ck1003o`00
0?lcc3?o<l`c00[o<l`c00?o0000oefRGOmMXUd00omMXUd3o`0000[oQGZ500?o0000omLXeooG:=L0
4?oG:=L00ol0003on0OhooP7n004ooP7n0;o00002_oi1_T00ol0003oo0?loo`3o004o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo0?l00?o0000onTFjOoY5^T03ooY5^T00ol0003oX5nPoj1OX00<oj1OX003o`000?mF
ZEKoEZUF00WoEZUF00?o0000ob;M8_lRgB801_lRgB800ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o1?/4o`Ck1006o`Ck1003o`000?lc
c3?o<l`c00[o<l`c00?o0000oefRGOmMXUd00ol0000=ohEjQ@03o`000?oG:=OoebSG013oebSG00?o
0000ooP7n?oh1oP01_oh1oP2o`0000Won@Ki0_l00004ooh1oP03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ojAKYonTFj@0=onTFj@?o00003onPGj00
0ol0003oEZUFoeJYEP08oeJYEP03o`000?lRgB;o8]dR00Go8]dR00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`Ck1?l4n`@01Ol4n`@0
0ol0003o<l`coc?<<`0;oc?<<`;o00004On5NXD00ol0003oebSGomLXe`0?omLXe`03o`000?oh1oSo
n0Oh00Son0Oh0_l00007ooT6n@03o`000?on0OkooP7n00CooP7n00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojAKYonTFj@09onTFj@Go00000_oE:]D00ol0
003oX5nPoj1OX00=oj1OX003o`000?mFZEKoEZUF00WoEZUF00?o0000ob;M8_lRgB801?lRgB800ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o1?/4o`Ck1004o`Ck1003o`000?lcc3?o<l`c00_o<l`c00?o0000ohEjQOn5NXD04?n5NXD00ol0
003oebSGomLXe`0?omLXe`03o`000?oh1oSon0Oh00[on0Oh0_l00004ooT6n@03o`000?on0OkooP7n
00KooP7n0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo0?loo`3o007oo`3o003o`000?oY5^WojAKY00CojAKY1Ol00007omDZe@03
o`000?nPGj3oX5nP00goX5nP00?o0000oeJYE_mFZEH02OmFZEH00ol0003o8]dRob;M8P03ob;M8P03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l4n`Co1?/400?o1?/400?o0000oc?<<olcc3<02olcc3<00ol0003oQGZ5ohEjQ@0@ohEjQ@03
o`000?oG:=OoebSG00ooebSG00?o0000ooP7n?oh1oP03?oh1oP2o`000003ooT6nOl0003ooP7n00[o
oP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000onTFjOl00000
1?l0000<omDZe@03o`000?nPGj3oX5nP00koX5nP00?o0000oeJYE_mFZEH02?mFZEH00ol0003o8]dR
ob;M8P02ob;M8P03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l4n`Co1?/400;o1?/400?o0000oc?<<olcc3<02olcc3<00ol0003oQGZ5
ohEjQ@0AohEjQ@03o`000?oG:=OoebSG00goebSG00?o0000ooP7n?oh1oP03ooh1oP00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01Ool0o`3o`00017oeB[E00?o0000oj1OX?nPGj003_nP
Gj000ol0003oEZUFoeJYEP09oeJYEP04o`000?lRgB;o8]dRo`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l4n`Co1?/4o`Ck1?l000003Olcc3<00ol0003o
QGZ5ohEjQ@0AohEjQ@?o00003OoG:=L00ol0003on0OhooP7n00?ooP7n003o`000?on0OkooP7n00go
oP7n00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_ol0o`2o`0000;omPWf00?o0000omDZeOoE:]D03ooE:]D00ol0003o
X5nPoj1OX00>oj1OX003o`000?mFZEKoEZUF00SoEZUF1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o1?/4o`Ck1?l0000=oc?<<`03o`000?n5NXGoQGZ5
017oQGZ500?o0000okE:]OneB[D00ol0000:omLXe`Co00003Ooh1oP00ol0003ooP7nooh1oP0?ooh1
oP03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ood2oOom0_goo@;m0_l00005ooH9mP03o`000?oE:]GoeB[E00koeB[E00?o0000oj1O
X?nPGj003_nPGj000ol0003oEZUFoeJYEP07oeJYEP03o`000?lCk1?o4n`C00?o4n`C00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<oc?<
<`03o`000?n5NXGoQGZ5013oQGZ500?o0000okE:]OneB[D01?neB[D3o`0000KoebSG00?o0000oo@;
m?od2o@00_od2o@5o`0000Son0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?o
o@;m00?o0000ooH9m_of2OH01?of2OH00ol0003oeB[EomDZe@0=omDZe@03o`000?nPGj3oX5nP00oo
X5nP00?o0000oeJYE_mFZEH01?mFZEH2o`0000Oo4n`C00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
1oP700?o0000oc?<<olcc3<02?lcc3<3o`00013oQGZ500?o0000okE:]OneB[D02?neB[D3o`0000;o
ebSG00?o0000oo@;m?od2o@02?od2o@5o`0000?on0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?om0_goo@;m00Coo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003oeB[EomDZe@0;omDZe@Co0000
3onPGj000ol0003oEZUFoeJYEP03oeJYEP03o`000?lCk1?o4n`C00So4n`C00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o1oP7o`Oh1`05o`Oh1`;o0000
1_lcc3<2o`0000?oAKY500?o0000ohEjQOn5NXD03?n5NXD00ol0003o]DZeokE:]@0<okE:]@;o0000
4?od2o@3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?of2OKomPWf00KomPWf00?o
0000omDZeOoE:]D02OoE:]D00ol0003ohacSo`000002ojAKY0?o00003?nPGj001?l0003oEZUFoeJY
E_mFZEH2o`0000co4n`C00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`Oh1ol7n0L01ol7n0L00ol0003o<l`coc?<<`02oc?<<`03o`00
0?m5^TGoAKY500CoAKY50_l0000;ohEjQ@03o`000?neB[Go]DZe00co]DZe00?o0000omhQg_l00000
4_od2o@00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00OomPWf00?o
0000omDZeOoE:]D01_oE:]D2o`0000;ohacS00?o0000ojAKY?nTFj@00onTFj@3o`0000[oX5nP00?o
0000oeJYE_l000003olCk1<01?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`Oh1ol7n0L02?l7n0L01?l0003o<l`co`000?l00009odFjA@03o`000?n5NXGoQGZ500Oo
QGZ500?o0000okE:]OneB[D03?neB[D01?l0003ogR7NomhQg_l0000Coo@;m003o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWfooH9mP08ooH9mP03o`000?oE:]GoeB[E00Co
eB[E00?o0000on<LhooS7><00ooS7><00ol0003oY5^TojAKY005ojAKY0?o00001_nPGj04o`00013o
4n`C00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l7n0Oo1oP700Wo
1oP700?o0000odFjAOm5^TD02_m5^TD2o`0000KoQGZ500?o0000okE:]OneB[D03?neB[D00ol0003o
gR7NomhQgP02omhQgP03o`000?od2oCom0_d00oom0_d00?o0000ood2oOl000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?of2OKomPWf00WomPWf00Co0000omDZeOoE:]Go
eB[E0_l00006on<Lh`03o`000?nTFjCoY5^T00SoY5^T0ol000000onPGj3o0000o`000004odn`C`03
o`000?lCk1?o4n`C00go4n`C00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l7n0Oo1oP700Wo1oP700?o0000odFjAOm5^TD03?m5^TD00ol0003oQGZ5ohEjQ@03o`0000ko
]DZe00?o0000omhQg_oN8Mh00ooN8Mh00ol0003om0_doo@;m00>oo@;m005o`000?om0_goo@;mood2
oOl000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@09ood2o@03o`000?of2OKomPWf00[o
mPWf00?o0000omDZeOl000002?oS7><00ol0003oY5^TojAKY00;ojAKY003o`000?m?/4ooCk1?00Go
Ck1?00?o0000oa?/4olCk1<03?lCk1<00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`Oh1ol7n0L02?l7n0L2o`0000ooAKY50_l00002ojEJY@03o`000?neB[Go]DZe00_o
]DZe00?o0000omhQg_oN8Mh01?oN8Mh00ol0003om0_doo@;m00=oo@;m003o`000?om0_goo@;m00?o
o@;m00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ood2o@03o`000?of2OKomPWf00_omPWf00?o0000on<LhooS7><0
1ooS7><00ol0003oY5^TojAKY00;ojAKY003o`000?m?/4ooCk1?00KoCk1?00?o0000oa?/4olCk1<0
2olCk1<2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o1oP7o`Oh1`07o`Oh1`04o`00
0?lIiQWo6NHIo`0000koAKY500?o0000ojEJYOnUFZD00_nUFZD00ol0003o]DZeokE:]@09okE:]@03
o`000?oN8MkogR7N00KogR7N00?o0000oo@;m?od2o@02ood2o@00ol0003oo@;mood2o@05ood2o@04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000Soo@;m00?o0000ooH9m_of2OH02_of2OH2o`0000Wo
hacS00?o0000ojAKY?nTFj@02onTFj@00ol0003oCk1?odn`C`07odn`C`03o`000?lCk1?o4n`C00Wo
4n`C00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l7n0Oo1oP7
00Ko1oP700Go0000oaWV6OlIiQWo6NHIo`00000>odFjA@03o`000?nUFZGoYEZU00?oYEZU00?o0000
okE:]OneB[D01oneB[D00ol0003ogR7NomhQgP07omhQgP03o`000?od2oCom0_d00[om0_d00?o0000
ood2oOom0_d01oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ood2o@03o`000?of2OKomPWf
00WomPWf00Co0000oo@;m?od2oCo00002OoS7><00ol0003oY5^TojAKY009ojAKY003o`000?m?/4oo
Ck1?00WoCk1?00?o0000oa?/4olCk1<01olCk1<00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o1oP7o`Oh1`05o`Oh1`03o`000?lIiQWo
6NHI00?o6NHI00?o0000odFjAOm5^TD02_m5^TD00ol0003oYEZUojEJY@05ojEJY@03o`000?neB[Go
]DZe00Go]DZe00?o0000omhQg_oN8Mh02?oN8Mh00ol0003om0_doo@;m009oo@;m003o`000?om0_go
o@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_om0_d3o`0000WomPWf00?o0000oo@;
m?od2o@00_od2o@00ol0003ohacSon<Lh`06on<Lh`03o`000?nTFjCoY5^T00WoY5^T00?o0000odn`
Com?/4l02_m?/4l00ol0003o4n`Coa?/4`05oa?/4`03o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l7n0Oo1oP700Co1oP700?o0000oaWV
6OlIiQT01?lIiQT00ol0003oAKY5odFjA@0:odFjA@03o`000?nUFZGoYEZU00KoYEZU00?o0000okE:
]OneB[D00oneB[D00ol0003ogR7NomhQgP09omhQgP03o`000?od2oCom0_d00Som0_d00?o0000ood2
oOom0_d02Oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003oo/4n`?o00001Oof2OH00ol0003o
m0_doo@;m003oo@;m003o`000?oS7>?ohacS00KohacS00?o0000ojAKY?nTFj@02OnTFj@00ol0003o
Ck1?odn`C`0;odn`C`03o`000?lCk1?o4n`C00?o4n`C00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`Oh1ol7n0L00_l7n0L2o`0000So
6NHI00?o0000odFjAOm5^TD02Om5^TD00ol0003oYEZUojEJY@07ojEJY@05o`000?neB[Go]DZeokE:
]Ol000003OoN8Mh00ol0003om0_doo@;m006oo@;m003o`000?om0_goo@;m00[oo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?ok1?_on`Ck00Gon`Ck0ol000000oof2OKo0000oo@;m006oo@;m003
o`000?oS7>?ohacS00GohacS00?o0000ojAKY?nTFj@02OnTFj@00ol0003oCk1?odn`C`0<odn`C`05
o`000?lCk1?o4n`Coa?/4ol000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`Oh1ol000000_l000000ol;m0_o0000oaWV6@07oaWV6@03o`000?m5^TGoAKY5
00SoAKY500?o0000ojEJYOnUFZD02OnUFZD00ol0003o]DZeo`00000=omhQgPCo00001Ood2o@00ol0
003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003on`Ckoo/4n`08oo/4n`03
o`000?od2oCom0_d00Oom0_d00?o0000on<LhooS7><01?oS7><00ol0003oY5^TojAKY009ojAKY003
o`000?m?/4ooCk1?00goCk1?00?o0000oa?/4ol000003?l0o`0:o`0000Oo0?l00ol00005o`_d2`03
o`000?lIiQWo6NHI00Ko6NHI00?o0000odFjAOm5^TD01om5^TD00ol0003oYEZUojEJY@0:ojEJY@03
o`000?oN8MkogR7N00_ogR7N00?o0000ooL8moog2?L00_og2?L3o`000003oo@;m?l0003oo@;m00_o
o@;m0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003om0_doo@;m007oo@;m003o`00
0?oS7>?ohacS00GohacS00?o0000ojAKY?nTFj@01onTFj@00ol0003oCk1?odn`C`0?odn`C`;o0000
2ol0o`000ol0003o0_d2o`;m0P07o`;m0P03o`000?l0o`3o0?l000;o0?l00ol00008o`_d2`03o`00
0?lIiQWo6NHI00Ko6NHI00?o0000odFjAOm5^TD01om5^TD00ol0003oYEZUojEJY@0:ojEJY@03o`00
0?oN8MkogR7N00[ogR7N00?o0000ooL8moog2?L01_og2?L00ol0003oo@;mood2o@08ood2o@?o0000
0_om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003om0_doo@;
m008oo@;m003o`000?oS7>?ohacS00CohacS00?o0000ojAKY?nTFj@01onTFj@00ol0003oCk1?odn`
C`0>odn`C`04o`000?lLhaco7><Lo`0000Wo0?l000?o0000o`;m0_l2o@802Ol2o@801?l0003o0?l0
o`000?l0000<o`_d2`03o`000?lIiQWo6NHI00Ko6NHI00?o0000odFjAOm5^TD01_m5^TD00ol0003o
YEZUojEJY@0;ojEJY@03o`000?oN8MkogR7N00OogR7N0_l00009ooL8m`03o`000?om0_goo@;m00Co
o@;m1?l00006ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?od2oCom0_d00Som0_d00?o0000on<LhooS7><00ooS7><>o`0000goCk1?00?o0000oacS7?lLha`0
0_lLha`00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200_o0_d200?o0000o`_d2ol;m0/0
3?l;m0/00ol0003o6NHIoaWV6@06oaWV6@03o`000?m5^TGoAKY500GoAKY500?o0000ojEJYOnUFZD0
3?nUFZD00ol0003ogR7NomhQgP06omhQgP03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d0
0ol0000:ood2o@?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo@;m?od2o@02?od
2o@01Ol0003ohacSon<LhooS7>?o000000_o]TVf00?o0000oeRWF?mHYeP00ol00009odn`C`03o`00
0?lLhaco7><L00Co7><L00?o0000o`3o0?l0o`000ol0o`000ol0003o0_d2o`;m0P0<o`;m0P03o`00
0?l;m0_o2o@;00go2o@;00?o0000oaWV6OlIiQT01_lIiQT00ol0003oAKY5odFjA@03odFjA@?o0000
3OnUFZD00ol0003ogR7NomhQgP05omhQgP03o`000?og2?Oom`Sg00com`Sg0_l0000=ood2o@03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo@;m?od2o@02?od
2o@4o`0000co]TVf00?o0000oeRWF?mHYeP00omHYeP3o`0000GoCk1?00?o0000oacS7?lLha`01_lL
ha`01Ol0003o0?l0o`3o0?l0o`3o000000oo0_d200?o0000o`_d2ol;m0/03Ol;m0/00ol0003o6NHI
oaWV6@06oaWV6@03o`000?m5^TGoAKY500?o00000omPWf000ol0003oYEZUojEJY@0;ojEJY@03o`00
0?oN8MkogR7N00?ogR7N00?o0000ooL8moog2?L03Oog2?L00ol0003oo@;mood2o@0;ood2o@03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo/4nook1?/02_ok1?/3o`0000Kom0_d0ol0
0003onhAkP03o`000?nfBKKo]TVf00[o]TVf00?o0000oeRWF?mHYeP01_mHYeP3o`000003odn`Col0
003o7><L00Wo7><L00?o0000o`3o0?l000004?l2o@800ol0003o2o@;o`_d2`0=o`_d2`03o`000?lI
iQWo6NHI00Oo6NHI0_l00007of2OH003o`000?nUFZGoYEZU00[oYEZU00Co0000omhQg_oN8MkogR7N
0ol0000?ooL8m`03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000oo/4nook1?/02_ok
1?/01?l0003on@KiooT6nOoi1_T2o`000004oo@;m?l0003o0000o`0000KokQ7^00?o0000okI9]_nf
BKH02_nfBKH00ol0003oF:MHoeRWF009oeRWF003o`000?lLhaco7><L00[o7><L00?o0000o`;m0_l2
o@803ol2o@800ol0003o2o@;o`_d2`0>o`_d2`03o`000?lIiQWo6NHI00Ko6NHI00?o0000of2OH?mP
Wf001omPWf04o`0000SoYEZU00Co0000omhQg_oN8Mko00000oo_4>l2o`0000gom`Sg00?o0000ood2
oOom0_d02_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003o
n@KiooT6n@04ooT6n@03o`000?o^4NkokQ7^00OokQ7^00?o0000okI9]_nfBKH02OnfBKH00ol0003o
F:MHoeRWF00:oeRWF003o`000?lLhaco7><L00[o7><L00?o0000o`;m0_l2o@803ol2o@800ol0003o
2o@;o`_d2`0>o`_d2`03o`000?lIiQWo6NHI00Go6NHI00?o0000of2OH?mPWf002?mPWf001?l0003o
[e2_ojm@[on_D:l7o`0000;oYEZU0_l00006onl@k`;o00003?og2?L00ol0003oo@;mood2o@09ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oi1_Won@Ki00Go
n@Ki00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o]TVfokI9]P08okI9]P03o`000?mHYeSoF:MH00[o
F:MH00?o0000oacS7?lLha`02olLha`00ol0003o0_d2o`;m0P0>o`;m0P03o`000?l;m0_o2o@;00ko
2o@;1Ol00002oaWV6@03o`000?mPWf3oH9mP00WoH9mP00?o0000ojm@[on_D:l02?n_D:l3o`0000Wo
ka3_0_l0000:ooL8m`03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP07onhAkP03o`00
0?nfBKKo]TVf00So]TVf00?o0000oeRWF?mHYeP02_mHYeP00ol0003o7><LoacS700:oacS70;o0000
3_l2o@83o`0000go2o@;0ol00005oc7><@;o00002omPWf000ol0003o[e2_ojm@[`0;ojm@[`;o0000
2_o_4>l2o`0000Oom`Sg0ol00009ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:ooT6n@03o`00
0?o^4NkokQ7^00OokQ7^00?o0000okI9]_nfBKH02?nfBKH>o`0000Wo7><L0ol000000olFjAKo0000
o`;m0P0:o`;m0P?o00000_lGj1L00ol0003o2o@;o`_d2`09o`_d2`;o00002OlacS400ol0003oH9mP
of2OH009of2OH003o`000?n_D:oo[e2_00_o[e2_00?o0000oldbcOl000002oo_4>l2o`0000Com`Sg
00Co0000ooT6nOoi1_Won@Ki0_l00007ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oom0_d00ol0003on@Ki
ooT6n@09ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000okI9]_nfBKH02?nfBKH00ol0003oEjQG
oeNXE`0:oeNXE`03o`000?lLhaco7><L00Co7><L0ol00005oaKY5P03o`000?l2o@;o0_d200Co0_d2
1?l00006oaOX5`03o`000?l;m0_o2o@;00Ko2o@;0_l0000;oc7><@03o`000?mPWf3oH9mP00WoH9mP
00?o0000ojm@[on_D:l02_n_D:l01Ol0003ocC;=oldbcOo=</go000000coka3_0_l000000oog2?Oo
0000ooT6n@05ooT6n@03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o]TVfokI9]P07okI9]P03o`00
0?mGZ5OoEjQG00_oEjQG00?o0000oacS7?lLha`00_lLha`2o`0000Wo5^TF00?o0000o`;m0_l2o@80
0ol0000;oaOX5`03o`000?l;m0_o2o@;00;o2o@;0ol0000>oc7><@03o`000?mPWf3oH9mP00OoH9mP
00?o0000ojm@[on_D:l02on_D:l00ol0003ocC;=oldbc@02oldbc@03o`000?o_4>ooka3_00_oka3_
00?o0000ooT6nOoi1_T01_oi1_T2o`0000?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oi
1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01oo^4Nh00ol0003o]TVfokI9]P05okI9]P?o00003OmG
Z5L4o`0000_o5^TF0ol0000?oaOX5`04o`000?l;m0_o0000o`00017o<Lha00?o0000of2OH?mPWf00
1omPWf000ol0003o[e2_ojm@[`0:ojm@[`03o`000?o=</gocC;=00CocC;=00?o0000onl@koo_4>l0
1oo_4>l3o`0000_on@Ki1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooT6nOoi1_T02?oi1_T00ol0003okQ7^onhA
kP06onhAkP03o`000?nfBKKo]TVf00;o]TVf0ol00003oiEZU@03o`000?mGZ5OoEjQG00[oEjQG00?o
0000oaKY5_lFjAH02olFjAH00ol0003o4^dBo`00000AoaOX5`03o`000?lacS7o<Lha017o<Lha00?o
0000of2OH?mPWf001omPWf000ol0003o[e2_ojm@[`0:ojm@[`03o`000?o=</gocC;=00GocC;=00Co
0000onl@koo_4>ooka3_1Ol00002oo4>l@03o`000?oi1_Won@Ki00Won@Ki00Co0000ooh1o_on0Oko
oP7n0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP05onhAkP?o0000
00?o]TVfo`000?l000001onEJYD00ol0003oEjQGoeNXE`08oeNXE`?o00002_lFjAH2o`0000;o4^dB
00?o0000oaOX5olGj1L03olGj1L00ol0003o<Lhaoc7><@0Aoc7><@03o`000?mPWf3oH9mP00OoH9mP
00?o0000ojm@[on_D:l02On_D:l00ol0003ocC;=oldbc@07oldbc@?o00001ooa3_400ol0003on@Ki
ooT6n@09ooT6n@03o`000?on0OkooP7n00CooP7n0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi
1_T4o`0000;okQ7^0_l00003on<Lh`03o`000?nEJYGoUFZE00SoUFZE0_l00006oeNXE`;o00000om6
^DH00ol0003o5^TFoaKY5P06oaKY5P03o`000?lBkA;o4^dB00?o4^dB00?o0000oaOX5olGj1L03_lG
j1L00ol0003o<Lhaoc7><@0Boc7><@03o`000?mPWf3oH9mP00GoH9mP00?o0000ojm@[on_D:l02On_
D:l00ol0003ocC;=oldbc@08oldbc@03o`000?oa3_7ol@ka00Ool@ka00?o0000ooT6nOoi1_T02?oi
1_T00ol0003ooP7nooh1oP07ooh1oP;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki00Con@Ki0_l00004
ooL8m`;o00001OoS7><00ol0003oUFZEoiEZU@0:oiEZU@03o`000?mGZ5OoEjQG00;oEjQG00?o0000
odJiA_m6^DH01?m6^DH00ol0003o5^TFoaKY5P04oaKY5P03o`000?lBkA;o4^dB00Co4^dB00?o0000
oaOX5olGj1L03_lGj1L00ol0003o<Lhaoc7><@0Boc7><@[o00002_n_D:l00ol0003ocC;=oldbc@08
oldbc@03o`000?oa3_7ol@ka00Ool@ka00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP09
ooh1oP?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003on@KiooT6nOoi1_T2o`0000Oom`Sg00?o0000on<LhooS7><01?oS7><0
0ol0003oUFZEoiEZU@0:oiEZU@04o`000?mGZ5Oo0000o`0000SoA[U600Co0000oaKY5_lFjAKo5^TF
0_l00007oa;]4P03o`000?lGj1Oo5nPG00ko5nPG00?o0000oc7><OlacS404_lacS400ol0003oPGj1
oh5nP@07oh5nP@03o`000?n_D:oo[e2_00Ko[e2_00?o0000oldbcOo=</d02_o=</d00ol0003ol@ka
oo4>l@06oo4>l@03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?oi
1_Wo0000o`0000Wom`Sg00?o0000on<LhooS7><01?oS7><00ol0003oUFZEoiEZU@0;oiEZU@03o`00
0?m6^DKoA[U600WoA[U600?o0000oaKY5_l000002OlBkA800ol0003o5nPGoaOX5`0>oaOX5`;o0000
4_lacS400ol0003oPGj1oh5nP@09oh5nP@;o00001_n_D:l00ol0003ocC;=oldbc@0:oldbc@03o`00
0?oa3_7ol@ka00Kol@ka00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000ooL8moog2?L02Oog2?L00ol0003ohacSon<Lh`05on<Lh`03o`000?nEJYGoUFZE00[oUFZE00?o
0000odJiA_m6^DH02_m6^DH2o`0000Wo4^dB00?o0000oaOX5olGj1L03_lGj1L00ol0003o9MXUo`00
0002o`0000oo<Lha00?o0000oh5nPOn1OX402on1OX400ol0003o[e2_ojm@[`03o`0000gocC;=00?o
0000oo4>lOoa3_401_oa3_400ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003om`SgooL8m`09ooL8m`03o`000?oS7>?ohacS00GohacS00?o0000oiEZUOnEJYD02OnEJYD2
o`0000_oA[U60_l0000;oa;]4P03o`000?lGj1Oo5nPG00co5nPG00?o0000obGJ9OlUfRD00olUfRD3
o`0000co<Lha00?o0000oh5nPOn1OX403?n1OX42o`0000;oc3?<00?o0000oldbcOo=</d03?o=</d0
0ol0003ol@kaoo4>l@05oo4>l@03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?og2?Oom`Sg00[om`Sg00?o0000on<LhooS7><01_oS7><00ol0003oUFZEoiEZU@07oiEZ
U@03o`000?nLHico000000[oA[U600Co0000oco0?olo`3oo00002_lBkA800ol0003o5nPGoaOX5`0<
oaOX5`03o`000?lUfRGo9MXU00Ko9MXU0_l00008oc7><@;o00003on1OX400ol0003oc3?<ol`cc002
ol`cc003o`000?o=</gocC;=00_ocC;=00?o0000oo4>lOoa3_401Ooa3_400ol0003on@KiooT6n@07
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003om`SgooL8m`0:ooL8m`03o`000?oS7>?ohacS
00KohacS00?o0000oiEZUOnEJYD01_nEJYD01Ol0003oW6>LoiaSW?nLHico000000SoA[U600?o0000
oco0?olo`3l00_lo`3l00ol0003o4^dBoa;]4P06oa;]4PCo00003?lGj1L00ol0003o9MXUobGJ9@08
obGJ9@?o00000_lacS43o`000003ofBKI?l0003oPGj100goPGj100?o0000ol`cc?o<<l`01?o<<l`0
0ol0003ocC;=oldbc@0:oldbc@03o`000?oa3_7ol@ka00Gol@ka00?o0000ooT6nOoi1_T01_oi1_T0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02oog2?L00ol0003ohacSon<Lh`07on<L
h`03o`000?nEJYGoUFZE00?oUFZE0_l00005oiaSW003o`000?m6^DKoA[U600CoA[U600?o0000oco0
?olo`3l00olo`3l00ol0003o4^dBoa;]4P05oa;]4P03o`000?l<l`co3?<<00;o3?<<0ol00007oaOX
5`;o00003_lUfRD2o`0000GoI9]T00?o0000oh5nPOn1OX402_n1OX400ol0003oc3?<ol`cc005ol`c
c003o`000?o=</gocC;=00_ocC;=00?o0000oo4>lOoa3_401?oa3_400ol0003on@KiooT6n@06ooT6
n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003om`SgooL8m`0;ooL8m`03o`000?oS7>?ohacS00Oo
hacS00?o0000oiEZUOnEJYD00_nEJYD00ol0003oW6>LoiaSW006oiaSW003o`000?m6^DKoA[U600;o
A[U600?o0000oco0?olo`3l01Olo`3l00ol0003o4^dBoa;]4P02oa;]4P;o00002?l<l``3o`0000;o
5nPG0_l000000ol>l@ko0000obGJ9@0=obGJ9@03o`000?mTVfCoI9]T00GoI9]T00?o0000oh5nPOn1
OX402?n1OX400ol0003oc3?<ol`cc007ol`cc003o`000?o=</gocC;=00[ocC;=00?o0000oo4>lOoa
3_401?oa3_400ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003om`Sg
ooL8m`0<ooL8m`03o`000?oS7>?ohacS00SohacS00Co0000oiEZUOnEJYGo00002OnLHi`01Ol0003o
A[U6odJiA_m6^DKo000000So?l0o00Go0000oa;]4_lBkA;o4^dBo`00000=o`cc30;o00001?l>l@h0
0ol0003o9MXUobGJ9@0;obGJ9@03o`000?mTVfCoI9]T00KoI9]T00?o0000oh5nPOn1OX401on1OX40
0ol0003oc3?<ol`cc008ol`cc0Co00002?o=</d00ol0003ol@kaoo4>l@04oo4>l@03o`000?oi1_Wo
n@Ki00Kon@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?og2?Oom`Sg00_om`Sg0ol00009on<L
h`03o`000?nEJYGo000000_oW6>L00?o0000odJiA_l000002_lo`3l00ol0003o4^dBo`00000?o`cc
3003o`000?l>l@ko3_4>00;o3_4>00?o0000obGJ9OlUfRD02olUfRD00ol0003oI9]TofBKI006ofBK
I003o`000?n1OX7oPGj100KoPGj100?o0000ol`cc?o<<l`02Oo<<l`01?l0003oi1_Ton@Ki?oT6n@7
o`0000;ocC;=00?o0000oo4>lOoa3_400ooa3_400ol0003on@KiooT6n@05ooT6n@03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?og2?Oom`Sg00Som`Sg0ol00003ooL8m`03o`000?oS7>?ohacS00OohacS00?o0000oiaS
W?nLHi`02onLHi`00ol0003o?l0ooco0?`0:oco0?`03o`000?l<l`co3?<<00go3?<<00?o0000o`ka
3_l>l@h01?l>l@h00ol0003o9MXUobGJ9@09obGJ9@03o`000?mTVfCoI9]T00SoI9]T00?o0000oh5n
POn1OX400on1OX42o`0000coc3?<00?o0000on@Ki?oT6n@02?oT6n@<o`0000?on@Ki0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000ooL8moog2?L01_og2?L3o`0000Oom`Sg00?o0000on<LhooS7><01_oS7><00ol0003o
W6>LoiaSW00;oiaSW003o`000?lo`3oo?l0o00Wo?l0o0_l0000>o`cc3003o`000?l>l@ko3_4>00Go
3_4>00?o0000obGJ9OlUfRD02OlUfRD00ol0003oI9]TofBKI009ofBKI003o`000?n1OX7o000000;o
00000_o2?L800ol0003oc3?<ol`cc008ol`cc003o`000?oT6nCoi1_T00coi1_T00?o0000oo@;m?od
2o@01_od2o@3o`0000?ooP7n0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003om`SgooL8m`03ooL8m`?o00002oog2?L00ol0003ohacS
on<Lh`04on<Lh`03o`000?nLHicoW6>L00_oW6>L0ol00007oco0?`?o000000?o9]TVo`000?l<l``0
3Ol<l``00ol0003o3_4>o`ka3P06o`ka3P03o`000?lUfRGo9MXU00So9MXU00?o0000ofBKI?mTVf@0
2_mTVf@00ol0003o`Sg2ol8m`P04ol8m`P03o`000?o<<lcoc3?<00Ooc3?<00?o0000on@Ki?oT6n@0
2ooT6n@00ol0003om0_doo@;m008oo@;m003o`000?on0OkooP7n00CooP7n0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004ooL8mol0
003o0000o`0000oom`Sg00?o0000on<LhooS7><00ooS7><>o`0000?oQGZ50_l00002oco0?`?o0000
1OlVfBH00ol0003o3?<<o`cc300:o`cc3003o`000?l>l@ko3_4>00Oo3_4>00?o0000obGJ9OlUfRD0
2?lUfRD00ol0003oI9]TofBKI00:ofBKI003o`000?o2?L;o`Sg200Go`Sg200?o0000ol`cc?o<<l`0
1_o<<l`00ol0003oi1_Ton@Ki00;on@Ki003o`000?od2oCom0_d00Som0_d00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?om0_d2o`0001;om`Sg00?o0000on<LhooS7><00_oS7><00ol0003of2OHomPW
f00:omPWf003o`000?n5NXGoQGZ500?oQGZ50_l00009obKI9P03o`000?l<l`co3?<<00Wo3?<<00?o
0000o`ka3_l>l@h02?l>l@h2o`0000So9MXU00?o0000ofBKI?mTVf@02OmTVf@00ol0003o`Sg2ol8m
`P07ol8m`P03o`000?o<<lcoc3?<00Coc3?<00?o0000on@Ki?oT6n@02ooT6n@00ol0003om0_doo@;
m009oo@;m003o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ood2oOom0_d01oom0_d00ol0003om`SgooL8m`0?ooL8m`?o000000?ohacS
o`000?oH9mP02ooH9mP00ol0003oQGZ5ohEjQ@04ohEjQ@03o`000?lVfBKo9]TV00Wo9]TV00?o0000
o`cc3?l<l``01ol<l``00ol0003o3_4>o`ka3P09o`ka3P04o`000?lYeRWo0000o`0000Ko9MXU00?o
0000ofBKI?mTVf@02OmTVf@00ol0003o`Sg2ol8m`P08ol8m`P03o`000?o<<lcoc3?<00?oc3?<00?o
0000on@Ki?oT6n@02ooT6n@00ol0003om0_doo@;m009oo@;m003o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ood2oOom0_d02?om0_d0
0ol0003om`SgooL8m`0<ooL8m`;o00000oof2OH2o`0000cof2OH00?o0000ohEjQOn5NXD01?n5NXD0
0ol0003o9]TVobKI9P0:obKI9PWo00002ol>l@h00ol0003o:MHYobWF:@02obWF:@?o00000_lUfRD0
0ol0003oI9]TofBKI00:ofBKI003o`000?o2?L;o`Sg200Wo`Sg200?o0000ol`cc?o<<l`00_o<<l`0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?od2oCom0_d00Wom0_d00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@09ood2
o@;o00002_og2?L2o`0000GomPWf00?o0000onDJiOl000002_oH9mP00ol0003oQGZ5ohEjQ@06ohEj
Q@03o`000?lVfBKo9]TV00Wo9]TV00?o0000oa;]4_lBkA801OlBkA800ol0003o3_4>o`ka3P09o`ka
3P03o`000?lYeRWo:MHY00Go:MHY0ol00009ofBKI0?o00003Oo2?L801Ol0003oc3?<ol`cc?o<<lco
000000coi1_T00?o0000oo@;m?od2o@02Ood2o@00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8
moog2?L01Oog2?L2o`0000OomPWf00Co0000onDJiOoU6^Go00002OoH9mP00ol0003oQGZ5ohEjQ@06
ohEjQ@03o`000?lVfBKo9]TV00So9]TV00?o0000oa;]4_lBkA801olBkA800ol0003o3_4>o`ka3P07
o`ka3P03o`000?lYeRWo:MHY00So:MHY0ol00002ofBKI0Go00000_n/Dj`00ol0003o`Sg2ol8m`P0<
ol8m`P03o`000?o<<lco000000coi1_T00?o0000oo@;m?od2o@02_od2o@00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m
00goo@;m00?o0000ooL8moog2?L00_og2?L2o`0000SomPWf00?o0000onDJiOoU6^D00_oU6^D5o`00
00Cof2OH00?o0000ohEjQOn5NXD01_n5NXD00ol0003o9]TVobKI9P08obKI9P03o`000?lBkA;o4^dB
00Oo4^dB00?o0000o`ka3_l>l@h01ol>l@h00ol0003o:MHYobWF:@08obWF:@03o`000?m`Sg3oL8m`
00;o00002?n/Dj`00ol0003o`Sg2ol8m`P0<ol8m`PCo00002_oT6n@00ol0003om0_doo@;m00:oo@;
m003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ood2oOom0_d03_om0_d01?l0003om`Sgo`000?l0000:ooH9mP03o`000?oU6^GoiA[U
00;oiA[U00?o0000okm0_ono@;l00_no@;l4o`0000WoQGZ500?o0000obKI9_lVfBH02?lVfBH00ol0
003o4^dBoa;]4P08oa;]4P03o`000?l>l@ko3_4>00Go3_4>00?o0000obWF:OlYeRT02?lYeRT01Ol0
003oL8m`og2?L?m`Sg3o000000[o[5>/0ol0000;ol8m`P04o`000?o_4>ooka3_onl@k`Co00001OoT
6n@00ol0003om0_doo@;m00;oo@;m003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ood2oOom0_d03oom0_d00ol0003omPWfooH9mP0:
ooH9mP03o`000?oU6^GoiA[U00?oiA[U00?o0000okm0_ono@;l01?no@;l00ol0003oQGZ5ohEjQ@07
ohEjQ@03o`000?lVfBKo9]TV00Ko9]TV0_l0000;oa;]4P03o`000?l>l@ko3_4>00Go3_4>00?o0000
obWF:OlYeRT02?lYeRT00ol0003oL8m`og2?L002og2?L003o`000?n/Djco[5>/00Oo[5>/00?o0000
omdRgOoM8]d01?l00006ol8m`P03o`000?o_4>ooka3_00Koka3_0ol00002on@Ki003o`000?od2oCo
m0_d00_om0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of2OKomPWf00WomPWf00?o0000onDJ
iOoU6^D01?oU6^D00ol0003o_d2ookm0_`05okm0_`03o`000?n5NXGoQGZ500OoQGZ500?o0000obKI
9_lVfBH00_lVfBH3o`000003oc_4>ol0003o4^dB00[o4^dB00?o0000o`ka3_l>l@h01Ol>l@h00ol0
003o:MHYobWF:@07obWF:@03o`000?m`Sg3oL8m`00?oL8m`00?o0000ojaC[?n/Dj`01on/Dj`00ol0
003ogB;MomdRg@04omdRg@?o00000_o2?L800ol0003oka3_onl@k`0:onl@k`;o00003_od2o@00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?om0_goo@;m013oo@;m00?o0000ooH9m_of2OH02Oof2OH00ol0003oiA[UonDJi@04onDJi@03
o`000?no@;oo_d2o00Ko_d2o0_l00007ohEjQ@03o`000?lVfBKo000000;o00001Olka3/00ol0003o
4^dBoa;]4P08oa;]4P?o00001?l>l@h00ol0003o:MHYobWF:@08obWF:@03o`000?m`Sg3oL8m`00Co
L8m`00?o0000ojaC[?n/Dj`01_n/Dj`00ol0003ogB;MomdRg@07omdRg@;o00003_o_4>l00ol0003o
m0_doo@;m00;oo@;m003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfooH9mP08ooH9mP03o`00
0?oU6^GoiA[U00GoiA[U00?o0000okm0_ono@;l01?no@;l00ol0003o_4>loka3_003o`0000CoQGZ5
0_l00008oc_4>`03o`000?lBkA;o4^dB00Oo4^dB00Co0000oc;=<_lbcC;o</db0ol000000ol>l@ko
0000obWF:@09obWF:@03o`000?m`Sg3oL8m`00CoL8m`00?o0000ojaC[?n/Dj`01On/Dj`00ol0003o
gB;MomdRg@09omdRg@03o`000?o_4>ooka3_00goka3_00?o0000oo@;m?od2o@02_od2o@00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?om0_goo@;m017oo@;m00?o0000ooH9m_of2OH01oof2OH00ol0003oiA[UonDJi@06onDJi@03o`00
0?no@;oo_d2o00?o_d2o00?o0000oka3_?nl@k`01?nl@k`2o`000003ohEjQOl0003o>l@k00[o>l@k
00?o0000oa;]4_lBkA801OlBkA800ol0003o</dboc;=<P05oc;=<P03o`000?lYeRWo:MHY00Oo:MHY
0ol00007og2?L003o`000?n/Djco[5>/00Co[5>/00?o0000omdRgOoM8]d02OoM8]d00ol0003oka3_
onl@k`0=onl@k`03o`000?od2oCom0_d00[om0_d00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of
2OKomPWf00GomPWf0ol00009onDJi@05o`000?no@;oo_d2ookm0_ol000002Onl@k`00ol0003o>l@k
oc_4>`0;oc_4>`03o`000?lBkA;o4^dB00?o4^dB00?o0000oc;=<_lbcC801_lbcC800ol0003o:MHY
obWF:@06obWF:@05o`000?mUVVGoIIYUofFJIOl000001om`Sg000ol0003o[5>/ojaC[003ojaC[003
o`000?oM8]gogB;M00WogB;M00?o0000onl@koo_4>l03_o_4>l00ol0003om0_doo@;m009oo@;m003
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfo`000004o`0000;on@Ki00?o0000onDJiOoU6^D0
1ooU6^D01?l0003o_d2ookm0_ol00009oka3_0;o00003Olka3/00ol0003o4^dBoa;]4P02oa;]4P03
o`000?lbcC;o</db00So</db00?o0000obWF:OlYeRT00olYeRT2o`0000GoIIYU00?o0000og2?L?m`
Sg001?m`Sg000ol0003o[5>/ojaC[003ojaC[003o`000?oM8]gogB;M00WogB;M00?o0000onl@koo_
4>l03_o_4>l00ol0003om0_doo@;m009oo@;m003o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ood2oOom0_d04Oom0_d2o`0000Son@Ki
00?o0000onDJiOoU6^D01_oU6^D00ol0003o_d2oo`000009oka3_004o`000?n>LHkoSW6>o`0000go
>l@k00Co0000oa;]4_lBkA;o00003?lbcC801Ol0003o:MHYobWF:OlYeRWo000000SoIIYU0_l00005
og2?L003o`000?n/Djco[5>/00;o[5>/00?o0000omdRgOoM8]d02OoM8]d00ol0003oka3_onl@k`0>
onl@k`03o`000?od2oCom0_d00Wom0_d00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oi1_Won@Ki
00Oon@Ki00?o0000onDJiOoU6^D01ooU6^D00ol0003o_4>loka3_007oka3_003o`000?n>LHkoSW6>
00;oSW6>00?o0000oc_4>olka3/02_lka3/00ol0003o4^dBo`00000>oc;=<P03o`000?lYeRWo0000
00_oIIYU00?o0000og2?L?m`Sg000_m`Sg001Ol0003o[5>/ojaC[?n/Djco000000cogB;M00?o0000
onl@koo_4>l03_o_4>l3o`0000Wom0_d00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki
00Won@Ki00?o0000onDJiOoU6^D01_oU6^D00ol0003o_4>loka3_006oka3_003o`000?n>LHkoSW6>
00?oSW6>00?o0000oc_4>olka3/02olka3/00ol0003o</dboc;=<P0>oc;=<P03o`000?mUVVGoIIYU
00_oIIYU0_l00003og2?L004o`000?n/Djco[5>/o`0000[ogB;M0ol0000>onl@k`;o00000oon0Oh2
o`0000Oom0_d00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki00[on@Ki00?o0000onDJ
iOoU6^D01?oU6^D00ol0003o_4>loka3_006oka3_003o`000?n>LHkoSW6>00GoSW6>00?o0000oc_4
>olka3/01olka3/3o`00017o</db00?o0000ofFJIOmUVVD03OmUVVD01Ol0003oL8m`og2?L?l0003o
[5>/00Co00000ooM8]d5o`0000;om`Sg00?o0000onl@koo_4>l02_o_4>l2o`0000OooP7n0_l00004
oo@;m003o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03_om0_d00ol0003on@KiooT6n@0;ooT6n@03o`000?oU6^GoiA[U
00CoiA[U00?o0000oka3_?nl@k`01Onl@k`00ol0003oSW6>ohiaSP06ohiaSP03o`000?lka3_o>l@k
00Co>l@k0ol00002od2o@003o`000?lbcC;o</db00oo</db0_l0000?ofFJI@04o`000?m`Sg3o0000
o`0000Cod2o@0ol00008ooL8m`03o`000?o_4>ooka3_00Ooka3_0_l0000;ooh1oP;o00000_od2o@0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?om0_goo@;m00goo@;m00?o0000ooT6nOoi1_T03?oi1_T6o`0000Oo_4>l00?o0000ohia
S_n>LHh02?n>LHh00ol0003o>l@koc_4>`03o`0000Ko@;m000?o0000oc;=<_lbcC803OlbcC801?l0
003oJIIYofVFJOl0000?ofFJI@03o`000?o@;m3od2o@00God2o@00?o0000ooL8moog2?L02?og2?L0
0ol0003oka3_onl@k`05onl@k`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oi1_T00ol0003oj1OXonPGj004onPG
j003o`000?nl@kco_4>l00?o_4>l00?o0000ohiaS_n>LHh02_n>LHh2o`0000[o@;m000?o0000oc;=
<_lbcC802olbcC800ol0003oJIIYofVFJ@02ofVFJ@03o`000?mUVVGoIIYU00_oIIYU0_l00007om0_
d003o`000?og2?Oom`Sg00Wom`Sg00?o0000onl@koo_4>l00_o_4>l2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000ooT6nOoi1_T02ooi1_T00ol0003oj1OXonPGj006onPGj005o`000?nl@kco_4>loka3
_?l000003On>LHh00ol0003o@;m0od2o@00:od2o@003o`000?lbcC;o</db00Wo</db00?o0000ofVF
JOmYUVT01?mYUVT00ol0003oIIYUofFJI@08ofFJI@;o000000?oVFJIo`000?o@;m001oo@;m000ol0
003om`SgooL8m`09ooL8m`04o`000?o_4>oo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oi1_Won@Ki
00Won@Ki00?o0000onPGj?oX5nP02?oX5nP00ol0003o_4>lo`00000=ohiaSP03o`000?m0_d3o@;m0
00_o@;m000?o0000oc;=<_lbcC802?lbcC800ol0003oJIIYofVFJ@06ofVFJ@03o`000?mUVVGoIIYU
00GoIIYU0_l00003oiUVV@03o`000?o@;m3od2o@00Kod2o@00?o0000ooL8moog2?L02_og2?L00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on@KiooT6n@07ooT6n@03o`000?oX5nSoj1OX00[oj1OX00?o0000ohiaS_n>
LHh03?n>LHh00ol0003o@;m0od2o@00<od2o@003o`000?lbcC;o</db00Ko</db00?o0000ofVFJOmY
UVT02?mYUVT00ol0003oIIYUofFJI@02ofFJI@;o00001_nIIYT00ol0003od2o@om0_d005om0_d003
o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Gon@Ki
00?o0000onPGj?oX5nP03?oX5nP2o`0000coSW6>00?o0000od2o@?m0_d003Om0_d000ol0003o</db
oc;=<P04oc;=<P03o`000?mYUVWoJIIY00[oJIIY00Co0000ofFJIOl0003o00002?nIIYT00ol0003o
d2o@om0_d006om0_d003o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_oi1_T00ol0003oj1OXonPGj00=onPGj003o`000?nl@kco000000;o00002?n>LHh00ol0003o@;m0
od2o@00?od2o@0Ko00003_mYUVT00ol0003oVFJIoiUVV@08oiUVV@03o`000?o@;m3od2o@00Kod2o@
00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000ooX5n_oj1O[onPGj
0_l0000?onPGj003o`000?nl@kco_4>l00?o_4>l0ol00005ohiaSP;o00004?m0_d001_l0003oC[5>
odjaC_l0003oBKI9o`0000koJIIY00?o0000oiUVVOnIIYT02OnIIYT00ol0003od2o@om0_d005om0_
d003o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003o
j1OXonPGj00=onPGj003o`000?nl@kco_4>l00Ko_4>l0ol000001?n>LHko0000offBKOm]TVd3o`00
00co@;m000Go0000odjaC_m>/DkoC[5>o`000002odVfB@03o`000?mYUVWoJIIY00_oJIIY00?o0000
oiUVVOnIIYT02OnIIYT00ol0003od2o@om0_d006om0_d003o`000?og2?Oom`Sg00Som`Sg0_l0000A
ooh1oP?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003onPGjooX5nP04ooX5nPoo00003?nl@k`00ol0003oKI9]offBK@04offB
K@?o00002?m0_d000ol0003oC[5>odjaCP02odjaCP05o`000?m9]TWoBKI9odVfBOl000003?mYUVT0
0ol0003oVFJIoiUVV@09oiUVV@03o`000?o@;m3od2o@00God2o@3?l00002oo`3o0;o00003Oon0Oh2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o[5>_ojaC[00_ojaC[00?o0000oka3
_?nl@k`02_nl@k`00ol0003oKI9]offBK@07offBK@;o00001Om0_d000ol0003oC[5>odjaCP03odja
CP03o`000?m9]TWoBKI900;oBKI900?o0000ofVFJOmYUVT02OmYUVT00ol0003oVFJIoiUVV@0:oiUV
V@03o`000?o@;m3od2o@00?od2o@00?o0000oo<<looc3?<02Ooc3?<00ol0003oo0?loo`3o002oo`3
o0;o00002Oon0Oh2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?o[5>_ojaC[00[o
jaC[00?o0000oka3_?nl@k`02onl@k`00ol0003oKI9]offBK@09offBK@?o000000?o@;m0o`000?m>
/Dh01Om>/Dh00ol0003oBKI9odVfB@03odVfB@03o`000?mYUVWoJIIY00SoJIIY3_l00003om0_d0;o
00002ooc3?<00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ol0o`o`00000;on/Dj`03o`000?nl@kco_4>l00[o_4>l
0_l0000>offBK@03o`000?m>/DkoC[5>00GoC[5>00?o0000odVfBOm9]TT00om9]TT00ol0003oJIIY
ofVFJ@08ofVFJ@03o`000?o?<<oocc3?00_occ3?00?o0000om0_d?l000003Ooc3?<00ol0003oo0?l
oo`3o006oo`3o0;o000000?ooP7no`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00KonPGj00Co
0000oo0?l?o`3o3o00002_o[5>/00ol0003o_4>loka3_009oka3_003o`000?nQGZ7o000000koKI9]
00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oBKI9odVfB@04odVfB@03o`000?mYUVWoJIIY00KoJIIY
00?o0000oll`coo?<<l03Oo?<<l00ol0003ol`ccoo<<l`0<oo<<l`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo0?l?o`3o000_o`
3o000ol0003ojaC[on/Dj`06on/Dj`03o`000?nl@kco_4>l00So_4>l0_l00003oj5NX@03o`000?m]
TVgoKI9]00_oKI9]00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oBKI9odVfB@05odVfB@03o`000?mY
UVWoJIIY00GoJIIY00?o0000oll`coo?<<l03Oo?<<l00ol0003ol`ccoo<<l`0;oo<<l`03o`000?ol
0ocoo0?l00Woo0?l00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000
oo0?l?o`3o000oo`3o000ol0003ojaC[on/Dj`05on/Dj`03o`000?nl@kco_4>l00Oo_4>l00?o0000
oj5NXOnQGZ400onQGZ400ol0003oKI9]offBK@0:offBK@03o`000?m>/DkoC[5>00KoC[5>00?o0000
odVfBOm9]TT01_m9]TT00ol0003oJIIYofVFJ@04ofVFJ@03o`000?o?<<oocc3?00gocc3?3ol0000;
oo`3o003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000oo0?l?o`3o001Oo`3o000ol0
003ojaC[on/Dj`04on/Dj`03o`000?nl@kco_4>l00Go_4>l0_l00006oj5NX@03o`000?m]TVgoKI9]
00WoKI9]0_l00008odjaCP03o`000?m9]TWoBKI900KoBKI91Ol000000omYUVWo0000oll`c`0?oll`
c`03o`000?oe2_Gom@[e00_om@[e00?o0000oo`3o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000oo0?l?o`3o001_o`3o000ol0003o
jaC[on/Dj`04o`0000Ko_4>l00?o0000oj5NXOnQGZ401onQGZ400ol0003oKI9]offBK@05offBK@?o
000000?oJiA[o`000?m>/Dh01om>/Dh00ol0003oBKI9odVfB@05odVfB@03o`000?n6NHKoQWV600?o
QWV60_l0000?oll`c`;o00003Ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000WonPGj00?o0000oo0?l?o`3o001oo`3o02o`0000CoeRWF00Co0000oka3_?nl@kco
_4>l0_l0000:oj5NX@03o`000?m]TVgoKI9]00;oKI9]0ol00005of^DJ`03o`000?m>/DkoC[5>00Go
C[5>00?o0000odVfBOm9]TT01?m9]TT00ol0003oQWV6ohIiQP06ohIiQP03o`000?o?<<oocc3?00[o
cc3?0_l00002onTFj@03o`000?oe2_Gom@[e00[om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l008oo0?l003o`00
0?oF:MKoeRWF00CoeRWF00?o0000oka3_?l000003?nQGZ400ol0003oKI9]o`000002o`0000WoJiA[
00?o0000odjaC_m>/Dh01?m>/Dh00ol0003oBKI9odVfB@03odVfB@03o`000?n6NHKoQWV600SoQWV6
1_l00004oll`c`;o00001OoY5^T00ol0003om@[eooD:m@09ooD:m@03o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo0?l?o`3o001oo`
3o000ol0003oeRWFomHYeP06omHYeP03o`000?nQGZ7oXEjQ00coXEjQ00?o0000of^DJom[U6/02_m[
U6/00ol0003oC[5>odjaCP04odjaCP04o`000?m9]TWoBKI9odVfB@;o00002on6NHH00ol0003oe2_D
om@[e003om@[e0Co00002?oY5^T00ol0003om@[eooD:m@08ooD:m@03o`000?ol0ocoo0?l00Ooo0?l
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003ol0o`oo0?l007oo0?l003o`000?oF
:MKoeRWF00OoeRWF00?o0000oj5NXOnQGZ403?nQGZ400ol0003oJiA[of^DJ`0;of^DJ`03o`000?m>
/DkoC[5>00?oC[5>00Co0000odVfBOm9]TWo00003On6NHH00ol0003oe2_Dom@[e006om@[e003o`00
0?oY5^WojAKY00OojAKY00?o0000ooD:mOoe2_D01ooe2_D00ol0003oo0?loo`3o006oo`3o004o`00
0?oo0?ooo`3oool0o`;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo0?l?o`3o00
1_o`3o000ol0003oeRWFomHYeP09omHYeP03o`000?nQGZ7oXEjQ00WoXEjQ0_l0000>of^DJ`?o0000
0om>/Dh00ol0003oBKI9o`00000=ohIiQP03o`000?oD:mCoe2_D00Ooe2_D00?o0000onTFjOoY5^T0
2?oY5^T:o`0000Koo0?l0_l00006ool0o`03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Ool0o`00?o
0000omHYe_oF:MH02_oF:MH00ol0003oXEjQoj5NX@06oj5NX@;o000000?oWV6No`000?m[U6/02om[
U6/2o`0000?oLXeb1Ol0000>ohIiQP03o`000?oD:mCoe2_D00Ooe2_D00?o0000onTFjOoY5^T02?oY
5^T00ol0003on@KiooT6n@06ooT6n@03o`000?ol0ocoo0?l00?oo0?l00?o0000ool0oooo0?l01ooo
0?l2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP03ooH9mPCo00000_o`3o000ol0003oeRWFomHYeP0;
omHYeP03o`000?nQGZ7oXEjQ00?oXEjQ0ol00004oiiQWP03o`000?m[U6_oJiA[00OoJiA[0_l00008
og:=LP03o`000?n6NHKoQWV600goQWV600?o0000om@[e?oD:m@02?oD:m@00ol0003ojAKYonTFj@07
onTFj@03o`000?oi1_Won@Ki00Oon@Ki0ol000000ool0oco0000ool0o`0;ool0o`;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?of2OKomPWf00OomPWf0_l0000?omHYeP03o`000?nQGZ7oXEjQ00;o00002?nNHIh00ol0
003oJiA[of^DJ`05of^DJ`03o`000?mbSG;oLXeb00SoLXeb00?o0000ohIiQ_n6NHH03On6NHH00ol0
003oe2_Dom@[e008om@[e003o`000?oY5^WojAKY00KojAKY00?o0000ooT6nOoi1_T02?oi1_T01?l0
003oo@;mood2oOl0000?ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP09ooH9
mP03o`000?oF:MKoeRWF00koeRWF0_l0000;oiiQWP03o`000?m[U6_oJiA[00;oJiA[0_l0000;og:=
LP03o`000?n6NHKoQWV600goQWV600?o0000om@[e?oD:m@02?oD:m@00ol0003ojAKYonTFj@06onTF
j@03o`000?oi1_Won@Ki00Oon@Ki00Go0000ood2oOom0_goo@;mo`00000@ool0o`;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003omPWfooH9mP0:ooH9mP03o`000?oF:MKoeRWF00goeRWF0_l0000<oiiQWP04o`000?m[U6_o0000
o`0000goLXeb00?o0000ohIiQ_n6NHH03?n6NHH00ol0003oe2_Dom@[e009om@[e003o`000?oY5^Wo
jAKY00KojAKY00?o0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003omPWfooH9mP0:ooH9mP03o`000?oF:MKoeRWF00coeRWF00Co0000omLX
eooG:=Oo00003?nNHIh00ol0003oLXebog:=LP0>og:=LP03o`000?n6NHKoQWV600SoQWV61?l0000;
om@[e003o`000?oY5^WojAKY00KojAKY00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oo@;mood2o@04
ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003omPWfooH9mP0;ooH9mP03o`000?oF:MKoeRWF
00_oeRWF00?o0000omLXeooG:=L00_oG:=L00ol0003oWV6NoiiQWP09oiiQWP03o`000?mbSG;oLXeb
00koLXeb00Co0000ohIiQ_n6NHKoQWV61ol00003ojaC[003o`000?oD:mCoe2_D00Woe2_D00?o0000
onTFjOoY5^T01_oY5^T00ol0003on@KiooT6n@04ooT6n@03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00comPWf00?o0000omHYe_oF:MH02_oF:MH00ol0
003oebSGomLXe`03omLXe`03o`000?nNHIkoWV6N00SoWV6N00?o0000og:=L_mbSG803_mbSG84o`00
00_o[5>/00?o0000om@[e?oD:m@02?oD:m@00ol0003ojAKYonTFj@05onTFj@03o`000?oi1_Won@Ki
00Gon@Ki00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooH9m_of
2OH03?of2OH7o`0000GoeRWF00?o0000omLXeooG:=L01OoG:=L00ol0003oWV6NoiiQWP07oiiQWP03
o`000?mbSG;oLXeb00koLXeb00?o0000ojaC[?n/Dj`03On/Dj`00ol0003oe2_Dom@[e008om@[e003
o`000?oY5^WojAKY00CojAKY00?o0000ooT6nOoi1_T01?oi1_T00ol0003oo@;mood2o@07ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003omPWfooH9mP0=ooH9mP03o`000?oY5^WojAKY00CojAKY
1Ol00009omLXe`03o`000?nNHIkoWV6N00KoWV6N00?o0000og:=L_mbSG803_mbSG800ol0003o[5>/
ojaC[00=ojaC[003o`000?oD:mCoe2_D00Soe2_D00Co0000onTFjOoY5^WojAKY1Ol00004ooT6n@03
o`000?om0_goo@;m00Woo@;m1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooH9mP03o`000?oY5^WojAKY00WojAKY
0_l00009omLXe`03o`000?nNHIkoWV6N00KoWV6N00?o0000og:=L_mbSG803?mbSG800ol0003o[5>/
ojaC[00?ojaC[0Ko00001?oD:m@4o`0000Gom@[e0_l000000ooi1_Wo0000ood2o@0;ood2o@04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?ok1?_on`Ckoo/4n`?o00002_of2OH00ol0003o
jAKYonTFj@09onTFj@03o`000?oR7N;o000000;o00001ooG:=L00ol0003oWV6NoiiQWP05oiiQWP03
o`000?mbSG;oLXeb00SoLXeb1Ol0000AojaC[003o`000?oN8MkogR7N00?ogR7N1?l0000;ooD:m@03
o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000OomPWf
00?o0000onTFjOoY5^T02_oY5^T00ol0003ohQgRon8MhP02on8MhP?o00001OoG:=L00ol0003oWV6N
oiiQWP04oiiQWP04o`000?mbSG;oLXebog:=LPOo00001?n/Dj`00ol0003o[5>/ojaC[00>ojaC[003
o`000?oN8MkogR7N00OogR7N00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oo@;mood2o@09ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`08oo/4n`;o00001?of2OH00ol0003ojAKY
onTFj@0;onTFj@03o`000?oR7N;ohQgR00GohQgR0ol00003omLXe`04o`000?nNHIkoWV6NoiiQWPKo
00003?n/Dj`00ol0003o[5>/ojaC[00=ojaC[003o`000?oN8MkogR7N00OogR7N00?o0000ooD:mOoe
2_D02_oe2_D00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo/4n`?o000000?omPWfo`000?oY5^T0
3?oY5^T00ol0003ohQgRon8MhP08on8MhP?o000000CoebSGo`000?l0003o00000_oC;=<00ol0003o
[5>/ojaC[00=ojaC[003o`000?n/Djco[5>/00co[5>/00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o
m@[eooD:m@0;ooD:m@03o`000?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
n`Ck00?o0000onTFjOoY5^T03?oY5^T00ol0003ohQgRon8MhP0;on8MhP03o`000?oC;=?odbcC00?o
dbcC00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003o_T6no`00000=ojaC[003o`000?oN8MkogR7N00So
gR7N00?o0000ooD:mOoe2_D03?oe2_D3o`0000Goo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ok1?_on`Ck00con`Ck00?o0000onTFjOoY5^T03?oY5^T00ol0003ohQgRon8MhP0:on8MhP03o`00
0?oC;=?odbcC00GodbcC00?o0000ojaC[?n/Dj`02_n/Dj`01?l0003o_T6noki1__nn@Kh2o`0000[o
[5>/00?o0000omhQg_oN8Mh02OoN8Mh00ol0003om@[eooD:m@0<ooD:m@03o`000?om0_goo@;m00?o
000000?oo@;mo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onTFjOoY5^T0
3?oY5^T00ol0003ohQgRon8MhP09on8MhP03o`000?oC;=?odbcC00KodbcC00?o0000ojaC[?n/Dj`0
2On/Dj`00ol0003o_T6noki1_P02oki1_P03o`000?oF:MKo000000;o00001on/Dj`00ol0003ogR7N
omhQgP09omhQgP03o`000?oe2_Gom@[e00_om@[e00?o0000ood2oOom0_d01?om0_d00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000oo/4nook1?/02ook1?/00ol0003ojAKYonTFj@0;onTFj@03o`000?oR
7N;ohQgR00SohQgR00?o0000om</dooC;=<01ooC;=<00ol0003o[5>/ojaC[008ojaC[003o`000?nn
@Kko_T6n00?o_T6n00?o0000omHYe_oF:MH00_oF:MH2o`0000Co[5>/00?o0000omhQg_oN8Mh02_oN
8Mh00ol0003om@[eooD:m@0:ooD:m@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?ok1?_on`Ck00[on`Ck0ol0000;onTFj@Ko00001?oR7N800ol0003odbcCom</d`08
om</d`03o`000?n/Djco[5>/00Oo[5>/00?o0000oki1__nn@Kh00onn@Kh00ol0003oeRWFomHYeP05
omHYeP?o000000?o[5>/o`000?oN8Mh02ooN8Mh00ol0003om@[eooD:m@09ooD:m@03o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00?o0000ooP7
n?oh1oP01?l00006onTFj@03o`000?o/4ncok1?/00Cok1?/1?l0000<om</d`03o`000?n/Djco[5>/
00Go[5>/00?o0000oki1__nn@Kh01?nn@Kh00ol0003oeRWFomHYeP08omHYeP03o`000?oN8MkogR7N
00_ogR7N00?o0000ooD:mOoe2_D02?oe2_D00ol0003oo@;mood2o@08ood2o@Go00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?ok1?_on`Ck00Oon`Ck00?o0000ooP7n?oh1oP01Ooh1oP3o`0000;ojAKY00?o0000on`Ck?o/
4n`02?o/4n`00ol0003odbcCom</d`0:om</d`03o`000?n/Djco[5>/00Co[5>/00?o0000oki1__nn
@Kh01Onn@Kh00ol0003oeRWFomHYeP08omHYeP03o`000?oN8MkogR7N00WogR7N1?l00008ooD:m@03
o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh0_l0000<on`Ck003o`000?oC;=?odbcC00WodbcC
00?o0000ojaC[?n/Dj`00on/Dj`00ol0003o_T6noki1_P05oki1_P03o`000?oF:MKoeRWF00[oeRWF
00?o0000omhQg_oN8Mh01?oN8Mh4o`0000Col`cc00?o0000ooD:mOoe2_D01?oe2_D00ol0003oo@;m
ood2o@0:ood2o@03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7n?oh1oP02ooh
1oP00ol0003ok1?/on`Ck00:on`Ck003o`000?oC;=?odbcC00WodbcC00?o0000ojaC[?n/Dj`00_n/
Dj`00ol0003o_T6noki1_P06oki1_P03o`000?oF:MKoeRWF00[oeRWF00?o0000omhQg_oN8Mh01?l0
0009oo<<l`Ko00003?om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000oo/4nook1?_on`Ck0_l0
000=ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000om</dooC;=<02OoC;=<01Ol0003o[5>/ojaC
[?n/Djco000000Wo_T6n00?o0000omHYe_oF:MH02ooF:MH2o`0000gol`cc00?o0000oo`3o?ol0o`0
0_ol0o`00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Cko`00
0002ooh1oP;o00002ooh1oP00ol0003ok1?/on`Ck00;on`Ck003o`000?oC;=?odbcC00WodbcC00?o
0000ojaC[?l000002Onn@Kh00ol0003oeRWFomHYeP0<omHYeP03o`000?oc3??ol`cc00col`cc00?o
0000oo`3o?ol0o`00ool0o`00ol0003oo@;mood2o@09ood2o@03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oh1oP00ol0003ok1?/on`Ck00:on`Ck003o`000?oC;=?o
dbcC00SodbcC1Ol00008oki1_P03o`000?oF:MKoeRWF00coeRWF00?o0000oo<<looc3?<02ooc3?<0
0ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001oon0Oh2o`0000Son0Oh00?o0000on`Ck?o/4n`02_o/4n`00ol0003odbcCom</d`07om</
d`03o`000?oK9=_ofbCK00?ofbCK0ol00005oki1_P03o`000?oF:MKoeRWF00_oeRWF00?o0000oo<<
looc3?<03?oc3?<00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?oo0?oo000000WooP7n00?o0000ooP7n?oh1oP01Ooh1oP2o`0000co
k1?/00?o0000om</dooC;=<01OoC;=<00ol0003ofbCKom/Tf`07om/Tf`?o000000?o_T6no`000?oF
:MH03OoF:MH00ol0003ol`ccoo<<l`0<oo<<l`03o`000?ol0ocoo0?l00Koo0?l00?o0000ood2oOom
0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooP7n003o`000?oj1O[onPGj00;o00002_o/4n`00ol0003odbcCom</d`03om</d`;o0000
3OoK9=/2o`0000goeRWF0ol0000=oo<<l`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d0
1Oom0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooh1oSo0000ooX5nP04ooX5nP03o`000?o/4ncok1?/00Ook1?/00Co0000om</dooC;=?odbcC
0_l00002onl@k`03o`000?oK9=_ofbCK00cofbCK3Ol00003ooD:m@03o`000?oc3??ol`cc00[ol`cc
00?o0000oo`3o?ol0o`02?ol0o`01?l0003oo@;mood2oOom0_d4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj0_l00008on`Ck003o`000?oC;=?o000000Goka3_
00?o0000om/TfooK9=/02ooK9=/00ol0003ohacSon<Lh`09on<Lh`03o`000?oe2_Gom@[e00;om@[e
0_l00009oo<<l`03o`000?ol0ocoo0?l00[oo0?l0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX01ooj1OX4o`0000?ok1?/0ol0
0007onl@k`03o`000?oK9=_ofbCK00[ofbCK00?o0000on<LhooS7><02OoS7><00ol0003om@[eooD:
m@04ooD:m@;o00001ooc3?<00ol0003oo0?loo`3o00:oo`3o003o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj1OX02?oj1OX0
1?l0003onPGjooX5n_oj1OX3o`0000;omPWf00?o0000onl@koo_4>l01_o_4>l00ol0003ofbCKom/T
f`08om/Tf`03o`000?oS7>?ohacS00[ohacS00?o0000ooD:mOoe2_D01_oe2_D00ol0003ol`ccoo<<
l`04oo<<l`03o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[o
nPGj00ConPGj00Go0000ooH9m_of2OKomPWfo`000008onl@k`03o`000?oK9=_ofbCK00OofbCK00?o
0000on<LhooS7><02_oS7><00ol0003om@[eooD:m@07ooD:m@;o00001?oc3?<00ol0003oo0?loo`3
o008oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj00ConPGj00?o0000ooH9m_of2OH00_of2OH0
0ol0003oka3_onl@k`07onl@k`03o`000?oK9=_ofbCK00KofbCK00?o0000on<LhooS7><02_oS7><0
0ol0003om@[eooD:m@09ooD:m@05o`000?oc3??ol`ccoo<<lol000002Ool0o`00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_onPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003omPWfooH9mP03
ooH9mP03o`000?o_4>ooka3_00Ooka3_00?o0000om/TfooK9=/01OoK9=/00ol0003ohacSon<Lh`0:
on<Lh`03o`000?oe2_Gom@[e00Wom@[e1?l00009oo`3o003o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?of2OKomPWf00?omPWf00?o0000
onl@koo_4>l02?o_4>l00ol0003ofbCKom/Tf`04om/Tf`03o`000?oS7>?ohacS00WohacS00?o0000
ooD:mOoe2_D02?oe2_D2o`0000?oo@;m00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oj1O[onPGj
00GonPGj00?o0000ooH9m_of2OH01?of2OH00ol0003oka3_onl@k`09onl@k`03o`000?oK9=_ofbCK
00;ofbCK00?o0000on<LhooS7><02_oS7><00ol0003om@[eooD:m@06ooD:m@;o00001_om0_d8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX01Ooj1OX00ol0003omPWfooH9mP05ooH9mP03o`000?o_4>ooka3_00Woka3_00Go0000om/TfooK
9=_ofbCKo`00000<on<Lh`03o`000?oe2_Gom@[e00Com@[e0_l00008ood2o@03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?of2OKomPWf00GomPWf00?o0000onl@koo_
4>l02_o_4>l00ol0003ofbCKo`000004o`0000WohacS00?o0000ooD:mOoe2_D00_oe2_D2o`0000[o
o@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003omPWfooH9mP07ooH9mP;o0000
2oo_4>l00ol0003om`SgooL8m`03ooL8m`Oo00000_oS7><00ol0003om@[eooD:m@02o`0000_oo@;m
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003onPGjooX5n_oj1O[o000000SonPGj00?o0000ooH9m_of2OH01oof2OH00ol0003on`Ck
o`000002o`0000Soka3_00?o0000ooL8moog2?L02_og2?L5o`0000goo@;m00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?oj1O[o000000WonPGj00?o
0000ooH9m_of2OH01_of2OH00ol0003on`Ckoo/4n`03oo/4n`?o00001?o_4>l00ol0003om`SgooL8
m`0=ooL8m`03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003omPWfooH9mP07
ooH9mP03o`000?ok1?_on`Ck00Kon`Ck0ol000000oo_4>oo0000ooL8m`0>ooL8m`03o`000?om0_go
o@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?oj1O[onPGj00;onPGj1_l00008ooH9mP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8
moog2?L03oog2?L00ol0003oo@;mood2o@0:ood2o@;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_ol0o`00ol0003omPWfooH9mP05ooH9mP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000ooL8moog2?L03oog2?L00ol0003oo@;mood2o@07ood2o@?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?ol0ocoo0?l00Woo0?l00?o0000ooH9m_of
2OH00oof2OH00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00oom`Sg00?o0000ood2oOom
0_d01Oom0_d2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Ool0o`00ol0003omPWfooH9mP02ooH9mP03o`000?ok1?_on`Ck00_on`Ck5?l00004ood2o@;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>oo`3o004o`000?of2OKomPWfo`0000kon`Ck
00?o0000ood2oOom0_d04?om0_d00ol0003oo@;mo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_ol0o`00ol0003omPWfo`00000>oo/4n`03o`00
0?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?ok1?_on`Ck00Won`Ck1Ol0
000Bood2o@;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo0?loo`3o00<oo`3o003o`000?ok1?_on`Ck00;on`Ck1ol00004ooh1oP03o`000?om0_go
o@;m00ooo@;m00?o0000ooh1o_l000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?ol0ocoo0?l00coo0?l1?l0000<ooh1oP03o`000?om0_goo@;m00coo@;m0_l00003ooh1
oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00_o
o@;m00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?on0OkooP7n00kooP7n00?o0000ood2oOom
0_d02Oom0_d2o`0000OooP7n00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?om0_goo@;m00Koo@;m0_l0000:ooh1oP03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aooh1oP?o00001_om0_d00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000oom0_d2o`0000kooP7n00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ood2oOl000004Oon0Oh00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n013ooP7n00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?on0OkooP7n013ooP7n00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003ooP7nooh1oP0?ooh1oP03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh02oon0Oh2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003ooP7nooh1oP09ooh1oP;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ooh1oP;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool01?l00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l2oooo00?o003o0_ooo`02o`00o`?oool00ol0
0?l2oooo00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Go003o00?oool0o`00ool00?l01ol00?l2
oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo0007o`00o`;oool01Ol00?l2oooo
00Wo003o00?oool0o`00ool00?l00ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`001_l00?l2oooo00Ko
003o0_ooo`09o`00o`;oool01?l00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00
ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00Wo003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`09o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool01_l00?l2oooo00Go003o0oooo`08o`00o`?oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool01_l00?l3oooo00?o003o0oooo`08o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0006o`00o`;oool000?o003ooooo0?ooo`000ooo
o`06o`00o`Goool01Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool01ol00?l00oooo`3o003oo`00o`0<o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00
o`03oooo0?l00?oo003o01Oo003o0_ooo`07o`00o`;oool03_l00?l2oooo00Go003o0_ooo`06o`00
o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o
003oo`00o`0Go`00o`;oool02?l00?l00oooo`3o003oo`00o`0=o`00o`;oool01?l00?l2oooo00Ko
003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1_l00?l2oooo01So003o0_ooo`08o`00o`;oool01ol00?l00oooo`3o003oo`00o`04o`00o`;oool0
1Ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_oo
o`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`06o`00o`;oool01_l0
0?l00oooo`3o003oo`00o`04o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?oo
o`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0F
o`00o`Goool02?l00?l2oooo00Go003o0_ooo`03o`00o`;oool01ol00?l2oooo00;o003o0_ooo`05
o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo
02Go003o0oooo`04o`00o`Coool02Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00
ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(640) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.997 .003 .997 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.997 .003 .997 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.992 .008 .992 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.992 .008 .992 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.987 .013 .987 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.981 .019 .981 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.981 .019 .981 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.952 .048 .952 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.962 .038 .962 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.915 .085 .915 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.975 .025 .975 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.991 .009 .991 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.838 .162 .838 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.978 .022 .978 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.951 .049 .951 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.948 .052 .948 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.958 .042 .958 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.967 .033 .967 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.983 .017 .983 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.932 .068 .932 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.968 .032 .968 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.89 .11 .89 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.98 .02 .98 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.963 .037 .963 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.939 .061 .939 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.964 .036 .964 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.852 .148 .852 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.974 .026 .974 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.94 .06 .94 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.98 .02 .98 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.891 .109 .891 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.65 .35 .65 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.718 .282 .718 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.993 .007 .993 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.97 .03 .97 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.91 .09 .91 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.919 .081 .919 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.669 .331 .669 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.633 .367 .633 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.59 .41 .59 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.898 .102 .898 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.915 .085 .915 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.997 .003 .997 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.895 .105 .895 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.842 .158 .842 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.751 .249 .751 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.979 .021 .979 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.953 .047 .953 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.68 .32 .68 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.618 .382 .618 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.847 .153 .847 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.351 .649 .351 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.346 .654 .346 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.388 .612 .388 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.743 .257 .743 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.741 .259 .741 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.978 .022 .978 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.344 .656 .344 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.318 .682 .318 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.925 .075 .925 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.528 .472 .528 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.636 .364 .636 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.886 .114 .886 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.874 .126 .874 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.561 .439 .561 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.846 .154 .846 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.283 .717 .283 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.754 .246 .754 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.627 .373 .627 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.079 .921 .079 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.253 .747 .253 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.965 .035 .965 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.139 .861 .139 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.115 .885 .115 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.831 .169 .831 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.968 .032 .968 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.372 .628 .372 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.091 .909 .091 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.156 .844 .156 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.716 .284 .716 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.238 .762 .238 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.433 .567 .433 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.108 .892 .108 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.076 .924 .076 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.258 .742 .258 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.427 .573 .427 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.938 .062 .938 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.455 .545 .455 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.522 .478 .522 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.011 .989 .011 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.052 .948 .052 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.075 .925 .075 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.681 .319 .681 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.86 .14 .86 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.996 .004 .996 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.907 .093 .907 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.333 .667 .333 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.091 .909 .091 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.751 .249 .751 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.99 .01 .99 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.105 .895 .105 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.315 .685 .315 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.026 .974 .026 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.203 .797 .203 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.794 .206 .794 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.295 .705 .295 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.058 .942 .058 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.968 .032 .968 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.99 .01 .99 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.841 .159 .841 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.891 .109 .891 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.159 .841 .159 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.958 .042 .958 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.534 .466 .534 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.533 .467 .533 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.022 .978 .022 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.166 .834 .166 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.42 .58 .42 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.679 .321 .679 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.032 .968 .032 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.978 .022 .978 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.152 .848 .152 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.154 .846 .154 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.96 .04 .96 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.402 .598 .402 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.989 .011 .989 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.29 .71 .29 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.206 .794 .206 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.196 .804 .196 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.871 .129 .871 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.852 .148 .852 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.833 .167 .833 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.105 .895 .105 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.447 .553 .447 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.607 .393 .607 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.814 .186 .814 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.952 .048 .952 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.986 .014 .986 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.399 .601 .399 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.677 .323 .677 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.277 .723 .277 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.935 .065 .935 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.916 .084 .916 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.816 .184 .816 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.961 .039 .961 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.988 .012 .988 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.384 .616 .384 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.512 .488 .512 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.981 .019 .981 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.376 .624 .376 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.869 .131 .869 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.623 .377 .623 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.763 .237 .763 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.53 .47 .53 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.967 .033 .967 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.954 .046 .954 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.96 .04 .96 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.974 .026 .974 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.69 .31 .69 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.991 .009 .991 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.933 .067 .933 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.6 .4 .6 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.655 .345 .655 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.811 .189 .811 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.805 .195 .805 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.989 .011 .989 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.937 .063 .937 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.987 .013 .987 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.716 .284 .716 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.975 .025 .975 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.922 .078 .922 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.894 .106 .894 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.874 .126 .874 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.807 .193 .807 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.845 .155 .845 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.761 .239 .761 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.878 .122 .878 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.937 .063 .937 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.966 .034 .966 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.947 .053 .947 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.958 .042 .958 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.974 .026 .974 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.938 .062 .938 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.837 .163 .837 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.929 .071 .929 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.957 .043 .957 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.976 .024 .976 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.972 .028 .972 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.977 .023 .977 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.951 .049 .951 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.989 .011 .989 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.995 .005 .995 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.991 .009 .991 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.981 .019 .981 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.957 .043 .957 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.989 .011 .989 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.973 .027 .973 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.98 .02 .98 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.984 .016 .984 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003ooP7nooh1oP05ooh1oPGo0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001oon0Oh3o`000003o`00ool0003ooP7n00kooP7n00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?on0OkooP7n00gooP7n00?o0000ooh1
o_on0Oh03oon0Oh01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooh1oP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n013ooP7n0ol00005ooh1oP03o`000?l00?oo000000;o00002_on0Oh2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003ooP7nooh1oP0?ooh1oP03
o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0<ooh1oP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?ooP7n0_l0000@ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ooh1oP?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?oo0?ooo`3oool0ool000004Oon
0Oh01?l0003oo0?loo`3o?l0000>ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh0
3_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ooh1oP?o000000?o003oo`000?on0Oh03oon0Oh00ol0003oo`3oool0o`02ool0o`03o`000?on
0OkooP7n00gooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0;ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000
ool0oooo0?l01?oo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00?oo0?l00?o0000
ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00oooP7n00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?on0OkooP7n
00kooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n
00[ooP7n00?o0000oo`3o?ol0o`01Ool0o`00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00_ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o006oo`3o003
o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0@ooh1oP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003ooP7n
ooh1oP0>ooh1oP;o00004?on0Oh00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n
00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00cooP7n
00?o0000ooh1o_on0Oh04?on0Oh<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_go0000013ooP7n00?o0000ool0oooo0?l02?oo
0?l9o`0000coo0?l00Co0000ooh1o_on0OkooP7n0ol0000@ooh1oP03o`000?on0OkooP7n00oooP7n
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?on0OkooP7n00cooP7n0_l00003ood2o@03o`000?on
0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003onPGjooX5nP05ooX5nP03o`000?ol
0ocoo0?l00_oo0?l0ol00003oo/4n`03o`000?on0OkooP7n00cooP7n0ol0000>ooh1oP;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000kooP7n00?o0000
ood2oOom0_d00oom0_d00ol0003ooP7nooh1oP0;ooh1oP;o00002ooo0?l00ol0003onPGjooX5nP06
ooX5nP03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oi1_Won@KiooT6n@;o00002_on0Oh2o`000003ooT6nOl0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@05ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOl000002ooo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Wo
n@Ki00Con@Ki0_l00005ooh1oP?o00001?oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?on0OkooP7n00SooP7n0_l00008ood2o@03o`000?on0OkooP7n00OooP7n0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00Oon`Ck00?o0000ooh1o_on0Oh01Oon0Oh2o`0000Won@Ki0_l000000oon
0Oko0000o`000007ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000SooP7n00?o0000ood2oOom
0_d02?om0_d00ol0003ooP7nooh1oP06ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003onPGjooX5nP08ooX5nP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?lo`000005ooh1oP;o00002oom0_d2o`0000KooP7n
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oj1O[onPGj00SonPGj
00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`0;oo/4n`05o`000?on0OkooP7nooh1o_l0
00003_oi1_T00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?ol0ocoo0?loo`3o?l0
00000oon0Oh00ol0003oo@;mood2o@0:ood2o@04o`000?og2?Oom`Sgo`0000?ooP7n0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo0?loo`3o005oo`3
o003o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_l000003ooi1_T00ol0003on@KiooT6n@08ooT6
n@03o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o003oo`3o003o`000?on0Oko000000_o
o@;m0_l00004ooL8m`03o`000?on0Oko000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP09ooX5nP03o`000?ol0ocoo0?l00Coo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003o
n@KiooT6n@0>ooT6n@03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000oo`3o?ol0o`0
1?ol0o`00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00Gom`Sg00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oj1O[onPGj00[onPGj00?o0000oo`3o?ol0o`0
0ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oi1_Won@Ki00gon@Ki00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3
o005oo`3o003o`000?om0_goo@;m00Ooo@;m0_l00008ooL8m`03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003onPGjooX5nP0:ooX5nP04o`000?ol0ocoo0?loo`3o0?o0000
3ook1?/00ol0003on@KiooT6n@0>ooT6n@03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d01?om0_d2o`0000_om`Sg1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02ooj1OX01?l0003oo0?lo`00
0?l00003onl@k`;o00003?ok1?/2o`00013on@Ki00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo0?l
oo`3o007oo`3o003o`000?om0_goo@;m00?oo@;m00?o0000ooL8moog2?L02oog2?L01?l0003oj1OX
onPGj?oX5nP5o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003onPGjooX5nP0<ooX5nP03
o`000?o_4>ooka3_00Goka3_0_l00008oo/4n`;o00000_o^4Nh00ol0003on@KiooT6n@0=ooT6n@03
o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o009oo`3o003o`000?om0_goo@;m00;o0000
3Oog2?L00ol0003oj1OXonPGj007onPGj0Ko00000_oo0?l4o`0000gonPGj00?o0000onl@koo_4>l0
1oo_4>l2o`0000Gon`Ck00?o0000onhAk_o^4Nh00oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`00
0?oi1_Won@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Woo0?l00?o
0000ood2oOl000003oog2?L00ol0003oj1OXonPGj00<onPGj0?o00001?oe2_D3o`0000WonPGj00?o
0000onl@koo_4>l02_o_4>l2o`000003oo/4nol0003o000000OokQ7^00?o0000ooT6nOoi1_T02ooi
1_T00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00KooP7n1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000
ooL8moog2?L03_og2?L00ol0003oj1OXonPGj00=onPGj003o`000?oe2_Gom@[e00Kom@[e0ol00005
ooX5nP03o`000?o_4>ooka3_00goka3_00?o0000onhAk_o^4Nh02?o^4Nh00ol0003on@KiooT6n@09
ooT6n@03o`000?oi1_Won@Ki00gon@Ki00Co0000ooh1o_on0OkooP7n1Ol00003oo/4n`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
oo`3o?ol0o`02ool0o`2o`0000oom`Sg00?o0000onPGj?oX5nP03OoX5nP00ol0003om@[eooD:m@0:
ooD:m@?o000000?onPGjo`000?o_4>l03oo_4>l00ol0003okQ7^onhAkP09onhAkP03o`000?oi1_Wo
n@Ki00Son@Ki00?o0000ooT6nOoi1_T03_oi1_T3o`0000Son`Ck00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?ol0ocoo0?l00Soo0?l0ol000000ooc
3??o0000ooL8m`0>ooL8m`03o`000?oX5nSoj1OX00goj1OX00?o0000ooD:mOoe2_D03Ooe2_D00ol0
003oka3_onl@k`0?onl@k`03o`000?o^4NkokQ7^00[okQ7^2ol0000;ooT6n@Go00003?ok1?/00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003onPGjo`000?oo0?oo0000
00Soo0?l0ol00005oo<<l`03o`000?og2?Oom`Sg00com`Sg00?o0000onPGj?oX5nP03OoX5nP00ol0
003om@[eooD:m@0=ooD:m@;o00004?o_4>l00ol0003okQ7^onhAkP0:onhAkP03o`000?o/4ncok1?/
00Ook1?/00?o0000ooT6nOoi1_T00_oi1_T7o`0000Col0o`00?o0000oo/4nook1?/02_ok1?/00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003onPGjooX5n_oj1OX2o`00
00Goo0?l0ol00009oo<<l`;o00002oog2?L00ol0003oj1OXonPGj00=onPGj003o`000?oe2_Gom@[e
00gom@[e00Co0000omXUf_oJ9M[o00003oo_4>l00ol0003okQ7^onhAkP09onhAkP03o`000?o/4nco
k1?/00Wok1?/1?l0000;oo0?l003o`000?ok1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooX5n_oj1OX01?oj1OX00ol0003oo0?lo`000002o`00
00col`cc00Co0000omlPgol0003o00002Oog2?L00ol0003oj1OXonPGj00=onPGj003o`000?oe2_Go
m@[e00gom@[e00Go0000omXUf_oJ9M[ofRGJo`00000=onl@k`03o`000?o^4NkokQ7^00[okQ7^00?o
0000on`Ck?o/4n`02Oo/4n`00ol0003ol0o`oo0?l00<oo0?l003o`000?ok1?_on`Ck00[on`Ck00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01_oj1OX0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?oO8=oogb3O00;ogb3O0_l00007ooL8m`03o`000?oX5nSo
j1OX00coj1OX00?o0000ooD:mOoe2_D03Ooe2_D00ol0003ofRGJomXUfP03omXUfP03o`000?o_4>oo
ka3_00[oka3_00?o0000onhAk_o^4Nh02_o^4Nh00ol0003ok1?/on`Ck009on`Ck003o`000?o`3o3o
l0o`00col0o`00?o0000oo/4nook1?/02ook1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?oc3??ol`cc00_ol`cc00?o0000omlP
gooO8=l01OoO8=l00ol0003om`SgooL8m`03ooL8m`03o`000?oX5nSoj1OX00goj1OX00?o0000ooD:
mOoe2_D03Ooe2_D00ol0003ofRGJomXUfP04omXUfP03o`000?o_4>ooka3_00Woka3_00?o0000onhA
k_o^4Nh02Oo^4Nh00ol0003ok1?/on`Ck00:on`Ck003o`000?o`3o3ol0o`00col0o`00?o0000oo/4
nook1?/02ook1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP07ooX5nP03o`000?oc3??ol`cc00_ol`cc00?o0000omlPgooO8=l01_oO8=l2o`0000?o
m`Sg00?o0000onPGj?oX5nP03OoX5nP00ol0003om@[eooD:m@0<ooD:m@03o`000?oJ9M[ofRGJ00Ko
fRGJ00?o0000onl@koo_4>l02?o_4>l00ol0003okQ7^onhAkP09onhAkP03o`000?o/4ncok1?/00[o
k1?/00?o0000oo0?l?o`3o003?o`3o000ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ooX5n_oj1OX02?oj1OX00ol0003ol`ccoo<<l`0:oo<<l`03o`00
0?oO8=oogb3O00Wogb3O0_l000000oog2?Oo0000onPGj00<onPGj0?o00003_oe2_D00ol0003ofRGJ
omXUfP07omXUfP03o`000?o_4>ooka3_00Ooka3_00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003ok1?/
on`Ck00;on`Ck003o`000?o`3o3ol0o`00col0o`00?o0000oo/4nook1?/02_ok1?/00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02_oj1OX00ol0003ol`ccoo<<
l`09oo<<l`03o`000?oO8=oogb3O00_ogb3O00?o0000onPGj?oX5nP02_oX5nP2o`0000?obcC;00?o
0000ooD:mOoe2_D02_oe2_D00ol0003ofRGJomXUfP09omXUfP03o`000?o_4>ooka3_00Koka3_00?o
0000onhAk_o^4Nh02?o^4Nh00ol0003ok1?/on`Ck00<on`Ck003o`000?o`3o3ol0o`00col0o`00?o
0000oo/4nook1?/02_ok1?/00ol0003oo`3oool0o`04ool0o`Co00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?oj1O[onPGj00_onPGj00?o0000oo<<looc3?<02?oc3?<0
0ol0003ogb3OomlPg`0<omlPg`03o`000?oX5nSoj1OX00Soj1OX0_l00006ol/db`;o00002_oe2_D0
0ol0003ofRGJomXUfP0:omXUfP03o`000?o_4>ooka3_00Goka3_00?o0000onhAk_o^4Nh02?o^4Nh0
0ol0003ok1?/on`Ck00<on`Ck003o`000?o`3o3ol0o`00col0o`00?o0000oo/4nook1?/02ook1?/0
0ol0003oo`3oo`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ooX5nP03o`000?oc3??ol`cc00Ool`cc00?o0000omlPgooO8=l03_oO8=l00ol0003oj1OXonPGj004
onPGj0?o00002_o;=</00ol0003om@[eooD:m@07ooD:m@03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000
onl@koo_4>l00oo_4>l00ol0003okQ7^onhAkP09onhAkP03o`000?o/4ncok1?/00cok1?/00?o0000
oo0?l?o`3o003?o`3o000ol0003on`Ckoo/4n`0;oo/4n`;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003onPGjooX5nP0<ooX5nP03o`000?oc3??ol`cc00Ool`cc00?o0000omlPgooO8=l03ooO8=l01?l0
003oj1OXonPGj?oX5nP2o`0000kobcC;0_l00006ooD:m@03o`000?oJ9M[ofRGJ00gofRGJ00?o0000
onl@koo_4>l00_o_4>l00ol0003okQ7^onhAkP08onhAkP03o`000?o/4ncok1?/00cok1?/0ol0000=
oo0?l003o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00oonPGj00?o0000oo<<looc3?<01_oc3?<00ol0003ogb3OomlPg`0@omlPg`Co00004_o;=</00ol0
003om@[eooD:m@03ooD:m@03o`000?oJ9M[ofRGJ00kofRGJ00Go0000onl@koo_4>ooka3_o`000005
onhAkPOo00003?o/4n`01Ol0003oh1oPon0Oh?oP7n3o000000col0o`00?o0000oo/4nook1?/02?ok
1?/3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000oonPGj00?o0000oo<<looc3?<01_oc3?<00ol0003ogb3OomlPg`0=
omlPg`?o000000Co`Ck1o`000?l0003o00004oo;=</2o`0000;om@[e00?o0000omXUf_oJ9MX04?oJ
9MX00ol0003oka3_o`000006o`0000Oocc3?00?o0000on`Ck?o/4n`02?o/4n`00ol0003oh1oPon0O
h003on0Oh0;o00002?o`3o03o`0000Kon`Ck1?l00002ooT6n@03o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003oo@;mo`000?o`3o03o`0000gonPGj00?o0000oo<<looc3?<01?oc3?<00ol0003ogb3OomlP
g`0;omlPg`?o00000oo1?/401Ol0003o]dRgo`000?n5NXGo000001CobcC;00?o0000ooD:mOl00000
4ooJ9MX00ol0003occ3?oll`c`0=oll`c`03o`000?o/4ncok1?/00Gok1?/0_l00008on0Oh003o`00
0?o`3o3ol0o`00Go00000oo]4^d00ol0003on`Ckoo/4n`03o`0000Oon@Ki00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?om0_goo@;mo`0000Col0o`0ol0000:ooX5nP03o`000?oc3??ol`cc00?ol`cc
00?o0000omlPgooO8=l02OoO8=l3o`0000Go`Ck100Co0000okM8]ongB;Oo00000_n5NXD00ol0003o
bcC;ol/db`0Bol/db`03o`000?oJ9M[ofRGJ01;ofRGJ00?o0000oll`coo?<<l03_o?<<l00ol0003o
k1?/on`Ck003on`Ck003o`000?oP7n3oh1oP00Woh1oP0_l00009ondBk@;o00002_oi1_T00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ood2oOom0_goo@;mo`000007oo0?l0;o00001ooj1OX5o`0000;o
l`cc00?o0000omlPgooO8=l01_oO8=l3o`0000So`Ck100Co0000okM8]ongB;Oo00000on5NXD00ol0
003obcC;ol/db`0Aol/db`03o`000?oJ9M[ofRGJ017ofRGJ00?o0000oll`coo?<<l04?o?<<l01Ol0
003ok1?/on`Ck?o/4nco000000coh1oP00?o0000ondBkOo]4^d02?o]4^d00ol0003on@KiooT6n@0:
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000Coo@;m00?o0000oo0?l?o`3o001oo`3o03o`00
0004ooX5n_l0003o0000o`0000GoiA[U0_l00006omlPg`?o00002_o1?/401Ol0003o]dRgokM8]ong
B;Oo000000CoQGZ500?o0000ol/dboo;=</04?o;=</00ol0003ofRGJomXUfP0AomXUfP03o`000?o?
<<oocc3?017occ3?00?o0000on`Ck?l000003OoP7n000ol0003okA;]ondBk@08ondBk@03o`000?oi
1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000
oo0?l?o`3o002_o`3o000ol0003oiA[UonDJi@08onDJi@03o`000?oO8=oogb3O00?o00003Oo1?/40
1Ol0003o]dRgokM8]ongB;Oo000000GoQGZ500?o0000ol/dboo;=</03oo;=</00ol0003ofRGJomXU
fP0AomXUfP03o`000?o?<<oocc3?01;occ3?00?o0000on0Oh?oP7n003?oP7n000ol0003okA;]ondB
k@08ondBk@03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ood2oOom0_d01Oom0_d0
0ol0003ol0o`oo0?l00:oo0?l003o`000?oU6^GoiA[U00WoiA[U0_l0000?ol4n`@03o`000?ngB;Oo
]dRg00;o]dRg00?o0000ohEjQOn5NXD01?n5NXD00ol0003obcC;ol/db`0=ol/db`?o00004OoJ9MX0
0ol0003occ3?oll`c`0Coll`c`03o`000?oP7n3oh1oP00_oh1oP00?o0000ondBkOo]4^d02Oo]4^d0
0ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ool0o`;o00002?om0_d0
0ol0003ol0o`oo0?l00:oo0?l003o`000?oU6^GoiA[U00WoiA[U00?o0000ol4n`Oo1?/403Oo1?/40
0ol0003o]dRgokM8]`03okM8]`03o`000?n5NXGoQGZ500GoQGZ500?o0000ol/dboo;=</02_o;=</2
o`0000?oR7N800?o0000omXUf_oJ9MX03_oJ9MX00ol0003occ3?oll`c`0Coll`c`03o`000?oP7n3o
h1oP00_oh1oP00?o0000ondBkOo]4^d02Oo]4^d00ol0003on@KiooT6n@0;ooT6n@03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000Goo`3o00?o0000ood2oOom0_d01oom0_d2o`0000_ol0o`00?o0000onDJ
iOoU6^D02ooU6^D00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?ngB;Oo]dRg00?o]dRg00?o0000ohEj
QOn5NXD01_n5NXD00ol0003obcC;ol/db`07ol/db`;o00001_n8MhP2o`0000kofRGJ00?o0000oll`
coo?<<l04oo?<<l00ol0003oh1oPon0Oh00;on0Oh003o`000?o]4^gokA;]00WokA;]00?o0000ooT6
nOoi1_T03?oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ool0oooo0?ooo`3oo`000009ood2
o@03o`000?oj1O[o000000_ol0o`00?o0000onDJiOoU6^D02ooU6^D00ol0003o`Ck1ol4n`@0;ol4n
`@03o`000?ngB;Oo]dRg00Co]dRg00?o0000ohEjQOn5NXD01on5NXD00ol0003obcC;ol/db`05ol/d
b`03o`000?n8MhSoR7N800SoR7N800?o0000omXUf_oJ9MX02_oJ9MX00ol0003occ3?oll`c`0Doll`
c`03o`000?oP7n3oh1oP00_oh1oP00?o0000ondBkOo]4^d02Oo]4^d00ol0003on@KiooT6n@0<ooT6
n@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oo`000009ood2o@04o`000?oj1O[onPGjo`00
00_ol0o`00?o0000onDJiOoU6^D02ooU6^D00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?ngB;Oo]dRg
00Co]dRg00?o0000ohEjQOn5NXD02?n5NXD00ol0003obcC;ol/db`02ol/db`;o00003?n8MhP2o`00
00[ofRGJ00?o0000oll`coo?<<l05?o?<<l00ol0003oh1oPon0Oh00;on0Oh003o`000?o]4^gokA;]
00WokA;]00?o0000ooT6nOoi1_T03Ooi1_T00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03
o`000?oj1O[onPGj00;onPGj00?o0000oo0?l?o`3o002?o`3o000ol0003oiA[UonDJi@0<onDJi@03
o`000?o1?/7o`Ck100Wo`Ck100?o0000okM8]ongB;L01OngB;L00ol0003oQGZ5ohEjQ@09ohEjQ@04
o`000?o;=<_o0000o`00013oR7N80_l00008omXUfP03o`000?o?<<oocc3?01Cocc3?0ol0000;on0O
h003o`000?o]4^gokA;]00WokA;]00?o0000ooT6nOoi1_T03Ooi1_T01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000oo0?
l?o`3o002?o`3o000ol0003oiA[UonDJi@0;onDJi@;o00002_o1?/400ol0003o]dRgokM8]`06okM8
]`03o`000?n5NXGoQGZ500[oQGZ500?o0000ohQgR?n8MhP04_n8MhP00ol0003ofRGJomXUfP04omXU
fP03o`000?o?<<oocc3?01Gocc3?00?o0000ol8m`_o2?L801Ol00005on0Oh003o`000?o]4^gokA;]
00[okA;]00?o0000ooT6nOoi1_T03_oi1_T3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@04ood2o@03
o`000?oj1O[onPGj00ConPGj00?o0000oo0?l?o`3o001oo`3o000ol0003oiA[UonDJi@0;onDJi@04
o`000?n^DJko[U6^o`0000Wo`Ck100?o0000okM8]ongB;L01_ngB;L00ol0003oQGZ5ohEjQ@0:ohEj
Q@03o`000?n8MhSoR7N801?oR7N80_l00003omXUfPCo00005?o?<<l00ol0003o`Sg2ol8m`P06ol8m
`PCo000000?oh1oPo`000?o]4^d02oo]4^d00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003oo@;mood2o@03ood2o@03o`000?oj1O[onPGj00GonPGj00?o0000oo0?l?o`
3o001oo`3o000ol0003oiA[UonDJi@09onDJi@;o00001?n^DJh00ol0003o`Ck1ol4n`@05ol4n`@03
o`000?ngB;Oo]dRg00Oo]dRg00?o0000ohEjQOn5NXD02_n5NXD00ol0003oR7N8ohQgR00EohQgR003
o`000?oJ9M[o000000CoWf2O0ol0000@oll`c`03o`000?o2?L;o`Sg200_o`Sg20_l0000<ondBk@03
o`000?oi1_Won@Ki00con@Ki0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ood2oOom0_d00_om0_d00ol0003onPGj
ooX5nP06ooX5nP03o`000?o`3o3ol0o`00Ool0o`00?o0000onDJiOoU6^D02?oU6^D00ol0003o[U6^
ojiA[P05ojiA[P03o`000?o1?/7o`Ck100Co`Ck100?o0000okM8]ongB;L01ongB;L00ol0003oQGZ5
ohEjQ@0:ohEjQ@03o`000?n8MhSoR7N801KoR7N800?o0000oimPWonOH9l01_nOH9l3o`0000cocc3?
00?o0000ol8m`_o2?L803Oo2?L800ol0003okA;]ondBk@09ondBk@Go00002Ooi1_T2o`000003oo/4
nol0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ood2oOl0003onPGj00WonPGj00?o0000oo0?l?o`3o001_o`
3o000ol0003oiA[UonDJi@07onDJi@03o`000?n^DJko[U6^00Oo[U6^00?o0000ol4n`Oo1?/400_o1
?/400ol0003o]dRgokM8]`08okM8]`03o`000?n5NXGoQGZ500WoQGZ500?o0000ohQgR?n8MhP05on8
MhP00ol0003oWf2OoimPW`09oimPW`?o00002Oo?<<l00ol0003o`Sg2ol8m`P0>ol8m`PKo00001?o]
4^d00ol0003om0_doo@;m003oo@;m0Go00000_oi1_T2o`0000Con`Ck00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?ok1?_on`Ckoo/4nol000002ooj1OX00ol0003ol0o`oo0?l006oo0?l003o`000?oU
6^GoiA[U00GoiA[U0_l0000;ojiA[P04o`000?o1?/7o`Ck1o`0000_o]dRg00?o0000ohEjQOn5NXD0
2On5NXD00ol0003oR7N8ohQgR00FohQgR003o`000?nOH9ooWf2O00goWf2O0ol00005oll`c`03o`00
0?o2?L;o`Sg200oo`Sg200?o0000omHYe_oF:MH00ooF:MH4o`0000_om0_d0_l00006oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`02oo/4n`ko00001_o`3o000ol0003oiA[UonDJ
i@05onDJi@03o`000?n^DJko[U6^00co[U6^00?o0000ol4n`Ol000002ongB;L00ol0003oQGZ5ohEj
Q@07ohEjQ@?o00006?n8MhP00ol0003oWf2OoimPW`0@oimPW`?o000000?occ3?o`000?o2?L804?o2
?L800ol0003oeRWFomHYeP07omHYeP03o`000?od2oCom0_d00[om0_d00?o0000oo/4nook1?/01Ook
1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005oo/4n`03o`000?oc3??ol`cc00_ol`cc0_l00004
oo0?l003o`000?oU6^GoiA[U00?oiA[U0_l0000@ojiA[P03o`000?ngB;Oo]dRg00[o]dRg00?o0000
ohEjQOn5NXD00on5NXD4o`0000;oEJYE00?o0000ohQgR?n8MhP05On8MhP00ol0003oWf2OoimPW`0D
oimPW`03o`000?o2?L;o`Sg2013o`Sg200?o0000omHYe_oF:MH01ooF:MH00ol0003om0_doo@;m00:
oo@;m003o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck
00Gon`Ck00?o0000oo<<looc3?<03Ooc3?<6o`0000?oiA[U00?o0000ojiA[_n^DJh04?n^DJh00ol0
003o]dRgokM8]`0:okM8]`03o`000?n5NXGo000000?o00001omEZUD00ol0003oR7N8ohQgR00DohQg
R003o`000?nOH9ooWf2O01CoWf2O00?o0000ol8m`_o2?L803oo2?L800ol0003oeRWFomHYeP08omHY
eP03o`000?od2oCom0_d00[om0_d00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oJ9M[ofRGJ00?o
fRGJ00?o0000onDJiOl000004on^DJh4o`0000Wo]dRg0_l0000<oeFZE@03o`000?n8MhSoR7N801?o
R7N800?o0000oimPWonOH9l05OnOH9l00ol0003o`Sg2ol8m`P0>ol8m`P03o`000?oF:MKoeRWF00So
eRWF00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<02ooc3?<00ol0003ofRGJomXUfP05omXUfP03o`00
0?n^DJko[U6^01;o[U6^00Co0000oenPGomOX5ooGj1O1Ol00003okM8]`03o`000?mEZUGoEJYE00go
EJYE0ol0000@ohQgR0;o00006?nOH9l00ol0003o`Sg2ol8m`P0=ol8m`P03o`000?oF:MKoeRWF00Wo
eRWF00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_on`Ck00?o0000oo<<looc3?<02_oc3?<00ol0003ofRGJomXUfP06omXUfP03o`00
0?n^DJko[U6^017o[U6^00?o0000oenPGomOX5l01omOX5l3o`00013oEJYE00?o0000obSG:?lXebP0
1Ol00009ohQgR0;o000000?oB[E:o`000?nOH9l05onOH9l00ol0003o`Sg2ol8m`P0=ol8m`P03o`00
0?oF:MKoeRWF00WoeRWF00?o0000oo@;m?od2o@02?od2o@2o`0000[on`Ck00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000oo/4nook1?/02Ook1?/00ol0003ol`ccoo<<
l`0:oo<<l`03o`000?oJ9M[ofRGJ00OofRGJ00?o0000ojiA[_n^DJh03on^DJh00ol0003oGj1OoenP
G`0:oenPG`03o`000?mEZUGoEJYE00goEJYE00?o0000obSG:?lXebP01_lXebP4o`0000CoR7N800?o
0000odZeB_m:]DX00_m:]DX00ol0003oWf2OoimPW`0FoimPW`03o`000?o2?L;o`Sg200_o`Sg200?o
0000omHYe_oF:MH02ooF:MH00ol0003om0_doo@;m006oo@;m003o`000?oj1O[o000000[on`Ck00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02?ok1?/=
o`0000[ofRGJ00?o0000ojiA[_n^DJh03on^DJh00ol0003oGj1OoenPG`0;oenPG`03o`000?mEZUGo
EJYE00coEJYE00?o0000obSG:?lXebP02_lXebP4o`0000GoB[E:00?o0000oimPWonOH9l05_nOH9l0
0ol0003o`Sg2ol8m`P0:ol8m`P03o`000?oF:MKoeRWF00coeRWF00?o0000oo@;m?od2o@01?od2o@2
o`0000?onPGj00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d00oom0_d00ol0003on`Ckoo/4n`07oo/4n`03o`000?ob3O;olPgb00WolPgb00?o0000omXU
f_oJ9MX02OoJ9MX00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mOX5ooGj1O00coGj1O00?o0000oeFZ
EOmEZUD03?mEZUD00ol0003o:=LXobSG:00;obSG:003o`000?lWf2Oo000000KoB[E:00?o0000oimP
WonOH9l05_nOH9l00ol0003o`Sg2ol8m`P09ol8m`P03o`000?oF:MKoeRWF00coeRWF00?o0000oo@;
m?od2o@00ood2o@00ol0003onPGjooX5nP03ooX5nP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/01_ok1?/00ol0003o
lPgboo8=lP08oo8=lP03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000ojiA[_n^DJh02?n^DJh4o`0000oo
Gj1O00?o0000oeFZEOmEZUD02omEZUD00ol0003o:=LXobSG:00;obSG:004o`000?lWf2Oo9mPWo`00
00OoB[E:00?o0000oimPWonOH9l05OnOH9l00ol0003o`Sg2ol8m`P08ol8m`P03o`000?oF:MKoeRWF
00goeRWF00?o0000oo@;m?od2o@00_od2o@00ol0003onPGjooX5nP05ooX5nP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Goo@;m00?o0000oo/4nook
1?/01Ook1?/00ol0003olPgboo8=lP08oo8=lP03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000ojiA[_n^
DJh00on^DJh5o`0000?oHiaS00?o0000oenPGomOX5l03_mOX5l00ol0003oEJYEoeFZE@0:oeFZE@03
o`000?lXebSo:=LX00[o:=LX00Go0000obOH9olWf2Oo9mPWo`000007odZeBP03o`000?nOH9ooWf2O
01GoWf2O00?o0000ol8m`_o2?L802?o2?L800ol0003oeRWFomHYeP0=omHYeP03o`000?od2oCom0_d
00;o00002?oj1OX00ol0003on`Ckoo/4n`08oo/4n`Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo8=l_ob3O802?ob3O800ol0003ofRGJomXUfP0<omXUfPGo00002OmSW6<00ol0003o
Gj1OoenPG`0<oenPG`;o00003?mEZUD00ol0003o:=LXobSG:00:obSG:005o`000?lWf2Oo9mPWobOH
9ol000002?m:]DX00ol0003oWf2OoimPW`0DoimPW`?o00001oo2?L800ol0003oeRWFomHYeP0>omHY
eP03o`000?od2oCo000000_onPGj00?o0000oo/4nook1?/01_ok1?/00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ood2oOom0_d01Oom0_d00ol0003on`Ckoo/4n`04oo/4n`03o`000?ob3O;olPgb00Oo
lPgb00?o0000omXUf_oJ9MX03?oJ9MX01?l0003oZeB[oj]DZol0000;of>LH`03o`000?mOX5ooGj1O
00_oGj1O00Co0000oa_T6olKi1_o00002_mEZUD00ol0003o:=LXobSG:00:obSG:003o`000?lWf2Oo
9mPW00;o9mPW00?o0000odZeB_m:]DX01_m:]DX00ol0003oWf2OoimPW`0AoimPW`?o00000onIIYT0
0ol0003o`Sg2ol8m`P04ol8m`P03o`000?oF:MKoeRWF00goeRWF1?l0000;ooX5nP03o`000?ok1?_o
n`Ck00Gon`Ck00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Koo@;m00Co0000oo/4
nook1?_on`Ck1?l00008oo8=lP03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000oj]DZon[E:/00_n[E:/0
0ol0003oHiaSof>LH`08of>LH`03o`000?mOX5ooGj1O00[oGj1O00?o0000oa_T6olKi1/00_lKi1/0
0ol0003oEJYEoeFZE@03oeFZE@Go00002olXebP00ol0003o9mPWobOH9`03obOH9`03o`000?m:]D[o
B[E:00OoB[E:00?o0000oimPWonOH9l03_nOH9l2o`0000OoVFJI00?o0000ol8m`_o2?L800_o2?L80
0ol0003oeRWFomHYeP0=omHYeP03o`000?oc3??ol`cc00;ol`cc00?o0000ooX5n_oj1OX02Ooj1OX0
0ol0003on`Ckoo/4n`03oo/4n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@07ood2
o@?o00001?oc3?<00ol0003olPgboo8=lP05oo8=lP03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oj]D
Zon[E:/00on[E:/00ol0003oHiaSof>LH`09of>LH`03o`000?mOX5ooGj1O00SoGj1O00?o0000oa_T
6olKi1/01?lKi1/5o`0000Co6^DJ00?o0000obSG:?lXebP02OlXebP00ol0003o9mPWobOH9`03obOH
9`03o`000?m:]D[oB[E:00SoB[E:00?o0000oimPWonOH9l02_nOH9l3o`0000[oVFJI00Go0000ol8m
`_o2?L;o`Sg2o`00000>omHYeP03o`000?oc3??ol`cc00Col`cc0_l00009ooX5nP03o`000?ok1?_o
n`Ck00;on`Ck00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo<<
looc3?<01Ooc3?<00ol0003olPgboo8=lP03oo8=lP03o`000?oJ9M[ofRGJ00[ofRGJ00?o0000oj]D
Zon[E:/01?n[E:/00ol0003oHiaSof>LH`09of>LH`03o`000?mOX5ooGj1O00OoGj1O00?o0000oa_T
6olKi1/01OlKi1/00ol0003o6^DJoa[U6P07oa[U6P03o`000?lXebSo:=LX00Oo:=LX00?o0000obOH
9olWf2L01?lWf2L00ol0003oB[E:odZeBP08odZeBP03o`000?nOH9ooWf2O00SoWf2O0_l0000>oiUV
V@Co00003?oF:MH2o`0000Wol`cc00?o0000ooX5n_oj1OX01ooj1OX01?l0003on`Ckoo/4nol0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003ol`ccoo<<l`07oo<<l`;o00000oob3O800ol0
003ofRGJomXUfP09omXUfP03o`000?n[E:_oZeB[00KoZeB[00?o0000of>LHomSW6<02OmSW6<00ol0
003oGj1OoenPG`05oenPG`03o`000?lKi1_o6n@K00Ko6n@K00?o0000oa[U6_lJiAX02?lJiAX00ol0
003o:=LXobSG:006obSG:003o`000?lWf2Oo9mPW00Co9mPW00?o0000odZeB_m:]DX02Om:]DX4o`00
00?oWf2O0ol0000@oiUVV@05o`000?oH9mSof2OHomPWf?l000002_oF:MH00ol0003ol`ccoo<<l`0:
oo<<l`Ko00000ooj1OX00ol0003on`Cko`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ood2oOom0_d01?om0_d00ol0
003ol`ccoo<<l`0:oo<<l`04o`000?ob3O;olPgbo`0000[ofRGJ00?o0000oj]DZon[E:/01on[E:/0
0ol0003oHiaSof>LH`09of>LH`03o`000?mOX5ooGj1O00CoGj1O00?o0000oa_T6olKi1/01olKi1/0
0ol0003o6^DJoa[U6P08oa[U6P;o00001_lXebP00ol0003o9mPWobOH9`05obOH9`03o`000?m:]D[o
B[E:00WoB[E:00Co0000of2OH?mPWf3oH9mP0ol0000BoiUVV@03o`000?oH9mSof2OH00?of2OH0_l0
0006omHYeP;o00003Ooc3?<00ol0003oo@;mood2o@03ood2o@Go00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ood2oOom0_d00oom0_d0
0ol0003ol`ccoo<<l`0<oo<<l`;o00002_oJ9MX00ol0003oZeB[oj]DZ`08oj]DZ`03o`000?mSW6?o
HiaS00[oHiaS00?o0000oenPGomOX5l00_mOX5l00ol0003o6n@Koa_T6`08oa_T6`03o`000?lJiA[o
6^DJ00Ko6^DJ0_l00002o`Ki1P03o`000?lXebSo:=LX00;o:=LX00?o0000obOH9olWf2L01_lWf2L0
0ol0003oB[E:odZeBP08odZeBP03o`000?mPWf3oH9mP00CoH9mP00?o0000oiUVVOnIIYT03onIIYT0
0ol0003of2OHomPWf006omPWf0;o00000ooF:MH00ol0003ol`ccoo<<l`0=oo<<l`03o`000?om0_go
o@;m00Ooo@;m0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003oo@;mood2o@02ood2o@03o`000?oc3??ol`cc
00kol`cc00?o0000omXUf_oJ9MX01ooJ9MX00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?mSW6?oHiaS
00WoHiaS00Go0000oenPGomOX5ooGj1Oo`00000;oa_T6`03o`000?lJiA[o6^DJ00Co6^DJ0_l00005
o`Ki1P05o`000?lXebSo:=LXobSG:?l000002?lWf2L00ol0003oB[E:odZeBP08odZeBP03o`000?mP
Wf3oH9mP00GoH9mP00?o0000oiUVVOnIIYT03_nIIYT00ol0003of2OHomPWf008omPWf003o`000?oF
:MKo000000ool`cc00?o0000ood2oOom0_d02?om0_d01?l0003ooP7no`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?om0_goo@;mo`00017ol`cc00?o0000omXUf_oJ9MX01_oJ9MX00ol0003oZeB[
oj]DZ`0;oj]DZ`03o`000?mSW6?oHiaS00WoHiaS00Co0000oenPGomOX5oo00003?lKi1/00ol0003o
6^DJoa[U6P02oa[U6P;o00002?l6n@H00ol0003o:=LXo`000009obOH9`03o`000?m:]D[oB[E:00So
B[E:00?o0000of2OH?mPWf001OmPWf000ol0003oVFJIoiUVV@0=oiUVV@03o`000?oH9mSof2OH00[o
f2OH00?o0000oo<<looc3?<03_oc3?<00ol0003oo@;mood2o@07ood2o@03o`000?on0OkooP7n00;o
oP7n00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000Boo<<l`03o`00
0?oJ9M[ofRGJ00CofRGJ00?o0000oj]DZon[E:/03?n[E:/00ol0003oHiaSof>LH`0:of>LH`?o0000
3?lKi1/00ol0003o6^DJoa[U6P02o`0000_o1_T600?o0000obOH9olWf2L02?lWf2L00ol0003oB[E:
odZeBP07odZeBP03o`000?mPWf3oH9mP00OoH9mP00?o0000oiUVVOnIIYT03?nIIYT00ol0003of2OH
omPWf00;omPWf0;o00003_oc3?<00ol0003oo@;mood2o@07ood2o@03o`000?on0OkooP7n00?ooP7n
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003ol`ccoo<<l`0?oo<<l`?o00000ooJ
9MX00ol0003oZeB[oj]DZ`0>oj]DZ`03o`000?mSW6?oHiaS00SoHiaS00Co0000ob?L8olSg2?o8m`S
0_l0000:oa_T6`?o00003Ol6n@H00ol0003o9mPWobOH9`08obOH9`03o`000?m:]D[oB[E:00OoB[E:
00?o0000of2OH?mPWf001omPWf000ol0003oVFJIoiUVV@0;oiUVV@03o`000?oH9mSof2OH00cof2OH
00?o0000ooX5n_l000000_l0000:oo<<l`03o`000?om0_goo@;m00Soo@;m00?o0000ooh1o_on0Oh0
1Oon0Oh2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o004oo`3o003o`000?oc3??ol`cc00col`cc0_l0
0003onXEjP03o`000?oJ9M[o0000017oZeB[00?o0000of>LHomSW6<01omSW6<00ol0003o8m`Sob?L
8`04ob?L8`;o00002?lKi1/00ol0003o1_T6o`Ki1P0>o`Ki1P;o00002?lWf2L00ol0003oB[E:odZe
BP06odZeBP03o`000?mPWf3oH9mP00WoH9mP00?o0000oiUVVOnIIYT02OnIIYT00ol0003of2OHomPW
f00=omPWf003o`000?oj1O[onPGj00;onPGj0ol00007oo<<l`03o`000?om0_goo@;m00Ooo@;m00?o
0000ooh1o_on0Oh02?on0Oh2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?oc3??o
l`cc00Wol`cc0_l00006onXEjP03o`000?n[E:_oZeB[013oZeB[00?o0000of>LHomSW6<01_mSW6<0
0ol0003o8m`Sob?L8`07ob?L8`03o`000?lKi1_o6n@K00Co6n@K0ol0000>o`Ki1P03o`000?l5nPGo
1OX500?o00001OlWf2L00ol0003oB[E:odZeBP06odZeBP03o`000?mPWf3oH9mP00[oH9mP00?o0000
oiUVVOnIIYT02?nIIYT00ol0003of2OHomPWf00=omPWf003o`000?oj1O[onPGj00GonPGj0ol00004
oo<<l`03o`000?om0_goo@;m00Ooo@;m00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo0?loo`3o006oo`3o003o`000?oc3??ol`cc00Gol`cc0ol00008onXEjP03o`000?n[E:_oZeB[
017oZeB[00Co0000of>LHomSW6?oHiaS1?l0000;ob?L8`;o000000Co6n@Ko`000?l0003o00000ol0
o`02o`0000_o1_T600?o0000o`Gj1Ol5nPD01?l5nPD2o`0000?o9mPW00?o0000odZeB_m:]DX01_m:
]DX00ol0003oH9mPof2OH00:of2OH003o`000?nIIYWoVFJI00OoVFJI00?o0000omPWf?oH9mP03_oH
9mP00ol0003onPGjooX5nP08ooX5nPCo00002_om0_d00ol0003ooP7nooh1oP0;ooh1oP;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo0?loo`3o007oo`3o003o`000?oc3??ol`cc00;ol`cc0_l0000<onXEjP03o`000?n[E:_o
ZeB[013oZeB[1?l00003oeRWF003o`000?lSg2?o8m`S00_o8m`S00?o0000o`3o0?l0o`001_l0o`00
0ol0003o1_T6o`Ki1P07o`Ki1P03o`000?l5nPGo1OX500Oo1OX53?l0000>of2OH003o`000?nIIYWo
VFJI00KoVFJI00?o0000omPWf?oH9mP03_oH9mP00ol0003onPGjooX5nP0;ooX5nP03o`000?om0_go
o@;m00Ooo@;m00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00Woo0?l00Co0000oo<<
lol0003o00003_oZ5NX00ol0003oZeB[oj]DZ`0?oj]DZ`03o`000?mHYeSoF:MH00KoF:MH00?o0000
ob?L8olSg2<02_lSg2<00ol0003o0?l0o`3o0007o`3o00;o00001_l6n@H00ol0003o1OX5o`Gj1@08
o`Gj1@03o`000?ldbcCo=</d00So=</d00?o0000of2OH?mPWf003?mPWf000ol0003oVFJIoiUVV@05
oiUVV@03o`000?oH9mSof2OH00oof2OH0_l0000=ooX5nP03o`000?om0_goo@;m00Koo@;m00?o0000
ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onXEj_oZ5NX03_oZ5NX00ol0
003oZeB[oj]DZ`0>oj]DZ`03o`000?mHYeSoF:MH00OoF:MH00?o0000ob?L8olSg2<02_lSg2<00ol0
003o0?l0o`3o0009o`3o00;o00000ol6n@H00ol0003o1OX5o`Gj1@09o`Gj1@03o`000?ldbcCo=</d
00Wo=</d00?o0000of2OH?mPWf002_mPWf04o`0000CoVFJI00?o0000omPWf?oH9mP04?oH9mP01?l0
003on0Oho`000?l0000<ooX5nP03o`000?om0_goo@;m00Goo@;m00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?ol0ocoo0?l00[oo0?l00?o0000onXEj_oZ5NX03ooZ5NX@o`0000[oF:MH00?o0000ob?L
8olSg2<02OlSg2<00ol0003o0?l0o`00000<o`3o0005o`000?l6n@Ko0000o`3o0?l000002_l5nPD0
0ol0003o=</docC;=009ocC;=003o`000?mPWf3oH9mP00OoH9mP0ol00004ohMhQ`?o000000?oVFJI
o`000?oH9mP04OoH9mP01?l0003on0OhooP7n?oh1oP2o`0000_onPGj00?o0000ood2oOom0_d00oom
0_d00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ojQGZonXEjP0?
onXEjP03o`000?nRGJ;oXUfR00coXUfR00?o0000oeRWF?mHYeP02OmHYeP00ol0003o8m`Sob?L8`07
ob?L8`04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`Gj1@03o`00
0?ldbcCo=</d00[o=</d00?o0000of2OH?mPWf000omPWf03o`0000[oQgR700?o0000omPWf?oH9mP0
4?oH9mP00ol0003on0OhooP7n004ooP7n0;o00002_oj1OX00ol0003oo@;mood2o@04o`0000oooP7n
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo0?l00?o0000onXEj_oZ5NX03ooZ5NX00ol0003oXUfRoj9MXP0<oj9MXP03o`000?mH
YeSoF:MH00WoF:MH00?o0000ob?L8olSg2<01_lSg2<00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o1OX5o`Gj1@06o`Gj1@03o`000?ld
bcCo=</d00[o=</d00?o0000of2OH?mPWf000ol0000=ohMhQ`03o`000?oH9mSof2OH013of2OH00?o
0000ooP7n?oh1oP01_oh1oP2o`0000WonPGj0_l00004ooh1oP03o`000?on0OkooP7n00_ooP7n00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ojQGZonXEjP0=onXEjP?o00003onRGJ80
0ol0003oF:MHoeRWF008oeRWF003o`000?lSg2?o8m`S00Go8m`S00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`Gj1Ol5nPD01Ol5nPD0
0ol0003o=</docC;=00;ocC;=0;o00004On7N8L00ol0003of2OHomPWf00?omPWf003o`000?oh1oSo
n0Oh00Son0Oh0_l00007ooX5nP03o`000?on0OkooP7n00CooP7n00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ojQGZonXEjP09onXEjPGo00000_oF:MH00ol0
003oXUfRoj9MXP0=oj9MXP03o`000?mHYeSoF:MH00WoF:MH00?o0000ob?L8olSg2<01?lSg2<00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o1OX5o`Gj1@04o`Gj1@03o`000?ldbcCo=</d00_o=</d00?o0000ohMhQon7N8L04?n7N8L00ol0
003of2OHomPWf00?omPWf003o`000?oh1oSon0Oh00[on0Oh0_l00004ooX5nP03o`000?on0OkooP7n
00KooP7n0_l0000:ooh1oP03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo0?loo`3o007oo`3o003o`000?oZ5N[ojQGZ00CojQGZ1Ol00007omHYeP03
o`000?nRGJ;oXUfR00goXUfR00?o0000oeRWF?mHYeP02OmHYeP00ol0003o8m`Sob?L8`03ob?L8`03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l5nPGo1OX500?o1OX500?o0000ocC;=?ldbc@02oldbc@00ol0003oQgR7ohMhQ`0@ohMhQ`03
o`000?oH9mSof2OH00oof2OH00?o0000ooP7n?oh1oP03?oh1oP2o`000003ooX5n_l0003ooP7n00[o
oP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000onXEj_l00000
1?l0000<omHYeP03o`000?nRGJ;oXUfR00koXUfR00?o0000oeRWF?mHYeP02?mHYeP00ol0003o8m`S
ob?L8`02ob?L8`03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l5nPGo1OX500;o1OX500?o0000ocC;=?ldbc@02oldbc@00ol0003oQgR7
ohMhQ`0AohMhQ`03o`000?oH9mSof2OH00gof2OH00?o0000ooP7n?oh1oP03ooh1oP00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Oon0Oh2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01Ool0o`3o`00017oeRWF00?o0000oj9MX_nRGJ803_nR
GJ800ol0003oF:MHoeRWF009oeRWF004o`000?lSg2?o8m`So`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l5nPGo1OX5o`Gj1Ol000003Oldbc@00ol0003o
QgR7ohMhQ`0AohMhQ`?o00003OoH9mP00ol0003on0OhooP7n00?ooP7n003o`000?on0OkooP7n00go
oP7n00Go0000ooh1o_on0OkooP7no`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_ol0o`2o`0000;omPWf00?o0000omHYe_oF:MH03ooF:MH00ol0003o
XUfRoj9MXP0>oj9MXP03o`000?mHYeSoF:MH00SoF:MH1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o1OX5o`Gj1Ol0000=ocC;=003o`000?n7N8OoQgR7
017oQgR700?o0000okM8]ongB;L00ol0000:omPWf0Co00003Ooh1oP00ol0003ooP7nooh1oP0?ooh1
oP03o`000?on0Oko000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ood2oOom0_goo@;m0_l00005ooH9mP03o`000?oF:MKoeRWF00koeRWF00?o0000oj9M
X_nRGJ803_nRGJ800ol0003oF:MHoeRWF007oeRWF003o`000?lDjaCo5>/D00?o5>/D00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<ocC;
=003o`000?n7N8OoQgR7013oQgR700?o0000okM8]ongB;L01?ngB;L3o`0000Kof2OH00?o0000oo@;
m?od2o@00_od2o@5o`0000Son0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?o
o@;m00?o0000ooH9m_of2OH01?of2OH00ol0003oeRWFomHYeP0=omHYeP03o`000?nRGJ;oXUfR00oo
XUfR00?o0000oeRWF?mHYeP01?mHYeP2o`0000Oo5>/D00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
2?L800?o0000ocC;=?ldbc@02?ldbc@3o`00013oQgR700?o0000okM8]ongB;L02?ngB;L3o`0000;o
f2OH00?o0000oo@;m?od2o@02?od2o@5o`0000?on0Oh00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?om0_goo@;m00Coo@;m00?o0000ooH9m_of2OH01Oof2OH00ol0003oeRWFomHYeP0;omHYePCo0000
3onRGJ800ol0003oF:MHoeRWF003oeRWF003o`000?lDjaCo5>/D00So5>/D00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o2?L8o`Sg2005o`Sg20;o0000
1_ldbc@2o`0000?oA[U600?o0000ohMhQon7N8L03?n7N8L00ol0003o]dRgokM8]`0<okM8]`;o0000
4?od2o@3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?of2OKomPWf00KomPWf00?o
0000omHYe_oF:MH02OoF:MH00ol0003ohacSo`000002ojIIYP?o00003?nRGJ801?l0003oF:MHoeRW
F?mHYeP2o`0000co5>/D00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`Sg2?l8m`P01ol8m`P00ol0003o=</docC;=002ocC;=003o`00
0?m6^DKoA[U600CoA[U60_l0000;ohMhQ`03o`000?ngB;Oo]dRg00co]dRg00?o0000omlPgol00000
4_od2o@00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00OomPWf00?o
0000omHYe_oF:MH01_oF:MH2o`0000;ohacS00?o0000ojIIY_nVFJH00onVFJH3o`0000[oXUfR00?o
0000oeRWF?l000003olDja@01?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`Sg2?l8m`P02?l8m`P01?l0003o=</do`000?l00009odJiAP03o`000?n7N8OoQgR700Oo
QgR700?o0000okM8]ongB;L03?ngB;L01?l0003ogb3OomlPgol0000Coo@;m003o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWfooH9mP08ooH9mP03o`000?oF:MKoeRWF00Co
eRWF00?o0000on<LhooS7><00ooS7><00ol0003oYUVVojIIYP05ojIIYP?o00001_nRGJ84o`00013o
5>/D00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l8m`So2?L800Wo
2?L800?o0000odJiA_m6^DH02_m6^DH2o`0000KoQgR700?o0000okM8]ongB;L03?ngB;L00ol0003o
gb3OomlPg`02omlPg`03o`000?od2oCom0_d00oom0_d00?o0000ood2oOl000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?of2OKomPWf00WomPWf00Co0000omHYe_oF:MKo
eRWF0_l00006on<Lh`03o`000?nVFJKoYUVV00SoYUVV0ol000000onRGJ;o0000o`000004oe6^D@03
o`000?lDjaCo5>/D00go5>/D00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l8m`So2?L800Wo2?L800?o0000odJiA_m6^DH03?m6^DH00ol0003oQgR7ohMhQ`03o`0000ko
]dRg00?o0000omlPgooO8=l00ooO8=l00ol0003om0_doo@;m00>oo@;m005o`000?om0_goo@;mood2
oOl000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@09ood2o@03o`000?of2OKomPWf00[o
mPWf00?o0000omHYe_l000002?oS7><00ol0003oYUVVojIIYP0;ojIIYP03o`000?mA[U7oDJiA00Go
DJiA00?o0000oaC[5?lDja@03?lDja@00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`Sg2?l8m`P02?l8m`P2o`0000ooA[U60_l00002ojMHY`03o`000?ngB;Oo]dRg00_o
]dRg00?o0000omlPgooO8=l01?oO8=l00ol0003om0_doo@;m00=oo@;m003o`000?om0_goo@;m00?o
o@;m00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ood2o@03o`000?of2OKomPWf00_omPWf00?o0000on<LhooS7><0
1ooS7><00ol0003oYUVVojIIYP0;ojIIYP03o`000?mA[U7oDJiA00KoDJiA00?o0000oaC[5?lDja@0
2olDja@2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o2?L8o`Sg2007o`Sg2004o`00
0?lJiA[o6^DJo`0000koA[U600?o0000ojMHYonWF:L00_nWF:L00ol0003o]dRgokM8]`09okM8]`03
o`000?oO8=oogb3O00Kogb3O00?o0000oo@;m?od2o@02ood2o@00ol0003oo@;mood2o@05ood2o@04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000Soo@;m00?o0000ooH9m_of2OH02_of2OH2o`0000Wo
hacS00?o0000ojIIY_nVFJH02onVFJH00ol0003oDJiAoe6^D@07oe6^D@03o`000?lDjaCo5>/D00Wo
5>/D00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l8m`So2?L8
00Ko2?L800Go0000oa[U6_lJiA[o6^DJo`00000>odJiAP03o`000?nWF:OoYeRW00?oYeRW00?o0000
okM8]ongB;L01ongB;L00ol0003ogb3OomlPg`07omlPg`03o`000?od2oCom0_d00[om0_d00?o0000
ood2oOom0_d01oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ood2o@03o`000?of2OKomPWf
00WomPWf00Co0000ooD:mOoe2_Go00002OoS7><00ol0003oYUVVojIIYP09ojIIYP03o`000?mA[U7o
DJiA00WoDJiA00?o0000oaC[5?lDja@01olDja@00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o2?L8o`Sg2005o`Sg2003o`000?lJiA[o
6^DJ00?o6^DJ00?o0000odJiA_m6^DH02_m6^DH00ol0003oYeRWojMHY`05ojMHY`03o`000?ngB;Oo
]dRg00Go]dRg00?o0000omlPgooO8=l02?oO8=l00ol0003om0_doo@;m009oo@;m003o`000?om0_go
o@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_om0_d3o`0000WomPWf00?o0000ooD:
mOoe2_D00_oe2_D00ol0003ohacSon<Lh`06on<Lh`03o`000?nVFJKoYUVV00WoYUVV00?o0000oe6^
DOmA[U402_mA[U400ol0003o5>/DoaC[5005oaC[5003o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l8m`So2?L800Co2?L800?o0000oa[U
6_lJiAX01?lJiAX00ol0003oA[U6odJiAP0:odJiAP03o`000?nWF:OoYeRW00KoYeRW00?o0000okM8
]ongB;L00ongB;L00ol0003ogb3OomlPg`09omlPg`03o`000?od2oCom0_d00Som0_d00?o0000ood2
oOom0_d02Oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003oo/4n`?o00001Oof2OH00ol0003o
m@[eooD:m@03ooD:m@03o`000?oS7>?ohacS00KohacS00?o0000ojIIY_nVFJH02OnVFJH00ol0003o
DJiAoe6^D@0;oe6^D@03o`000?lDjaCo5>/D00?o5>/D00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`Sg2?l8m`P00_l8m`P2o`0000So
6^DJ00?o0000odJiA_m6^DH02Om6^DH00ol0003oYeRWojMHY`07ojMHY`05o`000?ngB;Oo]dRgokM8
]ol000003OoO8=l00ol0003om0_doo@;m006oo@;m003o`000?om0_goo@;m00[oo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?ok1?_on`Ck00Gon`Ck0ol000000oof2OKo0000ooD:m@06ooD:m@03
o`000?oS7>?ohacS00GohacS00?o0000ojIIY_nVFJH02OnVFJH00ol0003oDJiAoe6^D@0<oe6^D@05
o`000?lDjaCo5>/DoaC[5?l000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`Sg2?l000000_l000000ol;m0_o0000oa[U6P07oa[U6P03o`000?m6^DKoA[U6
00SoA[U600?o0000ojMHYonWF:L02OnWF:L00ol0003o]dRgo`00000=omlPg`Co00001Ood2o@00ol0
003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003on`Ckoo/4n`08oo/4n`03
o`000?oe2_Gom@[e00Oom@[e00?o0000on<LhooS7><01?oS7><00ol0003oYUVVojIIYP09ojIIYP03
o`000?mA[U7oDJiA00goDJiA00?o0000oaC[5?l000003?l0o`0:o`0000Oo0?l00ol00005o`_d2`03
o`000?lJiA[o6^DJ00Ko6^DJ00?o0000odJiA_m6^DH01om6^DH00ol0003oYeRWojMHY`0:ojMHY`03
o`000?oO8=oogb3O00_ogb3O00?o0000ooL8moog2?L00_og2?L3o`000003oo@;m?l0003oo@;m00_o
o@;m0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003om@[eooD:m@07ooD:m@03o`00
0?oS7>?ohacS00GohacS00?o0000ojIIY_nVFJH01onVFJH00ol0003oDJiAoe6^D@0?oe6^D@;o0000
2ol0o`000ol0003o0_d2o`;m0P07o`;m0P03o`000?l0o`3o0?l000;o0?l00ol00008o`_d2`03o`00
0?lJiA[o6^DJ00Ko6^DJ00?o0000odJiA_m6^DH01om6^DH00ol0003oYeRWojMHY`0:ojMHY`03o`00
0?oO8=oogb3O00[ogb3O00?o0000ooL8moog2?L01_og2?L00ol0003oo@;mood2o@08ood2o@?o0000
0_om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003om@[eooD:
m@08ooD:m@03o`000?oS7>?ohacS00CohacS00?o0000ojIIY_nVFJH01onVFJH00ol0003oDJiAoe6^
D@0>oe6^D@04o`000?lMhQgo7N8Mo`0000Wo0?l000?o0000o`;m0_l2o@802Ol2o@801?l0003o0?l0
o`000?l0000<o`_d2`03o`000?lJiA[o6^DJ00Ko6^DJ00?o0000odJiA_m6^DH01_m6^DH00ol0003o
YeRWojMHY`0;ojMHY`03o`000?oO8=oogb3O00Oogb3O0_l00009ooL8m`03o`000?om0_goo@;m00Co
o@;m1?l00006ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?oe2_Gom@[e00Som@[e00?o0000on<LhooS7><00ooS7><>o`0000goDJiA00?o0000oagR7OlMhQd0
0_lMhQd00ol0003o0?l0o`3o0005o`3o0003o`000?l2o@;o0_d200_o0_d200?o0000o`_d2ol;m0/0
3?l;m0/00ol0003o6^DJoa[U6P06oa[U6P03o`000?m6^DKoA[U600GoA[U600?o0000ojMHYonWF:L0
3?nWF:L00ol0003ogb3OomlPg`06omlPg`03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d0
0ol0000:ood2o@?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooD:mOoe2_D02?oe
2_D01Ol0003ohacSon<LhooS7>?o000000_o]dRg00?o0000oeVVFOmIYUT00ol00009oe6^D@03o`00
0?lMhQgo7N8M00Co7N8M00?o0000o`3o0?l0o`000ol0o`000ol0003o0_d2o`;m0P0<o`;m0P03o`00
0?l;m0_o2o@;00go2o@;00?o0000oa[U6_lJiAX01_lJiAX00ol0003oA[U6odJiAP03odJiAP?o0000
3OnWF:L00ol0003ogb3OomlPg`05omlPg`03o`000?og2?Oom`Sg00com`Sg0_l0000=ood2o@03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooD:mOoe2_D02?oe
2_D4o`0000co]dRg00?o0000oeVVFOmIYUT00omIYUT3o`0000GoDJiA00?o0000oagR7OlMhQd01_lM
hQd01Ol0003o0?l0o`3o0?l0o`3o000000oo0_d200?o0000o`_d2ol;m0/03Ol;m0/00ol0003o6^DJ
oa[U6P06oa[U6P03o`000?m6^DKoA[U600?o00000omRWF800ol0003oYeRWojMHY`0;ojMHY`03o`00
0?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L03Oog2?L00ol0003oo@;mood2o@0;ood2o@03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo/4nook1?/02_ok1?/3o`0000Kom@[e0ol0
0003onhAkP03o`000?ngB;Oo]dRg00[o]dRg00?o0000oeVVFOmIYUT01_mIYUT3o`000003oe6^DOl0
003o7N8M00Wo7N8M00?o0000o`3o0?l000004?l2o@800ol0003o2o@;o`_d2`0=o`_d2`03o`000?lJ
iA[o6^DJ00Oo6^DJ0_l00007of:MHP03o`000?nWF:OoYeRW00[oYeRW00Co0000omlPgooO8=oogb3O
0ol0000?ooL8m`03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000oo/4nook1?/02_ok
1?/01?l0003on@KiooT6nOoi1_T2o`000004ooD:mOl0003o0000o`0000KokQ7^00?o0000okM8]ong
B;L02_ngB;L00ol0003oFJIIoeVVF@09oeVVF@03o`000?lMhQgo7N8M00[o7N8M00?o0000o`;m0_l2
o@803ol2o@800ol0003o2o@;o`_d2`0>o`_d2`03o`000?lJiA[o6^DJ00Ko6^DJ00?o0000of:MH_mR
WF801omRWF84o`0000SoYeRW00Co0000omlPgooO8=oo00000oo_4>l2o`0000gom`Sg00?o0000ood2
oOom0_d02_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003o
n@KiooT6n@04ooT6n@03o`000?o^4NkokQ7^00OokQ7^00?o0000okM8]ongB;L02OngB;L00ol0003o
FJIIoeVVF@0:oeVVF@03o`000?lMhQgo7N8M00[o7N8M00?o0000o`;m0_l2o@803ol2o@800ol0003o
2o@;o`_d2`0>o`_d2`03o`000?lJiA[o6^DJ00Go6^DJ00?o0000of:MH_mRWF802?mRWF801?l0003o
/4n`ok1?/?n`Ck07o`0000;oYeRW0_l00006onl@k`;o00003?og2?L00ol0003oo@;mood2o@09ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oi1_Won@Ki00Go
n@Ki00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o]dRgokM8]`08okM8]`03o`000?mIYUWoFJII00[o
FJII00?o0000oagR7OlMhQd02olMhQd00ol0003o0_d2o`;m0P0>o`;m0P03o`000?l;m0_o2o@;00ko
2o@;1Ol00002oa[U6P03o`000?mRWF;oHYeR00WoHYeR00?o0000ok1?/?n`Ck002?n`Ck03o`0000Wo
ka3_0_l0000:ooL8m`03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP07onhAkP03o`00
0?ngB;Oo]dRg00So]dRg00?o0000oeVVFOmIYUT02_mIYUT00ol0003o7N8MoagR7@0:oagR7@;o0000
3_l2o@83o`0000go2o@;0ol00005oc;=<P;o00002omRWF800ol0003o/4n`ok1?/00;ok1?/0;o0000
2_o_4>l2o`0000Oom`Sg0ol00009ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:ooT6n@03o`00
0?o^4NkokQ7^00OokQ7^00?o0000okM8]ongB;L02?ngB;L>o`0000Wo7N8M0ol000000olGj1Oo0000
o`;m0P0:o`;m0P?o00000_lGj1L00ol0003o2o@;o`_d2`09o`_d2`;o00002OlbcC800ol0003oHYeR
of:MHP09of:MHP03o`000?n`Ck3o/4n`00_o/4n`00?o0000olhac_l000002oo_4>l2o`0000Com`Sg
00Co0000ooT6nOoi1_Won@Ki0_l00007ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oom0_d00ol0003on@Ki
ooT6n@09ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000okM8]ongB;L02?ngB;L00ol0003oF:MH
oeRWF00:oeRWF003o`000?lMhQgo7N8M00Co7N8M0ol00005oaOX5`03o`000?l2o@;o0_d200Co0_d2
1?l00006oaOX5`03o`000?l;m0_o2o@;00Ko2o@;0_l0000;oc;=<P03o`000?mRWF;oHYeR00WoHYeR
00?o0000ok1?/?n`Ck002_n`Ck001Ol0003ocS7>olhac_o><Lko000000coka3_0_l000000oog2?Oo
0000ooT6n@05ooT6n@03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0;ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o]dRgokM8]`07okM8]`03o`00
0?mHYeSoF:MH00_oF:MH00?o0000oagR7OlMhQd00_lMhQd2o`0000Wo5nPG00?o0000o`;m0_l2o@80
0ol0000;oaOX5`03o`000?l;m0_o2o@;00;o2o@;0ol0000>oc;=<P03o`000?mRWF;oHYeR00OoHYeR
00?o0000ok1?/?n`Ck002on`Ck000ol0003ocS7>olhacP02olhacP03o`000?o_4>ooka3_00_oka3_
00?o0000ooT6nOoi1_T01_oi1_T2o`0000?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0<ood2o@03o`000?oi
1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01oo^4Nh00ol0003o]dRgokM8]`05okM8]`?o00003OmH
YeP4o`0000_o5nPG0ol0000?oaOX5`04o`000?l;m0_o0000o`00017o</db00?o0000of:MH_mRWF80
1omRWF800ol0003o/4n`ok1?/00:ok1?/003o`000?o><LkocS7>00CocS7>00?o0000onl@koo_4>l0
1oo_4>l3o`0000_on@Ki1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooT6nOoi1_T02?oi1_T00ol0003okQ7^onhA
kP06onhAkP03o`000?ngB;Oo]dRg00;o]dRg0ol00003oiMXU`03o`000?mHYeSoF:MH00[oF:MH00?o
0000oaOX5olGj1L02olGj1L00ol0003o4n`Co`00000AoaOX5`03o`000?lbcC;o</db017o</db00?o
0000of:MH_mRWF801omRWF800ol0003o/4n`ok1?/00:ok1?/003o`000?o><LkocS7>00GocS7>00Co
0000onl@koo_4>ooka3_1Ol00002oo8=lP03o`000?oi1_Won@Ki00Won@Ki00Co0000ooh1o_on0Oko
oP7n0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP05onhAkP?o0000
00?o]dRgo`000?l000001onGJ9L00ol0003oF:MHoeRWF008oeRWF0?o00002_lGj1L2o`0000;o4n`C
00?o0000oaOX5olGj1L03olGj1L00ol0003o</dboc;=<P0Aoc;=<P03o`000?mRWF;oHYeR00OoHYeR
00?o0000ok1?/?n`Ck002On`Ck000ol0003ocS7>olhacP07olhacP?o00001oob3O800ol0003on@Ki
ooT6n@09ooT6n@03o`000?on0OkooP7n00CooP7n0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?om0_goo@;m00koo@;m00?o0000ooT6nOoi1_T01ooi
1_T4o`0000;okQ7^0_l00003on@Ki003o`000?nGJ9OoUfRG00SoUfRG0_l00006oeRWF0;o00000om8
]dP00ol0003o5nPGoaOX5`06oaOX5`03o`000?lCk1?o4n`C00?o4n`C00?o0000oaOX5olGj1L03_lG
j1L00ol0003o</dboc;=<P0Boc;=<P03o`000?mRWF;oHYeR00GoHYeR00?o0000ok1?/?n`Ck002On`
Ck000ol0003ocS7>olhacP08olhacP03o`000?ob3O;olPgb00OolPgb00?o0000ooT6nOoi1_T02?oi
1_T00ol0003ooP7nooh1oP07ooh1oP;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki00Con@Ki0_l00004
ooL8m`;o00001OoT6n@00ol0003oUfRGoiMXU`0:oiMXU`03o`000?mHYeSoF:MH00;oF:MH00?o0000
odRgB?m8]dP01?m8]dP00ol0003o5nPGoaOX5`04oaOX5`03o`000?lCk1?o4n`C00Co4n`C00?o0000
oaOX5olGj1L03_lGj1L00ol0003o</dboc;=<P0Boc;=<P[o00002_n`Ck000ol0003ocS7>olhacP08
olhacP03o`000?ob3O;olPgb00OolPgb00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP09
ooh1oP?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ood2
oOom0_d03oom0_d01?l0003on@KiooT6nOoi1_T2o`0000Oom`Sg00?o0000on@Ki?oT6n@01?oT6n@0
0ol0003oUfRGoiMXU`0:oiMXU`04o`000?mHYeSo0000o`0000SoB;M800Co0000oaOX5olGj1Oo5nPG
0_l00007oa?/4`03o`000?lGj1Oo5nPG00ko5nPG00?o0000oc;=<_lbcC804_lbcC800ol0003oPgb3
oh=lP`07oh=lP`03o`000?n`Ck3o/4n`00Ko/4n`00?o0000olhac_o><Lh02_o><Lh00ol0003olPgb
oo8=lP06oo8=lP03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003oo@;mood2o@0?ood2o@04o`000?oi
1_Wo0000o`0000Wom`Sg00?o0000on@Ki?oT6n@01?oT6n@00ol0003oUfRGoiMXU`0;oiMXU`03o`00
0?m8]dSoB;M800WoB;M800?o0000oaOX5ol000002OlCk1<00ol0003o5nPGoaOX5`0>oaOX5`;o0000
4_lbcC800ol0003oPgb3oh=lP`09oh=lP`;o00001_n`Ck000ol0003ocS7>olhacP0:olhacP03o`00
0?ob3O;olPgb00KolPgb00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?om0_goo@;m013oo@;m00?o
0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki005on@Ki003o`000?nGJ9OoUfRG00[oUfRG00?o
0000odRgB?m8]dP02_m8]dP2o`0000Wo4n`C00?o0000oaOX5olGj1L03_lGj1L00ol0003o9]TVo`00
0002o`0000oo</db00?o0000oh=lPon3O8<02on3O8<00ol0003o/4n`ok1?/003o`0000gocS7>00?o
0000oo8=l_ob3O801_ob3O800ol0003on@KiooT6n@07ooT6n@03o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ood2oOom0_d03oom0_d0
0ol0003om`SgooL8m`09ooL8m`03o`000?oT6nCoi1_T00Goi1_T00?o0000oiMXUonGJ9L02OnGJ9L2
o`0000_oB;M80_l0000;oa?/4`03o`000?lGj1Oo5nPG00co5nPG00?o0000obKI9_lVfBH00olVfBH3
o`0000co</db00?o0000oh=lPon3O8<03?n3O8<2o`0000;ocS7>00?o0000olhac_o><Lh03?o><Lh0
0ol0003olPgboo8=lP05oo8=lP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003oo@;mood2o@0>ood2
o@03o`000?og2?Oom`Sg00[om`Sg00?o0000on@Ki?oT6n@01_oT6n@00ol0003oUfRGoiMXU`07oiMX
U`03o`000?nNHIko000000[oB;M800Co0000od2o@?m0_d3o00002_lCk1<00ol0003o5nPGoaOX5`0<
oaOX5`03o`000?lVfBKo9]TV00Ko9]TV0_l00008oc;=<P;o00003on3O8<00ol0003ocS7>olhacP02
olhacP03o`000?o><LkocS7>00_ocS7>00?o0000oo8=l_ob3O801Oob3O800ol0003on@KiooT6n@07
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ood2oOom0_d03_om0_d00ol0003om`SgooL8m`0:ooL8m`03o`000?oT6nCoi1_T
00Koi1_T00?o0000oiMXUonGJ9L01_nGJ9L01Ol0003oWV6NoiiQW_nNHIko000000SoB;M800?o0000
od2o@?m0_d000_m0_d000ol0003o4n`Coa?/4`06oa?/4`Co00003?lGj1L00ol0003o9]TVobKI9P08
obKI9P?o00000_lbcC83o`000003ofJII_l0003oPgb300goPgb300?o0000olhac_o><Lh01?o><Lh0
0ol0003ocS7>olhacP0:olhacP03o`000?ob3O;olPgb00GolPgb00?o0000ooT6nOoi1_T01_oi1_T0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02oog2?L00ol0003oi1_Ton@Ki007on@K
i003o`000?nGJ9OoUfRG00?oUfRG0_l00005oiiQWP03o`000?m8]dSoB;M800CoB;M800?o0000od2o
@?m0_d000om0_d000ol0003o4n`Coa?/4`05oa?/4`03o`000?l=lPgo3O8=00;o3O8=0ol00007oaOX
5`;o00003_lVfBH2o`0000GoIYUV00?o0000oh=lPon3O8<02_n3O8<00ol0003ocS7>olhacP05olha
cP03o`000?o><LkocS7>00_ocS7>00?o0000oo8=l_ob3O801?ob3O800ol0003on@KiooT6n@06ooT6
n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ood2oOom0_d03?om0_d00ol0003om`SgooL8m`0;ooL8m`03o`000?oT6nCoi1_T00Oo
i1_T00?o0000oiMXUonGJ9L00_nGJ9L00ol0003oWV6NoiiQWP06oiiQWP03o`000?m8]dSoB;M800;o
B;M800?o0000od2o@?m0_d001Om0_d000ol0003o4n`Coa?/4`02oa?/4`;o00002?l=lPd3o`0000;o
5nPG0_l000000ol>l@ko0000obKI9P0=obKI9P03o`000?mVVFKoIYUV00GoIYUV00?o0000oh=lPon3
O8<02?n3O8<00ol0003ocS7>olhacP07olhacP03o`000?o><LkocS7>00[ocS7>00?o0000oo8=l_ob
3O801?ob3O800ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ood2oOom0_d02oom0_d00ol0003om`Sg
ooL8m`0<ooL8m`03o`000?oT6nCoi1_T00Soi1_T00Co0000oiMXUonGJ9Oo00002OnNHIh01Ol0003o
B;M8odRgB?m8]dSo000000So@;m000Go0000oa?/4olCk1?o4n`Co`00000=o`gb3@;o00001?l>l@h0
0ol0003o9]TVobKI9P0;obKI9P03o`000?mVVFKoIYUV00KoIYUV00?o0000oh=lPon3O8<01on3O8<0
0ol0003ocS7>olhacP08olhacPCo00002?o><Lh00ol0003olPgboo8=lP04oo8=lP03o`000?oi1_Wo
n@Ki00Kon@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003oo@;mood2o@0:ood2o@03o`000?og2?Oom`Sg00_om`Sg0ol00009on@K
i003o`000?nGJ9Oo000000_oWV6N00?o0000odRgB?l000002_m0_d000ol0003o4n`Co`00000?o`gb
3@03o`000?l>l@ko3_4>00;o3_4>00?o0000obKI9_lVfBH02olVfBH00ol0003oIYUVofJIIP06ofJI
IP03o`000?n3O8?oPgb300KoPgb300?o0000olhac_o><Lh02Oo><Lh01?l0003oi1_Ton@Ki?oT6n@7
o`0000;ocS7>00?o0000oo8=l_ob3O800oob3O800ol0003on@KiooT6n@05ooT6n@03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ood2
o@03o`000?og2?Oom`Sg00Som`Sg0ol00003ooL8m`03o`000?oT6nCoi1_T00Ooi1_T00?o0000oiiQ
W_nNHIh02onNHIh00ol0003o@;m0od2o@00:od2o@003o`000?l=lPgo3O8=00go3O8=00?o0000o`ka
3_l>l@h01?l>l@h00ol0003o9]TVobKI9P09obKI9P03o`000?mVVFKoIYUV00SoIYUV00?o0000oh=l
Pon3O8<00on3O8<2o`0000cocS7>00?o0000on@Ki?oT6n@02?oT6n@<o`0000?on@Ki0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?om0_goo@;m00Oo
o@;m00?o0000ooL8moog2?L01_og2?L3o`0000Oom`Sg00?o0000on@Ki?oT6n@01_oT6n@00ol0003o
WV6NoiiQWP0;oiiQWP03o`000?m0_d3o@;m000Wo@;m00_l0000>o`gb3@03o`000?l>l@ko3_4>00Go
3_4>00?o0000obKI9_lVfBH02OlVfBH00ol0003oIYUVofJIIP09ofJIIP03o`000?n3O8?o000000;o
00000_o3?<<00ol0003ocS7>olhacP08olhacP03o`000?oT6nCoi1_T00coi1_T00?o0000ooD:mOoe
2_D01_oe2_D3o`0000?ooP7n0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ood2oOom0_d01_om0_d00ol0003om`SgooL8m`03ooL8m`?o00002oog2?L00ol0003oi1_T
on@Ki004on@Ki003o`000?nNHIkoWV6N00_oWV6N0ol00007od2o@0?o000000?o9mPWo`000?l=lPd0
3Ol=lPd00ol0003o3_4>o`ka3P06o`ka3P03o`000?lVfBKo9]TV00So9]TV00?o0000ofJII_mVVFH0
2_mVVFH00ol0003o`cc3ol<l``04ol<l``03o`000?o><LkocS7>00OocS7>00?o0000on@Ki?oT6n@0
2ooT6n@00ol0003om@[eooD:m@08ooD:m@03o`000?on0OkooP7n00CooP7n0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ood2oOom0_d00oom0_d4o`000004ooL8mol0
003o0000o`0000oom`Sg00?o0000on@Ki?oT6n@00ooT6n@>o`0000?oQgR70_l00002od2o@0?o0000
1OlWf2L00ol0003o3O8=o`gb3@0:o`gb3@03o`000?l>l@ko3_4>00Oo3_4>00?o0000obKI9_lVfBH0
2?lVfBH00ol0003oIYUVofJIIP0:ofJIIP03o`000?o3?<?o`cc300Go`cc300?o0000olhac_o><Lh0
1_o><Lh00ol0003oi1_Ton@Ki00;on@Ki003o`000?oe2_Gom@[e00Som@[e00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?om
0_go000000;o00001?om0_d2o`0001;om`Sg00?o0000on@Ki?oT6n@00_oT6n@00ol0003of2OHomPW
f00:omPWf003o`000?n7N8OoQgR700?oQgR70_l00009obOH9`03o`000?l=lPgo3O8=00Wo3O8=00?o
0000o`ka3_l>l@h02?l>l@h2o`0000So9]TV00?o0000ofJII_mVVFH02OmVVFH00ol0003o`cc3ol<l
``07ol<l``03o`000?o><LkocS7>00CocS7>00?o0000on@Ki?oT6n@02ooT6n@00ol0003om@[eooD:
m@09ooD:m@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ood2oOom0_d01oom0_d00ol0003om`SgooL8m`0?ooL8m`?o000000?oi1_T
o`000?oH9mP02ooH9mP00ol0003oQgR7ohMhQ`04ohMhQ`03o`000?lWf2Oo9mPW00Wo9mPW00?o0000
o`gb3Ol=lPd01ol=lPd00ol0003o3_4>o`ka3P09o`ka3P04o`000?lZeB[o0000o`0000Ko9]TV00?o
0000ofJII_mVVFH02OmVVFH00ol0003o`cc3ol<l``08ol<l``03o`000?o><LkocS7>00?ocS7>00?o
0000on@Ki?oT6n@02ooT6n@00ol0003om@[eooD:m@09ooD:m@03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ood2oOom0_d02?om0_d0
0ol0003om`SgooL8m`0<ooL8m`;o00000oof2OH2o`0000cof2OH00?o0000ohMhQon7N8L01?n7N8L0
0ol0003o9mPWobOH9`0:obOH9`Wo00002ol>l@h00ol0003o:]DZob[E:P02ob[E:P?o00000_lVfBH0
0ol0003oIYUVofJIIP0:ofJIIP03o`000?o3?<?o`cc300Wo`cc300?o0000olhac_o><Lh00_o><Lh0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?oe2_Gom@[e00Wom@[e00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@09ood2
o@;o00002_og2?L2o`0000GomPWf00?o0000onDJiOl000002_oH9mP00ol0003oQgR7ohMhQ`06ohMh
Q`03o`000?lWf2Oo9mPW00Wo9mPW00?o0000oa?/4olCk1<01OlCk1<00ol0003o3_4>o`ka3P09o`ka
3P03o`000?lZeB[o:]DZ00Go:]DZ0ol00009ofJIIP?o00003Oo3?<<01Ol0003ocS7>olhac_o><Lko
000000coi1_T00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8
moog2?L01Oog2?L2o`0000OomPWf00Co0000onDJiOoU6^Go00002OoH9mP00ol0003oQgR7ohMhQ`06
ohMhQ`03o`000?lWf2Oo9mPW00So9mPW00?o0000oa?/4olCk1<01olCk1<00ol0003o3_4>o`ka3P07
o`ka3P03o`000?lZeB[o:]DZ00So:]DZ0ol00002ofJIIPGo00000_n]DZd00ol0003o`cc3ol<l``0<
ol<l``03o`000?o><Lko000000coi1_T00?o0000ooD:mOoe2_D02_oe2_D00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m
00goo@;m00?o0000ooL8moog2?L00_og2?L2o`0000SomPWf00?o0000onDJiOoU6^D00_oU6^D5o`00
00Cof2OH00?o0000ohMhQon7N8L01_n7N8L00ol0003o9mPWobOH9`08obOH9`03o`000?lCk1?o4n`C
00Oo4n`C00?o0000o`ka3_l>l@h01ol>l@h00ol0003o:]DZob[E:P08ob[E:P03o`000?mbSG;oLXeb
00;o00002?n]DZd00ol0003o`cc3ol<l``0<ol<l``Co00002_oT6n@00ol0003om@[eooD:m@0:ooD:
m@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ood2oOom0_d03_om0_d01?l0003om`Sgo`000?l0000:ooH9mP03o`000?oU6^GoiA[U
00;oiA[U00?o0000ol0o`?o0?l000_o0?l04o`0000WoQgR700?o0000obOH9olWf2L02?lWf2L00ol0
003o4n`Coa?/4`08oa?/4`03o`000?l>l@ko3_4>00Go3_4>00?o0000ob[E:_lZeBX02?lZeBX01Ol0
003oLXebog:=L_mbSG;o000000[o[E:]0ol0000;ol<l``04o`000?o_4>ooka3_onl@k`Co00001OoT
6n@00ol0003om@[eooD:m@0;ooD:m@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ood2oOom0_d03oom0_d00ol0003omPWfooH9mP0:
ooH9mP03o`000?oU6^GoiA[U00?oiA[U00?o0000ol0o`?o0?l001?o0?l000ol0003oQgR7ohMhQ`07
ohMhQ`03o`000?lWf2Oo9mPW00Ko9mPW0_l0000;oa?/4`03o`000?l>l@ko3_4>00Go3_4>00?o0000
ob[E:_lZeBX02?lZeBX00ol0003oLXebog:=LP02og:=LP03o`000?n]DZgo[E:]00Oo[E:]00?o0000
omhQg_oN8Mh01?l00006ol<l``03o`000?o_4>ooka3_00Koka3_0ol00002on@Ki003o`000?oe2_Go
m@[e00_om@[e00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of2OKomPWf00WomPWf00?o0000onDJ
iOoU6^D01?oU6^D00ol0003o`3o0ol0o`005ol0o`003o`000?n7N8OoQgR700OoQgR700?o0000obOH
9olWf2L00_lWf2L3o`000003occ3??l0003o4n`C00[o4n`C00?o0000o`ka3_l>l@h01Ol>l@h00ol0
003o:]DZob[E:P07ob[E:P03o`000?mbSG;oLXeb00?oLXeb00?o0000ojeB[On]DZd01on]DZd00ol0
003ogR7NomhQgP04omhQgP?o00000_o3?<<00ol0003oka3_onl@k`0:onl@k`;o00003_oe2_D00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?om0_goo@;m013oo@;m00?o0000ooH9m_of2OH02Oof2OH00ol0003oiA[UonDJi@04onDJi@03
o`000?o0?l3o`3o000Ko`3o00_l00007ohMhQ`03o`000?lWf2Oo000000;o00001Oll`c`00ol0003o
4n`Coa?/4`08oa?/4`?o00001?l>l@h00ol0003o:]DZob[E:P08ob[E:P03o`000?mbSG;oLXeb00Co
LXeb00?o0000ojeB[On]DZd01_n]DZd00ol0003ogR7NomhQgP07omhQgP;o00003_o_4>l00ol0003o
m@[eooD:m@0;ooD:m@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfooH9mP08ooH9mP03o`00
0?oU6^GoiA[U00GoiA[U00?o0000ol0o`?o0?l001?o0?l000ol0003o_T6noki1_P03o`0000CoQgR7
0_l00008occ3?003o`000?lCk1?o4n`C00Oo4n`C00Co0000oc?<<olcc3?o<l`c0ol000000ol>l@ko
0000ob[E:P09ob[E:P03o`000?mbSG;oLXeb00CoLXeb00?o0000ojeB[On]DZd01On]DZd00ol0003o
gR7NomhQgP09omhQgP03o`000?o_4>ooka3_00goka3_00?o0000ooD:mOoe2_D02_oe2_D00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?om0_goo@;m017oo@;m00?o0000ooH9m_of2OH01oof2OH00ol0003oiA[UonDJi@06onDJi@03o`00
0?o0?l3o`3o000?o`3o000?o0000oki1__nn@Kh01?nn@Kh2o`000003ohMhQol0003o?<<l00[o?<<l
00?o0000oa?/4olCk1<01OlCk1<00ol0003o<l`coc?<<`05oc?<<`03o`000?lZeB[o:]DZ00Oo:]DZ
0ol00007og:=LP03o`000?n]DZgo[E:]00Co[E:]00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oka3_
onl@k`0=onl@k`03o`000?oe2_Gom@[e00[om@[e00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0@ood2o@03o`000?of
2OKomPWf00GomPWf0ol00009onDJi@05o`000?o0?l3o`3o0ol0o`?l000002Onn@Kh00ol0003o?<<l
occ3?00;occ3?003o`000?lCk1?o4n`C00?o4n`C00?o0000oc?<<olcc3<01_lcc3<00ol0003o:]DZ
ob[E:P06ob[E:P05o`000?mVVFKoIYUVofJII_l000001ombSG800ol0003o[E:]ojeB[@03ojeB[@03
o`000?oN8MkogR7N00WogR7N00?o0000onl@koo_4>l03_o_4>l00ol0003om@[eooD:m@09ooD:m@03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ood2oOom0_d04Oom0_d00ol0003omPWfo`000004o`0000;on@Ki00?o0000onDJiOoU6^D0
1ooU6^D01?l0003o`3o0ol0o`?l00009oki1_P;o00003Oll`c`00ol0003o4n`Coa?/4`02oa?/4`03
o`000?lcc3?o<l`c00So<l`c00?o0000ob[E:_lZeBX00olZeBX2o`0000GoIYUV00?o0000og:=L_mb
SG801?mbSG800ol0003o[E:]ojeB[@03ojeB[@03o`000?oN8MkogR7N00WogR7N00?o0000onl@koo_
4>l03_o_4>l00ol0003om@[eooD:m@09ooD:m@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ood2oOom0_d04Oom0_d2o`0000Son@Ki
00?o0000onDJiOoU6^D01_oU6^D00ol0003o`3o0o`000009oki1_P04o`000?n?L8ooSg2?o`0000go
?<<l00Co0000oa?/4olCk1?o00003?lcc3<01Ol0003o:]DZob[E:_lZeB[o000000SoIYUV0_l00005
og:=LP03o`000?n]DZgo[E:]00;o[E:]00?o0000omhQg_oN8Mh02OoN8Mh00ol0003oka3_onl@k`0>
onl@k`03o`000?oe2_Gom@[e00Wom@[e00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oi1_Won@Ki
00Oon@Ki00?o0000onDJiOoU6^D01ooU6^D00ol0003o_T6noki1_P07oki1_P03o`000?n?L8ooSg2?
00;oSg2?00?o0000occ3??ll`c`02_ll`c`00ol0003o4n`Co`00000>oc?<<`03o`000?lZeB[o0000
00_oIYUV00?o0000og:=L_mbSG800_mbSG801Ol0003o[E:]ojeB[On]DZgo000000cogR7N00?o0000
onl@koo_4>l03_o_4>l3o`0000Wom@[e00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki
00Won@Ki00?o0000onDJiOoU6^D01_oU6^D00ol0003o_T6noki1_P06oki1_P03o`000?n?L8ooSg2?
00?oSg2?00?o0000occ3??ll`c`02oll`c`00ol0003o<l`coc?<<`0>oc?<<`03o`000?mVVFKoIYUV
00_oIYUV0_l00003og:=LP04o`000?n]DZgo[E:]o`0000[ogR7N0ol0000>onl@k`;o00000oon0Oh2
o`0000Oom@[e00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oi1_Won@Ki00[on@Ki00?o0000onDJ
iOoU6^D01?oU6^D00ol0003o_T6noki1_P06oki1_P03o`000?n?L8ooSg2?00GoSg2?00?o0000occ3
??ll`c`01oll`c`3o`00017o<l`c00?o0000ofJII_mVVFH03OmVVFH01Ol0003oLXebog:=L_l0003o
[E:]00Co00000ooN8Mh5o`0000;om`Sg00?o0000onl@koo_4>l02_o_4>l2o`0000OooP7n0_l00004
ooD:m@03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03_om0_d00ol0003on@KiooT6n@0;ooT6n@03o`000?oU6^GoiA[U
00CoiA[U00?o0000oki1__nn@Kh01Onn@Kh00ol0003oSg2?ohm`S`06ohm`S`03o`000?ll`cco?<<l
00Co?<<l0ol00002od:m@P03o`000?lcc3?o<l`c00oo<l`c0_l0000?ofJIIP04o`000?mbSG;o0000
o`0000Cod2o@0ol00008ooL8m`03o`000?o_4>ooka3_00Ooka3_0_l0000;ooh1oP;o00000_oe2_D0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?om0_goo@;m00goo@;m00?o0000ooT6nOoi1_T03?oi1_T6o`0000Oo_T6n00?o0000ohm`
Son?L8l02?n?L8l00ol0003o?<<locc3?003o`0000Ko@[e200?o0000oc?<<olcc3<03Olcc3<01?l0
003oJiA[of^DJol0000?ofJIIP03o`000?o@;m3od2o@00God2o@00?o0000ooL8moog2?L02?og2?L0
0ol0003oka3_onl@k`05onl@k`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oi1_T00ol0003oj1OXonPGj004onPG
j003o`000?nn@Kko_T6n00?o_T6n00?o0000ohm`Son?L8l02_n?L8l2o`0000[o@[e200?o0000oc?<
<olcc3<02olcc3<00ol0003oJiA[of^DJ`02of^DJ`03o`000?mVVFKoIYUV00_oIYUV0_l00007om0_
d003o`000?og2?Oom`Sg00Wom`Sg00?o0000onl@koo_4>l00_o_4>l2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000ooT6nOoi1_T02ooi1_T00ol0003oj1OXonPGj006onPGj005o`000?nn@Kko_T6noki1
__l000003On?L8l00ol0003o@[e2od:m@P0:od:m@P03o`000?lcc3?o<l`c00Wo<l`c00?o0000of^D
Jom[U6/01?m[U6/00ol0003oIYUVofJIIP08ofJIIP;o000000?oVfBKo`000?o@;m001oo@;m000ol0
003om`SgooL8m`09ooL8m`04o`000?o_4>oo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oi1_Won@Ki
00Won@Ki00?o0000onPGj?oX5nP02?oX5nP00ol0003o_T6no`00000=ohm`S`03o`000?m2_D;o@[e2
00_o@[e200?o0000oc?<<olcc3<02?lcc3<00ol0003oJiA[of^DJ`06of^DJ`03o`000?mVVFKoIYUV
00GoIYUV0_l00003oi]TV`03o`000?o@;m3od2o@00Kod2o@00?o0000ooL8moog2?L02_og2?L00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on@KiooT6n@07ooT6n@03o`000?oX5nSoj1OX00[oj1OX00?o0000ohm`Son?
L8l03?n?L8l00ol0003o@[e2od:m@P0<od:m@P03o`000?lcc3?o<l`c00Ko<l`c00?o0000of^DJom[
U6/02?m[U6/00ol0003oIYUVofJIIP02ofJIIP;o00001_nKI9/00ol0003od2o@om0_d005om0_d003
o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Gon@Ki
00?o0000onPGj?oX5nP03?oX5nP2o`0000coSg2?00?o0000od:m@_m2_D803Om2_D800ol0003o<l`c
oc?<<`04oc?<<`03o`000?m[U6_oJiA[00[oJiA[00Co0000ofJII_l0003o00002?nKI9/00ol0003o
d2o@om0_d006om0_d003o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_oi1_T00ol0003oj1OXonPGj00=onPGj003o`000?nm@[go000000;o00002?n?L8l00ol0003o@[e2
od:m@P0?od:m@PKo00003_m[U6/00ol0003oVfBKoi]TV`08oi]TV`03o`000?o@;m3od2o@00Kod2o@
00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000ooX5n_oj1O[onPGj
0_l0000?onPGj003o`000?nm@[go_D:m00?o_D:m0ol00005ohm`S`;o00004?m2_D801_l0003oD:m@
oe2_D?l0003oBkA;o`0000koJiA[00?o0000oi]TVonKI9/02OnKI9/00ol0003od2o@om0_d005om0_
d003o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003o
j1OXonPGj00=onPGj003o`000?nm@[go_D:m00Ko_D:m0ol000001?n?L8oo0000ofjAK_m^TFh3o`00
00co@[e200Go0000oe2_D?m@[e3oD:m@o`000002od^dB`03o`000?m[U6_oJiA[00_oJiA[00?o0000
oi]TVonKI9/02OnKI9/00ol0003od2o@om0_d006om0_d003o`000?og2?Oom`Sg00Som`Sg0_l0000A
ooh1oP?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003onPGjooX5nP04ooX5nPoo00003?nm@[d00ol0003oKY5^ofjAKP04ofjA
KP?o00002?m2_D800ol0003oD:m@oe2_D002oe2_D005o`000?m;]4_oBkA;od^dBol000003?m[U6/0
0ol0003oVfBKoi]TV`09oi]TV`03o`000?o@;m3od2o@00God2o@3?l00002oo`3o0;o00003Oon0Oh2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?o[5>_ojaC[00_ojaC[00?o0000oke2
_Onm@[d02_nm@[d00ol0003oKY5^ofjAKP07ofjAKP;o00001Om2_D800ol0003oD:m@oe2_D003oe2_
D003o`000?m;]4_oBkA;00;oBkA;00?o0000of^DJom[U6/02Om[U6/00ol0003oVfBKoi]TV`0:oi]T
V`03o`000?o@;m3od2o@00?od2o@00?o0000oo@;m?od2o@02Ood2o@00ol0003oo0?loo`3o002oo`3
o0;o00002Oon0Oh2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?o[5>_ojaC[00[o
jaC[00?o0000oke2_Onm@[d02onm@[d00ol0003oKY5^ofjAKP09ofjAKP?o000000?o@[e2o`000?m@
[e001Om@[e000ol0003oBkA;od^dB`03od^dB`03o`000?m[U6_oJiA[00SoJiA[3_l00003om0_d0;o
00002ood2o@00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ol0o`o`00000;on/Dj`03o`000?nm@[go_D:m00[o_D:m
0_l0000>ofjAKP03o`000?m@[e3oD:m@00GoD:m@00?o0000od^dBom;]4/00om;]4/00ol0003oJiA[
of^DJ`08of^DJ`03o`000?o@;m3od2o@00_od2o@00?o0000om0_d?l000003Ood2o@00ol0003oo0?l
oo`3o006oo`3o0;o000000?ooP7no`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00KonPGj00Co
0000oo0?l?o`3o3o00002_o[5>/00ol0003o_D:moke2_@09oke2_@03o`000?nRGJ;o000000koKY5^
00?o0000oe2_D?m@[e001Om@[e000ol0003oBkA;od^dB`04od^dB`03o`000?m[U6_oJiA[00KoJiA[
00?o0000om0_d?o@;m003Oo@;m000ol0003om0_doo@;m00<oo@;m003o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo0?l?o`3o000_o`
3o000ol0003ojaC[on/Dj`06on/Dj`03o`000?nm@[go_D:m00So_D:m0_l00003oj9MXP03o`000?m^
TFkoKY5^00_oKY5^00?o0000oe2_D?m@[e001Om@[e000ol0003oBkA;od^dB`05od^dB`03o`000?m[
U6_oJiA[00GoJiA[00?o0000om0_d?o@;m003Oo@;m000ol0003om0_doo@;m00;oo@;m003o`000?ol
0ocoo0?l00Woo0?l00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000
oo0?l?o`3o000oo`3o000ol0003ojaC[on/Dj`05on/Dj`03o`000?nm@[go_D:m00Oo_D:m00?o0000
oj9MX_nRGJ800onRGJ800ol0003oKY5^ofjAKP0:ofjAKP03o`000?m@[e3oD:m@00KoD:m@00?o0000
od^dBom;]4/01_m;]4/00ol0003oJiA[of^DJ`04of^DJ`03o`000?o@;m3od2o@00god2o@3ol0000;
oo`3o003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000oo0?l?o`3o001Oo`3o000ol0
003ojaC[on/Dj`04on/Dj`03o`000?nm@[go_D:m00Go_D:m0_l00006oj9MXP03o`000?m^TFkoKY5^
00WoKY5^0_l00008oe2_D003o`000?m;]4_oBkA;00KoBkA;1Ol000000om[U6_o0000om0_d00?om0_
d003o`000?oe2_Gom@[e00_om@[e00?o0000oo`3o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?oj1O[onPGj00KonPGj00?o0000oo0?l?o`3o001_o`3o000ol0003o
jaC[on/Dj`04o`0000Ko_D:m00?o0000oj9MX_nRGJ801onRGJ800ol0003oKY5^ofjAKP05ofjAKP?o
000000?oKI9]o`000?m@[e001om@[e000ol0003oBkA;od^dB`05od^dB`03o`000?n8MhSoR7N800?o
R7N80_l0000?om0_d0;o00003Ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000WonPGj00?o0000oo0?l?o`3o001oo`3o02o`0000CoebSG00Co0000oke2_Onm@[go
_D:m0_l0000:oj9MXP03o`000?m^TFkoKY5^00;oKY5^0ol00005offBK@03o`000?m@[e3oD:m@00Go
D:m@00?o0000od^dBom;]4/01?m;]4/00ol0003oR7N8ohQgR006ohQgR003o`000?o@;m3od2o@00[o
d2o@0_l00002onXEjP03o`000?oe2_Gom@[e00[om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l008oo0?l003o`00
0?oG:=OoebSG00CoebSG00?o0000oke2_Ol000003?nRGJ800ol0003oKY5^o`000002o`0000WoKI9]
00?o0000oe2_D?m@[e001?m@[e000ol0003oBkA;od^dB`03od^dB`03o`000?n8MhSoR7N800SoR7N8
1_l00004om0_d0;o00001OoZ5NX00ol0003om@[eooD:m@09ooD:m@03o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000oo0?l?o`3o001oo`
3o000ol0003oebSGomLXe`06omLXe`03o`000?nRGJ;oXUfR00coXUfR00?o0000offBKOm]TVd02_m]
TVd00ol0003oD:m@oe2_D004oe2_D004o`000?m;]4_oBkA;od^dB`;o00002on8MhP00ol0003oeB[E
omDZe@03omDZe@Co00002?oZ5NX00ol0003om@[eooD:m@08ooD:m@03o`000?ol0ocoo0?l00Ooo0?l
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX00ooj1OX00ol0003ol0o`oo0?l007oo0?l003o`000?oG
:=OoebSG00OoebSG00?o0000oj9MX_nRGJ803?nRGJ800ol0003oKI9]offBK@0;offBK@03o`000?m@
[e3oD:m@00?oD:m@00Co0000od^dBom;]4_o00003On8MhP00ol0003oeB[EomDZe@06omDZe@03o`00
0?oZ5N[ojQGZ00OojQGZ00?o0000ooD:mOoe2_D01ooe2_D00ol0003oo0?loo`3o006oo`3o004o`00
0?oo0?ooo`3oool0o`;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00;onPGj00?o0000oo0?l?o`3o00
1_o`3o000ol0003oebSGomLXe`09omLXe`03o`000?nRGJ;oXUfR00WoXUfR0_l0000>offBK@?o0000
0om@[e000ol0003oBkA;o`00000=ohQgR003o`000?oE:]GoeB[E00OoeB[E00?o0000onXEj_oZ5NX0
2?oZ5NX:o`0000Koo0?l0_l00006ool0o`03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Ool0o`00?o
0000omLXeooG:=L02_oG:=L00ol0003oXUfRoj9MXP06oj9MXP;o000000?oX5nPo`000?m]TVd02om]
TVd2o`0000?oM8]d1Ol0000>ohQgR003o`000?oE:]GoeB[E00OoeB[E00?o0000onXEj_oZ5NX02?oZ
5NX00ol0003on@KiooT6n@06ooT6n@03o`000?ol0ocoo0?l00?oo0?l00?o0000ool0oooo0?l01ooo
0?l2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP03ooH9mPCo00000_o`3o000ol0003oebSGomLXe`0;
omLXe`03o`000?nRGJ;oXUfR00?oXUfR0ol00004oj1OX003o`000?m]TVgoKI9]00OoKI9]0_l00008
ogB;M003o`000?n8MhSoR7N800goR7N800?o0000omDZeOoE:]D02?oE:]D00ol0003ojQGZonXEjP07
onXEjP03o`000?oi1_Won@Ki00Oon@Ki0ol000000ool0oco0000ool0o`0;ool0o`;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?of2OKomPWf00OomPWf0_l0000?omLXe`03o`000?nRGJ;oXUfR00;o00002?nPGj000ol0
003oKI9]offBK@05offBK@03o`000?mdRgCoM8]d00SoM8]d00?o0000ohQgR?n8MhP03On8MhP00ol0
003oeB[EomDZe@08omDZe@03o`000?oZ5N[ojQGZ00KojQGZ00?o0000ooT6nOoi1_T02?oi1_T01?l0
003oo@;mood2oOl0000?ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003omPWfooH9mP09ooH9
mP03o`000?oG:=OoebSG00koebSG0_l0000;oj1OX003o`000?m]TVgoKI9]00;oKI9]0_l0000;ogB;
M003o`000?n8MhSoR7N800goR7N800?o0000omDZeOoE:]D02?oE:]D00ol0003ojQGZonXEjP06onXE
jP03o`000?oi1_Won@Ki00Oon@Ki00Go0000ood2oOom0_goo@;mo`00000@ool0o`;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003omPWfooH9mP0:ooH9mP03o`000?oG:=OoebSG00goebSG0_l0000<oj1OX004o`000?m]TVgo0000
o`0000goM8]d00?o0000ohQgR?n8MhP03?n8MhP00ol0003oeB[EomDZe@09omDZe@03o`000?oZ5N[o
jQGZ00KojQGZ00?o0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003omPWfooH9mP0:ooH9mP03o`000?oG:=OoebSG00coebSG00Co0000omPW
f?oH9mSo00003?nPGj000ol0003oM8]dogB;M00>ogB;M003o`000?n8MhSoR7N800SoR7N81?l0000;
omDZe@03o`000?oZ5N[ojQGZ00KojQGZ00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oo@;mood2o@04
ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003omPWfooH9mP0;ooH9mP03o`000?oG:=OoebSG
00_oebSG00?o0000omPWf?oH9mP00_oH9mP00ol0003oX5nPoj1OX009oj1OX003o`000?mdRgCoM8]d
00koM8]d00Co0000ohQgR?n8MhSoR7N81ol00003ojeB[@03o`000?oE:]GoeB[E00WoeB[E00?o0000
onXEj_oZ5NX01_oZ5NX00ol0003on@KiooT6n@04ooT6n@03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00comPWf00?o0000omLXeooG:=L02_oG:=L00ol0
003of2OHomPWf003omPWf003o`000?nPGj3oX5nP00SoX5nP00?o0000ogB;M?mdRg@03_mdRg@4o`00
00_o[E:]00?o0000omDZeOoE:]D02?oE:]D00ol0003ojQGZonXEjP05onXEjP03o`000?oi1_Won@Ki
00Gon@Ki00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooH9m_of
2OH03?of2OH7o`0000GoebSG00?o0000omPWf?oH9mP01OoH9mP00ol0003oX5nPoj1OX007oj1OX003
o`000?mdRgCoM8]d00koM8]d00?o0000ojeB[On]DZd03On]DZd00ol0003oeB[EomDZe@08omDZe@03
o`000?oZ5N[ojQGZ00CojQGZ00?o0000ooT6nOoi1_T01?oi1_T00ol0003oo@;mood2o@07ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003omPWfooH9mP0=ooH9mP03o`000?oZ5N[ojQGZ00CojQGZ
1Ol00009omPWf003o`000?nPGj3oX5nP00KoX5nP00?o0000ogB;M?mdRg@03_mdRg@00ol0003o[E:]
ojeB[@0=ojeB[@03o`000?oE:]GoeB[E00SoeB[E00Co0000onXEj_oZ5N[ojQGZ1Ol00004ooT6n@03
o`000?om0_goo@;m00Woo@;m1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooH9mP03o`000?oZ5N[ojQGZ00WojQGZ
0_l00009omPWf003o`000?nPGj3oX5nP00KoX5nP00?o0000ogB;M?mdRg@03?mdRg@00ol0003o[E:]
ojeB[@0?ojeB[@Ko00001?oE:]D4o`0000GomPWf0_l000000ooi1_Wo0000ood2o@0;ood2o@04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?ok1?_on`Ckoo/4n`?o00002_of2OH00ol0003o
jQGZonXEjP09onXEjP03o`000?oR7N;o000000;o00001ooH9mP00ol0003oX5nPoj1OX005oj1OX003
o`000?mdRgCoM8]d00SoM8]d1Ol0000AojeB[@03o`000?oN8MkogR7N00?ogR7N1?l0000;ooH9mP03
o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000OomPWf
00?o0000onXEj_oZ5NX02_oZ5NX00ol0003ohQgRon8MhP02on8MhP?o00001OoH9mP00ol0003oX5nP
oj1OX004oj1OX004o`000?mdRgCoM8]dogB;M0Oo00001?n^DJh00ol0003o[E:]ojeB[@0>ojeB[@03
o`000?oN8MkogR7N00OogR7N00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@09ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`08oo/4n`;o00001?of2OH00ol0003ojQGZ
onXEjP0;onXEjP03o`000?oR7N;ohQgR00GohQgR0ol00003omPWf004o`000?nPGj3oX5nPoj1OX0Ko
00003?n^DJh00ol0003o[E:]ojeB[@0=ojeB[@03o`000?oN8MkogR7N00OogR7N00?o0000ooH9m_of
2OH02_of2OH00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo/4n`?o000000?omPWfo`000?oZ5NX0
3?oZ5NX00ol0003ohQgRon8MhP08on8MhP?o000000Cof2OHo`000?l0003o00000_oD:m@00ol0003o
[U6^ojiA[P0=ojiA[P03o`000?n]DZgo[E:]00co[E:]00?o0000omhQg_oN8Mh02?oN8Mh00ol0003o
mPWfooH9mP0;ooH9mP03o`000?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
n`Ck00?o0000onXEj_oZ5NX03?oZ5NX00ol0003ohQgRon8MhP0;on8MhP03o`000?oD:mCoe2_D00?o
e2_D00?o0000ojiA[_n^DJh03?n^DJh00ol0003o`3o0o`00000=ojeB[@03o`000?oN8MkogR7N00So
gR7N00?o0000ooH9m_of2OH03?of2OH3o`0000Goo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ok1?_on`Ck00con`Ck00?o0000onXEj_oZ5NX03?oZ5NX00ol0003ohQgRon8MhP0:on8MhP03o`00
0?oD:mCoe2_D00Goe2_D00?o0000ojiA[_n^DJh02_n^DJh01?l0003o`3o0ol0o`?o0?l02o`0000[o
[E:]00?o0000omhQg_oN8Mh02OoN8Mh00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00?o
000000?oo@;mo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onXEj_oZ5NX0
3?oZ5NX00ol0003ohQgRon8MhP09on8MhP03o`000?oD:mCoe2_D00Koe2_D00?o0000ojiA[_n^DJh0
2On^DJh00ol0003o`3o0ol0o`002ol0o`003o`000?oG:=Oo000000;o00001on]DZd00ol0003ogR7N
omhQgP09omhQgP03o`000?of2OKomPWf00_omPWf00?o0000ood2oOom0_d01?om0_d00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000oo/4nook1?/02ook1?/00ol0003ojQGZonXEjP0;onXEjP03o`000?oR
7N;ohQgR00SohQgR00?o0000om@[e?oD:m@01ooD:m@00ol0003o[U6^ojiA[P08ojiA[P03o`000?o0
?l3o`3o000?o`3o000?o0000omLXeooG:=L00_oG:=L2o`0000Co[E:]00?o0000omhQg_oN8Mh02_oN
8Mh00ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?ok1?_on`Ck00[on`Ck0ol0000;onXEjPKo00001?oR7N800ol0003oe2_Dom@[e008
om@[e003o`000?n^DJko[U6^00Oo[U6^00?o0000ol0o`?o0?l000oo0?l000ol0003oebSGomLXe`05
omLXe`?o000000?o[E:]o`000?oN8Mh02ooN8Mh00ol0003omPWfooH9mP09ooH9mP03o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00?o0000ooP7
n?oh1oP01?l00006onXEjP03o`000?o/4ncok1?/00Cok1?/1?l0000<om@[e003o`000?n^DJko[U6^
00Go[U6^00?o0000ol0o`?o0?l001?o0?l000ol0003oebSGomLXe`08omLXe`03o`000?oN8MkogR7N
00_ogR7N00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@08ood2o@Go00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?ok1?_on`Ck00Oon`Ck00?o0000ooP7n?oh1oP01Ooh1oP3o`0000;ojQGZ00?o0000on`Ck?o/
4n`02?o/4n`00ol0003oe2_Dom@[e00:om@[e003o`000?n^DJko[U6^00Co[U6^00?o0000ol0o`?o0
?l001Oo0?l000ol0003oebSGomLXe`08omLXe`03o`000?oN8MkogR7N00WogR7N1?l00008ooH9mP03
o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh0_l0000<on`Ck003o`000?oD:mCoe2_D00Woe2_D
00?o0000ojiA[_n^DJh00on^DJh00ol0003o`3o0ol0o`005ol0o`003o`000?oG:=OoebSG00[oebSG
00?o0000omhQg_oN8Mh01?oN8Mh4o`0000Col`cc00?o0000ooH9m_of2OH01?of2OH00ol0003oo@;m
ood2o@0:ood2o@03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7n?oh1oP02ooh
1oP00ol0003ok1?/on`Ck00:on`Ck003o`000?oD:mCoe2_D00Woe2_D00?o0000ojiA[_n^DJh00_n^
DJh00ol0003o`3o0ol0o`006ol0o`003o`000?oG:=OoebSG00[oebSG00?o0000omhQg_oN8Mh01?l0
0009oo<<l`Ko00003?om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000oo/4nook1?_on`Ck0_l0
000=ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000om@[e?oD:m@02OoD:m@01Ol0003o[U6^ojiA
[_n^DJko000000Wo`3o000?o0000omLXeooG:=L02ooG:=L2o`0000gol`cc00?o0000oo`3o?ol0o`0
0_ol0o`00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Cko`00
0002ooh1oP;o00002ooh1oP00ol0003ok1?/on`Ck00;on`Ck003o`000?oD:mCoe2_D00Woe2_D00?o
0000ojiA[_l000002Oo0?l000ol0003oebSGomLXe`0<omLXe`03o`000?oc3??ol`cc00col`cc00?o
0000oo`3o?ol0o`00ool0o`00ol0003oo@;mood2o@09ood2o@03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oh1oP00ol0003ok1?/on`Ck00:on`Ck003o`000?oD:mCo
e2_D00Soe2_D1Ol00008ol0o`003o`000?oG:=OoebSG00coebSG00?o0000oo<<looc3?<02ooc3?<0
0ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001oon0Oh2o`0000Son0Oh00?o0000on`Ck?o/4n`02_o/4n`00ol0003oe2_Dom@[e007om@[
e003o`000?oL8mcog2?L00?og2?L0ol00005ol0o`003o`000?oG:=OoebSG00_oebSG00?o0000oo<<
looc3?<03?oc3?<00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?oo0?oo000000WooP7n00?o0000ooP7n?oh1oP01Ooh1oP2o`0000co
k1?/00?o0000om@[e?oD:m@01OoD:m@00ol0003og2?Lom`Sg007om`Sg0?o000000?o`3o0o`000?oG
:=L03OoG:=L00ol0003ol`ccoo<<l`0<oo<<l`03o`000?ol0ocoo0?l00Koo0?l00?o0000ood2oOom
0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooP7n003o`000?oj1O[onPGj00;o00002_o/4n`00ol0003oe2_Dom@[e003om@[e0;o0000
3OoL8m`2o`0000goebSG0ol0000=oo<<l`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ood2oOom0_d0
1Oom0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooh1oSo0000ooX5nP04ooX5nP03o`000?o/4ncok1?/00Ook1?/00Co0000om@[e?oD:mCoe2_D
0_l00002oo0?l003o`000?oL8mcog2?L00cog2?L3Ol00003ooD:m@03o`000?oc3??ol`cc00[ol`cc
00?o0000oo`3o?ol0o`02?ol0o`01?l0003oo@;mood2oOom0_d4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj0_l00008on`Ck003o`000?oD:mCo000000Gol0o`
00?o0000om`Sg?oL8m`02ooL8m`00ol0003oi1_Ton@Ki009on@Ki003o`000?oe2_Gom@[e00;om@[e
0_l00009oo<<l`03o`000?ol0ocoo0?l00[oo0?l0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX01ooj1OX4o`0000?ok1?/0ol0
0007oo0?l003o`000?oL8mcog2?L00[og2?L00?o0000on@Ki?oT6n@02OoT6n@00ol0003om@[eooD:
m@04ooD:m@;o00001ooc3?<00ol0003oo0?loo`3o00:oo`3o003o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj1OX02?oj1OX0
1?l0003onPGjooX5n_oj1OX3o`0000;om`Sg00?o0000oo0?l?o`3o001_o`3o000ol0003og2?Lom`S
g008om`Sg003o`000?oT6nCoi1_T00[oi1_T00?o0000ooD:mOoe2_D01_oe2_D00ol0003ol`ccoo<<
l`04oo<<l`03o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[o
nPGj00ConPGj00Go0000ooL8moog2?Oom`Sgo`000008oo0?l003o`000?oL8mcog2?L00Oog2?L00?o
0000on@Ki?oT6n@02_oT6n@00ol0003om@[eooD:m@07ooD:m@;o00001?oc3?<00ol0003oo0?loo`3
o008oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP08ooX5nP03o`000?oj1O[onPGj00ConPGj00?o0000ooL8moog2?L00_og2?L0
0ol0003ol0o`oo0?l007oo0?l003o`000?oL8mcog2?L00Kog2?L00?o0000on@Ki?oT6n@02_oT6n@0
0ol0003om@[eooD:m@09ooD:m@05o`000?oc3??ol`ccoo<<lol000002Ool0o`00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_onPGj00?o0000ooX5n_oj1OX01?oj1OX00ol0003om`SgooL8m`03
ooL8m`03o`000?o`3o3ol0o`00Ool0o`00?o0000om`Sg?oL8m`01OoL8m`00ol0003oi1_Ton@Ki00:
on@Ki003o`000?oe2_Gom@[e00Wom@[e1?l00009oo`3o003o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_oj1OX00ol0003onPGjooX5nP05ooX5nP03o`000?og2?Oom`Sg00?om`Sg00?o0000
oo0?l?o`3o002?o`3o000ol0003og2?Lom`Sg004om`Sg003o`000?oT6nCoi1_T00Woi1_T00?o0000
ooD:mOoe2_D02?oe2_D2o`0000?oo@;m00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP06ooX5nP03o`000?oj1O[onPGj
00GonPGj00?o0000ooL8moog2?L01?og2?L00ol0003ol0o`oo0?l009oo0?l003o`000?oL8mcog2?L
00;og2?L00?o0000on@Ki?oT6n@02_oT6n@00ol0003om@[eooD:m@06ooD:m@;o00001_om0_d8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooX5n_oj
1OX01Ooj1OX00ol0003om`SgooL8m`05ooL8m`03o`000?o`3o3ol0o`00Wol0o`00Go0000om`Sg?oL
8mcog2?Lo`00000<on@Ki003o`000?oe2_Gom@[e00Com@[e0_l00008ood2o@03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003onPGjooX5nP06ooX5nP03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo0?l?o`
3o002_o`3o000ol0003og2?Lo`000004o`0000Woi1_T00?o0000ooD:mOoe2_D00_oe2_D2o`0000[o
o@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?oj1O[onPGj00;onPGj00?o0000ooX5n_oj1OX01_oj1OX00ol0003om`SgooL8m`07ooL8m`;o0000
2oo`3o000ol0003om`SgooL8m`03ooL8m`Oo00000_oT6n@00ol0003om@[eooD:m@02o`0000_oo@;m
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003onPGjooX5n_oj1O[o000000SonPGj00?o0000ooL8moog2?L01oog2?L00ol0003on`Ck
o`000002o`0000Sol0o`00?o0000ooL8moog2?L02_og2?L5o`0000goo@;m00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?oj1O[o000000WonPGj00?o
0000ooL8moog2?L01_og2?L00ol0003on`Ckoo/4n`03oo/4n`?o00001?o`3o000ol0003om`SgooL8
m`0=ooL8m`03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003om`SgooL8m`07
ooL8m`03o`000?ok1?_on`Ck00Kon`Ck0ol000000oo`3o3o0000ooL8m`0>ooL8m`03o`000?om0_go
o@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?oj1O[onPGj00;onPGj1_l00008ooL8m`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8
moog2?L03oog2?L00ol0003oo@;mood2o@0:ood2o@;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_ol0o`00ol0003om`SgooL8m`05ooL8m`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000ooL8moog2?L03oog2?L00ol0003oo@;mood2o@07ood2o@?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?ol0ocoo0?l00Woo0?l00?o0000ooL8moog
2?L00oog2?L00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00oom`Sg00?o0000ood2oOom
0_d01Oom0_d2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Ool0o`00ol0003om`SgooL8m`02ooL8m`03o`000?ok1?_on`Ck00_on`Ck5?l00004ood2o@;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>oo`3o004o`000?og2?Oom`Sgo`0000kon`Ck
00?o0000ood2oOom0_d04?om0_d00ol0003oo@;mo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_ol0o`00ol0003om`Sgo`00000>oo/4n`03o`00
0?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?ok1?_on`Ck00Won`Ck1Ol0
000Bood2o@;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo0?loo`3o00<oo`3o003o`000?ok1?_on`Ck00;on`Ck1ol00004ooh1oP03o`000?om0_go
o@;m00ooo@;m00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?ol0ocoo0?l00coo0?l1?l0000<ooh1oP03o`000?om0_goo@;m00coo@;m0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00_o
o@;m00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?on0OkooP7n00kooP7n00?o0000ood2oOom
0_d02Oom0_d2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?om0_goo@;m00Koo@;m0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aooh1oP?o00001_om0_d00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?on0OkooP7nooh1o_l000000oom0_d2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00?ooP7n00?o0000ood2oOl000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1
o_on0Oh02oon0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00Ko
oP7n00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP08ooh1oP03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1
oP07ooh1oP;o00002oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
oP7nooh1oP03ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?on0OkooP7no`0001?ooP7n
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004oon0Oh2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ooh1oP03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000kooP7n0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_ooP7n00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ooh1oPCo0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool02ol00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l2oooo00?o003o0_ooo`09o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0007o`00o`;oool01Ol00?l00oooo`3o003oo`00o`07o`00o`;oool01Ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Oo003o0_ooo`05o`00o`;oool02?l00?l2oooo
00Go003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000Ko003o0_ooo`06o`00o`;oool000?o003ooooo0?oo
o`002_ooo`02o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
00?o003ooooo0?ooo`002_ooo`000ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`02o`00o`04oooo0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o
0_ooo`04o`00o`;oool01?l00?l3oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo0003o`00
ooooo`3o003o00Go003o0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`06o`00o`;oool0
1Ol00?l3oooo00;o003o00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00Ko003o0oooo`03o`00o`?oool01?l00?l00oooo`3o003oo`00o`02o`00o`;oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0006o`00o`;oool000?o003ooooo0?ooo`000ooo
o`05o`00o`;oool00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03o`00o`?oool00ol00?l3
oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00Oo003o00?oool0o`00ool00?l02_l00?l0
1?ooo`3o003oo`00ool00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Ooo
ool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01ol00?l2
oooo00co003o00?oool0o`00ool00?l00_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1W
o`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo
00So003o00?oool0o`00ool00?l02ol00?l01?ooo`3o003ooooo0?ooo`04o`00o`;oool01_l00?l0
0oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00
o`;oool06?l00?l2oooo00So003o0_ooo`0<o`00o`04oooo0?l00?ooool0oooo00Go003o0_ooo`04
o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01ol00?l00ooo
o`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l01_l00?l2oooo00co003o0oooo`05o`00
o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go
003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`08o`00o`;oool02ol00?l2oooo00Ko
003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0
oooo0005oooo00?o003o1Oooo`0Uo`00o`?oool02?l00?l2oooo00Oo003o1?ooo`1bo`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(650) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.992 .008 .992 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.992 .008 .992 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.987 .013 .987 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.982 .018 .982 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.992 .008 .992 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.981 .019 .981 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.953 .047 .953 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.964 .036 .964 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.918 .082 .918 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.976 .024 .976 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.991 .009 .991 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.841 .159 .841 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.979 .021 .979 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.952 .048 .952 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.95 .05 .95 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.959 .041 .959 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.968 .032 .968 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.983 .017 .983 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.934 .066 .934 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.969 .031 .969 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.893 .107 .893 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.981 .019 .981 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.964 .036 .964 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.94 .06 .94 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.965 .035 .965 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.855 .145 .855 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.975 .025 .975 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.942 .058 .942 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.981 .019 .981 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.894 .106 .894 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.656 .344 .656 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.724 .276 .724 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.971 .029 .971 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.912 .088 .912 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.921 .079 .921 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.675 .325 .675 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.639 .361 .639 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.596 .404 .596 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.9 .1 .9 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.918 .082 .918 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.898 .102 .898 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.846 .154 .846 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.753 .247 .753 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.98 .02 .98 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.955 .045 .955 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.686 .314 .686 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.623 .377 .623 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.849 .151 .849 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.357 .643 .357 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.352 .648 .352 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.396 .604 .396 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.746 .254 .746 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.746 .254 .746 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.979 .021 .979 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.351 .649 .351 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.324 .676 .324 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.927 .073 .927 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.533 .467 .533 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.643 .357 .643 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.889 .111 .889 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.877 .123 .877 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.567 .433 .567 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.849 .151 .849 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.288 .712 .288 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.76 .24 .76 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.635 .365 .635 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.082 .918 .082 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.257 .743 .257 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.966 .034 .966 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.145 .855 .145 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.12 .88 .12 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.835 .165 .835 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.969 .031 .969 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.379 .621 .379 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.095 .905 .095 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.161 .839 .161 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.722 .278 .722 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.243 .757 .243 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.44 .56 .44 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.983 .017 .983 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.114 .886 .114 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.08 .92 .08 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.264 .736 .264 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.435 .565 .435 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.94 .06 .94 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.463 .537 .463 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.529 .471 .529 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.011 .989 .011 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.055 .945 .055 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.079 .921 .079 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.688 .312 .688 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.864 .136 .864 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.909 .091 .909 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.34 .66 .34 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.758 .242 .758 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.99 .01 .99 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.111 .889 .111 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.323 .677 .323 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.03 .97 .03 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.207 .793 .207 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.798 .202 .798 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.302 .698 .302 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.061 .939 .061 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.969 .031 .969 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.991 .009 .991 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.845 .155 .845 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.894 .106 .894 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.165 .835 .165 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.959 .041 .959 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.541 .459 .541 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.537 .463 .537 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.028 .972 .028 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.171 .829 .171 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.427 .573 .427 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.685 .315 .685 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.037 .963 .037 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.978 .022 .978 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.155 .845 .155 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.162 .838 .162 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.961 .039 .961 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.408 .592 .408 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.298 .702 .298 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.21 .79 .21 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.198 .802 .198 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.875 .125 .875 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.855 .145 .855 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.837 .163 .837 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.111 .889 .111 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.453 .547 .453 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.613 .387 .613 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.818 .182 .818 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.953 .047 .953 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.986 .014 .986 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.405 .595 .405 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.682 .318 .682 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.283 .717 .283 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.937 .063 .937 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.918 .082 .918 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.996 .004 .996 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.82 .18 .82 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.962 .038 .962 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.989 .011 .989 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.392 .608 .392 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.52 .48 .52 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.982 .018 .982 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.385 .615 .385 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.872 .128 .872 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.627 .373 .627 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.768 .232 .768 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.536 .464 .536 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.968 .032 .968 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.955 .045 .955 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.961 .039 .961 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.975 .025 .975 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.697 .303 .697 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.991 .009 .991 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.936 .064 .936 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.608 .392 .608 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.661 .339 .661 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.814 .186 .814 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.81 .19 .81 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.99 .01 .99 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.939 .061 .939 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.987 .013 .987 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.723 .277 .723 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.976 .024 .976 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.925 .075 .925 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.897 .103 .897 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.877 .123 .877 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.812 .188 .812 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.848 .152 .848 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.993 .007 .993 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.766 .234 .766 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.882 .118 .882 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.938 .062 .938 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.967 .033 .967 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.949 .051 .949 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.959 .041 .959 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.975 .025 .975 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.94 .06 .94 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.841 .159 .841 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.931 .069 .931 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.958 .042 .958 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.977 .023 .977 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.972 .028 .972 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.977 .023 .977 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.952 .048 .952 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.99 .01 .99 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.992 .008 .992 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.981 .019 .981 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.959 .041 .959 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.989 .011 .989 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.974 .026 .974 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.981 .019 .981 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.994 .006 .994 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.985 .015 .985 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(660) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.992 .008 .992 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.992 .008 .992 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.988 .012 .988 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.982 .018 .982 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.982 .018 .982 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.955 .045 .955 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.965 .035 .965 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.92 .08 .92 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.977 .023 .977 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.991 .009 .991 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.992 .008 .992 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.845 .155 .845 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.979 .021 .979 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.954 .046 .954 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.951 .049 .951 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.96 .04 .96 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.969 .031 .969 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.984 .016 .984 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.935 .065 .935 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.969 .031 .969 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.895 .105 .895 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.981 .019 .981 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.965 .035 .965 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.942 .058 .942 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.966 .034 .966 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.859 .141 .859 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.976 .024 .976 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.943 .057 .943 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.981 .019 .981 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.896 .104 .896 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.662 .338 .662 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.729 .271 .729 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.972 .028 .972 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.914 .086 .914 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.922 .078 .922 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.68 .32 .68 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.644 .356 .644 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.601 .399 .601 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.902 .098 .902 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.92 .08 .92 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.901 .099 .901 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.849 .151 .849 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.756 .244 .756 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.981 .019 .981 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.956 .044 .956 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.691 .309 .691 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.628 .372 .628 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.851 .149 .851 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.362 .638 .362 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.357 .643 .357 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.403 .597 .403 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.75 .25 .75 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.751 .249 .751 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.98 .02 .98 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.358 .642 .358 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.33 .67 .33 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.93 .07 .93 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.988 .012 .988 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.538 .462 .538 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.649 .351 .649 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.892 .108 .892 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.996 .004 .996 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.88 .12 .88 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.572 .428 .572 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.852 .148 .852 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.293 .707 .293 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.766 .234 .766 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.642 .358 .642 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.991 .009 .991 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.085 .915 .085 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.262 .738 .262 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.967 .033 .967 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.151 .849 .151 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.124 .876 .124 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.839 .161 .839 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.97 .03 .97 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.386 .614 .386 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.099 .901 .099 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.165 .835 .165 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.728 .272 .728 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.248 .752 .248 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.447 .553 .447 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.984 .016 .984 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.12 .88 .12 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.083 .917 .083 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.27 .73 .27 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.443 .557 .443 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.942 .058 .942 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.47 .53 .47 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.537 .463 .537 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
0 1 0 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.012 .988 .012 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.058 .942 .058 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.083 .917 .083 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.695 .305 .695 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.868 .132 .868 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.911 .089 .911 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.348 .652 .348 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.763 .237 .763 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.99 .01 .99 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.118 .882 .118 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.33 .67 .33 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.035 .965 .035 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.21 .79 .21 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.802 .198 .802 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.309 .691 .309 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.064 .936 .064 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.97 .03 .97 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.991 .009 .991 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.849 .151 .849 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.898 .102 .898 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.17 .83 .17 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.96 .04 .96 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.548 .452 .548 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.541 .459 .541 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.033 .967 .033 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.176 .824 .176 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.433 .567 .433 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.692 .308 .692 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.042 .958 .042 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.996 .004 .996 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.979 .021 .979 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.158 .842 .158 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.169 .831 .169 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.962 .038 .962 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.414 .586 .414 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.305 .695 .305 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.215 .785 .215 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.201 .799 .201 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.879 .121 .879 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.857 .143 .857 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.841 .159 .841 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.116 .884 .116 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.459 .541 .459 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.618 .382 .618 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.822 .178 .822 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.955 .045 .955 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.986 .014 .986 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.412 .588 .412 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.687 .313 .687 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.289 .711 .289 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.939 .061 .939 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.921 .079 .921 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.823 .177 .823 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.963 .037 .963 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.989 .011 .989 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.399 .601 .399 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.527 .473 .527 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.982 .018 .982 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.395 .605 .395 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.875 .125 .875 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.63 .37 .63 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.773 .227 .773 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.542 .458 .542 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.969 .031 .969 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.956 .044 .956 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.962 .038 .962 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.976 .024 .976 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.703 .297 .703 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.991 .009 .991 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.938 .062 .938 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.615 .385 .615 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.667 .333 .667 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.818 .182 .818 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.814 .186 .814 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.99 .01 .99 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.94 .06 .94 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.987 .013 .987 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.73 .27 .73 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.977 .023 .977 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.927 .073 .927 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.9 .1 .9 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.88 .12 .88 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.816 .184 .816 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.85 .15 .85 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.77 .23 .77 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.886 .114 .886 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.94 .06 .94 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.968 .032 .968 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.95 .05 .95 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.96 .04 .96 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.976 .024 .976 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.942 .058 .942 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.844 .156 .844 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.933 .067 .933 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.959 .041 .959 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.978 .022 .978 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.973 .027 .973 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.978 .022 .978 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.954 .046 .954 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.99 .01 .99 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.992 .008 .992 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.982 .018 .982 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.96 .04 .96 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.989 .011 .989 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.974 .026 .974 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.981 .019 .981 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.985 .015 .985 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.996 .004 .996 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(670) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.992 .008 .992 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.988 .012 .988 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.983 .017 .983 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.983 .017 .983 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.956 .044 .956 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.966 .034 .966 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.922 .078 .922 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.977 .023 .977 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.992 .008 .992 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.849 .151 .849 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.979 .021 .979 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.955 .045 .955 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.952 .048 .952 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.961 .039 .961 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.97 .03 .97 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.984 .016 .984 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.937 .063 .937 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.97 .03 .97 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.898 .102 .898 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.982 .018 .982 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.966 .034 .966 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.944 .056 .944 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.966 .034 .966 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.862 .138 .862 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.977 .023 .977 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.944 .056 .944 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.982 .018 .982 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.898 .102 .898 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.668 .332 .668 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.734 .266 .734 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.973 .027 .973 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.916 .084 .916 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.924 .076 .924 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.686 .314 .686 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.649 .351 .649 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.606 .394 .606 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.904 .096 .904 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.922 .078 .922 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.903 .097 .903 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.853 .147 .853 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.758 .242 .758 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.981 .019 .981 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.957 .043 .957 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.697 .303 .697 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.632 .368 .632 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.853 .147 .853 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.368 .632 .368 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.363 .637 .363 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.41 .59 .41 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.754 .246 .754 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.755 .245 .755 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.98 .02 .98 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.365 .635 .365 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.336 .664 .336 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.932 .068 .932 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.989 .011 .989 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.543 .457 .543 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.655 .345 .655 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.894 .106 .894 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.883 .117 .883 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.578 .422 .578 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.855 .145 .855 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.298 .702 .298 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.772 .228 .772 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.648 .352 .648 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.088 .912 .088 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.266 .734 .266 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.968 .032 .968 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.156 .844 .156 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.129 .871 .129 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.843 .157 .843 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.971 .029 .971 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.393 .607 .393 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.103 .897 .103 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.169 .831 .169 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.734 .266 .734 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.253 .747 .253 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.454 .546 .454 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.984 .016 .984 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.126 .874 .126 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.087 .913 .087 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.275 .725 .275 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.451 .549 .451 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.944 .056 .944 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.477 .523 .477 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.545 .455 .545 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.003 .997 .003 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.012 .988 .012 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.061 .939 .061 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.087 .913 .087 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.701 .299 .701 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.871 .129 .871 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.913 .087 .913 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.355 .645 .355 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.769 .231 .769 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.124 .876 .124 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.337 .663 .337 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.04 .96 .04 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.214 .786 .214 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.806 .194 .806 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.315 .685 .315 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.068 .932 .068 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.971 .029 .971 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.991 .009 .991 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.853 .147 .853 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.901 .099 .901 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.176 .824 .176 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.961 .039 .961 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.554 .446 .554 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.545 .455 .545 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.038 .962 .038 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.18 .82 .18 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.439 .561 .439 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.698 .302 .698 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.047 .953 .047 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.979 .021 .979 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.045 .955 .045 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.161 .839 .161 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.176 .824 .176 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.963 .037 .963 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.42 .58 .42 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.99 .01 .99 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.312 .688 .312 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.219 .781 .219 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.204 .796 .204 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.882 .118 .882 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.86 .14 .86 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.845 .155 .845 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.121 .879 .121 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.464 .536 .464 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.623 .377 .623 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.826 .174 .826 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.956 .044 .956 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.987 .013 .987 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.418 .582 .418 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.692 .308 .692 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.295 .705 .295 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.94 .06 .94 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.923 .077 .923 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.826 .174 .826 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.964 .036 .964 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.989 .011 .989 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.407 .593 .407 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.533 .467 .533 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.983 .017 .983 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.404 .596 .404 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.878 .122 .878 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.634 .366 .634 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.777 .223 .777 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.549 .451 .549 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.97 .03 .97 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.957 .043 .957 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.962 .038 .962 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.976 .024 .976 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.709 .291 .709 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.992 .008 .992 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.939 .061 .939 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.622 .378 .622 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.673 .327 .673 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.821 .179 .821 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.819 .181 .819 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.996 .004 .996 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.99 .01 .99 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.941 .059 .941 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.988 .012 .988 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.736 .264 .736 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.977 .023 .977 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.929 .071 .929 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.903 .097 .903 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.883 .117 .883 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.821 .179 .821 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.997 .003 .997 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.852 .148 .852 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.775 .225 .775 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.995 .005 .995 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.889 .111 .889 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.941 .059 .941 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.969 .031 .969 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.952 .048 .952 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.961 .039 .961 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.976 .024 .976 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.944 .056 .944 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.848 .152 .848 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.935 .065 .935 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.96 .04 .96 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.978 .022 .978 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.974 .026 .974 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.979 .021 .979 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.955 .045 .955 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.99 .01 .99 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.992 .008 .992 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.982 .018 .982 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.962 .038 .962 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.99 .01 .99 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.975 .025 .975 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.982 .018 .982 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.986 .014 .986 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooh1oP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ooh1oP03o`000?l00?oo000000;o00002_on0Oh2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0<ooh1oP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?oo`3o0_l0000@ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo0?loo`3o?l0000>ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooh1o_on0Oh0
3_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?on0Oh03oon0Oh00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000oo`3o?ol0o`00_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?on
0OkooP7n00WooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?on0OkooP7n00kooP7n00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00?oo0?l00?o0000
ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?on0OkooP7n00oooP7n00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n
00_ooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o006oo`3o003
o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0@ooh1oP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?on0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00cooP7n
00?o0000ooh1o_on0Oh04?on0Oh<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_go0000013ooP7n00?o0000ool0oooo0?l02?oo
0?l9o`0000coo0?l00Co0000ool0oooo0?ooo`3o0ol0000@ooh1oP03o`000?on0OkooP7n00oooP7n
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ood2o@03o`000?on
0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003onPGjooX5nP05ooX5nP03o`000?ol
0ocoo0?l00_oo0?l0ol00003oo/4n`03o`000?on0OkooP7n00cooP7n0ol0000>ooh1oP;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ood2oOom0_d00oom0_d00ol0003ooP7nooh1oP0;ooh1oP;o00002ooo0?l00ol0003onPGjooX5nP06
ooX5nP03o`000?ol0ocoo0?l00[oo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP0:
ooh1oP04o`000?oj1O[onPGjooX5nP;o00002_on0Oh2o`000003ooT6nOl0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOl000002ooo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[o
nPGj00ConPGj0_l00005ooh1oP?o00001?oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ood2o@03o`000?on0OkooP7n00OooP7n0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo0?loo`3o009oo`3
o003o`000?ok1?_on`Ck00Oon`Ck00?o0000ooh1o_on0Oh01Oon0Oh2o`0000WonPGj0_l000000oon
0Oko0000o`000007ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ood2oOom
0_d02?om0_d00ol0003ooP7nooh1oP06ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003onPGjooX5nP08ooX5nP03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo/4nook
1?/02Ook1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mo`000005ool0o`;o00002oom0_d2o`0000KooP7n
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oj1O[onPGj00SonPGj
00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`0;oo/4n`05o`000?on0OkooP7nooh1o_l0
00003_oj1OX00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?om0_goo@;mood2oOl0
00000ooo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?oh1oSon0Oho`0000?ooP7n0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo0?loo`3o005oo`3
o003o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_l000003ooj1OX00ol0003on@KiooT6n@08ooT6
n@03o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo000000_o
o@;m0_l00004ooP7n003o`000?on0Oko000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
nPGjooX5nP09ooX5nP03o`000?ol0ocoo0?l00Coo0?l00?o0000oo/4nook1?/03_ok1?/00ol0003o
nPGjooX5nP0>ooX5nP03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ood2oOom0_d0
1?om0_d00ol0003oo@;mood2o@09ood2o@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oj1O[onPGj00[onPGj00?o0000oo`3o?ol0o`0
0ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oj1O[onPGj00gonPGj00?o0000ooT6nOoi1_T0
2_oi1_T00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2
o@05ood2o@03o`000?om0_goo@;m00Ooo@;m0_l00008ooP7n003o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003onPGjooX5nP0:ooX5nP04o`000?ol0ocoo0?loo`3o0?o0000
3ook1?/00ol0003onPGjooX5nP0>ooX5nP03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d01?om0_d2o`0000_on0Oh1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000ooX5n_oj1OX02ooj1OX01?l0003oo0?lo`00
0?l00003oo0?l0;o00003?ok1?/2o`00013onPGj00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00?oo@;m00?o0000ooP7n?oh1oP02ooh1oP01?l0003ojAKY
onTFjOoY5^T5o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003onPGjooX5nP0<ooX5nP03
o`000?o`3o3ol0o`00Gol0o`0_l00008oo/4n`;o00000_o`3o000ol0003onPGjooX5nP0=ooX5nP03
o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@09ood2o@03o`000?om0_goo@;m00;o0000
3Ooh1oP00ol0003ojAKYonTFj@07onTFj@Ko00000_oo0?l4o`0000gonPGj00?o0000oo0?l?o`3o00
1oo`3o02o`0000Gon`Ck00?o0000oo0?l?o`3o000oo`3o000ol0003onPGjooX5nP0<ooX5nP03o`00
0?oi1_Won@Ki00con@Ki00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Woo@;m00?o
0000ood2oOl000003ooh1oP00ol0003ojAKYonTFj@0<onTFj@?o00001?of2OH3o`0000WonPGj00?o
0000oo0?l?o`3o002_o`3o02o`000003oo/4nol0003o000000Ool0o`00?o0000ooX5n_oj1OX02ooj
1OX00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00KooP7n1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000
ooP7n?oh1oP03_oh1oP00ol0003ojAKYonTFj@0=onTFj@03o`000?of2OKomPWf00KomPWf0ol00005
ooX5nP03o`000?o`3o3ol0o`00gol0o`00?o0000oo0?l?o`3o002?o`3o000ol0003onPGjooX5nP09
ooX5nP03o`000?oi1_Won@Ki00gon@Ki00Co0000ooh1o_on0OkooP7n1Ol00003oo/4n`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ood2oOom0_d02oom0_d2o`0000oon0Oh00?o0000onTFjOoY5^T03OoY5^T00ol0003omPWfooH9mP0:
ooH9mP?o000000?onPGjo`000?o`3o003oo`3o000ol0003ol0o`oo0?l009oo0?l003o`000?oj1O[o
nPGj00SonPGj00?o0000ooT6nOoi1_T03_oi1_T3o`0000Son`Ck00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?om0_goo@;m00Soo@;m0ol000000ood
2oCo0000ooP7n00>ooP7n003o`000?oY5^WojAKY00gojAKY00?o0000ooH9m_of2OH03Oof2OH00ol0
003ol0o`oo0?l00?oo0?l003o`000?o`3o3ol0o`00[ol0o`2ol0000;ooT6n@Go00003?ok1?/00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003on`Cko`000?oo0?oo0000
00Soo@;m0ol00005oo@;m003o`000?oh1oSon0Oh00con0Oh00?o0000onTFjOoY5^T03OoY5^T00ol0
003omPWfooH9mP0=ooH9mP;o00004?o`3o000ol0003ol0o`oo0?l00:oo0?l003o`000?o]4^gokA;]
00OokA;]00?o0000ooT6nOoi1_T00_oi1_T7o`0000Col@ka00?o0000oo/4nook1?/02_ok1?/00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003on`Ckoo/4nook1?/2o`00
00Goo@;m0ol00009oo@;m0;o00002ooh1oP00ol0003ojAKYonTFj@0=onTFj@03o`000?of2OKomPWf
00gomPWf00Co0000om`Sg?oL8mco00003oo`3o000ol0003ol0o`oo0?l009oo0?l003o`000?o]4^go
kA;]00WokA;]1?l0000;oo4>l@03o`000?ok1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo/4nook1?/01?ok1?/00ol0003oo@;mo`000002o`00
00com0_d00Co0000on8Mh_l0003o00002Ooh1oP00ol0003ojAKYonTFj@0=onTFj@03o`000?of2OKo
mPWf00gomPWf00Go0000om`Sg?oL8mcog2?Lo`00000=oo0?l003o`000?o`3o3ol0o`00[ol0o`00?o
0000ondBkOo]4^d02Oo]4^d00ol0003ol@kaoo4>l@0<oo4>l@03o`000?ok1?_on`Ck00[on`Ck00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo/4nook1?/01_ok1?/0
0ol0003om0_doo@;m00<oo@;m003o`000?oR7N;ohQgR00;ohQgR0_l00007ooP7n003o`000?oY5^Wo
jAKY00cojAKY00?o0000ooH9m_of2OH03Oof2OH00ol0003og2?Lom`Sg003om`Sg003o`000?o`3o3o
l0o`00[ol0o`00?o0000oo0?l?o`3o002_o`3o000ol0003okA;]ondBk@09ondBk@03o`000?oa3_7o
l@ka00col@ka00?o0000oo/4nook1?/02ook1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?od2oCom0_d00_om0_d00?o0000on8M
h_oR7N801OoR7N800ol0003on0OhooP7n003ooP7n003o`000?oY5^WojAKY00gojAKY00?o0000ooH9
m_of2OH03Oof2OH00ol0003og2?Lom`Sg004om`Sg003o`000?o`3o3ol0o`00Wol0o`00?o0000oo0?
l?o`3o002Oo`3o000ol0003okA;]ondBk@0:ondBk@03o`000?oa3_7ol@ka00col@ka00?o0000oo/4
nook1?/02ook1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
n`Ckoo/4n`07oo/4n`03o`000?od2oCom0_d00_om0_d00?o0000on8Mh_oR7N801_oR7N82o`0000?o
n0Oh00?o0000onTFjOoY5^T03OoY5^T00ol0003omPWfooH9mP0<ooH9mP03o`000?oL8mcog2?L00Ko
g2?L00?o0000oo0?l?o`3o002?o`3o000ol0003ol0o`oo0?l009oo0?l003o`000?o]4^gokA;]00[o
kA;]00?o0000oo4>lOoa3_403?oa3_400ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000oo/4nook1?/02?ok1?/00ol0003om0_doo@;m00:oo@;m003o`00
0?oR7N;ohQgR00WohQgR0_l000000ooh1oSo0000onTFj@0<onTFj@?o00003_of2OH00ol0003og2?L
om`Sg007om`Sg003o`000?o`3o3ol0o`00Ool0o`00?o0000oo0?l?o`3o002Oo`3o000ol0003okA;]
ondBk@0;ondBk@03o`000?oa3_7ol@ka00col@ka00?o0000oo/4nook1?/02_ok1?/00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000oo/4nook1?/02_ok1?/00ol0003om0_doo@;
m009oo@;m003o`000?oR7N;ohQgR00_ohQgR00?o0000onTFjOoY5^T02_oY5^T2o`0000?ocS7>00?o
0000ooH9m_of2OH02_of2OH00ol0003og2?Lom`Sg009om`Sg003o`000?o`3o3ol0o`00Kol0o`00?o
0000oo0?l?o`3o002?o`3o000ol0003okA;]ondBk@0<ondBk@03o`000?oa3_7ol@ka00col@ka00?o
0000oo/4nook1?/02_ok1?/00ol0003oo`3oool0o`04ool0o`Co00000oon0Oh00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo@;m?od2o@02?od2o@0
0ol0003ohQgRon8MhP0<on8MhP03o`000?oY5^WojAKY00SojAKY0_l00006olhacP;o00002_of2OH0
0ol0003og2?Lom`Sg00:om`Sg003o`000?o`3o3ol0o`00Gol0o`00?o0000oo0?l?o`3o002?o`3o00
0ol0003okA;]ondBk@0<ondBk@03o`000?oa3_7ol@ka00col@ka00?o0000oo/4nook1?/02ook1?/0
0ol0003oo`3oo`000003o`0000SooP7n00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
oo/4n`03o`000?od2oCom0_d00Oom0_d00?o0000on8Mh_oR7N803_oR7N800ol0003ojAKYonTFj@04
onTFj@?o00002_o><Lh00ol0003omPWfooH9mP07ooH9mP03o`000?oL8mcog2?L00_og2?L00?o0000
oo0?l?o`3o000oo`3o000ol0003ol0o`oo0?l009oo0?l003o`000?o]4^gokA;]00cokA;]00?o0000
oo4>lOoa3_403?oa3_400ol0003on`Ckoo/4n`0;oo/4n`;o00003Oon0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003on`Ckoo/4n`0<oo/4n`03o`000?od2oCom0_d00Oom0_d00?o0000on8Mh_oR7N803ooR7N801?l0
003ojAKYonTFjOoY5^T2o`0000kocS7>0_l00006ooH9mP03o`000?oL8mcog2?L00gog2?L00?o0000
oo0?l?o`3o000_o`3o000ol0003ol0o`oo0?l008oo0?l003o`000?o]4^gokA;]00cokA;]0ol0000=
oo4>l@03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00oon`Ck00?o0000oo@;m?od2o@01_od2o@00ol0003ohQgRon8MhP0@on8MhPCo00004_o><Lh00ol0
003omPWfooH9mP03ooH9mP03o`000?oL8mcog2?L00kog2?L00Go0000oo0?l?o`3o3ol0o`o`000005
oo0?l0Oo00003?o]4^d01Ol0003ohacSon<LhooS7>?o000000col@ka00?o0000oo/4nook1?/02?ok
1?/3o`0000oooP7n00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000oon`Ck00?o0000oo@;m?od2o@01_od2o@00ol0003ohQgRon8MhP0=
on8MhP?o000000CoaC[5o`000?l0003o00004oo><Lh2o`0000;omPWf00?o0000om`Sg?oL8m`04?oL
8m`00ol0003ol0o`o`000006o`0000OodRgB00?o0000ondBkOo]4^d02?o]4^d00ol0003ohacSon<L
h`03on<Lh`;o00002?oa3_43o`0000Kon`Ck1?l00002ooT6n@03o`000?on0OkooP7n00kooP7n00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003oo@;mo`000?oa3_43o`0000gon`Ck00?o0000oo@;m?od2o@01?od2o@00ol0003ohQgRon8M
hP0;on8MhP?o00000oo5>/D01Ol0003o^dBko`000?n;M8_o000001CocS7>00?o0000ooH9m_l00000
4ooL8m`00ol0003odRgBom8]dP0=om8]dP03o`000?o]4^gokA;]00GokA;]0_l00008on<Lh`03o`00
0?oa3_7ol@ka00Go00000oo_4>l00ol0003on`Ckoo/4n`03o`0000Oon@Ki00?o0000ooh1o_on0Oh0
3Oon0Oh00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?om0_goo@;mo`0000Col@ka0ol0000:oo/4n`03o`000?od2oCom0_d00?om0_d
00?o0000on8Mh_oR7N802OoR7N83o`0000GoaC[500Co0000ok]4^onkA;_o00000_n;M8/00ol0003o
cS7>olhacP0BolhacP03o`000?oL8mcog2?L01;og2?L00?o0000om8]d_oB;M803_oB;M800ol0003o
kA;]ondBk@03ondBk@03o`000?oS7>?ohacS00WohacS0_l00009onl@k`;o00002_oi1_T00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ood2oOom0_goo@;mo`000007oo4>l@;o00001ook1?/5o`0000;o
m0_d00?o0000on8Mh_oR7N801_oR7N83o`0000SoaC[500Co0000ok]4^onkA;_o00000on;M8/00ol0
003ocS7>olhacP0AolhacP03o`000?oL8mcog2?L017og2?L00?o0000om8]d_oB;M804?oB;M801Ol0
003okA;]ondBkOo]4^go000000cohacS00?o0000onl@koo_4>l02?o_4>l00ol0003on@KiooT6n@0:
ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000Coo@;m00?o0000oo4>lOoa3_401ooa3_43o`00
0004oo/4nol0003o0000o`0000GoiaSW0_l00006on8MhP?o00002_o5>/D01Ol0003o^dBkok]4^onk
A;_o000000CoRgB;00?o0000olhac_o><Lh04?o><Lh00ol0003og2?Lom`Sg00Aom`Sg003o`000?oB
;M;odRgB017odRgB00?o0000ondBkOl000003OoS7><00ol0003oka3_onl@k`08onl@k`03o`000?oi
1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Coo@;m00?o0000
oo4>lOoa3_402_oa3_400ol0003oiaSWonLHi`08onLHi`03o`000?oR7N;ohQgR00?o00003Oo5>/D0
1Ol0003o^dBkok]4^onkA;_o000000GoRgB;00?o0000olhac_o><Lh03oo><Lh00ol0003og2?Lom`S
g00Aom`Sg003o`000?oB;M;odRgB01;odRgB00?o0000on<LhooS7><03?oS7><00ol0003oka3_onl@
k`08onl@k`03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ood2oOom0_d01Oom0_d0
0ol0003ol@kaoo4>l@0:oo4>l@03o`000?oW6>OoiaSW00WoiaSW0_l0000?olDja@03o`000?nkA;_o
^dBk00;o^dBk00?o0000oh]dRon;M8/01?n;M8/00ol0003ocS7>olhacP0=olhacP?o00004OoL8m`0
0ol0003odRgBom8]dP0Com8]dP03o`000?oS7>?ohacS00_ohacS00?o0000onl@koo_4>l02Oo_4>l0
0ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ooh1o_on0OkooP7no`000008ool0o`;o00002?om0_d0
0ol0003ol@kaoo4>l@0:oo4>l@03o`000?oW6>OoiaSW00WoiaSW00?o0000olDjaOo5>/D03Oo5>/D0
0ol0003o^dBkok]4^`03ok]4^`03o`000?n;M8_oRgB;00GoRgB;00?o0000olhac_o><Lh02_o><Lh2
o`0000?oRgB;00?o0000om`Sg?oL8m`03_oL8m`00ol0003odRgBom8]dP0Com8]dP03o`000?oS7>?o
hacS00_ohacS00?o0000onl@koo_4>l02Oo_4>l00ol0003on@KiooT6n@0;ooT6n@03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ooh1
o_on0Oh00oon0Oh2o`0000Goo`3o00?o0000ood2oOom0_d01oom0_d2o`0000_ol@ka00?o0000onLH
iooW6>L02ooW6>L00ol0003oaC[5olDja@0<olDja@03o`000?nkA;_o^dBk00?o^dBk00?o0000oh]d
Ron;M8/01_n;M8/00ol0003ocS7>olhacP07olhacP;o00001_n;M8/2o`0000kog2?L00?o0000om8]
d_oB;M804ooB;M800ol0003ohacSon<Lh`0;on<Lh`03o`000?o_4>ooka3_00Woka3_00?o0000ooT6
nOoi1_T03?oi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?on0OkooP7n00KooP7n00Go0000ool0oooo0?ooo`3oo`000009ood2
o@03o`000?oj1O[o000000_ol@ka00?o0000onLHiooW6>L02ooW6>L00ol0003oaC[5olDja@0;olDj
a@03o`000?nkA;_o^dBk00Co^dBk00?o0000oh]dRon;M8/01on;M8/00ol0003ocS7>olhacP05olha
cP03o`000?n;M8_oRgB;00SoRgB;00?o0000om`Sg?oL8m`02_oL8m`00ol0003odRgBom8]dP0Dom8]
dP03o`000?oS7>?ohacS00_ohacS00?o0000onl@koo_4>l02Oo_4>l00ol0003on@KiooT6n@0<ooT6
n@03o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oo`000009ood2o@04o`000?oj1O[onPGjo`00
00_ol@ka00?o0000onLHiooW6>L02ooW6>L00ol0003oaC[5olDja@0;olDja@03o`000?nkA;_o^dBk
00Co^dBk00?o0000oh]dRon;M8/02?n;M8/00ol0003ocS7>olhacP02olhacP;o00003?n;M8/2o`00
00[og2?L00?o0000om8]d_oB;M805?oB;M800ol0003ohacSon<Lh`0;on<Lh`03o`000?o_4>ooka3_
00Woka3_00?o0000ooT6nOoi1_T03Ooi1_T00ol0003ooP7nooh1oP06ooh1oP?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03
o`000?oj1O[onPGj00;onPGj00?o0000oo4>lOoa3_402?oa3_400ol0003oiaSWonLHi`0<onLHi`03
o`000?o5>/GoaC[500WoaC[500?o0000ok]4^onkA;/01OnkA;/00ol0003oRgB;oh]dR`09oh]dR`04
o`000?o><Lko0000o`00013oRgB;0_l00008om`Sg003o`000?oB;M;odRgB01CodRgB0ol0000;on<L
h`03o`000?o_4>ooka3_00Woka3_00?o0000ooT6nOoi1_T03Ooi1_T01?l0003ooP7nooh1o_on0Oh5
o`0000?ooP7n00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00?onPGj00?o0000oo4>
lOoa3_402?oa3_400ol0003oiaSWonLHi`0;onLHi`;o00002_o5>/D00ol0003o^dBkok]4^`06ok]4
^`03o`000?n;M8_oRgB;00[oRgB;00?o0000oh]dRon;M8/04_n;M8/00ol0003og2?Lom`Sg004om`S
g003o`000?oB;M;odRgB01GodRgB00?o0000olHia_o6>LH01Ol00005on<Lh`03o`000?o_4>ooka3_
00[oka3_00?o0000ooT6nOoi1_T03_oi1_T3o`0000WooP7n00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo@;mood2o@04ood2o@03
o`000?oj1O[onPGj00ConPGj00?o0000oo4>lOoa3_401ooa3_400ol0003oiaSWonLHi`0;onLHi`04
o`000?nbCK;o/Tfbo`0000WoaC[500?o0000ok]4^onkA;/01_nkA;/00ol0003oRgB;oh]dR`0:oh]d
R`03o`000?n;M8_oRgB;01?oRgB;0_l00003om`Sg0Co00005?oB;M800ol0003oaSW6olHiaP06olHi
aPCo000000?ohacSo`000?o_4>l02oo_4>l00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n
00[ooP7n00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ooh1o_on
0Oh02oon0Oh00ol0003oo@;mood2o@03ood2o@03o`000?oj1O[onPGj00GonPGj00?o0000oo4>lOoa
3_401ooa3_400ol0003oiaSWonLHi`09onLHi`;o00001?nbCK800ol0003oaC[5olDja@05olDja@03
o`000?nkA;_o^dBk00Oo^dBk00?o0000oh]dRon;M8/02_n;M8/00ol0003oRgB;oh]dR`0Eoh]dR`03
o`000?oL8mco000000CoXUfR0ol0000@om8]dP03o`000?o6>LKoaSW600_oaSW60_l0000<onl@k`03
o`000?oi1_Won@Ki00con@Ki0_l0000>ooh1oP03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ood2oOom0_d00_om0_d00ol0003onPGj
ooX5nP06ooX5nP03o`000?oa3_7ol@ka00Ool@ka00?o0000onLHiooW6>L02?oW6>L00ol0003o/Tfb
ok9=/P05ok9=/P03o`000?o5>/GoaC[500CoaC[500?o0000ok]4^onkA;/01onkA;/00ol0003oRgB;
oh]dR`0:oh]dR`03o`000?n;M8_oRgB;01KoRgB;00?o0000oj9MX_nRGJ801_nRGJ83o`0000codRgB
00?o0000olHia_o6>LH03Oo6>LH00ol0003oka3_onl@k`09onl@k`Go00002Ooi1_T2o`000003oo`3
o?l0003ooP7n00kooP7n00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ooh1o_on0Oh03?on0Oh3o`000003ood2oOl0003onPGj00WonPGj00?o0000oo4>lOoa3_401_oa
3_400ol0003oiaSWonLHi`07onLHi`03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000olDjaOo5>/D00_o5
>/D00ol0003o^dBkok]4^`08ok]4^`03o`000?n;M8_oRgB;00WoRgB;00?o0000oh]dRon;M8/05on;
M8/00ol0003oXUfRoj9MXP09oj9MXP?o00002OoB;M800ol0003oaSW6olHiaP0>olHiaPKo00001?o_
4>l00ol0003omPWfooH9mP03ooH9mPGo00000_oi1_T2o`0000Coo0?l00?o0000ooh1o_on0Oh03?on
0Oh00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP0<
ooh1oP05o`000?ok1?_on`Ckoo/4nol000002ooj1OX00ol0003ol@kaoo4>l@06oo4>l@03o`000?oW
6>OoiaSW00GoiaSW0_l0000;ok9=/P04o`000?o5>/GoaC[5o`0000_o^dBk00?o0000oh]dRon;M8/0
2On;M8/00ol0003oRgB;oh]dR`0Foh]dR`03o`000?nRGJ;oXUfR00goXUfR0ol00005om8]dP03o`00
0?o6>LKoaSW600ooaSW600?o0000omTVfOoI9]T00ooI9]T4o`0000_omPWf0_l00006oo`3o003o`00
0?on0OkooP7n00cooP7n00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`02oo/4n`ko00001_oa3_400ol0003oiaSWonLH
i`05onLHi`03o`000?nbCK;o/Tfb00co/Tfb00?o0000olDjaOl000002onkA;/00ol0003oRgB;oh]d
R`07oh]dR`?o00006?n;M8/00ol0003oXUfRoj9MXP0@oj9MXP?o000000?odRgBo`000?o6>LH04?o6
>LH00ol0003ofBKIomTVf@07omTVf@03o`000?of2OKomPWf00[omPWf00?o0000oo`3o?ol0o`01Ool
0o`00ol0003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?on0OkooP7n00WooP7n0_l00005oo/4n`03o`000?od2oCom0_d00_om0_d0_l00004
oo4>l@03o`000?oW6>OoiaSW00?oiaSW0_l0000@ok9=/P03o`000?nkA;_o^dBk00[o^dBk00?o0000
oh]dRon;M8/00on;M8/4o`0000;oFZEJ00?o0000oh]dRon;M8/05On;M8/00ol0003oXUfRoj9MXP0D
oj9MXP03o`000?o6>LKoaSW6013oaSW600?o0000omTVfOoI9]T01ooI9]T00ol0003omPWfooH9mP0:
ooH9mP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck
00Gon`Ck00?o0000oo@;m?od2o@03Ood2o@6o`0000?oiaSW00?o0000ok9=/_nbCK804?nbCK800ol0
003o^dBkok]4^`0:ok]4^`03o`000?n;M8_o000000?o00001omJYEX00ol0003oRgB;oh]dR`0Doh]d
R`03o`000?nRGJ;oXUfR01CoXUfR00?o0000olHia_o6>LH03oo6>LH00ol0003ofBKIomTVf@08omTV
f@03o`000?of2OKomPWf00[omPWf00?o0000oo`3o?ol0o`01Ool0o`00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/00ol0003om0_doo@;m00=oo@;m003o`000?oL8mcog2?L00?o
g2?L00?o0000onLHiol000004onbCK84o`0000Wo^dBk0_l0000<oeZUFP03o`000?n;M8_oRgB;01?o
RgB;00?o0000oj9MX_nRGJ805OnRGJ800ol0003oaSW6olHiaP0>olHiaP03o`000?oI9]WofBKI00So
fBKI00?o0000ooH9m_of2OH02Oof2OH00ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo@;m?od2o@02ood2o@00ol0003og2?Lom`Sg005om`Sg003o`00
0?nbCK;o/Tfb01;o/Tfb00Co0000ofBKI?mTVfCoI9]T1Ol00003ok]4^`03o`000?mJYE[oFZEJ00go
FZEJ0ol0000@oh]dR`;o00006?nRGJ800ol0003oaSW6olHiaP0=olHiaP03o`000?oI9]WofBKI00Wo
fBKI00?o0000ooH9m_of2OH02Oof2OH00ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00_o
oP7n00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_on`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003og2?Lom`Sg006om`Sg003o`00
0?nbCK;o/Tfb017o/Tfb00?o0000ofBKI?mTVf@01omTVf@3o`00013oFZEJ00?o0000obgB;Ol]dRd0
1Ol00009oh]dR`;o000000?oCk1?o`000?nRGJ805onRGJ800ol0003oaSW6olHiaP0=olHiaP03o`00
0?oI9]WofBKI00WofBKI00?o0000ooH9m_of2OH02?of2OH2o`0000[oo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003om0_doo@;
m00:oo@;m003o`000?oL8mcog2?L00Oog2?L00?o0000ok9=/_nbCK803onbCK800ol0003oI9]TofBK
I00:ofBKI003o`000?mJYE[oFZEJ00goFZEJ00?o0000obgB;Ol]dRd01_l]dRd4o`0000CoRgB;00?o
0000odn`Com?/4l00_m?/4l00ol0003oXUfRoj9MXP0Foj9MXP03o`000?o6>LKoaSW600_oaSW600?o
0000omTVfOoI9]T02ooI9]T00ol0003omPWfooH9mP06ooH9mP03o`000?ok1?_o000000[oo0?l00?o
0000ooh1o_on0Oh02_on0Oh00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo/4nook1?/02?ok1?/=
o`0000[og2?L00?o0000ok9=/_nbCK803onbCK800ol0003oI9]TofBKI00;ofBKI003o`000?mJYE[o
FZEJ00coFZEJ00?o0000obgB;Ol]dRd02_l]dRd4o`0000GoCk1?00?o0000oj9MX_nRGJ805_nRGJ80
0ol0003oaSW6olHiaP0:olHiaP03o`000?oI9]WofBKI00cofBKI00?o0000ooH9m_of2OH01?of2OH2
o`0000?on`Ck00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP08ooh1oP03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?oc3??ol`cc00Wol`cc00?o0000om`S
g?oL8m`02OoL8m`00ol0003o/Tfbok9=/P0=ok9=/P03o`000?mTVfCoI9]T00coI9]T00?o0000oeZU
F_mJYEX03?mJYEX00ol0003o;M8]obgB;@0;obgB;@03o`000?l]dRgo000000KoCk1?00?o0000oj9M
X_nRGJ805_nRGJ800ol0003oaSW6olHiaP09olHiaP03o`000?oI9]WofBKI00cofBKI00?o0000ooH9
m_of2OH00oof2OH00ol0003on`Ckoo/4n`03oo/4n`03o`000?ol0ocoo0?l00Soo0?l00?o0000ooh1
o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01_ok1?/00ol0003o
l`ccoo<<l`08oo<<l`03o`000?oL8mcog2?L00_og2?L00?o0000ok9=/_nbCK802?nbCK84o`0000oo
I9]T00?o0000oeZUF_mJYEX02omJYEX00ol0003o;M8]obgB;@0;obgB;@04o`000?l]dRgo;M8]o`00
00OoCk1?00?o0000oj9MX_nRGJ805OnRGJ800ol0003oaSW6olHiaP08olHiaP03o`000?oI9]WofBKI
00gofBKI00?o0000ooH9m_of2OH00_of2OH00ol0003on`Ckoo/4n`05oo/4n`03o`000?ol0ocoo0?l
00Ooo0?l00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook
1?/01Ook1?/00ol0003ol`ccoo<<l`08oo<<l`03o`000?oL8mcog2?L00_og2?L00?o0000ok9=/_nb
CK800onbCK85o`0000?oJ9MX00?o0000ofBKI?mTVf@03_mTVf@00ol0003oFZEJoeZUFP0:oeZUFP03
o`000?l]dRgo;M8]00[o;M8]00Go0000obgB;Ol]dRgo;M8]o`000007odn`C`03o`000?nRGJ;oXUfR
01GoXUfR00?o0000olHia_o6>LH02?o6>LH00ol0003ofBKIomTVf@0=omTVf@03o`000?of2OKomPWf
00;o00002?ok1?/00ol0003oo0?loo`3o008oo`3o0Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<02?oc3?<00ol0003og2?Lom`Sg00<om`Sg0Go00002OmXUfP00ol0003o
I9]TofBKI00<ofBKI0;o00003?mJYEX00ol0003o;M8]obgB;@0:obgB;@05o`000?l]dRgo;M8]obgB
;Ol000002?m?/4l00ol0003oXUfRoj9MXP0Doj9MXP?o00001oo6>LH00ol0003ofBKIomTVf@0>omTV
f@03o`000?of2OKo000000_on`Ck00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on`Ckoo/4n`04oo/4n`03o`000?oc3??ol`cc00Oo
l`cc00?o0000om`Sg?oL8m`03?oL8m`01?l0003o[e2_ojm@[ol0000;ofRGJ003o`000?mTVfCoI9]T
00_oI9]T00Co0000ob3O8?lPgb3o00002_mJYEX00ol0003o;M8]obgB;@0:obgB;@03o`000?l]dRgo
;M8]00;o;M8]00?o0000odn`Com?/4l01_m?/4l00ol0003oXUfRoj9MXP0Aoj9MXP?o00000onOH9l0
0ol0003oaSW6olHiaP04olHiaP03o`000?oI9]WofBKI00gofBKI1?l0000;oo/4n`03o`000?ol0oco
o0?l00Goo0?l00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo/4
nook1?_on`Ck1?l00008oo<<l`03o`000?oL8mcog2?L00_og2?L00?o0000ojm@[on_D:l00_n_D:l0
0ol0003oJ9MXofRGJ008ofRGJ003o`000?mTVfCoI9]T00[oI9]T00?o0000ob3O8?lPgb000_lPgb00
0ol0003oFZEJoeZUFP03oeZUFPGo00002ol]dRd00ol0003o;M8]obgB;@03obgB;@03o`000?m?/4oo
Ck1?00OoCk1?00?o0000oj9MX_nRGJ803_nRGJ82o`0000OoWf2O00?o0000olHia_o6>LH00_o6>LH0
0ol0003ofBKIomTVf@0=omTVf@03o`000?od2oCom0_d00;om0_d00?o0000oo/4nook1?/02Ook1?/0
0ol0003oo0?loo`3o003oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?od2o@00ol0003ol`ccoo<<l`05oo<<l`03o`000?oL8mcog2?L00[og2?L00?o0000ojm@
[on_D:l00on_D:l00ol0003oJ9MXofRGJ009ofRGJ003o`000?mTVfCoI9]T00SoI9]T00?o0000ob3O
8?lPgb001?lPgb05o`0000Co7n0O00?o0000obgB;Ol]dRd02Ol]dRd00ol0003o;M8]obgB;@03obgB
;@03o`000?m?/4ooCk1?00SoCk1?00?o0000oj9MX_nRGJ802_nRGJ83o`0000[oWf2O00Go0000olHi
a_o6>LKoaSW6o`00000>omTVf@03o`000?od2oCom0_d00Com0_d0_l00009oo/4n`03o`000?ol0oco
o0?l00;oo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;
m?od2o@01Ood2o@00ol0003ol`ccoo<<l`03oo<<l`03o`000?oL8mcog2?L00[og2?L00?o0000ojm@
[on_D:l01?n_D:l00ol0003oJ9MXofRGJ009ofRGJ003o`000?mTVfCoI9]T00OoI9]T00?o0000ob3O
8?lPgb001OlPgb000ol0003o7n0OoaoP7`07oaoP7`03o`000?l]dRgo;M8]00Oo;M8]00?o0000obgB
;Ol]dRd01?l]dRd00ol0003oCk1?odn`C`08odn`C`03o`000?nRGJ;oXUfR00SoXUfR0_l0000>oimP
W`Co00003?oI9]T2o`0000Wom0_d00?o0000oo/4nook1?/01ook1?/01?l0003oo0?loo`3o?l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003om0_doo@;m007oo@;m0;o00000ooc3?<00ol0
003og2?Lom`Sg009om`Sg003o`000?n_D:oo[e2_00Ko[e2_00?o0000ofRGJ?mXUfP02OmXUfP00ol0
003oI9]TofBKI005ofBKI003o`000?lPgb3o8=lP00Ko8=lP00?o0000oaoP7olOh1l02?lOh1l00ol0
003o;M8]obgB;@06obgB;@03o`000?l]dRgo;M8]00Co;M8]00?o0000odn`Com?/4l02Om?/4l4o`00
00?oXUfR0ol0000@oimPW`05o`000?oJ9M[ofRGJomXUf_l000002_oI9]T00ol0003om0_doo@;m00:
oo@;m0Ko00000ook1?/00ol0003oo0?lo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003om0_doo@;m00:oo@;m004o`000?oc3??ol`cco`0000[og2?L00?o0000ojm@[on_D:l01on_D:l0
0ol0003oJ9MXofRGJ009ofRGJ003o`000?mTVfCoI9]T00CoI9]T00?o0000ob3O8?lPgb001olPgb00
0ol0003o7n0OoaoP7`08oaoP7`;o00001_l]dRd00ol0003o;M8]obgB;@05obgB;@03o`000?m?/4oo
Ck1?00WoCk1?00Co0000ofNHIomWV6OoIiQW0ol0000BoimPW`03o`000?oJ9M[ofRGJ00?ofRGJ0_l0
0006omTVf@;o00003Ood2o@00ol0003oo@;mood2o@03ood2o@Go00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003om0_doo@;m00<oo@;m0;o00002_oL8m`00ol0003o[e2_ojm@[`08ojm@[`03o`000?mXUfSo
J9MX00[oJ9MX00?o0000ofBKI?mTVf@00_mTVf@00ol0003o8=lPob3O8008ob3O8003o`000?lOh1oo
7n0O00Ko7n0O0_l00002o`[e2P03o`000?l]dRgo;M8]00;o;M8]00?o0000obgB;Ol]dRd01_l]dRd0
0ol0003oCk1?odn`C`08odn`C`03o`000?mWV6OoIiQW00CoIiQW00?o0000oimPWonOH9l03onOH9l0
0ol0003ofRGJomXUfP06omXUfP;o00000ooI9]T00ol0003om0_doo@;m00=oo@;m003o`000?om0_go
o@;m00Ooo@;m0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?od2oCom0_d
00kom0_d00?o0000om`Sg?oL8m`01ooL8m`00ol0003o[e2_ojm@[`0:ojm@[`03o`000?mXUfSoJ9MX
00WoJ9MX00Go0000ofBKI?mTVfCoI9]To`00000;ob3O8003o`000?lOh1oo7n0O00Co7n0O0_l00005
o`[e2P05o`000?l]dRgo;M8]obgB;Ol000002?l]dRd00ol0003oCk1?odn`C`08odn`C`03o`000?mW
V6OoIiQW00GoIiQW00?o0000oimPWonOH9l03_nOH9l00ol0003ofRGJomXUfP08omXUfP03o`000?oI
9]Wo000000oom0_d00?o0000ood2oOom0_d02?om0_d01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017om0_d00?o0000om`Sg?oL8m`01_oL8m`00ol0003o[e2_
ojm@[`0;ojm@[`03o`000?mXUfSoJ9MX00WoJ9MX00Co0000ofBKI?mTVfCo00003?lPgb000ol0003o
7n0OoaoP7`02oaoP7`;o00002?l:m@X00ol0003o;M8]o`000009obgB;@03o`000?m?/4ooCk1?00So
Ck1?00?o0000ofNHIomWV6L01OmWV6L00ol0003oWf2OoimPW`0=oimPW`03o`000?oJ9M[ofRGJ00[o
fRGJ00?o0000oo@;m?od2o@03_od2o@00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000Boo@;m003o`00
0?oL8mcog2?L00Cog2?L00?o0000ojm@[on_D:l03?n_D:l00ol0003oJ9MXofRGJ00:ofRGJ0?o0000
3?lPgb000ol0003o7n0OoaoP7`02o`0000_o2_D:00?o0000obgB;Ol]dRd02?l]dRd00ol0003oCk1?
odn`C`07odn`C`03o`000?mWV6OoIiQW00OoIiQW00?o0000oimPWonOH9l03?nOH9l00ol0003ofRGJ
omXUfP0;omXUfP;o00003_od2o@00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003om0_doo@;m00?oo@;m0?o00000ooL
8m`00ol0003o[e2_ojm@[`0>ojm@[`03o`000?mXUfSoJ9MX00SoJ9MX00Co0000obOH9olWf2Oo9mPW
0_l0000:ob3O80?o00003Ol:m@X00ol0003o;M8]obgB;@08obgB;@03o`000?m?/4ooCk1?00OoCk1?
00?o0000ofNHIomWV6L01omWV6L00ol0003oWf2OoimPW`0;oimPW`03o`000?oJ9M[ofRGJ00cofRGJ
00?o0000ooX5n_l000000_l0000:oo@;m003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o004oo`3o003o`000?od2oCom0_d00com0_d0_l0
0003on`Ck003o`000?oL8mco0000017o[e2_00?o0000ofRGJ?mXUfP01omXUfP00ol0003o9mPWobOH
9`04obOH9`;o00002?lPgb000ol0003o2_D:o`[e2P0>o`[e2P;o00002?l]dRd00ol0003oCk1?odn`
C`06odn`C`03o`000?mWV6OoIiQW00WoIiQW00?o0000oimPWonOH9l02OnOH9l00ol0003ofRGJomXU
fP0=omXUfP03o`000?oj1O[onPGj00;onPGj0ol00007oo@;m003o`000?om0_goo@;m00Ooo@;m00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?od2oCo
m0_d00Wom0_d0_l00006on`Ck003o`000?n_D:oo[e2_013o[e2_00?o0000ofRGJ?mXUfP01_mXUfP0
0ol0003o9mPWobOH9`07obOH9`03o`000?lPgb3o8=lP00Co8=lP0ol0000>o`[e2P03o`000?l9mPWo
2OH900?o00001Ol]dRd00ol0003oCk1?odn`C`06odn`C`03o`000?mWV6OoIiQW00[oIiQW00?o0000
oimPWonOH9l02?nOH9l00ol0003ofRGJomXUfP0=omXUfP03o`000?oj1O[onPGj00GonPGj0ol00004
oo@;m003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo0?loo`3o006oo`3o003o`000?od2oCom0_d00Gom0_d0ol00008on`Ck003o`000?n_D:oo[e2_
017o[e2_00Co0000ofRGJ?mXUfSoJ9MX1?l0000;obOH9`;o000000Co8=lPo`000?l0003o00000ol0
o`02o`0000_o2_D:00?o0000o`Wf2Ol9mPT01?l9mPT2o`0000?o;M8]00?o0000odn`Com?/4l01_m?
/4l00ol0003oIiQWofNHI`0:ofNHI`03o`000?nOH9ooWf2O00OoWf2O00?o0000omXUf_oJ9MX03_oJ
9MX00ol0003onPGjooX5nP08ooX5nPCo00002_om0_d00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo0?loo`3o007oo`3o003o`000?od2oCom0_d00;om0_d0_l0000<on`Ck003o`000?n_D:oo
[e2_013o[e2_1?l00003oefRG@03o`000?lWf2Oo9mPW00_o9mPW00?o0000o`3o0?l0o`001_l0o`00
0ol0003o2_D:o`[e2P07o`[e2P03o`000?l9mPWo2OH900Oo2OH93?l0000>ofNHI`03o`000?nOH9oo
Wf2O00KoWf2O00?o0000omXUf_oJ9MX03_oJ9MX00ol0003onPGjooX5nP0;ooX5nP03o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00Woo0?l00Co0000oo@;
m?l0003o00003_o/4n`00ol0003o[e2_ojm@[`0?ojm@[`03o`000?mMXUgoGJ9M00KoGJ9M00?o0000
obOH9olWf2L02_lWf2L00ol0003o0?l0o`3o0007o`3o00;o00001_l:m@X00ol0003o2OH9o`Wf2@08
o`Wf2@03o`000?lhacSo><Lh00So><Lh00?o0000ofNHIomWV6L03?mWV6L00ol0003oWf2OoimPW`05
oimPW`03o`000?oJ9M[ofRGJ00oofRGJ0_l0000=ooX5nP03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on`Ck?o/4n`03_o/4n`00ol0
003o[e2_ojm@[`0>ojm@[`03o`000?mMXUgoGJ9M00OoGJ9M00?o0000obOH9olWf2L02_lWf2L00ol0
003o0?l0o`3o0009o`3o00;o00000ol:m@X00ol0003o2OH9o`Wf2@09o`Wf2@03o`000?lhacSo><Lh
00Wo><Lh00?o0000ofNHIomWV6L02_mWV6L4o`0000CoWf2O00?o0000omXUf_oJ9MX04?oJ9MX01?l0
003on@Kio`000?l0000<ooX5nP03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?ol0ocoo0?l00[oo0?l00?o0000on`Ck?o/4n`03oo/4n`@o`0000[oGJ9M00?o0000obOH
9olWf2L02OlWf2L00ol0003o0?l0o`00000<o`3o0005o`000?l:m@[o0000o`3o0?l000002_l9mPT0
0ol0003o><LhocS7>009ocS7>003o`000?mWV6OoIiQW00OoIiQW0ol00004ohacS0?o000000?oWf2O
o`000?oJ9MX04OoJ9MX01?l0003on@KiooT6nOoi1_T2o`0000_onPGj00?o0000ood2oOom0_d00oom
0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ok1?/on`Ck00?
on`Ck003o`000?nVFJKoYUVV00coYUVV00?o0000oefRGOmMXUd02OmMXUd00ol0003o9mPWobOH9`07
obOH9`04o`000?l0o`3o0?l0o`0000go0?l000Go0000o`3o0?l0o`3o0?l0o`000009o`Wf2@03o`00
0?lhacSo><Lh00[o><Lh00?o0000ofNHIomWV6L00omWV6L3o`0000[oS7><00?o0000omXUf_oJ9MX0
4?oJ9MX00ol0003on@KiooT6n@04ooT6n@;o00002_oj1OX00ol0003oo@;mood2o@04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo0?l00?o0000on`Ck?o/4n`03oo/4n`00ol0003oYUVVojIIYP0<ojIIYP03o`000?mM
XUgoGJ9M00WoGJ9M00?o0000obOH9olWf2L01_lWf2L00ol0003o0?l0o`3o0002o`3o0003o`000?l0
o`3o0?l000[o0?l000?o0000o`3o0?l0o`000_l0o`000ol0003o2OH9o`Wf2@06o`Wf2@03o`000?lh
acSo><Lh00[o><Lh00?o0000ofNHIomWV6L00ol0000=ohacS003o`000?oJ9M[ofRGJ013ofRGJ00?o
0000ooT6nOoi1_T01_oi1_T2o`0000WonPGj0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003ok1?/on`Ck00=on`Ck0?o00003onVFJH0
0ol0003oGJ9MoefRG@08oefRG@03o`000?lWf2Oo9mPW00Go9mPW00?o0000o`3o0?l0o`000ol0o`00
0ol0003o0?l0o`3o000:o`3o0003o`000?l0o`3o0?l000?o0?l000?o0000o`Wf2Ol9mPT01Ol9mPT0
0ol0003o><LhocS7>00;ocS7>0;o00004On<Lh`00ol0003ofRGJomXUfP0?omXUfP03o`000?oi1_Wo
n@Ki00Son@Ki0_l00007ooX5nP03o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003ok1?/on`Ck009on`Ck0Go00000_oI9]T00ol0
003oYUVVojIIYP0=ojIIYP03o`000?mMXUgoGJ9M00WoGJ9M00?o0000obOH9olWf2L01?lWf2L00ol0
003o0?l0o`3o0004o`3o0003o`000?l0o`3o0?l000So0?l000?o0000o`3o0?l0o`001Ol0o`000ol0
003o2OH9o`Wf2@04o`Wf2@03o`000?lhacSo><Lh00_o><Lh00?o0000ohacS?n<Lh`04?n<Lh`00ol0
003ofRGJomXUfP0?omXUfP03o`000?oi1_Won@Ki00[on@Ki0_l00004ooX5nP03o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo0?loo`3o007oo`3o003o`000?o/4ncok1?/00Cok1?/1Ol00007omTVf@03
o`000?nVFJKoYUVV00goYUVV00?o0000oefRGOmMXUd02OmMXUd00ol0003o9mPWobOH9`03obOH9`03
o`000?l0o`3o0?l000Go0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o0?l0o`3o0006o`3o0003
o`000?l9mPWo2OH900?o2OH900?o0000ocS7>?lhacP02olhacP00ol0003oS7><ohacS00@ohacS003
o`000?oJ9M[ofRGJ00oofRGJ00?o0000ooT6nOoi1_T03?oi1_T2o`000003ooX5n_l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000on`Ck?l00000
1?l0000<omTVf@03o`000?nVFJKoYUVV00koYUVV00?o0000oefRGOmMXUd02?mMXUd00ol0003o9mPW
obOH9`02obOH9`03o`000?l0o`3o0?l000Oo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o0?l0
o`3o0007o`3o0003o`000?l9mPWo2OH900;o2OH900?o0000ocS7>?lhacP02olhacP00ol0003oS7><
ohacS00AohacS003o`000?oJ9M[ofRGJ00gofRGJ00?o0000ooT6nOoi1_T03ooi1_T00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01Ool0o`3o`00017ofBKI00?o0000ojIIY_nVFJH03_nV
FJH00ol0003oGJ9MoefRG@09oefRG@04o`000?lWf2Oo9mPWo`0000[o0?l000?o0000o`3o0?l0o`00
1ol0o`000ol0003o0?l0o`3o0008o`3o0005o`000?l9mPWo2OH9o`Wf2Ol000003OlhacP00ol0003o
S7><ohacS00AohacS0?o00003OoJ9MX00ol0003on@KiooT6n@0?ooT6n@03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_ol0o`2o`0000;om`Sg00?o0000omTVfOoI9]T03ooI9]T00ol0003o
YUVVojIIYP0>ojIIYP03o`000?mMXUgoGJ9M00SoGJ9M1Ol0000;o`3o0003o`000?l0o`3o0?l000Ko
0?l000?o0000o`3o0?l0o`002Ol0o`001?l0003o2OH9o`Wf2Ol0000=ocS7>003o`000?n<LhcoS7><
017oS7><00?o0000oka3_?nl@k`00ol0000:omXUfPCo00003Ooi1_T00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ood2oOom0_goo@;m0_l00005ooL8m`03o`000?oI9]WofBKI00kofBKI00?o0000ojII
Y_nVFJH03_nVFJH00ol0003oGJ9MoefRG@07oefRG@03o`000?lFjAKo5^TF00?o5^TF00?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0005o`3o0003o`000?l0o`3o0?l000[o0?l01Ol0000<ocS7
>003o`000?n<LhcoS7><013oS7><00?o0000oka3_?nl@k`01?nl@k`3o`0000KofRGJ00?o0000ooD:
mOoe2_D00_oe2_D5o`0000Son@Ki00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?o
o@;m00?o0000ooL8moog2?L01?og2?L00ol0003ofBKIomTVf@0=omTVf@03o`000?nVFJKoYUVV00oo
YUVV00?o0000oefRGOmMXUd01?mMXUd2o`0000Oo5^TF00?o0000o`3o0?l0o`001ol0o`0Eo`0000Go
3?<<00?o0000ocS7>?lhacP02?lhacP3o`00013oS7><00?o0000oka3_?nl@k`02?nl@k`3o`0000;o
fRGJ00?o0000ooD:mOoe2_D02?oe2_D5o`0000?on@Ki00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?om0_goo@;m00Coo@;m00?o0000ooL8moog2?L01Oog2?L00ol0003ofBKIomTVf@0;omTVf@Co0000
3onVFJH00ol0003oGJ9MoefRG@03oefRG@03o`000?lFjAKo5^TF00So5^TF00?o0000o`3o0?l0o`00
1?l0o`02o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o3?<<o`cc3005o`cc30;o0000
1_lhacP2o`0000?oBkA;00?o0000ohacS?n<Lh`03?n<Lh`00ol0003o_4>loka3_00<oka3_0;o0000
4?oe2_D3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?og2?Oom`Sg00Kom`Sg00?o
0000omTVfOoI9]T02OoI9]T00ol0003oiA[Uo`000002oj]DZ`?o00003?nVFJH01?l0003oGJ9MoefR
GOmMXUd2o`0000co5^TF00?o0000o`3o0?l0o`000_l0o`000ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000o`cc3?l<l``01ol<l``00ol0003o><LhocS7>002ocS7>003o`00
0?m;]4_oBkA;00CoBkA;0_l0000;ohacS003o`000?nl@kco_4>l00co_4>l00?o0000on8Mh_l00000
4_oe2_D00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o
0000omTVfOoI9]T01_oI9]T2o`0000;oiA[U00?o0000oj]DZon[E:/00on[E:/3o`0000[oYUVV00?o
0000oefRGOl000003olFjAH01?l0003o0?l0o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000o`cc3?l<l``02?l<l``01?l0003o><Lho`000?l00009od^dB`03o`000?n<LhcoS7><00Oo
S7><00?o0000oka3_?nl@k`03?nl@k`01?l0003ohQgRon8Mh_l0000CooD:m@03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ood2oOom0_d01oom0_d00ol0003om`SgooL8m`08ooL8m`03o`000?oI9]WofBKI00Co
fBKI00?o0000onDJiOoU6^D00ooU6^D00ol0003oZeB[oj]DZ`05oj]DZ`?o00001_nVFJH4o`00013o
5^TF00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l<l`co3?<<00Wo
3?<<00?o0000od^dBom;]4/02_m;]4/2o`0000KoS7><00?o0000oka3_?nl@k`03?nl@k`00ol0003o
hQgRon8MhP02on8MhP03o`000?oe2_Gom@[e00oom@[e00?o0000ood2oOl000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?og2?Oom`Sg00Wom`Sg00Co0000omTVfOoI9]Wo
fBKI0_l00006onDJi@03o`000?n[E:_oZeB[00SoZeB[0ol000000onVFJKo0000o`000004oeJYEP03
o`000?lFjAKo5^TF00go5^TF00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?l<l`co3?<<00Wo3?<<00?o0000od^dBom;]4/03?m;]4/00ol0003oS7><ohacS003o`0000ko
_4>l00?o0000on8Mh_oR7N800ooR7N800ol0003om@[eooD:m@0>ooD:m@05o`000?om0_goo@;mood2
oOl000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@09ood2o@03o`000?og2?Oom`Sg00[o
m`Sg00?o0000omTVfOl000002?oU6^D00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?mFZEKoEZUF00Go
EZUF00?o0000oaKY5_lFjAH03?lFjAH00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000o`cc3?l<l``02?l<l``2o`0000ooBkA;0_l00002ojaC[003o`000?nl@kco_4>l00_o
_4>l00?o0000on8Mh_oR7N801?oR7N800ol0003om@[eooD:m@0=ooD:m@03o`000?om0_goo@;m00?o
o@;m00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onDJiOoU6^D0
1ooU6^D00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?mFZEKoEZUF00KoEZUF00?o0000oaKY5_lFjAH0
2olFjAH2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o3?<<o`cc3007o`cc3004o`00
0?lNhAko7^4No`0000koBkA;00?o0000ojaC[?n/Dj`00_n/Dj`00ol0003o_4>loka3_009oka3_003
o`000?oR7N;ohQgR00KohQgR00?o0000ooD:mOoe2_D02ooe2_D00ol0003oo@;mood2o@05ood2o@04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000Soo@;m00?o0000ooL8moog2?L02_og2?L2o`0000Wo
iA[U00?o0000oj]DZon[E:/02on[E:/00ol0003oEZUFoeJYEP07oeJYEP03o`000?lFjAKo5^TF00Wo
5^TF00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l<l`co3?<<
00Ko3?<<00Go0000oakQ7_lNhAko7^4No`00000>od^dB`03o`000?n/Djco[5>/00?o[5>/00?o0000
oka3_?nl@k`01onl@k`00ol0003ohQgRon8MhP07on8MhP03o`000?oe2_Gom@[e00[om@[e00?o0000
ood2oOom0_d01oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ood2o@03o`000?og2?Oom`Sg
00Wom`Sg00Co0000ooH9m_of2OKo00002OoU6^D00ol0003oZeB[oj]DZ`09oj]DZ`03o`000?mFZEKo
EZUF00WoEZUF00?o0000oaKY5_lFjAH01olFjAH00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o3?<<o`cc3005o`cc3003o`000?lNhAko
7^4N00?o7^4N00?o0000od^dBom;]4/02_m;]4/00ol0003o[5>/ojaC[005ojaC[003o`000?nl@kco
_4>l00Go_4>l00?o0000on8Mh_oR7N802?oR7N800ol0003om@[eooD:m@09ooD:m@03o`000?om0_go
o@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_om0_d3o`0000Wom`Sg00?o0000ooH9
m_of2OH00_of2OH00ol0003oiA[UonDJi@06onDJi@03o`000?n[E:_oZeB[00WoZeB[00?o0000oeJY
E_mFZEH02_mFZEH00ol0003o5^TFoaKY5P05oaKY5P03o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l<l`co3?<<00Co3?<<00?o0000oakQ
7_lNhAh01?lNhAh00ol0003oBkA;od^dB`0:od^dB`03o`000?n/Djco[5>/00Ko[5>/00?o0000oka3
_?nl@k`00onl@k`00ol0003ohQgRon8MhP09on8MhP03o`000?oe2_Gom@[e00Som@[e00?o0000ood2
oOom0_d02Oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003oo/4n`?o00001Oog2?L00ol0003o
mPWfooH9mP03ooH9mP03o`000?oU6^GoiA[U00KoiA[U00?o0000oj]DZon[E:/02On[E:/00ol0003o
EZUFoeJYEP0;oeJYEP03o`000?lFjAKo5^TF00?o5^TF00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000o`cc3?l<l``00_l<l``2o`0000So
7^4N00?o0000od^dBom;]4/02Om;]4/00ol0003o[5>/ojaC[007ojaC[005o`000?nl@kco_4>loka3
_?l000003OoR7N800ol0003om@[eooD:m@06ooD:m@03o`000?om0_goo@;m00[oo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?ok1?_on`Ck00Gon`Ck0ol000000oog2?Oo0000ooH9mP06ooH9mP03
o`000?oU6^GoiA[U00GoiA[U00?o0000oj]DZon[E:/02On[E:/00ol0003oEZUFoeJYEP0<oeJYEP05
o`000?lFjAKo5^TFoaKY5_l000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000o`cc3?l000000_l000000ol;m0_o0000oakQ7P07oakQ7P03o`000?m;]4_oBkA;
00SoBkA;00?o0000ojaC[?n/Dj`02On/Dj`00ol0003o_4>lo`00000=on8MhPCo00001Ooe2_D00ol0
003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003on`Ckoo/4n`08oo/4n`03
o`000?of2OKomPWf00OomPWf00?o0000onDJiOoU6^D01?oU6^D00ol0003oZeB[oj]DZ`09oj]DZ`03
o`000?mFZEKoEZUF00goEZUF00?o0000oaKY5_l000003?l0o`0:o`0000Oo0?l00ol00005o`_d2`03
o`000?lNhAko7^4N00Ko7^4N00?o0000od^dBom;]4/01om;]4/00ol0003o[5>/ojaC[00:ojaC[003
o`000?oR7N;ohQgR00_ohQgR00?o0000ooP7n?oh1oP00_oh1oP3o`000003ooD:mOl0003oo@;m00_o
o@;m0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003omPWfooH9mP07ooH9mP03o`00
0?oU6^GoiA[U00GoiA[U00?o0000oj]DZon[E:/01on[E:/00ol0003oEZUFoeJYEP0?oeJYEP;o0000
2ol0o`000ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l000;o0?l00ol00008o`_d2`03o`00
0?lNhAko7^4N00Ko7^4N00?o0000od^dBom;]4/01om;]4/00ol0003o[5>/ojaC[00:ojaC[003o`00
0?oR7N;ohQgR00[ohQgR00?o0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@08ood2o@?o0000
0_om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003omPWfooH9
mP08ooH9mP03o`000?oU6^GoiA[U00CoiA[U00?o0000oj]DZon[E:/01on[E:/00ol0003oEZUFoeJY
EP0>oeJYEP04o`000?lQgR7o8MhQo`0000Wo0?l000?o0000o`?l0ol3o0<02Ol3o0<01?l0003o0?l0
o`000?l0000<o`_d2`03o`000?lNhAko7^4N00Ko7^4N00?o0000od^dBom;]4/01_m;]4/00ol0003o
[5>/ojaC[00;ojaC[003o`000?oR7N;ohQgR00OohQgR0_l00009ooP7n003o`000?om0_goo@;m00Co
o@;m1?l00006ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`09oo/4n`03o`00
0?of2OKomPWf00SomPWf00?o0000onDJiOoU6^D00ooU6^D>o`0000goEZUF00?o0000ob7N8OlQgR40
0_lQgR400ol0003o0?l0o`3o0005o`3o0003o`000?l3o0?o0o`300_o0o`300?o0000o`_d2ol;m0/0
3?l;m0/00ol0003o7^4NoakQ7P06oakQ7P03o`000?m;]4_oBkA;00GoBkA;00?o0000ojaC[?n/Dj`0
3?n/Dj`00ol0003ohQgRon8MhP06on8MhP03o`000?oh1oSon0Oh00[on0Oh00?o0000ood2oOom0_d0
0ol0000:ood2o@?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooH9m_of2OH02?of
2OH01Ol0003oiA[UonDJiOoU6^Go000000_o^dBk00?o0000oejQG_mNXEh00ol00009oeJYEP03o`00
0?lQgR7o8MhQ00Co8MhQ00?o0000o`3o0?l0o`000ol0o`000ol0003o0o`3o`?l0`0<o`?l0`03o`00
0?l;m0_o2o@;00go2o@;00?o0000oakQ7_lNhAh01_lNhAh00ol0003oBkA;od^dB`03od^dB`?o0000
3On/Dj`00ol0003ohQgRon8MhP05on8MhP03o`000?oh1oSon0Oh00con0Oh0_l0000=ood2o@03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooH9m_of2OH02?of
2OH4o`0000co^dBk00?o0000oejQG_mNXEh00omNXEh3o`0000GoEZUF00?o0000ob7N8OlQgR401_lQ
gR401Ol0003o0?l0o`3o0?l0o`3o000000oo0o`300?o0000o`_d2ol;m0/03Ol;m0/00ol0003o7^4N
oakQ7P06oakQ7P03o`000?m;]4_oBkA;00?o00000omXUfP00ol0003o[5>/ojaC[00;ojaC[003o`00
0?oR7N;ohQgR00?ohQgR00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oo@;mood2o@0;ood2o@03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo/4nook1?/02_ok1?/3o`0000KomPWf0ol0
0003onl@k`03o`000?nkA;_o^dBk00[o^dBk00?o0000oejQG_mNXEh01_mNXEh3o`000003oeJYE_l0
003o8MhQ00Wo8MhQ00?o0000o`3o0?l000004?l3o0<00ol0003o2o@;o`_d2`0=o`_d2`03o`000?lN
hAko7^4N00Oo7^4N0_l00007ofRGJ003o`000?n/Djco[5>/00[o[5>/00Co0000on8Mh_oR7N;ohQgR
0ol0000?ooP7n003o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000oo/4nook1?/02_ok
1?/01?l0003onPGjooX5n_oj1OX2o`000004ooH9m_l0003o0000o`0000Koka3_00?o0000ok]4^onk
A;/02_nkA;/00ol0003oGZ5NoejQGP09oejQGP03o`000?lQgR7o8MhQ00[o8MhQ00?o0000o`?l0ol3
o0<03ol3o0<00ol0003o2o@;o`_d2`0>o`_d2`03o`000?lNhAko7^4N00Ko7^4N00?o0000ofRGJ?mX
UfP01omXUfP4o`0000So[5>/00Co0000on8Mh_oR7N;o00000oo`3o02o`0000gon0Oh00?o0000ood2
oOom0_d02_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003o
nPGjooX5nP04ooX5nP03o`000?o_4>ooka3_00Ooka3_00?o0000ok]4^onkA;/02OnkA;/00ol0003o
GZ5NoejQGP0:oejQGP03o`000?lQgR7o8MhQ00[o8MhQ00?o0000o`?l0ol3o0<03ol3o0<00ol0003o
2o@;o`_d2`0>o`_d2`03o`000?lNhAko7^4N00Go7^4N00?o0000ofRGJ?mXUfP02?mXUfP01?l0003o
]DZeokE:]OneB[D7o`0000;o[5>/0_l00006oo0?l0;o00003?oh1oP00ol0003oo@;mood2o@09ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?oj1O[onPGj00Go
nPGj00?o0000onl@koo_4>l02?o_4>l00ol0003o^dBkok]4^`08ok]4^`03o`000?mNXEkoGZ5N00[o
GZ5N00?o0000ob7N8OlQgR402olQgR400ol0003o0o`3o`?l0`0>o`?l0`03o`000?l;m0_o2o@;00ko
2o@;1Ol00002oakQ7P03o`000?mXUfSoJ9MX00WoJ9MX00?o0000okE:]OneB[D02?neB[D3o`0000Wo
l0o`0_l0000:ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ok1?_on`Ck00Son`Ck00?o0000ooX5n_oj1OX01ooj1OX00ol0003oka3_onl@k`07onl@k`03o`00
0?nkA;_o^dBk00So^dBk00?o0000oejQG_mNXEh02_mNXEh00ol0003o8MhQob7N8@0:ob7N8@;o0000
3_l3o0<3o`0000go2o@;0ol00005ocC;=0;o00002omXUfP00ol0003o]DZeokE:]@0;okE:]@;o0000
2_o`3o02o`0000Oon0Oh0ol00009ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:ooX5nP03o`00
0?o_4>ooka3_00Ooka3_00?o0000ok]4^onkA;/02?nkA;/>o`0000Wo8MhQ0ol000000olJiA[o0000
o`?l0`0:o`?l0`?o00000_lGj1L00ol0003o2o@;o`_d2`09o`_d2`;o00002Oldbc@00ol0003oJ9MX
ofRGJ009ofRGJ003o`000?neB[Go]DZe00_o]DZe00?o0000om8]d_l000002oo`3o02o`0000Con0Oh
00Co0000ooX5n_oj1O[onPGj0_l00007ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003onPGj
ooX5nP09ooX5nP03o`000?o_4>ooka3_00Koka3_00?o0000ok]4^onkA;/02?nkA;/00ol0003oG:=L
oebSG00:oebSG003o`000?lQgR7o8MhQ00Co8MhQ0ol00005oa[U6P03o`000?l3o0?o0o`300Co0o`3
1?l00006oaOX5`03o`000?l;m0_o2o@;00Ko2o@;0_l0000;ocC;=003o`000?mXUfSoJ9MX00WoJ9MX
00?o0000okE:]OneB[D02_neB[D01Ol0003odRgBom8]d_oB;M;o000000col0o`0_l000000ooh1oSo
0000ooX5nP05ooX5nP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oj1O[onPGj00SonPGj00?o0000onl@koo_4>l01_o_4>l00ol0003o^dBkok]4^`07ok]4^`03o`00
0?mLXecoG:=L00_oG:=L00?o0000ob7N8OlQgR400_lQgR42o`0000Wo6^DJ00?o0000o`?l0ol3o0<0
0ol0000;oaOX5`03o`000?l;m0_o2o@;00;o2o@;0ol0000>ocC;=003o`000?mXUfSoJ9MX00OoJ9MX
00?o0000okE:]OneB[D02oneB[D00ol0003odRgBom8]dP02om8]dP03o`000?o`3o3ol0o`00_ol0o`
00?o0000ooX5n_oj1OX01_oj1OX2o`0000?oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oj
1O[onPGj00OonPGj00?o0000onl@koo_4>l01oo_4>l00ol0003o^dBkok]4^`05ok]4^`?o00003OmL
Xe`4o`0000_o6^DJ0ol0000?oaOX5`04o`000?l;m0_o0000o`00017o=</d00?o0000ofRGJ?mXUfP0
1omXUfP00ol0003o]DZeokE:]@0:okE:]@03o`000?oB;M;odRgB00CodRgB00?o0000oo0?l?o`3o00
1oo`3o03o`0000_onPGj1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02?oj1OX00ol0003oka3_onl@
k`06onl@k`03o`000?nkA;_o^dBk00;o^dBk0ol00003oi]TV`03o`000?mLXecoG:=L00[oG:=L00?o
0000oa[U6_lJiAX02olJiAX00ol0003o5^TFo`00000AoaOX5`03o`000?ldbcCo=</d017o=</d00?o
0000ofRGJ?mXUfP01omXUfP00ol0003o]DZeokE:]@0:okE:]@03o`000?oB;M;odRgB00GodRgB00Co
0000oo0?l?o`3o3ol0o`1Ol00002oo<<l`03o`000?oj1O[onPGj00WonPGj00Co0000ooh1o_on0Oko
oP7n0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003oka3_onl@k`05onl@k`?o0000
00?o^dBko`000?l000001onKI9/00ol0003oG:=LoebSG008oebSG0?o00002_lJiAX2o`0000;o5^TF
00?o0000oaOX5olGj1L03olGj1L00ol0003o=</docC;=00AocC;=003o`000?mXUfSoJ9MX00OoJ9MX
00?o0000okE:]OneB[D02OneB[D00ol0003odRgBom8]dP07om8]dP?o00001ooc3?<00ol0003onPGj
ooX5nP09ooX5nP03o`000?on0OkooP7n00CooP7n0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000ooX5n_oj1OX01ooj
1OX4o`0000;oka3_0_l00003onDJi@03o`000?nKI9_oVfBK00SoVfBK0_l00006oebSG0;o00000om<
/d`00ol0003o6^DJoa[U6P06oa[U6P03o`000?lFjAKo5^TF00?o5^TF00?o0000oaOX5olGj1L03_lG
j1L00ol0003o=</docC;=00BocC;=003o`000?mXUfSoJ9MX00GoJ9MX00?o0000okE:]OneB[D02One
B[D00ol0003odRgBom8]dP08om8]dP03o`000?oc3??ol`cc00Ool`cc00?o0000ooX5n_oj1OX02?oj
1OX00ol0003ooP7nooh1oP07ooh1oP;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oj1O[onPGj00ConPGj0_l00004
ooP7n0;o00001OoU6^D00ol0003oVfBKoi]TV`0:oi]TV`03o`000?mLXecoG:=L00;oG:=L00?o0000
odbcC?m</d`01?m</d`00ol0003o6^DJoa[U6P04oa[U6P03o`000?lFjAKo5^TF00Co5^TF00?o0000
oaOX5olGj1L03_lGj1L00ol0003o=</docC;=00BocC;=0[o00002_neB[D00ol0003odRgBom8]dP08
om8]dP03o`000?oc3??ol`cc00Ool`cc00?o0000ooX5n_oj1OX02?oj1OX00ol0003ooP7nooh1oP09
ooh1oP?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003onPGjooX5n_oj1OX2o`0000Oon0Oh00?o0000onDJiOoU6^D01?oU6^D0
0ol0003oVfBKoi]TV`0:oi]TV`04o`000?mLXeco0000o`0000SoC;=<00Co0000oa[U6_lJiA[o6^DJ
0_l00007oaKY5P03o`000?lGj1Oo5nPG00ko5nPG00?o0000ocC;=?ldbc@04_ldbc@00ol0003oR7N8
ohQgR007ohQgR003o`000?neB[Go]DZe00Ko]DZe00?o0000om8]d_oB;M802_oB;M800ol0003ol`cc
oo<<l`06oo<<l`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?oj
1O[o0000o`0000Won0Oh00?o0000onDJiOoU6^D01?oU6^D00ol0003oVfBKoi]TV`0;oi]TV`03o`00
0?m</dcoC;=<00WoC;=<00?o0000oa[U6_l000002OlFjAH00ol0003o5nPGoaOX5`0>oaOX5`;o0000
4_ldbc@00ol0003oR7N8ohQgR009ohQgR0;o00001_neB[D00ol0003odRgBom8]dP0:om8]dP03o`00
0?oc3??ol`cc00Kol`cc00?o0000ooX5n_oj1OX02?oj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooP7n?oh1oP02Ooh1oP00ol0003oiA[UonDJi@05onDJi@03o`000?nKI9_oVfBK00[oVfBK00?o
0000odbcC?m</d`02_m</d`2o`0000Wo5^TF00?o0000oaOX5olGj1L03_lGj1L00ol0003o:MHYo`00
0002o`0000oo=</d00?o0000ohQgR?n8MhP02on8MhP00ol0003o]DZeokE:]@03o`0000godRgB00?o
0000oo<<looc3?<01_oc3?<00ol0003onPGjooX5nP07ooX5nP03o`000?on0OkooP7n00cooP7n00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on0OhooP7n009ooP7n003o`000?oU6^GoiA[U00GoiA[U00?o0000oi]TVonKI9/02OnKI9/2
o`0000_oC;=<0_l0000;oaKY5P03o`000?lGj1Oo5nPG00co5nPG00?o0000obWF:OlYeRT00olYeRT3
o`0000co=</d00?o0000ohQgR?n8MhP03?n8MhP2o`0000;odBkA00?o0000om8]d_oB;M803?oB;M80
0ol0003ol`ccoo<<l`05oo<<l`03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00[on0Oh00?o0000onDJiOoU6^D01_oU6^D00ol0003oVfBKoi]TV`07oi]T
V`03o`000?nQGZ7o000000[oC;=<00Co0000odBkA?m4^dCo00002_lFjAH00ol0003o5nPGoaOX5`0<
oaOX5`03o`000?lYeRWo:MHY00Ko:MHY0_l00008ocC;=0;o00003on8MhP00ol0003odBkAom4^d@02
om4^d@03o`000?oB;M;odRgB00_odRgB00?o0000oo<<looc3?<01Ooc3?<00ol0003onPGjooX5nP07
ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on0OhooP7n00:ooP7n003o`000?oU6^GoiA[U
00KoiA[U00?o0000oi]TVonKI9/01_nKI9/01Ol0003oXEjQoj5NXOnQGZ7o000000SoC;=<00?o0000
odBkA?m4^d@00_m4^d@00ol0003o5^TFoaKY5P06oaKY5PCo00003?lGj1L00ol0003o:MHYobWF:@08
obWF:@?o00000_ldbc@3o`000003of^DJol0003oR7N800goR7N800?o0000om4^dOoA;]401?oA;]40
0ol0003odRgBom8]dP0:om8]dP03o`000?oc3??ol`cc00Gol`cc00?o0000ooX5n_oj1OX01_oj1OX0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003oiA[UonDJi@07onDJ
i@03o`000?nKI9_oVfBK00?oVfBK0_l00005oj5NX@03o`000?m</dcoC;=<00CoC;=<00?o0000odBk
A?m4^d@00om4^d@00ol0003o5^TFoaKY5P05oaKY5P03o`000?l?l0oo3o0?00;o3o0?0ol00007oaOX
5`;o00003_lYeRT2o`0000GoJiA[00?o0000ohQgR?n8MhP02_n8MhP00ol0003odBkAom4^d@05om4^
d@03o`000?oB;M;odRgB00_odRgB00?o0000oo<<looc3?<01?oc3?<00ol0003onPGjooX5nP06ooX5
nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on0OhooP7n00;ooP7n003o`000?oU6^GoiA[U00Oo
iA[U00?o0000oi]TVonKI9/00_nKI9/00ol0003oXEjQoj5NX@06oj5NX@03o`000?m</dcoC;=<00;o
C;=<00?o0000odBkA?m4^d@01Om4^d@00ol0003o5^TFoaKY5P02oaKY5P;o00002?l?l0l3o`0000;o
5nPG0_l000000olAkQ7o0000obWF:@0=obWF:@03o`000?m[U6_oJiA[00GoJiA[00?o0000ohQgR?n8
MhP02?n8MhP00ol0003odBkAom4^d@07om4^d@03o`000?oB;M;odRgB00[odRgB00?o0000oo<<looc
3?<01?oc3?<00ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on0Oh
ooP7n00<ooP7n003o`000?oU6^GoiA[U00SoiA[U00Co0000oi]TVonKI9_o00002OnQGZ401Ol0003o
C;=<odbcC?m</dco000000SoA;]400Go0000oaKY5_lFjAKo5^TFo`00000=o`o`3`;o00001?lAkQ40
0ol0003o:MHYobWF:@0;obWF:@03o`000?m[U6_oJiA[00KoJiA[00?o0000ohQgR?n8MhP01on8MhP0
0ol0003odBkAom4^d@08om4^d@Co00002?oB;M800ol0003ol`ccoo<<l`04oo<<l`03o`000?oj1O[o
nPGj00KonPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oh1oSon0Oh00_on0Oh0ol00009onDJ
i@03o`000?nKI9_o000000_oXEjQ00?o0000odbcC?l000002_m4^d@00ol0003o5^TFo`00000?o`o`
3`03o`000?lAkQ7o4NhA00;o4NhA00?o0000obWF:OlYeRT02olYeRT00ol0003oJiA[of^DJ`06of^D
J`03o`000?n8MhSoR7N800KoR7N800?o0000om4^dOoA;]402OoA;]401?l0003oiaSWonLHiooW6>L7
o`0000;odRgB00?o0000oo<<looc3?<00ooc3?<00ol0003onPGjooX5nP05ooX5nP03o`000?on0Oko
oP7n00cooP7n00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oh1oSon0Oh00Son0Oh0ol00003ooP7n003o`000?oU6^GoiA[U00OoiA[U00?o0000oj5N
XOnQGZ402onQGZ400ol0003oA;]4odBkA00:odBkA003o`000?l?l0oo3o0?00go3o0?00?o0000oa7^
4OlAkQ401?lAkQ400ol0003o:MHYobWF:@09obWF:@03o`000?m[U6_oJiA[00SoJiA[00?o0000ohQg
R?n8MhP00on8MhP2o`0000codBkA00?o0000onLHiooW6>L02?oW6>L<o`0000?onPGj0ol0000=ooh1
oP03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooP7n?oh1oP01_oh1oP3o`0000Oon0Oh00?o0000onDJiOoU6^D01_oU6^D00ol0003o
XEjQoj5NX@0;oj5NX@03o`000?m4^dCoA;]400WoA;]40_l0000>o`o`3`03o`000?lAkQ7o4NhA00Go
4NhA00?o0000obWF:OlYeRT02OlYeRT00ol0003oJiA[of^DJ`09of^DJ`03o`000?n8MhSo000000;o
00000_o6>LH00ol0003odBkAom4^d@08om4^d@03o`000?oW6>OoiaSW00coiaSW00?o0000ooH9m_of
2OH01_of2OH3o`0000?ooP7n0_l00009ooh1oP;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on0OhooP7n003ooP7n0?o00002ooh1oP00ol0003oiA[U
onDJi@04onDJi@03o`000?nQGZ7oXEjQ00_oXEjQ0ol00007odBkA0?o000000?o:m@[o`000?l?l0l0
3Ol?l0l00ol0003o4NhAoa7^4@06oa7^4@03o`000?lYeRWo:MHY00So:MHY00?o0000of^DJom[U6/0
2_m[U6/00ol0003oaSW6olHiaP04olHiaP03o`000?oA;]7odBkA00OodBkA00?o0000onLHiooW6>L0
2ooW6>L00ol0003omPWfooH9mP08ooH9mP03o`000?on0OkooP7n00CooP7n0ol00004ooh1oP;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooP7n?l0
003o0000o`0000oon0Oh00?o0000onDJiOoU6^D00ooU6^D>o`0000?oRgB;0_l00002odBkA0?o0000
1Ol[e2/00ol0003o3o0?o`o`3`0:o`o`3`03o`000?lAkQ7o4NhA00Oo4NhA00?o0000obWF:OlYeRT0
2?lYeRT00ol0003oJiA[of^DJ`0:of^DJ`03o`000?o6>LKoaSW600GoaSW600?o0000om4^dOoA;]40
1_oA;]400ol0003oiaSWonLHi`0;onLHi`03o`000?of2OKomPWf00SomPWf00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ooh1o_l0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?om0_d2o`0001;on0Oh00?o0000onDJiOoU6^D00_oU6^D00ol0003ofRGJomXU
fP0:omXUfP03o`000?n;M8_oRgB;00?oRgB;0_l00009ob_D:`03o`000?l?l0oo3o0?00Wo3o0?00?o
0000oa7^4OlAkQ402?lAkQ42o`0000So:MHY00?o0000of^DJom[U6/02Om[U6/00ol0003oaSW6olHi
aP07olHiaP03o`000?oA;]7odBkA00CodBkA00?o0000onLHiooW6>L02ooW6>L00ol0003omPWfooH9
mP09ooH9mP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ood2oOom0_d01oom0_d00ol0003on0OhooP7n00?ooP7n0?o000000?oiA[U
o`000?oJ9MX02ooJ9MX00ol0003oRgB;oh]dR`04oh]dR`03o`000?l[e2_o:m@[00Wo:m@[00?o0000
o`o`3ol?l0l01ol?l0l00ol0003o4NhAoa7^4@09oa7^4@04o`000?l^dBko0000o`0000Ko:MHY00?o
0000of^DJom[U6/02Om[U6/00ol0003oaSW6olHiaP08olHiaP03o`000?oA;]7odBkA00?odBkA00?o
0000onLHiooW6>L02ooW6>L00ol0003omPWfooH9mP09ooH9mP03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ood2oOom0_d02?om0_d0
0ol0003on0OhooP7n00<ooP7n0;o00000oog2?L2o`0000cofRGJ00?o0000oh]dRon;M8/01?n;M8/0
0ol0003o:m@[ob_D:`0:ob_D:`Wo00002olAkQ400ol0003o;]4^obkA;P02obkA;P?o00000_lYeRT0
0ol0003oJiA[of^DJ`0:of^DJ`03o`000?o6>LKoaSW600WoaSW600?o0000om4^dOoA;]400_oA;]40
0ol0003oiaSWonLHi`0:onLHi`03o`000?of2OKomPWf00WomPWf00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@09ood2
o@;o00002_oh1oP2o`0000Gom`Sg00?o0000onLHiol000002_oJ9MX00ol0003oRgB;oh]dR`06oh]d
R`03o`000?l[e2_o:m@[00Wo:m@[00?o0000oaKY5_lFjAH01OlFjAH00ol0003o4NhAoa7^4@09oa7^
4@03o`000?l^dBko;]4^00Go;]4^0ol00009of^DJ`?o00003Oo6>LH01Ol0003odBkAom4^dOoA;]7o
000000coiaSW00?o0000ooH9m_of2OH02Oof2OH00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m00coo@;m00?o0000ooP7
n?oh1oP01Ooh1oP2o`0000Oom`Sg00Co0000onLHiooW6>Oo00002OoJ9MX00ol0003oRgB;oh]dR`06
oh]dR`03o`000?l[e2_o:m@[00So:m@[00?o0000oaKY5_lFjAH01olFjAH00ol0003o4NhAoa7^4@07
oa7^4@03o`000?l^dBko;]4^00So;]4^0ol00002of^DJ`Go00000_naC[400ol0003oaSW6olHiaP0<
olHiaP03o`000?oA;]7o000000coiaSW00?o0000ooH9m_of2OH02_of2OH00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?om0_goo@;m
00goo@;m00?o0000ooP7n?oh1oP00_oh1oP2o`0000Som`Sg00?o0000onLHiooW6>L00_oW6>L5o`00
00CofRGJ00?o0000oh]dRon;M8/01_n;M8/00ol0003o:m@[ob_D:`08ob_D:`03o`000?lFjAKo5^TF
00Oo5^TF00?o0000oa7^4OlAkQ401olAkQ400ol0003o;]4^obkA;P08obkA;P03o`000?mfRGKoMXUf
00;o00002?naC[400ol0003oaSW6olHiaP0<olHiaPCo00002_oW6>L00ol0003omPWfooH9mP0:ooH9
mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ood2oOom0_d03_om0_d01?l0003on0Oho`000?l0000:ooL8m`03o`000?oW6>OoiaSW
00;oiaSW00?o0000ol8m`_o2?L800_o2?L84o`0000WoRgB;00?o0000ob_D:ol[e2/02?l[e2/00ol0
003o5^TFoaKY5P08oaKY5P03o`000?lAkQ7o4NhA00Go4NhA00?o0000obkA;_l^dBh02?l^dBh01Ol0
003oMXUfogJ9M_mfRGKo000000[o/Dja0ol0000;olHiaP04o`000?o`3o3ol0o`oo0?l0Co00001OoW
6>L00ol0003omPWfooH9mP0;ooH9mP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ood2oOom0_d03oom0_d00ol0003om`SgooL8m`0:
ooL8m`03o`000?oW6>OoiaSW00?oiaSW00?o0000ol8m`_o2?L801?o2?L800ol0003oRgB;oh]dR`07
oh]dR`03o`000?l[e2_o:m@[00Ko:m@[0_l0000;oaKY5P03o`000?lAkQ7o4NhA00Go4NhA00?o0000
obkA;_l^dBh02?l^dBh00ol0003oMXUfogJ9MP02ogJ9MP03o`000?naC[7o/Dja00Oo/Dja00?o0000
on0Oh?oP7n001?l00006olHiaP03o`000?o`3o3ol0o`00Kol0o`0ol00002onLHi`03o`000?of2OKo
mPWf00_omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?og2?Oom`Sg00Wom`Sg00?o0000onLH
iooW6>L01?oW6>L00ol0003o`Sg2ol8m`P05ol8m`P03o`000?n;M8_oRgB;00OoRgB;00?o0000ob_D
:ol[e2/00_l[e2/3o`000003od2o@?l0003o5^TF00[o5^TF00?o0000oa7^4OlAkQ401OlAkQ400ol0
003o;]4^obkA;P07obkA;P03o`000?mfRGKoMXUf00?oMXUf00?o0000ok5>/OnaC[401onaC[400ol0
003oh1oPon0Oh004on0Oh0?o00000_o6>LH00ol0003ol0o`oo0?l00:oo0?l0;o00003_of2OH00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?om0_goo@;m013oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003oiaSWonLHi`04onLHi`03
o`000?o2?L;o`Sg200Ko`Sg20_l00007oh]dR`03o`000?l[e2_o000000;o00001Om0_d000ol0003o
5^TFoaKY5P08oaKY5P?o00001?lAkQ400ol0003o;]4^obkA;P08obkA;P03o`000?mfRGKoMXUf00Co
MXUf00?o0000ok5>/OnaC[401_naC[400ol0003oh1oPon0Oh007on0Oh0;o00003_o`3o000ol0003o
mPWfooH9mP0;ooH9mP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ood2oOom0_d04Oom0_d00ol0003om`SgooL8m`08ooL8m`03o`00
0?oW6>OoiaSW00GoiaSW00?o0000ol8m`_o2?L801?o2?L800ol0003o`Ck1ol4n`@03o`0000CoRgB;
0_l00008od2o@003o`000?lFjAKo5^TF00Oo5^TF00Co0000ocK9=_lfbCKo=/Tf0ol000000olAkQ7o
0000obkA;P09obkA;P03o`000?mfRGKoMXUf00CoMXUf00?o0000ok5>/OnaC[401OnaC[400ol0003o
h1oPon0Oh009on0Oh003o`000?o`3o3ol0o`00gol0o`00?o0000ooH9m_of2OH02_of2OH00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?om0_goo@;m017oo@;m00?o0000ooL8moog2?L01oog2?L00ol0003oiaSWonLHi`06onLHi`03o`00
0?o2?L;o`Sg200?o`Sg200?o0000ol4n`Oo1?/401?o1?/42o`000003oh]dRol0003o@;m000[o@;m0
00?o0000oaKY5_lFjAH01OlFjAH00ol0003o=/TfocK9=P05ocK9=P03o`000?l^dBko;]4^00Oo;]4^
0ol00007ogJ9MP03o`000?naC[7o/Dja00Co/Dja00?o0000on0Oh?oP7n002OoP7n000ol0003ol0o`
oo0?l00=oo0?l003o`000?of2OKomPWf00[omPWf00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003oo@;mood2o@0@ood2o@03o`000?og
2?Oom`Sg00Gom`Sg0ol00009onLHi`05o`000?o2?L;o`Sg2ol8m`_l000002Oo1?/400ol0003o@;m0
od2o@00;od2o@003o`000?lFjAKo5^TF00?o5^TF00?o0000ocK9=_lfbCH01_lfbCH00ol0003o;]4^
obkA;P06obkA;P05o`000?m[U6_oJiA[of^DJol000001omfRGH00ol0003o/Djaok5>/@03ok5>/@03
o`000?oP7n3oh1oP00Woh1oP00?o0000oo0?l?o`3o003_o`3o000ol0003omPWfooH9mP09ooH9mP03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ood2oOom0_d04Oom0_d00ol0003om`Sgo`000004o`0000;onPGj00?o0000onLHiooW6>L0
1ooW6>L01?l0003o`Sg2ol8m`_l00009ol4n`@;o00003Om0_d000ol0003o5^TFoaKY5P02oaKY5P03
o`000?lfbCKo=/Tf00So=/Tf00?o0000obkA;_l^dBh00ol^dBh2o`0000GoJiA[00?o0000ogJ9M_mf
RGH01?mfRGH00ol0003o/Djaok5>/@03ok5>/@03o`000?oP7n3oh1oP00Woh1oP00?o0000oo0?l?o`
3o003_o`3o000ol0003omPWfooH9mP09ooH9mP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ood2oOom0_d04Oom0_d2o`0000SonPGj
00?o0000onLHiooW6>L01_oW6>L00ol0003o`Sg2o`000009ol4n`@04o`000?nCK9?oTfbCo`0000go
@;m000Co0000oaKY5_lFjAKo00003?lfbCH01Ol0003o;]4^obkA;_l^dBko000000SoJiA[0_l00005
ogJ9MP03o`000?naC[7o/Dja00;o/Dja00?o0000on0Oh?oP7n002OoP7n000ol0003ol0o`oo0?l00>
oo0?l003o`000?of2OKomPWf00WomPWf00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0@ood2o@03o`000?oj1O[onPGj
00OonPGj00?o0000onLHiooW6>L01ooW6>L00ol0003o`Ck1ol4n`@07ol4n`@03o`000?nCK9?oTfbC
00;oTfbC00?o0000od2o@?m0_d002_m0_d000ol0003o5^TFo`00000>ocK9=P03o`000?l^dBko0000
00_oJiA[00?o0000ogJ9M_mfRGH00_mfRGH01Ol0003o/Djaok5>/OnaC[7o000000coh1oP00?o0000
oo0?l?o`3o003_o`3o03o`0000WomPWf00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oj1O[onPGj
00WonPGj00?o0000onLHiooW6>L01_oW6>L00ol0003o`Ck1ol4n`@06ol4n`@03o`000?nCK9?oTfbC
00?oTfbC00?o0000od2o@?m0_d002om0_d000ol0003o=/TfocK9=P0>ocK9=P03o`000?m[U6_oJiA[
00_oJiA[0_l00003ogJ9MP04o`000?naC[7o/Djao`0000[oh1oP0ol0000>oo0?l0;o00000oon0Oh2
o`0000OomPWf00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003oo@;mood2o@0?ood2o@03o`000?oj1O[onPGj00[onPGj00?o0000onLH
iooW6>L01?oW6>L00ol0003o`Ck1ol4n`@06ol4n`@03o`000?nCK9?oTfbC00GoTfbC00?o0000od2o
@?m0_d001om0_d03o`00017o=/Tf00?o0000of^DJom[U6/03Om[U6/01Ol0003oMXUfogJ9M_l0003o
/Dja00Co00000ooP7n05o`0000;on0Oh00?o0000oo0?l?o`3o002_o`3o02o`0000OooP7n0_l00004
ooH9mP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ood2oOom0_d03_om0_d00ol0003onPGjooX5nP0;ooX5nP03o`000?oW6>OoiaSW
00CoiaSW00?o0000ol4n`Oo1?/401Oo1?/400ol0003oTfbCoi=/T`06oi=/T`03o`000?m0_d3o@;m0
00Co@;m00ol00002odJiAP03o`000?lfbCKo=/Tf00oo=/Tf0_l0000?of^DJ`04o`000?mfRGKo0000
o`0000CodbcC0ol00008ooP7n003o`000?o`3o3ol0o`00Ool0o`0_l0000;ooh1oP;o00000_of2OH0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?om0_goo@;m00goo@;m00?o0000ooX5n_oj1OX03?oj1OX6o`0000Oo`Ck100?o0000oi=/
TonCK9<02?nCK9<00ol0003o@;m0od2o@003o`0000KoA[U600?o0000ocK9=_lfbCH03OlfbCH01?l0
003oL8m`og2?L?l0000?of^DJ`03o`000?oC;=?odbcC00GodbcC00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ol0o`oo0?l005oo0?l003o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oj1OX00ol0003ojQGZonXEjP04onXE
jP03o`000?o1?/7o`Ck100?o`Ck100?o0000oi=/TonCK9<02_nCK9<2o`0000[oA[U600?o0000ocK9
=_lfbCH02olfbCH00ol0003oL8m`og2?L002og2?L003o`000?m[U6_oJiA[00_oJiA[0_l00007om</
d`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo0?l?o`3o000_o`3o02o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ojQGZonXEjP06onXEjP05o`000?o1?/7o`Ck1ol4n
`Ol000003OnCK9<00ol0003oA[U6odJiAP0:odJiAP03o`000?lfbCKo=/Tf00Wo=/Tf00?o0000og2?
L?m`Sg001?m`Sg000ol0003oJiA[of^DJ`08of^DJ`;o000000?oWf2Oo`000?oC;=<01ooC;=<00ol0
003on0OhooP7n009ooP7n004o`000?o`3o3o0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oj1O[onPGj
00WonPGj00?o0000onXEj_oZ5NX02?oZ5NX00ol0003o`Ck1o`00000=oi=/T`03o`000?m6^DKoA[U6
00_oA[U600?o0000ocK9=_lfbCH02?lfbCH00ol0003oL8m`og2?L006og2?L003o`000?m[U6_oJiA[
00GoJiA[0_l00003oimPW`03o`000?oC;=?odbcC00KodbcC00?o0000ooP7n?oh1oP02_oh1oP00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003onPGjooX5nP07ooX5nP03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000oi=/TonC
K9<03?nCK9<00ol0003oA[U6odJiAP0<odJiAP03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000og2?L?m`
Sg002?m`Sg000ol0003oJiA[of^DJ`02of^DJ`;o00001_nOH9l00ol0003odbcCom</d`05om</d`03
o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj00GonPGj
00?o0000onXEj_oZ5NX03?oZ5NX2o`0000coTfbC00?o0000odJiA_m6^DH03Om6^DH00ol0003o=/Tf
ocK9=P04ocK9=P03o`000?m`Sg3oL8m`00[oL8m`00Co0000of^DJol0003o00002?nOH9l00ol0003o
dbcCom</d`06om</d`03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_oj1OX00ol0003ojQGZonXEjP0=onXEjP03o`000?o1?/7o000000;o00002?nCK9<00ol0003oA[U6
odJiAP0?odJiAPKo00003_m`Sg000ol0003oWf2OoimPW`08oimPW`03o`000?oC;=?odbcC00KodbcC
00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo/4nook1?_on`Ck
0_l0000?onXEjP03o`000?o1?/7o`Ck100?o`Ck10ol00005oi=/T`;o00004?m6^DH01_l0003oEZUF
oeJYE_l0003oD:m@o`0000koL8m`00?o0000oimPWonOH9l02OnOH9l00ol0003odbcCom</d`05om</
d`03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo/4nook1?/00ook1?/00ol0003o
jQGZonXEjP0=onXEjP03o`000?o1?/7o`Ck100Ko`Ck10ol000001?nCK9?o0000ogB;M?mdRg@3o`00
00coA[U600Go0000oeJYE_mFZEKoEZUFo`000002oe2_D003o`000?m`Sg3oL8m`00_oL8m`00?o0000
oimPWonOH9l02OnOH9l00ol0003odbcCom</d`06om</d`03o`000?oh1oSon0Oh00Son0Oh0_l0000A
ooh1oP?o000000?ooP7no`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003on`Ckoo/4n`04oo/4n`oo00003?o1?/400ol0003oM8]dogB;M004ogB;
M0?o00002?m6^DH00ol0003oEZUFoeJYEP02oeJYEP05o`000?m@[e3oD:m@oe2_D?l000003?m`Sg00
0ol0003oWf2OoimPW`09oimPW`03o`000?oC;=?odbcC00GodbcC3?l00002oo`3o0;o00003Oon0Oh2
o`0000GooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?o/4ncok1?/00_ok1?/00?o0000ol4n
`Oo1?/402_o1?/400ol0003oM8]dogB;M007ogB;M0;o00001Om6^DH00ol0003oEZUFoeJYEP03oeJY
EP03o`000?m@[e3oD:m@00;oD:m@00?o0000og2?L?m`Sg002Om`Sg000ol0003oWf2OoimPW`0:oimP
W`03o`000?oC;=?odbcC00?odbcC00?o0000oo@;m?od2o@02Ood2o@00ol0003oo0?loo`3o002oo`3
o0;o00002Oon0Oh2o`0000OooP7n00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?o/4ncok1?/00[o
k1?/00?o0000ol4n`Oo1?/402oo1?/400ol0003oM8]dogB;M009ogB;M0?o000000?oA[U6o`000?mF
ZEH01OmFZEH00ol0003oD:m@oe2_D003oe2_D003o`000?m`Sg3oL8m`00SoL8m`3_l00003om</d`;o
00002ood2o@00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n0ol00009ooh1oP03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo/4nook1?/01Ook1?/00ol0003ol@kao`00000;on`Ck003o`000?o1?/7o`Ck100[o`Ck1
0_l0000>ogB;M003o`000?mFZEKoEZUF00GoEZUF00?o0000oe2_D?m@[e000om@[e000ol0003oL8m`
og2?L008og2?L003o`000?oC;=?odbcC00_odbcC00?o0000om</dol000003Ood2o@00ol0003oo0?l
oo`3o006oo`3o0;o000000?ooP7no`000?l000003Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00Co
0000oo4>lOoa3_7o00002_o/4n`00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nWF:Oo000000koM8]d
00?o0000oeJYE_mFZEH01OmFZEH00ol0003oD:m@oe2_D004oe2_D003o`000?m`Sg3oL8m`00KoL8m`
00?o0000om</dooC;=<03OoC;=<00ol0003om0_doo@;m00<oo@;m003o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo4>lOoa3_400_oa
3_400ol0003ok1?/on`Ck006on`Ck003o`000?o1?/7o`Ck100So`Ck10_l00003ojMHY`03o`000?md
RgCoM8]d00_oM8]d00?o0000oeJYE_mFZEH01OmFZEH00ol0003oD:m@oe2_D005oe2_D003o`000?m`
Sg3oL8m`00GoL8m`00?o0000om</dooC;=<03OoC;=<00ol0003om0_doo@;m00;oo@;m003o`000?ol
0ocoo0?l00Woo0?l00?o0000ooh1o_on0Oh03Oon0Oh00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo4>lOoa3_400ooa3_400ol0003ok1?/on`Ck005on`Ck003o`000?o1?/7o`Ck100Oo`Ck100?o0000
ojMHYonWF:L00onWF:L00ol0003oM8]dogB;M00:ogB;M003o`000?mFZEKoEZUF00KoEZUF00?o0000
oe2_D?m@[e001_m@[e000ol0003oL8m`og2?L004og2?L003o`000?oC;=?odbcC00godbcC3ol0000;
oo`3o003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo4>lOoa3_401Ooa3_400ol0
003ok1?/on`Ck004on`Ck003o`000?o1?/7o`Ck100Go`Ck10_l00006ojMHY`03o`000?mdRgCoM8]d
00WoM8]d0_l00008oeJYEP03o`000?m@[e3oD:m@00KoD:m@1Ol000000om`Sg3o0000om</d`0?om</
d`03o`000?of2OKomPWf00_omPWf00?o0000oo`3o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0<ooh1
oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo4>lOoa3_401_oa3_400ol0003o
k1?/on`Ck004o`0000Ko`Ck100?o0000ojMHYonWF:L01onWF:L00ol0003oM8]dogB;M005ogB;M0?o
000000?oLhaco`000?mFZEH01omFZEH00ol0003oD:m@oe2_D005oe2_D003o`000?n=LXgoSG:=00?o
SG:=0_l0000?om</d`;o00003Oof2OH00ol0003oo0?loo`3o008oo`3o003o`000?on0OkooP7n00go
oP7n00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Won`Ck00?o0000oo4>lOoa3_401ooa3_42o`0000CofRGJ00Co0000ol4n`Oo1?/7o
`Ck10_l0000:ojMHY`03o`000?mdRgCoM8]d00;oM8]d0ol00005og><L`03o`000?mFZEKoEZUF00Go
EZUF00?o0000oe2_D?m@[e001?m@[e000ol0003oSG:=ohebS@06ohebS@03o`000?oC;=?odbcC00[o
dbcC0_l00002on`Ck003o`000?of2OKomPWf00[omPWf00?o0000oo`3o?ol0o`02?ol0o`00ol0003o
oP7nooh1oP0=ooh1oP03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo/4nook1?/01_ok1?/00ol0003ol@kaoo4>l@08oo4>l@03o`00
0?oJ9M[ofRGJ00CofRGJ00?o0000ol4n`Ol000003?nWF:L00ol0003oM8]do`000002o`0000WoLhac
00?o0000oeJYE_mFZEH01?mFZEH00ol0003oD:m@oe2_D003oe2_D003o`000?n=LXgoSG:=00SoSG:=
1_l00004om</d`;o00001Oo/4n`00ol0003omPWfooH9mP09ooH9mP03o`000?ol0ocoo0?l00Soo0?l
00?o0000ooh1o_on0Oh03?on0Oh00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo4>lOoa3_401ooa
3_400ol0003ofRGJomXUfP06omXUfP03o`000?nWF:OoYeRW00coYeRW00?o0000og><LomcS7<02_mc
S7<00ol0003oEZUFoeJYEP04oeJYEP04o`000?m@[e3oD:m@oe2_D0;o00002on=LXd00ol0003of2OH
omPWf003omPWf0Co00002?o/4n`00ol0003omPWfooH9mP08ooH9mP03o`000?ol0ocoo0?l00Ooo0?l
0ol0000=ooh1oP03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003ol@kaoo4>l@07oo4>l@03o`000?oJ
9M[ofRGJ00OofRGJ00?o0000ojMHYonWF:L03?nWF:L00ol0003oLhacog><L`0;og><L`03o`000?mF
ZEKoEZUF00?oEZUF00Co0000oe2_D?m@[e3o00003On=LXd00ol0003of2OHomPWf006omPWf003o`00
0?o/4ncok1?/00Ook1?/00?o0000ooH9m_of2OH01oof2OH00ol0003oo0?loo`3o006oo`3o004o`00
0?oo0?ooo`3oool0o`;o00002oon0Oh00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00;on`Ck00?o0000oo4>lOoa3_40
1_oa3_400ol0003ofRGJomXUfP09omXUfP03o`000?nWF:OoYeRW00WoYeRW0_l0000>og><L`?o0000
0omFZEH00ol0003oD:m@o`00000=ohebS@03o`000?oH9mSof2OH00Oof2OH00?o0000on`Ck?o/4n`0
2?o/4n`:o`0000Koo0?l0_l00006ool0o`03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Ool@ka00?o
0000omXUf_oJ9MX02_oJ9MX00ol0003oYeRWojMHY`06ojMHY`;o000000?oYEZUo`000?mcS7<02omc
S7<2o`0000?oNXEj1Ol0000>ohebS@03o`000?oH9mSof2OH00Oof2OH00?o0000on`Ck?o/4n`02?o/
4n`00ol0003on@KiooT6n@06ooT6n@03o`000?ol0ocoo0?l00?oo0?l00?o0000ool0oooo0?l01ooo
0?l2o`0000SooP7n00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`03ooL8m`Co00000_oa3_400ol0003ofRGJomXUfP0;
omXUfP03o`000?nWF:OoYeRW00?oYeRW0ol00004ojEJY@03o`000?mcS7?oLhac00OoLhac0_l00008
ogZ5NP03o`000?n=LXgoSG:=00goSG:=00?o0000omPWf?oH9mP02?oH9mP00ol0003ok1?/on`Ck007
on`Ck003o`000?oi1_Won@Ki00Oon@Ki0ol000000ool0oco0000ool0o`0;ool0o`;o00001Oon0Oh0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?og2?Oom`Sg00Oom`Sg0_l0000?omXUfP03o`000?nWF:OoYeRW00;o00002?nUFZD00ol0
003oLhacog><L`05og><L`03o`000?mjQG[oNXEj00SoNXEj00?o0000ohebSOn=LXd03On=LXd00ol0
003of2OHomPWf008omPWf003o`000?o/4ncok1?/00Kok1?/00?o0000ooT6nOoi1_T02?oi1_T01?l0
003oo@;mood2oOl0000?ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003om`SgooL8m`09ooL8
m`03o`000?oJ9M[ofRGJ00kofRGJ0_l0000;ojEJY@03o`000?mcS7?oLhac00;oLhac0_l0000;ogZ5
NP03o`000?n=LXgoSG:=00goSG:=00?o0000omPWf?oH9mP02?oH9mP00ol0003ok1?/on`Ck006on`C
k003o`000?oi1_Won@Ki00Oon@Ki00Go0000ood2oOom0_goo@;mo`00000@ool0o`;o000000?ooP7n
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003om`SgooL8m`0:ooL8m`03o`000?oJ9M[ofRGJ00gofRGJ0_l0000<ojEJY@04o`000?mcS7?o0000
o`0000goNXEj00?o0000ohebSOn=LXd03?n=LXd00ol0003of2OHomPWf009omPWf003o`000?o/4nco
k1?/00Kok1?/00?o0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003om`SgooL8m`0:ooL8m`03o`000?oJ9M[ofRGJ00cofRGJ00Co0000omXU
f_oJ9M[o00003?nUFZD00ol0003oNXEjogZ5NP0>ogZ5NP03o`000?n=LXgoSG:=00SoSG:=1?l0000;
omPWf003o`000?o/4ncok1?/00Kok1?/00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oo@;mood2o@04
ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003om`SgooL8m`0;ooL8m`03o`000?oJ9M[ofRGJ
00_ofRGJ00?o0000omXUf_oJ9MX00_oJ9MX00ol0003oYEZUojEJY@09ojEJY@03o`000?mjQG[oNXEj
00koNXEj00Co0000ohebSOn=LXgoSG:=1ol00003ok9=/P03o`000?oH9mSof2OH00Wof2OH00?o0000
on`Ck?o/4n`01_o/4n`00ol0003on@KiooT6n@04ooT6n@03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00com`Sg00?o0000omXUf_oJ9MX02_oJ9MX00ol0
003ofRGJomXUfP03omXUfP03o`000?nUFZGoYEZU00SoYEZU00?o0000ogZ5N_mjQGX03_mjQGX4o`00
00_o/Tfb00?o0000omPWf?oH9mP02?oH9mP00ol0003ok1?/on`Ck005on`Ck003o`000?oi1_Won@Ki
00Gon@Ki00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog
2?L03?og2?L7o`0000GofRGJ00?o0000omXUf_oJ9MX01OoJ9MX00ol0003oYEZUojEJY@07ojEJY@03
o`000?mjQG[oNXEj00koNXEj00?o0000ok9=/_nbCK803OnbCK800ol0003of2OHomPWf008omPWf003
o`000?o/4ncok1?/00Cok1?/00?o0000ooT6nOoi1_T01?oi1_T00ol0003oo@;mood2o@07ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003om`SgooL8m`0=ooL8m`03o`000?o/4ncok1?/00Cok1?/
1Ol00009omXUfP03o`000?nUFZGoYEZU00KoYEZU00?o0000ogZ5N_mjQGX03_mjQGX00ol0003o/Tfb
ok9=/P0=ok9=/P03o`000?oH9mSof2OH00Sof2OH00Co0000on`Ck?o/4ncok1?/1Ol00004ooT6n@03
o`000?om0_goo@;m00Woo@;m1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooL8m`03o`000?o/4ncok1?/00Wok1?/
0_l00009omXUfP03o`000?nUFZGoYEZU00KoYEZU00?o0000ogZ5N_mjQGX03?mjQGX00ol0003o/Tfb
ok9=/P0?ok9=/PKo00001?oH9mP4o`0000GomPWf0_l000000ooi1_Wo0000ood2o@0;ood2o@04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?ok1?_on`Ckoo/4n`?o00002_og2?L00ol0003o
k1?/on`Ck009on`Ck003o`000?oT6nCo000000;o00001ooJ9MX00ol0003oYEZUojEJY@05ojEJY@03
o`000?mjQG[oNXEj00SoNXEj1Ol0000Aok9=/P03o`000?oQ7^7ohAkQ00?ohAkQ1?l0000;ooH9mP03
o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000Oom`Sg
00?o0000on`Ck?o/4n`02_o/4n`00ol0003oi1_Ton@Ki002on@Ki0?o00001OoJ9MX00ol0003oYEZU
ojEJY@04ojEJY@04o`000?mjQG[oNXEjogZ5NPOo00001?ncC;<00ol0003o/Tfbok9=/P0>ok9=/P03
o`000?oQ7^7ohAkQ00OohAkQ00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@09ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`08oo/4n`;o00001?og2?L00ol0003ok1?/
on`Ck00;on`Ck003o`000?oT6nCoi1_T00Goi1_T0ol00003omXUfP04o`000?nUFZGoYEZUojEJY@Ko
00003?ncC;<00ol0003o/Tfbok9=/P0=ok9=/P03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ooH9m_of
2OH02_of2OH00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo/4n`?o000000?om`Sgo`000?o/4n`0
3?o/4n`00ol0003oi1_Ton@Ki008on@Ki0?o000000CofRGJo`000?l0003o00000_oG:=L00ol0003o
/dbcok=</`0=ok=</`03o`000?nbCK;o/Tfb00co/Tfb00?o0000on4NhOoQ7^402?oQ7^400ol0003o
mPWfooH9mP0;ooH9mP03o`000?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003ooP7nooh1o_on0Oko000000oo
n`Ck00?o0000on`Ck?o/4n`03?o/4n`00ol0003oi1_Ton@Ki00;on@Ki003o`000?oG:=OoebSG00?o
ebSG00?o0000ok=</oncC;<03?ncC;<00ol0003oa3_4o`00000=ok9=/P03o`000?oQ7^7ohAkQ00So
hAkQ00?o0000ooH9m_of2OH03?of2OH3o`0000Goo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP03ooh1oP03o`00
0?ok1?_on`Ck00con`Ck00?o0000on`Ck?o/4n`03?o/4n`00ol0003oi1_Ton@Ki00:on@Ki003o`00
0?oG:=OoebSG00GoebSG00?o0000ok=</oncC;<02_ncC;<01?l0003oa3_4ol@ka?o4>l@2o`0000[o
/Tfb00?o0000on4NhOoQ7^402OoQ7^400ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00?o
000000?oo@;mo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003ooP7nooh1oP04ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000on`Ck?o/4n`0
3?o/4n`00ol0003oi1_Ton@Ki009on@Ki003o`000?oG:=OoebSG00KoebSG00?o0000ok=</oncC;<0
2OncC;<00ol0003oa3_4ol@ka002ol@ka003o`000?oJ9M[o000000;o00001onbCK800ol0003ohAkQ
on4Nh@09on4Nh@03o`000?of2OKomPWf00_omPWf00?o0000ood2oOom0_d01?om0_d00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?on
0OkooP7n00KooP7n00?o0000oo/4nook1?/02ook1?/00ol0003ok1?/on`Ck00;on`Ck003o`000?oT
6nCoi1_T00Soi1_T00?o0000omLXeooG:=L01ooG:=L00ol0003o/dbcok=</`08ok=</`03o`000?o4
>lCoa3_400?oa3_400?o0000omXUf_oJ9MX00_oJ9MX2o`0000Co/Tfb00?o0000on4NhOoQ7^402_oQ
7^400ol0003omPWfooH9mP0:ooH9mP03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003ooP7nooh1oP07
ooh1oP03o`000?ok1?_on`Ck00[on`Ck0ol0000;on`Ck0Ko00001?oT6n@00ol0003oebSGomLXe`08
omLXe`03o`000?ncC;?o/dbc00Oo/dbc00?o0000ol@ka?o4>l@00oo4>l@00ol0003ofRGJomXUfP05
omXUfP?o000000?o/Tfbo`000?oQ7^402ooQ7^400ol0003omPWfooH9mP09ooH9mP03o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00?o0000ooT6
nOoi1_T01?l00006on`Ck003o`000?o^4NkokQ7^00CokQ7^1?l0000<omLXe`03o`000?ncC;?o/dbc
00Go/dbc00?o0000ol@ka?o4>l@01?o4>l@00ol0003ofRGJomXUfP08omXUfP03o`000?oQ7^7ohAkQ
00_ohAkQ00?o0000ooH9m_of2OH02?of2OH00ol0003oo@;mood2o@08ood2o@Go00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003ooP7nooh1oP0:ooh1oP03
o`000?ok1?_on`Ck00Oon`Ck00?o0000ooT6nOoi1_T01Ooi1_T3o`0000;ok1?/00?o0000onhAk_o^
4Nh02?o^4Nh00ol0003oebSGomLXe`0:omLXe`03o`000?ncC;?o/dbc00Co/dbc00?o0000ol@ka?o4
>l@01Oo4>l@00ol0003ofRGJomXUfP08omXUfP03o`000?oQ7^7ohAkQ00WohAkQ1?l00008ooH9mP03
o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`05oo/4n`03o`000?oi1_Won@Ki00Won@Ki0_l0000<onhAkP03o`000?oG:=OoebSG00WoebSG
00?o0000ok=</oncC;<00oncC;<00ol0003oa3_4ol@ka005ol@ka003o`000?oJ9M[ofRGJ00[ofRGJ
00?o0000on4NhOoQ7^401?oQ7^44o`0000Com0_d00?o0000ooH9m_of2OH01?of2OH00ol0003oo@;m
ood2o@0:ood2o@03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooT6nOoi1_T02ooi
1_T00ol0003okQ7^onhAkP0:onhAkP03o`000?oG:=OoebSG00WoebSG00?o0000ok=</oncC;<00_nc
C;<00ol0003oa3_4ol@ka006ol@ka003o`000?oJ9M[ofRGJ00[ofRGJ00?o0000on4NhOoQ7^401?l0
0009oo@;m0Ko00003?om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?on0OkooP7n00cooP7n00Co0000oo/4nook1?_on`Ck0_l0
000=ooT6n@03o`000?o^4NkokQ7^00[okQ7^00?o0000omLXeooG:=L02OoG:=L01Ol0003o/dbcok=<
/oncC;?o000000Woa3_400?o0000omXUf_oJ9MX02ooJ9MX2o`0000gom0_d00?o0000ood2oOom0_d0
0_om0_d00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Cko`00
0002ooh1oP;o00002ooi1_T00ol0003okQ7^onhAkP0;onhAkP03o`000?oG:=OoebSG00WoebSG00?o
0000ok=</ol000002Oo4>l@00ol0003ofRGJomXUfP0<omXUfP03o`000?od2oCom0_d00com0_d00?o
0000ood2oOom0_d00oom0_d00ol0003oo@;mood2o@09ood2o@03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oi1_T00ol0003okQ7^onhAkP0:onhAkP03o`000?oG:=Oo
ebSG00SoebSG1Ol00008ol@ka003o`000?oJ9M[ofRGJ00cofRGJ00?o0000oo@;m?od2o@02ood2o@0
0ol0003oo@;mood2o@05ood2o@03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003ooP7nooh1oP0<ooh1
oP;o00001oon0Oh2o`0000Son@Ki00?o0000onhAk_o^4Nh02_o^4Nh00ol0003oebSGomLXe`07omLX
e`03o`000?oN8MkogR7N00?ogR7N0ol00005ol@ka003o`000?oJ9M[ofRGJ00_ofRGJ00?o0000oo@;
m?od2o@03?od2o@00ol0003oo@;mood2o@06ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
oP7nooh1oP0;ooh1oP03o`000?oo0?oo000000WooP7n00?o0000ooT6nOoi1_T01Ooi1_T2o`0000co
kQ7^00?o0000omLXeooG:=L01OoG:=L00ol0003ogR7NomhQgP07omhQgP?o000000?oa3_4o`000?oJ
9MX03OoJ9MX00ol0003om0_doo@;m00<oo@;m003o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom
0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?on0OkooP7n00SooP7n0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooT6n@03o`000?ok1?_on`Ck00;o00002_o^4Nh00ol0003oebSGomLXe`03omLXe`;o0000
3OoN8Mh2o`0000gofRGJ0ol0000=oo@;m003o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom0_d0
1Oom0_d00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooi1_Wo0000oo/4n`04oo/4n`03o`000?o^4NkokQ7^00OokQ7^00Co0000omLXeooG:=OoebSG
0_l00002oo4>l@03o`000?oN8MkogR7N00cogR7N3Ol00003ooH9mP03o`000?od2oCom0_d00[om0_d
00?o0000ood2oOom0_d02?om0_d01?l0003oo@;mood2oOom0_d4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ooh1oP;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck0_l00008onhAkP03o`000?oG:=Oo000000Gol@ka
00?o0000omhQg_oN8Mh02ooN8Mh00ol0003oiQWVonHIiP09onHIiP03o`000?of2OKomPWf00;omPWf
0_l00009oo@;m003o`000?om0_goo@;m00[oo@;m0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000oon0Oko0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/01ook1?/4o`0000?okQ7^0ol0
0007oo4>l@03o`000?oN8MkogR7N00[ogR7N00?o0000onHIi_oV6NH02OoV6NH00ol0003omPWfooH9
mP04ooH9mP;o00001ood2o@00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo/4nook1?/02?ok1?/0
1?l0003onPGjooX5n_oj1OX3o`0000;om`Sg00?o0000oo4>lOoa3_401_oa3_400ol0003ogR7NomhQ
gP08omhQgP03o`000?oV6NKoiQWV00[oiQWV00?o0000ooH9m_of2OH01_of2OH00ol0003om0_doo@;
m004oo@;m003o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oj1O[o
nPGj00ConPGj00Go0000ooL8moog2?Oom`Sgo`000008oo4>l@03o`000?oN8MkogR7N00OogR7N00?o
0000onHIi_oV6NH02_oV6NH00ol0003omPWfooH9mP07ooH9mP;o00001?od2o@00ol0003oo@;mood2
o@08ood2o@03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on`Ckoo/4n`08oo/4n`03o`000?oj1O[onPGj00ConPGj00?o0000ooL8moog2?L00_og2?L0
0ol0003ol@kaoo4>l@07oo4>l@03o`000?oN8MkogR7N00KogR7N00?o0000onHIi_oV6NH02_oV6NH0
0ol0003omPWfooH9mP09ooH9mP05o`000?od2oCom0_doo@;m?l000002Oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_on`Ck00?o0000ooX5n_oj1OX01?oj1OX00ol0003om`SgooL8m`03
ooL8m`03o`000?oa3_7ol@ka00Ool@ka00?o0000omhQg_oN8Mh01OoN8Mh00ol0003oiQWVonHIiP0:
onHIiP03o`000?of2OKomPWf00WomPWf1?l00009ood2o@03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ok1?/00ol0003onPGjooX5nP05ooX5nP03o`000?og2?Oom`Sg00?om`Sg00?o0000
oo4>lOoa3_402?oa3_400ol0003ogR7NomhQgP04omhQgP03o`000?oV6NKoiQWV00WoiQWV00?o0000
ooH9m_of2OH02?of2OH2o`0000?oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?oj1O[onPGj
00GonPGj00?o0000ooL8moog2?L01?og2?L00ol0003ol@kaoo4>l@09oo4>l@03o`000?oN8MkogR7N
00;ogR7N00?o0000onHIi_oV6NH02_oV6NH00ol0003omPWfooH9mP06ooH9mP;o00001_om0_d8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooX5n_oj
1OX01Ooj1OX00ol0003om`SgooL8m`05ooL8m`03o`000?oa3_7ol@ka00Wol@ka00Go0000omhQg_oN
8MkogR7No`00000<onHIiP03o`000?of2OKomPWf00ComPWf0_l00008ood2o@03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003onPGjooX5nP06ooX5nP03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo4>lOoa
3_402_oa3_400ol0003ogR7No`000004o`0000WoiQWV00?o0000ooH9m_of2OH00_of2OH2o`0000[o
o@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ok1?_on`Ck00;on`Ck00?o0000ooX5n_oj1OX01_oj1OX00ol0003om`SgooL8m`07ooL8m`;o0000
2ooa3_400ol0003on0OhooP7n003ooP7n0Oo00000_oV6NH00ol0003omPWfooH9mP02o`0000_oo@;m
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003on`Ckoo/4nook1?_o000000SonPGj00?o0000ooL8moog2?L01oog2?L00ol0003on`Ck
o`000002o`0000Sol@ka00?o0000ooP7n?oh1oP02_oh1oP5o`0000goo@;m00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ok1?_o000000WonPGj00?o
0000ooL8moog2?L01_og2?L00ol0003on`Ckoo/4n`03oo/4n`?o00001?oa3_400ol0003on0OhooP7
n00=ooP7n003o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003om`SgooL8m`07
ooL8m`03o`000?ok1?_on`Ck00Kon`Ck0ol000000ooa3_7o0000ooP7n00>ooP7n003o`000?om0_go
o@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?oj1O[onPGj00;onPGj1_l00008ooL8m`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooP7
n?oh1oP03ooh1oP00ol0003oo@;mood2o@0:ood2o@;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?ok1?_on`Ck00[o
n`Ck00?o0000ooP7n?oh1oP03ooh1oP00ol0003oo@;mood2o@07ood2o@?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ooL8moog
2?L00oog2?L00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oh1oSon0Oh00oon0Oh00?o0000ood2oOom
0_d01Oom0_d2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oom0_d00ol0003om`SgooL8m`02ooL8m`03o`000?ok1?_on`Ck00_on`Ck5?l00004ood2o@;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ood2o@04o`000?og2?Oom`Sgo`0000kon`Ck
00?o0000ood2oOom0_d04?om0_d00ol0003oo@;mo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_om0_d00ol0003om`Sgo`00000>oo/4n`03o`00
0?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0=ood2o@03o`000?ok1?_on`Ck00Won`Ck1Ol0
000Bood2o@;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo@;mood2o@0<ood2o@03o`000?ok1?_on`Ck00;on`Ck1ol00004ooh1oP03o`000?om0_go
o@;m00ooo@;m00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?om0_goo@;m00coo@;m1?l0000<ooh1oP03o`000?om0_goo@;m00coo@;m0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d03?om0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00_o
o@;m00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo@;mood2o@0:ood2o@03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom
0_d02Oom0_d2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003ooP7n
ooh1oP0?ooh1oP03o`000?om0_goo@;m00Koo@;m0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aooh1oP?o00001_om0_d00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003ooP7nooh1oP0>ooh1oP05o`000?oo0?ooo`3oool0ool000000oom0_d2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?oo
o`3o00?oo`3o00?o0000ood2oOl000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1
oP07ooh1oP;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
oP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?on0OkooP7no`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`09o`00o`Coool02Ol00?l00oooo`3o003oo`00o`08o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000So003o0_ooo`03o`00o`;oool01ol0
0?l00oooo`3o003oo`00o`07o`00o`;oool00ol00?l00oooo`3o003oo`00o`06o`00o`;oool0Iol0
0?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool01?l00?l2oooo00?o003o00?oool0
o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Oo003o0_ooo`05o`00o`03oooo0?l00?oo
003o00Go003o00?oool0o`00ool00?l01_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00Oo003o0_ooo`05o`00o`;oool01ol00?l00oooo`3o003oo`00o`05o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo0006o`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l01Ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool02?l00?l00oooo`3o003oo`00o`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`06o`00o`;oool01Ol00?l3oooo00So003o00?oool0o`00ool00?l0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool01_l00?l3oooo00?o003o0oooo`09o`00o`03oooo
0?l00?oo003o00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_oo
o`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l0
0?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`001_l00?l2oooo0003o`00oooo
o`3oool000?oool02ol00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00Ko003o0_oo
o`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3
oooo00?o003o0oooo`04o`00o`Coool000?o003ooooo0?l00?l00_ooo`07o`00o`03oooo0?l00?oo
003o00oo003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1
ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`07o`00
o`;oool04?l00?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00
o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00So
003o00?oool0o`00ool00?l03ol00?l01?ooo`3o003oo`00ool00?l2oooo00Ko003o00?oool0o`00
ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01_l00?l2oooo01So
003o0_ooo`08o`00o`;oool01ol00?l00oooo`3o003oo`00o`06o`00o`03oooo0?l00?oo003o00;o
003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l01_l00?l2oooo00Oo003o
00?oool0o`00ool00?l01Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Ko003o
00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o1Oooo`08o`00o`;oool01Ol00?l:oooo00Co003o0_ooo`02o`00o`;oool01Ol0
0?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0U
o`00o`?oool00_l00?l:oooo00Go003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo
003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(680) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.997 .003 .997 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.996 .004 .996 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.989 .011 .989 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.983 .017 .983 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.983 .017 .983 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.957 .043 .957 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.967 .033 .967 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.994 .006 .994 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.924 .076 .924 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.978 .022 .978 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.992 .008 .992 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.852 .148 .852 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.98 .02 .98 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.956 .044 .956 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.954 .046 .954 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.962 .038 .962 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.97 .03 .97 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.985 .015 .985 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.938 .062 .938 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.971 .029 .971 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.9 .1 .9 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.982 .018 .982 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.967 .033 .967 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.945 .055 .945 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.967 .033 .967 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.865 .135 .865 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.977 .023 .977 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.945 .055 .945 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.982 .018 .982 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.901 .099 .901 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.674 .326 .674 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.738 .262 .738 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.994 .006 .994 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.974 .026 .974 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.997 .003 .997 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.917 .083 .917 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.925 .075 .925 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.691 .309 .691 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.654 .346 .654 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.612 .388 .612 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.906 .094 .906 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.924 .076 .924 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.906 .094 .906 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.856 .144 .856 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.76 .24 .76 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.982 .018 .982 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.959 .041 .959 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.703 .297 .703 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.637 .363 .637 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.855 .145 .855 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.373 .627 .373 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.368 .632 .368 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.417 .583 .417 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.757 .243 .757 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.759 .241 .759 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.981 .019 .981 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.372 .628 .372 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.341 .659 .341 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.934 .066 .934 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.989 .011 .989 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.548 .452 .548 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.661 .339 .661 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.896 .104 .896 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.886 .114 .886 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.583 .417 .583 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.858 .142 .858 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.302 .698 .302 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.777 .223 .777 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.655 .345 .655 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.092 .908 .092 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.271 .729 .271 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.969 .031 .969 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.162 .838 .162 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.133 .867 .133 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.847 .153 .847 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.972 .028 .972 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.4 .6 .4 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.107 .893 .107 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.173 .827 .173 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.739 .261 .739 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.258 .742 .258 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.46 .54 .46 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.985 .015 .985 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.132 .868 .132 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.091 .909 .091 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.281 .719 .281 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.458 .542 .458 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.945 .055 .945 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.485 .515 .485 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.552 .448 .552 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.005 .995 .005 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.013 .987 .013 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.064 .936 .064 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.09 .91 .09 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.708 .292 .708 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.875 .125 .875 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.915 .085 .915 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.363 .637 .363 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.774 .226 .774 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.131 .869 .131 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.344 .656 .344 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.044 .956 .044 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.218 .782 .218 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.809 .191 .809 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.322 .678 .322 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.071 .929 .071 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.972 .028 .972 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.992 .008 .992 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.857 .143 .857 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.903 .097 .903 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.182 .818 .182 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.962 .038 .962 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.561 .439 .561 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.549 .451 .549 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.043 .957 .043 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.185 .815 .185 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.445 .555 .445 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.704 .296 .704 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.051 .949 .051 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.98 .02 .98 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.046 .954 .046 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.165 .835 .165 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.184 .816 .184 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.964 .036 .964 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.425 .575 .425 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.32 .68 .32 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.224 .776 .224 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.207 .793 .207 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.885 .115 .885 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.862 .138 .862 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.849 .151 .849 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.126 .874 .126 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.47 .53 .47 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.628 .372 .628 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.829 .171 .829 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.958 .042 .958 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.987 .013 .987 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.424 .576 .424 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.696 .304 .696 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.301 .699 .301 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.942 .058 .942 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.925 .075 .925 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.829 .171 .829 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.965 .035 .965 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.99 .01 .99 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.414 .586 .414 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.54 .46 .54 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.984 .016 .984 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.413 .587 .413 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.88 .12 .88 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.638 .362 .638 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.781 .219 .781 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.555 .445 .555 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.971 .029 .971 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.957 .043 .957 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.963 .037 .963 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.977 .023 .977 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.715 .285 .715 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.992 .008 .992 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.941 .059 .941 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.629 .371 .629 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.679 .321 .679 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.824 .176 .824 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.823 .177 .823 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.991 .009 .991 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.943 .057 .943 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.988 .012 .988 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.742 .258 .742 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.978 .022 .978 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.931 .069 .931 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.906 .094 .906 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.997 .003 .997 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.887 .113 .887 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.825 .175 .825 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.855 .145 .855 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.779 .221 .779 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.893 .107 .893 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.943 .057 .943 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.97 .03 .97 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.953 .047 .953 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.962 .038 .962 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.977 .023 .977 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.945 .055 .945 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.851 .149 .851 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.937 .063 .937 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.961 .039 .961 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.979 .021 .979 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.979 .021 .979 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.957 .043 .957 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.99 .01 .99 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.993 .007 .993 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.983 .017 .983 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.963 .037 .963 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.99 .01 .99 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.976 .024 .976 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.982 .018 .982 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.986 .014 .986 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(690) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.989 .011 .989 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.984 .016 .984 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.983 .017 .983 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.958 .042 .958 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.968 .032 .968 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.926 .074 .926 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.979 .021 .979 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.992 .008 .992 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.856 .144 .856 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.98 .02 .98 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.957 .043 .957 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.955 .045 .955 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.963 .037 .963 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.971 .029 .971 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.985 .015 .985 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.94 .06 .94 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.972 .028 .972 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.902 .098 .902 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.982 .018 .982 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.968 .032 .968 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.947 .053 .947 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.968 .032 .968 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.868 .132 .868 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.978 .022 .978 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.947 .053 .947 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.983 .017 .983 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.903 .097 .903 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.68 .32 .68 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.743 .257 .743 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.974 .026 .974 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.919 .081 .919 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.926 .074 .926 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.697 .303 .697 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.659 .341 .659 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.616 .384 .616 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.908 .092 .908 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.926 .074 .926 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.908 .092 .908 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.859 .141 .859 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.762 .238 .762 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.982 .018 .982 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.96 .04 .96 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.708 .292 .708 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.641 .359 .641 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.857 .143 .857 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.378 .622 .378 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.373 .627 .373 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.424 .576 .424 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.76 .24 .76 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.764 .236 .764 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.982 .018 .982 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.379 .621 .379 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.347 .653 .347 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.936 .064 .936 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.552 .448 .552 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.667 .333 .667 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.899 .101 .899 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.889 .111 .889 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.588 .412 .588 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.86 .14 .86 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.307 .693 .307 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.782 .218 .782 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.661 .339 .661 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.095 .905 .095 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.275 .725 .275 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.97 .03 .97 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.168 .832 .168 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.137 .863 .137 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.851 .149 .851 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.973 .027 .973 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.407 .593 .407 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.11 .89 .11 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.177 .823 .177 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.745 .255 .745 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.263 .737 .263 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.467 .533 .467 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.985 .015 .985 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.138 .862 .138 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.094 .906 .094 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.996 .004 .996 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.286 .714 .286 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.465 .535 .465 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.947 .053 .947 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.492 .508 .492 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.559 .441 .559 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.007 .993 .007 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.013 .987 .013 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.067 .933 .067 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.094 .906 .094 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.714 .286 .714 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.878 .122 .878 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.917 .083 .917 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.37 .63 .37 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.779 .221 .779 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.137 .863 .137 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.35 .65 .35 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.049 .951 .049 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.222 .778 .222 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.813 .187 .813 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.328 .672 .328 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.074 .926 .074 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.973 .027 .973 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.992 .008 .992 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.86 .14 .86 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.906 .094 .906 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.188 .812 .188 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.963 .037 .963 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.567 .433 .567 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.553 .447 .553 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.048 .952 .048 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.189 .811 .189 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.45 .55 .45 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.71 .29 .71 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.056 .944 .056 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.981 .019 .981 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.046 .954 .046 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.168 .832 .168 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.191 .809 .191 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.965 .035 .965 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.431 .569 .431 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.327 .673 .327 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.229 .771 .229 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.21 .79 .21 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.888 .112 .888 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.864 .136 .864 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.852 .148 .852 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.132 .868 .132 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.475 .525 .475 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.633 .367 .633 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.833 .167 .833 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.959 .041 .959 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.988 .012 .988 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.43 .57 .43 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.7 .3 .7 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.307 .693 .307 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.944 .056 .944 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.926 .074 .926 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.832 .168 .832 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.966 .034 .966 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.99 .01 .99 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.421 .579 .421 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.546 .454 .546 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.984 .016 .984 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.422 .578 .422 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.882 .118 .882 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.642 .358 .642 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.785 .215 .785 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.561 .439 .561 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.971 .029 .971 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.958 .042 .958 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.963 .037 .963 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.977 .023 .977 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.72 .28 .72 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.992 .008 .992 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.943 .057 .943 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.636 .364 .636 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.685 .315 .685 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.827 .173 .827 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.827 .173 .827 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.991 .009 .991 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.944 .056 .944 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.988 .012 .988 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.748 .252 .748 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.933 .067 .933 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.908 .092 .908 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.889 .111 .889 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.829 .171 .829 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.857 .143 .857 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.784 .216 .784 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.896 .104 .896 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.944 .056 .944 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.971 .029 .971 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.955 .045 .955 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.963 .037 .963 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.978 .022 .978 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.947 .053 .947 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.855 .145 .855 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.939 .061 .939 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.962 .038 .962 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.979 .021 .979 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.98 .02 .98 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.958 .042 .958 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.991 .009 .991 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.993 .007 .993 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.983 .017 .983 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.964 .036 .964 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.99 .01 .99 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.976 .024 .976 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.983 .017 .983 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.987 .013 .987 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(700) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.989 .011 .989 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.984 .016 .984 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.984 .016 .984 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.997 .003 .997 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.96 .04 .96 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.968 .032 .968 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.928 .072 .928 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.979 .021 .979 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.859 .141 .859 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.98 .02 .98 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.958 .042 .958 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.956 .044 .956 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.964 .036 .964 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.972 .028 .972 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.986 .014 .986 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.941 .059 .941 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.972 .028 .972 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.904 .096 .904 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.983 .017 .983 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.969 .031 .969 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.949 .051 .949 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.968 .032 .968 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.871 .129 .871 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.978 .022 .978 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.948 .052 .948 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.983 .017 .983 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.905 .095 .905 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.685 .315 .685 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.747 .253 .747 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.975 .025 .975 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.92 .08 .92 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.928 .072 .928 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.702 .298 .702 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.664 .336 .664 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.621 .379 .621 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.909 .091 .909 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.928 .072 .928 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.911 .089 .911 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.862 .138 .862 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.764 .236 .764 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.983 .017 .983 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.961 .039 .961 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.714 .286 .714 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.645 .355 .645 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.858 .142 .858 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.383 .617 .383 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.377 .623 .377 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.43 .57 .43 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.763 .237 .763 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.768 .232 .768 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.982 .018 .982 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.385 .615 .385 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.352 .648 .352 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.937 .063 .937 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.557 .443 .557 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.672 .328 .672 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.901 .099 .901 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.891 .109 .891 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.593 .407 .593 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.862 .138 .862 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.311 .689 .311 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.787 .213 .787 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.667 .333 .667 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.992 .008 .992 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.098 .902 .098 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.279 .721 .279 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.971 .029 .971 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.174 .826 .174 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.141 .859 .141 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.854 .146 .854 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.973 .027 .973 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.413 .587 .413 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.114 .886 .114 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.181 .819 .181 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.75 .25 .75 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.268 .732 .268 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.473 .527 .473 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.986 .014 .986 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.143 .857 .143 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
0 1 0 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.097 .903 .097 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.292 .708 .292 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.471 .529 .471 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.948 .052 .948 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.498 .502 .498 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.566 .434 .566 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.01 .99 .01 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.014 .986 .014 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.069 .931 .069 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.098 .902 .098 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.72 .28 .72 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.881 .119 .881 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.919 .081 .919 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.377 .623 .377 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.784 .216 .784 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.143 .857 .143 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.357 .643 .357 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.053 .947 .053 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.225 .775 .225 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.817 .183 .817 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.334 .666 .334 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.077 .923 .077 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.974 .026 .974 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.992 .008 .992 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.864 .136 .864 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.909 .091 .909 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.194 .806 .194 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.964 .036 .964 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.573 .427 .573 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.557 .443 .557 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.053 .947 .053 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.194 .806 .194 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.456 .544 .456 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.715 .285 .715 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.061 .939 .061 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.981 .019 .981 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.047 .953 .047 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.171 .829 .171 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.198 .802 .198 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.966 .034 .966 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.436 .564 .436 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.334 .666 .334 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.234 .766 .234 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.212 .788 .212 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.891 .109 .891 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.866 .134 .866 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.856 .144 .856 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.137 .863 .137 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.48 .52 .48 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.637 .363 .637 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.836 .164 .836 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.96 .04 .96 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.988 .012 .988 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.436 .564 .436 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.704 .296 .704 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.313 .687 .313 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.945 .055 .945 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.928 .072 .928 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.835 .165 .835 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.967 .033 .967 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.99 .01 .99 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.428 .572 .428 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.553 .447 .553 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.985 .015 .985 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.431 .569 .431 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.885 .115 .885 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.646 .354 .646 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.789 .211 .789 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.567 .433 .567 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.972 .028 .972 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.959 .041 .959 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.964 .036 .964 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.978 .022 .978 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.726 .274 .726 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.992 .008 .992 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.945 .055 .945 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.643 .357 .643 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.69 .31 .69 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.83 .17 .83 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.831 .169 .831 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.991 .009 .991 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.946 .054 .946 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.989 .011 .989 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.753 .247 .753 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.979 .021 .979 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.935 .065 .935 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.911 .089 .911 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.892 .108 .892 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.833 .167 .833 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.859 .141 .859 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.788 .212 .788 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.9 .1 .9 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.996 .004 .996 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.945 .055 .945 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.972 .028 .972 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.956 .044 .956 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.964 .036 .964 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.978 .022 .978 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.949 .051 .949 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.858 .142 .858 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.941 .059 .941 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.963 .037 .963 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.98 .02 .98 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.976 .024 .976 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.98 .02 .98 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.959 .041 .959 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.991 .009 .991 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.993 .007 .993 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.984 .016 .984 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.965 .035 .965 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.991 .009 .991 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.977 .023 .977 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.983 .017 .983 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.987 .013 .987 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(710) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.99 .01 .99 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.985 .015 .985 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.984 .016 .984 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.961 .039 .961 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.969 .031 .969 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.929 .071 .929 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.98 .02 .98 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.994 .006 .994 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.862 .138 .862 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.98 .02 .98 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.959 .041 .959 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.957 .043 .957 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.965 .035 .965 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.973 .027 .973 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.986 .014 .986 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.942 .058 .942 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.973 .027 .973 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.906 .094 .906 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.983 .017 .983 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.969 .031 .969 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.95 .05 .95 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.969 .031 .969 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.873 .127 .873 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.979 .021 .979 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.949 .051 .949 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.984 .016 .984 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.907 .093 .907 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.69 .31 .69 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.751 .249 .751 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.976 .024 .976 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.922 .078 .922 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.929 .071 .929 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.707 .293 .707 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.669 .331 .669 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.626 .374 .626 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.911 .089 .911 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.93 .07 .93 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.913 .087 .913 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.865 .135 .865 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.766 .234 .766 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.983 .017 .983 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.962 .038 .962 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.719 .281 .719 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.648 .352 .648 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.86 .14 .86 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.388 .612 .388 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.382 .618 .382 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.437 .563 .437 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.766 .234 .766 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.771 .229 .771 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.983 .017 .983 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.392 .608 .392 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.358 .642 .358 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.939 .061 .939 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.99 .01 .99 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.561 .439 .561 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.678 .322 .678 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.903 .097 .903 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.894 .106 .894 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.598 .402 .598 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.864 .136 .864 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.315 .685 .315 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.792 .208 .792 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.673 .327 .673 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.102 .898 .102 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.282 .718 .282 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.972 .028 .972 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.179 .821 .179 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.145 .855 .145 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.858 .142 .858 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.974 .026 .974 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.42 .58 .42 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.117 .883 .117 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.185 .815 .185 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.755 .245 .755 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.272 .728 .272 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.479 .521 .479 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.986 .014 .986 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.149 .851 .149 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.004 .996 .004 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.1 .9 .1 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.297 .703 .297 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.478 .522 .478 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.95 .05 .95 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.505 .495 .505 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.573 .427 .573 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.012 .988 .012 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.015 .985 .015 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.072 .928 .072 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.101 .899 .101 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.725 .275 .725 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.884 .116 .884 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.921 .079 .921 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.384 .616 .384 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.09 .91 .09 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.788 .212 .788 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.148 .852 .148 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.363 .637 .363 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.058 .942 .058 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.229 .771 .229 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.82 .18 .82 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.34 .66 .34 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.08 .92 .08 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.975 .025 .975 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.992 .008 .992 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.867 .133 .867 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.911 .089 .911 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.2 .8 .2 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.965 .035 .965 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.579 .421 .579 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.561 .439 .561 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.058 .942 .058 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.198 .802 .198 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.461 .539 .461 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.721 .279 .721 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.065 .935 .065 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.982 .018 .982 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.048 .952 .048 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.174 .826 .174 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.205 .795 .205 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.967 .033 .967 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.442 .558 .442 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.991 .009 .991 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.342 .658 .342 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.238 .762 .238 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.215 .785 .215 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.894 .106 .894 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.869 .131 .869 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.859 .141 .859 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.142 .858 .142 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.484 .516 .484 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.641 .359 .641 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.839 .161 .839 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.961 .039 .961 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.997 .003 .997 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.989 .011 .989 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.441 .559 .441 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.707 .293 .707 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.319 .681 .319 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.947 .053 .947 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.93 .07 .93 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.838 .162 .838 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.968 .032 .968 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.991 .009 .991 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.435 .565 .435 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.559 .441 .559 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.985 .015 .985 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.44 .56 .44 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.887 .113 .887 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.65 .35 .65 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.793 .207 .793 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.573 .427 .573 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.973 .027 .973 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.959 .041 .959 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.964 .036 .964 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.978 .022 .978 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.731 .269 .731 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.993 .007 .993 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.947 .053 .947 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.65 .35 .65 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.696 .304 .696 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.833 .167 .833 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.834 .166 .834 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.991 .009 .991 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.947 .053 .947 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.989 .011 .989 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.759 .241 .759 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.98 .02 .98 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.937 .063 .937 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.913 .087 .913 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.895 .105 .895 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.837 .163 .837 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.861 .139 .861 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.792 .208 .792 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.903 .097 .903 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.946 .054 .946 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.973 .027 .973 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.957 .043 .957 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.964 .036 .964 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.979 .021 .979 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.95 .05 .95 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.861 .139 .861 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.942 .058 .942 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.964 .036 .964 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.981 .019 .981 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.977 .023 .977 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.981 .019 .981 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.994 .006 .994 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.961 .039 .961 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.991 .009 .991 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.993 .007 .993 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.984 .016 .984 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.967 .033 .967 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.991 .009 .991 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.978 .022 .978 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.984 .016 .984 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.988 .012 .988 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.996 .004 .996 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(720) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.993 .007 .993 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.99 .01 .99 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.985 .015 .985 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.985 .015 .985 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.962 .038 .962 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.97 .03 .97 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.931 .069 .931 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.98 .02 .98 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.865 .135 .865 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.98 .02 .98 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.96 .04 .96 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.958 .042 .958 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.965 .035 .965 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.973 .027 .973 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.986 .014 .986 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.943 .057 .943 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.974 .026 .974 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.908 .092 .908 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.984 .016 .984 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.97 .03 .97 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.951 .049 .951 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.97 .03 .97 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.876 .124 .876 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.979 .021 .979 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.95 .05 .95 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.984 .016 .984 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.909 .091 .909 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.695 .305 .695 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.755 .245 .755 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.994 .006 .994 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.976 .024 .976 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.923 .077 .923 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.93 .07 .93 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.712 .288 .712 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.674 .326 .674 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.63 .37 .63 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.912 .088 .912 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.932 .068 .932 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.915 .085 .915 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.868 .132 .868 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.768 .232 .768 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.984 .016 .984 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.964 .036 .964 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.724 .276 .724 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.652 .348 .652 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.861 .139 .861 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.392 .608 .392 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.386 .614 .386 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.443 .557 .443 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.769 .231 .769 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.775 .225 .775 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.983 .017 .983 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.398 .602 .398 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.363 .637 .363 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.941 .059 .941 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.565 .435 .565 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.683 .317 .683 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.904 .096 .904 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.896 .104 .896 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.602 .398 .602 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.866 .134 .866 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.319 .681 .319 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.797 .203 .797 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.678 .322 .678 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.105 .895 .105 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.286 .714 .286 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.973 .027 .973 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.184 .816 .184 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.149 .851 .149 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.861 .139 .861 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.975 .025 .975 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.426 .574 .426 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.121 .879 .121 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.188 .812 .188 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.76 .24 .76 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.277 .723 .277 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.484 .516 .484 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.987 .013 .987 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.154 .846 .154 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.007 .993 .007 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.104 .896 .104 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
0 1 0 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.302 .698 .302 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.484 .516 .484 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.951 .049 .951 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.511 .489 .511 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.58 .42 .58 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.015 .985 .015 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.016 .984 .016 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.075 .925 .075 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.105 .895 .105 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.731 .269 .731 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.887 .113 .887 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.923 .077 .923 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.391 .609 .391 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.091 .909 .091 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.792 .208 .792 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.991 .009 .991 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.154 .846 .154 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.369 .631 .369 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.063 .937 .063 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.233 .767 .233 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.824 .176 .824 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.345 .655 .345 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.083 .917 .083 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.975 .025 .975 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.993 .007 .993 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.87 .13 .87 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.913 .087 .913 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.206 .794 .206 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.965 .035 .965 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.585 .415 .585 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.565 .435 .565 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.063 .937 .063 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.202 .798 .202 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.467 .533 .467 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.726 .274 .726 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.07 .93 .07 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.982 .018 .982 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.048 .952 .048 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.178 .822 .178 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.212 .788 .212 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.968 .032 .968 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.447 .553 .447 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.349 .651 .349 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.243 .757 .243 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.218 .782 .218 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.896 .104 .896 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.871 .129 .871 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.862 .138 .862 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.147 .853 .147 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.489 .511 .489 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.645 .355 .645 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.842 .158 .842 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.962 .038 .962 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.989 .011 .989 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.447 .553 .447 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.711 .289 .711 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.325 .675 .325 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.948 .052 .948 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.932 .068 .932 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.84 .16 .84 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.969 .031 .969 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.991 .009 .991 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.442 .558 .442 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.565 .435 .565 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.985 .015 .985 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.448 .552 .448 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.889 .111 .889 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.654 .346 .654 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.796 .204 .796 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.579 .421 .579 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.973 .027 .973 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.96 .04 .96 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.965 .035 .965 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.979 .021 .979 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.736 .264 .736 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.993 .007 .993 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.948 .052 .948 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.656 .344 .656 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.701 .299 .701 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.836 .164 .836 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.838 .162 .838 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.992 .008 .992 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.948 .052 .948 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.989 .011 .989 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.764 .236 .764 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.981 .019 .981 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.939 .061 .939 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.915 .085 .915 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.897 .103 .897 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.84 .16 .84 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.864 .136 .864 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.796 .204 .796 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.906 .094 .906 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.948 .052 .948 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.974 .026 .974 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.958 .042 .958 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.965 .035 .965 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.98 .02 .98 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.952 .048 .952 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.864 .136 .864 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.944 .056 .944 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.965 .035 .965 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.981 .019 .981 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.977 .023 .977 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.981 .019 .981 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.962 .038 .962 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.991 .009 .991 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.993 .007 .993 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.985 .015 .985 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.968 .032 .968 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.991 .009 .991 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.978 .022 .978 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.984 .016 .984 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.996 .004 .996 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.988 .012 .988 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(730) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.993 .007 .993 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.99 .01 .99 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.986 .014 .986 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.993 .007 .993 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.985 .015 .985 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.963 .037 .963 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.971 .029 .971 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.933 .067 .933 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.981 .019 .981 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.992 .008 .992 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.868 .132 .868 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.961 .039 .961 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.959 .041 .959 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.966 .034 .966 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.974 .026 .974 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.987 .013 .987 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.945 .055 .945 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.974 .026 .974 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.909 .091 .909 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.984 .016 .984 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.971 .029 .971 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.953 .047 .953 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.97 .03 .97 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.879 .121 .879 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.98 .02 .98 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.95 .05 .95 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.985 .015 .985 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.91 .09 .91 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.7 .3 .7 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.759 .241 .759 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.977 .023 .977 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.924 .076 .924 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.931 .069 .931 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.717 .283 .717 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.678 .322 .678 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.634 .366 .634 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.913 .087 .913 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.933 .067 .933 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.917 .083 .917 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.87 .13 .87 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.769 .231 .769 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.984 .016 .984 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.965 .035 .965 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.729 .271 .729 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.655 .345 .655 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.863 .137 .863 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.396 .604 .396 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.39 .61 .39 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.45 .55 .45 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.771 .229 .771 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.779 .221 .779 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.984 .016 .984 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.404 .596 .404 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.368 .632 .368 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.942 .058 .942 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.568 .432 .568 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.687 .313 .687 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.906 .094 .906 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.899 .101 .899 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.607 .393 .607 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.868 .132 .868 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.323 .677 .323 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.802 .198 .802 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.684 .316 .684 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.109 .891 .109 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.289 .711 .289 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.974 .026 .974 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.19 .81 .19 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.153 .847 .153 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.864 .136 .864 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.976 .024 .976 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.433 .567 .433 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.124 .876 .124 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.192 .808 .192 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.765 .235 .765 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.281 .719 .281 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.49 .51 .49 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.987 .013 .987 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.16 .84 .16 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.01 .99 .01 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.106 .894 .106 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.001 .999 .001 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.307 .693 .307 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.49 .51 .49 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.953 .047 .953 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.518 .482 .518 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.587 .413 .587 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.018 .982 .018 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.016 .984 .016 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.078 .922 .078 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.108 .892 .108 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.736 .264 .736 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.89 .11 .89 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.925 .075 .925 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.398 .602 .398 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.091 .909 .091 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.796 .204 .796 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.16 .84 .16 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.375 .625 .375 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.067 .933 .067 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.236 .764 .236 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.827 .173 .827 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.351 .649 .351 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.086 .914 .086 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.976 .024 .976 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.993 .007 .993 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.873 .127 .873 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.916 .084 .916 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.211 .789 .211 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.966 .034 .966 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.59 .41 .59 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.569 .431 .569 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.068 .932 .068 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.206 .794 .206 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.472 .528 .472 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.731 .269 .731 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.074 .926 .074 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.983 .017 .983 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.049 .951 .049 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.181 .819 .181 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.219 .781 .219 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.968 .032 .968 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.451 .549 .451 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.356 .644 .356 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.248 .752 .248 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.221 .779 .221 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.899 .101 .899 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.873 .127 .873 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.865 .135 .865 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.152 .848 .152 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.493 .507 .493 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.649 .351 .649 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.844 .156 .844 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.963 .037 .963 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.989 .011 .989 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.452 .548 .452 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.714 .286 .714 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.331 .669 .331 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.949 .051 .949 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.933 .067 .933 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.842 .158 .842 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.97 .03 .97 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.991 .009 .991 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.448 .552 .448 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.57 .43 .57 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.986 .014 .986 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.457 .543 .457 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.891 .109 .891 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.658 .342 .658 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.8 .2 .8 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.584 .416 .584 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.974 .026 .974 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.96 .04 .96 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.965 .035 .965 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.979 .021 .979 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.741 .259 .741 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.993 .007 .993 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.95 .05 .95 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.663 .337 .663 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.706 .294 .706 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.839 .161 .839 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.841 .159 .841 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.992 .008 .992 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.949 .051 .949 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.99 .01 .99 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.769 .231 .769 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.981 .019 .981 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.941 .059 .941 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.917 .083 .917 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.9 .1 .9 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.844 .156 .844 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.866 .134 .866 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.8 .2 .8 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.909 .091 .909 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.949 .051 .949 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.975 .025 .975 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.959 .041 .959 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.966 .034 .966 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.98 .02 .98 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.953 .047 .953 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.867 .133 .867 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.946 .054 .946 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.966 .034 .966 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.982 .018 .982 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.978 .022 .978 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.982 .018 .982 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.963 .037 .963 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.985 .015 .985 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.969 .031 .969 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.991 .009 .991 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.979 .021 .979 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.984 .016 .984 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.988 .012 .988 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.996 .004 .996 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(740) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.99 .01 .99 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.986 .014 .986 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.985 .015 .985 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.964 .036 .964 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.972 .028 .972 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.934 .066 .934 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.981 .019 .981 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.87 .13 .87 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.962 .038 .962 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.959 .041 .959 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.967 .033 .967 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.975 .025 .975 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.987 .013 .987 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.946 .054 .946 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.975 .025 .975 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.911 .089 .911 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.984 .016 .984 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.972 .028 .972 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.954 .046 .954 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.971 .029 .971 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.881 .119 .881 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.98 .02 .98 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.951 .049 .951 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.985 .015 .985 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.912 .088 .912 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.705 .295 .705 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.762 .238 .762 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.977 .023 .977 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.925 .075 .925 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.931 .069 .931 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.721 .279 .721 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.683 .317 .683 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.638 .362 .638 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.915 .085 .915 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.935 .065 .935 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.919 .081 .919 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.873 .127 .873 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.77 .23 .77 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.984 .016 .984 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.966 .034 .966 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.734 .266 .734 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.658 .342 .658 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.864 .136 .864 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.4 .6 .4 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.394 .606 .394 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.456 .544 .456 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.774 .226 .774 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.782 .218 .782 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.984 .016 .984 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.41 .59 .41 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.373 .627 .373 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.944 .056 .944 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.572 .428 .572 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.692 .308 .692 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.908 .092 .908 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.901 .099 .901 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.611 .389 .611 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.87 .13 .87 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.327 .673 .327 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.806 .194 .806 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.689 .311 .689 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.112 .888 .112 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.292 .708 .292 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.974 .026 .974 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.195 .805 .195 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.156 .844 .156 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.867 .133 .867 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.976 .024 .976 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.439 .561 .439 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.127 .873 .127 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.195 .805 .195 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.769 .231 .769 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.285 .715 .285 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.495 .505 .495 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.987 .013 .987 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.165 .835 .165 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.013 .987 .013 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.109 .891 .109 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.003 .997 .003 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.311 .689 .311 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.495 .505 .495 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.954 .046 .954 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.524 .476 .524 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.593 .407 .593 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.02 .98 .02 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.017 .983 .017 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.08 .92 .08 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.111 .889 .111 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.741 .259 .741 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.892 .108 .892 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.926 .074 .926 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.405 .595 .405 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.092 .908 .092 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.8 .2 .8 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.165 .835 .165 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.38 .62 .38 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.071 .929 .071 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.24 .76 .24 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.83 .17 .83 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.356 .644 .356 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.089 .911 .089 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.977 .023 .977 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.993 .007 .993 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.876 .124 .876 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.918 .082 .918 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.217 .783 .217 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.967 .033 .967 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.596 .404 .596 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.573 .427 .573 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.073 .927 .073 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.211 .789 .211 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.477 .523 .477 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.736 .264 .736 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.079 .921 .079 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.983 .017 .983 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.05 .95 .05 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.184 .816 .184 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.225 .775 .225 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.969 .031 .969 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.456 .544 .456 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.363 .637 .363 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.253 .747 .253 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.224 .776 .224 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.901 .099 .901 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.875 .125 .875 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.868 .132 .868 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.156 .844 .156 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.497 .503 .497 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.653 .347 .653 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.847 .153 .847 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.964 .036 .964 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.99 .01 .99 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.457 .543 .457 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.717 .283 .717 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.336 .664 .336 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.951 .049 .951 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.934 .066 .934 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.845 .155 .845 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.971 .029 .971 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.992 .008 .992 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.454 .546 .454 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.576 .424 .576 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.986 .014 .986 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.465 .535 .465 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.893 .107 .893 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.661 .339 .661 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.803 .197 .803 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.59 .41 .59 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.974 .026 .974 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.961 .039 .961 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.966 .034 .966 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.98 .02 .98 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.745 .255 .745 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.993 .007 .993 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.951 .049 .951 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.669 .331 .669 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.711 .289 .711 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.842 .158 .842 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.844 .156 .844 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.992 .008 .992 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.95 .05 .95 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.99 .01 .99 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.774 .226 .774 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.982 .018 .982 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.942 .058 .942 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.919 .081 .919 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.902 .098 .902 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.847 .153 .847 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.868 .132 .868 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.994 .006 .994 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.804 .196 .804 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.911 .089 .911 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.95 .05 .95 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.975 .025 .975 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.96 .04 .96 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.967 .033 .967 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.981 .019 .981 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.955 .045 .955 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.87 .13 .87 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.947 .053 .947 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.967 .033 .967 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.982 .018 .982 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.978 .022 .978 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.982 .018 .982 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.964 .036 .964 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.996 .004 .996 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.986 .014 .986 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.97 .03 .97 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.992 .008 .992 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.979 .021 .979 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.985 .015 .985 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.989 .011 .989 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.997 .003 .997 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ooh1oP?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_on0Oh2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0<ooh1oP03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?on
0Oh4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh03_on
0Oh00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003ooP7nooh1oP0=ooh1oP05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo@;mood2oOl0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh0
3_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?on0Oh03oon0Oh00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ood2oOom0_d00_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh03_on0Oh00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?on0OkooP7n00kooP7n00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00oooP7n00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh03oon0Oh00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?on0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ooh1o_on0Oh04?on0Oh<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013ooP7n00?o0000ool0oooo0?l02?oo
0?l9o`0000coo@;m00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?on0OkooP7n00oooP7n
00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?on
0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`05oo/4n`03o`000?om
0_goo@;m00_oo@;m0ol00003oo`3o003o`000?oo0?ooo`3o00coo`3o0ol0000>ooh1oP;o00003Oon
0Oh2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP0;ooh1oP;o00002ooo0?l00ol0003on`Ckoo/4n`06
oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo`3oool0o`0:
ool0o`04o`000?ok1?_on`Ckoo/4n`;o00002_on0Oh2o`000003oo/4nol0003ooP7n00kooP7n00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOl000002ooo0?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?om0_go
o@;m00Woo@;m00?o0000oo`3o?ol0o`01_ol0o`00ol0003oo`3oool0o`08ool0o`03o`000?ok1?_o
n`Ck00Con`Ck0_l00005ooh1oP?o00001?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?on0OkooP7n00OooP7n0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo/4nook1?/01ook1?/00ol0003oo@;mood2o@09ood2
o@03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l01Ooo0?l2o`0000Won`Ck0_l000000oon
0Oko0000o`000007oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003ooP7nooh1oP06ooh1oP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003on`Ckoo/4n`08oo/4n`03o`000?om0_goo@;m00Ooo@;m00?o0000oo`3o?ol
0o`02Ool0o`00ol0003oo`3oool0o`03ool0o`03o`000?ok1?_on`Ck00_on`Ck00?o0000oo/4nook
1?/01ook1?/00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mo`000005ool0o`;o00002oon0Oh2o`0000KooP7n
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?ok1?_on`Ck00Son`Ck
00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00;oo`3o005o`000?oo0?ooo`3oool0ool0
00003_ok1?/00ol0003on`Ckoo/4n`08oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?om0_goo@;mood2oOl0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?oi1_Won@Kio`0000?ooP7n0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000oo/4nook1?/02Ook1?/00ol0003oo@;mood2o@05ood2
o@03o`000?ol0ocoo0?l00coo0?l00?o0000ool0ool000003ook1?/00ol0003on`Ckoo/4n`08oo/4
n`03o`000?on0OkooP7n00kooP7n00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo000000_o
oP7n0_l00004ooT6n@03o`000?on0Oko000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
n`Ckoo/4n`09oo/4n`03o`000?om0_goo@;m00Coo@;m00?o0000oo`3o?ol0o`03_ol0o`00ol0003o
n`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ood2oOom0_d0
1?om0_d00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?ok1?_on`Ck00[on`Ck00?o0000ood2oOom0_d0
0oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/0
2_ok1?/00ol0003ooP7nooh1oP0>ooh1oP03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2
o@05ood2o@03o`000?on0OkooP7n00OooP7n0_l00008ooT6n@03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003on`Ckoo/4n`0:oo/4n`04o`000?om0_goo@;mood2o@?o0000
3ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
3oon0Oh3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000ooh1o_on0Oh01?on0Oh2o`0000_on@Ki1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000oo/4nook1?/02ook1?/01?l0003oo@;mo`00
0?l00003oo<<l`;o00003?ol0o`2o`00013on`Ck00?o0000oo/4nook1?/02ook1?/00ol0003ooP7n
ooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo@;m
ood2o@07ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ooT6nOoi1_T02ooi1_T01?l0003okA;]
ondBkOo]4^d5o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003on`Ckoo/4n`0<oo/4n`03
o`000?oc3??ol`cc00Gol`cc0_l00008oo`3o0;o00000_oc3?<00ol0003on`Ckoo/4n`0=oo/4n`03
o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@09ood2o@03o`000?on0OkooP7n00;o0000
3Ooi1_T00ol0003okA;]ondBk@07ondBk@Ko00000_oo0?l4o`0000gon`Ck00?o0000oo<<looc3?<0
1ooc3?<2o`0000Goo0?l00?o0000oo<<looc3?<00ooc3?<00ol0003on`Ckoo/4n`0<oo/4n`03o`00
0?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Woo@;m00?o
0000ooh1o_l000003ooi1_T00ol0003okA;]ondBk@0<ondBk@?o00001?og2?L3o`0000Won`Ck00?o
0000oo<<looc3?<02_oc3?<2o`000003oo`3o?l0003o000000Ool`cc00?o0000oo/4nook1?/02ook
1?/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00KooP7n1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000
ooT6nOoi1_T03_oi1_T00ol0003okA;]ondBk@0=ondBk@03o`000?og2?Oom`Sg00Kom`Sg0ol00005
oo/4n`03o`000?oc3??ol`cc00gol`cc00?o0000oo<<looc3?<02?oc3?<00ol0003on`Ckoo/4n`09
oo/4n`03o`000?ok1?_on`Ck00gon`Ck00Co0000ooh1o_on0OkooP7n1Ol00003oo`3o003o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ood2oOom0_d02oom0_d2o`0000oon@Ki00?o0000ondBkOo]4^d03Oo]4^d00ol0003om`SgooL8m`0:
ooL8m`?o000000?on`Cko`000?oc3?<03ooc3?<00ol0003ol`ccoo<<l`09oo<<l`03o`000?ok1?_o
n`Ck00Son`Ck00?o0000oo/4nook1?/03_ok1?/3o`0000Soo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?om0_goo@;m00Soo@;m0ol000000oog
2?Oo0000ooT6n@0>ooT6n@03o`000?o]4^gokA;]00gokA;]00?o0000ooL8moog2?L03Oog2?L00ol0
003ol`ccoo<<l`0?oo<<l`03o`000?oc3??ol`cc00[ol`cc2ol0000;oo/4n`Go00003?ol0o`00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo0?lo`000?oo0?oo0000
00Soo@;m0ol00005ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ondBkOo]4^d03Oo]4^d00ol0
003om`SgooL8m`0=ooL8m`;o00004?oc3?<00ol0003ol`ccoo<<l`0:oo<<l`03o`000?oa3_7ol@ka
00Ool@ka00?o0000oo/4nook1?/00_ok1?/7o`0000Com0_d00?o0000oo`3o?ol0o`02_ol0o`00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo0?loo`3o?ol0o`2o`00
00Goo@;m0ol00009ooL8m`;o00002ooi1_T00ol0003okA;]ondBk@0=ondBk@03o`000?og2?Oom`Sg
00gom`Sg00Co0000omlOgooO7moo00003ooc3?<00ol0003ol`ccoo<<l`09oo<<l`03o`000?oa3_7o
l@ka00Wol@ka1?l0000;oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`01?ol0o`00ol0003oo@;mo`000002o`00
00com`Sg00Co0000onHIi_l0003o00002Ooi1_T00ol0003okA;]ondBk@0=ondBk@03o`000?og2?Oo
m`Sg00gom`Sg00Go0000omlOgooO7moogaoOo`00000=oo<<l`03o`000?oc3??ol`cc00[ol`cc00?o
0000oo4>lOoa3_402Ooa3_400ol0003om0_doo@;m00<oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oV6NKoiQWV00;oiQWV0_l00007ooT6n@03o`000?o]4^go
kA;]00cokA;]00?o0000ooL8moog2?L03Oog2?L00ol0003ogaoOomlOg`03omlOg`03o`000?oc3??o
l`cc00[ol`cc00?o0000oo<<looc3?<02_oc3?<00ol0003ol@kaoo4>l@09oo4>l@03o`000?od2oCo
m0_d00com0_d00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo0?loo`3o006oo`3o003o`000?og2?Oom`Sg00_om`Sg00?o0000onHI
i_oV6NH01OoV6NH00ol0003on@KiooT6n@03ooT6n@03o`000?o]4^gokA;]00gokA;]00?o0000ooL8
moog2?L03Oog2?L00ol0003ogaoOomlOg`04omlOg`03o`000?oc3??ol`cc00Wol`cc00?o0000oo<<
looc3?<02Ooc3?<00ol0003ol@kaoo4>l@0:oo4>l@03o`000?od2oCom0_d00com0_d00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o007oo`3o003o`000?og2?Oom`Sg00_om`Sg00?o0000onHIi_oV6NH01_oV6NH2o`0000?o
n@Ki00?o0000ondBkOo]4^d03Oo]4^d00ol0003om`SgooL8m`0<ooL8m`03o`000?oO7moogaoO00Ko
gaoO00?o0000oo<<looc3?<02?oc3?<00ol0003ol`ccoo<<l`09oo<<l`03o`000?oa3_7ol@ka00[o
l@ka00?o0000oo@;m?od2o@03?od2o@00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003om`SgooL8m`0:ooL8m`03o`00
0?oV6NKoiQWV00WoiQWV0_l000000ooi1_Wo0000ondBk@0<ondBk@?o00003_og2?L00ol0003ogaoO
omlOg`07omlOg`03o`000?oc3??ol`cc00Ool`cc00?o0000oo<<looc3?<02Ooc3?<00ol0003ol@ka
oo4>l@0;oo4>l@03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003om`SgooL8
m`09ooL8m`03o`000?oV6NKoiQWV00_oiQWV00?o0000ondBkOo]4^d02_o]4^d2o`0000?oe2_D00?o
0000ooL8moog2?L02_og2?L00ol0003ogaoOomlOg`09omlOg`03o`000?oc3??ol`cc00Kol`cc00?o
0000oo<<looc3?<02?oc3?<00ol0003ol@kaoo4>l@0<oo4>l@03o`000?od2oCom0_d00com0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooL8moog2?L02?og2?L0
0ol0003oiQWVonHIiP0<onHIiP03o`000?o]4^gokA;]00SokA;]0_l00006om@[e0;o00002_og2?L0
0ol0003ogaoOomlOg`0:omlOg`03o`000?oc3??ol`cc00Gol`cc00?o0000oo<<looc3?<02?oc3?<0
0ol0003ol@kaoo4>l@0<oo4>l@03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02ool0o`0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onHIi_oV6NH03_oV6NH00ol0003okA;]ondBk@04
ondBk@?o00002_oD:m@00ol0003om`SgooL8m`07ooL8m`03o`000?oO7moogaoO00_ogaoO00?o0000
oo<<looc3?<00ooc3?<00ol0003ol`ccoo<<l`09oo<<l`03o`000?oa3_7ol@ka00col@ka00?o0000
oo@;m?od2o@03?od2o@00ol0003oo0?loo`3o00;oo`3o0;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onHIi_oV6NH03ooV6NH01?l0
003okA;]ondBkOo]4^d2o`0000koe2_D0_l00006ooL8m`03o`000?oO7moogaoO00gogaoO00?o0000
oo<<looc3?<00_oc3?<00ol0003ol`ccoo<<l`08oo<<l`03o`000?oa3_7ol@ka00col@ka0ol0000=
oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo0?l00?o0000ooL8moog2?L01_og2?L00ol0003oiQWVonHIiP0@onHIiPCo00004_oD:m@00ol0
003om`SgooL8m`03ooL8m`03o`000?oO7moogaoO00kogaoO00Go0000oo<<looc3??ol`cco`000005
oo<<l`Oo00003?oa3_401Ol0003ojAKYonTFjOoY5^Wo000000com0_d00?o0000oo`3o?ol0o`02?ol
0o`3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo0?l00?o0000ooL8moog2?L01_og2?L00ol0003oiQWVonHIiP0=
onHIiP?o000000CocS7>o`000?l0003o00004ooD:m@2o`0000;om`Sg00?o0000omlOgooO7ml04?oO
7ml00ol0003ol`cco`000006o`0000OoebSG00?o0000oo4>lOoa3_402?oa3_400ol0003ojAKYonTF
j@03onTFj@;o00002?od2o@3o`0000Koo0?l1?l00002ooX5nP03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?od2o@3o`0000goo0?l00?o0000ooL8moog2?L01?og2?L00ol0003oiQWVonHI
iP0;onHIiP?o00000oo><Lh01Ol0003oa3_4o`000?nGJ9Oo000001Coe2_D00?o0000ooL8mol00000
4ooO7ml00ol0003oebSGomLXe`0=omLXe`03o`000?oa3_7ol@ka00Gol@ka0_l00008onTFj@03o`00
0?od2oCom0_d00Go00000oob3O800ol0003oo0?loo`3o003o`0000OonPGj00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Com0_d0ol0000:oo`3o003o`000?og2?Oom`Sg00?om`Sg
00?o0000onHIi_oV6NH02OoV6NH3o`0000GocS7>00Co0000ol@ka?o4>lCo00000_nGJ9L00ol0003o
e2_Dom@[e00Bom@[e003o`000?oO7moogaoO01;ogaoO00?o0000omLXeooG:=L03_oG:=L00ol0003o
l@kaoo4>l@03oo4>l@03o`000?oY5^WojAKY00WojAKY0_l00009oo8=lP;o00002_oj1OX00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007oo@;m0;o00001ool0o`5o`0000;o
m`Sg00?o0000onHIi_oV6NH01_oV6NH3o`0000SocS7>00Co0000ol@ka?o4>lCo00000onGJ9L00ol0
003oe2_Dom@[e00Aom@[e003o`000?oO7moogaoO017ogaoO00?o0000omLXeooG:=L04?oG:=L01Ol0
003ol@kaoo4>lOoa3_7o000000cojAKY00?o0000oo8=l_ob3O802?ob3O800ol0003onPGjooX5nP0:
ooX5nP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000oo@;m?od2o@01ood2o@3o`00
0004oo`3o?l0003o0000o`0000GojaC[0_l00006onHIiP?o00002_o><Lh01Ol0003oa3_4ol@ka?o4
>lCo000000CoUfRG00?o0000om@[e?oD:m@04?oD:m@00ol0003ogaoOomlOg`0AomlOg`03o`000?oG
:=OoebSG017oebSG00?o0000oo4>lOl000003OoY5^T00ol0003olPgboo8=lP08oo8=lP03o`000?oj
1O[onPGj00[onPGj00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
oo@;m?od2o@02_od2o@00ol0003ojaC[on/Dj`08on/Dj`03o`000?oV6NKoiQWV00?o00003Oo><Lh0
1Ol0003oa3_4ol@ka?o4>lCo000000GoUfRG00?o0000om@[e?oD:m@03ooD:m@00ol0003ogaoOomlO
g`0AomlOg`03o`000?oG:=OoebSG01;oebSG00?o0000onTFjOoY5^T03?oY5^T00ol0003olPgboo8=
lP08oo8=lP03o`000?oj1O[onPGj00_onPGj00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003om0_doo@;m00:oo@;m003o`000?o[5>_ojaC[00WojaC[0_l0000?olhacP03o`000?o4>lCo
a3_400;oa3_400?o0000oiMXUonGJ9L01?nGJ9L00ol0003oe2_Dom@[e00=om@[e0?o00004OoO7ml0
0ol0003oebSGomLXe`0ComLXe`03o`000?oY5^WojAKY00_ojAKY00?o0000oo8=l_ob3O802Oob3O80
0ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003om0_doo@;m00:oo@;m003o`000?o[5>_ojaC[00WojaC[00?o0000olhac_o><Lh03Oo><Lh0
0ol0003oa3_4ol@ka003ol@ka003o`000?nGJ9OoUfRG00GoUfRG00?o0000om@[e?oD:m@02_oD:m@2
o`0000?oTVfB00?o0000omlOgooO7ml03_oO7ml00ol0003oebSGomLXe`0ComLXe`03o`000?oY5^Wo
jAKY00_ojAKY00?o0000oo8=l_ob3O802Oob3O800ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_om0_d00?o0000on/D
joo[5>/02oo[5>/00ol0003ocS7>olhacP0<olhacP03o`000?o4>lCoa3_400?oa3_400?o0000oiMX
UonGJ9L01_nGJ9L00ol0003oe2_Dom@[e007om@[e0;o00001_nBKI82o`0000kogaoO00?o0000omLX
eooG:=L04ooG:=L00ol0003ojAKYonTFj@0;onTFj@03o`000?ob3O;olPgb00WolPgb00?o0000ooX5
n_oj1OX03?oj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_om0_d00?o0000on/Djoo[5>/02oo[5>/00ol0003ocS7>olhacP0;olha
cP03o`000?o4>lCoa3_400Coa3_400?o0000oiMXUonGJ9L01onGJ9L00ol0003oe2_Dom@[e005om@[
e003o`000?nBKI;oTVfB00SoTVfB00?o0000omlOgooO7ml02_oO7ml00ol0003oebSGomLXe`0DomLX
e`03o`000?oY5^WojAKY00_ojAKY00?o0000oo8=l_ob3O802Oob3O800ol0003onPGjooX5nP0<ooX5
nP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_om0_d00?o0000on/Djoo[5>/02oo[5>/00ol0003ocS7>olhacP0;olhacP03o`000?o4>lCoa3_4
00Coa3_400?o0000oiMXUonGJ9L02?nGJ9L00ol0003oe2_Dom@[e002om@[e0;o00003?nBKI82o`00
00[ogaoO00?o0000omLXeooG:=L05?oG:=L00ol0003ojAKYonTFj@0;onTFj@03o`000?ob3O;olPgb
00WolPgb00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000oo@;m?od2o@02?od2o@00ol0003ojaC[on/Dj`0<on/Dj`03
o`000?o><LkocS7>00WocS7>00?o0000ol@ka?o4>l@01Oo4>l@00ol0003oUfRGoiMXU`09oiMXU`04
o`000?oD:mCo0000o`00013oTVfB0_l00008omlOg`03o`000?oG:=OoebSG01CoebSG0ol0000;onTF
j@03o`000?ob3O;olPgb00WolPgb00?o0000ooX5n_oj1OX03Ooj1OX01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000oo@;
m?od2o@02?od2o@00ol0003ojaC[on/Dj`0;on/Dj`;o00002_o><Lh00ol0003oa3_4ol@ka006ol@k
a003o`000?nGJ9OoUfRG00[oUfRG00?o0000oi9]T_nBKI804_nBKI800ol0003ogaoOomlOg`04omlO
g`03o`000?oG:=OoebSG01GoebSG00?o0000oldbcOo=</d01Ol00005onTFj@03o`000?ob3O;olPgb
00[olPgb00?o0000ooX5n_oj1OX03_oj1OX3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000oo@;m?od2o@01ood2o@00ol0003ojaC[on/Dj`0;on/Dj`04
o`000?nkA;_o^dBko`0000WocS7>00?o0000ol@ka?o4>l@01_o4>l@00ol0003oUfRGoiMXU`0:oiMX
U`03o`000?nBKI;oTVfB01?oTVfB0_l00003omlOg`Co00005?oG:=L00ol0003ocC;=oldbc@06oldb
c@Co000000?ojAKYo`000?ob3O802oob3O800ol0003onPGjooX5nP0>ooX5nP03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo@;m?od
2o@01ood2o@00ol0003ojaC[on/Dj`09on/Dj`;o00001?nkA;/00ol0003ocS7>olhacP05olhacP03
o`000?o4>lCoa3_400Ooa3_400?o0000oiMXUonGJ9L02_nGJ9L00ol0003oTVfBoi9]TP0Eoi9]TP03
o`000?oO7moo000000CoZEJY0ol0000@omLXe`03o`000?o=</gocC;=00_ocC;=0_l0000<oo8=lP03
o`000?oj1O[onPGj00conPGj0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?od2oCom0_d00Oom0_d00?o0000on/Djoo[5>/02?o[5>/00ol0003o^dBk
ok]4^`05ok]4^`03o`000?o><LkocS7>00CocS7>00?o0000ol@ka?o4>l@01oo4>l@00ol0003oUfRG
oiMXU`0:oiMXU`03o`000?nBKI;oTVfB01KoTVfB00?o0000ojUFZOnYEZT01_nYEZT3o`0000coebSG
00?o0000oldbcOo=</d03Oo=</d00ol0003olPgboo8=lP09oo8=lPGo00002Ooj1OX2o`000003ood2
oOl0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000oo@;m?od2o@01_od
2o@00ol0003ojaC[on/Dj`07on/Dj`03o`000?nkA;_o^dBk00Oo^dBk00?o0000olhac_o><Lh00_o>
<Lh00ol0003oa3_4ol@ka008ol@ka003o`000?nGJ9OoUfRG00WoUfRG00?o0000oi9]T_nBKI805onB
KI800ol0003oZEJYojUFZ@09ojUFZ@?o00002OoG:=L00ol0003ocC;=oldbc@0>oldbc@Ko00001?ob
3O800ol0003on0OhooP7n003ooP7n0Go00000_oj1OX2o`0000Coo@;m00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?ol0ocoo0?loo`3o?l000002ook1?/00ol0003om0_doo@;m006oo@;m003o`000?o[
5>_ojaC[00GojaC[0_l0000;ok]4^`04o`000?o><LkocS7>o`0000_oa3_400?o0000oiMXUonGJ9L0
2OnGJ9L00ol0003oTVfBoi9]TP0Foi9]TP03o`000?nYEZWoZEJY00goZEJY0ol00005omLXe`03o`00
0?o=</gocC;=00oocC;=00?o0000omhQg_oN8Mh00ooN8Mh4o`0000_on0Oh0_l00006ood2o@03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o002oo`3o0ko00001_od2o@00ol0003ojaC[on/D
j`05on/Dj`03o`000?nkA;_o^dBk00co^dBk00?o0000olhac_l000002oo4>l@00ol0003oUfRGoiMX
U`07oiMXU`?o00006?nBKI800ol0003oZEJYojUFZ@0@ojUFZ@?o000000?oebSGo`000?o=</d04?o=
</d00ol0003ogR7NomhQgP07omhQgP03o`000?oh1oSon0Oh00[on0Oh00?o0000ood2oOom0_d01Oom
0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005oo`3o003o`000?of2OKomPWf00_omPWf0_l00004
oo@;m003o`000?o[5>_ojaC[00?ojaC[0_l0000@ok]4^`03o`000?o4>lCoa3_400[oa3_400?o0000
oiMXUonGJ9L00onGJ9L4o`0000;oIiQW00?o0000oi9]T_nBKI805OnBKI800ol0003oZEJYojUFZ@0D
ojUFZ@03o`000?o=</gocC;=013ocC;=00?o0000omhQg_oN8Mh01ooN8Mh00ol0003on0OhooP7n00:
ooP7n003o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Goo0?l00?o0000ooH9m_of2OH03Oof2OH6o`0000?ojaC[00?o0000ok]4^onkA;/04?nkA;/00ol0
003oa3_4ol@ka00:ol@ka003o`000?nGJ9Oo000000?o00001omWV6L00ol0003oTVfBoi9]TP0Doi9]
TP03o`000?nYEZWoZEJY01CoZEJY00?o0000oldbcOo=</d03oo=</d00ol0003ogR7NomhQgP08omhQ
gP03o`000?oh1oSon0Oh00[on0Oh00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003omPWfooH9mP0=ooH9mP03o`000?oQ7^7ohAkQ00?o
hAkQ00?o0000on/Djol000004onkA;/4o`0000Woa3_40_l0000<ofNHI`03o`000?nBKI;oTVfB01?o
TVfB00?o0000ojUFZOnYEZT05OnYEZT00ol0003ocC;=oldbc@0>oldbc@03o`000?oN8MkogR7N00So
gR7N00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooH9m_of2OH02oof2OH00ol0003ohAkQon4Nh@05on4Nh@03o`00
0?nkA;_o^dBk01;o^dBk00Co0000og2?L?m`Sg3oL8m`1Ol00003ol@ka003o`000?mWV6OoIiQW00go
IiQW0ol0000@oi9]TP;o00006?nYEZT00ol0003ocC;=oldbc@0=oldbc@03o`000?oN8MkogR7N00Wo
gR7N00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo0?l00?o0000ooH9m_of2OH02_of2OH00ol0003ohAkQon4Nh@06on4Nh@03o`00
0?nkA;_o^dBk017o^dBk00?o0000og2?L?m`Sg001om`Sg03o`00013oIiQW00?o0000ocO8=olgb3L0
1Ol00009oi9]TP;o000000?oG:=Lo`000?nYEZT05onYEZT00ol0003ocC;=oldbc@0=oldbc@03o`00
0?oN8MkogR7N00WogR7N00?o0000ooP7n?oh1oP02?oh1oP2o`0000[oo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02Ool0o`00ol0003omPWfooH9
mP0:ooH9mP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ok]4^onkA;/03onkA;/00ol0003oL8m`og2?
L00:og2?L003o`000?mWV6OoIiQW00goIiQW00?o0000ocO8=olgb3L01_lgb3L4o`0000CoTVfB00?o
0000oebSG?mLXe`00_mLXe`00ol0003oZEJYojUFZ@0FojUFZ@03o`000?o=</gocC;=00_ocC;=00?o
0000omhQg_oN8Mh02ooN8Mh00ol0003on0OhooP7n006ooP7n003o`000?ol0oco000000[oo@;m00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02?ol0o`=
o`0000[ohAkQ00?o0000ok]4^onkA;/03onkA;/00ol0003oL8m`og2?L00;og2?L003o`000?mWV6Oo
IiQW00coIiQW00?o0000ocO8=olgb3L02_lgb3L4o`0000GoG:=L00?o0000ojUFZOnYEZT05_nYEZT0
0ol0003ocC;=oldbc@0:oldbc@03o`000?oN8MkogR7N00cogR7N00?o0000ooP7n?oh1oP01?oh1oP2
o`0000?oo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?oe2_Gom@[e00Wom@[e00?o0000on4N
hOoQ7^402OoQ7^400ol0003o^dBkok]4^`0=ok]4^`03o`000?m`Sg3oL8m`00coL8m`00?o0000ofNH
IomWV6L03?mWV6L00ol0003o=lPgocO8=`0;ocO8=`03o`000?liaSWo000000KoG:=L00?o0000ojUF
ZOnYEZT05_nYEZT00ol0003ocC;=oldbc@09oldbc@03o`000?oN8MkogR7N00cogR7N00?o0000ooP7
n?oh1oP00ooh1oP00ol0003oo0?loo`3o003oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003o
m@[eooD:m@08ooD:m@03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ok]4^onkA;/02?nkA;/4o`0000oo
L8m`00?o0000ofNHIomWV6L02omWV6L00ol0003o=lPgocO8=`0;ocO8=`04o`000?liaSWo>LHio`00
00OoG:=L00?o0000ojUFZOnYEZT05OnYEZT00ol0003ocC;=oldbc@08oldbc@03o`000?oN8MkogR7N
00gogR7N00?o0000ooP7n?oh1oP00_oh1oP00ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m
00Ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo`3o?ol
0o`01Ool0o`00ol0003om@[eooD:m@08ooD:m@03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000ok]4^onk
A;/00onkA;/5o`0000?oM8]d00?o0000og2?L?m`Sg003_m`Sg000ol0003oIiQWofNHI`0:ofNHI`03
o`000?lgb3Oo=lPg00[o=lPg00Go0000ocW6>OliaSWo>LHio`000007oebSG003o`000?nYEZWoZEJY
01GoZEJY00?o0000oldbcOo=</d02?o=</d00ol0003ogR7NomhQgP0=omhQgP03o`000?oh1oSon0Oh
00;o00002?ol0o`00ol0003oo@;mood2o@08ood2o@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003ohAkQon4Nh@0<on4Nh@Go00002OmdRg@00ol0003o
L8m`og2?L00<og2?L0;o00003?mWV6L00ol0003o=lPgocO8=`0:ocO8=`05o`000?liaSWo>LHiocW6
>Ol000002?mLXe`00ol0003oZEJYojUFZ@0DojUFZ@?o00001oo=</d00ol0003ogR7NomhQgP0>omhQ
gP03o`000?oh1oSo000000_oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oo
m@[e00?o0000on4NhOoQ7^403?oQ7^401?l0003o^4NhokQ7^?l0000;ogB;M003o`000?m`Sg3oL8m`
00_oL8m`00Co0000ob[E:_lZeB[o00002_mWV6L00ol0003o=lPgocO8=`0:ocO8=`03o`000?liaSWo
>LHi00;o>LHi00?o0000oebSG?mLXe`01_mLXe`00ol0003oZEJYojUFZ@0AojUFZ@?o00000on[E:/0
0ol0003ocC;=oldbc@04oldbc@03o`000?oN8MkogR7N00gogR7N1?l0000;oo`3o003o`000?om0_go
o@;m00Goo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo`3
o?ol0ocoo0?l1?l00008ooD:m@03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000okQ7^?nhAkP00_nhAkP0
0ol0003oM8]dogB;M008ogB;M003o`000?m`Sg3oL8m`00[oL8m`00?o0000ob[E:_lZeBX00_lZeBX0
0ol0003oIiQWofNHI`03ofNHI`Go00002olgb3L00ol0003o>LHiocW6>@03ocW6>@03o`000?mLXeco
G:=L00OoG:=L00?o0000ojUFZOnYEZT03_nYEZT2o`0000OoZeB[00?o0000oldbcOo=</d00_o=</d0
0ol0003ogR7NomhQgP0=omhQgP03o`000?of2OKomPWf00;omPWf00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo@;mood2o@03ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?of2OH00ol0003om@[eooD:m@05ooD:m@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000okQ7
^?nhAkP00onhAkP00ol0003oM8]dogB;M009ogB;M003o`000?m`Sg3oL8m`00SoL8m`00?o0000ob[E
:_lZeBX01?lZeBX5o`0000Co:]DZ00?o0000ocO8=olgb3L02Olgb3L00ol0003o>LHiocW6>@03ocW6
>@03o`000?mLXecoG:=L00SoG:=L00?o0000ojUFZOnYEZT02_nYEZT3o`0000[oZeB[00Go0000oldb
cOo=</gocC;=o`00000>omhQgP03o`000?of2OKomPWf00ComPWf0_l00009oo`3o003o`000?om0_go
o@;m00;oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooH9
m_of2OH01Oof2OH00ol0003om@[eooD:m@03ooD:m@03o`000?oQ7^7ohAkQ00[ohAkQ00?o0000okQ7
^?nhAkP01?nhAkP00ol0003oM8]dogB;M009ogB;M003o`000?m`Sg3oL8m`00OoL8m`00?o0000ob[E
:_lZeBX01OlZeBX00ol0003o:]DZob[E:P07ob[E:P03o`000?lgb3Oo=lPg00Oo=lPg00?o0000ocW6
>OliaST01?liaST00ol0003oG:=LoebSG008oebSG003o`000?nYEZWoZEJY00SoZEJY0_l0000>oj]D
Z`Co00003?oN8Mh2o`0000WomPWf00?o0000oo`3o?ol0o`01ool0o`01?l0003oo@;mood2oOl0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003omPWfooH9mP07ooH9mP;o00000ooe2_D00ol0
003ohAkQon4Nh@09on4Nh@03o`000?nhAkSo^4Nh00Ko^4Nh00?o0000ogB;M?mdRg@02OmdRg@00ol0
003oL8m`og2?L005og2?L003o`000?lZeB[o:]DZ00Ko:]DZ00?o0000ob[E:_lZeBX02?lZeBX00ol0
003o=lPgocO8=`06ocO8=`03o`000?liaSWo>LHi00Co>LHi00?o0000oebSG?mLXe`02OmLXe`4o`00
00?oZEJY0ol0000@oj]DZ`05o`000?oN8MkogR7NomhQg_l000002_oN8Mh00ol0003omPWfooH9mP0:
ooH9mPKo00000ool0o`00ol0003oo@;mo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003omPWfooH9mP0:ooH9mP04o`000?oe2_Gom@[eo`0000[ohAkQ00?o0000okQ7^?nhAkP01onhAkP0
0ol0003oM8]dogB;M009ogB;M003o`000?m`Sg3oL8m`00CoL8m`00?o0000ob[E:_lZeBX01olZeBX0
0ol0003o:]DZob[E:P08ob[E:P;o00001_lgb3L00ol0003o>LHiocW6>@05ocW6>@03o`000?mLXeco
G:=L00WoG:=L00Co0000ogN8MomgR7OoMhQg0ol0000Boj]DZ`03o`000?oN8MkogR7N00?ogR7N0_l0
0006omhQgP;o00003Oof2OH00ol0003oo@;mood2o@03ood2o@Go00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003omPWfooH9mP0<ooH9mP;o00002_oQ7^400ol0003o^4NhokQ7^008okQ7^003o`000?mdRgCo
M8]d00[oM8]d00?o0000og2?L?m`Sg000_m`Sg000ol0003o:]DZob[E:P08ob[E:P03o`000?lZeB[o
:]DZ00Ko:]DZ0_l00002oa;]4P03o`000?lgb3Oo=lPg00;o=lPg00?o0000ocW6>OliaST01_liaST0
0ol0003oG:=LoebSG008oebSG003o`000?mgR7OoMhQg00CoMhQg00?o0000oj]DZon[E:/03on[E:/0
0ol0003ogR7NomhQgP06omhQgP;o00000ooN8Mh00ol0003omPWfooH9mP0=ooH9mP03o`000?om0_go
o@;m00Ooo@;m0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?of2OKomPWf
00komPWf00?o0000on4NhOoQ7^401ooQ7^400ol0003o^4NhokQ7^00:okQ7^003o`000?mdRgCoM8]d
00WoM8]d00Go0000og2?L?m`Sg3oL8m`o`00000;ob[E:P03o`000?lZeB[o:]DZ00Co:]DZ0_l00005
oa;]4P05o`000?lgb3Oo=lPgocO8=ol000002?liaST00ol0003oG:=LoebSG008oebSG003o`000?mg
R7OoMhQg00GoMhQg00?o0000oj]DZon[E:/03_n[E:/00ol0003ogR7NomhQgP08omhQgP03o`000?oN
8Mko000000oomPWf00?o0000ood2oOom0_d02?om0_d01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017omPWf00?o0000on4NhOoQ7^401_oQ7^400ol0003o^4Nh
okQ7^00;okQ7^003o`000?mdRgCoM8]d00WoM8]d00Co0000og2?L?m`Sg3o00003?lZeBX00ol0003o
:]DZob[E:P02ob[E:P;o00002?lBkA800ol0003o=lPgo`000009ocW6>@03o`000?mLXecoG:=L00So
G:=L00?o0000ogN8MomgR7L01OmgR7L00ol0003oZeB[oj]DZ`0=oj]DZ`03o`000?oN8MkogR7N00[o
gR7N00?o0000ooH9m_of2OH03_of2OH00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooH9mP03o`00
0?oQ7^7ohAkQ00CohAkQ00?o0000okQ7^?nhAkP03?nhAkP00ol0003oM8]dogB;M00:ogB;M0?o0000
3?lZeBX00ol0003o:]DZob[E:P02o`0000_o4^dB00?o0000ocW6>OliaST02?liaST00ol0003oG:=L
oebSG007oebSG003o`000?mgR7OoMhQg00OoMhQg00?o0000oj]DZon[E:/03?n[E:/00ol0003ogR7N
omhQgP0;omhQgP;o00003_of2OH00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d00oom0_d00ol0003omPWfooH9mP0?ooH9mP?o00000ooQ
7^400ol0003o^4NhokQ7^00>okQ7^003o`000?mdRgCoM8]d00SoM8]d00Co0000oc7><OlacS7o<Lha
0_l0000:ob[E:P?o00003OlBkA800ol0003o>LHiocW6>@08ocW6>@03o`000?mLXecoG:=L00OoG:=L
00?o0000ogN8MomgR7L01omgR7L00ol0003oZeB[oj]DZ`0;oj]DZ`03o`000?oN8MkogR7N00cogR7N
00?o0000oo/4nol000000_l0000:ooH9mP03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@04ood2o@03o`000?of2OKomPWf00comPWf0_l0
0003onl@k`03o`000?oQ7^7o0000017o^4Nh00?o0000ogB;M?mdRg@01omdRg@00ol0003o<Lhaoc7>
<@04oc7><@;o00002?lZeBX00ol0003o4^dBoa;]4P0>oa;]4P;o00002?liaST00ol0003oG:=LoebS
G006oebSG003o`000?mgR7OoMhQg00WoMhQg00?o0000oj]DZon[E:/02On[E:/00ol0003ogR7NomhQ
gP0=omhQgP03o`000?ok1?_on`Ck00;on`Ck0ol00007ooH9mP03o`000?om0_goo@;m00Ooo@;m00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?of2OKo
mPWf00WomPWf0_l00006onl@k`03o`000?nhAkSo^4Nh013o^4Nh00?o0000ogB;M?mdRg@01_mdRg@0
0ol0003o<Lhaoc7><@07oc7><@03o`000?lZeB[o:]DZ00Co:]DZ0ol0000>oa;]4P03o`000?lBkA;o
4^dB00?o00001OliaST00ol0003oG:=LoebSG006oebSG003o`000?mgR7OoMhQg00[oMhQg00?o0000
oj]DZon[E:/02?n[E:/00ol0003ogR7NomhQgP0=omhQgP03o`000?ok1?_on`Ck00Gon`Ck0ol00004
ooH9mP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo@;mood2o@06ood2o@03o`000?of2OKomPWf00GomPWf0ol00008onl@k`03o`000?nhAkSo^4Nh
017o^4Nh00Co0000ogB;M?mdRgCoM8]d1?l0000;oc7><@;o000000Co:]DZo`000?l0003o00000ol5
nPD2o`0000_o4^dB00?o0000oa;]4_lBkA801?lBkA82o`0000?o>LHi00?o0000oebSG?mLXe`01_mL
Xe`00ol0003oMhQgogN8M`0:ogN8M`03o`000?n[E:_oZeB[00OoZeB[00?o0000omhQg_oN8Mh03_oN
8Mh00ol0003on`Ckoo/4n`08oo/4n`Co00002_om0_d00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo@;mood2o@07ood2o@03o`000?of2OKomPWf00;omPWf0_l0000<onl@k`03o`000?nhAkSo
^4Nh013o^4Nh1?l00003ofRGJ003o`000?lacS7o<Lha00_o<Lha00?o0000o`Gj1Ol5nPD01_l5nPD0
0ol0003o4^dBoa;]4P07oa;]4P03o`000?lBkA;o4^dB00Oo4^dB3?l0000>ogN8M`03o`000?n[E:_o
ZeB[00KoZeB[00?o0000omhQg_oN8Mh03_oN8Mh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?om0_go
o@;m00Ooo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Woo@;m00Co0000ooH9
m_l0003o00003_o_4>l00ol0003o^4NhokQ7^00?okQ7^003o`000?mXUfSoJ9MX00KoJ9MX00?o0000
oc7><OlacS402_lacS400ol0003o1OX5o`Gj1@07o`Gj1@;o00001_lBkA800ol0003o4^dBoa;]4P08
oa;]4P03o`000?m0_d3o@;m000So@;m000?o0000ogN8MomgR7L03?mgR7L00ol0003oZeB[oj]DZ`05
oj]DZ`03o`000?oN8MkogR7N00oogR7N0_l0000=oo/4n`03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000onl@koo_4>l03_o_4>l00ol0
003o^4NhokQ7^00>okQ7^003o`000?mXUfSoJ9MX00OoJ9MX00?o0000oc7><OlacS402_lacS400ol0
003o1OX5o`Gj1@09o`Gj1@;o00000olBkA800ol0003o4^dBoa;]4P09oa;]4P03o`000?m0_d3o@;m0
00Wo@;m000?o0000ogN8MomgR7L02_mgR7L4o`0000CoZeB[00?o0000omhQg_oN8Mh04?oN8Mh01?l0
003onPGjo`000?l0000<oo/4n`03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?om0_goo@;m00[oo@;m00?o0000onl@koo_4>l03oo_4>l@o`0000[oJ9MX00?o0000oc7>
<OlacS402OlacS400ol0003o0o`3o`00000<o`Gj1@05o`000?lBkA;o0000o`3o0?l000002_lBkA80
0ol0003o@;m0od2o@009od2o@003o`000?mgR7OoMhQg00OoMhQg0ol00004oiMXU`?o000000?oZeB[
o`000?oN8Mh04OoN8Mh01?l0003onPGjooX5n_oj1OX2o`0000_on`Ck00?o0000ood2oOom0_d00oom
0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ood2oOom0_d02_om0_d00ol0003oka3_onl@k`0?
onl@k`03o`000?n^DJko[U6^00co[U6^00?o0000ofRGJ?mXUfP02OmXUfP00ol0003o<Lhaoc7><@07
oc7><@04o`000?l3o0?o0o`3o`0000go1OX500Go0000o`3o0?l0o`3o0?l0o`000009oa;]4P03o`00
0?m0_d3o@;m000[o@;m000?o0000ogN8MomgR7L00omgR7L3o`0000[oUfRG00?o0000omhQg_oN8Mh0
4?oN8Mh00ol0003onPGjooX5nP04ooX5nP;o00002_ok1?/00ol0003oo@;mood2o@04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo@;m00?o0000onl@koo_4>l03oo_4>l00ol0003o[U6^ojiA[P0<ojiA[P03o`000?mX
UfSoJ9MX00WoJ9MX00?o0000oc7><OlacS401_lacS400ol0003o0o`3o`?l0`02o`?l0`03o`000?l5
nPGo1OX500[o1OX500?o0000o`3o0?l0o`000_l0o`000ol0003o4^dBoa;]4P06oa;]4P03o`000?m0
_d3o@;m000[o@;m000?o0000ogN8MomgR7L00ol0000=oiMXU`03o`000?oN8MkogR7N013ogR7N00?o
0000ooX5n_oj1OX01_oj1OX2o`0000Won`Ck0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003oka3_onl@k`0=onl@k`?o00003on^DJh0
0ol0003oJ9MXofRGJ008ofRGJ003o`000?lacS7o<Lha00Go<Lha00?o0000o`?l0ol3o0<00ol3o0<0
0ol0003o1OX5o`Gj1@0:o`Gj1@03o`000?l0o`3o0?l000?o0?l000?o0000oa;]4_lBkA801OlBkA80
0ol0003o@;m0od2o@00;od2o@0;o00004OnGJ9L00ol0003ogR7NomhQgP0?omhQgP03o`000?oj1O[o
nPGj00SonPGj0_l00007oo/4n`03o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ood2oOom0_d02?om0_d00ol0003oka3_onl@k`09onl@k`Go00000_oN8Mh00ol0
003o[U6^ojiA[P0=ojiA[P03o`000?mXUfSoJ9MX00WoJ9MX00?o0000oc7><OlacS401?lacS400ol0
003o0o`3o`?l0`04o`?l0`03o`000?l5nPGo1OX500So1OX500?o0000o`3o0?l0o`001Ol0o`000ol0
003o4^dBoa;]4P04oa;]4P03o`000?m0_d3o@;m000_o@;m000?o0000oiMXUonGJ9L04?nGJ9L00ol0
003ogR7NomhQgP0?omhQgP03o`000?oj1O[onPGj00[onPGj0_l00004oo/4n`03o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?o_4>ooka3_00Coka3_1Ol00007omhQgP03
o`000?n^DJko[U6^00go[U6^00?o0000ofRGJ?mXUfP02OmXUfP00ol0003o<Lhaoc7><@03oc7><@03
o`000?l3o0?o0o`300Go0o`300?o0000o`Gj1Ol5nPD02?l5nPD00ol0003o0?l0o`3o0006o`3o0003
o`000?lBkA;o4^dB00?o4^dB00?o0000od2o@?m0_d002om0_d000ol0003oUfRGoiMXU`0@oiMXU`03
o`000?oN8MkogR7N00oogR7N00?o0000ooX5n_oj1OX03?oj1OX2o`000003oo/4nol0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000onl@kol00000
1?l0000<omhQgP03o`000?n^DJko[U6^00ko[U6^00?o0000ofRGJ?mXUfP02?mXUfP00ol0003o<Lha
oc7><@02oc7><@03o`000?l3o0?o0o`300Oo0o`300?o0000o`Gj1Ol5nPD01ol5nPD00ol0003o0?l0
o`3o0007o`3o0003o`000?lBkA;o4^dB00;o4^dB00?o0000od2o@?m0_d002om0_d000ol0003oUfRG
oiMXU`0AoiMXU`03o`000?oN8MkogR7N00gogR7N00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d01Oom0_d3o`00017ogR7N00?o0000ojiA[_n^DJh03_n^
DJh00ol0003oJ9MXofRGJ009ofRGJ004o`000?lacS7o<Lhao`0000[o0o`300?o0000o`Gj1Ol5nPD0
1ol5nPD00ol0003o0?l0o`3o0008o`3o0005o`000?lBkA;o4^dBoa;]4_l000003Om0_d000ol0003o
UfRGoiMXU`0AoiMXU`?o00003OoN8Mh00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_om0_d2o`0000;on0Oh00?o0000omhQg_oN8Mh03ooN8Mh00ol0003o
[U6^ojiA[P0>ojiA[P03o`000?mXUfSoJ9MX00SoJ9MX1Ol0000;o`?l0`03o`000?l5nPGo1OX500Ko
1OX500?o0000o`3o0?l0o`002Ol0o`001?l0003o4^dBoa;]4_l0000=od2o@003o`000?nGJ9OoUfRG
017oUfRG00?o0000olHia_o6>LH00ol0000:omhQgPCo00003Ooj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooP7n003o`000?oN8MkogR7N00kogR7N00?o0000ojiA
[_n^DJh03_n^DJh00ol0003oJ9MXofRGJ007ofRGJ003o`000?lLhaco7><L00?o7><L00?o0000o`?l
0ol3o0<02?l3o0<00ol0003o1OX5o`Gj1@05o`Gj1@03o`000?l0o`3o0?l000[o0?l01Ol0000<od2o
@003o`000?nGJ9OoUfRG013oUfRG00?o0000olHia_o6>LH01?o6>LH3o`0000KogR7N00?o0000ooL8
moog2?L00_og2?L5o`0000SonPGj00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooP7n?oh1oP01?oh1oP00ol0003ogR7NomhQgP0=omhQgP03o`000?n^DJko[U6^00oo
[U6^00?o0000ofRGJ?mXUfP01?mXUfP2o`0000Oo7><L00?o0000o`?l0ol3o0<01ol3o0<Eo`0000Go
5>/D00?o0000od2o@?m0_d002?m0_d03o`00013oUfRG00?o0000olHia_o6>LH02?o6>LH3o`0000;o
gR7N00?o0000ooL8moog2?L02?og2?L5o`0000?onPGj00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooP7n?oh1oP01Ooh1oP00ol0003ogR7NomhQgP0;omhQgPCo0000
3on^DJh00ol0003oJ9MXofRGJ003ofRGJ003o`000?lLhaco7><L00So7><L00?o0000o`?l0ol3o0<0
1?l3o0<2o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o5>/DoaC[5005oaC[50;o0000
1_m0_d02o`0000?oEZUF00?o0000oiMXUonGJ9L03?nGJ9L00ol0003oaSW6olHiaP0<olHiaP;o0000
4?og2?L3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o
0000omhQg_oN8Mh02OoN8Mh00ol0003ojAKYo`000002okA;]0?o00003?n^DJh01?l0003oJ9MXofRG
J?mXUfP2o`0000co7><L00?o0000o`?l0ol3o0<00_l3o0<00ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000oaC[5?lDja@01olDja@00ol0003o@;m0od2o@002od2o@003o`00
0?mFZEKoEZUF00CoEZUF0_l0000;oiMXU`03o`000?o6>LKoaSW600coaSW600?o0000onHIi_l00000
4_og2?L00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Oon0Oh00?o
0000omhQg_oN8Mh01_oN8Mh2o`0000;ojAKY00?o0000okA;]?ndBk@00ondBk@3o`0000[o[U6^00?o
0000ofRGJ?l000003olLha`01?l0003o0o`3o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000oaC[5?lDja@02?lDja@01?l0003o@;m0o`000?l00009oeJYEP03o`000?nGJ9OoUfRG00Oo
UfRG00?o0000olHia_o6>LH03?o6>LH01?l0003oiQWVonHIi_l0000CooL8m`03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on0OhooP7n008ooP7n003o`000?oN8MkogR7N00Co
gR7N00?o0000onTFjOoY5^T00ooY5^T00ol0003o]4^dokA;]005okA;]0?o00001_n^DJh4o`00013o
7><L00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lDjaCo5>/D00Wo
5>/D00?o0000oeJYE_mFZEH02_mFZEH2o`0000KoUfRG00?o0000olHia_o6>LH03?o6>LH00ol0003o
iQWVonHIiP02onHIiP03o`000?og2?Oom`Sg00oom`Sg00?o0000ood2oOl000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00Won0Oh00Co0000omhQg_oN8Mko
gR7N0_l00006onTFj@03o`000?ndBkCo]4^d00So]4^d0ol000000on^DJko0000o`000004oenPG`03
o`000?lLhaco7><L00go7><L00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?lDjaCo5>/D00Wo5>/D00?o0000oeJYE_mFZEH03?mFZEH00ol0003oUfRGoiMXU`03o`0000ko
aSW600?o0000onHIi_oV6NH00ooV6NH00ol0003om`SgooL8m`0>ooL8m`05o`000?om0_goo@;mood2
oOl000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00[o
n0Oh00?o0000omhQg_l000002?oY5^T00ol0003o]4^dokA;]00;okA;]003o`000?mOX5ooGj1O00Go
Gj1O00?o0000oacS7?lLha`03?lLha`00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000oaC[5?lDja@02?lDja@2o`0000ooEZUF0_l00002okI9]P03o`000?o6>LKoaSW600_o
aSW600?o0000onHIi_oV6NH01?oV6NH00ol0003om`SgooL8m`0=ooL8m`03o`000?om0_goo@;m00?o
o@;m00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oh1oSon0Oh00_on0Oh00?o0000onTFjOoY5^T0
1ooY5^T00ol0003o]4^dokA;]00;okA;]003o`000?mOX5ooGj1O00KoGj1O00?o0000oacS7?lLha`0
2olLha`2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o5>/DoaC[5007oaC[5004o`00
0?lWf2Oo9mPWo`0000koEZUF00?o0000okI9]_nfBKH00_nfBKH00ol0003oaSW6olHiaP09olHiaP03
o`000?oV6NKoiQWV00KoiQWV00?o0000ooL8moog2?L02oog2?L00ol0003oo@;mood2o@05ood2o@04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooP7n?oh1oP02_oh1oP2o`0000Wo
jAKY00?o0000okA;]?ndBk@02ondBk@00ol0003oGj1OoenPG`07oenPG`03o`000?lLhaco7><L00Wo
7><L00Co0000o`3o0?l0o`3o00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lDjaCo5>/D
00Ko5>/D00Go0000obOH9olWf2Oo9mPWo`00000>oeJYEP03o`000?nfBKKo]TVf00?o]TVf00?o0000
olHia_o6>LH01oo6>LH00ol0003oiQWVonHIiP07onHIiP03o`000?og2?Oom`Sg00[om`Sg00?o0000
ood2oOom0_d01oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00Co0000ooL8moog2?Oo00002OoY5^T00ol0003o]4^dokA;]009okA;]003o`000?mOX5oo
Gj1O00WoGj1O00?o0000oacS7?lLha`01olLha`00ol0003o0?l0o`3o0002o`3o0003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o5>/DoaC[5005oaC[5003o`000?lWf2Oo
9mPW00?o9mPW00?o0000oeJYE_mFZEH02_mFZEH00ol0003o]TVfokI9]P05okI9]P03o`000?o6>LKo
aSW600GoaSW600?o0000onHIi_oV6NH02?oV6NH00ol0003om`SgooL8m`09ooL8m`03o`000?om0_go
o@;m00Soo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won0Oh00?o0000ooL8
moog2?L00_og2?L00ol0003ojAKYonTFj@06onTFj@03o`000?ndBkCo]4^d00Wo]4^d00?o0000oenP
GomOX5l02_mOX5l00ol0003o7><LoacS7005oacS7003o`000?l0o`3o0?l000Co0?l000?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lDjaCo5>/D00Co5>/D00?o0000obOH
9olWf2L01?lWf2L00ol0003oEZUFoeJYEP0:oeJYEP03o`000?nfBKKo]TVf00Ko]TVf00?o0000olHi
a_o6>LH00oo6>LH00ol0003oiQWVonHIiP09onHIiP03o`000?og2?Oom`Sg00Som`Sg00?o0000ood2
oOom0_d02Oom0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003oo`3o0?o00001Ooh1oP00ol0003o
m`SgooL8m`03ooL8m`03o`000?oY5^WojAKY00KojAKY00?o0000okA;]?ndBk@02OndBk@00ol0003o
Gj1OoenPG`0;oenPG`03o`000?lLhaco7><L00?o7><L00?o0000o`3o0?l0o`001_l0o`000ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000oaC[5?lDja@00_lDja@2o`0000So
9mPW00?o0000oeJYE_mFZEH02OmFZEH00ol0003o]TVfokI9]P07okI9]P05o`000?o6>LKoaSW6olHi
a_l000003OoV6NH00ol0003om`SgooL8m`06ooL8m`03o`000?om0_goo@;m00[oo@;m00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l0ol000000ooh1oSo0000ooL8m`06ooL8m`03
o`000?oY5^WojAKY00GojAKY00?o0000okA;]?ndBk@02OndBk@00ol0003oGj1OoenPG`0<oenPG`05
o`000?lLhaco7><LoacS7?l000002_l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000oaC[5?l000000_l000000ol<l`co0000obOH9`07obOH9`03o`000?mFZEKoEZUF
00SoEZUF00?o0000okI9]_nfBKH02OnfBKH00ol0003oaSW6o`00000=onHIiPCo00001Oog2?L00ol0
003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o008oo`3o003
o`000?og2?Oom`Sg00Oom`Sg00?o0000onTFjOoY5^T01?oY5^T00ol0003o]4^dokA;]009okA;]003
o`000?mOX5ooGj1O00goGj1O00?o0000oacS7?l000003?l0o`0:o`0000Oo0?l00ol00005o`cc3003
o`000?lWf2Oo9mPW00Ko9mPW00?o0000oeJYE_mFZEH01omFZEH00ol0003o]TVfokI9]P0:okI9]P03
o`000?oV6NKoiQWV00_oiQWV00?o0000ooT6nOoi1_T00_oi1_T3o`000003ooL8mol0003oo@;m00_o
o@;m0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8m`07ooL8m`03o`00
0?oY5^WojAKY00GojAKY00?o0000okA;]?ndBk@01ondBk@00ol0003oGj1OoenPG`0?oenPG`;o0000
2ol0o`000ol0003o1?/4o`Ck1007o`Ck1003o`000?l0o`3o0?l000;o0?l00ol00008o`cc3003o`00
0?lWf2Oo9mPW00Ko9mPW00?o0000oeJYE_mFZEH01omFZEH00ol0003o]TVfokI9]P0:okI9]P03o`00
0?oV6NKoiQWV00[oiQWV00?o0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@08ood2o@?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8
m`08ooL8m`03o`000?oY5^WojAKY00CojAKY00?o0000okA;]?ndBk@01ondBk@00ol0003oGj1OoenP
G`0>oenPG`04o`000?lWf2Oo9mPWo`0000Wo0?l000?o0000o`Ck1?l4n`@02Ol4n`@01?l0003o0?l0
o`000?l0000<o`cc3003o`000?lWf2Oo9mPW00Ko9mPW00?o0000oeJYE_mFZEH01_mFZEH00ol0003o
]TVfokI9]P0;okI9]P03o`000?oV6NKoiQWV00OoiQWV0_l00009ooT6n@03o`000?om0_goo@;m00Co
o@;m1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo0?loo`3o009oo`3o003o`00
0?og2?Oom`Sg00Som`Sg00?o0000onTFjOoY5^T00ooY5^T>o`0000goGj1O00?o0000obOH9olWf2L0
0_lWf2L00ol0003o0?l0o`3o0005o`3o0003o`000?l4n`Co1?/400_o1?/400?o0000o`cc3?l<l``0
3?l<l``00ol0003o9mPWobOH9`06obOH9`03o`000?mFZEKoEZUF00GoEZUF00?o0000okI9]_nfBKH0
3?nfBKH00ol0003oiQWVonHIiP06onHIiP03o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooL8moog2?L02?og
2?L01Ol0003ojAKYonTFjOoY5^Wo000000_o`cc300?o0000ofJII_mVVFH00ol00009oenPG`03o`00
0?lWf2Oo9mPW00Co9mPW00?o0000o`3o0?l0o`000ol0o`000ol0003o1?/4o`Ck100<o`Ck1003o`00
0?l<l`co3?<<00go3?<<00?o0000obOH9olWf2L01_lWf2L00ol0003oEZUFoeJYEP03oeJYEP?o0000
3OnfBKH00ol0003oiQWVonHIiP05onHIiP03o`000?oi1_Won@Ki00con@Ki0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooL8moog2?L02?og
2?L4o`0000co`cc300?o0000ofJII_mVVFH00omVVFH3o`0000GoGj1O00?o0000obOH9olWf2L01_lW
f2L01Ol0003o0?l0o`3o0?l0o`3o000000oo1?/400?o0000o`cc3?l<l``03Ol<l``00ol0003o9mPW
obOH9`06obOH9`03o`000?mFZEKoEZUF00?o00000omdRg@00ol0003o]TVfokI9]P0;okI9]P03o`00
0?oV6NKoiQWV00?oiQWV00?o0000ooT6nOoi1_T03Ooi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`02_ol0o`3o`0000Kom`Sg0ol0
0003oo8=lP03o`000?o3?<?o`cc300[o`cc300?o0000ofJII_mVVFH01_mVVFH3o`000003oenPGol0
003o9mPW00Wo9mPW00?o0000o`3o0?l000004?l4n`@00ol0003o3?<<o`cc300=o`cc3003o`000?lW
f2Oo9mPW00Oo9mPW0_l00007ogB;M003o`000?nfBKKo]TVf00[o]TVf00Co0000onHIi_oV6NKoiQWV
0ol0000?ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02_ol
0o`01?l0003on`Ckoo/4nook1?/2o`000004ooL8mol0003o0000o`0000KolPgb00?o0000ol<l`oo3
?<<02_o3?<<00ol0003oIYUVofJIIP09ofJIIP03o`000?lWf2Oo9mPW00[o9mPW00?o0000o`Ck1?l4
n`@03ol4n`@00ol0003o3?<<o`cc300>o`cc3003o`000?lWf2Oo9mPW00Ko9mPW00?o0000ogB;M?md
Rg@01omdRg@4o`0000So]TVf00Co0000onHIi_oV6NKo00000ooc3?<2o`0000gon@Ki00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003o
n`Ckoo/4n`04oo/4n`03o`000?ob3O;olPgb00OolPgb00?o0000ol<l`oo3?<<02Oo3?<<00ol0003o
IYUVofJIIP0:ofJIIP03o`000?lWf2Oo9mPW00[o9mPW00?o0000o`Ck1?l4n`@03ol4n`@00ol0003o
3?<<o`cc300>o`cc3003o`000?lWf2Oo9mPW00Go9mPW00?o0000ogB;M?mdRg@02?mdRg@01?l0003o
_T6noki1__nn@Kh7o`0000;o]TVf0_l00006oo<<l`;o00003?oi1_T00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o008oo`3o003o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo8=l_ob3O802?ob3O800ol0003o`cc3ol<l``08ol<l``03o`000?mVVFKoIYUV00[o
IYUV00?o0000obOH9olWf2L02olWf2L00ol0003o1?/4o`Ck100>o`Ck1003o`000?l<l`co3?<<00ko
3?<<1Ol00002obOH9`03o`000?mdRgCoM8]d00WoM8]d00?o0000oki1__nn@Kh02?nn@Kh3o`0000Wo
l`cc0_l0000:ooT6n@03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000oo/4nook1?/01ook1?/00ol0003olPgboo8=lP07oo8=lP03o`00
0?o3?<?o`cc300So`cc300?o0000ofJII_mVVFH02_mVVFH00ol0003o9mPWobOH9`0:obOH9`;o0000
3_l4n`@3o`0000go3?<<0ol00005ocW6>@;o00002omdRg@00ol0003o_T6noki1_P0;oki1_P;o0000
2_oc3?<2o`0000Oon@Ki0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo/4n`03o`00
0?ob3O;olPgb00OolPgb00?o0000ol<l`oo3?<<02?o3?<<>o`0000Wo9mPW0ol000000olPgb3o0000
o`Ck100:o`Ck10?o00000_lGj1L00ol0003o3?<<o`cc3009o`cc30;o00002OliaST00ol0003oM8]d
ogB;M009ogB;M003o`000?nn@Kko_T6n00_o_T6n00?o0000omPWf?l000002ooc3?<2o`0000Con@Ki
00Co0000oo/4nook1?_on`Ck0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?ob3O;olPgb00KolPgb00?o0000ol<l`oo3?<<02?o3?<<00ol0003oI9]T
ofBKI00:ofBKI003o`000?lWf2Oo9mPW00Co9mPW0ol00005ob3O8003o`000?l4n`Co1?/400Co1?/4
1?l00006oaOX5`03o`000?l<l`co3?<<00Ko3?<<0_l0000;ocW6>@03o`000?mdRgCoM8]d00WoM8]d
00?o0000oki1__nn@Kh02_nn@Kh01Ol0003of2OHomPWf?oH9mSo000000col`cc0_l000000ooi1_Wo
0000oo/4n`05oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo8=l_ob3O801_ob3O800ol0003o`cc3ol<l``07ol<l``03o`00
0?mTVfCoI9]T00_oI9]T00?o0000obOH9olWf2L00_lWf2L2o`0000Wo8=lP00?o0000o`Ck1?l4n`@0
0ol0000;oaOX5`03o`000?l<l`co3?<<00;o3?<<0ol0000>ocW6>@03o`000?mdRgCoM8]d00OoM8]d
00?o0000oki1__nn@Kh02onn@Kh00ol0003of2OHomPWf002omPWf003o`000?oc3??ol`cc00_ol`cc
00?o0000oo/4nook1?/01_ok1?/2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok
1?_on`Ck00Oon`Ck00?o0000oo8=l_ob3O801oob3O800ol0003o`cc3ol<l``05ol<l``?o00003OmT
Vf@4o`0000_o8=lP0ol0000?oaOX5`04o`000?l<l`co0000o`00017o>LHi00?o0000ogB;M?mdRg@0
1omdRg@00ol0003o_T6noki1_P0:oki1_P03o`000?oH9mSof2OH00Cof2OH00?o0000oo<<looc3?<0
1ooc3?<3o`0000_on`Ck1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003olPgboo8=
lP06oo8=lP03o`000?o3?<?o`cc300;o`cc30ol00003oj=LX`03o`000?mTVfCoI9]T00[oI9]T00?o
0000ob3O8?lPgb002olPgb000ol0003o6n@Ko`00000AoaOX5`03o`000?liaSWo>LHi017o>LHi00?o
0000ogB;M?mdRg@01omdRg@00ol0003o_T6noki1_P0:oki1_P03o`000?oH9mSof2OH00Gof2OH00Co
0000oo<<looc3??ol`cc1Ol00002ooD:m@03o`000?ok1?_on`Ck00Won`Ck00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook1?/00ol0003olPgboo8=lP05oo8=lP?o0000
00?o`cc3o`000?l000001onSG:<00ol0003oI9]TofBKI008ofBKI0?o00002_lPgb02o`0000;o6n@K
00?o0000oaOX5olGj1L03olGj1L00ol0003o>LHiocW6>@0AocW6>@03o`000?mdRgCoM8]d00OoM8]d
00?o0000oki1__nn@Kh02Onn@Kh00ol0003of2OHomPWf007omPWf0?o00001ooe2_D00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook
1?/4o`0000;olPgb0_l00003onTFj@03o`000?nSG:?oXebS00SoXebS0_l00006ofBKI0;o00000omC
[5<00ol0003o8=lPob3O8006ob3O8003o`000?lKi1_o6n@K00?o6n@K00?o0000oaOX5olGj1L03_lG
j1L00ol0003o>LHiocW6>@0BocW6>@03o`000?mdRgCoM8]d00GoM8]d00?o0000oki1__nn@Kh02Onn
@Kh00ol0003of2OHomPWf008omPWf003o`000?oe2_Gom@[e00Oom@[e00?o0000oo/4nook1?/02?ok
1?/00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00Con`Ck0_l00004
ooT6n@;o00001OoY5^T00ol0003oXebSoj=LX`0:oj=LX`03o`000?mTVfCoI9]T00;oI9]T00?o0000
oe>/DomC[5<01?mC[5<00ol0003o8=lPob3O8004ob3O8003o`000?lKi1_o6n@K00Co6n@K00?o0000
oaOX5olGj1L03_lGj1L00ol0003o>LHiocW6>@0BocW6>@[o00002_nn@Kh00ol0003of2OHomPWf008
omPWf003o`000?oe2_Gom@[e00Oom@[e00?o0000oo/4nook1?/02?ok1?/00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003on`Ckoo/4nook1?/2o`0000Oon@Ki00?o0000onTFjOoY5^T01?oY5^T0
0ol0003oXebSoj=LX`0:oj=LX`04o`000?mTVfCo0000o`0000SoDjaC00Co0000ob3O8?lPgb3o8=lP
0_l00007oa_T6`03o`000?lGj1Oo5nPG00ko5nPG00?o0000ocW6>OliaST04_liaST00ol0003oTfbC
oi=/T`07oi=/T`03o`000?nn@Kko_T6n00Ko_T6n00?o0000omPWf?oH9mP02_oH9mP00ol0003om@[e
ooD:m@06ooD:m@03o`000?ok1?_on`Ck00Son`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ok
1?_o0000o`0000Won@Ki00?o0000onTFjOoY5^T01?oY5^T00ol0003oXebSoj=LX`0;oj=LX`03o`00
0?mC[5?oDjaC00WoDjaC00?o0000ob3O8?l000002OlKi1/00ol0003o5nPGoaOX5`0>oaOX5`;o0000
4_liaST00ol0003oTfbCoi=/T`09oi=/T`;o00001_nn@Kh00ol0003of2OHomPWf00:omPWf003o`00
0?oe2_Gom@[e00Kom@[e00?o0000oo/4nook1?/02?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooT6nOoi1_T02Ooi1_T00ol0003ojAKYonTFj@05onTFj@03o`000?nSG:?oXebS00[oXebS00?o
0000oe>/DomC[5<02_mC[5<2o`0000Wo6n@K00?o0000oaOX5olGj1L03_lGj1L00ol0003o;m0_o`00
0002o`0000oo>LHi00?o0000oi=/TonCK9<02onCK9<00ol0003o_T6noki1_P03o`0000gof2OH00?o
0000ooD:mOoe2_D01_oe2_D00ol0003on`Ckoo/4n`07oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on@KiooT6n@09ooT6n@03o`000?oY5^WojAKY00GojAKY00?o0000oj=LXonSG:<02OnSG:<2
o`0000_oDjaC0_l0000;oa_T6`03o`000?lGj1Oo5nPG00co5nPG00?o0000obo@;ol_d2l00ol_d2l3
o`0000co>LHi00?o0000oi=/TonCK9<03?nCK9<2o`0000;of2OH00?o0000omPWf?oH9mP03?oH9mP0
0ol0003om@[eooD:m@05ooD:m@03o`000?ok1?_on`Ck00Oon`Ck00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oi1_Won@Ki00[on@Ki00?o0000onTFjOoY5^T01_oY5^T00ol0003oXebSoj=LX`07oj=L
X`03o`000?nXEjSo000000[oDjaC00Co0000odZeB_m:]D[o00002_lKi1/00ol0003o5nPGoaOX5`0<
oaOX5`03o`000?l_d2oo;m0_00Ko;m0_0_l00008ocW6>@;o00003onCK9<00ol0003of2OHomPWf002
omPWf003o`000?oH9mSof2OH00_of2OH00?o0000ooD:mOoe2_D01Ooe2_D00ol0003on`Ckoo/4n`07
oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on@KiooT6n@0:ooT6n@03o`000?oY5^WojAKY
00KojAKY00?o0000oj=LXonSG:<01_nSG:<01Ol0003oZ5NXojQGZ?nXEjSo000000SoDjaC00?o0000
odZeB_m:]DX00_m:]DX00ol0003o6n@Koa_T6`06oa_T6`Co00003?lGj1L00ol0003o;m0_obo@;`08
obo@;`?o00000_liaST3o`000003ogB;M?l0003oTfbC00goTfbC00?o0000omPWf?oH9mP01?oH9mP0
0ol0003of2OHomPWf00:omPWf003o`000?oe2_Gom@[e00Gom@[e00?o0000oo/4nook1?/01_ok1?/0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi1_T02ooi1_T00ol0003ojAKYonTFj@07onTF
j@03o`000?nSG:?oXebS00?oXebS0_l00005ojQGZ003o`000?mC[5?oDjaC00CoDjaC00?o0000odZe
B_m:]DX00om:]DX00ol0003o6n@Koa_T6`05oa_T6`03o`000?lDjaCo5>/D00;o5>/D0ol00007oaOX
5`;o00003_l_d2l2o`0000GoM8]d00?o0000oi=/TonCK9<02_nCK9<00ol0003of2OHomPWf005omPW
f003o`000?oH9mSof2OH00_of2OH00?o0000ooD:mOoe2_D01?oe2_D00ol0003on`Ckoo/4n`06oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on@KiooT6n@0;ooT6n@03o`000?oY5^WojAKY00Oo
jAKY00?o0000oj=LXonSG:<00_nSG:<00ol0003oZ5NXojQGZ006ojQGZ003o`000?mC[5?oDjaC00;o
DjaC00?o0000odZeB_m:]DX01Om:]DX00ol0003o6n@Koa_T6`02oa_T6`;o00002?lDja@3o`0000;o
5nPG0_l000000olFjAKo0000obo@;`0=obo@;`03o`000?mdRgCoM8]d00GoM8]d00?o0000oi=/TonC
K9<02?nCK9<00ol0003of2OHomPWf007omPWf003o`000?oH9mSof2OH00[of2OH00?o0000ooD:mOoe
2_D01?oe2_D00ol0003on`Ckoo/4n`06oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on@Ki
ooT6n@0<ooT6n@03o`000?oY5^WojAKY00SojAKY00Co0000oj=LXonSG:?o00002OnXEjP01Ol0003o
DjaCoe>/DomC[5?o000000SoB[E:00Go0000oa_T6olKi1_o6n@Ko`00000=oaC[50;o00001?lFjAH0
0ol0003o;m0_obo@;`0;obo@;`03o`000?mdRgCoM8]d00KoM8]d00?o0000oi=/TonCK9<01onCK9<0
0ol0003of2OHomPWf008omPWf0Co00002?oH9mP00ol0003om@[eooD:m@04ooD:m@03o`000?ok1?_o
n`Ck00Kon`Ck00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oi1_Won@Ki00_on@Ki0ol00009onTF
j@03o`000?nSG:?o000000_oZ5NX00?o0000oe>/Dol000002_m:]DX00ol0003o6n@Ko`00000?oaC[
5003o`000?lFjAKo5^TF00;o5^TF00?o0000obo@;ol_d2l02ol_d2l00ol0003oM8]dogB;M006ogB;
M003o`000?nCK9?oTfbC00KoTfbC00?o0000omPWf?oH9mP02OoH9mP01?l0003ojaC[on/Djoo[5>/7
o`0000;of2OH00?o0000ooD:mOoe2_D00ooe2_D00ol0003on`Ckoo/4n`05oo/4n`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oi1_Won@Ki00Son@Ki0ol00003ooT6n@03o`000?oY5^WojAKY00OojAKY00?o0000ojQG
Z?nXEjP02onXEjP00ol0003oB[E:odZeBP0:odZeBP03o`000?lDjaCo5>/D00go5>/D00?o0000oaKY
5_lFjAH01?lFjAH00ol0003o;m0_obo@;`09obo@;`03o`000?mdRgCoM8]d00SoM8]d00?o0000oi=/
TonCK9<00onCK9<2o`0000cof2OH00?o0000on/Djoo[5>/02?o[5>/<o`0000?on`Ck0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooT6nOoi1_T01_oi1_T3o`0000Oon@Ki00?o0000onTFjOoY5^T01_oY5^T00ol0003o
Z5NXojQGZ00;ojQGZ003o`000?m:]D[oB[E:00WoB[E:0_l0000>oaC[5003o`000?lFjAKo5^TF00Go
5^TF00?o0000obo@;ol_d2l02Ol_d2l00ol0003oM8]dogB;M009ogB;M003o`000?nCK9?o000000;o
00000_o=</d00ol0003of2OHomPWf008omPWf003o`000?o[5>_ojaC[00cojaC[00?o0000ooL8moog
2?L01_og2?L3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on@KiooT6n@03ooT6n@?o00002ooi1_T00ol0003ojAKY
onTFj@04onTFj@03o`000?nXEjSoZ5NX00_oZ5NX0ol00007odZeBP?o000000?o<Lhao`000?lDja@0
3OlDja@00ol0003o5^TFoaKY5P06oaKY5P03o`000?l_d2oo;m0_00So;m0_00?o0000ogB;M?mdRg@0
2_mdRg@00ol0003ocC;=oldbc@04oldbc@03o`000?oH9mSof2OH00Oof2OH00?o0000on/Djoo[5>/0
2oo[5>/00ol0003om`SgooL8m`08ooL8m`03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooT6nOl0
003o0000o`0000oon@Ki00?o0000onTFjOoY5^T00ooY5^T>o`0000?oTVfB0_l00002odZeBP?o0000
1OlacS400ol0003o5>/DoaC[500:oaC[5003o`000?lFjAKo5^TF00Oo5^TF00?o0000obo@;ol_d2l0
2?l_d2l00ol0003oM8]dogB;M00:ogB;M003o`000?o=</gocC;=00GocC;=00?o0000omPWf?oH9mP0
1_oH9mP00ol0003ojaC[on/Dj`0;on/Dj`03o`000?og2?Oom`Sg00Som`Sg00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on@Ki00?o0000onTFjOoY5^T00_oY5^T00ol0003ogB;MomdR
g@0:omdRg@03o`000?nBKI;oTVfB00?oTVfB0_l00009oc7><@03o`000?lDjaCo5>/D00Wo5>/D00?o
0000oaKY5_lFjAH02?lFjAH2o`0000So;m0_00?o0000ogB;M?mdRg@02OmdRg@00ol0003ocC;=oldb
c@07oldbc@03o`000?oH9mSof2OH00Cof2OH00?o0000on/Djoo[5>/02oo[5>/00ol0003om`SgooL8
m`09ooL8m`03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@0?ooT6n@?o000000?ojAKY
o`000?oM8]d02ooM8]d00ol0003oTVfBoi9]TP04oi9]TP03o`000?lacS7o<Lha00Wo<Lha00?o0000
oaC[5?lDja@01olDja@00ol0003o5^TFoaKY5P09oaKY5P04o`000?lfbCKo0000o`0000Ko;m0_00?o
0000ogB;M?mdRg@02OmdRg@00ol0003ocC;=oldbc@08oldbc@03o`000?oH9mSof2OH00?of2OH00?o
0000on/Djoo[5>/02oo[5>/00ol0003om`SgooL8m`09ooL8m`03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on@KiooT6n@0<ooT6n@;o00000ooh1oP2o`0000cogB;M00?o0000oi9]T_nBKI801?nBKI80
0ol0003o<Lhaoc7><@0:oc7><@Wo00002olFjAH00ol0003o=/TfocK9=P02ocK9=P?o00000_l_d2l0
0ol0003oM8]dogB;M00:ogB;M003o`000?o=</gocC;=00WocC;=00?o0000omPWf?oH9mP00_oH9mP0
0ol0003ojaC[on/Dj`0:on/Dj`03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_oi1_T2o`0000Gon0Oh00?o0000onXEj_l000002_oM8]d00ol0003oTVfBoi9]TP06oi9]
TP03o`000?lacS7o<Lha00Wo<Lha00?o0000oacS7?lLha`01OlLha`00ol0003o5^TFoaKY5P09oaKY
5P03o`000?lfbCKo=/Tf00Go=/Tf0ol00009ogB;M0?o00003Oo=</d01Ol0003of2OHomPWf?oH9mSo
000000cojaC[00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6
nOoi1_T01Ooi1_T2o`0000Oon0Oh00Co0000onXEj_oZ5N[o00002OoM8]d00ol0003oTVfBoi9]TP06
oi9]TP03o`000?lacS7o<Lha00So<Lha00?o0000oacS7?lLha`01olLha`00ol0003o5^TFoaKY5P07
oaKY5P03o`000?lfbCKo=/Tf00So=/Tf0ol00002ogB;M0Go00000_ngB;L00ol0003ocC;=oldbc@0<
oldbc@03o`000?oH9mSo000000cojaC[00?o0000ooL8moog2?L02_og2?L00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000ooT6nOoi1_T00_oi1_T2o`0000Son0Oh00?o0000onXEj_oZ5NX00_oZ5NX5o`00
00CogB;M00?o0000oi9]T_nBKI801_nBKI800ol0003o<Lhaoc7><@08oc7><@03o`000?lLhaco7><L
00Oo7><L00?o0000oaKY5_lFjAH01olFjAH00ol0003o=/TfocK9=P08ocK9=P03o`000?moP7ooOh1o
00;o00002?ngB;L00ol0003ocC;=oldbc@0<oldbc@Co00002_o[5>/00ol0003om`SgooL8m`0:ooL8
m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on@Kio`000?l0000:ooP7n003o`000?oZ5N[ojQGZ
00;ojQGZ00?o0000olDjaOo5>/D00_o5>/D4o`0000WoTVfB00?o0000oc7><OlacS402?lacS400ol0
003o7><LoacS7008oacS7003o`000?lFjAKo5^TF00Go5^TF00?o0000ocK9=_lfbCH02?lfbCH01Ol0
003oOh1oogn0OomoP7oo000000[o]dRg0ol0000;oldbc@04o`000?oc3??ol`ccoo<<l`Co00001Oo[
5>/00ol0003om`SgooL8m`0;ooL8m`03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on0OhooP7n00:
ooP7n003o`000?oZ5N[ojQGZ00?ojQGZ00?o0000olDjaOo5>/D01?o5>/D00ol0003oTVfBoi9]TP07
oi9]TP03o`000?lacS7o<Lha00Ko<Lha0_l0000;oacS7003o`000?lFjAKo5^TF00Go5^TF00?o0000
ocK9=_lfbCH02?lfbCH00ol0003oOh1oogn0O`02ogn0O`03o`000?ngB;Oo]dRg00Oo]dRg00?o0000
on@Ki?oT6n@01?l00006oldbc@03o`000?oc3??ol`cc00Kol`cc0ol00002on/Dj`03o`000?og2?Oo
m`Sg00_om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000onXE
j_oZ5NX01?oZ5NX00ol0003oaC[5olDja@05olDja@03o`000?nBKI;oTVfB00OoTVfB00?o0000oc7>
<OlacS400_lacS43o`000003odRgB?l0003o7><L00[o7><L00?o0000oaKY5_lFjAH01OlFjAH00ol0
003o=/TfocK9=P07ocK9=P03o`000?moP7ooOh1o00?oOh1o00?o0000okM8]ongB;L01ongB;L00ol0
003oi1_Ton@Ki004on@Ki0?o00000_o=</d00ol0003ol`ccoo<<l`0:oo<<l`;o00003_og2?L00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ojQGZonXEjP04onXEjP03
o`000?o5>/GoaC[500KoaC[50_l00007oi9]TP03o`000?lacS7o000000;o00001Om8]dP00ol0003o
7><LoacS7008oacS70?o00001?lFjAH00ol0003o=/TfocK9=P08ocK9=P03o`000?moP7ooOh1o00Co
Oh1o00?o0000okM8]ongB;L01_ngB;L00ol0003oi1_Ton@Ki007on@Ki0;o00003_oc3?<00ol0003o
m`SgooL8m`0;ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on0OhooP7n008ooP7n003o`00
0?oZ5N[ojQGZ00GojQGZ00?o0000olDjaOo5>/D01?o5>/D00ol0003oaSW6olHiaP03o`0000CoTVfB
0_l00008odRgB003o`000?lLhaco7><L00Oo7><L00Co0000ocg2?Olm`Sgo?L8m0ol000000olFjAKo
0000ocK9=P09ocK9=P03o`000?moP7ooOh1o00CoOh1o00?o0000okM8]ongB;L01OngB;L00ol0003o
i1_Ton@Ki009on@Ki003o`000?oc3??ol`cc00gol`cc00?o0000ooL8moog2?L02_og2?L00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ojQGZonXEjP06onXEjP03o`00
0?o5>/GoaC[500?oaC[500?o0000olHia_o6>LH01?o6>LH2o`000003oi9]T_l0003oB;M800[oB;M8
00?o0000oacS7?lLha`01OlLha`00ol0003o?L8mocg2?@05ocg2?@03o`000?lfbCKo=/Tf00Oo=/Tf
0ol00007ogn0O`03o`000?ngB;Oo]dRg00Co]dRg00?o0000on@Ki?oT6n@02OoT6n@00ol0003ol`cc
oo<<l`0=oo<<l`03o`000?og2?Oom`Sg00[om`Sg00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oh
1oSon0Oh00Gon0Oh0ol00009onXEjP05o`000?o5>/GoaC[5olDjaOl000002Oo6>LH00ol0003oB;M8
odRgB00;odRgB003o`000?lLhaco7><L00?o7><L00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003o=/Tf
ocK9=P06ocK9=P05o`000?mdRgCoM8]dogB;M?l000001omoP7l00ol0003o]dRgokM8]`03okM8]`03
o`000?oT6nCoi1_T00Woi1_T00?o0000oo<<looc3?<03_oc3?<00ol0003om`SgooL8m`09ooL8m`03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on0Oho`000004o`0000;onPGj00?o0000onXEj_oZ5NX0
1ooZ5NX01?l0003oaC[5olDjaOl00009olHiaP;o00003Om8]dP00ol0003o7><LoacS7002oacS7003
o`000?lm`Sgo?L8m00So?L8m00?o0000ocK9=_lfbCH00olfbCH2o`0000GoM8]d00?o0000ogn0Oomo
P7l01?moP7l00ol0003o]dRgokM8]`03okM8]`03o`000?oT6nCoi1_T00Woi1_T00?o0000oo<<looc
3?<03_oc3?<00ol0003om`SgooL8m`09ooL8m`03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000SonPGj
00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oaC[5o`000009olHiaP04o`000?nLHicoW6>Lo`0000go
B;M800Co0000oacS7?lLhaco00003?lm`Sd01Ol0003o=/TfocK9=_lfbCKo000000SoM8]d0_l00005
ogn0O`03o`000?ngB;Oo]dRg00;o]dRg00?o0000on@Ki?oT6n@02OoT6n@00ol0003ol`ccoo<<l`0>
oo<<l`03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj
00OonPGj00?o0000onXEj_oZ5NX01ooZ5NX00ol0003oaSW6olHiaP07olHiaP03o`000?nLHicoW6>L
00;oW6>L00?o0000odRgB?m8]dP02_m8]dP00ol0003o7><Lo`00000>ocg2?@03o`000?lfbCKo0000
00_oM8]d00?o0000ogn0OomoP7l00_moP7l01Ol0003o]dRgokM8]ongB;Oo000000coi1_T00?o0000
oo<<looc3?<03_oc3?<3o`0000Wom`Sg00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oj1O[onPGj
00WonPGj00?o0000onXEj_oZ5NX01_oZ5NX00ol0003oaSW6olHiaP06olHiaP03o`000?nLHicoW6>L
00?oW6>L00?o0000odRgB?m8]dP02om8]dP00ol0003o?L8mocg2?@0>ocg2?@03o`000?mdRgCoM8]d
00_oM8]d0_l00003ogn0O`04o`000?ngB;Oo]dRgo`0000[oi1_T0ol0000>oo<<l`;o00000oon0Oh2
o`0000Oom`Sg00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oj1O[onPGj00[onPGj00?o0000onXE
j_oZ5NX01?oZ5NX00ol0003oaSW6olHiaP06olHiaP03o`000?nLHicoW6>L00GoW6>L00?o0000odRg
B?m8]dP01om8]dP3o`00017o?L8m00?o0000ogB;M?mdRg@03OmdRg@01Ol0003oOh1oogn0Ool0003o
]dRg00Co00000ooT6n@5o`0000;on@Ki00?o0000oo<<looc3?<02_oc3?<2o`0000OooP7n0_l00004
ooL8m`03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oZ5N[ojQGZ
00CojQGZ00?o0000olHia_o6>LH01Oo6>LH00ol0003oW6>LoiaSW006oiaSW003o`000?m8]dSoB;M8
00CoB;M80ol00002odn`C`03o`000?lm`Sgo?L8m00oo?L8m0_l0000?ogB;M004o`000?moP7oo0000
o`0000Cof2OH0ol00008ooT6n@03o`000?oc3??ol`cc00Ool`cc0_l0000;ooh1oP;o00000_og2?L0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000ooX5n_oj1OX03?oj1OX6o`0000OoaSW600?o0000oiaS
W?nLHi`02?nLHi`00ol0003oB;M8odRgB003o`0000KoCk1?00?o0000ocg2?Olm`Sd03Olm`Sd01?l0
003oNXEjogZ5N_l0000?ogB;M003o`000?oH9mSof2OH00Gof2OH00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ol`ccoo<<l`05oo<<l`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_oj1OX00ol0003ok1?/on`Ck004on`C
k003o`000?o6>LKoaSW600?oaSW600?o0000oiaSW?nLHi`02_nLHi`2o`0000[oCk1?00?o0000ocg2
?Olm`Sd02olm`Sd00ol0003oNXEjogZ5NP02ogZ5NP03o`000?mdRgCoM8]d00_oM8]d0_l00007omPW
f003o`000?oi1_Won@Ki00Won@Ki00?o0000oo<<looc3?<00_oc3?<2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ok1?/on`Ck006on`Ck005o`000?o6>LKoaSW6olHi
a_l000003OnLHi`00ol0003oCk1?odn`C`0:odn`C`03o`000?lm`Sgo?L8m00Wo?L8m00?o0000ogZ5
N_mjQGX01?mjQGX00ol0003oM8]dogB;M008ogB;M0;o000000?oYeRWo`000?oH9mP01ooH9mP00ol0
003on@KiooT6n@09ooT6n@04o`000?oc3??o0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oj1O[onPGj
00WonPGj00?o0000on`Ck?o/4n`02?o/4n`00ol0003oaSW6o`00000=oiaSW003o`000?m?/4ooCk1?
00_oCk1?00?o0000ocg2?Olm`Sd02?lm`Sd00ol0003oNXEjogZ5NP06ogZ5NP03o`000?mdRgCoM8]d
00GoM8]d0_l00003ojMHY`03o`000?oH9mSof2OH00Kof2OH00?o0000ooT6nOoi1_T02_oi1_T00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003onPGjooX5nP07ooX5nP03o`000?o/4ncok1?/00[ok1?/00?o0000oiaSW?nL
Hi`03?nLHi`00ol0003oCk1?odn`C`0<odn`C`03o`000?lm`Sgo?L8m00Ko?L8m00?o0000ogZ5N_mj
QGX02?mjQGX00ol0003oM8]dogB;M002ogB;M0;o00001_nWF:L00ol0003of2OHomPWf005omPWf003
o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj00GonPGj
00?o0000on`Ck?o/4n`03?o/4n`2o`0000coW6>L00?o0000odn`Com?/4l03Om?/4l00ol0003o?L8m
ocg2?@04ocg2?@03o`000?mjQG[oNXEj00[oNXEj00Co0000ogB;M?l0003o00002?nWF:L00ol0003o
f2OHomPWf006omPWf003o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_oj1OX00ol0003ok1?/on`Ck00=on`Ck003o`000?o8=lSo000000;o00002?nLHi`00ol0003oCk1?
odn`C`0?odn`C`Ko00003_mjQGX00ol0003oYeRWojMHY`08ojMHY`03o`000?oH9mSof2OH00Kof2OH
00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo/4nook1?_on`Ck
0_l0000?on`Ck003o`000?o8=lSob3O800?ob3O80ol00005oiaSW0;o00004?m?/4l01_l0003oHIiQ
of6NHOl0003oFjAKo`0000koNXEj00?o0000ojMHYonWF:L02OnWF:L00ol0003of2OHomPWf005omPW
f003o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo/4nook1?/00ook1?/00ol0003o
k1?/on`Ck00=on`Ck003o`000?o8=lSob3O800Kob3O80ol000001?nLHico0000ogj1O_mnPGh3o`00
00coCk1?00Go0000of6NHOmQWV7oHIiQo`000002oe^TF`03o`000?mjQG[oNXEj00_oNXEj00?o0000
ojMHYonWF:L02OnWF:L00ol0003of2OHomPWf006omPWf003o`000?oi1_Won@Ki00Son@Ki0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003on`Ckoo/4n`04oo/4n`oo00003?o8=lP00ol0003oOX5nogj1OP04ogj1
OP?o00002?m?/4l00ol0003oHIiQof6NH@02of6NH@05o`000?mKY5_oFjAKoe^TFol000003?mjQGX0
0ol0003oYeRWojMHY`09ojMHY`03o`000?oH9mSof2OH00Gof2OH3?l00002ood2o@;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?o^4NkokQ7^00_okQ7^00?o0000olPg
b?o8=lP02_o8=lP00ol0003oOX5nogj1OP07ogj1OP;o00001Om?/4l00ol0003oHIiQof6NH@03of6N
H@03o`000?mKY5_oFjAK00;oFjAK00?o0000ogZ5N_mjQGX02OmjQGX00ol0003oYeRWojMHY`0:ojMH
Y`03o`000?oH9mSof2OH00?of2OH00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@02ood2
o@;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?o^4NkokQ7^00[o
kQ7^00?o0000olPgb?o8=lP02oo8=lP00ol0003oOX5nogj1OP09ogj1OP?o000000?oCk1?o`000?mQ
WV401OmQWV400ol0003oFjAKoe^TF`03oe^TF`03o`000?mjQG[oNXEj00SoNXEj3_l00003omPWf0;o
00002oof2OH00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo/4nook1?/01Ook1?/00ol0003ol`cco`00000;onhAkP03o`000?o8=lSob3O800[ob3O8
0_l0000>ogj1OP03o`000?mQWV7oHIiQ00GoHIiQ00?o0000oe^TFomKY5/00omKY5/00ol0003oNXEj
ogZ5NP08ogZ5NP03o`000?oH9mSof2OH00_of2OH00?o0000omPWf?l000003Oof2OH00ol0003oo@;m
ood2o@06ood2o@;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00Co
0000oo<<looc3??o00002_o^4Nh00ol0003ob3O8olPgb009olPgb003o`000?naC[7o000000koOX5n
00?o0000of6NHOmQWV401OmQWV400ol0003oFjAKoe^TF`04oe^TF`03o`000?mjQG[oNXEj00KoNXEj
00?o0000omPWf?oH9mP03OoH9mP00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo<<looc3?<00_oc
3?<00ol0003okQ7^onhAkP06onhAkP03o`000?o8=lSob3O800Sob3O80_l00003ok5>/@03o`000?mn
PGkoOX5n00_oOX5n00?o0000of6NHOmQWV401OmQWV400ol0003oFjAKoe^TF`05oe^TF`03o`000?mj
QG[oNXEj00GoNXEj00?o0000omPWf?oH9mP03OoH9mP00ol0003omPWfooH9mP0;ooH9mP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000
oo<<looc3?<00ooc3?<00ol0003okQ7^onhAkP05onhAkP03o`000?o8=lSob3O800Oob3O800?o0000
ok5>/OnaC[400onaC[400ol0003oOX5nogj1OP0:ogj1OP03o`000?mQWV7oHIiQ00KoHIiQ00?o0000
oe^TFomKY5/01_mKY5/00ol0003oNXEjogZ5NP04ogZ5NP03o`000?oH9mSof2OH00gof2OH3ol0000;
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo<<looc3?<01Ooc3?<00ol0
003okQ7^onhAkP04onhAkP03o`000?o8=lSob3O800Gob3O80_l00006ok5>/@03o`000?mnPGkoOX5n
00WoOX5n0_l00008of6NH@03o`000?mKY5_oFjAK00KoFjAK1Ol000000omjQG[o0000omPWf00?omPW
f003o`000?og2?Oom`Sg00_om`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o0000oo<<looc3?<01_oc3?<00ol0003o
kQ7^onhAkP04o`0000Kob3O800?o0000ok5>/OnaC[401onaC[400ol0003oOX5nogj1OP05ogj1OP?o
000000?oOX5no`000?mQWV401omQWV400ol0003oFjAKoe^TF`05oe^TF`03o`000?nHIiSoV6NH00?o
V6NH0_l0000?omPWf0;o00003Oog2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Won`Ck00?o0000oo<<looc3?<01ooc3?<2o`0000Cogb3O00Co0000olPgb?o8=lSo
b3O80_l0000:ok5>/@03o`000?mnPGkoOX5n00;oOX5n0ol00005ogj1OP03o`000?mQWV7oHIiQ00Go
HIiQ00?o0000oe^TFomKY5/01?mKY5/00ol0003oV6NHoiQWV006oiQWV003o`000?oH9mSof2OH00[o
f2OH0_l00002onl@k`03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d02?om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo/4nook1?/01_ok1?/00ol0003ol`ccoo<<l`08oo<<l`03o`00
0?oO8=oogb3O00Cogb3O00?o0000olPgb?l000003?naC[400ol0003oOX5no`000002o`0000WoOX5n
00?o0000of6NHOmQWV401?mQWV400ol0003oFjAKoe^TF`03oe^TF`03o`000?nHIiSoV6NH00SoV6NH
1_l00004omPWf0;o00001Oo_4>l00ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo<<looc3?<01ooc
3?<00ol0003ogb3OomlPg`06omlPg`03o`000?naC[7o/Dja00co/Dja00?o0000ogj1O_mnPGh02_mn
PGh00ol0003oHIiQof6NH@04of6NH@04o`000?mKY5_oFjAKoe^TF`;o00002onHIiP00ol0003ogR7N
omhQgP03omhQgPCo00002?o_4>l00ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00Ooo@;m
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo/4nook1?/00ook1?/00ol0003ol`ccoo<<l`07oo<<l`03o`000?oO
8=oogb3O00Oogb3O00?o0000ok5>/OnaC[403?naC[400ol0003oOX5nogj1OP0;ogj1OP03o`000?mQ
WV7oHIiQ00?oHIiQ00Co0000oe^TFomKY5_o00003OnHIiP00ol0003ogR7NomhQgP06omhQgP03o`00
0?o_4>ooka3_00Ooka3_00?o0000ooL8moog2?L01oog2?L00ol0003oo@;mood2o@06ood2o@04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00;on`Ck00?o0000oo<<looc3?<0
1_oc3?<00ol0003ogb3OomlPg`09omlPg`03o`000?naC[7o/Dja00Wo/Dja0_l0000>ogj1OP?o0000
0omQWV400ol0003oFjAKo`00000=oiQWV003o`000?oN8MkogR7N00OogR7N00?o0000onl@koo_4>l0
2?o_4>l:o`0000Koo@;m0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Ool`cc00?o
0000omlPgooO8=l02_oO8=l00ol0003o/Djaok5>/@06ok5>/@;o000000?o/4n`o`000?mnPGh02omn
PGh2o`0000?oQWV61Ol0000>oiQWV003o`000?oN8MkogR7N00OogR7N00?o0000onl@koo_4>l02?o_
4>l00ol0003onPGjooX5nP06ooX5nP03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n003ooP7n0Co00000_oc3?<00ol0003ogb3OomlPg`0;
omlPg`03o`000?naC[7o/Dja00?o/Dja0ol00004ok1?/003o`000?mnPGkoOX5n00OoOX5n0_l00008
ohIiQP03o`000?nHIiSoV6NH00goV6NH00?o0000omhQg_oN8Mh02?oN8Mh00ol0003oka3_onl@k`07
onl@k`03o`000?oj1O[onPGj00OonPGj0ol000000oom0_go0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Oon0Oh0_l0000?omlPg`03o`000?naC[7o/Dja00;o00002?n`Ck000ol0
003oOX5nogj1OP05ogj1OP03o`000?n6NHKoQWV600SoQWV600?o0000oiQWV?nHIiP03OnHIiP00ol0
003ogR7NomhQgP08omhQgP03o`000?o_4>ooka3_00Koka3_00?o0000ooX5n_oj1OX02?oj1OX01?l0
003oo@;mood2oOl0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on0OhooP7n009ooP7
n003o`000?oO8=oogb3O00kogb3O0_l0000;ok1?/003o`000?mnPGkoOX5n00;oOX5n0_l0000;ohIi
QP03o`000?nHIiSoV6NH00goV6NH00?o0000omhQg_oN8Mh02?oN8Mh00ol0003oka3_onl@k`06onl@
k`03o`000?oj1O[onPGj00OonPGj00Go0000ood2oOom0_goo@;mo`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on0OhooP7n00:ooP7n003o`000?oO8=oogb3O00gogb3O0_l0000<ok1?/004o`000?mnPGko0000
o`0000goQWV600?o0000oiQWV?nHIiP03?nHIiP00ol0003ogR7NomhQgP09omhQgP03o`000?o_4>oo
ka3_00Koka3_00?o0000ooX5n_oj1OX01_oj1OX00ol0003oo@;mood2o@03ood2o@03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003on0OhooP7n00:ooP7n003o`000?oO8=oogb3O00cogb3O00Co0000omhQ
g_oN8Mko00003?n`Ck000ol0003oQWV6ohIiQP0>ohIiQP03o`000?nHIiSoV6NH00SoV6NH1?l0000;
omhQgP03o`000?o_4>ooka3_00Koka3_00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oo@;mood2o@04
ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on0OhooP7n00;ooP7n003o`000?oO8=oogb3O
00_ogb3O00?o0000omhQg_oN8Mh00_oN8Mh00ol0003o/4n`ok1?/009ok1?/003o`000?n6NHKoQWV6
00koQWV600Co0000oiQWV?nHIiSoV6NH1ol00003oka3_003o`000?oN8MkogR7N00WogR7N00?o0000
onl@koo_4>l01_o_4>l00ol0003onPGjooX5nP04ooX5nP03o`000?om0_goo@;m00Koo@;m00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oh1oSon0Oh00con0Oh00?o0000omlPgooO8=l02_oO8=l00ol0
003ogR7NomhQgP03omhQgP03o`000?n`Ck3o/4n`00So/4n`00?o0000ohIiQ_n6NHH03_n6NHH4o`00
00_o_4>l00?o0000omhQg_oN8Mh02?oN8Mh00ol0003oka3_onl@k`05onl@k`03o`000?oj1O[onPGj
00GonPGj00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh
1oP03?oh1oP7o`0000Gogb3O00?o0000omhQg_oN8Mh01OoN8Mh00ol0003o/4n`ok1?/007ok1?/003
o`000?n6NHKoQWV600koQWV600?o0000oka3_?nl@k`03Onl@k`00ol0003ogR7NomhQgP08omhQgP03
o`000?o_4>ooka3_00Coka3_00?o0000ooX5n_oj1OX01?oj1OX00ol0003oo@;mood2o@07ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003on0OhooP7n00=ooP7n003o`000?o_4>ooka3_00Coka3_
1Ol00009omhQgP03o`000?n`Ck3o/4n`00Ko/4n`00?o0000ohIiQ_n6NHH03_n6NHH00ol0003o_4>l
oka3_00=oka3_003o`000?oN8MkogR7N00SogR7N00Co0000onl@koo_4>ooka3_1Ol00004ooX5nP03
o`000?om0_goo@;m00Woo@;m1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooP7n003o`000?o_4>ooka3_00Woka3_
0_l00009omhQgP03o`000?n`Ck3o/4n`00Ko/4n`00?o0000ohIiQ_n6NHH03?n6NHH00ol0003o_4>l
oka3_00?oka3_0Ko00001?oN8Mh4o`0000Gon0Oh0_l000000ooj1O[o0000ood2o@0;ood2o@04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?ol0ocoo0?loo`3o0?o00002_oh1oP00ol0003o
ka3_onl@k`09onl@k`03o`000?oX5nSo000000;o00001ooN8Mh00ol0003o/4n`ok1?/005ok1?/003
o`000?n6NHKoQWV600SoQWV61Ol0000Aoka3_003o`000?oV6NKoiQWV00?oiQWV1?l0000;ooP7n003
o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01Ool0o`2o`0000Oon0Oh
00?o0000onl@koo_4>l02_o_4>l00ol0003oj1OXonPGj002onPGj0?o00001OoN8Mh00ol0003o/4n`
ok1?/004ok1?/004o`000?n6NHKoQWV6ohIiQPOo00001?nm@[d00ol0003o_4>loka3_00>oka3_003
o`000?oV6NKoiQWV00OoiQWV00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@09ood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o008oo`3o0;o00001?oh1oP00ol0003oka3_
onl@k`0;onl@k`03o`000?oX5nSoj1OX00Goj1OX0ol00003omhQgP04o`000?n`Ck3o/4n`ok1?/0Ko
00003?nm@[d00ol0003o_4>loka3_00=oka3_003o`000?oV6NKoiQWV00OoiQWV00?o0000ooP7n?oh
1oP02_oh1oP00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=oo`3o0?o000000?on0Oho`000?o_4>l0
3?o_4>l00ol0003oj1OXonPGj008onPGj0?o000000CogR7No`000?l0003o00000_oM8]d00ol0003o
_D:moke2_@0=oke2_@03o`000?nl@kco_4>l00co_4>l00?o0000onHIi_oV6NH02?oV6NH00ol0003o
n0OhooP7n00;ooP7n003o`000?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o0?l00?o0000onl@koo_4>l03?o_4>l00ol0003oj1OXonPGj00;onPGj003o`000?oM8]gogB;M00?o
gB;M00?o0000oke2_Onm@[d03?nm@[d00ol0003oc3?<o`00000=oka3_003o`000?oV6NKoiQWV00So
iQWV00?o0000ooP7n?oh1oP03?oh1oP3o`0000Goo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ol0ocoo0?l00coo0?l00?o0000onl@koo_4>l03?o_4>l00ol0003oj1OXonPGj00:onPGj003o`00
0?oM8]gogB;M00GogB;M00?o0000oke2_Onm@[d02_nm@[d01?l0003oc3?<ol`cc?o<<l`2o`0000[o
_4>l00?o0000onHIi_oV6NH02OoV6NH00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00?o
000000?oo@;mo`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000onl@koo_4>l0
3?o_4>l00ol0003oj1OXonPGj009onPGj003o`000?oM8]gogB;M00KogB;M00?o0000oke2_Onm@[d0
2Onm@[d00ol0003oc3?<ol`cc002ol`cc003o`000?oP7n3o000000;o00001onl@k`00ol0003oiQWV
onHIiP09onHIiP03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02ool0o`00ol0003oka3_onl@k`0;onl@k`03o`000?oX
5nSoj1OX00Soj1OX00?o0000omdRgOoM8]d01ooM8]d00ol0003o_D:moke2_@08oke2_@03o`000?o<
<lcoc3?<00?oc3?<00?o0000on0Oh?oP7n000_oP7n02o`0000Co_4>l00?o0000onHIi_oV6NH02_oV
6NH00ol0003on0OhooP7n00:ooP7n003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?ol0ocoo0?l00[oo0?l0ol0000;onl@k`Ko00001?oX5nP00ol0003ogB;MomdRg@08
omdRg@03o`000?nm@[go_D:m00Oo_D:m00?o0000ol`cc?o<<l`00oo<<l`00ol0003oh1oPon0Oh005
on0Oh0?o000000?o_4>lo`000?oV6NH02ooV6NH00ol0003on0OhooP7n009ooP7n003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l00Woo0?l00?o0000ooX5
n_oj1OX01?l00006onl@k`03o`000?oa3_7ol@ka00Col@ka1?l0000<omdRg@03o`000?nm@[go_D:m
00Go_D:m00?o0000ol`cc?o<<l`01?o<<l`00ol0003oh1oPon0Oh008on0Oh003o`000?oV6NKoiQWV
00_oiQWV00?o0000ooP7n?oh1oP02?oh1oP00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?ol0ocoo0?l00Ooo0?l00?o0000ooX5n_oj1OX01Ooj1OX3o`0000;oka3_00?o0000oo4>lOoa
3_402?oa3_400ol0003ogB;MomdRg@0:omdRg@03o`000?nm@[go_D:m00Co_D:m00?o0000ol`cc?o<
<l`01Oo<<l`00ol0003oh1oPon0Oh008on0Oh003o`000?oV6NKoiQWV00WoiQWV1?l00008ooP7n003
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?l
oo`3o005oo`3o003o`000?oj1O[onPGj00WonPGj0_l0000<oo4>l@03o`000?oM8]gogB;M00WogB;M
00?o0000oke2_Onm@[d00onm@[d00ol0003oc3?<ol`cc005ol`cc003o`000?oP7n3oh1oP00[oh1oP
00?o0000onHIi_oV6NH01?oV6NH4o`0000ComPWf00?o0000ooP7n?oh1oP01?oh1oP00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX02ooj
1OX00ol0003ol@kaoo4>l@0:oo4>l@03o`000?oM8]gogB;M00WogB;M00?o0000oke2_Onm@[d00_nm
@[d00ol0003oc3?<ol`cc006ol`cc003o`000?oP7n3oh1oP00[oh1oP00?o0000onHIi_oV6NH01?l0
0009ooH9mPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000oo`3o?ol0ocoo0?l0_l0
000=ooX5nP03o`000?oa3_7ol@ka00[ol@ka00?o0000omdRgOoM8]d02OoM8]d01Ol0003o_D:moke2
_Onm@[go000000Woc3?<00?o0000on0Oh?oP7n002ooP7n02o`0000gomPWf00?o0000ood2oOom0_d0
0_om0_d00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?lo`00
0002ooh1oP;o00002ooj1OX00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oM8]gogB;M00WogB;M00?o
0000oke2_Ol000002Oo<<l`00ol0003oh1oPon0Oh00<on0Oh003o`000?of2OKomPWf00comPWf00?o
0000ood2oOom0_d00oom0_d00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oj1OX00ol0003ol@kaoo4>l@0:oo4>l@03o`000?oM8]go
gB;M00SogB;M1Ol00008ol`cc003o`000?oP7n3oh1oP00coh1oP00?o0000ooH9m_of2OH02oof2OH0
0ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000SonPGj00?o0000oo4>lOoa3_402_oa3_400ol0003ogB;MomdRg@07omdR
g@03o`000?oT6nCoi1_T00?oi1_T0ol00005ol`cc003o`000?oP7n3oh1oP00_oh1oP00?o0000ooH9
m_of2OH03?of2OH00ol0003oo@;mood2o@06ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000ooX5n_oj1OX01Ooj1OX2o`0000co
l@ka00?o0000omdRgOoM8]d01OoM8]d00ol0003oi1_Ton@Ki007on@Ki0?o000000?oc3?<o`000?oP
7n003OoP7n000ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Koo@;m00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooX5nP03o`000?ok1?_on`Ck00;o00002_oa3_400ol0003ogB;MomdRg@03omdRg@;o0000
3OoT6n@2o`0000goh1oP0ol0000=ooH9mP03o`000?om0_goo@;m00Ooo@;m00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooj1O[o0000oo/4n`04oo/4n`03o`000?oa3_7ol@ka00Ool@ka00Co0000omdRgOoM8]gogB;M
0_l00002oo@;m003o`000?oT6nCoi1_T00coi1_T3Ol00003ooP7n003o`000?of2OKomPWf00[omPWf
00?o0000ood2oOom0_d02?om0_d01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck0_l00008oo4>l@03o`000?oM8]go000000Gom0_d
00?o0000on@Ki?oT6n@02ooT6n@00ol0003ojaC[on/Dj`09on/Dj`03o`000?oh1oSon0Oh00;on0Oh
0_l00009ooH9mP03o`000?om0_goo@;m00[oo@;m0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/01ook1?/4o`0000?ol@ka0ol0
0007oo@;m003o`000?oT6nCoi1_T00[oi1_T00?o0000on/Djoo[5>/02Oo[5>/00ol0003on0OhooP7
n004ooP7n0;o00001oof2OH00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo/4nook1?/02?ok1?/0
1?l0003on`Ckoo/4nook1?/3o`0000;on@Ki00?o0000oo@;m?od2o@01_od2o@00ol0003oi1_Ton@K
i008on@Ki003o`000?o[5>_ojaC[00[ojaC[00?o0000ooP7n?oh1oP01_oh1oP00ol0003omPWfooH9
mP04ooH9mP03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_o
n`Ck00Con`Ck00Go0000ooT6nOoi1_Won@Kio`000008oo@;m003o`000?oT6nCoi1_T00Ooi1_T00?o
0000on/Djoo[5>/02_o[5>/00ol0003on0OhooP7n007ooP7n0;o00001?of2OH00ol0003oo@;mood2
o@08ood2o@03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on`Ckoo/4n`08oo/4n`03o`000?ok1?_on`Ck00Con`Ck00?o0000ooT6nOoi1_T00_oi1_T0
0ol0003om0_doo@;m007oo@;m003o`000?oT6nCoi1_T00Koi1_T00?o0000on/Djoo[5>/02_o[5>/0
0ol0003on0OhooP7n009ooP7n005o`000?of2OKomPWfooH9m_l000002Oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_on`Ck00?o0000oo/4nook1?/01?ok1?/00ol0003on@KiooT6n@03
ooT6n@03o`000?od2oCom0_d00Oom0_d00?o0000on@Ki?oT6n@01OoT6n@00ol0003ojaC[on/Dj`0:
on/Dj`03o`000?oh1oSon0Oh00Won0Oh1?l00009ood2o@03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ok1?/00ol0003on`Ckoo/4n`05oo/4n`03o`000?oi1_Won@Ki00?on@Ki00?o0000
oo@;m?od2o@02?od2o@00ol0003oi1_Ton@Ki004on@Ki003o`000?o[5>_ojaC[00WojaC[00?o0000
ooP7n?oh1oP02?oh1oP2o`0000?oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003on`Ckoo/4n`06oo/4n`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooT6nOoi1_T01?oi1_T00ol0003om0_doo@;m009oo@;m003o`000?oT6nCoi1_T
00;oi1_T00?o0000on/Djoo[5>/02_o[5>/00ol0003on0OhooP7n006ooP7n0;o00001_om0_d8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo/4nook
1?/01Ook1?/00ol0003on@KiooT6n@05ooT6n@03o`000?od2oCom0_d00Wom0_d00Go0000on@Ki?oT
6nCoi1_To`00000<on/Dj`03o`000?oh1oSon0Oh00Con0Oh0_l00008ood2o@03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003on`Ckoo/4n`06oo/4n`03o`000?oi1_Won@Ki00Gon@Ki00?o0000oo@;m?od
2o@02_od2o@00ol0003oi1_To`000004o`0000WojaC[00?o0000ooP7n?oh1oP00_oh1oP2o`0000[o
o@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ok1?_on`Ck00;on`Ck00?o0000oo/4nook1?/01_ok1?/00ol0003on@KiooT6n@07ooT6n@;o0000
2ood2o@00ol0003onPGjooX5nP03ooX5nPOo00000_o[5>/00ol0003on0OhooP7n002o`0000_oo@;m
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003on`Ckoo/4nook1?_o000000Son`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo0?l
o`000002o`0000Som0_d00?o0000ooX5n_oj1OX02_oj1OX5o`0000goo@;m00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ok1?_o000000Won`Ck00?o
0000ooT6nOoi1_T01_oi1_T00ol0003oo0?loo`3o003oo`3o0?o00001?od2o@00ol0003onPGjooX5
nP0=ooX5nP03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000oo/4nook1?/01ook1?/00ol0003on@KiooT6n@07
ooT6n@03o`000?ol0ocoo0?l00Koo0?l0ol000000ood2oCo0000ooX5nP0>ooX5nP03o`000?om0_go
o@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?ok1?_on`Ck00;on`Ck1_l00008ooT6n@03o`000?ol0ocoo0?l00[oo0?l00?o0000ooX5
n_oj1OX03ooj1OX00ol0003oo@;mood2o@0:ood2o@;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_om0_d00ol0003on@KiooT6n@05ooT6n@03o`000?ol0ocoo0?l00[o
o0?l00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;mood2o@07ood2o@?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ooT6nOoi
1_T00ooi1_T00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj00oonPGj00?o0000ood2oOom
0_d01Oom0_d2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oom0_d00ol0003on@KiooT6n@02ooT6n@03o`000?ol0ocoo0?l00_oo0?l5?l00004ood2o@;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ood2o@04o`000?oi1_Won@Kio`0000koo0?l
00?o0000ooh1o_on0Oh04?on0Oh00ol0003oo@;mo`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_om0_d00ol0003on@Kio`00000>oo`3o003o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00Woo0?l1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo@;mood2o@0<ood2o@03o`000?ol0ocoo0?l00;oo0?l1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?om0_goo@;m00coo@;m1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`0:o`00o`03oooo0?l00?oo003o00_o003o0_ooo`07o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000[o003o00?oool0o`00ool00?l02ol0
0?l2oooo00Ko003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002_l00?l00oooo`3o003oo`00o`0;o`00o`;oool01Ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000_o003o00?oool0o`00ool00?l02_l00?l2oooo
00Go003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000_o003o00?oool0o`00ool00?l00ol00?l<oooo00;o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool02ol00?l00oooo`3o003oo`00o`03o`00o`coool0
00?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l0
0?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o
0oooo`04o`00o`;oool03?l00?l00oooo`3o003oo`00o`02o`00o`03oooo0?l00?oo003o00Co003o
0_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol0
0?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0<o`00o`03oooo0?l00?oo003o00?o003o
00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l00?ooool0oooo00co003o
00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`02o`00o`;oool01?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo000=o`00o`03oooo0?l00?oo003o00?o003o0_ooo`03o`00o`;oool01?l0
0?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05
o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o
003o00;oool03Ol00?l00oooo`3o003oo`00o`04o`00o`04oooo0?l00?oo003oo`00o`;oool01?l0
0?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05
o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`0=o`00o`03oooo0?l00?oo003o00Go003o00?oool0
o`00ool00?l00_ooo`04o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00
o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00ko003o00?oool0o`00
ool00?l01Ol00?l01?ooo`3o003ooooo0?ooo`04o`00o`;oool01_l00?l00oooo`3o003oo`00o`05
o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo
00Go003o00?oool0o`00ool00?l01_l00?l00oooo`3o003oo`00o`05o`00o`04oooo0?l00?ooool0
oooo00Go003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00
o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l00ol00?l00ooo
o`3o003oo`00o`05o`00o`03oooo0?l00?oo003o00Ko003o0oooo`05o`00o`;oool01?l00?l2oooo
00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o0oooo`07o`00o`03
oooo0?l00?oo003o01Ko003o1Oooo`03o`00o`[oool02?l00?l2oooo00Ko003o0_ooo`02o`00o`;o
ool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o
1Oooo`0No`00o`[oool02?l00?l2oooo00Oo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Ooo
ool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(750) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.997 .003 .997 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.991 .009 .991 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.986 .014 .986 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.986 .014 .986 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.965 .035 .965 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.972 .028 .972 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.936 .064 .936 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.982 .018 .982 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.873 .127 .873 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.962 .038 .962 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.96 .04 .96 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.967 .033 .967 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.975 .025 .975 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.987 .013 .987 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.947 .053 .947 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.975 .025 .975 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.913 .087 .913 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.985 .015 .985 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.972 .028 .972 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.955 .045 .955 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.971 .029 .971 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.884 .116 .884 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.981 .019 .981 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.952 .048 .952 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.986 .014 .986 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.914 .086 .914 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.709 .291 .709 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.766 .234 .766 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.995 .005 .995 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.978 .022 .978 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.926 .074 .926 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.932 .068 .932 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.726 .274 .726 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.687 .313 .687 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.641 .359 .641 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.916 .084 .916 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.936 .064 .936 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.921 .079 .921 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.875 .125 .875 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.772 .228 .772 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.967 .033 .967 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.738 .262 .738 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.661 .339 .661 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.865 .135 .865 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.404 .596 .404 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.398 .602 .398 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.462 .538 .462 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.776 .224 .776 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.785 .215 .785 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.984 .016 .984 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.416 .584 .416 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.378 .622 .378 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.945 .055 .945 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.997 .003 .997 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.575 .425 .575 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.696 .304 .696 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.909 .091 .909 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.903 .097 .903 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.615 .385 .615 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.872 .128 .872 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.33 .67 .33 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.81 .19 .81 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.694 .306 .694 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.115 .885 .115 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.295 .705 .295 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.975 .025 .975 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.2 .8 .2 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.16 .84 .16 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.87 .13 .87 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.977 .023 .977 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.445 .555 .445 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.13 .87 .13 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.198 .802 .198 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.774 .226 .774 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.289 .711 .289 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.5 .5 .5 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.988 .012 .988 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.17 .83 .17 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.017 .983 .017 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.112 .888 .112 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.006 .994 .006 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.316 .684 .316 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.501 .499 .501 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.955 .045 .955 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.53 .47 .53 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.996 .004 .996 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.599 .401 .599 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.023 .977 .023 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.018 .982 .018 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.083 .917 .083 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.114 .886 .114 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.745 .255 .745 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.895 .105 .895 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.928 .072 .928 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.411 .589 .411 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.092 .908 .092 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.804 .196 .804 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.17 .83 .17 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.386 .614 .386 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.076 .924 .076 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.244 .756 .244 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.833 .167 .833 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.36 .64 .36 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.092 .908 .092 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.977 .023 .977 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.993 .007 .993 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.879 .121 .879 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.92 .08 .92 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.223 .777 .223 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.968 .032 .968 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.601 .399 .601 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.577 .423 .577 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.078 .922 .078 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.214 .786 .214 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.482 .518 .482 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.741 .259 .741 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.997 .003 .997 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.083 .917 .083 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.983 .017 .983 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.051 .949 .051 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.187 .813 .187 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.232 .768 .232 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.969 .031 .969 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.461 .539 .461 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.992 .008 .992 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.37 .63 .37 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.258 .742 .258 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.227 .773 .227 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.903 .097 .903 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.877 .123 .877 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.871 .129 .871 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.161 .839 .161 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.501 .499 .501 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.656 .344 .656 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.849 .151 .849 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.965 .035 .965 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.99 .01 .99 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.462 .538 .462 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.72 .28 .72 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.342 .658 .342 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.952 .048 .952 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.936 .064 .936 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.847 .153 .847 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.972 .028 .972 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.992 .008 .992 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.46 .54 .46 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.581 .419 .581 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.987 .013 .987 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.473 .527 .473 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.895 .105 .895 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.665 .335 .665 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.806 .194 .806 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.596 .404 .596 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.975 .025 .975 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.961 .039 .961 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.966 .034 .966 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.98 .02 .98 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.75 .25 .75 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.953 .047 .953 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.675 .325 .675 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.716 .284 .716 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.845 .155 .845 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.847 .153 .847 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.992 .008 .992 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.951 .049 .951 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.99 .01 .99 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.779 .221 .779 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.982 .018 .982 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.944 .056 .944 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.921 .079 .921 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.905 .095 .905 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.851 .149 .851 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.87 .13 .87 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.808 .192 .808 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.914 .086 .914 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.95 .05 .95 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.976 .024 .976 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.968 .032 .968 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.981 .019 .981 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.956 .044 .956 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.873 .127 .873 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.949 .051 .949 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.968 .032 .968 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.983 .017 .983 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.979 .021 .979 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.983 .017 .983 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.965 .035 .965 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.986 .014 .986 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.971 .029 .971 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.992 .008 .992 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.98 .02 .98 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.985 .015 .985 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.989 .011 .989 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(760) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.991 .009 .991 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.987 .013 .987 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.986 .014 .986 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.966 .034 .966 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.973 .027 .973 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.937 .063 .937 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.982 .018 .982 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.993 .007 .993 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.876 .124 .876 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.963 .037 .963 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.961 .039 .961 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.968 .032 .968 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.976 .024 .976 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.988 .012 .988 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.947 .053 .947 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.976 .024 .976 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.914 .086 .914 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.985 .015 .985 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.973 .027 .973 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.956 .044 .956 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.971 .029 .971 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.886 .114 .886 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.981 .019 .981 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.953 .047 .953 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.986 .014 .986 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.915 .085 .915 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.714 .286 .714 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.769 .231 .769 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.978 .022 .978 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.927 .073 .927 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.933 .067 .933 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.73 .27 .73 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.691 .309 .691 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.645 .355 .645 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.917 .083 .917 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.938 .062 .938 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.923 .077 .923 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.878 .122 .878 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.773 .227 .773 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.968 .032 .968 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.743 .257 .743 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.664 .336 .664 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.866 .134 .866 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.407 .593 .407 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.401 .599 .401 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.468 .532 .468 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.778 .222 .778 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.788 .212 .788 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.985 .015 .985 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.422 .578 .422 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.383 .617 .383 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.947 .053 .947 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.578 .422 .578 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.7 .3 .7 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.911 .089 .911 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.906 .094 .906 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.619 .381 .619 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.873 .127 .873 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.333 .667 .333 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.814 .186 .814 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.698 .302 .698 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.993 .007 .993 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.118 .882 .118 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.298 .702 .298 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.976 .024 .976 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.205 .795 .205 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.163 .837 .163 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.873 .127 .873 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.977 .023 .977 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.451 .549 .451 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.132 .868 .132 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.202 .798 .202 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.778 .222 .778 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.293 .707 .293 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.505 .495 .505 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.988 .012 .988 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.175 .825 .175 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.02 .98 .02 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.115 .885 .115 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.008 .992 .008 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.32 .68 .32 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.506 .494 .506 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.956 .044 .956 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.535 .465 .535 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.606 .394 .606 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.025 .975 .025 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.019 .981 .019 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.085 .915 .085 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.117 .883 .117 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.75 .25 .75 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.897 .103 .897 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.929 .071 .929 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.418 .582 .418 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.093 .907 .093 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.807 .193 .807 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.175 .825 .175 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.391 .609 .391 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.08 .92 .08 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.247 .753 .247 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.836 .164 .836 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.365 .635 .365 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.095 .905 .095 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.978 .022 .978 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.994 .006 .994 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.882 .118 .882 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.922 .078 .922 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.229 .771 .229 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.968 .032 .968 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
0 1 0 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.606 .394 .606 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.581 .419 .581 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.082 .918 .082 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.218 .782 .218 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.486 .514 .486 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.745 .255 .745 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.087 .913 .087 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.984 .016 .984 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.052 .948 .052 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.19 .81 .19 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.239 .761 .239 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.97 .03 .97 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.465 .535 .465 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.377 .623 .377 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.263 .737 .263 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.23 .77 .23 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.906 .094 .906 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.879 .121 .879 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.873 .127 .873 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.166 .834 .166 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.504 .496 .504 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.659 .341 .659 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.852 .148 .852 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.966 .034 .966 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.99 .01 .99 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.467 .533 .467 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.722 .278 .722 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.348 .652 .348 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.953 .047 .953 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.937 .063 .937 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.849 .151 .849 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.972 .028 .972 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.992 .008 .992 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.466 .534 .466 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.586 .414 .586 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.987 .013 .987 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.481 .519 .481 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.896 .104 .896 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.669 .331 .669 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.809 .191 .809 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.601 .399 .601 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.975 .025 .975 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.961 .039 .961 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.966 .034 .966 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.98 .02 .98 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.754 .246 .754 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.954 .046 .954 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.681 .319 .681 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.721 .279 .721 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.847 .153 .847 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.85 .15 .85 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.952 .048 .952 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.99 .01 .99 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.783 .217 .783 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.983 .017 .983 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.946 .054 .946 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.923 .077 .923 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.907 .093 .907 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.854 .146 .854 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.872 .128 .872 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.811 .189 .811 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.917 .083 .917 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.951 .049 .951 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.977 .023 .977 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.962 .038 .962 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.968 .032 .968 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.982 .018 .982 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.957 .043 .957 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.876 .124 .876 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.95 .05 .95 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.968 .032 .968 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.983 .017 .983 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.979 .021 .979 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.983 .017 .983 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.966 .034 .966 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.971 .029 .971 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.992 .008 .992 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.981 .019 .981 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.985 .015 .985 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.995 .005 .995 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.989 .011 .989 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.997 .003 .997 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(770) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.991 .009 .991 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.987 .013 .987 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.986 .014 .986 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.967 .033 .967 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.973 .027 .973 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.938 .062 .938 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.982 .018 .982 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.878 .122 .878 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.964 .036 .964 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.962 .038 .962 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.968 .032 .968 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.976 .024 .976 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.988 .012 .988 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.948 .052 .948 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.976 .024 .976 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.915 .085 .915 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.985 .015 .985 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.974 .026 .974 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.957 .043 .957 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.972 .028 .972 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.889 .111 .889 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.982 .018 .982 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.953 .047 .953 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.986 .014 .986 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.916 .084 .916 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.718 .282 .718 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.772 .228 .772 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.979 .021 .979 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.928 .072 .928 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.934 .066 .934 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.734 .266 .734 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.696 .304 .696 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.648 .352 .648 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.918 .082 .918 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.939 .061 .939 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.925 .075 .925 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.88 .12 .88 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.774 .226 .774 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.968 .032 .968 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.747 .253 .747 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.667 .333 .667 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.867 .133 .867 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.411 .589 .411 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.405 .595 .405 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.474 .526 .474 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.78 .22 .78 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.791 .209 .791 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.985 .015 .985 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.427 .573 .427 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.388 .612 .388 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.948 .052 .948 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.581 .419 .581 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.704 .296 .704 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.912 .088 .912 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.908 .092 .908 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.623 .377 .623 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.875 .125 .875 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.336 .664 .336 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.818 .182 .818 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.703 .297 .703 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.122 .878 .122 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.3 .7 .3 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.976 .024 .976 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.21 .79 .21 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.166 .834 .166 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.876 .124 .876 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.978 .022 .978 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.457 .543 .457 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.135 .865 .135 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.204 .796 .204 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.782 .218 .782 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.297 .703 .297 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.51 .49 .51 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.988 .012 .988 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.18 .82 .18 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.023 .977 .023 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.117 .883 .117 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.011 .989 .011 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.325 .675 .325 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.511 .489 .511 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.957 .043 .957 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.541 .459 .541 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.612 .388 .612 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.028 .972 .028 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.02 .98 .02 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.088 .912 .088 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.12 .88 .12 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.754 .246 .754 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.899 .101 .899 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.997 .003 .997 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.931 .069 .931 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.424 .576 .424 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.093 .907 .093 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.81 .19 .81 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.18 .82 .18 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.396 .604 .396 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.084 .916 .084 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.25 .75 .25 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.839 .161 .839 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.37 .63 .37 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.097 .903 .097 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.978 .022 .978 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.994 .006 .994 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.885 .115 .885 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.923 .077 .923 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.234 .766 .234 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.969 .031 .969 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.003 .997 .003 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.611 .389 .611 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.585 .415 .585 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.087 .913 .087 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.222 .778 .222 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.491 .509 .491 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.75 .25 .75 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.092 .908 .092 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.984 .016 .984 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.053 .947 .053 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.193 .807 .193 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.245 .755 .245 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.971 .029 .971 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.469 .531 .469 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.384 .616 .384 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.268 .732 .268 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.233 .767 .233 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.908 .092 .908 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.881 .119 .881 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.876 .124 .876 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.17 .83 .17 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.508 .492 .508 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.662 .338 .662 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.854 .146 .854 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.967 .033 .967 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.99 .01 .99 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.471 .529 .471 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.725 .275 .725 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.353 .647 .353 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.954 .046 .954 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.938 .062 .938 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.85 .15 .85 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.973 .027 .973 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.992 .008 .992 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.472 .528 .472 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.591 .409 .591 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.987 .013 .987 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.489 .511 .489 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.898 .102 .898 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.672 .328 .672 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.812 .188 .812 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.607 .393 .607 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.976 .024 .976 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.962 .038 .962 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.967 .033 .967 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.981 .019 .981 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.758 .242 .758 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.955 .045 .955 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.687 .313 .687 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.725 .275 .725 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.85 .15 .85 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.853 .147 .853 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.953 .047 .953 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.991 .009 .991 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.788 .212 .788 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.983 .017 .983 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.947 .053 .947 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.925 .075 .925 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.909 .091 .909 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.857 .143 .857 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.874 .126 .874 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.815 .185 .815 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.919 .081 .919 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.952 .048 .952 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.977 .023 .977 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.963 .037 .963 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.969 .031 .969 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.982 .018 .982 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.959 .041 .959 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.878 .122 .878 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.952 .048 .952 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.969 .031 .969 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.984 .016 .984 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.98 .02 .98 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.983 .017 .983 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.967 .033 .967 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.972 .028 .972 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.992 .008 .992 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.981 .019 .981 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.985 .015 .985 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.99 .01 .99 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(780) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.991 .009 .991 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.987 .013 .987 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.987 .013 .987 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.967 .033 .967 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.974 .026 .974 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.94 .06 .94 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.983 .017 .983 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.88 .12 .88 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.964 .036 .964 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.962 .038 .962 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.969 .031 .969 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.977 .023 .977 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.988 .012 .988 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.949 .051 .949 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.977 .023 .977 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.917 .083 .917 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.985 .015 .985 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.974 .026 .974 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.958 .042 .958 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.972 .028 .972 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.891 .109 .891 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.982 .018 .982 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.954 .046 .954 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.987 .013 .987 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.918 .082 .918 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.722 .278 .722 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.775 .225 .775 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.979 .021 .979 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.929 .071 .929 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.934 .066 .934 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.739 .261 .739 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.7 .3 .7 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.652 .348 .652 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.919 .081 .919 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.941 .059 .941 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.927 .073 .927 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.882 .118 .882 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.775 .225 .775 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.969 .031 .969 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.751 .249 .751 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.669 .331 .669 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.868 .132 .868 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.414 .586 .414 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.408 .592 .408 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.48 .52 .48 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.782 .218 .782 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.794 .206 .794 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.985 .015 .985 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.433 .567 .433 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.393 .607 .393 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.949 .051 .949 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.584 .416 .584 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.708 .292 .708 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.913 .087 .913 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.91 .09 .91 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.626 .374 .626 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.876 .124 .876 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.339 .661 .339 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.822 .178 .822 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.707 .293 .707 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.125 .875 .125 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.303 .697 .303 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.977 .023 .977 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.215 .785 .215 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.17 .83 .17 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.878 .122 .878 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.979 .021 .979 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.463 .537 .463 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.137 .863 .137 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.207 .793 .207 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.786 .214 .786 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.3 .7 .3 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.514 .486 .514 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.989 .011 .989 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.185 .815 .185 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.026 .974 .026 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.119 .881 .119 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.013 .987 .013 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.329 .671 .329 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.515 .485 .515 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.958 .042 .958 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.546 .454 .546 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.617 .383 .617 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.031 .969 .031 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.021 .979 .021 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.09 .91 .09 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.123 .877 .123 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.758 .242 .758 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.902 .098 .902 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.932 .068 .932 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.43 .57 .43 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.094 .906 .094 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.813 .187 .813 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.185 .815 .185 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.401 .599 .401 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.089 .911 .089 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.254 .746 .254 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.842 .158 .842 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.374 .626 .374 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.1 .9 .1 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.979 .021 .979 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.994 .006 .994 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.887 .113 .887 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.925 .075 .925 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.24 .76 .24 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.97 .03 .97 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.006 .994 .006 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.615 .385 .615 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.589 .411 .589 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.091 .909 .091 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.225 .775 .225 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.495 .505 .495 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.754 .246 .754 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.096 .904 .096 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.985 .015 .985 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.055 .945 .055 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.196 .804 .196 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.251 .749 .251 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.971 .029 .971 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.473 .527 .473 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.391 .609 .391 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.273 .727 .273 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.236 .764 .236 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.91 .09 .91 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.883 .117 .883 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.878 .122 .878 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.175 .825 .175 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.511 .489 .511 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.665 .335 .665 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.856 .144 .856 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.968 .032 .968 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.991 .009 .991 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.476 .524 .476 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.727 .273 .727 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.359 .641 .359 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.956 .044 .956 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.939 .061 .939 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.852 .148 .852 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.974 .026 .974 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.992 .008 .992 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.477 .523 .477 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.596 .404 .596 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.988 .012 .988 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.496 .504 .496 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.899 .101 .899 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.676 .324 .676 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.814 .186 .814 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.612 .388 .612 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.976 .024 .976 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.962 .038 .962 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.967 .033 .967 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.981 .019 .981 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.762 .238 .762 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.956 .044 .956 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.693 .307 .693 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.73 .27 .73 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.853 .147 .853 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.855 .145 .855 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.954 .046 .954 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.991 .009 .991 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.792 .208 .792 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.984 .016 .984 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.949 .051 .949 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.927 .073 .927 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.911 .089 .911 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.86 .14 .86 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.876 .124 .876 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.818 .182 .818 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.996 .004 .996 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.921 .079 .921 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.953 .047 .953 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.978 .022 .978 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.963 .037 .963 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.97 .03 .97 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.983 .017 .983 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.96 .04 .96 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.881 .119 .881 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.953 .047 .953 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.97 .03 .97 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.984 .016 .984 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.98 .02 .98 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.984 .016 .984 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.967 .033 .967 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.994 .006 .994 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.987 .013 .987 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.973 .027 .973 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.992 .008 .992 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.982 .018 .982 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.99 .01 .99 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(790) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.992 .008 .992 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.988 .012 .988 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.987 .013 .987 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.968 .032 .968 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.975 .025 .975 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.995 .005 .995 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.941 .059 .941 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.983 .017 .983 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.882 .118 .882 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.965 .035 .965 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.963 .037 .963 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.969 .031 .969 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.978 .022 .978 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.989 .011 .989 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.95 .05 .95 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.977 .023 .977 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.918 .082 .918 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.986 .014 .986 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.975 .025 .975 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.959 .041 .959 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.973 .027 .973 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.893 .107 .893 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.982 .018 .982 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.955 .045 .955 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.987 .013 .987 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.919 .081 .919 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.726 .274 .726 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.778 .222 .778 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.979 .021 .979 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.93 .07 .93 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.935 .065 .935 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.743 .257 .743 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.704 .296 .704 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.655 .345 .655 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.92 .08 .92 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.942 .058 .942 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.928 .072 .928 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.884 .116 .884 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.776 .224 .776 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.986 .014 .986 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.97 .03 .97 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.756 .244 .756 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.672 .328 .672 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.869 .131 .869 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.417 .583 .417 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.411 .589 .411 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.485 .515 .485 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.784 .216 .784 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.796 .204 .796 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.986 .014 .986 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.438 .562 .438 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.397 .603 .397 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.95 .05 .95 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.992 .008 .992 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.586 .414 .586 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.712 .288 .712 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.914 .086 .914 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.912 .088 .912 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.63 .37 .63 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.877 .123 .877 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.342 .658 .342 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.826 .174 .826 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.711 .289 .711 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.128 .872 .128 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.305 .695 .305 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.977 .023 .977 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.22 .78 .22 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.173 .827 .173 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.881 .119 .881 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.979 .021 .979 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.468 .532 .468 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.14 .86 .14 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.21 .79 .21 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.79 .21 .79 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.304 .696 .304 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.518 .482 .518 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.989 .011 .989 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.19 .81 .19 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.028 .972 .028 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.121 .879 .121 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.015 .985 .015 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.333 .667 .333 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.52 .48 .52 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.959 .041 .959 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.552 .448 .552 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.623 .377 .623 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.033 .967 .033 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.022 .978 .022 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.092 .908 .092 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.125 .875 .125 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.762 .238 .762 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.904 .096 .904 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.934 .066 .934 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.436 .564 .436 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.095 .905 .095 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.816 .184 .816 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.189 .811 .189 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.405 .595 .405 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.093 .907 .093 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.257 .743 .257 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.845 .155 .845 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.378 .622 .378 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.102 .898 .102 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.979 .021 .979 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.994 .006 .994 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.889 .111 .889 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.927 .073 .927 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.245 .755 .245 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.97 .03 .97 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.009 .991 .009 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.62 .38 .62 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.593 .407 .593 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.095 .905 .095 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.229 .771 .229 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.5 .5 .5 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.758 .242 .758 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.1 .9 .1 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.985 .015 .985 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.056 .944 .056 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.199 .801 .199 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.257 .743 .257 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.972 .028 .972 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.477 .523 .477 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.398 .602 .398 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.278 .722 .278 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.239 .761 .239 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.912 .088 .912 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.885 .115 .885 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.88 .12 .88 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.179 .821 .179 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.514 .486 .514 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.668 .332 .668 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.858 .142 .858 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.969 .031 .969 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.991 .009 .991 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.48 .52 .48 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.73 .27 .73 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.364 .636 .364 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.957 .043 .957 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.94 .06 .94 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.854 .146 .854 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.975 .025 .975 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.482 .518 .482 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.601 .399 .601 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.988 .012 .988 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.504 .496 .504 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.901 .099 .901 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.68 .32 .68 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.817 .183 .817 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.617 .383 .617 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.976 .024 .976 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.962 .038 .962 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.967 .033 .967 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.981 .019 .981 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.766 .234 .766 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.958 .042 .958 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.698 .302 .698 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.734 .266 .734 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.855 .145 .855 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.858 .142 .858 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.955 .045 .955 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.991 .009 .991 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.796 .204 .796 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.984 .016 .984 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.95 .05 .95 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.928 .072 .928 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.913 .087 .913 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.863 .137 .863 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.878 .122 .878 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.822 .178 .822 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.924 .076 .924 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.954 .046 .954 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.978 .022 .978 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.964 .036 .964 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.97 .03 .97 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.983 .017 .983 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.961 .039 .961 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.883 .117 .883 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.954 .046 .954 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.971 .029 .971 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.985 .015 .985 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.981 .019 .981 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.984 .016 .984 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.968 .032 .968 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.974 .026 .974 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.982 .018 .982 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.99 .01 .99 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(800) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.992 .008 .992 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.988 .012 .988 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.987 .013 .987 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.969 .031 .969 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.975 .025 .975 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.942 .058 .942 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.983 .017 .983 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.884 .116 .884 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.965 .035 .965 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.963 .037 .963 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.97 .03 .97 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.978 .022 .978 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.989 .011 .989 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.951 .049 .951 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.978 .022 .978 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.919 .081 .919 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.986 .014 .986 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.975 .025 .975 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.96 .04 .96 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.973 .027 .973 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.895 .105 .895 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.983 .017 .983 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.955 .045 .955 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.987 .013 .987 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.92 .08 .92 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.73 .27 .73 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.781 .219 .781 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.98 .02 .98 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.931 .069 .931 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.936 .064 .936 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.747 .253 .747 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.707 .293 .707 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.657 .343 .657 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.921 .079 .921 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.943 .057 .943 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.93 .07 .93 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.886 .114 .886 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.777 .223 .777 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.986 .014 .986 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.971 .029 .971 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.76 .24 .76 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.674 .326 .674 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.87 .13 .87 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.42 .58 .42 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.414 .586 .414 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.491 .509 .491 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.785 .215 .785 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.799 .201 .799 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.986 .014 .986 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.443 .557 .443 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.402 .598 .402 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.952 .048 .952 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.589 .411 .589 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.715 .285 .715 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.915 .085 .915 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.914 .086 .914 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.633 .367 .633 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.878 .122 .878 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.345 .655 .345 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.829 .171 .829 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.715 .285 .715 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.131 .869 .131 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.307 .693 .307 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.978 .022 .978 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.224 .776 .224 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.175 .825 .175 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.883 .117 .883 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.98 .02 .98 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.474 .526 .474 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.142 .858 .142 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.212 .788 .212 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.794 .206 .794 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.307 .693 .307 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.522 .478 .522 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.989 .011 .989 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.195 .805 .195 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.031 .969 .031 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.123 .877 .123 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.017 .983 .017 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.337 .663 .337 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.524 .476 .524 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.96 .04 .96 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.557 .443 .557 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.629 .371 .629 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.036 .964 .036 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.024 .976 .024 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.094 .906 .094 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.128 .872 .128 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.766 .234 .766 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.905 .095 .905 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.935 .065 .935 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.442 .558 .442 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.095 .905 .095 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.819 .181 .819 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.194 .806 .194 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.41 .59 .41 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.097 .903 .097 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.26 .74 .26 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.848 .152 .848 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.382 .618 .382 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.997 .003 .997 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.105 .895 .105 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.98 .02 .98 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.994 .006 .994 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.892 .108 .892 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.928 .072 .928 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.25 .75 .25 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.971 .029 .971 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.012 .988 .012 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.624 .376 .624 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.596 .404 .596 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.1 .9 .1 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.232 .768 .232 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.504 .496 .504 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.762 .238 .762 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.104 .896 .104 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.985 .015 .985 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.057 .943 .057 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.202 .798 .202 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.263 .737 .263 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.972 .028 .972 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.481 .519 .481 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.405 .595 .405 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.283 .717 .283 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.242 .758 .242 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.913 .087 .913 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.886 .114 .886 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.882 .118 .882 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.183 .817 .183 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.517 .483 .517 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.67 .33 .67 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.86 .14 .86 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.969 .031 .969 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.991 .009 .991 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.484 .516 .484 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.732 .268 .732 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.369 .631 .369 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.958 .042 .958 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.941 .059 .941 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.856 .144 .856 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.975 .025 .975 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.487 .513 .487 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.605 .395 .605 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.988 .012 .988 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.511 .489 .511 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.902 .098 .902 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.683 .317 .683 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.819 .181 .819 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.622 .378 .622 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.977 .023 .977 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.963 .037 .963 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.967 .033 .967 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.981 .019 .981 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.77 .23 .77 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.994 .006 .994 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.959 .041 .959 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.703 .297 .703 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.738 .262 .738 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.858 .142 .858 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.86 .14 .86 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.956 .044 .956 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.991 .009 .991 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.8 .2 .8 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.985 .015 .985 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.951 .049 .951 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.93 .07 .93 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.915 .085 .915 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.865 .135 .865 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.88 .12 .88 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.825 .175 .825 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.926 .074 .926 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.954 .046 .954 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.979 .021 .979 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.965 .035 .965 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.971 .029 .971 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.984 .016 .984 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.962 .038 .962 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.886 .114 .886 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.955 .045 .955 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.971 .029 .971 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.985 .015 .985 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.981 .019 .981 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.984 .016 .984 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.969 .031 .969 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.974 .026 .974 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.983 .017 .983 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.991 .009 .991 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(810) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.994 .006 .994 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.994 .006 .994 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.992 .008 .992 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.988 .012 .988 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.987 .013 .987 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.97 .03 .97 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.975 .025 .975 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.943 .057 .943 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.984 .016 .984 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.886 .114 .886 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.966 .034 .966 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.964 .036 .964 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.97 .03 .97 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.978 .022 .978 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.989 .011 .989 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.951 .049 .951 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.978 .022 .978 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.92 .08 .92 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.986 .014 .986 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.976 .024 .976 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.961 .039 .961 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.973 .027 .973 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.897 .103 .897 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.983 .017 .983 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.956 .044 .956 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.922 .078 .922 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.733 .267 .733 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.783 .217 .783 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.98 .02 .98 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.931 .069 .931 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.936 .064 .936 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.75 .25 .75 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.711 .289 .711 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.66 .34 .66 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.922 .078 .922 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.944 .056 .944 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.931 .069 .931 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.888 .112 .888 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.778 .222 .778 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.986 .014 .986 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.972 .028 .972 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.764 .236 .764 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.676 .324 .676 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.87 .13 .87 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.422 .578 .422 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.416 .584 .416 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.496 .504 .496 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.787 .213 .787 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.801 .199 .801 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.986 .014 .986 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.448 .552 .448 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.406 .594 .406 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.953 .047 .953 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.591 .409 .591 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.718 .282 .718 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.916 .084 .916 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.997 .003 .997 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.916 .084 .916 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.636 .364 .636 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.88 .12 .88 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.347 .653 .347 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.833 .167 .833 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.718 .282 .718 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.134 .866 .134 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.309 .691 .309 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.978 .022 .978 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.229 .771 .229 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.178 .822 .178 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.885 .115 .885 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.98 .02 .98 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.479 .521 .479 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.144 .856 .144 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.215 .785 .215 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.798 .202 .798 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.31 .69 .31 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.526 .474 .526 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.99 .01 .99 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.199 .801 .199 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.034 .966 .034 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.125 .875 .125 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.019 .981 .019 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.34 .66 .34 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.528 .472 .528 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.961 .039 .961 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.562 .438 .562 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.634 .366 .634 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.038 .962 .038 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.025 .975 .025 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.097 .903 .097 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.13 .87 .13 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.769 .231 .769 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.907 .093 .907 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.937 .063 .937 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.448 .552 .448 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.096 .904 .096 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.821 .179 .821 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.198 .802 .198 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.414 .586 .414 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.101 .899 .101 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.263 .737 .263 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.851 .149 .851 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.385 .615 .385 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.107 .893 .107 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.98 .02 .98 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.894 .106 .894 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.93 .07 .93 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.256 .744 .256 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.972 .028 .972 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.015 .985 .015 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.629 .371 .629 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.6 .4 .6 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.104 .896 .104 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.235 .765 .235 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.508 .492 .508 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.766 .234 .766 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.107 .893 .107 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.986 .014 .986 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.058 .942 .058 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.205 .795 .205 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.269 .731 .269 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.972 .028 .972 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.485 .515 .485 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.411 .589 .411 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.288 .712 .288 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.245 .755 .245 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.915 .085 .915 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.888 .112 .888 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.884 .116 .884 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.187 .813 .187 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.52 .48 .52 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.673 .327 .673 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.862 .138 .862 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.97 .03 .97 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.991 .009 .991 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.488 .512 .488 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.734 .266 .734 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.374 .626 .374 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.959 .041 .959 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.942 .058 .942 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.997 .003 .997 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.857 .143 .857 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.976 .024 .976 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.492 .508 .492 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.61 .39 .61 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.989 .011 .989 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.518 .482 .518 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.903 .097 .903 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.687 .313 .687 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.822 .178 .822 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.627 .373 .627 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.977 .023 .977 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.963 .037 .963 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.968 .032 .968 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.982 .018 .982 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.773 .227 .773 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.96 .04 .96 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.709 .291 .709 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.742 .258 .742 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.86 .14 .86 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.862 .138 .862 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.993 .007 .993 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.957 .043 .957 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.991 .009 .991 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.803 .197 .803 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.985 .015 .985 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.953 .047 .953 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.931 .069 .931 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.917 .083 .917 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.868 .132 .868 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.881 .119 .881 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.828 .172 .828 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.928 .072 .928 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.955 .045 .955 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.979 .021 .979 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.965 .035 .965 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.972 .028 .972 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.984 .016 .984 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.963 .037 .963 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.888 .112 .888 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.957 .043 .957 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.972 .028 .972 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.985 .015 .985 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.981 .019 .981 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.985 .015 .985 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.97 .03 .97 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.988 .012 .988 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.975 .025 .975 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.983 .017 .983 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.991 .009 .991 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.997 .003 .997 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo@;mood2oOl0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ood2oOom0_d00_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000coo@;m00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?om
0_goo@;m00_oo@;m0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo0?loo`3o006
oo`3o003o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?ol0ocoo0?loo`3o0;o00002_oo0?l2o`000003oo/4nol0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ood2oOl000002ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_go
o@;m00Woo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?ol0oco
o0?l00Coo0?l0_l00005ool0o`?o00001?ok1?/00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo0?l0_l000000ooo
0?oo0000o`000007oo/4n`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo/4nook
1?/01ook1?/00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_ol0o`00ol0003on`Ckoo/4n`08oo/4n`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?oj1O[onPGjo`0000?oo`3o0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@05ood2
o@03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003ool0o`00ol0003on`Ckoo/4n`08oo/4
n`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004ooX5nP03o`000?oo0?oo000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o009oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o
o0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00Won`Ck00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000oo/4nook1?/0
2_ok1?/00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008ooX5nP03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o00:oo`3o004o`000?om0_goo@;mood2o@?o0000
3oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00[on`Ck00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_onPGj1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02ool0o`01?l0003oo@;mo`00
0?l00003ooD:m@;o00003?om0_d2o`00013oo0?l00?o0000oo/4nook1?/02ook1?/00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000ooX5n_oj1OX02ooj1OX01?l0003oka3_
onl@koo_4>l5o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00<oo`3o003
o`000?oe2_Gom@[e00Gom@[e0_l00008ood2o@;o00000_oe2_D00ol0003oo0?loo`3o00=oo`3o003
o`000?ok1?_on`Ck00_on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ooj1OX00ol0003oka3_onl@k`07onl@k`Ko00000_oo0?l4o`0000goo0?l00?o0000ooD:mOoe2_D0
1ooe2_D2o`0000Goo@;m00?o0000ooD:mOoe2_D00ooe2_D00ol0003oo0?loo`3o00<oo`3o003o`00
0?ok1?_on`Ck00con`Ck00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ooj1OX00ol0003oka3_onl@k`0<onl@k`?o00001?oh1oP3o`0000Woo0?l00?o
0000ooD:mOoe2_D02_oe2_D2o`000003ood2oOl0003o000000Oom@[e00?o0000oo`3o?ol0o`02ool
0o`00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oka3_onl@k`0=onl@k`03o`000?oh1oSon0Oh00Kon0Oh0ol00005
oo`3o003o`000?oe2_Gom@[e00gom@[e00?o0000ooD:mOoe2_D02?oe2_D00ol0003oo0?loo`3o009
oo`3o003o`000?ok1?_on`Ck00gon`Ck00Co0000ool0oooo0?ooo`3o1Ol00003oo`3o003o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000oonPGj00?o0000onl@koo_4>l03Oo_4>l00ol0003on0OhooP7n00:
ooP7n0?o000000?oo0?lo`000?oe2_D03ooe2_D00ol0003om@[eooD:m@09ooD:m@03o`000?ol0oco
o0?l00Soo0?l00?o0000oo/4nook1?/03_ok1?/3o`0000Soo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooh
1oSo0000ooX5nP0>ooX5nP03o`000?o_4>ooka3_00goka3_00?o0000ooP7n?oh1oP03Ooh1oP00ol0
003om@[eooD:m@0?ooD:m@03o`000?oe2_Gom@[e00[om@[e2ol0000;oo/4n`Go00003?ol0o`00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo0?lo`000?oo0?oo0000
00SooP7n0ol00005ooP7n003o`000?oj1O[onPGj00conPGj00?o0000onl@koo_4>l03Oo_4>l00ol0
003on0OhooP7n00=ooP7n0;o00004?oe2_D00ol0003om@[eooD:m@0:ooD:m@03o`000?oc3??ol`cc
00Ool`cc00?o0000oo/4nook1?/00_ok1?/7o`0000ComPWf00?o0000oo`3o?ol0o`02_ol0o`00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo0?loo`3o?ol0o`2o`00
00GooP7n0ol00009ooP7n0;o00002ooj1OX00ol0003oka3_onl@k`0=onl@k`03o`000?oh1oSon0Oh
00gon0Oh00Co0000on<LhooS7>?o00003ooe2_D00ol0003om@[eooD:m@09ooD:m@03o`000?oc3??o
l`cc00Wol`cc1?l0000;ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ooP7no`000002o`00
00con0Oh00Co0000onXEj_l0003o00002Ooj1OX00ol0003oka3_onl@k`0=onl@k`03o`000?oh1oSo
n0Oh00gon0Oh00Go0000on<LhooS7>?ohacSo`00000=ooD:m@03o`000?oe2_Gom@[e00[om@[e00?o
0000oo<<looc3?<02Ooc3?<00ol0003omPWfooH9mP0<ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003on0OhooP7n00<ooP7n003o`000?oZ5N[ojQGZ00;ojQGZ0_l00007ooX5nP03o`000?o_4>oo
ka3_00coka3_00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ohacSon<Lh`03on<Lh`03o`000?oe2_Go
m@[e00[om@[e00?o0000ooD:mOoe2_D02_oe2_D00ol0003ol`ccoo<<l`09oo<<l`03o`000?of2OKo
mPWf00comPWf00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo0?loo`3o006oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000onXE
j_oZ5NX01OoZ5NX00ol0003onPGjooX5nP03ooX5nP03o`000?o_4>ooka3_00goka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003ohacSon<Lh`04on<Lh`03o`000?oe2_Gom@[e00Wom@[e00?o0000ooD:
mOoe2_D02Ooe2_D00ol0003ol`ccoo<<l`0:oo<<l`03o`000?of2OKomPWf00comPWf00?o0000oo`3
o?ol0o`02ool0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o007oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000onXEj_oZ5NX01_oZ5NX2o`0000?o
nPGj00?o0000onl@koo_4>l03Oo_4>l00ol0003on0OhooP7n00<ooP7n003o`000?oS7>?ohacS00Ko
hacS00?o0000ooD:mOoe2_D02?oe2_D00ol0003om@[eooD:m@09ooD:m@03o`000?oc3??ol`cc00[o
l`cc00?o0000ooH9m_of2OH03?of2OH00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on0OhooP7n00:ooP7n003o`00
0?oZ5N[ojQGZ00WojQGZ0_l000000ooj1O[o0000onl@k`0<onl@k`?o00003_oh1oP00ol0003ohacS
on<Lh`07on<Lh`03o`000?oe2_Gom@[e00Oom@[e00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ol`cc
oo<<l`0;oo<<l`03o`000?of2OKomPWf00comPWf00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003on0OhooP7
n009ooP7n003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000onl@koo_4>l02_o_4>l2o`0000?ofBKI00?o
0000ooP7n?oh1oP02_oh1oP00ol0003ohacSon<Lh`09on<Lh`03o`000?oe2_Gom@[e00Kom@[e00?o
0000ooD:mOoe2_D02?oe2_D00ol0003ol`ccoo<<l`0<oo<<l`03o`000?of2OKomPWf00comPWf00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ojQGZonXEjP0<onXEjP03o`000?o_4>ooka3_00Soka3_0_l00006omTVf@;o00002_oh1oP0
0ol0003ohacSon<Lh`0:on<Lh`03o`000?oe2_Gom@[e00Gom@[e00?o0000ooD:mOoe2_D02?oe2_D0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?of2OKomPWf00comPWf00?o0000oo`3o?ol0o`02ool0o`0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000onXEj_oZ5NX03_oZ5NX00ol0003oka3_onl@k`04
onl@k`?o00002_oI9]T00ol0003on0OhooP7n007ooP7n003o`000?oS7>?ohacS00_ohacS00?o0000
ooD:mOoe2_D00ooe2_D00ol0003om@[eooD:m@09ooD:m@03o`000?oc3??ol`cc00col`cc00?o0000
ooH9m_of2OH03?of2OH00ol0003oo0?loo`3o00;oo`3o0;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000onXEj_oZ5NX03ooZ5NX01?l0
003oka3_onl@koo_4>l2o`0000kofBKI0_l00006ooP7n003o`000?oS7>?ohacS00gohacS00?o0000
ooD:mOoe2_D00_oe2_D00ol0003om@[eooD:m@08ooD:m@03o`000?oc3??ol`cc00col`cc0ol0000=
ooH9mP03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo0?l00?o0000ooP7n?oh1oP01_oh1oP00ol0003ojQGZonXEjP0@onXEjPCo00004_oI9]T00ol0
003on0OhooP7n003ooP7n003o`000?oS7>?ohacS00kohacS00Go0000ooD:mOoe2_Gom@[eo`000005
ooD:m@Oo00003?oc3?<01Ol0003okA;]ondBkOo]4^go000000comPWf00?o0000oo`3o?ol0o`02?ol
0o`3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo0?l00?o0000ooP7n?oh1oP01_oh1oP00ol0003ojQGZonXEjP0=
onXEjP?o000000CoeB[Eo`000?l0003o00004ooI9]T2o`0000;on0Oh00?o0000on<LhooS7><04?oS
7><00ol0003om@[eo`000006o`0000Oog2?L00?o0000oo<<looc3?<02?oc3?<00ol0003okA;]ondB
k@03ondBk@;o00002?of2OH3o`0000Koo0?l1?l00002oo/4n`03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?of2OH3o`0000goo0?l00?o0000ooP7n?oh1oP01?oh1oP00ol0003ojQGZonXE
jP0;onXEjP?o00000ooE:]D01Ol0003oc3?<o`000?nRGJ;o000001CofBKI00?o0000ooP7n?l00000
4ooS7><00ol0003og2?Lom`Sg00=om`Sg003o`000?oc3??ol`cc00Gol`cc0_l00008ondBk@03o`00
0?of2OKomPWf00Go00000ood2o@00ol0003oo0?loo`3o003o`0000Oon`Ck00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000ComPWf0ol0000:oo`3o003o`000?oh1oSon0Oh00?on0Oh
00?o0000onXEj_oZ5NX02OoZ5NX3o`0000GoeB[E00Co0000ol`cc?o<<lco00000_nRGJ800ol0003o
fBKIomTVf@0BomTVf@03o`000?oS7>?ohacS01;ohacS00?o0000om`Sg?oL8m`03_oL8m`00ol0003o
l`ccoo<<l`03oo<<l`03o`000?o]4^gokA;]00WokA;]0_l00009oo@;m0;o00002_ok1?/00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooH9mP;o00001ool0o`5o`0000;o
n0Oh00?o0000onXEj_oZ5NX01_oZ5NX3o`0000SoeB[E00Co0000ol`cc?o<<lco00000onRGJ800ol0
003ofBKIomTVf@0AomTVf@03o`000?oS7>?ohacS017ohacS00?o0000om`Sg?oL8m`04?oL8m`01Ol0
003ol`ccoo<<looc3??o000000cokA;]00?o0000oo@;m?od2o@02?od2o@00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooH9m_of2OH01oof2OH3o`00
0004oo`3o?l0003o0000o`0000GokQ7^0_l00006onXEjP?o00002_oE:]D01Ol0003oc3?<ol`cc?o<
<lco000000CoXUfR00?o0000omTVfOoI9]T04?oI9]T00ol0003ohacSon<Lh`0Aon<Lh`03o`000?oL
8mcog2?L017og2?L00?o0000oo<<lol000003Oo]4^d00ol0003om0_doo@;m008oo@;m003o`000?ok
1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooH9m_of2OH02_of2OH00ol0003okQ7^onhAkP08onhAkP03o`000?oZ5N[ojQGZ00?o00003OoE:]D0
1Ol0003oc3?<ol`cc?o<<lco000000GoXUfR00?o0000omTVfOoI9]T03ooI9]T00ol0003ohacSon<L
h`0Aon<Lh`03o`000?oL8mcog2?L01;og2?L00?o0000ondBkOo]4^d03?o]4^d00ol0003om0_doo@;
m008oo@;m003o`000?ok1?_on`Ck00_on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o^4NkokQ7^00WokQ7^0_l0000?omDZe@03o`000?o<<lco
c3?<00;oc3?<00?o0000oj9MX_nRGJ801?nRGJ800ol0003ofBKIomTVf@0=omTVf@?o00004OoS7><0
0ol0003og2?Lom`Sg00Com`Sg003o`000?o]4^gokA;]00_okA;]00?o0000oo@;m?od2o@02Ood2o@0
0ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o^4NkokQ7^00WokQ7^00?o0000omDZeOoE:]D03OoE:]D0
0ol0003oc3?<ol`cc003ol`cc003o`000?nRGJ;oXUfR00GoXUfR00?o0000omTVfOoI9]T02_oI9]T2
o`0000?oVFJI00?o0000on<LhooS7><03_oS7><00ol0003og2?Lom`Sg00Com`Sg003o`000?o]4^go
kA;]00_okA;]00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_omPWf00?o0000onhA
k_o^4Nh02oo^4Nh00ol0003oeB[EomDZe@0<omDZe@03o`000?o<<lcoc3?<00?oc3?<00?o0000oj9M
X_nRGJ801_nRGJ800ol0003ofBKIomTVf@07omTVf@;o00001_nIIYT2o`0000kohacS00?o0000om`S
g?oL8m`04ooL8m`00ol0003okA;]ondBk@0;ondBk@03o`000?od2oCom0_d00Wom0_d00?o0000oo/4
nook1?/03?ok1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_omPWf00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oeB[EomDZe@0;omDZ
e@03o`000?o<<lcoc3?<00Coc3?<00?o0000oj9MX_nRGJ801onRGJ800ol0003ofBKIomTVf@05omTV
f@03o`000?nIIYWoVFJI00SoVFJI00?o0000on<LhooS7><02_oS7><00ol0003og2?Lom`Sg00Dom`S
g003o`000?o]4^gokA;]00_okA;]00?o0000oo@;m?od2o@02Ood2o@00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_omPWf00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oeB[EomDZe@0;omDZe@03o`000?o<<lcoc3?<
00Coc3?<00?o0000oj9MX_nRGJ802?nRGJ800ol0003ofBKIomTVf@02omTVf@;o00003?nIIYT2o`00
00[ohacS00?o0000om`Sg?oL8m`05?oL8m`00ol0003okA;]ondBk@0;ondBk@03o`000?od2oCom0_d
00Wom0_d00?o0000oo/4nook1?/03Ook1?/00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooH9m_of2OH02?of2OH00ol0003okQ7^onhAkP0<onhAkP03
o`000?oE:]GoeB[E00WoeB[E00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oXUfRoj9MXP09oj9MXP04
o`000?oI9]Wo0000o`00013oVFJI0_l00008on<Lh`03o`000?oL8mcog2?L01Cog2?L0ol0000;ondB
k@03o`000?od2oCom0_d00Wom0_d00?o0000oo/4nook1?/03Ook1?/01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooH9
m_of2OH02?of2OH00ol0003okQ7^onhAkP0;onhAkP;o00002_oE:]D00ol0003oc3?<ol`cc006ol`c
c003o`000?nRGJ;oXUfR00[oXUfR00?o0000oiUVVOnIIYT04_nIIYT00ol0003ohacSon<Lh`04on<L
h`03o`000?oL8mcog2?L01Gog2?L00?o0000om</dooC;=<01Ol00005ondBk@03o`000?od2oCom0_d
00[om0_d00?o0000oo/4nook1?/03_ok1?/3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooH9m_of2OH01oof2OH00ol0003okQ7^onhAkP0;onhAkP04
o`000?o3?<?o`cc3o`0000WoeB[E00?o0000ol`cc?o<<l`01_o<<l`00ol0003oXUfRoj9MXP0:oj9M
XP03o`000?nIIYWoVFJI01?oVFJI0_l00003on<Lh`Co00005?oL8m`00ol0003odbcCom</d`06om</
d`Co000000?okA;]o`000?od2o@02ood2o@00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooH9m_of
2OH01oof2OH00ol0003okQ7^onhAkP09onhAkP;o00001?o3?<<00ol0003oeB[EomDZe@05omDZe@03
o`000?o<<lcoc3?<00Ooc3?<00?o0000oj9MX_nRGJ802_nRGJ800ol0003oVFJIoiUVV@0EoiUVV@03
o`000?oS7>?o000000Co[e2_0ol0000@om`Sg003o`000?oC;=?odbcC00_odbcC0_l0000<oo@;m003
o`000?ok1?_on`Ck00con`Ck0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?of2OKomPWf00OomPWf00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o`cc3
ol<l``05ol<l``03o`000?oE:]GoeB[E00CoeB[E00?o0000ol`cc?o<<l`01oo<<l`00ol0003oXUfR
oj9MXP0:oj9MXP03o`000?nIIYWoVFJI01KoVFJI00?o0000ojm@[on_D:l01_n_D:l3o`0000cog2?L
00?o0000om</dooC;=<03OoC;=<00ol0003om0_doo@;m009oo@;m0Go00002Ook1?/2o`000003ood2
oOl0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooH9m_of2OH01_of
2OH00ol0003okQ7^onhAkP07onhAkP03o`000?o3?<?o`cc300Oo`cc300?o0000omDZeOoE:]D00_oE
:]D00ol0003oc3?<ol`cc008ol`cc003o`000?nRGJ;oXUfR00WoXUfR00?o0000oiUVVOnIIYT05onI
IYT00ol0003o[e2_ojm@[`09ojm@[`?o00002OoL8m`00ol0003odbcCom</d`0>om</d`Ko00001?od
2o@00ol0003on@KiooT6n@03ooT6n@Go00000_ok1?/2o`0000Coo@;m00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?ol0ocoo0?loo`3o?l000002ook1?/00ol0003omPWfooH9mP06ooH9mP03o`000?o^
4NkokQ7^00GokQ7^0_l0000;ol<l``04o`000?oE:]GoeB[Eo`0000_oc3?<00?o0000oj9MX_nRGJ80
2OnRGJ800ol0003oVFJIoiUVV@0FoiUVV@03o`000?n_D:oo[e2_00go[e2_0ol00005om`Sg003o`00
0?oC;=?odbcC00oodbcC00?o0000on<LhooS7><00ooS7><4o`0000_on@Ki0_l00006ood2o@03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o002oo`3o0ko00001_of2OH00ol0003okQ7^onhA
kP05onhAkP03o`000?o3?<?o`cc300co`cc300?o0000omDZeOl000002oo<<l`00ol0003oXUfRoj9M
XP07oj9MXP?o00006?nIIYT00ol0003o[e2_ojm@[`0@ojm@[`?o000000?og2?Lo`000?oC;=<04?oC
;=<00ol0003ohacSon<Lh`07on<Lh`03o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom
0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005oo`3o003o`000?og2?Oom`Sg00_om`Sg0_l00004
ooH9mP03o`000?o^4NkokQ7^00?okQ7^0_l0000@ol<l``03o`000?o<<lcoc3?<00[oc3?<00?o0000
oj9MX_nRGJ800onRGJ84o`0000;oLXeb00?o0000oiUVVOnIIYT05OnIIYT00ol0003o[e2_ojm@[`0D
ojm@[`03o`000?oC;=?odbcC013odbcC00?o0000on<LhooS7><01ooS7><00ol0003on@KiooT6n@0:
ooT6n@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Goo0?l00?o0000ooL8moog2?L03Oog2?L6o`0000?okQ7^00?o0000ol<l`oo3?<<04?o3?<<00ol0
003oc3?<ol`cc00:ol`cc003o`000?nRGJ;o000000?o00001ombSG800ol0003oVFJIoiUVV@0DoiUV
V@03o`000?n_D:oo[e2_01Co[e2_00?o0000om</dooC;=<03ooC;=<00ol0003ohacSon<Lh`08on<L
h`03o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oU6^GoiA[U00?o
iA[U00?o0000onhAk_l000004oo3?<<4o`0000Woc3?<0_l0000<og:=LP03o`000?nIIYWoVFJI01?o
VFJI00?o0000ojm@[on_D:l05On_D:l00ol0003odbcCom</d`0>om</d`03o`000?oS7>?ohacS00So
hacS00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooL8moog2?L02oog2?L00ol0003oiA[UonDJi@05onDJi@03o`00
0?o3?<?o`cc301;o`cc300Co0000ogZ5N_mjQG[oNXEj1Ol00003ol`cc003o`000?mbSG;oLXeb00go
LXeb0ol0000@oiUVV@;o00006?n_D:l00ol0003odbcCom</d`0=om</d`03o`000?oS7>?ohacS00Wo
hacS00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo0?l00?o0000ooL8moog2?L02_og2?L00ol0003oiA[UonDJi@06onDJi@03o`00
0?o3?<?o`cc3017o`cc300?o0000ogZ5N_mjQGX01omjQGX3o`00013oLXeb00?o0000od6n@Om1_T40
1Ol00009oiUVV@;o000000?oJIIYo`000?n_D:l05on_D:l00ol0003odbcCom</d`0=om</d`03o`00
0?oS7>?ohacS00WohacS00?o0000ooT6nOoi1_T02?oi1_T2o`0000[oo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8
m`0:ooL8m`03o`000?oU6^GoiA[U00OoiA[U00?o0000ol<l`oo3?<<03oo3?<<00ol0003oNXEjogZ5
NP0:ogZ5NP03o`000?mbSG;oLXeb00goLXeb00?o0000od6n@Om1_T401_m1_T44o`0000CoVFJI00?o
0000ofVFJOmYUVT00_mYUVT00ol0003o[e2_ojm@[`0Fojm@[`03o`000?oC;=?odbcC00_odbcC00?o
0000on<LhooS7><02ooS7><00ol0003on@KiooT6n@06ooT6n@03o`000?ol0oco000000[oo@;m00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02?ol0o`=
o`0000[oiA[U00?o0000ol<l`oo3?<<03oo3?<<00ol0003oNXEjogZ5NP0;ogZ5NP03o`000?mbSG;o
LXeb00coLXeb00?o0000od6n@Om1_T402_m1_T44o`0000GoJIIY00?o0000ojm@[on_D:l05_n_D:l0
0ol0003odbcCom</d`0:om</d`03o`000?oS7>?ohacS00cohacS00?o0000ooT6nOoi1_T01?oi1_T2
o`0000?oo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?of2OKomPWf00WomPWf00?o0000onDJ
iOoU6^D02OoU6^D00ol0003o`cc3ol<l``0=ol<l``03o`000?mjQG[oNXEj00coNXEj00?o0000og:=
L_mbSG803?mbSG800ol0003o@Ki1od6n@@0;od6n@@03o`000?m4^dCo000000KoJIIY00?o0000ojm@
[on_D:l05_n_D:l00ol0003odbcCom</d`09om</d`03o`000?oS7>?ohacS00cohacS00?o0000ooT6
nOoi1_T00ooi1_T00ol0003oo0?loo`3o003oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003o
mPWfooH9mP08ooH9mP03o`000?oU6^GoiA[U00_oiA[U00?o0000ol<l`oo3?<<02?o3?<<4o`0000oo
NXEj00?o0000og:=L_mbSG802ombSG800ol0003o@Ki1od6n@@0;od6n@@04o`000?m4^dCoA;]4o`00
00OoJIIY00?o0000ojm@[on_D:l05On_D:l00ol0003odbcCom</d`08om</d`03o`000?oS7>?ohacS
00gohacS00?o0000ooT6nOoi1_T00_oi1_T00ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m
00Ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo`3o?ol
0o`01Ool0o`00ol0003omPWfooH9mP08ooH9mP03o`000?oU6^GoiA[U00_oiA[U00?o0000ol<l`oo3
?<<00oo3?<<5o`0000?oOX5n00?o0000ogZ5N_mjQGX03_mjQGX00ol0003oLXebog:=LP0:og:=LP03
o`000?m1_T7o@Ki100[o@Ki100Go0000odBkA?m4^dCoA;]4o`000007ofVFJ@03o`000?n_D:oo[e2_
01Go[e2_00?o0000om</dooC;=<02?oC;=<00ol0003ohacSon<Lh`0=on<Lh`03o`000?oi1_Won@Ki
00;o00002?ol0o`00ol0003oo@;mood2o@08ood2o@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooH9m_of2OH02?of2OH00ol0003oiA[UonDJi@0<onDJi@Go00002OmnPGh00ol0003o
NXEjogZ5NP0<ogZ5NP;o00003?mbSG800ol0003o@Ki1od6n@@0:od6n@@05o`000?m4^dCoA;]4odBk
A?l000002?mYUVT00ol0003o[e2_ojm@[`0Dojm@[`?o00001ooC;=<00ol0003ohacSon<Lh`0>on<L
h`03o`000?oi1_Wo000000_oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o004oo`3o003o`000?of2OKomPWf00Oo
mPWf00?o0000onDJiOoU6^D03?oU6^D01?l0003o_cnooklo_ol0000;ogj1OP03o`000?mjQG[oNXEj
00_oNXEj00Co0000oc;=<_lbcC;o00002_mbSG800ol0003o@Ki1od6n@@0:od6n@@03o`000?m4^dCo
A;]400;oA;]400?o0000ofVFJOmYUVT01_mYUVT00ol0003o[e2_ojm@[`0Aojm@[`?o00000oneB[D0
0ol0003odbcCom</d`04om</d`03o`000?oS7>?ohacS00gohacS1?l0000;oo`3o003o`000?om0_go
o@;m00Goo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo`3
o?ol0ocoo0?l1?l00008ooH9mP03o`000?oU6^GoiA[U00_oiA[U00?o0000oklo_ono?kl00_no?kl0
0ol0003oOX5nogj1OP08ogj1OP03o`000?mjQG[oNXEj00[oNXEj00?o0000oc;=<_lbcC800_lbcC80
0ol0003oLXebog:=LP03og:=LPGo00002om1_T400ol0003oA;]4odBkA003odBkA003o`000?mYUVWo
JIIY00OoJIIY00?o0000ojm@[on_D:l03_n_D:l2o`0000Oo]DZe00?o0000om</dooC;=<00_oC;=<0
0ol0003ohacSon<Lh`0=on<Lh`03o`000?oh1oSon0Oh00;on0Oh00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo@;mood2o@03ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oh1oP00ol0003omPWfooH9mP05ooH9mP03o`000?oU6^GoiA[U00[oiA[U00?o0000oklo
_ono?kl00ono?kl00ol0003oOX5nogj1OP09ogj1OP03o`000?mjQG[oNXEj00SoNXEj00?o0000oc;=
<_lbcC801?lbcC85o`0000Co</db00?o0000od6n@Om1_T402Om1_T400ol0003oA;]4odBkA003odBk
A003o`000?mYUVWoJIIY00SoJIIY00?o0000ojm@[on_D:l02_n_D:l3o`0000[o]DZe00Go0000om</
dooC;=?odbcCo`00000>on<Lh`03o`000?oh1oSon0Oh00Con0Oh0_l00009oo`3o003o`000?om0_go
o@;m00;oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooP7
n?oh1oP01Ooh1oP00ol0003omPWfooH9mP03ooH9mP03o`000?oU6^GoiA[U00[oiA[U00?o0000oklo
_ono?kl01?no?kl00ol0003oOX5nogj1OP09ogj1OP03o`000?mjQG[oNXEj00OoNXEj00?o0000oc;=
<_lbcC801OlbcC800ol0003o</dboc;=<P07oc;=<P03o`000?m1_T7o@Ki100Oo@Ki100?o0000odBk
A?m4^d@01?m4^d@00ol0003oJIIYofVFJ@08ofVFJ@03o`000?n_D:oo[e2_00So[e2_0_l0000>okE:
]@Co00003?oS7><2o`0000Won0Oh00?o0000oo`3o?ol0o`01ool0o`01?l0003oo@;mood2oOl0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on0OhooP7n007ooP7n0;o00000oof2OH00ol0
003oiA[UonDJi@09onDJi@03o`000?no?koo_cno00Ko_cno00?o0000ogj1O_mnPGh02OmnPGh00ol0
003oNXEjogZ5NP05ogZ5NP03o`000?lbcC;o</db00Ko</db00?o0000oc;=<_lbcC802?lbcC800ol0
003o@Ki1od6n@@06od6n@@03o`000?m4^dCoA;]400CoA;]400?o0000ofVFJOmYUVT02OmYUVT4o`00
00?o[e2_0ol0000@okE:]@05o`000?oQ7^7ohAkQon4NhOl000002_oS7><00ol0003on0OhooP7n00:
ooP7n0Ko00000ool0o`00ol0003oo@;mo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003on0OhooP7n00:ooP7n004o`000?of2OKomPWfo`0000[oiA[U00?o0000oklo_ono?kl01ono?kl0
0ol0003oOX5nogj1OP09ogj1OP03o`000?mjQG[oNXEj00CoNXEj00?o0000oc;=<_lbcC801olbcC80
0ol0003o</dboc;=<P08oc;=<P;o00001_m1_T400ol0003oA;]4odBkA005odBkA003o`000?mYUVWo
JIIY00WoJIIY00Co0000ohAkQ?n4NhCoQ7^40ol0000BokE:]@03o`000?oQ7^7ohAkQ00?ohAkQ0_l0
0006on<Lh`;o00003Ooh1oP00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on0OhooP7n00<ooP7n0;o00002_oU6^D00ol0003o_cnooklo_`08oklo_`03o`000?mnPGko
OX5n00[oOX5n00?o0000ogZ5N_mjQGX00_mjQGX00ol0003o</dboc;=<P08oc;=<P03o`000?lbcC;o
</db00Ko</db0_l00002oaWV6@03o`000?m1_T7o@Ki100;o@Ki100?o0000odBkA?m4^d@01_m4^d@0
0ol0003oJIIYofVFJ@08ofVFJ@03o`000?n4NhCoQ7^400CoQ7^400?o0000okE:]OneB[D03oneB[D0
0ol0003ohAkQon4Nh@06on4Nh@;o00000ooS7><00ol0003on0OhooP7n00=ooP7n003o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oh1oSon0Oh
00kon0Oh00?o0000onDJiOoU6^D01ooU6^D00ol0003o_cnooklo_`0:oklo_`03o`000?mnPGkoOX5n
00WoOX5n00Go0000ogZ5N_mjQG[oNXEjo`00000;oc;=<P03o`000?lbcC;o</db00Co</db0_l00005
oaWV6@05o`000?m1_T7o@Ki1od6n@Ol000002?m4^d@00ol0003oJIIYofVFJ@08ofVFJ@03o`000?n4
NhCoQ7^400GoQ7^400?o0000okE:]OneB[D03_neB[D00ol0003ohAkQon4Nh@08on4Nh@03o`000?oS
7>?o000000oon0Oh00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017on0Oh00?o0000onDJiOoU6^D01_oU6^D00ol0003o_cno
oklo_`0;oklo_`03o`000?mnPGkoOX5n00WoOX5n00Co0000ogZ5N_mjQG[o00003?lbcC800ol0003o
</dboc;=<P02oc;=<P;o00002?lIiQT00ol0003o@Ki1o`000009odBkA003o`000?mYUVWoJIIY00So
JIIY00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003o]DZeokE:]@0=okE:]@03o`000?oQ7^7ohAkQ00[o
hAkQ00?o0000ooP7n?oh1oP03_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooP7n003o`00
0?oU6^GoiA[U00CoiA[U00?o0000oklo_ono?kl03?no?kl00ol0003oOX5nogj1OP0:ogj1OP?o0000
3?lbcC800ol0003o</dboc;=<P02o`0000_o6NHI00?o0000odBkA?m4^d@02?m4^d@00ol0003oJIIY
ofVFJ@07ofVFJ@03o`000?n4NhCoQ7^400OoQ7^400?o0000okE:]OneB[D03?neB[D00ol0003ohAkQ
on4Nh@0;on4Nh@;o00003_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d00oom0_d00ol0003on0OhooP7n00?ooP7n0?o00000ooU
6^D00ol0003o_cnooklo_`0>oklo_`03o`000?mnPGkoOX5n00SoOX5n00Co0000oc[5>_ljaC[o>/Dj
0_l0000:oc;=<P?o00003OlIiQT00ol0003oA;]4odBkA008odBkA003o`000?mYUVWoJIIY00OoJIIY
00?o0000ohAkQ?n4Nh@01on4Nh@00ol0003o]DZeokE:]@0;okE:]@03o`000?oQ7^7ohAkQ00cohAkQ
00?o0000oo`3o?l000000_l0000:ooP7n003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00con0Oh0_l0
0003oo4>l@03o`000?oU6^Go0000017o_cno00?o0000ogj1O_mnPGh01omnPGh00ol0003o>/Djoc[5
>P04oc[5>P;o00002?lbcC800ol0003o6NHIoaWV6@0>oaWV6@;o00002?m4^d@00ol0003oJIIYofVF
J@06ofVFJ@03o`000?n4NhCoQ7^400WoQ7^400?o0000okE:]OneB[D02OneB[D00ol0003ohAkQon4N
h@0=on4Nh@03o`000?ol0ocoo0?l00;oo0?l0ol00007ooP7n003o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oh1oSo
n0Oh00Won0Oh0_l00006oo4>l@03o`000?no?koo_cno013o_cno00?o0000ogj1O_mnPGh01_mnPGh0
0ol0003o>/Djoc[5>P07oc[5>P03o`000?lbcC;o</db00Co</db0ol0000>oaWV6@03o`000?lJiA[o
6^DJ00?o00001Om4^d@00ol0003oJIIYofVFJ@06ofVFJ@03o`000?n4NhCoQ7^400[oQ7^400?o0000
okE:]OneB[D02?neB[D00ol0003ohAkQon4Nh@0=on4Nh@03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo@;mood2o@06ood2o@03o`000?oh1oSon0Oh00Gon0Oh0ol00008oo4>l@03o`000?no?koo_cno
017o_cno00Co0000ogj1O_mnPGkoOX5n1?l0000;oc[5>P;o000000Co</dbo`000?l0003o00000ol9
mPT2o`0000_o6NHI00?o0000oa[U6_lJiAX01?lJiAX2o`0000?oA;]400?o0000ofVFJOmYUVT01_mY
UVT00ol0003oQ7^4ohAkQ00:ohAkQ003o`000?neB[Go]DZe00Oo]DZe00?o0000on4NhOoQ7^403_oQ
7^400ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00;on0Oh0_l0000<oo4>l@03o`000?no?koo
_cno013o_cno1?l00003og:=LP03o`000?ljaC[o>/Dj00_o>/Dj00?o0000o`Wf2Ol9mPT01_l9mPT0
0ol0003o6NHIoaWV6@07oaWV6@03o`000?lJiA[o6^DJ00Oo6^DJ3?l0000>ohAkQ003o`000?neB[Go
]DZe00Ko]DZe00?o0000on4NhOoQ7^403_oQ7^400ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Woo@;m00Co0000ooP7
n?l0003o00003_oa3_400ol0003o_cnooklo_`0?oklo_`03o`000?mbSG;oLXeb00KoLXeb00?o0000
oc[5>_ljaCX02_ljaCX00ol0003o2OH9o`Wf2@07o`Wf2@;o00001_lIiQT00ol0003o6^DJoa[U6P08
oa[U6P03o`000?m9]TWoBKI900SoBKI900?o0000ohAkQ?n4Nh@03?n4Nh@00ol0003o]DZeokE:]@05
okE:]@03o`000?oQ7^7ohAkQ00oohAkQ0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_403_oa3_400ol0
003o_cnooklo_`0>oklo_`03o`000?mbSG;oLXeb00OoLXeb00?o0000oc[5>_ljaCX02_ljaCX00ol0
003o2OH9o`Wf2@09o`Wf2@;o00000olIiQT00ol0003o6^DJoa[U6P09oa[U6P03o`000?m9]TWoBKI9
00WoBKI900?o0000ohAkQ?n4Nh@02_n4Nh@4o`0000Co]DZe00?o0000on4NhOoQ7^404?oQ7^401?l0
003on`Cko`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_403ooa3_4@o`0000[oLXeb00?o0000oc[5
>_ljaCX02OljaCX00ol0003o2?L8o`00000<o`Wf2@05o`000?lIiQWo0000o`?l0ol000002_lJiAX0
0ol0003oBKI9odVfB@09odVfB@03o`000?n4NhCoQ7^400OoQ7^40ol00004oj1OX0?o000000?o]DZe
o`000?oQ7^404OoQ7^401?l0003on`Ckoo/4nook1?/2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ood2oOom0_d02_om0_d00ol0003ol@kaoo4>l@0?
oo4>l@03o`000?nfBKKo]TVf00co]TVf00?o0000og:=L_mbSG802OmbSG800ol0003o>/Djoc[5>P07
oc[5>P04o`000?l8m`So2?L8o`0000go2OH900Go0000o`?l0ol3o0?o0o`3o`000009oa[U6P03o`00
0?m9]TWoBKI900[oBKI900?o0000ohAkQ?n4Nh@00on4Nh@3o`0000[oX5nP00?o0000on4NhOoQ7^40
4?oQ7^400ol0003on`Ckoo/4n`04oo/4n`;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo@;m00?o0000oo4>lOoa3_403ooa3_400ol0003o]TVfokI9]P0<okI9]P03o`000?mb
SG;oLXeb00WoLXeb00?o0000oc[5>_ljaCX01_ljaCX00ol0003o2?L8o`Sg2002o`Sg2003o`000?l9
mPWo2OH900[o2OH900?o0000o`?l0ol3o0<00_l3o0<00ol0003o6^DJoa[U6P06oa[U6P03o`000?m9
]TWoBKI900[oBKI900?o0000ohAkQ?n4Nh@00ol0000=oj1OX003o`000?oQ7^7ohAkQ013ohAkQ00?o
0000oo/4nook1?/01_ok1?/2o`0000Woo0?l0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003ol@kaoo4>l@0=oo4>l@?o00003onfBKH0
0ol0003oLXebog:=LP08og:=LP03o`000?ljaC[o>/Dj00Go>/Dj00?o0000o`Sg2?l8m`P00ol8m`P0
0ol0003o2OH9o`Wf2@0:o`Wf2@03o`000?l3o0?o0o`300?o0o`300?o0000oa[U6_lJiAX01OlJiAX0
0ol0003oBKI9odVfB@0;odVfB@;o00004OnPGj000ol0003ohAkQon4Nh@0?on4Nh@03o`000?ok1?_o
n`Ck00Son`Ck0_l00007oo`3o003o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ood2oOom0_d02?om0_d00ol0003ol@kaoo4>l@09oo4>l@Go00000_oR7N800ol0
003o]TVfokI9]P0=okI9]P03o`000?mbSG;oLXeb00WoLXeb00?o0000oc[5>_ljaCX01?ljaCX00ol0
003o2?L8o`Sg2004o`Sg2003o`000?l9mPWo2OH900So2OH900?o0000o`?l0ol3o0<01Ol3o0<00ol0
003o6^DJoa[U6P04oa[U6P03o`000?m9]TWoBKI900_oBKI900?o0000oj1OX?nPGj004?nPGj000ol0
003ohAkQon4Nh@0?on4Nh@03o`000?ok1?_on`Ck00[on`Ck0_l00004oo`3o003o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?oa3_7ol@ka00Col@ka1Ol00007on8MhP03
o`000?nfBKKo]TVf00go]TVf00?o0000og:=L_mbSG802OmbSG800ol0003o>/Djoc[5>P03oc[5>P03
o`000?l8m`So2?L800Go2?L800?o0000o`Wf2Ol9mPT02?l9mPT00ol0003o0o`3o`?l0`06o`?l0`03
o`000?lJiA[o6^DJ00?o6^DJ00?o0000odVfBOm9]TT02om9]TT00ol0003oX5nPoj1OX00@oj1OX003
o`000?oQ7^7ohAkQ00oohAkQ00?o0000oo/4nook1?/03?ok1?/2o`000003oo`3o?l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo4>lOl00000
1?l0000<on8MhP03o`000?nfBKKo]TVf00ko]TVf00?o0000og:=L_mbSG802?mbSG800ol0003o>/Dj
oc[5>P02oc[5>P03o`000?l8m`So2?L800Oo2?L800?o0000o`Wf2Ol9mPT01ol9mPT00ol0003o0o`3
o`?l0`07o`?l0`03o`000?lJiA[o6^DJ00;o6^DJ00?o0000odVfBOm9]TT02om9]TT00ol0003oX5nP
oj1OX00Aoj1OX003o`000?oQ7^7ohAkQ00gohAkQ00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d01Oom0_d3o`00017ohQgR00?o0000okI9]_nfBKH03_nf
BKH00ol0003oLXebog:=LP09og:=LP04o`000?ljaC[o>/Djo`0000[o2?L800?o0000o`Wf2Ol9mPT0
1ol9mPT00ol0003o0o`3o`?l0`08o`?l0`05o`000?lJiA[o6^DJoa[U6_l000003Om9]TT00ol0003o
X5nPoj1OX00Aoj1OX0?o00003OoQ7^400ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_om0_d2o`0000;on@Ki00?o0000on8Mh_oR7N803ooR7N800ol0003o
]TVfokI9]P0>okI9]P03o`000?mbSG;oLXeb00SoLXeb1Ol0000;o`Sg2003o`000?l9mPWo2OH900Ko
2OH900?o0000o`?l0ol3o0<02Ol3o0<01?l0003o6^DJoa[U6_l0000=odVfB@03o`000?nPGj3oX5nP
017oX5nP00?o0000oldbcOo=</d00ol0000:on4Nh@Co00003Ook1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooT6n@03o`000?oR7N;ohQgR00kohQgR00?o0000okI9
]_nfBKH03_nfBKH00ol0003oLXebog:=LP07og:=LP03o`000?lRgB;o8]dR00?o8]dR00?o0000o`Sg
2?l8m`P02?l8m`P00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l3o0?o0o`300[o0o`31Ol0000<odVf
B@03o`000?nPGj3oX5nP013oX5nP00?o0000oldbcOo=</d01?o=</d3o`0000KohAkQ00?o0000ooP7
n?oh1oP00_oh1oP5o`0000Son`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0003ohQgRon8MhP0=on8MhP03o`000?nfBKKo]TVf00oo
]TVf00?o0000og:=L_mbSG801?mbSG82o`0000Oo8]dR00?o0000o`Sg2?l8m`P01ol8m`PEo`0000Go
6n@K00?o0000odVfBOm9]TT02?m9]TT3o`00013oX5nP00?o0000oldbcOo=</d02?o=</d3o`0000;o
hAkQ00?o0000ooP7n?oh1oP02?oh1oP5o`0000?on`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ohQgRon8MhP0;on8MhPCo0000
3onfBKH00ol0003oLXebog:=LP03og:=LP03o`000?lRgB;o8]dR00So8]dR00?o0000o`Sg2?l8m`P0
1?l8m`P2o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o6n@Koa_T6`05oa_T6`;o0000
1_m9]TT2o`0000?oGj1O00?o0000oj1OX?nPGj003?nPGj000ol0003ocC;=oldbc@0<oldbc@;o0000
4?oh1oP3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00?o
0000on8Mh_oR7N802OoR7N800ol0003ojaC[o`000002ok]4^`?o00003?nfBKH01?l0003oLXebog:=
L_mbSG82o`0000co8]dR00?o0000o`Sg2?l8m`P00_l8m`P00ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000oa_T6olKi1/01olKi1/00ol0003oBKI9odVfB@02odVfB@03o`00
0?mOX5ooGj1O00CoGj1O0_l0000;oj1OX003o`000?o=</gocC;=00cocC;=00?o0000onXEj_l00000
4_oh1oP00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o
0000on8Mh_oR7N801_oR7N82o`0000;ojaC[00?o0000ok]4^onkA;/00onkA;/3o`0000[o]TVf00?o
0000og:=L_l000003olRgB801?l0003o2?L8o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000oa_T6olKi1/02?lKi1/01?l0003oBKI9o`000?l00009oenPG`03o`000?nPGj3oX5nP00Oo
X5nP00?o0000oldbcOo=</d03?o=</d01?l0003ojQGZonXEj_l0000CooP7n003o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oR7N;ohQgR00Co
hQgR00?o0000on/Djoo[5>/00oo[5>/00ol0003o^dBkok]4^`05ok]4^`?o00001_nfBKH4o`00013o
8]dR00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lKi1_o6n@K00Wo
6n@K00?o0000oenPGomOX5l02_mOX5l2o`0000KoX5nP00?o0000oldbcOo=</d03?o=</d00ol0003o
jQGZonXEjP02onXEjP03o`000?oh1oSon0Oh00oon0Oh00?o0000ooh1o_l000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Won@Ki00Co0000on8Mh_oR7N;o
hQgR0_l00006on/Dj`03o`000?nkA;_o^dBk00So^dBk0ol000000onfBKKo0000o`000004ofNHI`03
o`000?lRgB;o8]dR00go8]dR00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?lKi1_o6n@K00Wo6n@K00?o0000oenPGomOX5l03?mOX5l00ol0003oX5nPoj1OX003o`0000ko
cC;=00?o0000onXEj_oZ5NX00ooZ5NX00ol0003on0OhooP7n00>ooP7n005o`000?on0OkooP7nooh1
o_l000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00[o
n@Ki00?o0000on8Mh_l000002?o[5>/00ol0003o^dBkok]4^`0;ok]4^`03o`000?mWV6OoIiQW00Go
IiQW00?o0000ob;M8_lRgB803?lRgB800ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000oa_T6olKi1/02?lKi1/2o`0000ooGj1O0_l00002oke2_@03o`000?o=</gocC;=00_o
cC;=00?o0000onXEj_oZ5NX01?oZ5NX00ol0003on0OhooP7n00=ooP7n003o`000?on0OkooP7n00?o
oP7n00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000on/Djoo[5>/0
1oo[5>/00ol0003o^dBkok]4^`0;ok]4^`03o`000?mWV6OoIiQW00KoIiQW00?o0000ob;M8_lRgB80
2olRgB82o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o6n@Koa_T6`07oa_T6`04o`00
0?l_d2oo;m0_o`0000koGj1O00?o0000oke2_Onm@[d00_nm@[d00ol0003ocC;=oldbc@09oldbc@03
o`000?oZ5N[ojQGZ00KojQGZ00?o0000ooP7n?oh1oP02ooh1oP00ol0003ooP7nooh1oP05ooh1oP04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooT6nOoi1_T02_oi1_T2o`0000Wo
jaC[00?o0000ok]4^onkA;/02onkA;/00ol0003oIiQWofNHI`07ofNHI`03o`000?lRgB;o8]dR00Wo
8]dR00Co0000o`Ck1?l4n`Co00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lKi1_o6n@K
00Ko6n@K00Go0000obo@;ol_d2oo;m0_o`00000>oenPG`03o`000?nm@[go_D:m00?o_D:m00?o0000
oldbcOo=</d01oo=</d00ol0003ojQGZonXEjP07onXEjP03o`000?oh1oSon0Oh00[on0Oh00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oi1_Won@Ki
00Won@Ki00Co0000ooP7n?oh1oSo00002Oo[5>/00ol0003o^dBkok]4^`09ok]4^`03o`000?mWV6Oo
IiQW00WoIiQW00?o0000ob;M8_lRgB801olRgB800ol0003o1?/4o`Ck1002o`Ck1003o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o6n@Koa_T6`05oa_T6`03o`000?l_d2oo
;m0_00?o;m0_00?o0000oenPGomOX5l02_mOX5l00ol0003o_D:moke2_@05oke2_@03o`000?o=</go
cC;=00GocC;=00?o0000onXEj_oZ5NX02?oZ5NX00ol0003on0OhooP7n009ooP7n003o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won@Ki00?o0000ooP7
n?oh1oP00_oh1oP00ol0003ojaC[on/Dj`06on/Dj`03o`000?nkA;_o^dBk00Wo^dBk00?o0000ofNH
IomWV6L02_mWV6L00ol0003o8]dRob;M8P05ob;M8P03o`000?l4n`Co1?/400Co1?/400?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lKi1_o6n@K00Co6n@K00?o0000obo@
;ol_d2l01?l_d2l00ol0003oGj1OoenPG`0:oenPG`03o`000?nm@[go_D:m00Ko_D:m00?o0000oldb
cOo=</d00oo=</d00ol0003ojQGZonXEjP09onXEjP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003oo`3o0?o00001Ooi1_T00ol0003o
n0OhooP7n003ooP7n003o`000?o[5>_ojaC[00KojaC[00?o0000ok]4^onkA;/02OnkA;/00ol0003o
IiQWofNHI`0;ofNHI`03o`000?lRgB;o8]dR00?o8]dR00?o0000o`Ck1?l4n`@01_l4n`@00ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000oa_T6olKi1/00_lKi1/2o`0000So
;m0_00?o0000oenPGomOX5l02OmOX5l00ol0003o_D:moke2_@07oke2_@05o`000?o=</gocC;=oldb
cOl000003OoZ5NX00ol0003on0OhooP7n006ooP7n003o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l0ol000000ooi1_Wo0000ooP7n006ooP7n003
o`000?o[5>_ojaC[00GojaC[00?o0000ok]4^onkA;/02OnkA;/00ol0003oIiQWofNHI`0<ofNHI`05
o`000?lRgB;o8]dRob;M8_l000002_l4n`@00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000oa_T6ol000000_l000000ol>l@ko0000obo@;`07obo@;`03o`000?mOX5ooGj1O
00SoGj1O00?o0000oke2_Onm@[d02Onm@[d00ol0003ocC;=o`00000=onXEjPCo00001Ooh1oP00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o008oo`3o003
o`000?oh1oSon0Oh00Oon0Oh00?o0000on/Djoo[5>/01?o[5>/00ol0003o^dBkok]4^`09ok]4^`03
o`000?mWV6OoIiQW00goIiQW00?o0000ob;M8_l000003?l4n`@:o`0000Oo0?l00ol00005o`ka3P03
o`000?l_d2oo;m0_00Ko;m0_00?o0000oenPGomOX5l01omOX5l00ol0003o_D:moke2_@0:oke2_@03
o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooX5n_oj1OX00_oj1OX3o`000003ooP7n?l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003on0OhooP7n007ooP7n003o`00
0?o[5>_ojaC[00GojaC[00?o0000ok]4^onkA;/01onkA;/00ol0003oIiQWofNHI`0?ofNHI`;o0000
2ol4n`@00ol0003o1_T6o`Ki1P07o`Ki1P03o`000?l0o`3o0?l000;o0?l00ol00008o`ka3P03o`00
0?l_d2oo;m0_00Ko;m0_00?o0000oenPGomOX5l01omOX5l00ol0003o_D:moke2_@0:oke2_@03o`00
0?oZ5N[ojQGZ00[ojQGZ00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003on0OhooP7
n008ooP7n003o`000?o[5>_ojaC[00CojaC[00?o0000ok]4^onkA;/01onkA;/00ol0003oIiQWofNH
I`0>ofNHI`04o`000?l]dRgo;M8]o`0000Wo1?/400?o0000o`Ki1_l6n@H02Ol6n@H01?l0003o0?l0
o`000?l0000<o`ka3P03o`000?l_d2oo;m0_00Ko;m0_00?o0000oenPGomOX5l01_mOX5l00ol0003o
_D:moke2_@0;oke2_@03o`000?oZ5N[ojQGZ00OojQGZ0_l00009ooX5nP03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo0?loo`3o009oo`3o003o`00
0?oh1oSon0Oh00Son0Oh00?o0000on/Djoo[5>/00oo[5>/>o`0000goIiQW00?o0000obgB;Ol]dRd0
0_l]dRd00ol0003o1?/4o`Ck1005o`Ck1003o`000?l6n@Ko1_T600_o1_T600?o0000o`ka3_l>l@h0
3?l>l@h00ol0003o;m0_obo@;`06obo@;`03o`000?mOX5ooGj1O00GoGj1O00?o0000oke2_Onm@[d0
3?nm@[d00ol0003ojQGZonXEjP06onXEjP03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7n?oh1oP02?oh
1oP01Ol0003ojaC[on/Djoo[5>_o000000_ob3O800?o0000ofbCK?m/Tf`00ol00009ofNHI`03o`00
0?l]dRgo;M8]00Co;M8]00?o0000o`Ck1?l4n`@00ol4n`@00ol0003o1_T6o`Ki1P0<o`Ki1P03o`00
0?l>l@ko3_4>00go3_4>00?o0000obo@;ol_d2l01_l_d2l00ol0003oGj1OoenPG`03oenPG`?o0000
3Onm@[d00ol0003ojQGZonXEjP05onXEjP03o`000?oj1O[onPGj00conPGj0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7n?oh1oP02?oh
1oP4o`0000cob3O800?o0000ofbCK?m/Tf`00om/Tf`3o`0000GoIiQW00?o0000obgB;Ol]dRd01_l]
dRd01Ol0003o1?/4o`Ck1?l4n`Co000000oo1_T600?o0000o`ka3_l>l@h03Ol>l@h00ol0003o;m0_
obo@;`06obo@;`03o`000?mOX5ooGj1O00?o00000ommPWd00ol0003o_D:moke2_@0;oke2_@03o`00
0?oZ5N[ojQGZ00?ojQGZ00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`02_ol0o`3o`0000Kon0Oh0ol0
0003oo<<l`03o`000?o8=lSob3O800[ob3O800?o0000ofbCK?m/Tf`01_m/Tf`3o`000003ofNHIol0
003o;M8]00Wo;M8]00?o0000o`Ck1?l000004?l6n@H00ol0003o3_4>o`ka3P0=o`ka3P03o`000?l_
d2oo;m0_00Oo;m0_0_l00007ogf2O@03o`000?nm@[go_D:m00[o_D:m00Co0000onXEj_oZ5N[ojQGZ
0ol0000?ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02_ol
0o`01?l0003on`Ckoo/4nook1?/2o`000004ooP7n?l0003o0000o`0000Kol`cc00?o0000olPgb?o8
=lP02_o8=lP00ol0003oK9=/ofbCK009ofbCK003o`000?l]dRgo;M8]00[o;M8]00?o0000o`Ki1_l6
n@H03ol6n@H00ol0003o3_4>o`ka3P0>o`ka3P03o`000?l_d2oo;m0_00Ko;m0_00?o0000ogf2OOmm
PWd01ommPWd4o`0000So_D:m00Co0000onXEj_oZ5N[o00000ood2o@2o`0000gonPGj00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003o
n`Ckoo/4n`04oo/4n`03o`000?oc3??ol`cc00Ool`cc00?o0000olPgb?o8=lP02Oo8=lP00ol0003o
K9=/ofbCK00:ofbCK003o`000?l]dRgo;M8]00[o;M8]00?o0000o`Ki1_l6n@H03ol6n@H00ol0003o
3_4>o`ka3P0>o`ka3P03o`000?l_d2oo;m0_00Go;m0_00?o0000ogf2OOmmPWd02?mmPWd01?l0003o
aC[5olDjaOo5>/D7o`0000;o_D:m0_l00006oo@;m0;o00003?oj1OX00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o008oo`3o003o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<02?oc3?<00ol0003ob3O8olPgb008olPgb003o`000?m/TfcoK9=/00[o
K9=/00?o0000obgB;Ol]dRd02ol]dRd00ol0003o1_T6o`Ki1P0>o`Ki1P03o`000?l>l@ko3_4>00ko
3_4>1Ol00002obo@;`03o`000?mmPWgoOH9m00WoOH9m00?o0000olDjaOo5>/D02?o5>/D3o`0000Wo
m0_d0_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?o8=lSob3O800Sob3O800?o0000ofbCK?m/Tf`02_m/Tf`00ol0003o;M8]obgB;@0:obgB;@;o0000
3_l6n@H3o`0000go3_4>0ol00005ock1?P;o00002ommPWd00ol0003oaC[5olDja@0;olDja@;o0000
2_od2o@2o`0000OonPGj0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo/4n`03o`00
0?oc3??ol`cc00Ool`cc00?o0000olPgb?o8=lP02?o8=lP>o`0000Wo;M8]0ol000000olTfbCo0000
o`Ki1P0:o`Ki1P?o00000_lHiaP00ol0003o3_4>o`ka3P09o`ka3P;o00002Oln`Ch00ol0003oOH9m
ogf2O@09ogf2O@03o`000?o5>/GoaC[500_oaC[500?o0000omhQg_l000002ood2o@2o`0000ConPGj
00Co0000oo`3o?ol0ocoo0?l0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oc3??ol`cc00Kol`cc00?o0000olPgb?o8=lP02?o8=lP00ol0003oJYEZ
ofZEJP0:ofZEJP03o`000?l]dRgo;M8]00Co;M8]0ol00005obCK9003o`000?l6n@Ko1_T600Co1_T6
1?l00006oaSW6003o`000?l>l@ko3_4>00Ko3_4>0_l0000;ock1?P03o`000?mmPWgoOH9m00WoOH9m
00?o0000olDjaOo5>/D02_o5>/D01Ol0003ogR7NomhQg_oN8Mko000000com0_d0_l000000ooj1O[o
0000oo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<01_oc3?<00ol0003ob3O8olPgb007olPgb003o`00
0?mZUF[oJYEZ00_oJYEZ00?o0000obgB;Ol]dRd00_l]dRd2o`0000Wo9=/T00?o0000o`Ki1_l6n@H0
0ol0000;oaSW6003o`000?l>l@ko3_4>00;o3_4>0ol0000>ock1?P03o`000?mmPWgoOH9m00OoOH9m
00?o0000olDjaOo5>/D02oo5>/D00ol0003ogR7NomhQgP02omhQgP03o`000?od2oCom0_d00_om0_d
00?o0000oo`3o?ol0o`01_ol0o`2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok
1?_on`Ck00Oon`Ck00?o0000oo<<looc3?<01ooc3?<00ol0003ob3O8olPgb005olPgb0?o00003OmZ
UFX4o`0000_o9=/T0ol0000?oaSW6004o`000?l>l@ko0000o`00017o?/4n00?o0000ogf2OOmmPWd0
1ommPWd00ol0003oaC[5olDja@0:olDja@03o`000?oN8MkogR7N00CogR7N00?o0000oo@;m?od2o@0
1ood2o@3o`0000_oo0?l1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ol`ccoo<<
l`06oo<<l`03o`000?o8=lSob3O800;ob3O80ol00003ojQGZ003o`000?mZUF[oJYEZ00[oJYEZ00?o
0000obCK9?lTfb@02olTfb@00ol0003o7mlOo`00000AoaSW6003o`000?ln`Cko?/4n017o?/4n00?o
0000ogf2OOmmPWd01ommPWd00ol0003oaC[5olDja@0:olDja@03o`000?oN8MkogR7N00GogR7N00Co
0000oo@;m?od2oCom0_d1Ol00002ooL8m`03o`000?ol0ocoo0?l00Woo0?l00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`05oo<<l`?o0000
00?ob3O8o`000?l000001onXEjP00ol0003oJYEZofZEJP08ofZEJP?o00002_lTfb@2o`0000;o7mlO
00?o0000oaSW6?lHiaP03olHiaP00ol0003o?/4nock1?P0Aock1?P03o`000?mmPWgoOH9m00OoOH9m
00?o0000olDjaOo5>/D02Oo5>/D00ol0003ogR7NomhQgP07omhQgP?o00001oog2?L00ol0003oo0?l
oo`3o009oo`3o003o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook
1?/4o`0000;ol`cc0_l00003on`Ck003o`000?nXEjSoZ5NX00SoZ5NX0_l00006ofZEJP;o00000omH
YeP00ol0003o9=/TobCK9006obCK9003o`000?lOgaoo7mlO00?o7mlO00?o0000oaSW6?lHiaP03_lH
iaP00ol0003o?/4nock1?P0Bock1?P03o`000?mmPWgoOH9m00GoOH9m00?o0000olDjaOo5>/D02Oo5
>/D00ol0003ogR7NomhQgP08omhQgP03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol
0o`00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00Con`Ck0_l00004
ooX5nP;o00001Oo/4n`00ol0003oZ5NXojQGZ00:ojQGZ003o`000?mZUF[oJYEZ00;oJYEZ00?o0000
oeRWF?mHYeP01?mHYeP00ol0003o9=/TobCK9004obCK9003o`000?lOgaoo7mlO00Co7mlO00?o0000
oaSW6?lHiaP03_lHiaP00ol0003o?/4nock1?P0Bock1?P[o00002_o5>/D00ol0003ogR7NomhQgP08
omhQgP03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003on`Ckoo/4nook1?/2o`0000OonPGj00?o0000on`Ck?o/4n`01?o/4n`0
0ol0003oZ5NXojQGZ00:ojQGZ004o`000?mZUF[o0000o`0000SoF:MH00Co0000obCK9?lTfbCo9=/T
0_l00007oaoO7`03o`000?lHiaSo6>LH00ko6>LH00?o0000ock1?_ln`Ch04_ln`Ch00ol0003oW6>L
oiaSW007oiaSW003o`000?o5>/GoaC[500KoaC[500?o0000omhQg_oN8Mh02_oN8Mh00ol0003om`Sg
ooL8m`06ooL8m`03o`000?ol0ocoo0?l00Soo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ok
1?_o0000o`0000WonPGj00?o0000on`Ck?o/4n`01?o/4n`00ol0003oZ5NXojQGZ00;ojQGZ003o`00
0?mHYeSoF:MH00WoF:MH00?o0000obCK9?l000002OlOgal00ol0003o6>LHoaSW600>oaSW60;o0000
4_ln`Ch00ol0003oW6>LoiaSW009oiaSW0;o00001_o5>/D00ol0003ogR7NomhQgP0:omhQgP03o`00
0?og2?Oom`Sg00Kom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ok1?/on`Ck005on`Ck003o`000?nXEjSoZ5NX00[oZ5NX00?o
0000oeRWF?mHYeP02_mHYeP2o`0000Wo7mlO00?o0000oaSW6?lHiaP03_lHiaP00ol0003o=</do`00
0002o`0000oo?/4n00?o0000oiaSW?nLHi`02onLHi`00ol0003oaC[5olDja@03o`0000gogR7N00?o
0000ooL8moog2?L01_og2?L00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003onPGjooX5nP09ooX5nP03o`000?o/4ncok1?/00Gok1?/00?o0000ojQGZ?nXEjP02OnXEjP2
o`0000_oF:MH0_l0000;oaoO7`03o`000?lHiaSo6>LH00co6>LH00?o0000ocC;=?ldbc@00oldbc@3
o`0000co?/4n00?o0000oiaSW?nLHi`03?nLHi`2o`0000;og2?L00?o0000omhQg_oN8Mh03?oN8Mh0
0ol0003om`SgooL8m`05ooL8m`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00[onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oZ5NXojQGZ007ojQG
Z003o`000?n]DZgo000000[oF:MH00Co0000odn`Com?/4oo00002_lOgal00ol0003o6>LHoaSW600<
oaSW6003o`000?ldbcCo=</d00Ko=</d0_l00008ock1?P;o00003onLHi`00ol0003og2?Lom`Sg002
om`Sg003o`000?oN8MkogR7N00_ogR7N00?o0000ooL8moog2?L01Oog2?L00ol0003oo0?loo`3o007
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o/4ncok1?/
00Kok1?/00?o0000ojQGZ?nXEjP01_nXEjP01Ol0003o[E:]ojeB[On]DZgo000000SoF:MH00?o0000
odn`Com?/4l00_m?/4l00ol0003o7mlOoaoO7`06oaoO7`Co00003?lHiaP00ol0003o=</docC;=008
ocC;=0?o00000_ln`Ch3o`000003ogb3O?l0003oW6>L00goW6>L00?o0000om`Sg?oL8m`01?oL8m`0
0ol0003ogR7NomhQgP0:omhQgP03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ok1?/on`Ck007on`C
k003o`000?nXEjSoZ5NX00?oZ5NX0_l00005ojeB[@03o`000?mHYeSoF:MH00CoF:MH00?o0000odn`
Com?/4l00om?/4l00ol0003o7mlOoaoO7`05oaoO7`03o`000?lHiaSo6>LH00;o6>LH0ol00007oaSW
60;o00003_ldbc@2o`0000GoO8=l00?o0000oiaSW?nLHi`02_nLHi`00ol0003og2?Lom`Sg005om`S
g003o`000?oN8MkogR7N00_ogR7N00?o0000ooL8moog2?L01?og2?L00ol0003oo0?loo`3o006oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?o/4ncok1?/00Oo
k1?/00?o0000ojQGZ?nXEjP00_nXEjP00ol0003o[E:]ojeB[@06ojeB[@03o`000?mHYeSoF:MH00;o
F:MH00?o0000odn`Com?/4l01Om?/4l00ol0003o7mlOoaoO7`02oaoO7`;o00002?lHiaP3o`0000;o
6>LH0_l000000olKi1_o0000ocC;=00=ocC;=003o`000?mlPgcoO8=l00GoO8=l00?o0000oiaSW?nL
Hi`02?nLHi`00ol0003og2?Lom`Sg007om`Sg003o`000?oN8MkogR7N00[ogR7N00?o0000ooL8moog
2?L01?og2?L00ol0003oo0?loo`3o006oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGj
ooX5nP0<ooX5nP03o`000?o/4ncok1?/00Sok1?/00Co0000ojQGZ?nXEjSo00002On]DZd01Ol0003o
F:MHoeRWF?mHYeSo000000SoCk1?00Go0000oaoO7olOgaoo7mlOo`00000=oaSW60;o00001?lKi1/0
0ol0003o=</docC;=00;ocC;=003o`000?mlPgcoO8=l00KoO8=l00?o0000oiaSW?nLHi`01onLHi`0
0ol0003og2?Lom`Sg008om`Sg0Co00002?oN8Mh00ol0003om`SgooL8m`04ooL8m`03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00_onPGj0ol00009on`C
k003o`000?nXEjSo000000_o[E:]00?o0000oeRWF?l000002_m?/4l00ol0003o7mlOo`00000?oaSW
6003o`000?lKi1_o6n@K00;o6n@K00?o0000ocC;=?ldbc@02oldbc@00ol0003oO8=logb3O006ogb3
O003o`000?nLHicoW6>L00KoW6>L00?o0000om`Sg?oL8m`02OoL8m`01?l0003okQ7^onhAk_o^4Nh7
o`0000;ogR7N00?o0000ooL8moog2?L00oog2?L00ol0003oo0?loo`3o005oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oj1O[onPGj00SonPGj0ol00003ooX5nP03o`000?o/4ncok1?/00Ook1?/00?o0000ojeB
[On]DZd02on]DZd00ol0003oCk1?odn`C`0:odn`C`03o`000?lHiaSo6>LH00go6>LH00?o0000oa_T
6olKi1/01?lKi1/00ol0003o=</docC;=009ocC;=003o`000?mlPgcoO8=l00SoO8=l00?o0000oiaS
W?nLHi`00onLHi`2o`0000cog2?L00?o0000onhAk_o^4Nh02?o^4Nh<o`0000?oo0?l0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX3o`0000OonPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
[E:]ojeB[@0;ojeB[@03o`000?m?/4ooCk1?00WoCk1?0_l0000>oaSW6003o`000?lKi1_o6n@K00Go
6n@K00?o0000ocC;=?ldbc@02Oldbc@00ol0003oO8=logb3O009ogb3O003o`000?nLHico000000;o
00000_oB;M800ol0003og2?Lom`Sg008om`Sg003o`000?o^4NkokQ7^00cokQ7^00?o0000ooP7n?oh
1oP01_oh1oP3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003onPGjooX5nP03ooX5nP?o00002ooj1OX00ol0003ok1?/
on`Ck004on`Ck003o`000?n]DZgo[E:]00_o[E:]0ol00007odn`C`?o000000?o=lPgo`000?lHiaP0
3OlHiaP00ol0003o6n@Koa_T6`06oa_T6`03o`000?ldbcCo=</d00So=</d00?o0000ogb3O?mlPg`0
2_mlPg`00ol0003odRgBom8]dP04om8]dP03o`000?oL8mcog2?L00Oog2?L00?o0000onhAk_o^4Nh0
2oo^4Nh00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooX5n_l0
003o0000o`0000oonPGj00?o0000on`Ck?o/4n`00oo/4n`>o`0000?oUfRG0_l00002odn`C`?o0000
1Olgb3L00ol0003o6>LHoaSW600:oaSW6003o`000?lKi1_o6n@K00Oo6n@K00?o0000ocC;=?ldbc@0
2?ldbc@00ol0003oO8=logb3O00:ogb3O003o`000?oB;M;odRgB00GodRgB00?o0000om`Sg?oL8m`0
1_oL8m`00ol0003okQ7^onhAkP0;onhAkP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;onPGj00?o0000on`Ck?o/4n`00_o/4n`00ol0003ogR7NomhQ
gP0:omhQgP03o`000?nGJ9OoUfRG00?oUfRG0_l00009ocO8=`03o`000?lHiaSo6>LH00Wo6>LH00?o
0000oa_T6olKi1/02?lKi1/2o`0000So=</d00?o0000ogb3O?mlPg`02OmlPg`00ol0003odRgBom8]
dP07om8]dP03o`000?oL8mcog2?L00Cog2?L00?o0000onhAk_o^4Nh02oo^4Nh00ol0003on0OhooP7
n009ooP7n003o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o000000?ok1?/
o`000?oN8Mh02ooN8Mh00ol0003oUfRGoiMXU`04oiMXU`03o`000?lgb3Oo=lPg00Wo=lPg00?o0000
oaSW6?lHiaP01olHiaP00ol0003o6n@Koa_T6`09oa_T6`04o`000?ll`cco0000o`0000Ko=</d00?o
0000ogb3O?mlPg`02OmlPg`00ol0003odRgBom8]dP08om8]dP03o`000?oL8mcog2?L00?og2?L00?o
0000onhAk_o^4Nh02oo^4Nh00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00000ooi1_T2o`0000cogR7N00?o0000oiMXUonGJ9L01?nGJ9L0
0ol0003o=lPgocO8=`0:ocO8=`Wo00002olKi1/00ol0003o?<<locc3?002occ3?0?o00000_ldbc@0
0ol0003oO8=logb3O00:ogb3O003o`000?oB;M;odRgB00WodRgB00?o0000om`Sg?oL8m`00_oL8m`0
0ol0003okQ7^onhAkP0:onhAkP03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_oj1OX2o`0000Gon@Ki00?o0000on`Ck?l000002_oN8Mh00ol0003oUfRGoiMXU`06oiMX
U`03o`000?lgb3Oo=lPg00Wo=lPg00?o0000ob7N8OlQgR401OlQgR400ol0003o6n@Koa_T6`09oa_T
6`03o`000?ll`cco?<<l00Go?<<l0ol00009ogb3O0?o00003OoB;M801Ol0003og2?Lom`Sg?oL8mco
000000cokQ7^00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX01Ooj1OX2o`0000Oon@Ki00Co0000on`Ck?o/4nco00002OoN8Mh00ol0003oUfRGoiMXU`06
oiMXU`03o`000?lgb3Oo=lPg00So=lPg00?o0000ob7N8OlQgR401olQgR400ol0003o6n@Koa_T6`07
oa_T6`03o`000?ll`cco?<<l00So?<<l0ol00002ogb3O0Go00000_nkA;/00ol0003odRgBom8]dP0<
om8]dP03o`000?oL8mco000000cokQ7^00?o0000ooP7n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000ooX5n_oj1OX00_oj1OX2o`0000Son@Ki00?o0000on`Ck?o/4n`00_o/4n`5o`00
00CogR7N00?o0000oiMXUonGJ9L01_nGJ9L00ol0003o=lPgocO8=`08ocO8=`03o`000?lQgR7o8MhQ
00Oo8MhQ00?o0000oa_T6olKi1/01olKi1/00ol0003o?<<locc3?008occ3?003o`000?n5NXGoQGZ5
00;o00002?nkA;/00ol0003odRgBom8]dP0<om8]dPCo00002_o^4Nh00ol0003on0OhooP7n00:ooP7
n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003onPGjo`000?l0000:ooT6n@03o`000?o/4ncok1?/
00;ok1?/00?o0000olLhaoo7><L00_o7><L4o`0000WoUfRG00?o0000ocO8=olgb3L02?lgb3L00ol0
003o8MhQob7N8@08ob7N8@03o`000?lKi1_o6n@K00Go6n@K00?o0000occ3??ll`c`02?ll`c`01Ol0
003oQGZ5ohEjQOn5NXGo000000[o^dBk0ol0000;om8]dP04o`000?od2oCom0_doo@;m0Co00001Oo^
4Nh00ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o/4ncok1?/00?ok1?/00?o0000olLhaoo7><L01?o7><L00ol0003oUfRGoiMXU`07
oiMXU`03o`000?lgb3Oo=lPg00Ko=lPg0_l0000;ob7N8@03o`000?lKi1_o6n@K00Go6n@K00?o0000
occ3??ll`c`02?ll`c`00ol0003oQGZ5ohEjQ@02ohEjQ@03o`000?nkA;_o^dBk00Oo^dBk00?o0000
onLHiooW6>L01?l00006om8]dP03o`000?od2oCom0_d00Kom0_d0ol00002onhAkP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000on`C
k?o/4n`01?o/4n`00ol0003oacS7olLha`05olLha`03o`000?nGJ9OoUfRG00OoUfRG00?o0000ocO8
=olgb3L00_lgb3L3o`000003odn`Col0003o8MhQ00[o8MhQ00?o0000oa_T6olKi1/01OlKi1/00ol0
003o?<<locc3?007occ3?003o`000?n5NXGoQGZ500?oQGZ500?o0000ok]4^onkA;/01onkA;/00ol0
003oiaSWonLHi`04onLHi`?o00000_oB;M800ol0003om0_doo@;m00:oo@;m0;o00003_oh1oP00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ok1?/on`Ck004on`Ck003
o`000?o7><OoacS700KoacS70_l00007oiMXU`03o`000?lgb3Oo000000;o00001Om?/4l00ol0003o
8MhQob7N8@08ob7N8@?o00001?lKi1/00ol0003o?<<locc3?008occ3?003o`000?n5NXGoQGZ500Co
QGZ500?o0000ok]4^onkA;/01_nkA;/00ol0003oiaSWonLHi`07onLHi`;o00003_od2o@00ol0003o
n0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o/4ncok1?/00Gok1?/00?o0000olLhaoo7><L01?o7><L00ol0003obCK9olTfb@03o`0000CoUfRG
0_l00008odn`C`03o`000?lQgR7o8MhQ00Oo8MhQ00Co0000od>l@om3_4?o@ka30ol000000olKi1_o
0000occ3?009occ3?003o`000?n5NXGoQGZ500CoQGZ500?o0000ok]4^onkA;/01OnkA;/00ol0003o
iaSWonLHi`09onLHi`03o`000?od2oCom0_d00gom0_d00?o0000ooP7n?oh1oP02_oh1oP00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003ok1?/on`Ck006on`Ck003o`00
0?o7><OoacS700?oacS700?o0000olTfbOo9=/T01?o9=/T2o`000003oiMXUol0003oCk1?00[oCk1?
00?o0000ob7N8OlQgR401OlQgR400ol0003o@ka3od>l@`05od>l@`03o`000?ll`cco?<<l00Oo?<<l
0ol00007ohEjQ@03o`000?nkA;_o^dBk00Co^dBk00?o0000onLHiooW6>L02OoW6>L00ol0003om0_d
oo@;m00=oo@;m003o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009on`Ck005o`000?o7><OoacS7olLhaol000002Oo9=/T00ol0003oCk1?
odn`C`0;odn`C`03o`000?lQgR7o8MhQ00?o8MhQ00?o0000od>l@om3_4<01_m3_4<00ol0003o?<<l
occ3?006occ3?005o`000?mlPgcoO8=logb3O?l000001on5NXD00ol0003o^dBkok]4^`03ok]4^`03
o`000?oW6>OoiaSW00WoiaSW00?o0000oo@;m?od2o@03_od2o@00ol0003on0OhooP7n009ooP7n003
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;on`Ck00?o0000on`Ck?o/4n`0
1oo/4n`01?l0003oacS7olLhaol00009olTfb@;o00003Om?/4l00ol0003o8MhQob7N8@02ob7N8@03
o`000?m3_4?o@ka300So@ka300?o0000occ3??ll`c`00oll`c`2o`0000GoO8=l00?o0000ohEjQOn5
NXD01?n5NXD00ol0003o^dBkok]4^`03ok]4^`03o`000?oW6>OoiaSW00WoiaSW00?o0000oo@;m?od
2o@03_od2o@00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Son`Ck
00?o0000on`Ck?o/4n`01_o/4n`00ol0003oacS7o`000009olTfb@04o`000?nRGJ;oXUfRo`0000go
Ck1?00Co0000ob7N8OlQgR7o00003?m3_4<01Ol0003o?<<locc3??ll`cco000000SoO8=l0_l00005
ohEjQ@03o`000?nkA;_o^dBk00;o^dBk00?o0000onLHiooW6>L02OoW6>L00ol0003om0_doo@;m00>
oo@;m003o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000on`Ck?o/4n`01oo/4n`00ol0003obCK9olTfb@07olTfb@03o`000?nRGJ;oXUfR
00;oXUfR00?o0000odn`Com?/4l02_m?/4l00ol0003o8MhQo`00000>od>l@`03o`000?ll`cco0000
00_oO8=l00?o0000ohEjQOn5NXD00_n5NXD01Ol0003o^dBkok]4^onkA;_o000000coiaSW00?o0000
oo@;m?od2o@03_od2o@3o`0000Won0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000on`Ck?o/4n`01_o/4n`00ol0003obCK9olTfb@06olTfb@03o`000?nRGJ;oXUfR
00?oXUfR00?o0000odn`Com?/4l02om?/4l00ol0003o@ka3od>l@`0>od>l@`03o`000?mlPgcoO8=l
00_oO8=l0_l00003ohEjQ@04o`000?nkA;_o^dBko`0000[oiaSW0ol0000>oo@;m0;o00000oon0Oh2
o`0000Oon0Oh00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000on`C
k?o/4n`01?o/4n`00ol0003obCK9olTfb@06olTfb@03o`000?nRGJ;oXUfR00GoXUfR00?o0000odn`
Com?/4l01om?/4l3o`00017o@ka300?o0000ogb3O?mlPg`03OmlPg`01Ol0003oQGZ5ohEjQOl0003o
^dBk00Co00000ooW6>L5o`0000;onPGj00?o0000oo@;m?od2o@02_od2o@2o`0000OooP7n0_l00004
ooP7n003o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o/4ncok1?/
00Cok1?/00?o0000olTfbOo9=/T01Oo9=/T00ol0003oXUfRoj9MXP06oj9MXP03o`000?m?/4ooCk1?
00CoCk1?0ol00002oeNXE`03o`000?m3_4?o@ka300oo@ka30_l0000?ogb3O004o`000?n5NXGo0000
o`0000CofbCK0ol00008ooX5nP03o`000?od2oCom0_d00Oom0_d0_l0000;ooh1oP;o00000_oh1oP0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo/4nook1?/03?ok1?/6o`0000OobCK900?o0000oj9M
X_nRGJ802?nRGJ800ol0003oCk1?odn`C`03o`0000KoEjQG00?o0000od>l@om3_4<03Om3_4<01?l0
003oPWf2oh9mP_l0000?ogb3O003o`000?oK9=_ofbCK00GofbCK00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003om0_doo@;m005oo@;m003o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ok1?/00ol0003okQ7^onhAkP04onhA
kP03o`000?o9=/WobCK900?obCK900?o0000oj9MX_nRGJ802_nRGJ82o`0000[oEjQG00?o0000od>l
@om3_4<02om3_4<00ol0003oPWf2oh9mPP02oh9mPP03o`000?mlPgcoO8=l00_oO8=l0_l00007om/T
f`03o`000?oj1O[onPGj00WonPGj00?o0000oo@;m?od2o@00_od2o@2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP06onhAkP05o`000?o9=/WobCK9olTf
bOl000003OnRGJ800ol0003oEjQGoeNXE`0:oeNXE`03o`000?m3_4?o@ka300Wo@ka300?o0000oh9m
P_n2OH801?n2OH800ol0003oO8=logb3O008ogb3O0;o000000?o[5>/o`000?oK9=/01ooK9=/00ol0
003onPGjooX5nP09ooX5nP04o`000?od2oCo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000onhAk_o^4Nh02?o^4Nh00ol0003obCK9o`00000=oj9MXP03o`000?mGZ5OoEjQG
00_oEjQG00?o0000od>l@om3_4<02?m3_4<00ol0003oPWf2oh9mPP06oh9mPP03o`000?mlPgcoO8=l
00GoO8=l0_l00003ojaC[003o`000?oK9=_ofbCK00KofbCK00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?o^4NkokQ7^00[okQ7^00?o0000oj9MX_nR
GJ803?nRGJ800ol0003oEjQGoeNXE`0<oeNXE`03o`000?m3_4?o@ka300Ko@ka300?o0000oh9mP_n2
OH802?n2OH800ol0003oO8=logb3O002ogb3O0;o00001_n/Dj`00ol0003ofbCKom/Tf`05om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck00Gon`Ck
00?o0000onhAk_o^4Nh03?o^4Nh2o`0000coXUfR00?o0000oeNXEomGZ5L03OmGZ5L00ol0003o@ka3
od>l@`04od>l@`03o`000?n2OH;oPWf200[oPWf200Co0000ogb3O?l0003o00002?n/Dj`00ol0003o
fbCKom/Tf`06om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ok1?/00ol0003okQ7^onhAkP0=onhAkP03o`000?o=</go000000;o00002?nRGJ800ol0003oEjQG
oeNXE`0?oeNXE`Ko00003_n2OH800ol0003o[5>/ojaC[008ojaC[003o`000?oK9=_ofbCK00KofbCK
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?onhAkP03o`000?o=</gocC;=00?ocC;=0ol00005oj9MXP;o00004?mGZ5L01_l0003oJIIY
ofVFJOl0003oHYeRo`0000koPWf200?o0000ojaC[?n/Dj`02On/Dj`00ol0003ofbCKom/Tf`05om/T
f`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
kQ7^onhAkP0=onhAkP03o`000?o=</gocC;=00KocC;=0ol000001?nRGJ;o0000ohIiQ_n6NHH3o`00
00coEjQG00Go0000ofVFJOmYUVWoJIIYo`000002of:MHP03o`000?n2OH;oPWf200_oPWf200?o0000
ojaC[?n/Dj`02On/Dj`00ol0003ofbCKom/Tf`06om/Tf`03o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?o=</d00ol0003oQWV6ohIiQP04ohIi
QP?o00002?mGZ5L00ol0003oJIIYofVFJ@02ofVFJ@05o`000?mRWF;oHYeRof:MH_l000003?n2OH80
0ol0003o[5>/ojaC[009ojaC[003o`000?oK9=_ofbCK00GofbCK3?l00002ood2o@;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o_4>ooka3_00_oka3_00?o0000oldb
cOo=</d02_o=</d00ol0003oQWV6ohIiQP07ohIiQP;o00001OmGZ5L00ol0003oJIIYofVFJ@03ofVF
J@03o`000?mRWF;oHYeR00;oHYeR00?o0000oh9mP_n2OH802On2OH800ol0003o[5>/ojaC[00:ojaC
[003o`000?oK9=_ofbCK00?ofbCK00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@02ood2
o@;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o_4>ooka3_00[o
ka3_00?o0000oldbcOo=</d02oo=</d00ol0003oQWV6ohIiQP09ohIiQP?o000000?oEjQGo`000?mY
UVT01OmYUVT00ol0003oHYeRof:MHP03of:MHP03o`000?n2OH;oPWf200SoPWf23_l00003om/Tf`;o
00002oof2OH00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om0_do`00000;onl@k`03o`000?o=</gocC;=00[ocC;=
0_l0000>ohIiQP03o`000?mYUVWoJIIY00GoJIIY00?o0000of:MH_mRWF800omRWF800ol0003oPWf2
oh9mPP08oh9mPP03o`000?oL8mcog2?L00_og2?L00?o0000om/Tfol000003Oof2OH00ol0003oo@;m
ood2o@06ood2o@;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000oo@;m?od2oCo00002_o_4>l00ol0003ocC;=oldbc@09oldbc@03o`000?ngB;Oo000000koQWV6
00?o0000ofVFJOmYUVT01OmYUVT00ol0003oHYeRof:MHP04of:MHP03o`000?n2OH;oPWf200KoPWf2
00?o0000om`Sg?oL8m`03OoL8m`00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@00_od
2o@00ol0003oka3_onl@k`06onl@k`03o`000?o=</gocC;=00SocC;=0_l00003okM8]`03o`000?n6
NHKoQWV600_oQWV600?o0000ofVFJOmYUVT01OmYUVT00ol0003oHYeRof:MHP05of:MHP03o`000?n2
OH;oPWf200GoPWf200?o0000om`Sg?oL8m`03OoL8m`00ol0003omPWfooH9mP0;ooH9mP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo@;m?od2o@00ood2o@00ol0003oka3_onl@k`05onl@k`03o`000?o=</gocC;=00OocC;=00?o0000
okM8]ongB;L00ongB;L00ol0003oQWV6ohIiQP0:ohIiQP03o`000?mYUVWoJIIY00KoJIIY00?o0000
of:MH_mRWF801_mRWF800ol0003oPWf2oh9mPP04oh9mPP03o`000?oL8mcog2?L00gog2?L3ol0000;
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01Ood2o@00ol0
003oka3_onl@k`04onl@k`03o`000?o=</gocC;=00GocC;=0_l00006okM8]`03o`000?n6NHKoQWV6
00WoQWV60_l00008ofVFJ@03o`000?mRWF;oHYeR00KoHYeR1Ol000000on2OH;o0000om`Sg00?om`S
g003o`000?og2?Oom`Sg00_om`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003o
ka3_onl@k`04o`0000KocC;=00?o0000okM8]ongB;L01ongB;L00ol0003oQWV6ohIiQP05ohIiQP?o
000000?oQgR7o`000?mYUVT01omYUVT00ol0003oHYeRof:MHP05of:MHP03o`000?nQGZ7oXEjQ00?o
XEjQ0_l0000?om`Sg0;o00003Oog2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000oo@;m?od2o@01ood2o@2o`0000CohacS00Co0000oldbcOo=</go
cC;=0_l0000:okM8]`03o`000?n6NHKoQWV600;oQWV60ol00005ohMhQ`03o`000?mYUVWoJIIY00Go
JIIY00?o0000of:MH_mRWF801?mRWF800ol0003oXEjQoj5NX@06oj5NX@03o`000?oL8mcog2?L00[o
g2?L0_l00002oo4>l@03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d02?om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om0_doo@;m008oo@;m003o`00
0?oS7>?ohacS00CohacS00?o0000oldbcOl000003?ngB;L00ol0003oQWV6o`000002o`0000WoQgR7
00?o0000ofVFJOmYUVT01?mYUVT00ol0003oHYeRof:MHP03of:MHP03o`000?nQGZ7oXEjQ00SoXEjQ
1_l00004om`Sg0;o00001Ooa3_400ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@01ood
2o@00ol0003ohacSon<Lh`06on<Lh`03o`000?ngB;Oo]dRg00co]dRg00?o0000ohMhQon7N8L02_n7
N8L00ol0003oJIIYofVFJ@04ofVFJ@04o`000?mRWF;oHYeRof:MHP;o00002onQGZ400ol0003ohQgR
on8MhP03on8MhPCo00002?oa3_400ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00Ooo@;m
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om0_doo@;m007oo@;m003o`000?oS
7>?ohacS00OohacS00?o0000okM8]ongB;L03?ngB;L00ol0003oQgR7ohMhQ`0;ohMhQ`03o`000?mY
UVWoJIIY00?oJIIY00Co0000of:MH_mRWF;o00003OnQGZ400ol0003ohQgRon8MhP06on8MhP03o`00
0?oa3_7ol@ka00Ool@ka00?o0000ooL8moog2?L01oog2?L00ol0003oo@;mood2o@06ood2o@04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000oo@;m?od2o@0
1_od2o@00ol0003ohacSon<Lh`09on<Lh`03o`000?ngB;Oo]dRg00Wo]dRg0_l0000>ohMhQ`?o0000
0omYUVT00ol0003oHYeRo`00000=oj5NX@03o`000?oR7N;ohQgR00OohQgR00?o0000oo4>lOoa3_40
2?oa3_4:o`0000Koo@;m0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom0_d00?o
0000on<LhooS7><02_oS7><00ol0003o]dRgokM8]`06okM8]`;o000000?o]dRgo`000?n7N8L02on7
N8L2o`0000?oSg2?1Ol0000>oj5NX@03o`000?oR7N;ohQgR00OohQgR00?o0000oo4>lOoa3_402?oa
3_400ol0003on`Ckoo/4n`06oo/4n`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@03ooT6n@Co00000_od2o@00ol0003ohacSon<Lh`0;
on<Lh`03o`000?ngB;Oo]dRg00?o]dRg0ol00004okM8]`03o`000?n7N8OoQgR700OoQgR70_l00008
ohm`S`03o`000?nQGZ7oXEjQ00goXEjQ00?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@07
oo4>l@03o`000?ok1?_on`Ck00Oon`Ck0ol000000oom0_go0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oi1_Won@Ki00Oon@Ki0_l0000?on<Lh`03o`000?ngB;Oo]dRg00;o00002?ngB;L00ol0
003oQgR7ohMhQ`05ohMhQ`03o`000?n?L8ooSg2?00SoSg2?00?o0000oj5NXOnQGZ403OnQGZ400ol0
003ohQgRon8MhP08on8MhP03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@09ooT6
n@03o`000?oS7>?ohacS00kohacS0_l0000;okM8]`03o`000?n7N8OoQgR700;oQgR70_l0000;ohm`
S`03o`000?nQGZ7oXEjQ00goXEjQ00?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@06oo4>
l@03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on@KiooT6n@0:ooT6n@03o`000?oS7>?ohacS00gohacS0_l0000<okM8]`04o`000?n7N8Oo0000
o`0000goSg2?00?o0000oj5NXOnQGZ403?nQGZ400ol0003ohQgRon8MhP09on8MhP03o`000?oa3_7o
l@ka00Kol@ka00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003on@KiooT6n@0:ooT6n@03o`000?oS7>?ohacS00cohacS00Co0000on4N
hOoQ7^7o00003?ngB;L00ol0003oSg2?ohm`S`0>ohm`S`03o`000?nQGZ7oXEjQ00SoXEjQ1?l0000;
on8MhP03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on@KiooT6n@0;ooT6n@03o`000?oS7>?ohacS
00_ohacS00?o0000on4NhOoQ7^400_oQ7^400ol0003o]dRgokM8]`09okM8]`03o`000?n?L8ooSg2?
00koSg2?00Co0000oj5NXOnQGZ7oXEjQ1ol00003ol@ka003o`000?oR7N;ohQgR00WohQgR00?o0000
oo4>lOoa3_401_oa3_400ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00con@Ki00?o0000on<LhooS7><02_oS7><00ol0
003ohAkQon4Nh@03on4Nh@03o`000?ngB;Oo]dRg00So]dRg00?o0000ohm`Son?L8l03_n?L8l4o`00
00_oa3_400?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@05oo4>l@03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi
1_T03?oi1_T7o`0000GohacS00?o0000on4NhOoQ7^401OoQ7^400ol0003o]dRgokM8]`07okM8]`03
o`000?n?L8ooSg2?00koSg2?00?o0000ol@ka?o4>l@03Oo4>l@00ol0003ohQgRon8MhP08on8MhP03
o`000?oa3_7ol@ka00Col@ka00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003on@KiooT6n@0=ooT6n@03o`000?oa3_7ol@ka00Col@ka
1Ol00009on4Nh@03o`000?ngB;Oo]dRg00Ko]dRg00?o0000ohm`Son?L8l03_n?L8l00ol0003oa3_4
ol@ka00=ol@ka003o`000?oR7N;ohQgR00SohQgR00Co0000oo4>lOoa3_7ol@ka1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooT6n@03o`000?oa3_7ol@ka00Wol@ka
0_l00009on4Nh@03o`000?ngB;Oo]dRg00Ko]dRg00?o0000ohm`Son?L8l03?n?L8l00ol0003oa3_4
ol@ka00?ol@ka0Ko00001?oR7N84o`0000Gon@Ki0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_oi1_T00ol0003o
l@kaoo4>l@09oo4>l@03o`000?oZ5N[o000000;o00001ooQ7^400ol0003o]dRgokM8]`05okM8]`03
o`000?n?L8ooSg2?00SoSg2?1Ol0000Aol@ka003o`000?oZ5N[ojQGZ00?ojQGZ1?l0000;ooT6n@03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000Oon@Ki
00?o0000oo4>lOoa3_402_oa3_400ol0003ojQGZonXEjP02onXEjP?o00001OoQ7^400ol0003o]dRg
okM8]`04okM8]`04o`000?n?L8ooSg2?ohm`S`Oo00001?o4>l@00ol0003oa3_4ol@ka00>ol@ka003
o`000?oZ5N[ojQGZ00OojQGZ00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?oi1_T00ol0003ol@ka
oo4>l@0;oo4>l@03o`000?oZ5N[ojQGZ00GojQGZ0ol00003on4Nh@04o`000?ngB;Oo]dRgokM8]`Ko
00003?o4>l@00ol0003oa3_4ol@ka00=ol@ka003o`000?oZ5N[ojQGZ00OojQGZ00?o0000ooT6nOoi
1_T02_oi1_T00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on@Kio`000?oa3_40
3?oa3_400ol0003ojQGZonXEjP08onXEjP?o000000CohAkQo`000?l0003o00000_oR7N800ol0003o
a3_4ol@ka00=ol@ka003o`000?o4>lCoa3_400coa3_400?o0000onXEj_oZ5NX02?oZ5NX00ol0003o
n@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo4>lOoa3_403?oa3_400ol0003ojQGZonXEjP0;onXEjP03o`000?oR7N;ohQgR00?o
hQgR00?o0000ol@ka?o4>l@03?o4>l@00ol0003odRgBo`00000=ol@ka003o`000?oZ5N[ojQGZ00So
jQGZ00?o0000ooT6nOoi1_T03?oi1_T3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_403?oa3_400ol0003ojQGZonXEjP0:onXEjP03o`00
0?oR7N;ohQgR00GohQgR00?o0000ol@ka?o4>l@02_o4>l@01?l0003odRgBom8]d_oB;M82o`0000[o
a3_400?o0000onXEj_oZ5NX02OoZ5NX00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo4>lOoa3_40
3?oa3_400ol0003ojQGZonXEjP09onXEjP03o`000?oR7N;ohQgR00KohQgR00?o0000ol@ka?o4>l@0
2Oo4>l@00ol0003odRgBom8]dP02om8]dP03o`000?oT6nCo000000;o00001oo4>l@00ol0003ojQGZ
onXEjP09onXEjP03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oZ
5N[ojQGZ00SojQGZ00?o0000on8Mh_oR7N801ooR7N800ol0003oa3_4ol@ka008ol@ka003o`000?oB
;M;odRgB00?odRgB00?o0000on@Ki?oT6n@00_oT6n@2o`0000Coa3_400?o0000onXEj_oZ5NX02_oZ
5NX00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo4>l@Ko00001?oZ5NX00ol0003ohQgRon8MhP08
on8MhP03o`000?o4>lCoa3_400Ooa3_400?o0000om8]d_oB;M800ooB;M800ol0003oi1_Ton@Ki005
on@Ki0?o000000?oa3_4o`000?oZ5NX02ooZ5NX00ol0003on@KiooT6n@09ooT6n@03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooX5
n_oj1OX01?l00006oo4>l@03o`000?oc3??ol`cc00Col`cc1?l0000<on8MhP03o`000?o4>lCoa3_4
00Goa3_400?o0000om8]d_oB;M801?oB;M800ol0003oi1_Ton@Ki008on@Ki003o`000?oZ5N[ojQGZ
00_ojQGZ00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000ooX5n_oj1OX01Ooj1OX3o`0000;ol@ka00?o0000oo<<looc
3?<02?oc3?<00ol0003ohQgRon8MhP0:on8MhP03o`000?o4>lCoa3_400Coa3_400?o0000om8]d_oB
;M801OoB;M800ol0003oi1_Ton@Ki008on@Ki003o`000?oZ5N[ojQGZ00WojQGZ1?l00008ooT6n@03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?oj1O[onPGj00WonPGj0_l0000<oo<<l`03o`000?oR7N;ohQgR00WohQgR
00?o0000ol@ka?o4>l@00oo4>l@00ol0003odRgBom8]dP05om8]dP03o`000?oT6nCoi1_T00[oi1_T
00?o0000onXEj_oZ5NX01?oZ5NX4o`0000Con0Oh00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ooX5n_oj1OX02ooj
1OX00ol0003ol`ccoo<<l`0:oo<<l`03o`000?oR7N;ohQgR00WohQgR00?o0000ol@ka?o4>l@00_o4
>l@00ol0003odRgBom8]dP06om8]dP03o`000?oT6nCoi1_T00[oi1_T00?o0000onXEj_oZ5NX01?l0
0009ooP7n0Ko00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=ooX5nP03o`000?oc3??ol`cc00[ol`cc00?o0000on8Mh_oR7N802OoR7N801Ol0003oa3_4ol@k
a?o4>lCo000000WodRgB00?o0000on@Ki?oT6n@02ooT6n@2o`0000gon0Oh00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ooj1OX00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oR7N;ohQgR00WohQgR00?o
0000ol@ka?l000002OoB;M800ol0003oi1_Ton@Ki00<on@Ki003o`000?oh1oSon0Oh00con0Oh00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oj1OX00ol0003ol`ccoo<<l`0:oo<<l`03o`000?oR7N;o
hQgR00SohQgR1Ol00008om8]dP03o`000?oT6nCoi1_T00coi1_T00?o0000ooP7n?oh1oP02ooh1oP0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000SonPGj00?o0000oo<<looc3?<02_oc3?<00ol0003ohQgRon8MhP07on8M
hP03o`000?oX5nSoj1OX00?oj1OX0ol00005om8]dP03o`000?oT6nCoi1_T00_oi1_T00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000ooX5n_oj1OX01Ooj1OX2o`0000co
l`cc00?o0000on8Mh_oR7N801OoR7N800ol0003oj1OXonPGj007onPGj0?o000000?odRgBo`000?oT
6n@03OoT6n@00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooX5nP03o`000?ol0ocoo0?l00;o00002_oc3?<00ol0003ohQgRon8MhP03on8MhP;o0000
3OoX5nP2o`0000goi1_T0ol0000=ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooj1O[o0000oo`3o004oo`3o003o`000?oc3??ol`cc00Ool`cc00Co0000on8Mh_oR7N;ohQgR
0_l00002ooH9mP03o`000?oX5nSoj1OX00coj1OX3Ol00003ooP7n003o`000?oh1oSon0Oh00[on0Oh
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008oo<<l`03o`000?oR7N;o000000GomPWf
00?o0000onPGj?oX5nP02ooX5nP00ol0003okQ7^onhAkP09onhAkP03o`000?oh1oSon0Oh00;on0Oh
0_l00009ooP7n003o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?ol`cc0ol0
0007ooH9mP03o`000?oX5nSoj1OX00[oj1OX00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on0OhooP7
n004ooP7n0;o00001ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo0?loo`3o?ol0o`3o`0000;onPGj00?o0000ooH9m_of2OH01_of2OH00ol0003oj1OXonPG
j008onPGj003o`000?o^4NkokQ7^00[okQ7^00?o0000ooP7n?oh1oP01_oh1oP00ol0003on0OhooP7
n004ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?ol0oco
o0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`000008ooH9mP03o`000?oX5nSoj1OX00Ooj1OX00?o
0000onhAk_o^4Nh02_o^4Nh00ol0003on0OhooP7n007ooP7n0;o00001?oh1oP00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l00Coo0?l00?o0000ooX5n_oj1OX00_oj1OX0
0ol0003omPWfooH9mP07ooH9mP03o`000?oX5nSoj1OX00Koj1OX00?o0000onhAk_o^4Nh02_o^4Nh0
0ol0003on0OhooP7n009ooP7n005o`000?oh1oSon0OhooP7n?l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003onPGjooX5nP03
ooX5nP03o`000?of2OKomPWf00OomPWf00?o0000onPGj?oX5nP01OoX5nP00ol0003okQ7^onhAkP0:
onhAkP03o`000?oh1oSon0Oh00Won0Oh1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?oj1O[onPGj00?onPGj00?o0000
ooH9m_of2OH02?of2OH00ol0003oj1OXonPGj004onPGj003o`000?o^4NkokQ7^00WokQ7^00?o0000
ooP7n?oh1oP02?oh1oP2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?ol0ocoo0?l
00Goo0?l00?o0000ooX5n_oj1OX01?oj1OX00ol0003omPWfooH9mP09ooH9mP03o`000?oX5nSoj1OX
00;oj1OX00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on0OhooP7n006ooP7n0;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`01Ool0o`00ol0003onPGjooX5nP05ooX5nP03o`000?of2OKomPWf00WomPWf00Go0000onPGj?oX
5nSoj1OXo`00000<onhAkP03o`000?oh1oSon0Oh00Con0Oh0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oj1O[onPGj00GonPGj00?o0000ooH9m_of
2OH02_of2OH00ol0003oj1OXo`000004o`0000WokQ7^00?o0000ooP7n?oh1oP00_oh1oP2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003onPGjooX5nP07ooX5nP;o0000
2oof2OH00ol0003onPGjooX5nP03ooX5nPOo00000_o^4Nh00ol0003on0OhooP7n002o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003oo0?loo`3o?ol0oco000000Soo0?l00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;m
o`000002o`0000SomPWf00?o0000ooX5n_oj1OX02_oj1OX5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ol0oco000000Woo0?l00?o
0000ooX5n_oj1OX01_oj1OX00ol0003oo@;mood2o@03ood2o@?o00001?of2OH00ol0003onPGjooX5
nP0=ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP07
ooX5nP03o`000?om0_goo@;m00Koo@;m0ol000000oof2OKo0000ooX5nP0>ooX5nP03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?ol0ocoo0?l00;oo0?l1_l00008ooX5nP03o`000?om0_goo@;m00[oo@;m00?o0000ooX5
n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?om0_goo@;m00[o
o@;m00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003oo@;mood2o@0;ood2o@03o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?oj1O[onPGjo`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003onPGjo`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01_l00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Co003o0_ooo`07o`00o`;oool02?l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`07o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01ol00?l2oooo
00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?oo
ool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Co
ool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`06o`00o`;oool01Ol00?l3oooo00Ko003o0_ooo`06o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00
ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool0
1ol00?l2oooo00?o003o0oooo`07o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2?l00?l00oooo`3o003oo`00o`03oooo00So003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`09o`00o`Coool02Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o
0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol00?l00oooo`3o003oo`00
o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o003ooooo0?ooo`002?l0
0?l4oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Y
o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04
o`00o`Coool000?o003ooooo0?l00?l00_ooo`07o`00o`?oool00_l00?l2oooo00So003o0_ooo`06
o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo
00Go003o00?oool0o`00ool00?l05ol00?l2oooo00Ko003o0oooo`04o`00o`;oool01ol00?l2oooo
00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So003o0oooo`05o`00o`?o
ool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o
0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`07o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l0
0?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00?o003o0_oo
o`06o`00o`;oool01_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool01_l00?l00olb</coool0oooo
001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3oooo00Oo003o00?oool0o`00ool00?l05_l00?l5
oooo00Co003o0_ooo`04o`00o`;oool01Ol00?l4oooo00So003o0_ooo`02o`00o`;oool01Ol00?l5
oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00
o`Goool02?l00?l2oooo00Wo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o
;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(820) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.992 .008 .992 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.989 .011 .989 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.97 .03 .97 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.976 .024 .976 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.945 .055 .945 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.984 .016 .984 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.995 .005 .995 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.888 .112 .888 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.966 .034 .966 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.964 .036 .964 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.97 .03 .97 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.979 .021 .979 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.989 .011 .989 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.952 .048 .952 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.978 .022 .978 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.921 .079 .921 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.986 .014 .986 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.976 .024 .976 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.962 .038 .962 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.974 .026 .974 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.899 .101 .899 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.983 .017 .983 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.956 .044 .956 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.923 .077 .923 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.737 .263 .737 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.786 .214 .786 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.98 .02 .98 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.932 .068 .932 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.937 .063 .937 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.754 .246 .754 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.715 .285 .715 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.663 .337 .663 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.923 .077 .923 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.945 .055 .945 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.933 .067 .933 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.89 .11 .89 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.778 .222 .778 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.986 .014 .986 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.972 .028 .972 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.767 .233 .767 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.678 .322 .678 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.871 .129 .871 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.425 .575 .425 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.419 .581 .419 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.501 .499 .501 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.788 .212 .788 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.803 .197 .803 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.987 .013 .987 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.453 .547 .453 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.41 .59 .41 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.954 .046 .954 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.593 .407 .593 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.721 .279 .721 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.917 .083 .917 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.917 .083 .917 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.64 .36 .64 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.881 .119 .881 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.35 .65 .35 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.836 .164 .836 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.722 .278 .722 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.137 .863 .137 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.311 .689 .311 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.979 .021 .979 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.233 .767 .233 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.181 .819 .181 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.888 .112 .888 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.981 .019 .981 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.484 .516 .484 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.146 .854 .146 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.217 .783 .217 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.801 .199 .801 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.313 .687 .313 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.53 .47 .53 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.99 .01 .99 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.204 .796 .204 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.036 .964 .036 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.127 .873 .127 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.021 .979 .021 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.344 .656 .344 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.532 .468 .532 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.962 .038 .962 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.566 .434 .566 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.639 .361 .639 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.041 .959 .041 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.026 .974 .026 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.098 .902 .098 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.133 .867 .133 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.773 .227 .773 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.909 .091 .909 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.938 .062 .938 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.454 .546 .454 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.097 .903 .097 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.824 .176 .824 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.202 .798 .202 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.418 .582 .418 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.104 .896 .104 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.266 .734 .266 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.853 .147 .853 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.389 .611 .389 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.11 .89 .11 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.981 .019 .981 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.896 .104 .896 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.931 .069 .931 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.261 .739 .261 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.972 .028 .972 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.017 .983 .017 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.633 .367 .633 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.604 .396 .604 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.108 .892 .108 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.238 .762 .238 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.512 .488 .512 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.769 .231 .769 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.111 .889 .111 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.997 .003 .997 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.986 .014 .986 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.06 .94 .06 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.208 .792 .208 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.275 .725 .275 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.973 .027 .973 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.488 .512 .488 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.993 .007 .993 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.418 .582 .418 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.292 .708 .292 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.248 .752 .248 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.917 .083 .917 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.89 .11 .89 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.886 .114 .886 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.191 .809 .191 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.522 .478 .522 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.675 .325 .675 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.864 .136 .864 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.971 .029 .971 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.492 .508 .492 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.736 .264 .736 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.379 .621 .379 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.96 .04 .96 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.943 .057 .943 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.858 .142 .858 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.976 .024 .976 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.497 .503 .497 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.614 .386 .614 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.989 .011 .989 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.525 .475 .525 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.905 .095 .905 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.69 .31 .69 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.824 .176 .824 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.632 .368 .632 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.977 .023 .977 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.963 .037 .963 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.968 .032 .968 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.982 .018 .982 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.777 .223 .777 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.961 .039 .961 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.714 .286 .714 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.746 .254 .746 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.862 .138 .862 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.864 .136 .864 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.997 .003 .997 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.958 .042 .958 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.807 .193 .807 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.985 .015 .985 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.954 .046 .954 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.933 .067 .933 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.918 .082 .918 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.87 .13 .87 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.883 .117 .883 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.832 .168 .832 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.93 .07 .93 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.955 .045 .955 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.98 .02 .98 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.966 .034 .966 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.972 .028 .972 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.985 .015 .985 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.964 .036 .964 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.891 .109 .891 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.958 .042 .958 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.973 .027 .973 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.986 .014 .986 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.982 .018 .982 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.985 .015 .985 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.995 .005 .995 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.97 .03 .97 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.976 .024 .976 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.983 .017 .983 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.991 .009 .991 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo@;mood2oOl0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ood2oOom0_d00_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000coo@;m00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?om
0_goo@;m00_oo@;m0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo0?loo`3o006
oo`3o003o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?ol0ocoo0?loo`3o0;o00002_oo0?l2o`000003oo`3o?l0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ood2oOl000002ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_go
o@;m00Woo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?ol0oco
o0?l00Coo0?l0_l00005ool0o`?o00001?ol0o`00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo0?l0_l000000ooo
0?oo0000o`000007oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol
0o`01ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ok1?_on`Cko`0000?oo`3o0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@05ood2
o@03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003ool0o`00ol0003oo0?loo`3o008oo`3
o003o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo/4n`03o`000?oo0?oo000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o009oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o
o0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo/4n`03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o00:oo`3o004o`000?om0_goo@;mood2o@?o0000
3oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_on`Ck1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02ool0o`01?l0003oo@;mo`00
0?l00003ooD:m@;o00003?om0_d2o`00013oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo/4nook1?/02ook1?/01?l0003ol0o`
oo0?l?o`3o05o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00<oo`3o003
o`000?oe2_Gom@[e00Gom@[e0_l00008ood2o@;o00000_of2OH00ol0003oo0?loo`3o00=oo`3o003
o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ook1?/00ol0003ol0o`oo0?l007oo0?l0Ko00000_oo0?l4o`0000goo0?l00?o0000ooD:mOoe2_D0
1ooe2_D2o`0000Goo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003oo0?loo`3o00<oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ook1?/00ol0003ol0o`oo0?l00<oo0?l0?o00001?oh1oP3o`0000Woo0?l00?o
0000ooD:mOoe2_D02_oe2_D2o`000003ood2oOl0003o000000OomPWf00?o0000oo`3o?ol0o`02ool
0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo/4nook1?/03_ok1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oh1oSon0Oh00Kon0Oh0ol00005
oo`3o003o`000?oe2_Gom@[e00gom@[e00?o0000ooH9m_of2OH02?of2OH00ol0003oo0?loo`3o009
oo`3o003o`000?ol0ocoo0?l00goo0?l00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000oon`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on0OhooP7n00:
ooP7n0?o000000?oo0?lo`000?oe2_D03ooe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?ol0oco
o0?l00Soo0?l00?o0000oo`3o?ol0o`03_ol0o`3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooh
1oSo0000oo/4n`0>oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooP7n?oh1oP03Ooh1oP00ol0
003om@[eooD:m@0?ooD:m@03o`000?of2OKomPWf00[omPWf2ol0000;oo`3o0Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo0?lo`000?oo0?oo0000
00SooP7n0ol00005ooP7n003o`000?ok1?_on`Ck00con`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0
003on0OhooP7n00=ooP7n0;o00004?oe2_D00ol0003omPWfooH9mP0:ooH9mP03o`000?od2oCom0_d
00Oom0_d00?o0000oo`3o?ol0o`00_ol0o`7o`0000ComPWf00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo0?loo`3o?ol0o`2o`00
00GooP7n0ol00009ooP7n0;o00002ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oh1oSon0Oh
00gon0Oh00Co0000on<LhooS7>?o00003ooe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCo
m0_d00Wom0_d1?l0000;ooH9mP03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ooP7no`000002o`00
00con0Oh00Co0000onXEj_l0003o00002Ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oh1oSo
n0Oh00gon0Oh00Go0000on<LhooS7>?ohacSo`00000=ooD:m@03o`000?of2OKomPWf00[omPWf00?o
0000oo@;m?od2o@02Ood2o@00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003on0OhooP7n00<ooP7n003o`000?oZ5N[ojQGZ00;ojQGZ0_l00007oo/4n`03o`000?o`3o3o
l0o`00col0o`00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ohacSon<Lh`03on<Lh`03o`000?oe2_Go
m@[e00[om@[e00?o0000ooH9m_of2OH02_of2OH00ol0003om0_doo@;m009oo@;m003o`000?of2OKo
mPWf00comPWf00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo0?loo`3o006oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000onXE
j_oZ5NX01OoZ5NX00ol0003on`Ckoo/4n`03oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003ohacSon<Lh`04on<Lh`03o`000?oe2_Gom@[e00Wom@[e00?o0000ooH9
m_of2OH02Oof2OH00ol0003om0_doo@;m00:oo@;m003o`000?of2OKomPWf00comPWf00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o007oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000onXEj_oZ5NX01_oZ5NX2o`0000?o
n`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on0OhooP7n00<ooP7n003o`000?oS7>?ohacS00Ko
hacS00?o0000ooD:mOoe2_D02?oe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00[o
m0_d00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on0OhooP7n00:ooP7n003o`00
0?oZ5N[ojQGZ00WojQGZ0_l000000ook1?_o0000oo0?l00<oo0?l0?o00003_oh1oP00ol0003ohacS
on<Lh`07on<Lh`03o`000?oe2_Gom@[e00Oom@[e00?o0000ooH9m_of2OH02Oof2OH00ol0003om0_d
oo@;m00;oo@;m003o`000?of2OKomPWf00comPWf00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003on0OhooP7
n009ooP7n003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000oo0?l?o`3o002_o`3o02o`0000?ofRGJ00?o
0000ooP7n?oh1oP02_oh1oP00ol0003ohacSon<Lh`09on<Lh`03o`000?oe2_Gom@[e00Kom@[e00?o
0000ooH9m_of2OH02?of2OH00ol0003om0_doo@;m00<oo@;m003o`000?of2OKomPWf00comPWf00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ojQGZonXEjP0<onXEjP03o`000?o`3o3ol0o`00Sol0o`0_l00006omXUfP;o00002_oh1oP0
0ol0003ohacSon<Lh`0:on<Lh`03o`000?oe2_Gom@[e00Gom@[e00?o0000ooH9m_of2OH02?of2OH0
0ol0003om0_doo@;m00<oo@;m003o`000?of2OKomPWf00comPWf00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000onXEj_oZ5NX03_oZ5NX00ol0003ol0o`oo0?l004
oo0?l0?o00002_oJ9MX00ol0003on0OhooP7n007ooP7n003o`000?oS7>?ohacS00_ohacS00?o0000
ooD:mOoe2_D00ooe2_D00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00com0_d00?o0000
ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000onXEj_oZ5NX03ooZ5NX01?l0
003ol0o`oo0?l?o`3o02o`0000kofRGJ0_l00006ooP7n003o`000?oS7>?ohacS00gohacS00?o0000
ooD:mOoe2_D00_oe2_D00ol0003omPWfooH9mP08ooH9mP03o`000?od2oCom0_d00com0_d0ol0000=
ooH9mP03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo0?l00?o0000ooP7n?oh1oP01_oh1oP00ol0003ojQGZonXEjP0@onXEjPCo00004_oJ9MX00ol0
003on0OhooP7n003ooP7n003o`000?oS7>?ohacS00kohacS00Go0000ooD:mOoe2_Gom@[eo`000005
ooH9mPOo00003?od2o@01Ol0003okQ7^onhAk_o^4Nko000000comPWf00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo0?l00?o0000ooP7n?oh1oP01_oh1oP00ol0003ojQGZonXEjP0=
onXEjP?o000000CoeRWFo`000?l0003o00004ooJ9MX2o`0000;on0Oh00?o0000on<LhooS7><04?oS
7><00ol0003om@[eo`000006o`0000Oog2?L00?o0000oo@;m?od2o@02?od2o@00ol0003okQ7^onhA
kP03onhAkP;o00002?of2OH3o`0000Koo@;m1?l00002oo/4n`03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?of2OH3o`0000goo0?l00?o0000ooP7n?oh1oP01?oh1oP00ol0003ojQGZonXE
jP0;onXEjP?o00000ooF:MH01Ol0003ocC;=o`000?nSG:?o000001CofRGJ00?o0000ooP7n?l00000
4ooS7><00ol0003og2?Lom`Sg00=om`Sg003o`000?od2oCom0_d00Gom0_d0_l00008onhAkP03o`00
0?of2OKomPWf00Go00000ooe2_D00ol0003oo@;mood2o@03o`0000Oon`Ck00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000ComPWf0ol0000:oo`3o003o`000?oh1oSon0Oh00?on0Oh
00?o0000onXEj_oZ5NX02OoZ5NX3o`0000GoeRWF00Co0000oldbcOo=</go00000_nSG:<00ol0003o
fRGJomXUfP0BomXUfP03o`000?oS7>?ohacS01;ohacS00?o0000om`Sg?oL8m`03_oL8m`00ol0003o
m0_doo@;m003oo@;m003o`000?o^4NkokQ7^00WokQ7^0_l00009ooD:m@;o00002_ok1?/00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooH9mP;o00001ool0o`5o`0000;o
n0Oh00?o0000onXEj_oZ5NX01_oZ5NX3o`0000SoeRWF00Co0000oldbcOo=</go00000onSG:<00ol0
003ofRGJomXUfP0AomXUfP03o`000?oS7>?ohacS017ohacS00?o0000om`Sg?oL8m`04?oL8m`01Ol0
003om0_doo@;m?od2oCo000000cokQ7^00?o0000ooD:mOoe2_D02?oe2_D00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooH9m_of2OH01oof2OH3o`00
0004oo`3o?l0003o0000o`0000GokQ7^0_l00006onXEjP?o00002_oF:MH01Ol0003ocC;=oldbcOo=
</go000000CoXebS00?o0000omXUf_oJ9MX04?oJ9MX00ol0003ohacSon<Lh`0Aon<Lh`03o`000?oL
8mcog2?L017og2?L00?o0000oo@;m?l000003Oo^4Nh00ol0003om@[eooD:m@08ooD:m@03o`000?ok
1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooH9m_of2OH02_of2OH00ol0003okQ7^onhAkP08onhAkP03o`000?oZ5N[ojQGZ00?o00003OoF:MH0
1Ol0003ocC;=oldbcOo=</go000000GoXebS00?o0000omXUf_oJ9MX03ooJ9MX00ol0003ohacSon<L
h`0Aon<Lh`03o`000?oL8mcog2?L01;og2?L00?o0000onhAk_o^4Nh03?o^4Nh00ol0003om@[eooD:
m@08ooD:m@03o`000?ok1?_on`Ck00_on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o^4NkokQ7^00WokQ7^0_l0000?omHYeP03o`000?o=</go
cC;=00;ocC;=00?o0000oj=LXonSG:<01?nSG:<00ol0003ofRGJomXUfP0=omXUfP?o00004OoS7><0
0ol0003og2?Lom`Sg00Com`Sg003o`000?o^4NkokQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D0
0ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o^4NkokQ7^00WokQ7^00?o0000omHYe_oF:MH03OoF:MH0
0ol0003ocC;=oldbc@03oldbc@03o`000?nSG:?oXebS00GoXebS00?o0000omXUf_oJ9MX02_oJ9MX2
o`0000?oVVFJ00?o0000on<LhooS7><03_oS7><00ol0003og2?Lom`Sg00Com`Sg003o`000?o^4Nko
kQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_omPWf00?o0000onhA
k_o^4Nh02oo^4Nh00ol0003oeRWFomHYeP0<omHYeP03o`000?o=</gocC;=00?ocC;=00?o0000oj=L
XonSG:<01_nSG:<00ol0003ofRGJomXUfP07omXUfP;o00001_nJIIX2o`0000kohacS00?o0000om`S
g?oL8m`04ooL8m`00ol0003okQ7^onhAkP0;onhAkP03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4
nook1?/03?ok1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_omPWf00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oeRWFomHYeP0;omHY
eP03o`000?o=</gocC;=00CocC;=00?o0000oj=LXonSG:<01onSG:<00ol0003ofRGJomXUfP05omXU
fP03o`000?nJII[oVVFJ00SoVVFJ00?o0000on<LhooS7><02_oS7><00ol0003og2?Lom`Sg00Dom`S
g003o`000?o^4NkokQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_omPWf00?o0000onhAk_o^4Nh02oo^4Nh00ol0003oeRWFomHYeP0;omHYeP03o`000?o=</gocC;=
00CocC;=00?o0000oj=LXonSG:<02?nSG:<00ol0003ofRGJomXUfP02omXUfP;o00003?nJIIX2o`00
00[ohacS00?o0000om`Sg?oL8m`05?oL8m`00ol0003okQ7^onhAkP0;onhAkP03o`000?oe2_Gom@[e
00Wom@[e00?o0000oo/4nook1?/03Ook1?/00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooH9m_of2OH02?of2OH00ol0003okQ7^onhAkP0<onhAkP03
o`000?oF:MKoeRWF00WoeRWF00?o0000oldbcOo=</d01Oo=</d00ol0003oXebSoj=LX`09oj=LX`04
o`000?oJ9M[o0000o`00013oVVFJ0_l00008on<Lh`03o`000?oL8mcog2?L01Cog2?L0ol0000;onhA
kP03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4nook1?/03Ook1?/01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooH9
m_of2OH02?of2OH00ol0003okQ7^onhAkP0;onhAkP;o00002_oF:MH00ol0003ocC;=oldbc@06oldb
c@03o`000?nSG:?oXebS00[oXebS00?o0000oiYUV_nJIIX04_nJIIX00ol0003ohacSon<Lh`04on<L
h`03o`000?oL8mcog2?L01Gog2?L00?o0000om@[e?oD:m@01Ol00005onhAkP03o`000?oe2_Gom@[e
00[om@[e00?o0000oo/4nook1?/03_ok1?/3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooH9m_of2OH01oof2OH00ol0003okQ7^onhAkP0;onhAkP04
o`000?o4>lCoa3_4o`0000WoeRWF00?o0000oldbcOo=</d01_o=</d00ol0003oXebSoj=LX`0:oj=L
X`03o`000?nJII[oVVFJ01?oVVFJ0_l00003on<Lh`Co00005?oL8m`00ol0003oe2_Dom@[e006om@[
e0Co000000?okQ7^o`000?oe2_D02ooe2_D00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooH9m_of
2OH01oof2OH00ol0003okQ7^onhAkP09onhAkP;o00001?o4>l@00ol0003oeRWFomHYeP05omHYeP03
o`000?o=</gocC;=00OocC;=00?o0000oj=LXonSG:<02_nSG:<00ol0003oVVFJoiYUVP0EoiYUVP03
o`000?oS7>?o000000Co/4n`0ol0000@om`Sg003o`000?oD:mCoe2_D00_oe2_D0_l0000<ooD:m@03
o`000?ok1?_on`Ck00con`Ck0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?of2OKomPWf00OomPWf00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oa3_4
ol@ka005ol@ka003o`000?oF:MKoeRWF00CoeRWF00?o0000oldbcOo=</d01oo=</d00ol0003oXebS
oj=LX`0:oj=LX`03o`000?nJII[oVVFJ01KoVVFJ00?o0000ok1?/?n`Ck001_n`Ck03o`0000cog2?L
00?o0000om@[e?oD:m@03OoD:m@00ol0003om@[eooD:m@09ooD:m@Go00002Ook1?/2o`000003ood2
oOl0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooH9m_of2OH01_of
2OH00ol0003okQ7^onhAkP07onhAkP03o`000?o4>lCoa3_400Ooa3_400?o0000omHYe_oF:MH00_oF
:MH00ol0003ocC;=oldbc@08oldbc@03o`000?nSG:?oXebS00WoXebS00?o0000oiYUV_nJIIX05onJ
IIX00ol0003o/4n`ok1?/009ok1?/0?o00002OoL8m`00ol0003oe2_Dom@[e00>om@[e0Ko00001?oe
2_D00ol0003on@KiooT6n@03ooT6n@Go00000_ok1?/2o`0000Coo@;m00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?ol0ocoo0?loo`3o?l000002ook1?/00ol0003omPWfooH9mP06ooH9mP03o`000?o^
4NkokQ7^00GokQ7^0_l0000;ol@ka004o`000?oF:MKoeRWFo`0000_ocC;=00?o0000oj=LXonSG:<0
2OnSG:<00ol0003oVVFJoiYUVP0FoiYUVP03o`000?n`Ck3o/4n`00go/4n`0ol00005om`Sg003o`00
0?oD:mCoe2_D00ooe2_D00?o0000on@Ki?oT6n@00ooT6n@4o`0000_on@Ki0_l00006ood2o@03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o002oo`3o0ko00001_of2OH00ol0003okQ7^onhA
kP05onhAkP03o`000?o4>lCoa3_400coa3_400?o0000omHYe_l000002oo=</d00ol0003oXebSoj=L
X`07oj=LX`?o00006?nJIIX00ol0003o/4n`ok1?/00@ok1?/0?o000000?og2?Lo`000?oD:m@04?oD
:m@00ol0003oi1_Ton@Ki007on@Ki003o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom
0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005oo`3o003o`000?og2?Oom`Sg00_om`Sg0_l00004
ooH9mP03o`000?o^4NkokQ7^00?okQ7^0_l0000@ol@ka003o`000?o=</gocC;=00[ocC;=00?o0000
oj=LXonSG:<00onSG:<4o`0000;oM8]d00?o0000oiYUV_nJIIX05OnJIIX00ol0003o/4n`ok1?/00D
ok1?/003o`000?oD:mCoe2_D013oe2_D00?o0000on@Ki?oT6n@01ooT6n@00ol0003on@KiooT6n@0:
ooT6n@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Goo0?l00?o0000ooL8moog2?L03Oog2?L6o`0000?okQ7^00?o0000ol@ka?o4>l@04?o4>l@00ol0
003ocC;=oldbc@0:oldbc@03o`000?nSG:?o000000?o00001omdRg@00ol0003oVVFJoiYUVP0DoiYU
VP03o`000?n`Ck3o/4n`01Co/4n`00?o0000om@[e?oD:m@03ooD:m@00ol0003oi1_Ton@Ki008on@K
i003o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oV6NKoiQWV00?o
iQWV00?o0000onhAk_l000004oo4>l@4o`0000WocC;=0_l0000<ogB;M003o`000?nJII[oVVFJ01?o
VVFJ00?o0000ok1?/?n`Ck005On`Ck000ol0003oe2_Dom@[e00>om@[e003o`000?oT6nCoi1_T00So
i1_T00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooL8moog2?L02oog2?L00ol0003oiQWVonHIiP05onHIiP03o`00
0?o4>lCoa3_401;oa3_400Co0000og^4NomkQ7_oNhAk1Ol00003oldbc@03o`000?mdRgCoM8]d00go
M8]d0ol0000@oiYUVP;o00006?n`Ck000ol0003oe2_Dom@[e00=om@[e003o`000?oT6nCoi1_T00Wo
i1_T00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo0?l00?o0000ooL8moog2?L02_og2?L00ol0003oiQWVonHIiP06onHIiP03o`00
0?o4>lCoa3_4017oa3_400?o0000og^4NomkQ7/01omkQ7/3o`00013oM8]d00?o0000od:m@_m2_D80
1Ol00009oiYUVP;o000000?oJiA[o`000?n`Ck005on`Ck000ol0003oe2_Dom@[e00=om@[e003o`00
0?oT6nCoi1_T00Woi1_T00?o0000ooT6nOoi1_T02?oi1_T2o`0000[oo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8
m`0:ooL8m`03o`000?oV6NKoiQWV00OoiQWV00?o0000ol@ka?o4>l@03oo4>l@00ol0003oNhAkog^4
N`0:og^4N`03o`000?mdRgCoM8]d00goM8]d00?o0000od:m@_m2_D801_m2_D84o`0000CoVVFJ00?o
0000of^DJom[U6/00_m[U6/00ol0003o/4n`ok1?/00Fok1?/003o`000?oD:mCoe2_D00_oe2_D00?o
0000on@Ki?oT6n@02ooT6n@00ol0003on@KiooT6n@06ooT6n@03o`000?ol0oco000000[oo@;m00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02?ol0o`=
o`0000[oiQWV00?o0000ol@ka?o4>l@03oo4>l@00ol0003oNhAkog^4N`0;og^4N`03o`000?mdRgCo
M8]d00coM8]d00?o0000od:m@_m2_D802_m2_D84o`0000GoJiA[00?o0000ok1?/?n`Ck005_n`Ck00
0ol0003oe2_Dom@[e00:om@[e003o`000?oT6nCoi1_T00coi1_T00?o0000ooT6nOoi1_T01?oi1_T2
o`0000?oo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?of2OKomPWf00WomPWf00?o0000onHI
i_oV6NH02OoV6NH00ol0003oa3_4ol@ka00=ol@ka003o`000?mkQ7_oNhAk00coNhAk00?o0000ogB;
M?mdRg@03?mdRg@00ol0003o@[e2od:m@P0;od:m@P03o`000?m6^DKo000000KoJiA[00?o0000ok1?
/?n`Ck005_n`Ck000ol0003oe2_Dom@[e009om@[e003o`000?oT6nCoi1_T00coi1_T00?o0000ooT6
nOoi1_T00ooi1_T00ol0003oo0?loo`3o003oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003o
mPWfooH9mP08ooH9mP03o`000?oV6NKoiQWV00_oiQWV00?o0000ol@ka?o4>l@02?o4>l@4o`0000oo
NhAk00?o0000ogB;M?mdRg@02omdRg@00ol0003o@[e2od:m@P0;od:m@P04o`000?m6^DKoA[U6o`00
00OoJiA[00?o0000ok1?/?n`Ck005On`Ck000ol0003oe2_Dom@[e008om@[e003o`000?oT6nCoi1_T
00goi1_T00?o0000ooT6nOoi1_T00_oi1_T00ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m
00Ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo`3o?ol
0o`01Ool0o`00ol0003omPWfooH9mP08ooH9mP03o`000?oV6NKoiQWV00_oiQWV00?o0000ol@ka?o4
>l@00oo4>l@5o`0000?oP7n000?o0000og^4NomkQ7/03_mkQ7/00ol0003oM8]dogB;M00:ogB;M003
o`000?m2_D;o@[e200[o@[e200Go0000odJiA_m6^DKoA[U6o`000007of^DJ`03o`000?n`Ck3o/4n`
01Go/4n`00?o0000om@[e?oD:m@02?oD:m@00ol0003oi1_Ton@Ki00=on@Ki003o`000?oi1_Won@Ki
00;o00002?ol0o`00ol0003oo@;mood2o@08ood2o@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooH9m_of2OH02?of2OH00ol0003oiQWVonHIiP0<onHIiPGo00002On0Oh000ol0003o
NhAkog^4N`0<og^4N`;o00003?mdRg@00ol0003o@[e2od:m@P0:od:m@P05o`000?m6^DKoA[U6odJi
A_l000002?m[U6/00ol0003o/4n`ok1?/00Dok1?/0?o00001ooD:m@00ol0003oi1_Ton@Ki00>on@K
i003o`000?oi1_Wo000000_oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o004oo`3o003o`000?of2OKomPWf00Oo
mPWf00?o0000onHIi_oV6NH03?oV6NH01?l0003o`Ck1ol4n`Ol0000;oh1oP003o`000?mkQ7_oNhAk
00_oNhAk00Co0000ocC;=?ldbcCo00002_mdRg@00ol0003o@[e2od:m@P0:od:m@P03o`000?m6^DKo
A[U600;oA[U600?o0000of^DJom[U6/01_m[U6/00ol0003o/4n`ok1?/00Aok1?/0?o00000onfBKH0
0ol0003oe2_Dom@[e004om@[e003o`000?oT6nCoi1_T00goi1_T1?l0000;oo`3o003o`000?om0_go
o@;m00Goo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo`3
o?ol0ocoo0?l1?l00008ooH9mP03o`000?oV6NKoiQWV00_oiQWV00?o0000ol4n`Oo1?/400_o1?/40
0ol0003oP7n0oh1oP008oh1oP003o`000?mkQ7_oNhAk00[oNhAk00?o0000ocC;=?ldbc@00_ldbc@0
0ol0003oM8]dogB;M003ogB;M0Go00002om2_D800ol0003oA[U6odJiAP03odJiAP03o`000?m[U6_o
JiA[00OoJiA[00?o0000ok1?/?n`Ck003_n`Ck02o`0000Oo]TVf00?o0000om@[e?oD:m@00_oD:m@0
0ol0003oi1_Ton@Ki00=on@Ki003o`000?oh1oSon0Oh00;on0Oh00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo@;mood2o@03ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oh1oP00ol0003omPWfooH9mP05ooH9mP03o`000?oV6NKoiQWV00[oiQWV00?o0000ol4n
`Oo1?/400oo1?/400ol0003oP7n0oh1oP009oh1oP003o`000?mkQ7_oNhAk00SoNhAk00?o0000ocC;
=?ldbc@01?ldbc@5o`0000Co<l`c00?o0000od:m@_m2_D802Om2_D800ol0003oA[U6odJiAP03odJi
AP03o`000?m[U6_oJiA[00SoJiA[00?o0000ok1?/?n`Ck002_n`Ck03o`0000[o]TVf00Go0000om@[
e?oD:mCoe2_Do`00000>on@Ki003o`000?oh1oSon0Oh00Con0Oh0_l00009oo`3o003o`000?om0_go
o@;m00;oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooP7
n?oh1oP01Ooh1oP00ol0003omPWfooH9mP03ooH9mP03o`000?oV6NKoiQWV00[oiQWV00?o0000ol4n
`Oo1?/401?o1?/400ol0003oP7n0oh1oP009oh1oP003o`000?mkQ7_oNhAk00OoNhAk00?o0000ocC;
=?ldbc@01Oldbc@00ol0003o<l`coc?<<`07oc?<<`03o`000?m2_D;o@[e200Oo@[e200?o0000odJi
A_m6^DH01?m6^DH00ol0003oJiA[of^DJ`08of^DJ`03o`000?n`Ck3o/4n`00So/4n`0_l0000>okI9
]PCo00003?oT6n@2o`0000Won0Oh00?o0000oo`3o?ol0o`01ool0o`01?l0003oo@;mood2oOl0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on0OhooP7n007ooP7n0;o00000oof2OH00ol0
003oiQWVonHIiP09onHIiP03o`000?o1?/7o`Ck100Ko`Ck100?o0000oh1oP?n0Oh002On0Oh000ol0
003oNhAkog^4N`05og^4N`03o`000?ldbcCo=</d00Ko=</d00?o0000oc?<<olcc3<02?lcc3<00ol0
003o@[e2od:m@P06od:m@P03o`000?m6^DKoA[U600CoA[U600?o0000of^DJom[U6/02Om[U6/4o`00
00?o/4n`0ol0000@okI9]P05o`000?oR7N;ohQgRon8Mh_l000002_oT6n@00ol0003on0OhooP7n00:
ooP7n0Ko00000ool0o`00ol0003oo@;mo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003on0OhooP7n00:ooP7n004o`000?of2OKomPWfo`0000[oiQWV00?o0000ol4n`Oo1?/401oo1?/40
0ol0003oP7n0oh1oP009oh1oP003o`000?mkQ7_oNhAk00CoNhAk00?o0000ocC;=?ldbc@01oldbc@0
0ol0003o<l`coc?<<`08oc?<<`;o00001_m2_D800ol0003oA[U6odJiAP05odJiAP03o`000?m[U6_o
JiA[00WoJiA[00Co0000ohIiQ_n6NHKoQWV60ol0000BokI9]P03o`000?oR7N;ohQgR00?ohQgR0_l0
0006on@Ki0;o00003Ooh1oP00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on0OhooP7n00<ooP7n0;o00002_oV6NH00ol0003o`Ck1ol4n`@08ol4n`@03o`000?n0Oh3o
P7n000[oP7n000?o0000og^4NomkQ7/00_mkQ7/00ol0003o=</docC;=008ocC;=003o`000?lcc3?o
<l`c00Ko<l`c0_l00002oa[U6P03o`000?m2_D;o@[e200;o@[e200?o0000odJiA_m6^DH01_m6^DH0
0ol0003oJiA[of^DJ`08of^DJ`03o`000?n6NHKoQWV600CoQWV600?o0000okI9]_nfBKH03onfBKH0
0ol0003ohQgRon8MhP06on8MhP;o00000ooT6n@00ol0003on0OhooP7n00=ooP7n003o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oh1oSon0Oh
00kon0Oh00?o0000onHIi_oV6NH01ooV6NH00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?n0Oh3oP7n0
00WoP7n000Go0000og^4NomkQ7_oNhAko`00000;ocC;=003o`000?lcc3?o<l`c00Co<l`c0_l00005
oa[U6P05o`000?m2_D;o@[e2od:m@_l000002?m6^DH00ol0003oJiA[of^DJ`08of^DJ`03o`000?n6
NHKoQWV600GoQWV600?o0000okI9]_nfBKH03_nfBKH00ol0003ohQgRon8MhP08on8MhP03o`000?oT
6nCo000000oon0Oh00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017on0Oh00?o0000onHIi_oV6NH01_oV6NH00ol0003o`Ck1
ol4n`@0;ol4n`@03o`000?n0Oh3oP7n000WoP7n000Co0000og^4NomkQ7_o00003?ldbc@00ol0003o
<l`coc?<<`02oc?<<`;o00002?lJiAX00ol0003o@[e2o`000009odJiAP03o`000?m[U6_oJiA[00So
JiA[00?o0000ohIiQ_n6NHH01On6NHH00ol0003o]TVfokI9]P0=okI9]P03o`000?oR7N;ohQgR00[o
hQgR00?o0000ooP7n?oh1oP03_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooP7n003o`00
0?oV6NKoiQWV00CoiQWV00?o0000ol4n`Oo1?/403?o1?/400ol0003oP7n0oh1oP00:oh1oP0?o0000
3?ldbc@00ol0003o<l`coc?<<`02o`0000_o6^DJ00?o0000odJiA_m6^DH02?m6^DH00ol0003oJiA[
of^DJ`07of^DJ`03o`000?n6NHKoQWV600OoQWV600?o0000okI9]_nfBKH03?nfBKH00ol0003ohQgR
on8MhP0;on8MhP;o00003_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d00oom0_d00ol0003on0OhooP7n00?ooP7n0?o00000ooV
6NH00ol0003o`Ck1ol4n`@0>ol4n`@03o`000?n0Oh3oP7n000SoP7n000Co0000oc_4>olka3_o>l@k
0_l0000:ocC;=0?o00003OlJiAX00ol0003oA[U6odJiAP08odJiAP03o`000?m[U6_oJiA[00OoJiA[
00?o0000ohIiQ_n6NHH01on6NHH00ol0003o]TVfokI9]P0;okI9]P03o`000?oR7N;ohQgR00cohQgR
00?o0000oo`3o?l000000_l0000:ooP7n003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00con0Oh0_l0
0003oo4>l@03o`000?oV6NKo0000017o`Ck100?o0000oh1oP?n0Oh001on0Oh000ol0003o>l@koc_4
>`04oc_4>`;o00002?ldbc@00ol0003o6^DJoa[U6P0>oa[U6P;o00002?m6^DH00ol0003oJiA[of^D
J`06of^DJ`03o`000?n6NHKoQWV600WoQWV600?o0000okI9]_nfBKH02OnfBKH00ol0003ohQgRon8M
hP0=on8MhP03o`000?ol0ocoo0?l00;oo0?l0ol00007ooP7n003o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oh1oSo
n0Oh00Won0Oh0_l00006oo4>l@03o`000?o1?/7o`Ck1013o`Ck100?o0000oh1oP?n0Oh001_n0Oh00
0ol0003o>l@koc_4>`07oc_4>`03o`000?ldbcCo=</d00Co=</d0ol0000>oa[U6P03o`000?lKi1_o
6n@K00?o00001Om6^DH00ol0003oJiA[of^DJ`06of^DJ`03o`000?n6NHKoQWV600[oQWV600?o0000
okI9]_nfBKH02?nfBKH00ol0003ohQgRon8MhP0=on8MhP03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo@;mood2o@06ood2o@03o`000?oh1oSon0Oh00Gon0Oh0ol00008oo4>l@03o`000?o1?/7o`Ck1
017o`Ck100Co0000oh1oP?n0Oh3oP7n01?l0000;oc_4>`;o000000Co=</do`000?l0003o00000ol:
m@X2o`0000_o6^DJ00?o0000oa_T6olKi1/01?lKi1/2o`0000?oA[U600?o0000of^DJom[U6/01_m[
U6/00ol0003oQWV6ohIiQP0:ohIiQP03o`000?nfBKKo]TVf00Oo]TVf00?o0000on8Mh_oR7N803_oR
7N800ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00;on0Oh0_l0000<oo4>l@03o`000?o1?/7o
`Ck1013o`Ck11?l00003og><L`03o`000?lka3_o>l@k00_o>l@k00?o0000o`[e2_l:m@X01_l:m@X0
0ol0003o6^DJoa[U6P07oa[U6P03o`000?lKi1_o6n@K00Oo6n@K3?l0000>ohIiQP03o`000?nfBKKo
]TVf00Ko]TVf00?o0000on8Mh_oR7N803_oR7N800ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Woo@;m00Co0000ooP7
n?l0003o00003_oa3_400ol0003o`Ck1ol4n`@0?ol4n`@03o`000?mcS7?oLhac00KoLhac00?o0000
oc_4>olka3/02_lka3/00ol0003o2_D:o`[e2P07o`[e2P;o00001_lJiAX00ol0003o6n@Koa_T6`08
oa_T6`03o`000?m:]D[oB[E:00SoB[E:00?o0000ohIiQ_n6NHH03?n6NHH00ol0003o]TVfokI9]P05
okI9]P03o`000?oR7N;ohQgR00oohQgR0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_403_oa3_400ol0
003o`Ck1ol4n`@0>ol4n`@03o`000?mcS7?oLhac00OoLhac00?o0000oc_4>olka3/02_lka3/00ol0
003o2_D:o`[e2P09o`[e2P;o00000olJiAX00ol0003o6n@Koa_T6`09oa_T6`03o`000?m:]D[oB[E:
00WoB[E:00?o0000ohIiQ_n6NHH02_n6NHH4o`0000Co]TVf00?o0000on8Mh_oR7N804?oR7N801?l0
003on`Cko`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?om0_goo@;m00[oo@;m00?o0000oo4>lOoa3_403ooa3_4@o`0000[oLhac00?o0000oc_4
>olka3/02Olka3/00ol0003o2OH9o`00000<o`[e2P05o`000?lJiA[o0000o`Ck1?l000002_lKi1/0
0ol0003oB[E:odZeBP09odZeBP03o`000?n6NHKoQWV600OoQWV60ol00004oj5NX@?o000000?o]TVf
o`000?oR7N804OoR7N801?l0003on`Ckoo/4nook1?/2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ood2oOom0_d02_om0_d00ol0003ol@kaoo4>l@0?
oo4>l@03o`000?ngB;Oo]dRg00co]dRg00?o0000og><LomcS7<02OmcS7<00ol0003o>l@koc_4>`07
oc_4>`04o`000?l9mPWo2OH9o`0000go2_D:00Go0000o`Ck1?l4n`Co1?/4o`000009oa_T6`03o`00
0?m:]D[oB[E:00[oB[E:00?o0000ohIiQ_n6NHH00on6NHH3o`0000[oXEjQ00?o0000on8Mh_oR7N80
4?oR7N800ol0003on`Ckoo/4n`04oo/4n`;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo@;m00?o0000oo4>lOoa3_403ooa3_400ol0003o]dRgokM8]`0<okM8]`03o`000?mc
S7?oLhac00WoLhac00?o0000oc_4>olka3/01_lka3/00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l:
m@[o2_D:00[o2_D:00?o0000o`Ck1?l4n`@00_l4n`@00ol0003o6n@Koa_T6`06oa_T6`03o`000?m:
]D[oB[E:00[oB[E:00?o0000ohIiQ_n6NHH00ol0000=oj5NX@03o`000?oR7N;ohQgR013ohQgR00?o
0000oo/4nook1?/01_ok1?/2o`0000Woo0?l0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003ol@kaoo4>l@0=oo4>l@?o00003ongB;L0
0ol0003oLhacog><L`08og><L`03o`000?lka3_o>l@k00Go>l@k00?o0000o`Wf2Ol9mPT00ol9mPT0
0ol0003o2_D:o`[e2P0:o`[e2P03o`000?l4n`Co1?/400?o1?/400?o0000oa_T6olKi1/01OlKi1/0
0ol0003oB[E:odZeBP0;odZeBP;o00004OnQGZ400ol0003ohQgRon8MhP0?on8MhP03o`000?ok1?_o
n`Ck00Son`Ck0_l00007oo`3o003o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ood2oOom0_d02?om0_d00ol0003ol@kaoo4>l@09oo4>l@Go00000_oS7><00ol0
003o]dRgokM8]`0=okM8]`03o`000?mcS7?oLhac00WoLhac00?o0000oc_4>olka3/01?lka3/00ol0
003o2OH9o`Wf2@04o`Wf2@03o`000?l:m@[o2_D:00So2_D:00?o0000o`Ck1?l4n`@01Ol4n`@00ol0
003o6n@Koa_T6`04oa_T6`03o`000?m:]D[oB[E:00_oB[E:00?o0000oj5NXOnQGZ404?nQGZ400ol0
003ohQgRon8MhP0?on8MhP03o`000?ok1?_on`Ck00[on`Ck0_l00004oo`3o003o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?oa3_7ol@ka00Col@ka1Ol00007on<Lh`03
o`000?ngB;Oo]dRg00go]dRg00?o0000og><LomcS7<02OmcS7<00ol0003o>l@koc_4>`03oc_4>`03
o`000?l9mPWo2OH900Go2OH900?o0000o`[e2_l:m@X02?l:m@X00ol0003o1?/4o`Ck1006o`Ck1003
o`000?lKi1_o6n@K00?o6n@K00?o0000odZeB_m:]DX02om:]DX00ol0003oXEjQoj5NX@0@oj5NX@03
o`000?oR7N;ohQgR00oohQgR00?o0000oo/4nook1?/03?ok1?/2o`000003oo`3o?l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo4>lOl00000
1?l0000<on<Lh`03o`000?ngB;Oo]dRg00ko]dRg00?o0000og><LomcS7<02?mcS7<00ol0003o>l@k
oc_4>`02oc_4>`03o`000?l9mPWo2OH900Oo2OH900?o0000o`[e2_l:m@X01ol:m@X00ol0003o1?/4
o`Ck1007o`Ck1003o`000?lKi1_o6n@K00;o6n@K00?o0000odZeB_m:]DX02om:]DX00ol0003oXEjQ
oj5NX@0Aoj5NX@03o`000?oR7N;ohQgR00gohQgR00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d01Oom0_d3o`00017ohacS00?o0000okM8]ongB;L03_ng
B;L00ol0003oLhacog><L`09og><L`04o`000?lka3_o>l@ko`0000[o2OH900?o0000o`[e2_l:m@X0
1ol:m@X00ol0003o1?/4o`Ck1008o`Ck1005o`000?lKi1_o6n@Koa_T6ol000003Om:]DX00ol0003o
XEjQoj5NX@0Aoj5NX@?o00003OoR7N800ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_om0_d2o`0000;on@Ki00?o0000on<LhooS7><03ooS7><00ol0003o
]dRgokM8]`0>okM8]`03o`000?mcS7?oLhac00SoLhac1Ol0000;o`Wf2@03o`000?l:m@[o2_D:00Ko
2_D:00?o0000o`Ck1?l4n`@02Ol4n`@01?l0003o6n@Koa_T6ol0000=odZeBP03o`000?nQGZ7oXEjQ
017oXEjQ00?o0000olhac_o><Lh00ol0000:on8MhPCo00003Ook1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooT6n@03o`000?oS7>?ohacS00kohacS00?o0000okM8
]ongB;L03_ngB;L00ol0003oLhacog><L`07og><L`03o`000?lSg2?o8m`S00?o8m`S00?o0000o`Wf
2Ol9mPT02?l9mPT00ol0003o2_D:o`[e2P05o`[e2P03o`000?l4n`Co1?/400[o1?/41Ol0000<odZe
BP03o`000?nQGZ7oXEjQ013oXEjQ00?o0000olhac_o><Lh01?o><Lh3o`0000KohQgR00?o0000ooT6
nOoi1_T00_oi1_T5o`0000Son`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0003ohacSon<Lh`0=on<Lh`03o`000?ngB;Oo]dRg00oo
]dRg00?o0000og><LomcS7<01?mcS7<2o`0000Oo8m`S00?o0000o`Wf2Ol9mPT01ol9mPTEo`0000Go
7><L00?o0000odZeB_m:]DX02?m:]DX3o`00013oXEjQ00?o0000olhac_o><Lh02?o><Lh3o`0000;o
hQgR00?o0000ooT6nOoi1_T02?oi1_T5o`0000?on`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ohacSon<Lh`0;on<Lh`Co0000
3ongB;L00ol0003oLhacog><L`03og><L`03o`000?lSg2?o8m`S00So8m`S00?o0000o`Wf2Ol9mPT0
1?l9mPT2o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o7><LoacS7005oacS70;o0000
1_m:]DX2o`0000?oHIiQ00?o0000oj5NXOnQGZ403?nQGZ400ol0003ocS7>olhacP0<olhacP;o0000
4?oi1_T3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00?o
0000on<LhooS7><02OoS7><00ol0003ojaC[o`000002oka3_0?o00003?ngB;L01?l0003oLhacog><
LomcS7<2o`0000co8m`S00?o0000o`Wf2Ol9mPT00_l9mPT00ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000oacS7?lLha`01olLha`00ol0003oB[E:odZeBP02odZeBP03o`00
0?mQWV7oHIiQ00CoHIiQ0_l0000;oj5NX@03o`000?o><LkocS7>00cocS7>00?o0000on/Djol00000
4_oi1_T00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o
0000on<LhooS7><01_oS7><2o`0000;ojaC[00?o0000oka3_?nl@k`00onl@k`3o`0000[o]dRg00?o
0000og><Lol000003olSg2<01?l0003o2OH9o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000oacS7?lLha`02?lLha`01?l0003oB[E:o`000?l00009of6NH@03o`000?nQGZ7oXEjQ00Oo
XEjQ00?o0000olhac_o><Lh03?o><Lh01?l0003ojaC[on/Djol0000CooT6n@03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oS7>?ohacS00Co
hacS00?o0000on/Djoo[5>/00oo[5>/00ol0003o_4>loka3_005oka3_0?o00001_ngB;L4o`00013o
8m`S00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lLhaco7><L00Wo
7><L00?o0000of6NHOmQWV402_mQWV42o`0000KoXEjQ00?o0000olhac_o><Lh03?o><Lh00ol0003o
jaC[on/Dj`02on/Dj`03o`000?oi1_Won@Ki00oon@Ki00?o0000ooh1o_l000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Won@Ki00Co0000on<LhooS7>?o
hacS0_l00006on/Dj`03o`000?nl@kco_4>l00So_4>l0ol000000ongB;Oo0000o`000004ofRGJ003
o`000?lSg2?o8m`S00go8m`S00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?lLhaco7><L00Wo7><L00?o0000of6NHOmQWV403?mQWV400ol0003oXEjQoj5NX@03o`0000ko
cS7>00?o0000on/Djoo[5>/00oo[5>/00ol0003on@KiooT6n@0>ooT6n@05o`000?on0OkooP7nooh1
o_l000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00[o
n@Ki00?o0000on<Lhol000002?o[5>/00ol0003o_4>loka3_00;oka3_003o`000?mXUfSoJ9MX00Go
J9MX00?o0000ob?L8olSg2<03?lSg2<00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000oacS7?lLha`02?lLha`2o`0000ooHIiQ0_l00002oki1_P03o`000?o><LkocS7>00_o
cS7>00?o0000on/Djoo[5>/01?o[5>/00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n00?o
oP7n00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000on/Djoo[5>/0
1oo[5>/00ol0003o_4>loka3_00;oka3_003o`000?mXUfSoJ9MX00KoJ9MX00?o0000ob?L8olSg2<0
2olSg2<2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7><LoacS7007oacS7004o`00
0?l`cc3o<<l`o`0000koHIiQ00?o0000oki1__nn@Kh00_nn@Kh00ol0003ocS7>olhacP09olhacP03
o`000?o[5>_ojaC[00KojaC[00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7nooh1oP05ooh1oP04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooT6nOoi1_T02_oi1_T2o`0000Wo
jaC[00?o0000oka3_?nl@k`02onl@k`00ol0003oJ9MXofRGJ007ofRGJ003o`000?lSg2?o8m`S00Wo
8m`S00Co0000o`Gj1Ol5nPGo00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lLhaco7><L
00Ko7><L00Go0000oc3?<?l`cc3o<<l`o`00000>of6NH@03o`000?nn@Kko_T6n00?o_T6n00?o0000
olhac_o><Lh01oo><Lh00ol0003ojaC[on/Dj`07on/Dj`03o`000?oi1_Won@Ki00[on@Ki00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oi1_Won@Ki
00Won@Ki00Co0000ooP7n?oh1oSo00002Oo[5>/00ol0003o_4>loka3_009oka3_003o`000?mXUfSo
J9MX00WoJ9MX00?o0000ob?L8olSg2<01olSg2<00ol0003o1OX5o`Gj1@02o`Gj1@03o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7><LoacS7005oacS7003o`000?l`cc3o
<<l`00?o<<l`00?o0000of6NHOmQWV402_mQWV400ol0003o_T6noki1_P05oki1_P03o`000?o><Lko
cS7>00GocS7>00?o0000on/Djoo[5>/02?o[5>/00ol0003on@KiooT6n@09ooT6n@03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won@Ki00?o0000ooP7
n?oh1oP00_oh1oP00ol0003ojaC[on/Dj`06on/Dj`03o`000?nl@kco_4>l00Wo_4>l00?o0000ofRG
J?mXUfP02_mXUfP00ol0003o8m`Sob?L8`05ob?L8`03o`000?l5nPGo1OX500Co1OX500?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lLhaco7><L00Co7><L00?o0000oc3?
<?l`cc001?l`cc000ol0003oHIiQof6NH@0:of6NH@03o`000?nn@Kko_T6n00Ko_T6n00?o0000olha
c_o><Lh00oo><Lh00ol0003ojaC[on/Dj`09on/Dj`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooi1_T00ol0003o
n0OhooP7n003ooP7n003o`000?o[5>_ojaC[00KojaC[00?o0000oka3_?nl@k`02Onl@k`00ol0003o
J9MXofRGJ00;ofRGJ003o`000?lSg2?o8m`S00?o8m`S00?o0000o`Gj1Ol5nPD01_l5nPD00ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000oacS7?lLha`00_lLha`2o`0000So
<<l`00?o0000of6NHOmQWV402OmQWV400ol0003o_T6noki1_P07oki1_P05o`000?o><LkocS7>olha
c_l000003Oo[5>/00ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooi1_Wo0000ooP7n006ooP7n003
o`000?o[5>_ojaC[00GojaC[00?o0000oka3_?nl@k`02Onl@k`00ol0003oJ9MXofRGJ00<ofRGJ005
o`000?lSg2?o8m`Sob?L8ol000002_l5nPD00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000oacS7?l000000_l000000ol?l0oo0000oc3?<007oc3?<003o`000?mQWV7oHIiQ
00SoHIiQ00?o0000oki1__nn@Kh02Onn@Kh00ol0003ocS7>o`00000=on/Dj`Co00001Ooi1_T00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oh1oSon0Oh00Oon0Oh00?o0000on/Djoo[5>/01?o[5>/00ol0003o_4>loka3_009oka3_003
o`000?mXUfSoJ9MX00goJ9MX00?o0000ob?L8ol000003?l5nPD:o`0000Oo0?l00ol00005o`o`3`03
o`000?l`cc3o<<l`00Ko<<l`00?o0000of6NHOmQWV401omQWV400ol0003o_T6noki1_P0:oki1_P03
o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5n_oj1OX00_oj1OX3o`000003ooT6nOl0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7n007ooP7n003o`00
0?o[5>_ojaC[00GojaC[00?o0000oka3_?nl@k`01onl@k`00ol0003oJ9MXofRGJ00?ofRGJ0;o0000
2ol5nPD00ol0003o1_T6o`Ki1P07o`Ki1P03o`000?l0o`3o0?l000;o0?l00ol00008o`o`3`03o`00
0?l`cc3o<<l`00Ko<<l`00?o0000of6NHOmQWV401omQWV400ol0003o_T6noki1_P0:oki1_P03o`00
0?o[5>_ojaC[00[ojaC[00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n008ooP7n003o`000?o[5>_ojaC[00CojaC[00?o0000oka3_?nl@k`01onl@k`00ol0003oJ9MXofRG
J00>ofRGJ004o`000?l^dBko;]4^o`0000Wo1OX500?o0000o`Ki1_l6n@H02Ol6n@H01?l0003o0?l0
o`000?l0000<o`o`3`03o`000?l`cc3o<<l`00Ko<<l`00?o0000of6NHOmQWV401_mQWV400ol0003o
_T6noki1_P0;oki1_P03o`000?o[5>_ojaC[00OojaC[0_l00009ooX5nP03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oh1oSon0Oh00Son0Oh00?o0000on/Djoo[5>/00oo[5>/>o`0000goJ9MX00?o0000obkA;_l^dBh0
0_l^dBh00ol0003o1OX5o`Gj1@05o`Gj1@03o`000?l6n@Ko1_T600_o1_T600?o0000o`o`3ol?l0l0
3?l?l0l00ol0003o<<l`oc3?<006oc3?<003o`000?mQWV7oHIiQ00GoHIiQ00?o0000oki1__nn@Kh0
3?nn@Kh00ol0003ojaC[on/Dj`06on/Dj`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP01Ol0003ojaC[on/Djoo[5>_o000000_obCK900?o0000ofbCK?m/Tf`00ol00009ofRGJ003o`00
0?l^dBko;]4^00Co;]4^00?o0000o`Gj1Ol5nPD00ol5nPD00ol0003o1_T6o`Ki1P0<o`Ki1P03o`00
0?l?l0oo3o0?00go3o0?00?o0000oc3?<?l`cc001_l`cc000ol0003oHIiQof6NH@03of6NH@?o0000
3Onn@Kh00ol0003ojaC[on/Dj`05on/Dj`03o`000?oj1O[onPGj00conPGj0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP4o`0000cobCK900?o0000ofbCK?m/Tf`00om/Tf`3o`0000GoJ9MX00?o0000obkA;_l^dBh01_l^
dBh01Ol0003o1OX5o`Gj1Ol5nPGo000000oo1_T600?o0000o`o`3ol?l0l03Ol?l0l00ol0003o<<l`
oc3?<006oc3?<003o`000?mQWV7oHIiQ00?o00000omoP7l00ol0003o_T6noki1_P0;oki1_P03o`00
0?o[5>_ojaC[00?ojaC[00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon0Oh0ol0
0003oo<<l`03o`000?o9=/WobCK900[obCK900?o0000ofbCK?m/Tf`01_m/Tf`3o`000003ofRGJ?l0
003o;]4^00Wo;]4^00?o0000o`Gj1Ol000004?l6n@H00ol0003o3o0?o`o`3`0=o`o`3`03o`000?l`
cc3o<<l`00Oo<<l`0_l00007ogn0O`03o`000?nn@Kko_T6n00[o_T6n00Co0000on/Djoo[5>_ojaC[
0ol0000?ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003on`Ckoo/4nook1?/2o`000004ooP7n?l0003o0000o`0000Kol`cc00?o0000olTfbOo9
=/T02_o9=/T00ol0003oK9=/ofbCK009ofbCK003o`000?l^dBko;]4^00[o;]4^00?o0000o`Ki1_l6
n@H03ol6n@H00ol0003o3o0?o`o`3`0>o`o`3`03o`000?l`cc3o<<l`00Ko<<l`00?o0000ogn0Oomo
P7l01omoP7l4o`0000So_T6n00Co0000on/Djoo[5>_o00000ood2o@2o`0000gonPGj00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
n`Ckoo/4n`04oo/4n`03o`000?oc3??ol`cc00Ool`cc00?o0000olTfbOo9=/T02Oo9=/T00ol0003o
K9=/ofbCK00:ofbCK003o`000?l^dBko;]4^00[o;]4^00?o0000o`Ki1_l6n@H03ol6n@H00ol0003o
3o0?o`o`3`0>o`o`3`03o`000?l`cc3o<<l`00Go<<l`00?o0000ogn0OomoP7l02?moP7l01?l0003o
aSW6olHia_o6>LH7o`0000;o_T6n0_l00006oo@;m0;o00003?oj1OX00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<02?oc3?<00ol0003obCK9olTfb@08olTfb@03o`000?m/TfcoK9=/00[o
K9=/00?o0000obkA;_l^dBh02ol^dBh00ol0003o1_T6o`Ki1P0>o`Ki1P03o`000?l?l0oo3o0?00ko
3o0?1Ol00002oc3?<003o`000?moP7ooOh1o00WoOh1o00?o0000olHia_o6>LH02?o6>LH3o`0000Wo
m0_d0_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?o9=/WobCK900SobCK900?o0000ofbCK?m/Tf`02_m/Tf`00ol0003o;]4^obkA;P0:obkA;P;o0000
3_l6n@H3o`0000go3o0?0ol00005oco0?`;o00002omoP7l00ol0003oaSW6olHiaP0;olHiaP;o0000
2_od2o@2o`0000OonPGj0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo/4n`03o`00
0?oc3??ol`cc00Ool`cc00?o0000olTfbOo9=/T02?o9=/T>o`0000Wo;]4^0ol000000olUfRGo0000
o`Ki1P0:o`Ki1P?o00000_lHiaP00ol0003o3o0?o`o`3`09o`o`3`;o00002Olo`3l00ol0003oOh1o
ogn0O`09ogn0O`03o`000?o6>LKoaSW600_oaSW600?o0000omhQg_l000002ood2o@2o`0000ConPGj
00Co0000oo`3o?ol0ocoo0?l0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oc3??ol`cc00Kol`cc00?o0000olTfbOo9=/T02?o9=/T00ol0003oJiA[
of^DJ`0:of^DJ`03o`000?l^dBko;]4^00Co;]4^0ol00005obGJ9@03o`000?l6n@Ko1_T600Co1_T6
1?l00006oaSW6003o`000?l?l0oo3o0?00Ko3o0?0_l0000;oco0?`03o`000?moP7ooOh1o00WoOh1o
00?o0000olHia_o6>LH02_o6>LH01Ol0003ogR7NomhQg_oN8Mko000000com0_d0_l000000ooj1O[o
0000oo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<01_oc3?<00ol0003obCK9olTfb@07olTfb@03o`00
0?m[U6_oJiA[00_oJiA[00?o0000obkA;_l^dBh00_l^dBh2o`0000Wo9MXU00?o0000o`Ki1_l6n@H0
0ol0000;oaSW6003o`000?l?l0oo3o0?00;o3o0?0ol0000>oco0?`03o`000?moP7ooOh1o00OoOh1o
00?o0000olHia_o6>LH02oo6>LH00ol0003ogR7NomhQgP02omhQgP03o`000?od2oCom0_d00_om0_d
00?o0000oo`3o?ol0o`01_ol0o`2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok
1?_on`Ck00Oon`Ck00?o0000oo<<looc3?<01ooc3?<00ol0003obCK9olTfb@05olTfb@?o00003Om[
U6/4o`0000_o9MXU0ol0000?oaSW6004o`000?l?l0oo0000o`00017o?l0o00?o0000ogn0OomoP7l0
1omoP7l00ol0003oaSW6olHiaP0:olHiaP03o`000?oN8MkogR7N00CogR7N00?o0000oo@;m?od2o@0
1ood2o@3o`0000_oo0?l1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ol`ccoo<<
l`06oo<<l`03o`000?o9=/WobCK900;obCK90ol00003ojUFZ@03o`000?m[U6_oJiA[00[oJiA[00?o
0000obGJ9OlUfRD02olUfRD00ol0003o8=lPo`00000AoaSW6003o`000?lo`3oo?l0o017o?l0o00?o
0000ogn0OomoP7l01omoP7l00ol0003oaSW6olHiaP0:olHiaP03o`000?oN8MkogR7N00GogR7N00Co
0000oo@;m?od2oCom0_d1Ol00002ooL8m`03o`000?ol0ocoo0?l00Woo0?l00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`05oo<<l`?o0000
00?obCK9o`000?l000001onYEZT00ol0003oJiA[of^DJ`08of^DJ`?o00002_lUfRD2o`0000;o8=lP
00?o0000oaSW6?lHiaP03olHiaP00ol0003o?l0ooco0?`0Aoco0?`03o`000?moP7ooOh1o00OoOh1o
00?o0000olHia_o6>LH02Oo6>LH00ol0003ogR7NomhQgP07omhQgP?o00001oog2?L00ol0003oo0?l
oo`3o009oo`3o003o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook
1?/4o`0000;ol`cc0_l00003on`Ck003o`000?nYEZWoZEJY00SoZEJY0_l00006of^DJ`;o00000omI
YUT00ol0003o9MXUobGJ9@06obGJ9@03o`000?lPgb3o8=lP00?o8=lP00?o0000oaSW6?lHiaP03_lH
iaP00ol0003o?l0ooco0?`0Boco0?`03o`000?moP7ooOh1o00GoOh1o00?o0000olHia_o6>LH02Oo6
>LH00ol0003ogR7NomhQgP08omhQgP03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol
0o`00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00Con`Ck0_l00004
ooX5nP;o00001Oo/4n`00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?m[U6_oJiA[00;oJiA[00?o0000
oeVVFOmIYUT01?mIYUT00ol0003o9MXUobGJ9@04obGJ9@03o`000?lPgb3o8=lP00Co8=lP00?o0000
oaSW6?lHiaP03_lHiaP00ol0003o?l0ooco0?`0Boco0?`[o00002_o6>LH00ol0003ogR7NomhQgP08
omhQgP03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003on`Ckoo/4nook1?/2o`0000OonPGj00?o0000on`Ck?o/4n`01?o/4n`0
0ol0003oZEJYojUFZ@0:ojUFZ@04o`000?m[U6_o0000o`0000SoFJII00Co0000obGJ9OlUfRGo9MXU
0_l00007ob3O8003o`000?lHiaSo6>LH00ko6>LH00?o0000oco0?olo`3l04_lo`3l00ol0003oWF:M
oieRW@07oieRW@03o`000?o6>LKoaSW600KoaSW600?o0000omhQg_oN8Mh02_oN8Mh00ol0003om`Sg
ooL8m`06ooL8m`03o`000?ol0ocoo0?l00Soo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ok
1?_o0000o`0000WonPGj00?o0000on`Ck?o/4n`01?o/4n`00ol0003oZEJYojUFZ@0;ojUFZ@03o`00
0?mIYUWoFJII00WoFJII00?o0000obGJ9Ol000002OlPgb000ol0003o6>LHoaSW600>oaSW60;o0000
4_lo`3l00ol0003oWF:MoieRW@09oieRW@;o00001_o6>LH00ol0003ogR7NomhQgP0:omhQgP03o`00
0?og2?Oom`Sg00Kom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ok1?/on`Ck005on`Ck003o`000?nYEZWoZEJY00[oZEJY00?o
0000oeVVFOmIYUT02_mIYUT2o`0000Wo8=lP00?o0000oaSW6?lHiaP03_lHiaP00ol0003o=LXeo`00
0002o`0000oo?l0o00?o0000oieRWOnMHYd02onMHYd00ol0003oaSW6olHiaP03o`0000gogR7N00?o
0000ooL8moog2?L01_og2?L00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003onPGjooX5nP09ooX5nP03o`000?o/4ncok1?/00Gok1?/00?o0000ojUFZOnYEZT02OnYEZT2
o`0000_oFJII0_l0000;ob3O8003o`000?lHiaSo6>LH00co6>LH00?o0000ocG:=OlebSD00olebSD3
o`0000co?l0o00?o0000oieRWOnMHYd03?nMHYd2o`0000;ogB;M00?o0000omhQg_oN8Mh03?oN8Mh0
0ol0003om`SgooL8m`05ooL8m`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00[onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oZEJYojUFZ@07ojUF
Z@03o`000?n]DZgo000000[oFJII00Co0000odn`Com?/4oo00002_lPgb000ol0003o6>LHoaSW600<
oaSW6003o`000?lebSGo=LXe00Ko=LXe0_l00008oco0?`;o00003onMHYd00ol0003ogB;MomdRg@02
omdRg@03o`000?oN8MkogR7N00_ogR7N00?o0000ooL8moog2?L01Oog2?L00ol0003oo0?loo`3o007
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o/4ncok1?/
00Kok1?/00?o0000ojUFZOnYEZT01_nYEZT01Ol0003o[E:]ojeB[On]DZgo000000SoFJII00?o0000
odn`Com?/4l00_m?/4l00ol0003o8=lPob3O8006ob3O80Co00003?lHiaP00ol0003o=LXeocG:=@08
ocG:=@?o00000_lo`3l3o`000003ogf2OOl0003oWF:M00goWF:M00?o0000omdRgOoM8]d01?oM8]d0
0ol0003ogR7NomhQgP0:omhQgP03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ok1?/on`Ck007on`C
k003o`000?nYEZWoZEJY00?oZEJY0_l00005ojeB[@03o`000?mIYUWoFJII00CoFJII00?o0000odn`
Com?/4l00om?/4l00ol0003o8=lPob3O8005ob3O8003o`000?lIiQWo6NHI00;o6NHI0ol00007oaSW
60;o00003_lebSD2o`0000GoOH9m00?o0000oieRWOnMHYd02_nMHYd00ol0003ogB;MomdRg@05omdR
g@03o`000?oN8MkogR7N00_ogR7N00?o0000ooL8moog2?L01?og2?L00ol0003oo0?loo`3o006oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?o/4ncok1?/00Oo
k1?/00?o0000ojUFZOnYEZT00_nYEZT00ol0003o[E:]ojeB[@06ojeB[@03o`000?mIYUWoFJII00;o
FJII00?o0000odn`Com?/4l01Om?/4l00ol0003o8=lPob3O8002ob3O80;o00002?lIiQT3o`0000;o
6>LH0_l000000olLhaco0000ocG:=@0=ocG:=@03o`000?mmPWgoOH9m00GoOH9m00?o0000oieRWOnM
HYd02?nMHYd00ol0003ogB;MomdRg@07omdRg@03o`000?oN8MkogR7N00[ogR7N00?o0000ooL8moog
2?L01?og2?L00ol0003oo0?loo`3o006oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGj
ooX5nP0<ooX5nP03o`000?o/4ncok1?/00Sok1?/00Co0000ojUFZOnYEZWo00002On]DZd01Ol0003o
FJIIoeVVFOmIYUWo000000SoCk1?00Go0000ob3O8?lPgb3o8=lPo`00000=oaWV6@;o00001?lLha`0
0ol0003o=LXeocG:=@0;ocG:=@03o`000?mmPWgoOH9m00KoOH9m00?o0000oieRWOnMHYd01onMHYd0
0ol0003ogB;MomdRg@08omdRg@Co00002?oN8Mh00ol0003om`SgooL8m`04ooL8m`03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00_onPGj0ol00009on`C
k003o`000?nYEZWo000000_o[E:]00?o0000oeVVFOl000002_m?/4l00ol0003o8=lPo`00000?oaWV
6@03o`000?lLhaco7><L00;o7><L00?o0000ocG:=OlebSD02olebSD00ol0003oOH9mogf2O@06ogf2
O@03o`000?nMHYgoWF:M00KoWF:M00?o0000omdRgOoM8]d02OoM8]d01?l0003okQ7^onhAk_o^4Nh7
o`0000;ogR7N00?o0000ooL8moog2?L00oog2?L00ol0003oo0?loo`3o005oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oj1O[onPGj00SonPGj0ol00003ooX5nP03o`000?o/4ncok1?/00Ook1?/00?o0000ojeB
[On]DZd02on]DZd00ol0003oCk1?odn`C`0:odn`C`03o`000?lIiQWo6NHI00go6NHI00?o0000oacS
7?lLha`01?lLha`00ol0003o=LXeocG:=@09ocG:=@03o`000?mmPWgoOH9m00SoOH9m00?o0000oieR
WOnMHYd00onMHYd2o`0000cogB;M00?o0000onhAk_o^4Nh02?o^4Nh<o`0000?oo0?l0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX3o`0000OonPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
[E:]ojeB[@0;ojeB[@03o`000?m?/4ooCk1?00WoCk1?0_l0000>oaWV6@03o`000?lLhaco7><L00Go
7><L00?o0000ocG:=OlebSD02OlebSD00ol0003oOH9mogf2O@09ogf2O@03o`000?nMHYgo000000;o
00000_oB;M800ol0003ogB;MomdRg@08omdRg@03o`000?o^4NkokQ7^00cokQ7^00?o0000ooP7n?oh
1oP01_oh1oP3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003onPGjooX5nP03ooX5nP?o00002ooj1OX00ol0003ok1?/
on`Ck004on`Ck003o`000?n]DZgo[E:]00_o[E:]0ol00007odn`C`?o000000?o=lPgo`000?lIiQT0
3OlIiQT00ol0003o7><LoacS7006oacS7003o`000?lebSGo=LXe00So=LXe00?o0000ogf2OOmmPWd0
2_mmPWd00ol0003odRgBom8]dP04om8]dP03o`000?oM8]gogB;M00OogB;M00?o0000onhAk_o^4Nh0
2oo^4Nh00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooX5n_l0
003o0000o`0000oonPGj00?o0000on`Ck?o/4n`00oo/4n`>o`0000?oUfRG0_l00002odn`C`?o0000
1Olgb3L00ol0003o6NHIoaWV6@0:oaWV6@03o`000?lLhaco7><L00Oo7><L00?o0000ocG:=OlebSD0
2?lebSD00ol0003oOH9mogf2O@0:ogf2O@03o`000?oB;M;odRgB00GodRgB00?o0000omdRgOoM8]d0
1_oM8]d00ol0003okQ7^onhAkP0;onhAkP03o`000?oh1oSon0Oh00Son0Oh00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;onPGj00?o0000on`Ck?o/4n`00_o/4n`00ol0003ogR7NomhQ
gP0:omhQgP03o`000?nGJ9OoUfRG00?oUfRG0_l00009ocO8=`03o`000?lIiQWo6NHI00Wo6NHI00?o
0000oacS7?lLha`02?lLha`2o`0000So=LXe00?o0000ogf2OOmmPWd02OmmPWd00ol0003odRgBom8]
dP07om8]dP03o`000?oM8]gogB;M00CogB;M00?o0000onhAk_o^4Nh02oo^4Nh00ol0003on0OhooP7
n009ooP7n003o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o000000?ok1?/
o`000?oN8Mh02ooN8Mh00ol0003oUfRGoiMXU`04oiMXU`03o`000?lgb3Oo=lPg00Wo=lPg00?o0000
oaWV6OlIiQT01olIiQT00ol0003o7><LoacS7009oacS7004o`000?ll`cco0000o`0000Ko=LXe00?o
0000ogf2OOmmPWd02OmmPWd00ol0003odRgBom8]dP08om8]dP03o`000?oM8]gogB;M00?ogB;M00?o
0000onhAk_o^4Nh02oo^4Nh00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00000ooi1_T2o`0000cogR7N00?o0000oiMXUonGJ9L01?nGJ9L0
0ol0003o=lPgocO8=`0:ocO8=`Wo00002olLha`00ol0003o?<<locc3?002occ3?0?o00000_lebSD0
0ol0003oOH9mogf2O@0:ogf2O@03o`000?oB;M;odRgB00WodRgB00?o0000omdRgOoM8]d00_oM8]d0
0ol0003okQ7^onhAkP0:onhAkP03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_oj1OX2o`0000Gon@Ki00?o0000on`Ck?l000002_oN8Mh00ol0003oUfRGoiMXU`06oiMX
U`03o`000?lgb3Oo=lPg00Wo=lPg00?o0000ob;M8_lRgB801OlRgB800ol0003o7><LoacS7009oacS
7003o`000?ll`cco?<<l00Go?<<l0ol00009ogf2O@?o00003OoB;M801Ol0003ogB;MomdRgOoM8]go
000000cokQ7^00?o0000ooP7n?oh1oP02Ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX01Ooj1OX2o`0000Oon@Ki00Co0000on`Ck?o/4nco00002OoN8Mh00ol0003oUfRGoiMXU`06
oiMXU`03o`000?lgb3Oo=lPg00So=lPg00?o0000ob;M8_lRgB801olRgB800ol0003o7><LoacS7007
oacS7003o`000?ll`cco?<<l00So?<<l0ol00002ogf2O@Go00000_nl@k`00ol0003odRgBom8]dP0<
om8]dP03o`000?oM8]go000000cokQ7^00?o0000ooP7n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000ooX5n_oj1OX00_oj1OX2o`0000Son@Ki00?o0000on`Ck?o/4n`00_o/4n`5o`00
00CogR7N00?o0000oiMXUonGJ9L01_nGJ9L00ol0003o=lPgocO8=`08ocO8=`03o`000?lRgB;o8]dR
00Oo8]dR00?o0000oacS7?lLha`01olLha`00ol0003o?<<locc3?008occ3?003o`000?n5NXGoQGZ5
00;o00002?nl@k`00ol0003odRgBom8]dP0<om8]dPCo00002_o^4Nh00ol0003on0OhooP7n00:ooP7
n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003onPGjo`000?l0000:ooT6n@03o`000?o/4ncok1?/
00;ok1?/00?o0000olLhaoo7><L00_o7><L4o`0000WoUfRG00?o0000ocO8=olgb3L02?lgb3L00ol0
003o8]dRob;M8P08ob;M8P03o`000?lLhaco7><L00Go7><L00?o0000occ3??ll`c`02?ll`c`01Ol0
003oQGZ5ohEjQOn5NXGo000000[o_4>l0ol0000;om8]dP04o`000?oe2_Gom@[eooD:m@Co00001Oo^
4Nh00ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o/4ncok1?/00?ok1?/00?o0000olLhaoo7><L01?o7><L00ol0003oUfRGoiMXU`07
oiMXU`03o`000?lgb3Oo=lPg00Ko=lPg0_l0000;ob;M8P03o`000?lLhaco7><L00Go7><L00?o0000
occ3??ll`c`02?ll`c`00ol0003oQGZ5ohEjQ@02ohEjQ@03o`000?nl@kco_4>l00Oo_4>l00?o0000
onLHiooW6>L01?l00006om8]dP03o`000?oe2_Gom@[e00Kom@[e0ol00002onhAkP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000on`C
k?o/4n`01?o/4n`00ol0003oacS7olLha`05olLha`03o`000?nGJ9OoUfRG00OoUfRG00?o0000ocO8
=olgb3L00_lgb3L3o`000003oe2_D?l0003o8]dR00[o8]dR00?o0000oacS7?lLha`01OlLha`00ol0
003o?<<locc3?007occ3?003o`000?n5NXGoQGZ500?oQGZ500?o0000oka3_?nl@k`01onl@k`00ol0
003oiaSWonLHi`04onLHi`?o00000_oB;M800ol0003om@[eooD:m@0:ooD:m@;o00003_oh1oP00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ok1?/on`Ck004on`Ck003
o`000?o7><OoacS700KoacS70_l00007oiMXU`03o`000?lgb3Oo000000;o00001Om@[e000ol0003o
8]dRob;M8P08ob;M8P?o00001?lLha`00ol0003o?<<locc3?008occ3?003o`000?n5NXGoQGZ500Co
QGZ500?o0000oka3_?nl@k`01_nl@k`00ol0003oiaSWonLHi`07onLHi`;o00003_oe2_D00ol0003o
n0OhooP7n00;ooP7n003o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o/4ncok1?/00Gok1?/00?o0000olLhaoo7><L01?o7><L00ol0003obCK9olTfb@03o`0000CoUfRG
0_l00008oe2_D003o`000?lRgB;o8]dR00Oo8]dR00Co0000odBkA?m4^dCoA;]40ol000000olLhaco
0000occ3?009occ3?003o`000?n5NXGoQGZ500CoQGZ500?o0000oka3_?nl@k`01Onl@k`00ol0003o
iaSWonLHi`09onLHi`03o`000?oe2_Gom@[e00gom@[e00?o0000ooP7n?oh1oP02_oh1oP00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003ok1?/on`Ck006on`Ck003o`00
0?o7><OoacS700?oacS700?o0000olTfbOo9=/T01?o9=/T2o`000003oiMXUol0003oD:m@00[oD:m@
00?o0000ob;M8_lRgB801OlRgB800ol0003oA;]4odBkA005odBkA003o`000?ll`cco?<<l00Oo?<<l
0ol00007ohEjQ@03o`000?nl@kco_4>l00Co_4>l00?o0000onLHiooW6>L02OoW6>L00ol0003om@[e
ooD:m@0=ooD:m@03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009on`Ck005o`000?o7><OoacS7olLhaol000002Oo9=/T00ol0003oD:m@
oe2_D00;oe2_D003o`000?lRgB;o8]dR00?o8]dR00?o0000odBkA?m4^d@01_m4^d@00ol0003o?<<l
occ3?006occ3?005o`000?mlPgcoO8=logb3O?l000001on5NXD00ol0003o_4>loka3_003oka3_003
o`000?oW6>OoiaSW00WoiaSW00?o0000ooD:mOoe2_D03_oe2_D00ol0003on0OhooP7n009ooP7n003
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;on`Ck00?o0000on`Ck?o/4n`0
1oo/4n`01?l0003oacS7olLhaol00009olTfb@;o00003Om@[e000ol0003o8]dRob;M8P02ob;M8P03
o`000?m4^dCoA;]400SoA;]400?o0000occ3??ll`c`00oll`c`2o`0000GoO8=l00?o0000ohEjQOn5
NXD01?n5NXD00ol0003o_4>loka3_003oka3_003o`000?oW6>OoiaSW00WoiaSW00?o0000ooD:mOoe
2_D03_oe2_D00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Son`Ck
00?o0000on`Ck?o/4n`01_o/4n`00ol0003oacS7o`000009olTfb@04o`000?nSG:?oXebSo`0000go
D:m@00Co0000ob;M8_lRgB;o00003?m4^d@01Ol0003o?<<locc3??ll`cco000000SoO8=l0_l00005
ohEjQ@03o`000?nl@kco_4>l00;o_4>l00?o0000onLHiooW6>L02OoW6>L00ol0003om@[eooD:m@0>
ooD:m@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000on`Ck?o/4n`01oo/4n`00ol0003obCK9olTfb@07olTfb@03o`000?nSG:?oXebS
00;oXebS00?o0000oe2_D?m@[e002_m@[e000ol0003o8]dRo`00000>odBkA003o`000?ll`cco0000
00_oO8=l00?o0000ohEjQOn5NXD00_n5NXD01Ol0003o_4>loka3_?nl@kco000000coiaSW00?o0000
ooD:mOoe2_D03_oe2_D3o`0000Won0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000on`Ck?o/4n`01_o/4n`00ol0003obCK9olTfb@06olTfb@03o`000?nSG:?oXebS
00?oXebS00?o0000oe2_D?m@[e002om@[e000ol0003oA;]4odBkA00>odBkA003o`000?mlPgcoO8=l
00_oO8=l0_l00003ohEjQ@04o`000?nl@kco_4>lo`0000[oiaSW0ol0000>ooD:m@;o00000oon0Oh2
o`0000Oon0Oh00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000on`C
k?o/4n`01?o/4n`00ol0003obCK9olTfb@06olTfb@03o`000?nSG:?oXebS00GoXebS00?o0000oe2_
D?m@[e001om@[e03o`00017oA;]400?o0000ogb3O?mlPg`03OmlPg`01Ol0003oQGZ5ohEjQOl0003o
_4>l00Co00000ooW6>L5o`0000;onPGj00?o0000ooD:mOoe2_D02_oe2_D2o`0000OooP7n0_l00004
ooP7n003o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o/4ncok1?/
00Cok1?/00?o0000olTfbOo9=/T01Oo9=/T00ol0003oXebSoj=LX`06oj=LX`03o`000?m@[e3oD:m@
00CoD:m@0ol00002oeRWF003o`000?m4^dCoA;]400ooA;]40_l0000?ogb3O004o`000?n5NXGo0000
o`0000CofbCK0ol00008ooX5nP03o`000?oe2_Gom@[e00Oom@[e0_l0000;ooh1oP;o00000_oh1oP0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo/4nook1?/03?ok1?/6o`0000OobCK900?o0000oj=L
XonSG:<02?nSG:<00ol0003oD:m@oe2_D003o`0000KoF:MH00?o0000odBkA?m4^d@03Om4^d@01?l0
003oPgb3oh=lPol0000?ogb3O003o`000?oK9=_ofbCK00GofbCK00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003om@[eooD:m@05ooD:m@03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ok1?/00ol0003okQ7^onhAkP04onhA
kP03o`000?o9=/WobCK900?obCK900?o0000oj=LXonSG:<02_nSG:<2o`0000[oF:MH00?o0000odBk
A?m4^d@02om4^d@00ol0003oPgb3oh=lP`02oh=lP`03o`000?mlPgcoO8=l00_oO8=l0_l00007om/T
f`03o`000?oj1O[onPGj00WonPGj00?o0000ooD:mOoe2_D00_oe2_D2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP06onhAkP05o`000?o9=/WobCK9olTf
bOl000003OnSG:<00ol0003oF:MHoeRWF00:oeRWF003o`000?m4^dCoA;]400WoA;]400?o0000oh=l
Pon3O8<01?n3O8<00ol0003oO8=logb3O008ogb3O0;o000000?o[5>/o`000?oK9=/01ooK9=/00ol0
003onPGjooX5nP09ooX5nP04o`000?oe2_Go0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000onhAk_o^4Nh02?o^4Nh00ol0003obCK9o`00000=oj=LX`03o`000?mHYeSoF:MH
00_oF:MH00?o0000odBkA?m4^d@02?m4^d@00ol0003oPgb3oh=lP`06oh=lP`03o`000?mlPgcoO8=l
00GoO8=l0_l00003ojaC[003o`000?oK9=_ofbCK00KofbCK00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?o^4NkokQ7^00[okQ7^00?o0000oj=LXonS
G:<03?nSG:<00ol0003oF:MHoeRWF00<oeRWF003o`000?m4^dCoA;]400KoA;]400?o0000oh=lPon3
O8<02?n3O8<00ol0003oO8=logb3O002ogb3O0;o00001_n/Dj`00ol0003ofbCKom/Tf`05om/Tf`03
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck00Gon`Ck
00?o0000onhAk_o^4Nh03?o^4Nh2o`0000coXebS00?o0000oeRWF?mHYeP03OmHYeP00ol0003oA;]4
odBkA004odBkA003o`000?n3O8?oPgb300[oPgb300Co0000ogb3O?l0003o00002?n/Dj`00ol0003o
fbCKom/Tf`06om/Tf`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ok1?/00ol0003okQ7^onhAkP0=onhAkP03o`000?o=</go000000;o00002?nSG:<00ol0003oF:MH
oeRWF00?oeRWF0Ko00003_n3O8<00ol0003o[5>/ojaC[008ojaC[003o`000?oK9=_ofbCK00KofbCK
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?onhAkP03o`000?o=</gocC;=00?ocC;=0ol00005oj=LX`;o00004?mHYeP01_l0003oJiA[
of^DJol0003oHiaSo`0000koPgb300?o0000ojaC[?n/Dj`02On/Dj`00ol0003ofbCKom/Tf`05om/T
f`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
kQ7^onhAkP0=onhAkP03o`000?o=</gocC;=00KocC;=0ol000001?nSG:?o0000ohMhQon7N8L3o`00
00coF:MH00Go0000of^DJom[U6_oJiA[o`000002of>LH`03o`000?n3O8?oPgb300_oPgb300?o0000
ojaC[?n/Dj`02On/Dj`00ol0003ofbCKom/Tf`06om/Tf`03o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?o=</d00ol0003oQgR7ohMhQ`04ohMh
Q`?o00002?mHYeP00ol0003oJiA[of^DJ`02of^DJ`05o`000?mSW6?oHiaSof>LHol000003?n3O8<0
0ol0003o[5>/ojaC[009ojaC[003o`000?oK9=_ofbCK00GofbCK3?l00002ood2o@;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o_4>ooka3_00_oka3_00?o0000oldb
cOo=</d02_o=</d00ol0003oQgR7ohMhQ`07ohMhQ`;o00001OmHYeP00ol0003oJiA[of^DJ`03of^D
J`03o`000?mSW6?oHiaS00;oHiaS00?o0000oh=lPon3O8<02On3O8<00ol0003o[5>/ojaC[00:ojaC
[003o`000?oK9=_ofbCK00?ofbCK00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@02ood2
o@;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o_4>ooka3_00[o
ka3_00?o0000oldbcOo=</d02oo=</d00ol0003oQgR7ohMhQ`09ohMhQ`?o000000?oF:MHo`000?m[
U6/01Om[U6/00ol0003oHiaSof>LH`03of>LH`03o`000?n3O8?oPgb300SoPgb33_l00003om/Tf`;o
00002oof2OH00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om0_do`00000;onl@k`03o`000?o=</gocC;=00[ocC;=
0_l0000>ohMhQ`03o`000?m[U6_oJiA[00GoJiA[00?o0000of>LHomSW6<00omSW6<00ol0003oPgb3
oh=lP`08oh=lP`03o`000?oM8]gogB;M00_ogB;M00?o0000om/Tfol000003Oof2OH00ol0003oo@;m
ood2o@06ood2o@;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000oo@;m?od2oCo00002_o_4>l00ol0003ocC;=oldbc@09oldbc@03o`000?nhAkSo000000koQgR7
00?o0000of^DJom[U6/01Om[U6/00ol0003oHiaSof>LH`04of>LH`03o`000?n3O8?oPgb300KoPgb3
00?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@00_od
2o@00ol0003oka3_onl@k`06onl@k`03o`000?o=</gocC;=00SocC;=0_l00003okQ7^003o`000?n7
N8OoQgR700_oQgR700?o0000of^DJom[U6/01Om[U6/00ol0003oHiaSof>LH`05of>LH`03o`000?n3
O8?oPgb300GoPgb300?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0;ooH9mP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo@;m?od2o@00ood2o@00ol0003oka3_onl@k`05onl@k`03o`000?o=</gocC;=00OocC;=00?o0000
okQ7^?nhAkP00onhAkP00ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?m[U6_oJiA[00KoJiA[00?o0000
of>LHomSW6<01_mSW6<00ol0003oPgb3oh=lP`04oh=lP`03o`000?oM8]gogB;M00gogB;M3ol0000;
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01Ood2o@00ol0
003oka3_onl@k`04onl@k`03o`000?o=</gocC;=00GocC;=0_l00006okQ7^003o`000?n7N8OoQgR7
00WoQgR70_l00008of^DJ`03o`000?mSW6?oHiaS00KoHiaS1Ol000000on3O8?o0000omdRg@0?omdR
g@03o`000?og2?Oom`Sg00_om`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003o
ka3_onl@k`04o`0000KocC;=00?o0000okQ7^?nhAkP01onhAkP00ol0003oQgR7ohMhQ`05ohMhQ`?o
000000?oR7N8o`000?m[U6/01om[U6/00ol0003oHiaSof>LH`05of>LH`03o`000?nRGJ;oXUfR00?o
XUfR0_l0000?omdRg@;o00003Oog2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000oo@;m?od2o@01ood2o@2o`0000CohacS00Co0000oldbcOo=</go
cC;=0_l0000:okQ7^003o`000?n7N8OoQgR700;oQgR70ol00005ohQgR003o`000?m[U6_oJiA[00Go
JiA[00?o0000of>LHomSW6<01?mSW6<00ol0003oXUfRoj9MXP06oj9MXP03o`000?oM8]gogB;M00[o
gB;M0_l00002oo4>l@03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d02?om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om0_doo@;m008oo@;m003o`00
0?oS7>?ohacS00CohacS00?o0000oldbcOl000003?nhAkP00ol0003oQgR7o`000002o`0000WoR7N8
00?o0000of^DJom[U6/01?m[U6/00ol0003oHiaSof>LH`03of>LH`03o`000?nRGJ;oXUfR00SoXUfR
1_l00004omdRg@;o00001Ooa3_400ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@01ood
2o@00ol0003ohacSon<Lh`06on<Lh`03o`000?nhAkSo^4Nh00co^4Nh00?o0000ohQgR?n8MhP02_n8
MhP00ol0003oJiA[of^DJ`04of^DJ`04o`000?mSW6?oHiaSof>LH`;o00002onRGJ800ol0003ohQgR
on8MhP03on8MhPCo00002?oa3_400ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00Ooo@;m
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om0_doo@;m007oo@;m003o`000?oS
7>?ohacS00OohacS00?o0000okQ7^?nhAkP03?nhAkP00ol0003oR7N8ohQgR00;ohQgR003o`000?m[
U6_oJiA[00?oJiA[00Co0000of>LHomSW6?o00003OnRGJ800ol0003ohQgRon8MhP06on8MhP03o`00
0?oa3_7ol@ka00Ool@ka00?o0000ooL8moog2?L01oog2?L00ol0003oo@;mood2o@06ood2o@04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000oo@;m?od2o@0
1_od2o@00ol0003ohacSon<Lh`09on<Lh`03o`000?nhAkSo^4Nh00Wo^4Nh0_l0000>ohQgR0?o0000
0om[U6/00ol0003oHiaSo`00000=oj9MXP03o`000?oR7N;ohQgR00OohQgR00?o0000oo4>lOoa3_40
2?oa3_4:o`0000Koo@;m0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom0_d00?o
0000on<LhooS7><02_oS7><00ol0003o^4NhokQ7^006okQ7^0;o000000?o^4Nho`000?n8MhP02on8
MhP2o`0000?oT6n@1Ol0000>oj9MXP03o`000?oR7N;ohQgR00OohQgR00?o0000oo4>lOoa3_402?oa
3_400ol0003on`Ckoo/4n`06oo/4n`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@03ooT6n@Co00000_od2o@00ol0003ohacSon<Lh`0;
on<Lh`03o`000?nhAkSo^4Nh00?o^4Nh0ol00004okQ7^003o`000?n8MhSoR7N800OoR7N80_l00008
oi1_T003o`000?nRGJ;oXUfR00goXUfR00?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@07
oo4>l@03o`000?ok1?_on`Ck00Oon`Ck0ol000000oom0_go0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oi1_Won@Ki00Oon@Ki0_l0000?on<Lh`03o`000?nhAkSo^4Nh00;o00002?nhAkP00ol0
003oR7N8ohQgR005ohQgR003o`000?n@Ki3oT6n@00SoT6n@00?o0000oj9MX_nRGJ803OnRGJ800ol0
003ohQgRon8MhP08on8MhP03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on@KiooT6n@09ooT6
n@03o`000?oS7>?ohacS00kohacS0_l0000;okQ7^003o`000?n8MhSoR7N800;oR7N80_l0000;oi1_
T003o`000?nRGJ;oXUfR00goXUfR00?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@06oo4>
l@03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on@KiooT6n@0:ooT6n@03o`000?oS7>?ohacS00gohacS0_l0000<okQ7^004o`000?n8MhSo0000
o`0000goT6n@00?o0000oj9MX_nRGJ803?nRGJ800ol0003ohQgRon8MhP09on8MhP03o`000?oa3_7o
l@ka00Kol@ka00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003on@KiooT6n@0:ooT6n@03o`000?oS7>?ohacS00cohacS00Co0000on4N
hOoQ7^7o00003?nhAkP00ol0003oT6n@oi1_T00>oi1_T003o`000?nRGJ;oXUfR00SoXUfR1?l0000;
on8MhP03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on@KiooT6n@0;ooT6n@03o`000?oS7>?ohacS
00_ohacS00?o0000on4NhOoQ7^400_oQ7^400ol0003o^4NhokQ7^009okQ7^003o`000?n@Ki3oT6n@
00koT6n@00Co0000oj9MX_nRGJ;oXUfR1ol00003ol@ka003o`000?oR7N;ohQgR00WohQgR00?o0000
oo4>lOoa3_401_oa3_400ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oi1_Won@Ki00con@Ki00?o0000on<LhooS7><02_oS7><00ol0
003ohAkQon4Nh@03on4Nh@03o`000?nhAkSo^4Nh00So^4Nh00?o0000oi1_T?n@Ki003_n@Ki04o`00
00_oa3_400?o0000on8Mh_oR7N802?oR7N800ol0003ol@kaoo4>l@05oo4>l@03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooT6nOoi
1_T03?oi1_T7o`0000GohacS00?o0000on4NhOoQ7^401OoQ7^400ol0003o^4NhokQ7^007okQ7^003
o`000?n@Ki3oT6n@00koT6n@00?o0000ol@ka?o4>l@03Oo4>l@00ol0003ohQgRon8MhP08on8MhP03
o`000?oa3_7ol@ka00Col@ka00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003on@KiooT6n@0=ooT6n@03o`000?oa3_7ol@ka00Col@ka
1Ol00009on4Nh@03o`000?nhAkSo^4Nh00Ko^4Nh00?o0000oi1_T?n@Ki003_n@Ki000ol0003oa3_4
ol@ka00=ol@ka003o`000?oR7N;ohQgR00SohQgR00Co0000oo4>lOoa3_7ol@ka1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooT6n@03o`000?oa3_7ol@ka00Wol@ka
0_l00009on4Nh@03o`000?nhAkSo^4Nh00Ko^4Nh00?o0000oi1_T?n@Ki003?n@Ki000ol0003oa3_4
ol@ka00?ol@ka0Ko00001?oR7N84o`0000Gon@Ki0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_oi1_T00ol0003o
l@kaoo4>l@09oo4>l@03o`000?oZ5N[o000000;o00001ooQ7^400ol0003o^4NhokQ7^005okQ7^003
o`000?n@Ki3oT6n@00SoT6n@1Ol0000Aol@ka003o`000?oZ5N[ojQGZ00?ojQGZ1?l0000;ooT6n@03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000Oon@Ki
00?o0000oo4>lOoa3_402_oa3_400ol0003ojQGZonXEjP02onXEjP?o00001OoQ7^400ol0003o^4Nh
okQ7^004okQ7^004o`000?n@Ki3oT6n@oi1_T0Oo00001?o5>/D00ol0003oa3_4ol@ka00>ol@ka003
o`000?oZ5N[ojQGZ00OojQGZ00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?oi1_T00ol0003ol@ka
oo4>l@0;oo4>l@03o`000?oZ5N[ojQGZ00GojQGZ0ol00003on4Nh@04o`000?nhAkSo^4NhokQ7^0Ko
00003?o5>/D00ol0003oa3_4ol@ka00=ol@ka003o`000?oZ5N[ojQGZ00OojQGZ00?o0000ooT6nOoi
1_T02_oi1_T00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on@Kio`000?oa3_40
3?oa3_400ol0003ojQGZonXEjP08onXEjP?o000000CohAkQo`000?l0003o00000_oS7><00ol0003o
aC[5olDja@0=olDja@03o`000?o4>lCoa3_400coa3_400?o0000onXEj_oZ5NX02?oZ5NX00ol0003o
n@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo4>lOoa3_403?oa3_400ol0003ojQGZonXEjP0;onXEjP03o`000?oS7>?ohacS00?o
hacS00?o0000olDjaOo5>/D03?o5>/D00ol0003odRgBo`00000=ol@ka003o`000?oZ5N[ojQGZ00So
jQGZ00?o0000ooT6nOoi1_T03?oi1_T3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo4>lOoa3_403?oa3_400ol0003ojQGZonXEjP0:onXEjP03o`00
0?oS7>?ohacS00GohacS00?o0000olDjaOo5>/D02_o5>/D01?l0003odRgBom8]d_oB;M82o`0000[o
a3_400?o0000onXEj_oZ5NX02OoZ5NX00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo4>lOoa3_40
3?oa3_400ol0003ojQGZonXEjP09onXEjP03o`000?oS7>?ohacS00KohacS00?o0000olDjaOo5>/D0
2Oo5>/D00ol0003odRgBom8]dP02om8]dP03o`000?oU6^Go000000;o00001oo4>l@00ol0003ojQGZ
onXEjP09onXEjP03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003ol@kaoo4>l@0;oo4>l@03o`000?oZ
5N[ojQGZ00SojQGZ00?o0000on<LhooS7><01ooS7><00ol0003oaC[5olDja@08olDja@03o`000?oB
;M;odRgB00?odRgB00?o0000onDJiOoU6^D00_oU6^D2o`0000Coa3_400?o0000onXEj_oZ5NX02_oZ
5NX00ol0003on@KiooT6n@0:ooT6n@03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo4>l@Ko00001?oZ5NX00ol0003ohacSon<Lh`08
on<Lh`03o`000?o5>/GoaC[500OoaC[500?o0000om8]d_oB;M800ooB;M800ol0003oiA[UonDJi@05
onDJi@?o000000?oa3_4o`000?oZ5NX02ooZ5NX00ol0003on@KiooT6n@09ooT6n@03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooX5
n_oj1OX01?l00006oo4>l@03o`000?od2oCom0_d00Com0_d1?l0000<on<Lh`03o`000?o5>/GoaC[5
00GoaC[500?o0000om8]d_oB;M801?oB;M800ol0003oiA[UonDJi@08onDJi@03o`000?oZ5N[ojQGZ
00_ojQGZ00?o0000ooT6nOoi1_T02?oi1_T00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000ooX5n_oj1OX01Ooj1OX3o`0000;ol@ka00?o0000oo@;m?od
2o@02?od2o@00ol0003ohacSon<Lh`0:on<Lh`03o`000?o5>/GoaC[500CoaC[500?o0000om8]d_oB
;M801OoB;M800ol0003oiA[UonDJi@08onDJi@03o`000?oZ5N[ojQGZ00WojQGZ1?l00008ooT6n@03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?oj1O[onPGj00WonPGj0_l0000<oo@;m003o`000?oS7>?ohacS00WohacS
00?o0000olDjaOo5>/D00oo5>/D00ol0003odRgBom8]dP05om8]dP03o`000?oU6^GoiA[U00[oiA[U
00?o0000onXEj_oZ5NX01?oZ5NX4o`0000Con0Oh00?o0000ooT6nOoi1_T01?oi1_T00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ooX5n_oj1OX02ooj
1OX00ol0003om0_doo@;m00:oo@;m003o`000?oS7>?ohacS00WohacS00?o0000olDjaOo5>/D00_o5
>/D00ol0003odRgBom8]dP06om8]dP03o`000?oU6^GoiA[U00[oiA[U00?o0000onXEj_oZ5NX01?l0
0009ooP7n0Ko00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=ooX5nP03o`000?od2oCom0_d00[om0_d00?o0000on<LhooS7><02OoS7><01Ol0003oaC[5olDj
aOo5>/Go000000WodRgB00?o0000onDJiOoU6^D02ooU6^D2o`0000gon0Oh00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ooj1OX00ol0003om0_doo@;m00;oo@;m003o`000?oS7>?ohacS00WohacS00?o
0000olDjaOl000002OoB;M800ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00con0Oh00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_oj1OX00ol0003om0_doo@;m00:oo@;m003o`000?oS7>?o
hacS00SohacS1Ol00008om8]dP03o`000?oU6^GoiA[U00coiA[U00?o0000ooP7n?oh1oP02ooh1oP0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000SonPGj00?o0000oo@;m?od2o@02_od2o@00ol0003ohacSon<Lh`07on<L
h`03o`000?oX5nSoj1OX00?oj1OX0ol00005om8]dP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000ooX5n_oj1OX01Ooj1OX2o`0000co
m0_d00?o0000on<LhooS7><01OoS7><00ol0003oj1OXonPGj007onPGj0?o000000?odRgBo`000?oU
6^D03OoU6^D00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004ooX5nP03o`000?ol0ocoo0?l00;o00002_od2o@00ol0003ohacSon<Lh`03on<Lh`;o0000
3OoX5nP2o`0000goiA[U0ol0000=ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ooj1O[o0000oo`3o004oo`3o003o`000?od2oCom0_d00Oom0_d00Co0000on<LhooS7>?ohacS
0_l00002ooH9mP03o`000?oX5nSoj1OX00coj1OX3Ol00003ooT6n@03o`000?oh1oSon0Oh00[on0Oh
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008oo@;m003o`000?oS7>?o000000GomPWf
00?o0000onPGj?oX5nP02ooX5nP00ol0003okQ7^onhAkP09onhAkP03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooP7n003o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om0_d0ol0
0007ooH9mP03o`000?oX5nSoj1OX00[oj1OX00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on@KiooT6
n@04ooT6n@;o00001ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo0?loo`3o?ol0o`3o`0000;onPGj00?o0000ooH9m_of2OH01_of2OH00ol0003oj1OXonPG
j008onPGj003o`000?o^4NkokQ7^00[okQ7^00?o0000ooT6nOoi1_T01_oi1_T00ol0003on0OhooP7
n004ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?ol0oco
o0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`000008ooH9mP03o`000?oX5nSoj1OX00Ooj1OX00?o
0000onhAk_o^4Nh02_o^4Nh00ol0003on@KiooT6n@07ooT6n@;o00001?oh1oP00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l00Coo0?l00?o0000ooX5n_oj1OX00_oj1OX0
0ol0003omPWfooH9mP07ooH9mP03o`000?oX5nSoj1OX00Koj1OX00?o0000onhAk_o^4Nh02_o^4Nh0
0ol0003on@KiooT6n@09ooT6n@05o`000?oh1oSon0OhooP7n?l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003onPGjooX5nP03
ooX5nP03o`000?of2OKomPWf00OomPWf00?o0000onPGj?oX5nP01OoX5nP00ol0003okQ7^onhAkP0:
onhAkP03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?oj1O[onPGj00?onPGj00?o0000
ooH9m_of2OH02?of2OH00ol0003oj1OXonPGj004onPGj003o`000?o^4NkokQ7^00WokQ7^00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?ol0ocoo0?l
00Goo0?l00?o0000ooX5n_oj1OX01?oj1OX00ol0003omPWfooH9mP09ooH9mP03o`000?oX5nSoj1OX
00;oj1OX00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`01Ool0o`00ol0003onPGjooX5nP05ooX5nP03o`000?of2OKomPWf00WomPWf00Go0000onPGj?oX
5nSoj1OXo`00000<onhAkP03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oj1O[onPGj00GonPGj00?o0000ooH9m_of
2OH02_of2OH00ol0003oj1OXo`000004o`0000WokQ7^00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003onPGjooX5nP07ooX5nP;o0000
2oof2OH00ol0003on`Ckoo/4n`03oo/4n`Oo00000_o^4Nh00ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003oo0?loo`3o?ol0oco000000Soo0?l00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;m
o`000002o`0000SomPWf00?o0000oo/4nook1?/02_ok1?/5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ol0oco000000Woo0?l00?o
0000ooX5n_oj1OX01_oj1OX00ol0003oo@;mood2o@03ood2o@?o00001?of2OH00ol0003on`Ckoo/4
n`0=oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP07
ooX5nP03o`000?om0_goo@;m00Koo@;m0ol000000oof2OKo0000oo/4n`0>oo/4n`03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?ol0ocoo0?l00;oo0?l1_l00008ooX5nP03o`000?om0_goo@;m00[oo@;m00?o0000oo/4
nook1?/03ook1?/00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?om0_goo@;m00[o
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?oj1O[onPGjo`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003onPGjo`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01?l00?l9oooo00Ko003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Co003o0_ooo`04o`00o`Soool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo00Co003o00?oool0o`00ool00?l00ol00?l2
oooo00?o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol0
0?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00
o`03oooo0?l00?oo003o00;o003o0_ooo`000ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo
00Go003o00?oool0o`00ool00?l00ol00?l01?ooo`3o003oo`00ool00?l2oooo00Go003o00?oool0
o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00
o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo
0?ooo`001_l00?l2oooo00Ko003o0_ooo`05o`00o`;oool02?l00?l00oooo`3o003oo`00o`04o`00
o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l0
0?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool01Ol00?l4oooo00;o
003o0_ooo`06o`00o`;oool01Ol00?l3oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo00Ko
003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Coool0o`00ool00?oo
003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool01?l00?l2oooo00Oo
003o0_ooo`03o`00o`?oool02?l00?l00oooo`3o003oo`00o`04o`00o`;oool01_l00?l2oooo00Ko
003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o
00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003o
oooo0?ooo`08o`00o`03oooo0?l00?oo003o00?oool02_l00?l00oooo`3o003oo`00o`03o`00o`;o
ool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003o
o`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool0
1?l00?l01?ooo`3o003ooooo0?ooo`09o`00o`Coool02ol00?l2oooo00Co003o0_ooo`06o`00o`;o
ool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool0
0ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool0
00?o003ooooo0?ooo`002?l00?l4oooo00go003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l0
0?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool01ol0
0?l3oooo00;o003o0_ooo`0;o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol0
0?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06
o`00o`?oool01?l00?l2oooo00[o003o0_ooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1W
o`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo
00Ko003o0_ooo`06o`00o`;oool00_l00?l00oooo`3o003oo`00o`04o`00o`;oool00ol00?l2oooo
00Ko003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;o
ool01_l00?l2oooo01So003o0_ooo`06o`00o`;oool01_l00?l2oooo00;o003o0_ooo`05o`00o`;o
ool01?l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o
0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00o`03o`00o`;oool0
1_l00?l2oooo00?o003o0_ooo`03o`00o`?oool01?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8b
c?ooo`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00
o`0Fo`00o`Goool01?l00?l2oooo00Co003o0_ooo`05o`00o`Koool01_l00?l2oooo00;o003o0_oo
o`05o`00o`Goool0Iol00?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5
oooo027o003o1Oooo`07o`00o`Coool02?l00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1oooo
o`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(830) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.992 .008 .992 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.989 .011 .989 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.994 .006 .994 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.971 .029 .971 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.976 .024 .976 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.946 .054 .946 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.984 .016 .984 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.993 .007 .993 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.89 .11 .89 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.967 .033 .967 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.965 .035 .965 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.971 .029 .971 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.979 .021 .979 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.953 .047 .953 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.979 .021 .979 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.922 .078 .922 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.986 .014 .986 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.977 .023 .977 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.963 .037 .963 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.974 .026 .974 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.901 .099 .901 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.984 .016 .984 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.957 .043 .957 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.924 .076 .924 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.74 .26 .74 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.788 .212 .788 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.981 .019 .981 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.933 .067 .933 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.937 .063 .937 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.758 .242 .758 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.718 .282 .718 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.665 .335 .665 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.923 .077 .923 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.946 .054 .946 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.934 .066 .934 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.892 .108 .892 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.779 .221 .779 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.973 .027 .973 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.771 .229 .771 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.68 .32 .68 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.872 .128 .872 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.427 .573 .427 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.421 .579 .421 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.507 .493 .507 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.79 .21 .79 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.805 .195 .805 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.987 .013 .987 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.458 .542 .458 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.414 .586 .414 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.955 .045 .955 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.595 .405 .595 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.724 .276 .724 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.918 .082 .918 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.919 .081 .919 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.643 .357 .643 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.882 .118 .882 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.352 .648 .352 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.839 .161 .839 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.725 .275 .725 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.14 .86 .14 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.313 .687 .313 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.979 .021 .979 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.237 .763 .237 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.183 .817 .183 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.89 .11 .89 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.981 .019 .981 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.49 .51 .49 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.147 .853 .147 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.219 .781 .219 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.805 .195 .805 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.316 .684 .316 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.534 .466 .534 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.99 .01 .99 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.208 .792 .208 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.039 .961 .039 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.129 .871 .129 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.023 .977 .023 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.347 .653 .347 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.535 .465 .535 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.962 .038 .962 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.571 .429 .571 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.645 .355 .645 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.043 .957 .043 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.027 .973 .027 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.1 .9 .1 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.135 .865 .135 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.776 .224 .776 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.911 .089 .911 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.939 .061 .939 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.459 .541 .459 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.097 .903 .097 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.826 .174 .826 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.992 .008 .992 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.206 .794 .206 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.422 .578 .422 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.108 .892 .108 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.269 .731 .269 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.856 .144 .856 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.392 .608 .392 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.112 .888 .112 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.981 .019 .981 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.898 .102 .898 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.932 .068 .932 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.266 .734 .266 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.973 .027 .973 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.02 .98 .02 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.637 .363 .637 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.608 .392 .608 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.111 .889 .111 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.241 .759 .241 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.516 .484 .516 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.773 .227 .773 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.115 .885 .115 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.986 .014 .986 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.061 .939 .061 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.211 .789 .211 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.281 .719 .281 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.973 .027 .973 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.492 .508 .492 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.424 .576 .424 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.297 .703 .297 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.251 .749 .251 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.918 .082 .918 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.892 .108 .892 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.888 .112 .888 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.195 .805 .195 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.525 .475 .525 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.677 .323 .677 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.865 .135 .865 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.972 .028 .972 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.496 .504 .496 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.738 .262 .738 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.384 .616 .384 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.961 .039 .961 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.944 .056 .944 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.86 .14 .86 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.977 .023 .977 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.501 .499 .501 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.618 .382 .618 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.989 .011 .989 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.531 .469 .531 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.906 .094 .906 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.694 .306 .694 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.826 .174 .826 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.637 .363 .637 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.978 .022 .978 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.968 .032 .968 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.982 .018 .982 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.78 .22 .78 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.962 .038 .962 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.719 .281 .719 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.75 .25 .75 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.865 .135 .865 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.867 .133 .867 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.959 .041 .959 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.81 .19 .81 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.986 .014 .986 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.955 .045 .955 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.934 .066 .934 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.92 .08 .92 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.873 .127 .873 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.885 .115 .885 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.835 .165 .835 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.932 .068 .932 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.956 .044 .956 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.98 .02 .98 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.967 .033 .967 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.973 .027 .973 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.985 .015 .985 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.965 .035 .965 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.893 .107 .893 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.959 .041 .959 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.973 .027 .973 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.986 .014 .986 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.982 .018 .982 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.985 .015 .985 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.971 .029 .971 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.976 .024 .976 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.984 .016 .984 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.986 .014 .986 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.991 .009 .991 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo@;mood2oOl0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ood2oOom0_d00_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000coo@;m00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?om
0_goo@;m00_oo@;m0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo0?loo`3o006
oo`3o003o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?ol0ocoo0?loo`3o0;o00002_oo0?l2o`000003oo`3o?l0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ood2oOl000002ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_go
o@;m00Woo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?ol0oco
o0?l00Coo0?l0_l00005ool0o`?o00001?ol0o`00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ood2
o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo0?l0_l000000ooo
0?oo0000o`000007oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo
0?l01ooo0?l00ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol
0o`01ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ok1?_on`Cko`0000?oo`3o0_l00008ood2
o@03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@05ood2
o@03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003ool0o`00ol0003oo0?loo`3o008oo`3
o003o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo/4n`03o`000?oo0?oo000000_oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o009oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o
o0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo/4n`03o`000?om0_goo@;m00_oo@;m00?o
0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o00:oo`3o004o`000?om0_goo@;mood2o@?o0000
3oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_on`Ck1?l0
0009ood2o@03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02ool0o`01?l0003oo@;mo`00
0?l00003ooH9mP;o00003?om0_d2o`00013oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo/4nook1?/02ook1?/01?l0003ol0o`
oo0?l?o`3o05o`0000Goo@;m00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00<oo`3o003
o`000?of2OKomPWf00GomPWf0_l00008ood2o@;o00000_of2OH00ol0003oo0?loo`3o00=oo`3o003
o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ook1?/00ol0003ol0o`oo0?l007oo0?l0Ko00000_oo0?l4o`0000goo0?l00?o0000ooH9m_of2OH0
1oof2OH2o`0000Goo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003oo0?loo`3o00<oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ook1?/00ol0003ol0o`oo0?l00<oo0?l0?o00001?oi1_T3o`0000Woo0?l00?o
0000ooH9m_of2OH02_of2OH2o`000003ood2oOl0003o000000OomPWf00?o0000oo`3o?ol0o`02ool
0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo/4nook1?/03_ok1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Won@Ki00Kon@Ki0ol00005
oo`3o003o`000?of2OKomPWf00gomPWf00?o0000ooH9m_of2OH02?of2OH00ol0003oo0?loo`3o009
oo`3o003o`000?ol0ocoo0?l00goo0?l00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000oon`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on@KiooT6n@0:
ooT6n@?o000000?oo0?lo`000?of2OH03oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?ol0oco
o0?l00Soo0?l00?o0000oo`3o?ol0o`03_ol0o`3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooi
1_Wo0000oo/4n`0>oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooT6nOoi1_T03Ooi1_T00ol0
003omPWfooH9mP0?ooH9mP03o`000?of2OKomPWf00[omPWf2ol0000;oo`3o0Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo0?lo`000?oo0?oo0000
00SooP7n0ol00005ooT6n@03o`000?ok1?_on`Ck00con`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0
003on@KiooT6n@0=ooT6n@;o00004?of2OH00ol0003omPWfooH9mP0:ooH9mP03o`000?od2oCom0_d
00Oom0_d00?o0000oo`3o?ol0o`00_ol0o`7o`0000Com`Sg00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo0?loo`3o?ol0o`2o`00
00GooP7n0ol00009ooT6n@;o00002ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Won@Ki
00gon@Ki00Co0000on@Ki?oT6nCo00003oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCo
m0_d00Wom0_d1?l0000;ooL8m`03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`01?ol0o`00ol0003ooP7no`000002o`00
00con@Ki00Co0000on/Djol0003o00002Ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Wo
n@Ki00gon@Ki00Go0000on@Ki?oT6nCoi1_To`00000=ooH9mP03o`000?of2OKomPWf00[omPWf00?o
0000oo@;m?od2o@02Ood2o@00ol0003om`SgooL8m`0<ooL8m`03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003on@KiooT6n@0<ooT6n@03o`000?o[5>_ojaC[00;ojaC[0_l00007oo/4n`03o`000?o`3o3o
l0o`00col0o`00?o0000ooT6nOoi1_T03Ooi1_T00ol0003oi1_Ton@Ki003on@Ki003o`000?of2OKo
mPWf00[omPWf00?o0000ooH9m_of2OH02_of2OH00ol0003om0_doo@;m009oo@;m003o`000?og2?Oo
m`Sg00com`Sg00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo0?loo`3o006oo`3o003o`000?oi1_Won@Ki00_on@Ki00?o0000on/D
joo[5>/01Oo[5>/00ol0003on`Ckoo/4n`03oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooT6
nOoi1_T03Ooi1_T00ol0003oi1_Ton@Ki004on@Ki003o`000?of2OKomPWf00WomPWf00?o0000ooH9
m_of2OH02Oof2OH00ol0003om0_doo@;m00:oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o007oo`3o003o`000?oi1_Won@Ki00_on@Ki00?o0000on/Djoo[5>/01_o[5>/2o`0000?o
n`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on@KiooT6n@0<ooT6n@03o`000?oT6nCoi1_T00Ko
i1_T00?o0000ooH9m_of2OH02?of2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00[o
m0_d00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003on@KiooT6n@0:ooT6n@03o`00
0?o[5>_ojaC[00WojaC[0_l000000ook1?_o0000oo0?l00<oo0?l0?o00003_oi1_T00ol0003oi1_T
on@Ki007on@Ki003o`000?of2OKomPWf00OomPWf00?o0000ooH9m_of2OH02Oof2OH00ol0003om0_d
oo@;m00;oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0003on@KiooT6
n@09ooT6n@03o`000?o[5>_ojaC[00_ojaC[00?o0000oo0?l?o`3o002_o`3o02o`0000?ofbCK00?o
0000ooT6nOoi1_T02_oi1_T00ol0003oi1_Ton@Ki009on@Ki003o`000?of2OKomPWf00KomPWf00?o
0000ooH9m_of2OH02?of2OH00ol0003om0_doo@;m00<oo@;m003o`000?og2?Oom`Sg00com`Sg00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ojaC[on/Dj`0<on/Dj`03o`000?o`3o3ol0o`00Sol0o`0_l00006om/Tf`;o00002_oi1_T0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?of2OKomPWf00GomPWf00?o0000ooH9m_of2OH02?of2OH0
0ol0003om0_doo@;m00<oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
oo`3o003o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[5>/03_o[5>/00ol0003ol0o`oo0?l004
oo0?l0?o00002_oK9=/00ol0003on@KiooT6n@07ooT6n@03o`000?oT6nCoi1_T00_oi1_T00?o0000
ooH9m_of2OH00oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00com0_d00?o0000
ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo0?loo`3o00<oo`3o003o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[5>/03oo[5>/01?l0
003ol0o`oo0?l?o`3o02o`0000kofbCK0_l00006ooT6n@03o`000?oT6nCoi1_T00goi1_T00?o0000
ooH9m_of2OH00_of2OH00ol0003omPWfooH9mP08ooH9mP03o`000?od2oCom0_d00com0_d0ol0000=
ooL8m`03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo0?l00?o0000ooT6nOoi1_T01_oi1_T00ol0003ojaC[on/Dj`0@on/Dj`Co00004_oK9=/00ol0
003on@KiooT6n@03ooT6n@03o`000?oT6nCoi1_T00koi1_T00Go0000ooH9m_of2OKomPWfo`000005
ooH9mPOo00003?od2o@01Ol0003okQ7^onhAk_o^4Nko000000com`Sg00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo0?l00?o0000ooT6nOoi1_T01_oi1_T00ol0003ojaC[on/Dj`0=
on/Dj`?o000000CoeRWFo`000?l0003o00004ooK9=/2o`0000;on@Ki00?o0000on@Ki?oT6n@04?oT
6n@00ol0003omPWfo`000006o`0000OogB;M00?o0000oo@;m?od2o@02?od2o@00ol0003okQ7^onhA
kP03onhAkP;o00002?og2?L3o`0000Koo@;m1?l00002oo/4n`03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?of2OH3o`0000goo0?l00?o0000ooT6nOoi1_T01?oi1_T00ol0003ojaC[on/D
j`0;on/Dj`?o00000ooF:MH01Ol0003ocS7>o`000?nUFZGo000001CofbCK00?o0000ooT6nOl00000
4ooT6n@00ol0003ogB;MomdRg@0=omdRg@03o`000?od2oCom0_d00Gom0_d0_l00008onhAkP03o`00
0?og2?Oom`Sg00Go00000ooe2_D00ol0003oo@;mood2o@03o`0000Oon`Ck00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000ComPWf0ol0000:oo`3o003o`000?oi1_Won@Ki00?on@Ki
00?o0000on/Djoo[5>/02Oo[5>/3o`0000GoeRWF00Co0000olhac_o><Lko00000_nUFZD00ol0003o
fbCKom/Tf`0Bom/Tf`03o`000?oT6nCoi1_T01;oi1_T00?o0000omdRgOoM8]d03_oM8]d00ol0003o
m0_doo@;m003oo@;m003o`000?o^4NkokQ7^00WokQ7^0_l00009ooD:m@;o00002_ok1?/00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooH9mP;o00001ool0o`5o`0000;o
n@Ki00?o0000on/Djoo[5>/01_o[5>/3o`0000SoeRWF00Co0000olhac_o><Lko00000onUFZD00ol0
003ofbCKom/Tf`0Aom/Tf`03o`000?oT6nCoi1_T017oi1_T00?o0000omdRgOoM8]d04?oM8]d01Ol0
003om0_doo@;m?od2oCo000000cokQ7^00?o0000ooD:mOoe2_D02?oe2_D00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooH9m_of2OH01oof2OH3o`00
0004oo`3o?l0003o0000o`0000Goka3_0_l00006on/Dj`?o00002_oF:MH01Ol0003ocS7>olhac_o>
<Lko000000CoYEZU00?o0000om/TfooK9=/04?oK9=/00ol0003oi1_Ton@Ki00Aon@Ki003o`000?oM
8]gogB;M017ogB;M00?o0000oo@;m?l000003Oo^4Nh00ol0003om@[eooD:m@08ooD:m@03o`000?ok
1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooH9m_of2OH02_of2OH00ol0003oka3_onl@k`08onl@k`03o`000?o[5>_ojaC[00?o00003OoF:MH0
1Ol0003ocS7>olhac_o><Lko000000GoYEZU00?o0000om/TfooK9=/03ooK9=/00ol0003oi1_Ton@K
i00Aon@Ki003o`000?oM8]gogB;M01;ogB;M00?o0000onhAk_o^4Nh03?o^4Nh00ol0003om@[eooD:
m@08ooD:m@03o`000?ok1?_on`Ck00_on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o_4>ooka3_00Woka3_0_l0000?omHYeP03o`000?o><Lko
cS7>00;ocS7>00?o0000ojEJYOnUFZD01?nUFZD00ol0003ofbCKom/Tf`0=om/Tf`?o00004OoT6n@0
0ol0003ogB;MomdRg@0ComdRg@03o`000?o^4NkokQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D0
0ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o_4>ooka3_00Woka3_00?o0000omHYe_oF:MH03OoF:MH0
0ol0003ocS7>olhacP03olhacP03o`000?nUFZGoYEZU00GoYEZU00?o0000om/TfooK9=/02_oK9=/2
o`0000?oVfBK00?o0000on@Ki?oT6n@03_oT6n@00ol0003ogB;MomdRg@0ComdRg@03o`000?o^4Nko
kQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_omPWf00?o0000onl@
koo_4>l02oo_4>l00ol0003oeRWFomHYeP0<omHYeP03o`000?o><LkocS7>00?ocS7>00?o0000ojEJ
YOnUFZD01_nUFZD00ol0003ofbCKom/Tf`07om/Tf`;o00001_nKI9/2o`0000koi1_T00?o0000omdR
gOoM8]d04ooM8]d00ol0003okQ7^onhAkP0;onhAkP03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4
nook1?/03?ok1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_omPWf00?o0000onl@koo_4>l02oo_4>l00ol0003oeRWFomHYeP0;omHY
eP03o`000?o><LkocS7>00CocS7>00?o0000ojEJYOnUFZD01onUFZD00ol0003ofbCKom/Tf`05om/T
f`03o`000?nKI9_oVfBK00SoVfBK00?o0000on@Ki?oT6n@02_oT6n@00ol0003ogB;MomdRg@0DomdR
g@03o`000?o^4NkokQ7^00_okQ7^00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_omPWf00?o0000onl@koo_4>l02oo_4>l00ol0003oeRWFomHYeP0;omHYeP03o`000?o><LkocS7>
00CocS7>00?o0000ojEJYOnUFZD02?nUFZD00ol0003ofbCKom/Tf`02om/Tf`;o00003?nKI9/2o`00
00[oi1_T00?o0000omdRgOoM8]d05?oM8]d00ol0003okQ7^onhAkP0;onhAkP03o`000?oe2_Gom@[e
00Wom@[e00?o0000oo/4nook1?/03Ook1?/00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooH9m_of2OH02?of2OH00ol0003oka3_onl@k`0<onl@k`03
o`000?oF:MKoeRWF00WoeRWF00?o0000olhac_o><Lh01Oo><Lh00ol0003oYEZUojEJY@09ojEJY@04
o`000?oK9=_o0000o`00013oVfBK0_l00008on@Ki003o`000?oM8]gogB;M01CogB;M0ol0000;onhA
kP03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4nook1?/03Ook1?/01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooH9
m_of2OH02?of2OH00ol0003oka3_onl@k`0;onl@k`;o00002_oF:MH00ol0003ocS7>olhacP06olha
cP03o`000?nUFZGoYEZU00[oYEZU00?o0000oi]TVonKI9/04_nKI9/00ol0003oi1_Ton@Ki004on@K
i003o`000?oM8]gogB;M01GogB;M00?o0000omDZeOoE:]D01Ol00005onhAkP03o`000?oe2_Gom@[e
00[om@[e00?o0000oo/4nook1?/03_ok1?/3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooH9m_of2OH01oof2OH00ol0003oka3_onl@k`0;onl@k`04
o`000?o5>/GoaC[5o`0000WoeRWF00?o0000olhac_o><Lh01_o><Lh00ol0003oYEZUojEJY@0:ojEJ
Y@03o`000?nKI9_oVfBK01?oVfBK0_l00003on@Ki0Co00005?oM8]d00ol0003oeB[EomDZe@06omDZ
e@Co000000?okQ7^o`000?oe2_D02ooe2_D00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooH9m_of
2OH01oof2OH00ol0003oka3_onl@k`09onl@k`;o00001?o5>/D00ol0003oeRWFomHYeP05omHYeP03
o`000?o><LkocS7>00OocS7>00?o0000ojEJYOnUFZD02_nUFZD00ol0003oVfBKoi]TV`0Eoi]TV`03
o`000?oT6nCo000000Co/Dja0ol0000@omdRg@03o`000?oE:]GoeB[E00_oeB[E0_l0000<ooD:m@03
o`000?ok1?_on`Ck00con`Ck0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?of2OKomPWf00OomPWf00?o0000onl@koo_4>l02?o_4>l00ol0003oaC[5
olDja@05olDja@03o`000?oF:MKoeRWF00CoeRWF00?o0000olhac_o><Lh01oo><Lh00ol0003oYEZU
ojEJY@0:ojEJY@03o`000?nKI9_oVfBK01KoVfBK00?o0000ok5>/OnaC[401_naC[43o`0000cogB;M
00?o0000omDZeOoE:]D03OoE:]D00ol0003om@[eooD:m@09ooD:m@Go00002Ook1?/2o`000003ood2
oOl0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooH9m_of2OH01_of
2OH00ol0003oka3_onl@k`07onl@k`03o`000?o5>/GoaC[500OoaC[500?o0000omHYe_oF:MH00_oF
:MH00ol0003ocS7>olhacP08olhacP03o`000?nUFZGoYEZU00WoYEZU00?o0000oi]TVonKI9/05onK
I9/00ol0003o/Djaok5>/@09ok5>/@?o00002OoM8]d00ol0003oeB[EomDZe@0>omDZe@Ko00001?oe
2_D00ol0003on@KiooT6n@03ooT6n@Go00000_ok1?/2o`0000Coo@;m00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?ol0ocoo0?loo`3o?l000002ook1?/00ol0003omPWfooH9mP06ooH9mP03o`000?o_
4>ooka3_00Goka3_0_l0000;olDja@04o`000?oF:MKoeRWFo`0000_ocS7>00?o0000ojEJYOnUFZD0
2OnUFZD00ol0003oVfBKoi]TV`0Foi]TV`03o`000?naC[7o/Dja00go/Dja0ol00005omdRg@03o`00
0?oE:]GoeB[E00ooeB[E00?o0000on@Ki?oT6n@00ooT6n@4o`0000_on@Ki0_l00006ood2o@03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o002oo`3o0ko00001_of2OH00ol0003oka3_onl@
k`05onl@k`03o`000?o5>/GoaC[500coaC[500?o0000omHYe_l000002oo><Lh00ol0003oYEZUojEJ
Y@07ojEJY@?o00006?nKI9/00ol0003o/Djaok5>/@0@ok5>/@?o000000?ogB;Mo`000?oE:]D04?oE
:]D00ol0003oi1_Ton@Ki007on@Ki003o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom
0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005oo`3o003o`000?og2?Oom`Sg00_om`Sg0_l00004
ooH9mP03o`000?o_4>ooka3_00?oka3_0_l0000@olDja@03o`000?o><LkocS7>00[ocS7>00?o0000
ojEJYOnUFZD00onUFZD4o`0000;oMHYe00?o0000oi]TVonKI9/05OnKI9/00ol0003o/Djaok5>/@0D
ok5>/@03o`000?oE:]GoeB[E013oeB[E00?o0000on@Ki?oT6n@01ooT6n@00ol0003on@KiooT6n@0:
ooT6n@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Goo0?l00?o0000ooL8moog2?L03Oog2?L6o`0000?oka3_00?o0000olDjaOo5>/D04?o5>/D00ol0
003ocS7>olhacP0:olhacP03o`000?nUFZGo000000?o00001omeRWD00ol0003oVfBKoi]TV`0Doi]T
V`03o`000?naC[7o/Dja01Co/Dja00?o0000omDZeOoE:]D03ooE:]D00ol0003oi1_Ton@Ki008on@K
i003o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oV6NKoiQWV00?o
iQWV00?o0000onl@kol000004oo5>/D4o`0000WocS7>0_l0000<ogF:M@03o`000?nKI9_oVfBK01?o
VfBK00?o0000ok5>/OnaC[405OnaC[400ol0003oeB[EomDZe@0>omDZe@03o`000?oT6nCoi1_T00So
i1_T00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooL8moog2?L02oog2?L00ol0003oiQWVonHIiP05onHIiP03o`00
0?o5>/GoaC[501;oaC[500Co0000ogf2OOmmPWgoOH9m1Ol00003olhacP03o`000?meRWGoMHYe00go
MHYe0ol0000@oi]TV`;o00006?naC[400ol0003oeB[EomDZe@0=omDZe@03o`000?oT6nCoi1_T00Wo
i1_T00?o0000ooT6nOoi1_T02Ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo0?l00?o0000ooL8moog2?L02_og2?L00ol0003oiQWVonHIiP06onHIiP03o`00
0?o5>/GoaC[5017oaC[500?o0000ogf2OOmmPWd01ommPWd3o`00013oMHYe00?o0000odBkA?m4^d@0
1Ol00009oi]TV`;o000000?oK9=/o`000?naC[405onaC[400ol0003oeB[EomDZe@0=omDZe@03o`00
0?oT6nCoi1_T00Woi1_T00?o0000ooT6nOoi1_T02?oi1_T2o`0000[oo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8
m`0:ooL8m`03o`000?oV6NKoiQWV00OoiQWV00?o0000olDjaOo5>/D03oo5>/D00ol0003oOH9mogf2
O@0:ogf2O@03o`000?meRWGoMHYe00goMHYe00?o0000odBkA?m4^d@01_m4^d@4o`0000CoVfBK00?o
0000ofbCK?m/Tf`00_m/Tf`00ol0003o/Djaok5>/@0Fok5>/@03o`000?oE:]GoeB[E00_oeB[E00?o
0000on@Ki?oT6n@02ooT6n@00ol0003on@KiooT6n@06ooT6n@03o`000?ol0oco000000[oo@;m00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02?ol0o`=
o`0000[oiQWV00?o0000olDjaOo5>/D03oo5>/D00ol0003oOH9mogf2O@0;ogf2O@03o`000?meRWGo
MHYe00coMHYe00?o0000odBkA?m4^d@02_m4^d@4o`0000GoK9=/00?o0000ok5>/OnaC[405_naC[40
0ol0003oeB[EomDZe@0:omDZe@03o`000?oT6nCoi1_T00coi1_T00?o0000ooT6nOoi1_T01?oi1_T2
o`0000?oo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?og2?Oom`Sg00Wom`Sg00?o0000onHI
i_oV6NH02OoV6NH00ol0003oaC[5olDja@0=olDja@03o`000?mmPWgoOH9m00coOH9m00?o0000ogF:
MOmeRWD03?meRWD00ol0003oA;]4odBkA00;odBkA003o`000?m7^4Oo000000KoK9=/00?o0000ok5>
/OnaC[405_naC[400ol0003oeB[EomDZe@09omDZe@03o`000?oT6nCoi1_T00coi1_T00?o0000ooT6
nOoi1_T00ooi1_T00ol0003oo0?loo`3o003oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003o
m`SgooL8m`08ooL8m`03o`000?oV6NKoiQWV00_oiQWV00?o0000olDjaOo5>/D02?o5>/D4o`0000oo
OH9m00?o0000ogF:MOmeRWD02omeRWD00ol0003oA;]4odBkA00;odBkA004o`000?m7^4OoAkQ7o`00
00OoK9=/00?o0000ok5>/OnaC[405OnaC[400ol0003oeB[EomDZe@08omDZe@03o`000?oT6nCoi1_T
00goi1_T00?o0000ooT6nOoi1_T00_oi1_T00ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m
00Ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo`3o?ol
0o`01Ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oV6NKoiQWV00_oiQWV00?o0000olDjaOo5
>/D00oo5>/D5o`0000?oPGj100?o0000ogf2OOmmPWd03_mmPWd00ol0003oMHYeogF:M@0:ogF:M@03
o`000?m4^dCoA;]400[oA;]400Go0000odNhAom7^4OoAkQ7o`000007ofbCK003o`000?naC[7o/Dja
01Go/Dja00?o0000omDZeOoE:]D02?oE:]D00ol0003oi1_Ton@Ki00=on@Ki003o`000?oi1_Won@Ki
00;o00002?ol0o`00ol0003oo@;mood2o@08ood2o@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiQWVonHIiP0<onHIiPGo00002On1OX400ol0003o
OH9mogf2O@0<ogf2O@;o00003?meRWD00ol0003oA;]4odBkA00:odBkA005o`000?m7^4OoAkQ7odNh
Aol000002?m/Tf`00ol0003o/Djaok5>/@0Dok5>/@?o00001ooE:]D00ol0003oi1_Ton@Ki00>on@K
i003o`000?oi1_Wo000000_oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o004oo`3o003o`000?og2?Oom`Sg00Oo
m`Sg00?o0000onHIi_oV6NH03?oV6NH01?l0003o`Sg2ol8m`_l0000;oh5nP@03o`000?mmPWgoOH9m
00_oOH9m00Co0000ocG:=OlebSGo00002_meRWD00ol0003oA;]4odBkA00:odBkA003o`000?m7^4Oo
AkQ700;oAkQ700?o0000ofbCK?m/Tf`01_m/Tf`00ol0003o/Djaok5>/@0Aok5>/@?o00000onhAkP0
0ol0003oeB[EomDZe@04omDZe@03o`000?oT6nCoi1_T00goi1_T1?l0000;oo`3o003o`000?om0_go
o@;m00Goo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo`3
o?ol0ocoo0?l1?l00008ooL8m`03o`000?oV6NKoiQWV00_oiQWV00?o0000ol8m`_o2?L800_o2?L80
0ol0003oPGj1oh5nP@08oh5nP@03o`000?mmPWgoOH9m00[oOH9m00?o0000ocG:=OlebSD00_lebSD0
0ol0003oMHYeogF:M@03ogF:M@Go00002om4^d@00ol0003oAkQ7odNhA`03odNhA`03o`000?m/Tfco
K9=/00OoK9=/00?o0000ok5>/OnaC[403_naC[42o`0000Oo^4Nh00?o0000omDZeOoE:]D00_oE:]D0
0ol0003oi1_Ton@Ki00=on@Ki003o`000?oh1oSon0Oh00;on0Oh00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo@;mood2o@03ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oh1oP00ol0003om`SgooL8m`05ooL8m`03o`000?oV6NKoiQWV00[oiQWV00?o0000ol8m
`_o2?L800oo2?L800ol0003oPGj1oh5nP@09oh5nP@03o`000?mmPWgoOH9m00SoOH9m00?o0000ocG:
=OlebSD01?lebSD5o`0000Co=</d00?o0000odBkA?m4^d@02Om4^d@00ol0003oAkQ7odNhA`03odNh
A`03o`000?m/TfcoK9=/00SoK9=/00?o0000ok5>/OnaC[402_naC[43o`0000[o^4Nh00Go0000omDZ
eOoE:]GoeB[Eo`00000>on@Ki003o`000?oh1oSon0Oh00Con0Oh0_l00009oo`3o003o`000?om0_go
o@;m00;oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooP7
n?oh1oP01Ooh1oP00ol0003om`SgooL8m`03ooL8m`03o`000?oV6NKoiQWV00[oiQWV00?o0000ol8m
`_o2?L801?o2?L800ol0003oPGj1oh5nP@09oh5nP@03o`000?mmPWgoOH9m00OoOH9m00?o0000ocG:
=OlebSD01OlebSD00ol0003o=</docC;=007ocC;=003o`000?m4^dCoA;]400OoA;]400?o0000odNh
Aom7^4L01?m7^4L00ol0003oK9=/ofbCK008ofbCK003o`000?naC[7o/Dja00So/Dja0_l0000>okQ7
^0Co00003?oT6n@2o`0000Won0Oh00?o0000oo`3o?ol0o`01ool0o`01?l0003oo@;mood2oOl0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on0OhooP7n007ooP7n0;o00000oog2?L00ol0
003oiQWVonHIiP09onHIiP03o`000?o2?L;o`Sg200Ko`Sg200?o0000oh5nPOn1OX402On1OX400ol0
003oOH9mogf2O@05ogf2O@03o`000?lebSGo=LXe00Ko=LXe00?o0000ocC;=?ldbc@02?ldbc@00ol0
003oA;]4odBkA006odBkA003o`000?m7^4OoAkQ700CoAkQ700?o0000ofbCK?m/Tf`02Om/Tf`4o`00
00?o/Dja0ol0000@okQ7^005o`000?oR7N;ohQgRon8Mh_l000002_oT6n@00ol0003on0OhooP7n00:
ooP7n0Ko00000ool0o`00ol0003oo@;mo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003on0OhooP7n00:ooP7n004o`000?og2?Oom`Sgo`0000[oiQWV00?o0000ol8m`_o2?L801oo2?L80
0ol0003oPGj1oh5nP@09oh5nP@03o`000?mmPWgoOH9m00CoOH9m00?o0000ocG:=OlebSD01olebSD0
0ol0003o=</docC;=008ocC;=0;o00001_m4^d@00ol0003oAkQ7odNhA`05odNhA`03o`000?m/Tfco
K9=/00WoK9=/00Co0000ohMhQon7N8OoQgR70ol0000BokQ7^003o`000?oR7N;ohQgR00?ohQgR0_l0
0006on@Ki0;o00003Ooh1oP00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on0OhooP7n00<ooP7n0;o00002_oV6NH00ol0003o`Sg2ol8m`P08ol8m`P03o`000?n1OX7o
PGj100[oPGj100?o0000ogf2OOmmPWd00_mmPWd00ol0003o=LXeocG:=@08ocG:=@03o`000?ldbcCo
=</d00Ko=</d0_l00002oa_T6`03o`000?m4^dCoA;]400;oA;]400?o0000odNhAom7^4L01_m7^4L0
0ol0003oK9=/ofbCK008ofbCK003o`000?n7N8OoQgR700CoQgR700?o0000okQ7^?nhAkP03onhAkP0
0ol0003ohQgRon8MhP06on8MhP;o00000ooT6n@00ol0003on0OhooP7n00=ooP7n003o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oh1oSon0Oh
00kon0Oh00?o0000onHIi_oV6NH01ooV6NH00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?n1OX7oPGj1
00WoPGj100Go0000ogf2OOmmPWgoOH9mo`00000;ocG:=@03o`000?ldbcCo=</d00Co=</d0_l00005
oa_T6`05o`000?m4^dCoA;]4odBkA?l000002?m7^4L00ol0003oK9=/ofbCK008ofbCK003o`000?n7
N8OoQgR700GoQgR700?o0000okQ7^?nhAkP03_nhAkP00ol0003ohQgRon8MhP08on8MhP03o`000?oT
6nCo000000oon0Oh00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017on0Oh00?o0000onHIi_oV6NH01_oV6NH00ol0003o`Sg2
ol8m`P0;ol8m`P03o`000?n1OX7oPGj100WoPGj100Co0000ogf2OOmmPWgo00003?lebSD00ol0003o
=</docC;=002ocC;=0;o00002?lKi1/00ol0003oA;]4o`000009odNhA`03o`000?m/TfcoK9=/00So
K9=/00?o0000ohMhQon7N8L01On7N8L00ol0003o^4NhokQ7^00=okQ7^003o`000?oR7N;ohQgR00[o
hQgR00?o0000ooP7n?oh1oP03_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooP7n003o`00
0?oV6NKoiQWV00CoiQWV00?o0000ol8m`_o2?L803?o2?L800ol0003oPGj1oh5nP@0:oh5nP@?o0000
3?lebSD00ol0003o=</docC;=002o`0000_o6n@K00?o0000odNhAom7^4L02?m7^4L00ol0003oK9=/
ofbCK007ofbCK003o`000?n7N8OoQgR700OoQgR700?o0000okQ7^?nhAkP03?nhAkP00ol0003ohQgR
on8MhP0;on8MhP;o00003_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d00oom0_d00ol0003on0OhooP7n00?ooP7n0?o00000ooV
6NH00ol0003o`Sg2ol8m`P0>ol8m`P03o`000?n1OX7oPGj100SoPGj100Co0000occ3??ll`cco?<<l
0_l0000:ocG:=@?o00003OlKi1/00ol0003oAkQ7odNhA`08odNhA`03o`000?m/TfcoK9=/00OoK9=/
00?o0000ohMhQon7N8L01on7N8L00ol0003o^4NhokQ7^00;okQ7^003o`000?oR7N;ohQgR00cohQgR
00?o0000oo`3o?l000000_l0000:ooP7n003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00con0Oh0_l0
0003oo8=lP03o`000?oV6NKo0000017o`Sg200?o0000oh5nPOn1OX401on1OX400ol0003o?<<locc3
?004occ3?0;o00002?lebSD00ol0003o6n@Koa_T6`0>oa_T6`;o00002?m7^4L00ol0003oK9=/ofbC
K006ofbCK003o`000?n7N8OoQgR700WoQgR700?o0000okQ7^?nhAkP02OnhAkP00ol0003ohQgRon8M
hP0=on8MhP03o`000?ol0ocoo0?l00;oo0?l0ol00007ooP7n003o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oh1oSo
n0Oh00Won0Oh0_l00006oo8=lP03o`000?o2?L;o`Sg2013o`Sg200?o0000oh5nPOn1OX401_n1OX40
0ol0003o?<<locc3?007occ3?003o`000?lebSGo=LXe00Co=LXe0ol0000>oa_T6`03o`000?lLhaco
7><L00?o00001Om7^4L00ol0003oK9=/ofbCK006ofbCK003o`000?n7N8OoQgR700[oQgR700?o0000
okQ7^?nhAkP02?nhAkP00ol0003ohQgRon8MhP0=on8MhP03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo@;mood2o@06ood2o@03o`000?oh1oSon0Oh00Gon0Oh0ol00008oo8=lP03o`000?o2?L;o`Sg2
017o`Sg200Co0000oh5nPOn1OX7oPGj11?l0000;occ3?0;o000000Co=LXeo`000?l0003o00000ol;
m0/2o`0000_o6n@K00?o0000oacS7?lLha`01?lLha`2o`0000?oAkQ700?o0000ofbCK?m/Tf`01_m/
Tf`00ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000on8Mh_oR7N803_oR
7N800ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00;on0Oh0_l0000<oo8=lP03o`000?o2?L;o
`Sg2013o`Sg21?l00003ogF:M@03o`000?ll`cco?<<l00_o?<<l00?o0000o`_d2ol;m0/01_l;m0/0
0ol0003o6n@Koa_T6`07oa_T6`03o`000?lLhaco7><L00Oo7><L3?l0000>ohMhQ`03o`000?nhAkSo
^4Nh00Ko^4Nh00?o0000on8Mh_oR7N803_oR7N800ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Woo@;m00Co0000ooP7
n?l0003o00003_ob3O800ol0003o`Sg2ol8m`P0?ol8m`P03o`000?meRWGoMHYe00KoMHYe00?o0000
occ3??ll`c`02_ll`c`00ol0003o2o@;o`_d2`07o`_d2`;o00001_lKi1/00ol0003o7><LoacS7008
oacS7003o`000?m</dcoC;=<00SoC;=<00?o0000ohMhQon7N8L03?n7N8L00ol0003o^4NhokQ7^005
okQ7^003o`000?oR7N;ohQgR00oohQgR0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000oo8=l_ob3O803_ob3O800ol0
003o`Sg2ol8m`P0>ol8m`P03o`000?meRWGoMHYe00OoMHYe00?o0000occ3??ll`c`02_ll`c`00ol0
003o2o@;o`_d2`09o`_d2`;o00000olKi1/00ol0003o7><LoacS7009oacS7003o`000?m</dcoC;=<
00WoC;=<00?o0000ohMhQon7N8L02_n7N8L4o`0000Co^4Nh00?o0000on8Mh_oR7N804?oR7N801?l0
003on`Cko`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?om0_goo@;m00[oo@;m00?o0000oo8=l_ob3O803oob3O8@o`0000[oMHYe00?o0000occ3
??ll`c`02Oll`c`00ol0003o2OH9o`00000<o`_d2`05o`000?lKi1_o0000o`Gj1Ol000002_lLha`0
0ol0003oC;=<odbcC009odbcC003o`000?n7N8OoQgR700OoQgR70ol00004oj=LX`?o000000?o^4Nh
o`000?oR7N804OoR7N801?l0003on`Ckoo/4nook1?/2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ood2oOom0_d02_om0_d00ol0003olPgboo8=lP0?
oo8=lP03o`000?ngB;Oo]dRg00co]dRg00?o0000ogF:MOmeRWD02OmeRWD00ol0003o?<<locc3?007
occ3?004o`000?l9mPWo2OH9o`0000go2o@;00Go0000o`Gj1Ol5nPGo1OX5o`000009oacS7003o`00
0?m</dcoC;=<00[oC;=<00?o0000ohMhQon7N8L00on7N8L3o`0000[oXebS00?o0000on8Mh_oR7N80
4?oR7N800ol0003on`Ckoo/4n`04oo/4n`;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000coo@;m00?o0000oo8=l_ob3O803oob3O800ol0003o]dRgokM8]`0<okM8]`03o`000?me
RWGoMHYe00WoMHYe00?o0000occ3??ll`c`01_ll`c`00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l;
m0_o2o@;00[o2o@;00?o0000o`Gj1Ol5nPD00_l5nPD00ol0003o7><LoacS7006oacS7003o`000?m<
/dcoC;=<00[oC;=<00?o0000ohMhQon7N8L00ol0000=oj=LX`03o`000?oR7N;ohQgR013ohQgR00?o
0000oo/4nook1?/01_ok1?/2o`0000Woo0?l0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003olPgboo8=lP0=oo8=lP?o00003ongB;L0
0ol0003oMHYeogF:M@08ogF:M@03o`000?ll`cco?<<l00Go?<<l00?o0000o`Wf2Ol9mPT00ol9mPT0
0ol0003o2o@;o`_d2`0:o`_d2`03o`000?l5nPGo1OX500?o1OX500?o0000oacS7?lLha`01OlLha`0
0ol0003oC;=<odbcC00;odbcC0;o00004OnSG:<00ol0003ohQgRon8MhP0?on8MhP03o`000?ok1?_o
n`Ck00Son`Ck0_l00007oo`3o003o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ood2oOom0_d02?om0_d00ol0003olPgboo8=lP09oo8=lPGo00000_oS7><00ol0
003o]dRgokM8]`0=okM8]`03o`000?meRWGoMHYe00WoMHYe00?o0000occ3??ll`c`01?ll`c`00ol0
003o2OH9o`Wf2@04o`Wf2@03o`000?l;m0_o2o@;00So2o@;00?o0000o`Gj1Ol5nPD01Ol5nPD00ol0
003o7><LoacS7004oacS7003o`000?m</dcoC;=<00_oC;=<00?o0000oj=LXonSG:<04?nSG:<00ol0
003ohQgRon8MhP0?on8MhP03o`000?ok1?_on`Ck00[on`Ck0_l00004oo`3o003o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?ob3O;olPgb00ColPgb1Ol00007on<Lh`03
o`000?ngB;Oo]dRg00go]dRg00?o0000ogF:MOmeRWD02OmeRWD00ol0003o?<<locc3?003occ3?003
o`000?l9mPWo2OH900Go2OH900?o0000o`_d2ol;m0/02?l;m0/00ol0003o1OX5o`Gj1@06o`Gj1@03
o`000?lLhaco7><L00?o7><L00?o0000odbcC?m</d`02om</d`00ol0003oXebSoj=LX`0@oj=LX`03
o`000?oR7N;ohQgR00oohQgR00?o0000oo/4nook1?/03?ok1?/2o`000003oo`3o?l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000oo8=l_l00000
1?l0000<on<Lh`03o`000?ngB;Oo]dRg00ko]dRg00?o0000ogF:MOmeRWD02?meRWD00ol0003o?<<l
occ3?002occ3?003o`000?l9mPWo2OH900Oo2OH900?o0000o`_d2ol;m0/01ol;m0/00ol0003o1OX5
o`Gj1@07o`Gj1@03o`000?lLhaco7><L00;o7><L00?o0000odbcC?m</d`02om</d`00ol0003oXebS
oj=LX`0Aoj=LX`03o`000?oR7N;ohQgR00gohQgR00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d01Oom0_d3o`00017ohacS00?o0000okM8]ongB;L03_ng
B;L00ol0003oMHYeogF:M@09ogF:M@04o`000?ll`cco?<<lo`0000[o2OH900?o0000o`_d2ol;m0/0
1ol;m0/00ol0003o1OX5o`Gj1@08o`Gj1@05o`000?lLhaco7><LoacS7?l000003Om</d`00ol0003o
XebSoj=LX`0Aoj=LX`?o00003OoR7N800ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_om0_d2o`0000;on@Ki00?o0000on<LhooS7><03ooS7><00ol0003o
]dRgokM8]`0>okM8]`03o`000?meRWGoMHYe00SoMHYe1Ol0000;o`Wf2@03o`000?l;m0_o2o@;00Ko
2o@;00?o0000o`Gj1Ol5nPD02Ol5nPD01?l0003o7><LoacS7?l0000=odbcC003o`000?nSG:?oXebS
017oXebS00?o0000oll`coo?<<l00ol0000:on8MhPCo00003Ook1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooT6n@03o`000?oS7>?ohacS00kohacS00?o0000okM8
]ongB;L03_ngB;L00ol0003oMHYeogF:M@07ogF:M@03o`000?lSg2?o8m`S00?o8m`S00?o0000o`Wf
2Ol9mPT02?l9mPT00ol0003o2o@;o`_d2`05o`_d2`03o`000?l5nPGo1OX500[o1OX51Ol0000<odbc
C003o`000?nSG:?oXebS013oXebS00?o0000oll`coo?<<l01?o?<<l3o`0000KohQgR00?o0000ooT6
nOoi1_T00_oi1_T5o`0000Son`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooT6nOoi1_T01?oi1_T00ol0003ohacSon<Lh`0=on<Lh`03o`000?ngB;Oo]dRg00oo
]dRg00?o0000ogF:MOmeRWD01?meRWD2o`0000Oo8m`S00?o0000o`Wf2Ol9mPT01ol9mPTEo`0000Go
7N8M00?o0000odbcC?m</d`02?m</d`3o`00013oXebS00?o0000oll`coo?<<l02?o?<<l3o`0000;o
hQgR00?o0000ooT6nOoi1_T02?oi1_T5o`0000?on`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ohacSon<Lh`0;on<Lh`Co0000
3ongB;L00ol0003oMHYeogF:M@03ogF:M@03o`000?lSg2?o8m`S00So8m`S00?o0000o`Wf2Ol9mPT0
1?l9mPT2o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o7N8MoagR7@05oagR7@;o0000
1_m</d`2o`0000?oHYeR00?o0000oj=LXonSG:<03?nSG:<00ol0003occ3?oll`c`0<oll`c`;o0000
4?oi1_T3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Won@Ki00Kon@Ki00?o
0000on<LhooS7><02OoS7><00ol0003ok1?/o`000002oke2_@?o00003?ngB;L01?l0003oMHYeogF:
MOmeRWD2o`0000co8m`S00?o0000o`Wf2Ol9mPT00_l9mPT00ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000oagR7OlMhQd01olMhQd00ol0003oC;=<odbcC002odbcC003o`00
0?mRWF;oHYeR00CoHYeR0_l0000;oj=LX`03o`000?o?<<oocc3?00cocc3?00?o0000on/Djol00000
4_oi1_T00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Oon@Ki00?o
0000on<LhooS7><01_oS7><2o`0000;ok1?/00?o0000oke2_Onm@[d00onm@[d3o`0000[o]dRg00?o
0000ogF:MOl000003olSg2<01?l0003o2OH9o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000oagR7OlMhQd02?lMhQd01?l0003oC;=<o`000?l00009of:MHP03o`000?nSG:?oXebS00Oo
XebS00?o0000oll`coo?<<l03?o?<<l01?l0003ojaC[on/Djol0000CooT6n@03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`000?oS7>?ohacS00Co
hacS00?o0000on`Ck?o/4n`00oo/4n`00ol0003o_D:moke2_@05oke2_@?o00001_ngB;L4o`00013o
8m`S00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lMhQgo7N8M00Wo
7N8M00?o0000of:MH_mRWF802_mRWF82o`0000KoXebS00?o0000oll`coo?<<l03?o?<<l00ol0003o
jaC[on/Dj`02on/Dj`03o`000?oi1_Won@Ki00oon@Ki00?o0000ooh1o_l000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00Won@Ki00Co0000on<LhooS7>?o
hacS0_l00006on`Ck003o`000?nm@[go_D:m00So_D:m0ol000000ongB;Oo0000o`000004ofVFJ@03
o`000?lSg2?o8m`S00go8m`S00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?lMhQgo7N8M00Wo7N8M00?o0000of:MH_mRWF803?mRWF800ol0003oXebSoj=LX`03o`0000ko
cc3?00?o0000on/Djoo[5>/00oo[5>/00ol0003on@KiooT6n@0>ooT6n@05o`000?on0OkooP7nooh1
o_l000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oi1_Won@Ki00[o
n@Ki00?o0000on<Lhol000002?o/4n`00ol0003o_D:moke2_@0;oke2_@03o`000?mYUVWoJIIY00Go
JIIY00?o0000ob?L8olSg2<03?lSg2<00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000oagR7OlMhQd02?lMhQd2o`0000ooHYeR0_l00002oklo_`03o`000?o?<<oocc3?00_o
cc3?00?o0000on/Djoo[5>/01?o[5>/00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n00?o
oP7n00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oi1_Won@Ki00_on@Ki00?o0000on`Ck?o/4n`0
1oo/4n`00ol0003o_D:moke2_@0;oke2_@03o`000?mYUVWoJIIY00KoJIIY00?o0000ob?L8olSg2<0
2olSg2<2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7N8MoagR7@07oagR7@04o`00
0?lacS7o<Lhao`0000koHYeR00?o0000oklo_ono?kl00_no?kl00ol0003occ3?oll`c`09oll`c`03
o`000?o[5>_ojaC[00KojaC[00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7nooh1oP05ooh1oP04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooT6nOoi1_T02_oi1_T2o`0000Wo
k1?/00?o0000oke2_Onm@[d02onm@[d00ol0003oJIIYofVFJ@07ofVFJ@03o`000?lSg2?o8m`S00Wo
8m`S00Co0000o`Gj1Ol5nPGo00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lMhQgo7N8M
00Ko7N8M00Go0000oc7><OlacS7o<Lhao`00000>of:MHP03o`000?no?koo_cno00?o_cno00?o0000
oll`coo?<<l01oo?<<l00ol0003ojaC[on/Dj`07on/Dj`03o`000?oi1_Won@Ki00[on@Ki00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oi1_Won@Ki
00Won@Ki00Co0000ooP7n?oh1oSo00002Oo/4n`00ol0003o_D:moke2_@09oke2_@03o`000?mYUVWo
JIIY00WoJIIY00?o0000ob?L8olSg2<01olSg2<00ol0003o1OX5o`Gj1@02o`Gj1@03o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7N8MoagR7@05oagR7@03o`000?lacS7o
<Lha00?o<Lha00?o0000of:MH_mRWF802_mRWF800ol0003o_cnooklo_`05oklo_`03o`000?o?<<oo
cc3?00Gocc3?00?o0000on/Djoo[5>/02?o[5>/00ol0003on@KiooT6n@09ooT6n@03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won@Ki00?o0000ooP7
n?oh1oP00_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`000?nm@[go_D:m00Wo_D:m00?o0000ofVF
JOmYUVT02_mYUVT00ol0003o8m`Sob?L8`05ob?L8`03o`000?l5nPGo1OX500Co1OX500?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lMhQgo7N8M00Co7N8M00?o0000oc7>
<OlacS401?lacS400ol0003oHYeRof:MHP0:of:MHP03o`000?no?koo_cno00Ko_cno00?o0000oll`
coo?<<l00oo?<<l00ol0003ojaC[on/Dj`09on/Dj`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooi1_T00ol0003o
n0OhooP7n003ooP7n003o`000?o/4ncok1?/00Kok1?/00?o0000oke2_Onm@[d02Onm@[d00ol0003o
JIIYofVFJ@0;ofVFJ@03o`000?lSg2?o8m`S00?o8m`S00?o0000o`Gj1Ol5nPD01_l5nPD00ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000oagR7OlMhQd00_lMhQd2o`0000So
<Lha00?o0000of:MH_mRWF802OmRWF800ol0003o_cnooklo_`07oklo_`05o`000?o?<<oocc3?oll`
col000003Oo[5>/00ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooi1_Wo0000ooP7n006ooP7n003
o`000?o/4ncok1?/00Gok1?/00?o0000oke2_Onm@[d02Onm@[d00ol0003oJIIYofVFJ@0<ofVFJ@05
o`000?lSg2?o8m`Sob?L8ol000002_l5nPD00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000oagR7Ol000000_l000000ol?l0oo0000oc7><@07oc7><@03o`000?mRWF;oHYeR
00SoHYeR00?o0000oklo_ono?kl02Ono?kl00ol0003occ3?o`00000=on/Dj`Co00001Ooi1_T00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oh1oSon0Oh00Oon0Oh00?o0000on`Ck?o/4n`01?o/4n`00ol0003o_D:moke2_@09oke2_@03
o`000?mYUVWoJIIY00goJIIY00?o0000ob?L8ol000003?l5nPD:o`0000Oo0?l00ol00005o`o`3`03
o`000?lacS7o<Lha00Ko<Lha00?o0000of:MH_mRWF801omRWF800ol0003o_cnooklo_`0:oklo_`03
o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5n_oj1OX00_oj1OX3o`000003ooT6nOl0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7n007ooP7n003o`00
0?o/4ncok1?/00Gok1?/00?o0000oke2_Onm@[d01onm@[d00ol0003oJIIYofVFJ@0?ofVFJ@;o0000
2ol5nPD00ol0003o1_T6o`Ki1P07o`Ki1P03o`000?l0o`3o0?l000;o0?l00ol00008o`o`3`03o`00
0?lacS7o<Lha00Ko<Lha00?o0000of:MH_mRWF801omRWF800ol0003o_cnooklo_`0:oklo_`03o`00
0?o[5>_ojaC[00[ojaC[00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n008ooP7n003o`000?o/4ncok1?/00Cok1?/00?o0000oke2_Onm@[d01onm@[d00ol0003oJIIYofVF
J@0>ofVFJ@04o`000?l^dBko;]4^o`0000Wo1OX500?o0000o`Ki1_l6n@H02Ol6n@H01?l0003o0?l0
o`000?l0000<o`o`3`03o`000?lacS7o<Lha00Ko<Lha00?o0000of:MH_mRWF801_mRWF800ol0003o
_cnooklo_`0;oklo_`03o`000?o[5>_ojaC[00OojaC[0_l00009ooX5nP03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oh1oSon0Oh00Son0Oh00?o0000on`Ck?o/4n`00oo/4n`>o`0000goJIIY00?o0000obkA;_l^dBh0
0_l^dBh00ol0003o1OX5o`Gj1@05o`Gj1@03o`000?l6n@Ko1_T600_o1_T600?o0000o`o`3ol?l0l0
3?l?l0l00ol0003o<Lhaoc7><@06oc7><@03o`000?mRWF;oHYeR00GoHYeR00?o0000oklo_ono?kl0
3?no?kl00ol0003ojaC[on/Dj`06on/Dj`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP01Ol0003ok1?/on`Ck?o/4nco000000_obCK900?o0000offBKOm]TVd00ol00009ofVFJ@03o`00
0?l^dBko;]4^00Co;]4^00?o0000o`Gj1Ol5nPD00ol5nPD00ol0003o1_T6o`Ki1P0<o`Ki1P03o`00
0?l?l0oo3o0?00go3o0?00?o0000oc7><OlacS401_lacS400ol0003oHYeRof:MHP03of:MHP?o0000
3Ono?kl00ol0003ojaC[on/Dj`05on/Dj`03o`000?oj1O[onPGj00conPGj0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP4o`0000cobCK900?o0000offBKOm]TVd00om]TVd3o`0000GoJIIY00?o0000obkA;_l^dBh01_l^
dBh01Ol0003o1OX5o`Gj1Ol5nPGo000000oo1_T600?o0000o`o`3ol?l0l03Ol?l0l00ol0003o<Lha
oc7><@06oc7><@03o`000?mRWF;oHYeR00?o00000on0Oh000ol0003o_cnooklo_`0;oklo_`03o`00
0?o[5>_ojaC[00?ojaC[00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon0Oh0ol0
0003oo<<l`03o`000?o9=/WobCK900[obCK900?o0000offBKOm]TVd01_m]TVd3o`000003ofVFJOl0
003o;]4^00Wo;]4^00?o0000o`Gj1Ol000004?l6n@H00ol0003o3o0?o`o`3`0=o`o`3`03o`000?la
cS7o<Lha00Oo<Lha0_l00007oh1oP003o`000?no?koo_cno00[o_cno00Co0000on/Djoo[5>_ojaC[
0ol0000?ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003on`Ckoo/4nook1?/2o`000004ooP7n?l0003o0000o`0000Kol`cc00?o0000olTfbOo9
=/T02_o9=/T00ol0003oKI9]offBK@09offBK@03o`000?l^dBko;]4^00[o;]4^00?o0000o`Ki1_l6
n@H03ol6n@H00ol0003o3o0?o`o`3`0>o`o`3`03o`000?lacS7o<Lha00Ko<Lha00?o0000oh1oP?n0
Oh001on0Oh04o`0000So_cno00Co0000on/Djoo[5>_o00000ood2o@2o`0000gonPGj00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
n`Ckoo/4n`04oo/4n`03o`000?oc3??ol`cc00Ool`cc00?o0000olTfbOo9=/T02Oo9=/T00ol0003o
KI9]offBK@0:offBK@03o`000?l^dBko;]4^00[o;]4^00?o0000o`Ki1_l6n@H03ol6n@H00ol0003o
3o0?o`o`3`0>o`o`3`03o`000?lacS7o<Lha00Go<Lha00?o0000oh1oP?n0Oh002?n0Oh001?l0003o
acS7olLhaoo7><L7o`0000;o_cno0_l00006oo@;m0;o00003?oj1OX00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<02?oc3?<00ol0003obCK9olTfb@08olTfb@03o`000?m]TVgoKI9]00[o
KI9]00?o0000obkA;_l^dBh02ol^dBh00ol0003o1_T6o`Ki1P0>o`Ki1P03o`000?l?l0oo3o0?00ko
3o0?1Ol00002oc7><@03o`000?n0Oh3oP7n000WoP7n000?o0000olLhaoo7><L02?o7><L3o`0000Wo
m0_d0_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?o9=/WobCK900SobCK900?o0000offBKOm]TVd02_m]TVd00ol0003o;]4^obkA;P0:obkA;P;o0000
3_l6n@H3o`0000go3o0?0ol00005od2o@0;o00002on0Oh000ol0003oacS7olLha`0;olLha`;o0000
2_od2o@2o`0000OonPGj0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo/4n`03o`00
0?oc3??ol`cc00Ool`cc00?o0000olTfbOo9=/T02?o9=/T>o`0000Wo;]4^0ol000000olUfRGo0000
o`Ki1P0:o`Ki1P?o00000_lHiaP00ol0003o3o0?o`o`3`09o`o`3`;o00002Om0_d000ol0003oP7n0
oh1oP009oh1oP003o`000?o7><OoacS700_oacS700?o0000omlPgol000002ood2o@2o`0000ConPGj
00Co0000oo`3o?ol0ocoo0?l0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oc3??ol`cc00Kol`cc00?o0000olTfbOo9=/T02?o9=/T00ol0003oJiA[
of^DJ`0:of^DJ`03o`000?l^dBko;]4^00Co;]4^0ol00005obGJ9@03o`000?l6n@Ko1_T600Co1_T6
1?l00006oaSW6003o`000?l?l0oo3o0?00Ko3o0?0_l0000;od2o@003o`000?n0Oh3oP7n000WoP7n0
00?o0000olLhaoo7><L02_o7><L01Ol0003ogb3OomlPgooO8=oo000000com0_d0_l000000ooj1O[o
0000oo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<01_oc3?<00ol0003obCK9olTfb@07olTfb@03o`00
0?m[U6_oJiA[00_oJiA[00?o0000obkA;_l^dBh00_l^dBh2o`0000Wo9MXU00?o0000o`Ki1_l6n@H0
0ol0000;oaSW6003o`000?l?l0oo3o0?00;o3o0?0ol0000>od2o@003o`000?n0Oh3oP7n000OoP7n0
00?o0000olLhaoo7><L02oo7><L00ol0003ogb3OomlPg`02omlPg`03o`000?od2oCom0_d00_om0_d
00?o0000oo`3o?ol0o`01_ol0o`2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok
1?_on`Ck00Oon`Ck00?o0000oo<<looc3?<01ooc3?<00ol0003obCK9olTfb@05olTfb@?o00003Om[
U6/4o`0000_o9MXU0ol0000?oaSW6004o`000?l?l0oo0000o`00017o@;m000?o0000oh1oP?n0Oh00
1on0Oh000ol0003oacS7olLha`0:olLha`03o`000?oO8=oogb3O00Cogb3O00?o0000oo@;m?od2o@0
1ood2o@3o`0000_oo0?l1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ol`ccoo<<
l`06oo<<l`03o`000?o9=/WobCK900;obCK90ol00003ojYEZP03o`000?m[U6_oJiA[00[oJiA[00?o
0000obGJ9OlUfRD02olUfRD00ol0003o8MhQo`00000AoaSW6003o`000?m0_d3o@;m0017o@;m000?o
0000oh1oP?n0Oh001on0Oh000ol0003oacS7olLha`0:olLha`03o`000?oO8=oogb3O00Gogb3O00Co
0000oo@;m?od2oCom0_d1Ol00002ooL8m`03o`000?ol0ocoo0?l00Woo0?l00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`05oo<<l`?o0000
00?obCK9o`000?l000001onZEJX00ol0003oJiA[of^DJ`08of^DJ`?o00002_lUfRD2o`0000;o8MhQ
00?o0000oaSW6?lHiaP03olHiaP00ol0003o@;m0od2o@00Aod2o@003o`000?n0Oh3oP7n000OoP7n0
00?o0000olLhaoo7><L02Oo7><L00ol0003ogb3OomlPg`07omlPg`?o00001oog2?L00ol0003oo0?l
oo`3o009oo`3o003o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook
1?/4o`0000;ol`cc0_l00003on`Ck003o`000?nZEJ[oZUFZ00SoZUFZ0_l00006of^DJ`;o00000omJ
YEX00ol0003o9MXUobGJ9@06obGJ9@03o`000?lQgR7o8MhQ00?o8MhQ00?o0000oaSW6?lHiaP03_lH
iaP00ol0003o@;m0od2o@00Bod2o@003o`000?n0Oh3oP7n000GoP7n000?o0000olLhaoo7><L02Oo7
><L00ol0003ogb3OomlPg`08omlPg`03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol
0o`00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00Con`Ck0_l00004
ooX5nP;o00001Oo/4n`00ol0003oZUFZojYEZP0:ojYEZP03o`000?m[U6_oJiA[00;oJiA[00?o0000
oeZUF_mJYEX01?mJYEX00ol0003o9MXUobGJ9@04obGJ9@03o`000?lQgR7o8MhQ00Co8MhQ00?o0000
oaSW6?lHiaP03_lHiaP00ol0003o@;m0od2o@00Bod2o@0[o00002_o7><L00ol0003ogb3OomlPg`08
omlPg`03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003on`Ckoo/4nook1?/2o`0000OonPGj00?o0000on`Ck?o/4n`01?o/4n`0
0ol0003oZUFZojYEZP0:ojYEZP04o`000?m[U6_o0000o`0000SoFZEJ00Co0000obGJ9OlUfRGo9MXU
0_l00007ob7N8@03o`000?lHiaSo6>LH00ko6>LH00?o0000od2o@?m0_d004_m0_d000ol0003oWV6N
oiiQWP07oiiQWP03o`000?o7><OoacS700KoacS700?o0000omlPgooO8=l02_oO8=l00ol0003om`Sg
ooL8m`06ooL8m`03o`000?ol0ocoo0?l00Soo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ok
1?_o0000o`0000WonPGj00?o0000on`Ck?o/4n`01?o/4n`00ol0003oZUFZojYEZP0;ojYEZP03o`00
0?mJYE[oFZEJ00WoFZEJ00?o0000obGJ9Ol000002OlQgR400ol0003o6>LHoaSW600>oaSW60;o0000
4_m0_d000ol0003oWV6NoiiQWP09oiiQWP;o00001_o7><L00ol0003ogb3OomlPg`0:omlPg`03o`00
0?og2?Oom`Sg00Kom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ok1?/on`Ck005on`Ck003o`000?nZEJ[oZUFZ00[oZUFZ00?o
0000oeZUF_mJYEX02_mJYEX2o`0000Wo8MhQ00?o0000oaSW6?lHiaP03_lHiaP00ol0003o=/Tfo`00
0002o`0000oo@;m000?o0000oiiQW_nNHIh02onNHIh00ol0003oacS7olLha`03o`0000gogb3O00?o
0000ooL8moog2?L01_og2?L00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003onPGjooX5nP09ooX5nP03o`000?o/4ncok1?/00Gok1?/00?o0000ojYEZ_nZEJX02OnZEJX2
o`0000_oFZEJ0_l0000;ob7N8@03o`000?lHiaSo6>LH00co6>LH00?o0000ocK9=_lfbCH00olfbCH3
o`0000co@;m000?o0000oiiQW_nNHIh03?nNHIh2o`0000;ogB;M00?o0000omlPgooO8=l03?oO8=l0
0ol0003om`SgooL8m`05ooL8m`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00[onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oZUFZojYEZP07ojYE
ZP03o`000?n^DJko000000[oFZEJ00Co0000oe2_D?m@[e3o00002_lQgR400ol0003o6>LHoaSW600<
oaSW6003o`000?lfbCKo=/Tf00Ko=/Tf0_l00008od2o@0;o00003onNHIh00ol0003ogB;MomdRg@02
omdRg@03o`000?oO8=oogb3O00_ogb3O00?o0000ooL8moog2?L01Oog2?L00ol0003oo0?loo`3o007
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o/4ncok1?/
00Kok1?/00?o0000ojYEZ_nZEJX01_nZEJX01Ol0003o[U6^ojiA[_n^DJko000000SoFZEJ00?o0000
oe2_D?m@[e000_m@[e000ol0003o8MhQob7N8@06ob7N8@Co00003?lHiaP00ol0003o=/TfocK9=P08
ocK9=P?o00000_m0_d03o`000003ogj1O_l0003oWV6N00goWV6N00?o0000omdRgOoM8]d01?oM8]d0
0ol0003ogb3OomlPg`0:omlPg`03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ok1?/on`Ck007on`C
k003o`000?nZEJ[oZUFZ00?oZUFZ0_l00005ojiA[P03o`000?mJYE[oFZEJ00CoFZEJ00?o0000oe2_
D?m@[e000om@[e000ol0003o8MhQob7N8@05ob7N8@03o`000?lIiQWo6NHI00;o6NHI0ol00007oaSW
60;o00003_lfbCH2o`0000GoOX5n00?o0000oiiQW_nNHIh02_nNHIh00ol0003ogB;MomdRg@05omdR
g@03o`000?oO8=oogb3O00_ogb3O00?o0000ooL8moog2?L01?og2?L00ol0003oo0?loo`3o006oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?o/4ncok1?/00Oo
k1?/00?o0000ojYEZ_nZEJX00_nZEJX00ol0003o[U6^ojiA[P06ojiA[P03o`000?mJYE[oFZEJ00;o
FZEJ00?o0000oe2_D?m@[e001Om@[e000ol0003o8MhQob7N8@02ob7N8@;o00002?lIiQT3o`0000;o
6>LH0_l000000olLhaco0000ocK9=P0=ocK9=P03o`000?mnPGkoOX5n00GoOX5n00?o0000oiiQW_nN
HIh02?nNHIh00ol0003ogB;MomdRg@07omdRg@03o`000?oO8=oogb3O00[ogb3O00?o0000ooL8moog
2?L01?og2?L00ol0003oo0?loo`3o006oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGj
ooX5nP0<ooX5nP03o`000?o/4ncok1?/00Sok1?/00Co0000ojYEZ_nZEJ[o00002On^DJh01Ol0003o
FZEJoeZUF_mJYE[o000000SoD:m@00Go0000ob7N8OlQgR7o8MhQo`00000=oaWV6@;o00001?lLha`0
0ol0003o=/TfocK9=P0;ocK9=P03o`000?mnPGkoOX5n00KoOX5n00?o0000oiiQW_nNHIh01onNHIh0
0ol0003ogB;MomdRg@08omdRg@Co00002?oO8=l00ol0003om`SgooL8m`04ooL8m`03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00_onPGj0ol00009on`C
k003o`000?nZEJ[o000000_o[U6^00?o0000oeZUF_l000002_m@[e000ol0003o8MhQo`00000?oaWV
6@03o`000?lLhaco7><L00;o7><L00?o0000ocK9=_lfbCH02olfbCH00ol0003oOX5nogj1OP06ogj1
OP03o`000?nNHIkoWV6N00KoWV6N00?o0000omdRgOoM8]d02OoM8]d01?l0003oka3_onl@koo_4>l7
o`0000;ogb3O00?o0000ooL8moog2?L00oog2?L00ol0003oo0?loo`3o005oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oj1O[onPGj00SonPGj0ol00003ooX5nP03o`000?o/4ncok1?/00Ook1?/00?o0000ojiA
[_n^DJh02on^DJh00ol0003oD:m@oe2_D00:oe2_D003o`000?lIiQWo6NHI00go6NHI00?o0000oacS
7?lLha`01?lLha`00ol0003o=/TfocK9=P09ocK9=P03o`000?mnPGkoOX5n00SoOX5n00?o0000oiiQ
W_nNHIh00onNHIh2o`0000cogB;M00?o0000onl@koo_4>l02?o_4>l<o`0000?oo0?l0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX3o`0000OonPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
[U6^ojiA[P0;ojiA[P03o`000?m@[e3oD:m@00WoD:m@0_l0000>oaWV6@03o`000?lLhaco7><L00Go
7><L00?o0000ocK9=_lfbCH02OlfbCH00ol0003oOX5nogj1OP09ogj1OP03o`000?nNHIko000000;o
00000_oC;=<00ol0003ogB;MomdRg@08omdRg@03o`000?o_4>ooka3_00coka3_00?o0000ooT6nOoi
1_T01_oi1_T3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003onPGjooX5nP03ooX5nP?o00002ooj1OX00ol0003ok1?/
on`Ck004on`Ck003o`000?n^DJko[U6^00_o[U6^0ol00007oe2_D0?o000000?o><Lho`000?lIiQT0
3OlIiQT00ol0003o7><LoacS7006oacS7003o`000?lfbCKo=/Tf00So=/Tf00?o0000ogj1O_mnPGh0
2_mnPGh00ol0003odbcCom</d`04om</d`03o`000?oM8]gogB;M00OogB;M00?o0000onl@koo_4>l0
2oo_4>l00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooX5n_l0
003o0000o`0000oonPGj00?o0000on`Ck?o/4n`00oo/4n`>o`0000?oV6NH0_l00002oe2_D0?o0000
1OlhacP00ol0003o6NHIoaWV6@0:oaWV6@03o`000?lLhaco7><L00Oo7><L00?o0000ocK9=_lfbCH0
2?lfbCH00ol0003oOX5nogj1OP0:ogj1OP03o`000?oC;=?odbcC00GodbcC00?o0000omdRgOoM8]d0
1_oM8]d00ol0003oka3_onl@k`0;onl@k`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;onPGj00?o0000on`Ck?o/4n`00_o/4n`00ol0003ogb3OomlP
g`0:omlPg`03o`000?nHIiSoV6NH00?oV6NH0_l00009ocS7>003o`000?lIiQWo6NHI00Wo6NHI00?o
0000oacS7?lLha`02?lLha`2o`0000So=/Tf00?o0000ogj1O_mnPGh02OmnPGh00ol0003odbcCom</
d`07om</d`03o`000?oM8]gogB;M00CogB;M00?o0000onl@koo_4>l02oo_4>l00ol0003on@KiooT6
n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o000000?ok1?/
o`000?oO8=l02ooO8=l00ol0003oV6NHoiQWV004oiQWV003o`000?lhacSo><Lh00Wo><Lh00?o0000
oaWV6OlIiQT01olIiQT00ol0003o7><LoacS7009oacS7004o`000?lm`Sgo0000o`0000Ko=/Tf00?o
0000ogj1O_mnPGh02OmnPGh00ol0003odbcCom</d`08om</d`03o`000?oM8]gogB;M00?ogB;M00?o
0000onl@koo_4>l02oo_4>l00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00000ooi1_T2o`0000cogb3O00?o0000oiQWV?nHIiP01?nHIiP0
0ol0003o><LhocS7>00:ocS7>0Wo00002olLha`00ol0003o?L8mocg2?@02ocg2?@?o00000_lfbCH0
0ol0003oOX5nogj1OP0:ogj1OP03o`000?oC;=?odbcC00WodbcC00?o0000omdRgOoM8]d00_oM8]d0
0ol0003oka3_onl@k`0:onl@k`03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_oj1OX2o`0000Gon@Ki00?o0000on`Ck?l000002_oO8=l00ol0003oV6NHoiQWV006oiQW
V003o`000?lhacSo><Lh00Wo><Lh00?o0000ob;M8_lRgB801OlRgB800ol0003o7><LoacS7009oacS
7003o`000?lm`Sgo?L8m00Go?L8m0ol00009ogj1OP?o00003OoC;=<01Ol0003ogB;MomdRgOoM8]go
000000coka3_00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX01Ooj1OX2o`0000Oon@Ki00Co0000on`Ck?o/4nco00002OoO8=l00ol0003oV6NHoiQWV006
oiQWV003o`000?lhacSo><Lh00So><Lh00?o0000ob;M8_lRgB801olRgB800ol0003o7><LoacS7007
oacS7003o`000?lm`Sgo?L8m00So?L8m0ol00002ogj1OPGo00000_nl@k`00ol0003odbcCom</d`0<
om</d`03o`000?oM8]go000000coka3_00?o0000ooT6nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000ooX5n_oj1OX00_oj1OX2o`0000Son@Ki00?o0000on`Ck?o/4n`00_o/4n`5o`00
00Cogb3O00?o0000oiQWV?nHIiP01_nHIiP00ol0003o><LhocS7>008ocS7>003o`000?lRgB;o8]dR
00Oo8]dR00?o0000oacS7?lLha`01olLha`00ol0003o?L8mocg2?@08ocg2?@03o`000?n6NHKoQWV6
00;o00002?nl@k`00ol0003odbcCom</d`0<om</d`Co00002_o_4>l00ol0003on@KiooT6n@0:ooT6
n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003onPGjo`000?l0000:ooT6n@03o`000?o/4ncok1?/
00;ok1?/00?o0000olLhaoo7><L00_o7><L4o`0000WoV6NH00?o0000ocS7>?lhacP02?lhacP00ol0
003o8]dRob;M8P08ob;M8P03o`000?lLhaco7><L00Go7><L00?o0000ocg2?Olm`Sd02?lm`Sd01Ol0
003oQWV6ohIiQ_n6NHKo000000[o_4>l0ol0000;om</d`04o`000?oe2_Gom@[eooD:m@Co00001Oo_
4>l00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o/4ncok1?/00?ok1?/00?o0000olLhaoo7><L01?o7><L00ol0003oV6NHoiQWV007
oiQWV003o`000?lhacSo><Lh00Ko><Lh0_l0000;ob;M8P03o`000?lLhaco7><L00Go7><L00?o0000
ocg2?Olm`Sd02?lm`Sd00ol0003oQWV6ohIiQP02ohIiQP03o`000?nl@kco_4>l00Oo_4>l00?o0000
onLHiooW6>L01?l00006om</d`03o`000?oe2_Gom@[e00Kom@[e0ol00002onl@k`03o`000?oi1_Wo
n@Ki00_on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000on`C
k?o/4n`01?o/4n`00ol0003oacS7olLha`05olLha`03o`000?nHIiSoV6NH00OoV6NH00?o0000ocS7
>?lhacP00_lhacP3o`000003oe2_D?l0003o8]dR00[o8]dR00?o0000oacS7?lLha`01OlLha`00ol0
003o?L8mocg2?@07ocg2?@03o`000?n6NHKoQWV600?oQWV600?o0000oka3_?nl@k`01onl@k`00ol0
003oiaSWonLHi`04onLHi`?o00000_oC;=<00ol0003om@[eooD:m@0:ooD:m@;o00003_oi1_T00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ok1?/on`Ck004on`Ck003
o`000?o7><OoacS700KoacS70_l00007oiQWV003o`000?lhacSo000000;o00001Om@[e000ol0003o
8]dRob;M8P08ob;M8P?o00001?lLha`00ol0003o?L8mocg2?@08ocg2?@03o`000?n6NHKoQWV600Co
QWV600?o0000oka3_?nl@k`01_nl@k`00ol0003oiaSWonLHi`07onLHi`;o00003_oe2_D00ol0003o
n@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o/4ncok1?/00Gok1?/00?o0000olLhaoo7><L01?o7><L00ol0003obSG:olXebP03o`0000CoV6NH
0_l00008oe2_D003o`000?lRgB;o8]dR00Oo8]dR00Co0000odBkA?m4^dCoA;]40ol000000olLhaco
0000ocg2?@09ocg2?@03o`000?n6NHKoQWV600CoQWV600?o0000oka3_?nl@k`01Onl@k`00ol0003o
iaSWonLHi`09onLHi`03o`000?oe2_Gom@[e00gom@[e00?o0000ooT6nOoi1_T02_oi1_T00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003ok1?/on`Ck006on`Ck003o`00
0?o7><OoacS700?oacS700?o0000olXeb_o:=LX01?o:=LX2o`000003oiQWV?l0003oD:m@00[oD:m@
00?o0000ob;M8_lRgB801OlRgB800ol0003oA;]4odBkA005odBkA003o`000?lm`Sgo?L8m00Oo?L8m
0ol00007ohIiQP03o`000?nl@kco_4>l00Co_4>l00?o0000onLHiooW6>L02OoW6>L00ol0003om@[e
ooD:m@0=ooD:m@03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009on`Ck005o`000?o7><OoacS7olLhaol000002Oo:=LX00ol0003oD:m@
oe2_D00;oe2_D003o`000?lRgB;o8]dR00?o8]dR00?o0000odBkA?m4^d@01_m4^d@00ol0003o?L8m
ocg2?@06ocg2?@05o`000?mmPWgoOH9mogf2OOl000001on6NHH00ol0003o_4>loka3_003oka3_003
o`000?oW6>OoiaSW00WoiaSW00?o0000ooD:mOoe2_D03_oe2_D00ol0003on@KiooT6n@09ooT6n@03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;on`Ck00?o0000on`Ck?o/4n`0
1oo/4n`01?l0003oacS7olLhaol00009olXebP;o00003Om@[e000ol0003o8]dRob;M8P02ob;M8P03
o`000?m4^dCoA;]400SoA;]400?o0000ocg2?Olm`Sd00olm`Sd2o`0000GoOH9m00?o0000ohIiQ_n6
NHH01?n6NHH00ol0003o_4>loka3_003oka3_003o`000?oW6>OoiaSW00WoiaSW00?o0000ooD:mOoe
2_D03_oe2_D00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Son`Ck
00?o0000on`Ck?o/4n`01_o/4n`00ol0003oacS7o`000009olXebP04o`000?nTFjCoY5^To`0000go
D:m@00Co0000ob;M8_lRgB;o00003?m4^d@01Ol0003o?L8mocg2?Olm`Sgo000000SoOH9m0_l00005
ohIiQP03o`000?nl@kco_4>l00;o_4>l00?o0000onLHiooW6>L02OoW6>L00ol0003om@[eooD:m@0>
ooD:m@03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000on`Ck?o/4n`01oo/4n`00ol0003obSG:olXebP07olXebP03o`000?nTFjCoY5^T
00;oY5^T00?o0000oe2_D?m@[e002_m@[e000ol0003o8]dRo`00000>odBkA003o`000?lm`Sgo0000
00_oOH9m00?o0000ohIiQ_n6NHH00_n6NHH01Ol0003o_4>loka3_?nl@kco000000coiaSW00?o0000
ooD:mOoe2_D03_oe2_D3o`0000Won@Ki00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000on`Ck?o/4n`01_o/4n`00ol0003obSG:olXebP06olXebP03o`000?nTFjCoY5^T
00?oY5^T00?o0000oe2_D?m@[e002om@[e000ol0003oA;]4odBkA00>odBkA003o`000?mmPWgoOH9m
00_oOH9m0_l00003ohIiQP04o`000?nl@kco_4>lo`0000[oiaSW0ol0000>ooD:m@;o00000oon0Oh2
o`0000Oon@Ki00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000on`C
k?o/4n`01?o/4n`00ol0003obSG:olXebP06olXebP03o`000?nTFjCoY5^T00GoY5^T00?o0000oe2_
D?m@[e001om@[e03o`00017oA;]400?o0000ogf2OOmmPWd03OmmPWd01Ol0003oQWV6ohIiQ_l0003o
_4>l00Co00000ooW6>L5o`0000;onPGj00?o0000ooD:mOoe2_D02_oe2_D2o`0000OooP7n0_l00004
ooT6n@03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o/4ncok1?/
00Cok1?/00?o0000olXeb_o:=LX01Oo:=LX00ol0003oY5^TojAKY006ojAKY003o`000?m@[e3oD:m@
00CoD:m@0ol00002oeRWF003o`000?m4^dCoA;]400ooA;]40_l0000?ogf2O@04o`000?n6NHKo0000
o`0000Cog2?L0ol00008ooX5nP03o`000?oe2_Gom@[e00Oom@[e0_l0000;ooh1oP;o00000_oi1_T0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo/4nook1?/03?ok1?/6o`0000OobSG:00?o0000ojAK
Y?nTFj@02?nTFj@00ol0003oD:m@oe2_D003o`0000KoF:MH00?o0000odBkA?m4^d@03Om4^d@01?l0
003oQ7^4ohAkQ?l0000?ogf2O@03o`000?oL8mcog2?L00Gog2?L00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003om@[eooD:m@05ooD:m@03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ok1?/00ol0003okQ7^onhAkP04onhA
kP03o`000?o:=L[obSG:00?obSG:00?o0000ojAKY?nTFj@02_nTFj@2o`0000[oF:MH00?o0000odBk
A?m4^d@02om4^d@00ol0003oQ7^4ohAkQ002ohAkQ003o`000?mmPWgoOH9m00_oOH9m0_l00007om`S
g003o`000?oj1O[onPGj00WonPGj00?o0000ooD:mOoe2_D00_oe2_D2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP06onhAkP05o`000?o:=L[obSG:olXe
b_l000003OnTFj@00ol0003oF:MHoeRWF00:oeRWF003o`000?m4^dCoA;]400WoA;]400?o0000ohAk
Q?n4Nh@01?n4Nh@00ol0003oOH9mogf2O@08ogf2O@;o000000?o[E:]o`000?oL8m`01ooL8m`00ol0
003onPGjooX5nP09ooX5nP04o`000?oe2_Go0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000onhAk_o^4Nh02?o^4Nh00ol0003obSG:o`00000=ojAKY003o`000?mHYeSoF:MH
00_oF:MH00?o0000odBkA?m4^d@02?m4^d@00ol0003oQ7^4ohAkQ006ohAkQ003o`000?mmPWgoOH9m
00GoOH9m0_l00003ojeB[@03o`000?oL8mcog2?L00Kog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?o^4NkokQ7^00[okQ7^00?o0000ojAKY?nT
Fj@03?nTFj@00ol0003oF:MHoeRWF00<oeRWF003o`000?m4^dCoA;]400KoA;]400?o0000ohAkQ?n4
Nh@02?n4Nh@00ol0003oOH9mogf2O@02ogf2O@;o00001_n]DZd00ol0003og2?Lom`Sg005om`Sg003
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck00Gon`Ck
00?o0000onhAk_o^4Nh03?o^4Nh2o`0000coY5^T00?o0000oeRWF?mHYeP03OmHYeP00ol0003oA;]4
odBkA004odBkA003o`000?n4NhCoQ7^400[oQ7^400Co0000ogf2OOl0003o00002?n]DZd00ol0003o
g2?Lom`Sg006om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ok1?/00ol0003okQ7^onhAkP0=onhAkP03o`000?o><Lko000000;o00002?nTFj@00ol0003oF:MH
oeRWF00?oeRWF0Ko00003_n4Nh@00ol0003o[E:]ojeB[@08ojeB[@03o`000?oL8mcog2?L00Kog2?L
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?onhAkP03o`000?o><LkocS7>00?ocS7>0ol00005ojAKY0;o00004?mHYeP01_l0003oK9=/
ofbCK?l0003oI9]To`0000koQ7^400?o0000ojeB[On]DZd02On]DZd00ol0003og2?Lom`Sg005om`S
g003o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
kQ7^onhAkP0=onhAkP03o`000?o><LkocS7>00KocS7>0ol000001?nTFjCo0000ohQgR?n8MhP3o`00
00coF:MH00Go0000ofbCK?m/TfcoK9=/o`000002ofBKI003o`000?n4NhCoQ7^400_oQ7^400?o0000
ojeB[On]DZd02On]DZd00ol0003og2?Lom`Sg006om`Sg003o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?o><Lh00ol0003oR7N8ohQgR004ohQg
R0?o00002?mHYeP00ol0003oK9=/ofbCK002ofbCK005o`000?mTVfCoI9]TofBKI?l000003?n4Nh@0
0ol0003o[E:]ojeB[@09ojeB[@03o`000?oL8mcog2?L00Gog2?L3?l00002ood2o@;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o_4>ooka3_00_oka3_00?o0000olha
c_o><Lh02_o><Lh00ol0003oR7N8ohQgR007ohQgR0;o00001OmHYeP00ol0003oK9=/ofbCK003ofbC
K003o`000?mTVfCoI9]T00;oI9]T00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o[E:]ojeB[@0:ojeB
[@03o`000?oL8mcog2?L00?og2?L00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@02ood2
o@;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o_4>ooka3_00[o
ka3_00?o0000olhac_o><Lh02oo><Lh00ol0003oR7N8ohQgR009ohQgR0?o000000?oF:MHo`000?m/
Tf`01Om/Tf`00ol0003oI9]TofBKI003ofBKI003o`000?n4NhCoQ7^400SoQ7^43_l00003om`Sg0;o
00002oof2OH00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om0_do`00000;onl@k`03o`000?o><LkocS7>00[ocS7>
0_l0000>ohQgR003o`000?m/TfcoK9=/00GoK9=/00?o0000ofBKI?mTVf@00omTVf@00ol0003oQ7^4
ohAkQ008ohAkQ003o`000?oM8]gogB;M00_ogB;M00?o0000om`Sg?l000003Oof2OH00ol0003oo@;m
ood2o@06ood2o@;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000oo@;m?od2oCo00002_o_4>l00ol0003ocS7>olhacP09olhacP03o`000?niA[Wo000000koR7N8
00?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oI9]TofBKI004ofBKI003o`000?n4NhCoQ7^400KoQ7^4
00?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@00_od
2o@00ol0003oka3_onl@k`06onl@k`03o`000?o><LkocS7>00SocS7>0_l00003okU6^@03o`000?n8
MhSoR7N800_oR7N800?o0000ofbCK?m/Tf`01Om/Tf`00ol0003oI9]TofBKI005ofBKI003o`000?n4
NhCoQ7^400GoQ7^400?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0;ooH9mP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo@;m?od2o@00ood2o@00ol0003oka3_onl@k`05onl@k`03o`000?o><LkocS7>00OocS7>00?o0000
okU6^OniA[T00oniA[T00ol0003oR7N8ohQgR00:ohQgR003o`000?m/TfcoK9=/00KoK9=/00?o0000
ofBKI?mTVf@01_mTVf@00ol0003oQ7^4ohAkQ004ohAkQ003o`000?oM8]gogB;M00gogB;M3ol0000;
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01Ood2o@00ol0
003oka3_onl@k`04onl@k`03o`000?o><LkocS7>00GocS7>0_l00006okU6^@03o`000?n8MhSoR7N8
00WoR7N80_l00008ofbCK003o`000?mTVfCoI9]T00KoI9]T1Ol000000on4NhCo0000omdRg@0?omdR
g@03o`000?og2?Oom`Sg00_om`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003o
ka3_onl@k`04o`0000KocS7>00?o0000okU6^OniA[T01oniA[T00ol0003oR7N8ohQgR005ohQgR0?o
000000?oR7N8o`000?m/Tf`01om/Tf`00ol0003oI9]TofBKI005ofBKI003o`000?nSG:?oXebS00?o
XebS0_l0000?omdRg@;o00003Oog2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000oo@;m?od2o@01ood2o@2o`0000Coi1_T00Co0000olhac_o><Lko
cS7>0_l0000:okU6^@03o`000?n8MhSoR7N800;oR7N80ol00005ohQgR003o`000?m/TfcoK9=/00Go
K9=/00?o0000ofBKI?mTVf@01?mTVf@00ol0003oXebSoj=LX`06oj=LX`03o`000?oM8]gogB;M00[o
gB;M0_l00002oo4>l@03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d02?om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om0_doo@;m008oo@;m003o`00
0?oT6nCoi1_T00Coi1_T00?o0000olhac_l000003?niA[T00ol0003oR7N8o`000002o`0000WoR7N8
00?o0000ofbCK?m/Tf`01?m/Tf`00ol0003oI9]TofBKI003ofBKI003o`000?nSG:?oXebS00SoXebS
1_l00004omdRg@;o00001Ooa3_400ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@01ood
2o@00ol0003oi1_Ton@Ki006on@Ki003o`000?niA[Wo^DJi00co^DJi00?o0000ohQgR?n8MhP02_n8
MhP00ol0003oK9=/ofbCK004ofbCK004o`000?mTVfCoI9]TofBKI0;o00002onSG:<00ol0003ohacS
on<Lh`03on<Lh`Co00002?oa3_400ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00Ooo@;m
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om0_doo@;m007oo@;m003o`000?oT
6nCoi1_T00Ooi1_T00?o0000okU6^OniA[T03?niA[T00ol0003oR7N8ohQgR00;ohQgR003o`000?m/
TfcoK9=/00?oK9=/00Co0000ofBKI?mTVfCo00003OnSG:<00ol0003ohacSon<Lh`06on<Lh`03o`00
0?oa3_7ol@ka00Ool@ka00?o0000ooL8moog2?L01oog2?L00ol0003oo@;mood2o@06ood2o@04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000oo@;m?od2o@0
1_od2o@00ol0003oi1_Ton@Ki009on@Ki003o`000?niA[Wo^DJi00Wo^DJi0_l0000>ohQgR0?o0000
0om/Tf`00ol0003oI9]To`00000=oj=LX`03o`000?oS7>?ohacS00OohacS00?o0000oo4>lOoa3_40
2?oa3_4:o`0000Koo@;m0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom0_d00?o
0000on@Ki?oT6n@02_oT6n@00ol0003o^DJiokU6^@06okU6^@;o000000?o^DJio`000?n8MhP02on8
MhP2o`0000?oTVfB1Ol0000>oj=LX`03o`000?oS7>?ohacS00OohacS00?o0000oo4>lOoa3_402?oa
3_400ol0003on`Ckoo/4n`06oo/4n`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP03ooX5nPCo00000_od2o@00ol0003oi1_Ton@Ki00;
on@Ki003o`000?niA[Wo^DJi00?o^DJi0ol00004okU6^@03o`000?n8MhSoR7N800OoR7N80_l00008
oi9]TP03o`000?nSG:?oXebS00goXebS00?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@07
oo4>l@03o`000?ok1?_on`Ck00Oon`Ck0ol000000oom0_go0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00OonPGj0_l0000?on@Ki003o`000?niA[Wo^DJi00;o00002?niA[T00ol0
003oR7N8ohQgR005ohQgR003o`000?nBKI;oTVfB00SoTVfB00?o0000oj=LXonSG:<03OnSG:<00ol0
003ohacSon<Lh`08on<Lh`03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5
nP03o`000?oT6nCoi1_T00koi1_T0_l0000;okU6^@03o`000?n8MhSoR7N800;oR7N80_l0000;oi9]
TP03o`000?nSG:?oXebS00goXebS00?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@06oo4>
l@03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003onPGjooX5nP0:ooX5nP03o`000?oT6nCoi1_T00goi1_T0_l0000<okU6^@04o`000?n8MhSo0000
o`0000goTVfB00?o0000oj=LXonSG:<03?nSG:<00ol0003ohacSon<Lh`09on<Lh`03o`000?oa3_7o
l@ka00Kol@ka00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oT6nCoi1_T00coi1_T00Co0000on4N
hOoQ7^7o00003?niA[T00ol0003oTVfBoi9]TP0>oi9]TP03o`000?nSG:?oXebS00SoXebS1?l0000;
on<Lh`03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oT6nCoi1_T
00_oi1_T00?o0000on4NhOoQ7^400_oQ7^400ol0003o^DJiokU6^@09okU6^@03o`000?nBKI;oTVfB
00koTVfB00Co0000oj=LXonSG:?oXebS1ol00003olDja@03o`000?oS7>?ohacS00WohacS00?o0000
oo4>lOoa3_401_oa3_400ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00conPGj00?o0000on@Ki?oT6n@02_oT6n@00ol0
003ohAkQon4Nh@03on4Nh@03o`000?niA[Wo^DJi00So^DJi00?o0000oi9]T_nBKI803_nBKI84o`00
00_oaC[500?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@05oo4>l@03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj
1OX03?oj1OX7o`0000Goi1_T00?o0000on4NhOoQ7^401OoQ7^400ol0003o^DJiokU6^@07okU6^@03
o`000?nBKI;oTVfB00koTVfB00?o0000olDjaOo5>/D03Oo5>/D00ol0003ohacSon<Lh`08on<Lh`03
o`000?oa3_7ol@ka00Col@ka00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003onPGjooX5nP0=ooX5nP03o`000?ob3O;olPgb00ColPgb
1Ol00009on4Nh@03o`000?niA[Wo^DJi00Ko^DJi00?o0000oi9]T_nBKI803_nBKI800ol0003oaC[5
olDja@0=olDja@03o`000?oS7>?ohacS00SohacS00Co0000oo4>lOoa3_7ol@ka1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooX5nP03o`000?ob3O;olPgb00WolPgb
0_l00009on4Nh@03o`000?niA[Wo^DJi00Ko^DJi00?o0000oi9]T_nBKI803?nBKI800ol0003oaC[5
olDja@0?olDja@Ko00001?oS7><4o`0000GonPGj0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_oj1OX00ol0003o
lPgboo8=lP09oo8=lP03o`000?o[5>_o000000;o00001ooQ7^400ol0003o^DJiokU6^@05okU6^@03
o`000?nBKI;oTVfB00SoTVfB1Ol0000AolDja@03o`000?o[5>_ojaC[00?ojaC[1?l0000;ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000OonPGj
00?o0000oo8=l_ob3O802_ob3O800ol0003ojaC[on/Dj`02on/Dj`?o00001OoQ7^400ol0003o^DJi
okU6^@04okU6^@04o`000?nBKI;oTVfBoi9]TPOo00001?o6>LH00ol0003oaC[5olDja@0>olDja@03
o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?oj1OX00ol0003olPgb
oo8=lP0;oo8=lP03o`000?o[5>_ojaC[00GojaC[0ol00003on4Nh@04o`000?niA[Wo^DJiokU6^@Ko
00003?o6>LH00ol0003oaC[5olDja@0=olDja@03o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?onPGjo`000?ob3O80
3?ob3O800ol0003ojaC[on/Dj`08on/Dj`?o000000CohAkQo`000?l0003o00000_oS7><00ol0003o
aSW6olHiaP0=olHiaP03o`000?o5>/GoaC[500coaC[500?o0000on/Djoo[5>/02?o[5>/00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo8=l_ob3O803?ob3O800ol0003ojaC[on/Dj`0;on/Dj`03o`000?oS7>?ohacS00?o
hacS00?o0000olHia_o6>LH03?o6>LH00ol0003odbcCo`00000=olDja@03o`000?o[5>_ojaC[00So
jaC[00?o0000ooX5n_oj1OX03?oj1OX3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O803?ob3O800ol0003ojaC[on/Dj`0:on/Dj`03o`00
0?oS7>?ohacS00GohacS00?o0000olHia_o6>LH02_o6>LH01?l0003odbcCom</dooC;=<2o`0000[o
aC[500?o0000on/Djoo[5>/02Oo[5>/00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo8=l_ob3O80
3?ob3O800ol0003ojaC[on/Dj`09on/Dj`03o`000?oS7>?ohacS00KohacS00?o0000olHia_o6>LH0
2Oo6>LH00ol0003odbcCom</d`02om</d`03o`000?oU6^Go000000;o00001oo5>/D00ol0003ojaC[
on/Dj`09on/Dj`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP0;oo8=lP03o`000?o[
5>_ojaC[00SojaC[00?o0000on<LhooS7><01ooS7><00ol0003oaSW6olHiaP08olHiaP03o`000?oC
;=?odbcC00?odbcC00?o0000onDJiOoU6^D00_oU6^D2o`0000CoaC[500?o0000on/Djoo[5>/02_o[
5>/00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo8=lPKo00001?o[5>/00ol0003ohacSon<Lh`08
on<Lh`03o`000?o6>LKoaSW600OoaSW600?o0000om</dooC;=<00ooC;=<00ol0003oiA[UonDJi@05
onDJi@?o000000?oaC[5o`000?o[5>/02oo[5>/00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo8=lP03o`000?od2oCom0_d00Com0_d1?l0000<on<Lh`03o`000?o6>LKoaSW6
00GoaSW600?o0000om</dooC;=<01?oC;=<00ol0003oiA[UonDJi@08onDJi@03o`000?o[5>_ojaC[
00_ojaC[00?o0000ooX5n_oj1OX02?oj1OX00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;olPgb00?o0000oo@;m?od
2o@02?od2o@00ol0003ohacSon<Lh`0:on<Lh`03o`000?o6>LKoaSW600CoaSW600?o0000om</dooC
;=<01OoC;=<00ol0003oiA[UonDJi@08onDJi@03o`000?o[5>_ojaC[00WojaC[1?l00008ooX5nP03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<oo@;m003o`000?oS7>?ohacS00WohacS
00?o0000olHia_o6>LH00oo6>LH00ol0003odbcCom</d`05om</d`03o`000?oU6^GoiA[U00[oiA[U
00?o0000on/Djoo[5>/01?o[5>/4o`0000Con0Oh00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003om0_doo@;m00:oo@;m003o`000?oS7>?ohacS00WohacS00?o0000olHia_o6>LH00_o6
>LH00ol0003odbcCom</d`06om</d`03o`000?oU6^GoiA[U00[oiA[U00?o0000on/Djoo[5>/01?l0
0009ooP7n0Ko00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?od2oCom0_d00[om0_d00?o0000on<LhooS7><02OoS7><01Ol0003oaSW6olHi
a_o6>LKo000000WodbcC00?o0000onDJiOoU6^D02ooU6^D2o`0000gon0Oh00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003om0_doo@;m00;oo@;m003o`000?oS7>?ohacS00WohacS00?o
0000olHia_l000002OoC;=<00ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00con0Oh00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003om0_doo@;m00:oo@;m003o`000?oS7>?o
hacS00SohacS1Ol00008om</d`03o`000?oU6^GoiA[U00coiA[U00?o0000ooP7n?oh1oP02ooh1oP0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003ohacSon<Lh`07on<L
h`03o`000?oY5^WojAKY00?ojAKY0ol00005om</d`03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
m0_d00?o0000on<LhooS7><01OoS7><00ol0003ojAKYonTFj@07onTFj@?o000000?odbcCo`000?oU
6^D03OoU6^D00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_od2o@00ol0003ohacSon<Lh`03on<Lh`;o0000
3OoY5^T2o`0000goiA[U0ol0000=ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?od2oCom0_d00Oom0_d00Co0000on<LhooS7>?ohacS
0_l00002ooH9mP03o`000?oY5^WojAKY00cojAKY3Ol00003ooT6n@03o`000?oh1oSon0Oh00[on0Oh
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008oo@;m003o`000?oS7>?o000000GomPWf
00?o0000onTFjOoY5^T02ooY5^T00ol0003okQ7^onhAkP09onhAkP03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooP7n003o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om0_d0ol0
0007ooH9mP03o`000?oY5^WojAKY00[ojAKY00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on@KiooT6
n@04ooT6n@;o00001ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo0?loo`3o?ol0o`3o`0000;onPGj00?o0000ooH9m_of2OH01_of2OH00ol0003ojAKYonTF
j@08onTFj@03o`000?o^4NkokQ7^00[okQ7^00?o0000ooT6nOoi1_T01_oi1_T00ol0003on0OhooP7
n004ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?ol0oco
o0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`000008ooH9mP03o`000?oY5^WojAKY00OojAKY00?o
0000onhAk_o^4Nh02_o^4Nh00ol0003on@KiooT6n@07ooT6n@;o00001?oh1oP00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l00Coo0?l00?o0000ooX5n_oj1OX00_oj1OX0
0ol0003omPWfooH9mP07ooH9mP03o`000?oY5^WojAKY00KojAKY00?o0000onhAk_o^4Nh02_o^4Nh0
0ol0003on@KiooT6n@09ooT6n@05o`000?oh1oSon0OhooP7n?l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003onPGjooX5nP03
ooX5nP03o`000?of2OKomPWf00OomPWf00?o0000onTFjOoY5^T01OoY5^T00ol0003okQ7^onhAkP0:
onhAkP03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?oj1O[onPGj00?onPGj00?o0000
ooH9m_of2OH02?of2OH00ol0003ojAKYonTFj@04onTFj@03o`000?o^4NkokQ7^00WokQ7^00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?ol0ocoo0?l
00Goo0?l00?o0000ooX5n_oj1OX01?oj1OX00ol0003omPWfooH9mP09ooH9mP03o`000?oY5^WojAKY
00;ojAKY00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`01Ool0o`00ol0003onPGjooX5nP05ooX5nP03o`000?of2OKomPWf00WomPWf00Go0000onTFjOoY
5^WojAKYo`00000<onhAkP03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oj1O[onPGj00GonPGj00?o0000ooH9m_of
2OH02_of2OH00ol0003ojAKYo`000004o`0000WokQ7^00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003onPGjooX5nP07ooX5nP;o0000
2oof2OH00ol0003on`Ckoo/4n`03oo/4n`Oo00000_o^4Nh00ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003oo0?loo`3o?ol0oco000000Soo0?l00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;m
o`000002o`0000SomPWf00?o0000oo/4nook1?/02_ok1?/5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ol0oco000000Woo0?l00?o
0000ooX5n_oj1OX01_oj1OX00ol0003oo@;mood2o@03ood2o@?o00001?of2OH00ol0003on`Ckoo/4
n`0=oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP07
ooX5nP03o`000?om0_goo@;m00Koo@;m0ol000000oof2OKo0000oo/4n`0>oo/4n`03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?ol0ocoo0?l00;oo0?l1_l00008ooX5nP03o`000?om0_goo@;m00[oo@;m00?o0000oo/4
nook1?/03ook1?/00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?om0_goo@;m00[o
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?oj1O[onPGjo`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003onPGjo`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool00ol00?l6oooo00[o003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Co003o0_ooo`02o`00o`?oool00ol0
0?l2oooo00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`08o`00o`;oool01Ol00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000Ko003o0_ooo`06o`00o`;oool02Ol00?l00ooo
o`3o003oo`00o`03o`00o`;oool01Ol00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1oooo
o`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;o
ool01?l00?l2oooo00Ko003o1?ooo`000ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo00Wo
003o0_ooo`04o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00Ko003o0_ooo`05o`00o`?oool0
2Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_oo
o`02o`00o`04oooo0?l00?oo003oo`00o`;oool00_l00?l2oooo00Oo003o0_ooo`04o`00o`;oool0
1?l00?l3oooo00Co003o0_ooo`07o`00o`;oool00ol00?l3oooo00[o003o0_ooo`03o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`08o`00o`03oooo0?l00?oo003o00?oool02_l00?l3oooo00?o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Wo003o1?ooo`0:o`00o`?oool01?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?oool0o`00ooooo`000_oo
o`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00?o003o0_oo
o`000ol00?ooool0oooo0008o`00o`Coool02?l00?l5oooo00Go003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00Oo003o0oooo`02
o`00o`;oool02?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool0
06Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l3oooo
00Co003o0_ooo`08o`00o`;oool01Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00So003o0_ooo`04o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;o
ool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool000?o003ooooo0?l00?l01Ol00?l2oooo00Go003o0_ooo`04o`00o`;oool0
1ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00
o`0Fo`00o`;oool000?o<S;<o`00ool00?l00ol00?l2oooo00Ko003o0_ooo`000ol00?ooool0o`00
o`05o`00o`;oool01Ol00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?ooo`3oool006Oo003o0Ooo
ool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`Goool01?l00?l2
oooo00Co003o0_ooo`03o`00o`;oool00ol00?l2oooo00Oo003o0_ooo`02o`00o`;oool01Ol00?l5
oooo06Oo003o0Oooool006Ko003o1_ooo`000ol00?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00
o`Goool01_l00?l4oooo00Wo003o1?ooo`1bo`00o`7ooooo003oo`00obco003o0Oooool00?oo003o
;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(840) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.989 .011 .989 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.972 .028 .972 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.977 .023 .977 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.947 .053 .947 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.984 .016 .984 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.892 .108 .892 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.967 .033 .967 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.965 .035 .965 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.971 .029 .971 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.98 .02 .98 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.953 .047 .953 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.979 .021 .979 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.923 .077 .923 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.977 .023 .977 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.964 .036 .964 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.974 .026 .974 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.903 .097 .903 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.984 .016 .984 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.957 .043 .957 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.925 .075 .925 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.743 .257 .743 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.791 .209 .791 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.981 .019 .981 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.933 .067 .933 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.938 .062 .938 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.761 .239 .761 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.722 .278 .722 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.668 .332 .668 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.924 .076 .924 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.947 .053 .947 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.936 .064 .936 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.894 .106 .894 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.78 .22 .78 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.974 .026 .974 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.775 .225 .775 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.681 .319 .681 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.872 .128 .872 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.429 .571 .429 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.423 .577 .423 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.511 .489 .511 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.791 .209 .791 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.807 .193 .807 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.987 .013 .987 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.462 .538 .462 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.418 .582 .418 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.956 .044 .956 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.993 .007 .993 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.597 .403 .597 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.727 .273 .727 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.919 .081 .919 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.921 .079 .921 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.645 .355 .645 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.882 .118 .882 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.354 .646 .354 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.842 .158 .842 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.728 .272 .728 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.994 .006 .994 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.143 .857 .143 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.314 .686 .314 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.979 .021 .979 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.241 .759 .241 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.186 .814 .186 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.892 .108 .892 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.981 .019 .981 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.495 .505 .495 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.149 .851 .149 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.221 .779 .221 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.808 .192 .808 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.318 .682 .318 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.537 .463 .537 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.99 .01 .99 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.212 .788 .212 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.041 .959 .041 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.13 .87 .13 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.997 .003 .997 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.025 .975 .025 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.351 .649 .351 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.539 .461 .539 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.963 .037 .963 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.575 .425 .575 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.65 .35 .65 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.045 .955 .045 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
0 1 0 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.028 .972 .028 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.102 .898 .102 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.137 .863 .137 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.779 .221 .779 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.912 .088 .912 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.94 .06 .94 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.464 .536 .464 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.098 .902 .098 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.828 .172 .828 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.209 .791 .209 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.426 .574 .426 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.112 .888 .112 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.272 .728 .272 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.858 .142 .858 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.395 .605 .395 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.114 .886 .114 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.981 .019 .981 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.9 .1 .9 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.934 .066 .934 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.271 .729 .271 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.973 .027 .973 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.023 .977 .023 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.64 .36 .64 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.612 .388 .612 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.115 .885 .115 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.244 .756 .244 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.519 .481 .519 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.776 .224 .776 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.118 .882 .118 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.987 .013 .987 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.062 .938 .062 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.213 .787 .213 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.286 .714 .286 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.974 .026 .974 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.495 .505 .495 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.43 .57 .43 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.302 .698 .302 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.254 .746 .254 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.92 .08 .92 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.893 .107 .893 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.89 .11 .89 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.199 .801 .199 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.527 .473 .527 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.679 .321 .679 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.867 .133 .867 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.972 .028 .972 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.5 .5 .5 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.739 .261 .739 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.389 .611 .389 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.962 .038 .962 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.945 .055 .945 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.861 .139 .861 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.977 .023 .977 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.993 .007 .993 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.506 .494 .506 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.622 .378 .622 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.99 .01 .99 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.538 .462 .538 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.907 .093 .907 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.697 .303 .697 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.828 .172 .828 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.641 .359 .641 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.978 .022 .978 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.968 .032 .968 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.982 .018 .982 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.783 .217 .783 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.963 .037 .963 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.724 .276 .724 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.754 .246 .754 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.867 .133 .867 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.868 .132 .868 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.959 .041 .959 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.814 .186 .814 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.986 .014 .986 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.956 .044 .956 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.935 .065 .935 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.922 .078 .922 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.875 .125 .875 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.887 .113 .887 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.838 .162 .838 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.934 .066 .934 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.956 .044 .956 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.981 .019 .981 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.967 .033 .967 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.973 .027 .973 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.985 .015 .985 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.966 .034 .966 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.895 .105 .895 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.96 .04 .96 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.974 .026 .974 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.986 .014 .986 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.982 .018 .982 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.985 .015 .985 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.972 .028 .972 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.993 .007 .993 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.989 .011 .989 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.977 .023 .977 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.993 .007 .993 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.984 .016 .984 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003oo@;mood2oOl0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ood2oOom0_d00_om0_d00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000coo@;m00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o005oo`3o003o`000?om
0_goo@;m00_oo@;m0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo0?loo`3o006
oo`3o003o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?ol0ocoo0?loo`3o0;o00002_oo0?l2o`000003oo`3o?l0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_go
o@;m00Woo@;m00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?ol0oco
o0?l00Coo0?l0_l00005ool0o`?o00001?ol0o`00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003oo@;mood2o@09ood2
o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo0?l0_l000000ooo
0?oo0000o`000007oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Ooo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol
0o`01ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?ol0ocoo0?l00Soo0?l
00?o0000ood2oOom0_d01_om0_d00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ok1?_on`Cko`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo@;mood2o@05ood2
o@03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003ool0o`00ol0003oo0?loo`3o008oo`3
o003o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo/4n`03o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o0?loo`3o009oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000ood2oOom0_d03_om0_d00ol0003o
o0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo/4n`03o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o00:oo`3o004o`000?om0_goo@;mood2o@?o0000
3oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_on`Ck1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`02ool0o`01?l0003oo@;mo`00
0?l00003ooH9mP;o00003?om0_d2o`00013oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo/4nook1?/02ook1?/01?l0003ol0o`
oo0?l?o`3o05o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o00<oo`3o003
o`000?of2OKomPWf00GomPWf0_l00008ood2o@;o00000_of2OH00ol0003oo0?loo`3o00=oo`3o003
o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ook1?/00ol0003ol0o`oo0?l007oo0?l0Ko00000_oo0?l4o`0000goo0?l00?o0000ooH9m_of2OH0
1oof2OH2o`0000Goo@;m00?o0000ooH9m_of2OH00oof2OH00ol0003oo0?loo`3o00<oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ook1?/00ol0003ol0o`oo0?l00<oo0?l0?o00001?oi1_T3o`0000Woo0?l00?o
0000ooH9m_of2OH02_of2OH2o`000003ood2oOl0003o000000OomPWf00?o0000oo`3o?ol0o`02ool
0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo/4nook1?/03_ok1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Won@Ki00Kon@Ki0ol00005
oo`3o003o`000?of2OKomPWf00gomPWf00?o0000ooH9m_of2OH02?of2OH00ol0003oo0?loo`3o009
oo`3o003o`000?ol0ocoo0?l00goo0?l00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000oon`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on@KiooT6n@0:
ooT6n@?o000000?oo0?lo`000?of2OH03oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?ol0oco
o0?l00Soo0?l00?o0000oo`3o?ol0o`03_ol0o`3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooi
1_Wo0000oo/4n`0>oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooT6nOoi1_T03Ooi1_T00ol0
003omPWfooH9mP0?ooH9mP03o`000?of2OKomPWf00[omPWf2ol0000;oo`3o0Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooT6n@03o`000?ok1?_on`Ck00con`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0
003on@KiooT6n@0=ooT6n@;o00004?of2OH00ol0003omPWfooH9mP0:ooH9mP03o`000?od2oCom0_d
00Oom0_d00?o0000oo`3o?ol0o`00_ol0o`7o`0000Com`Sg00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooT6n@;o00002ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Won@Ki
00gon@Ki00Co0000on@Ki?oT6nCo00003oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCo
m0_d00Wom0_d1?l0000;ooL8m`03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00con@Ki00Co0000on/Djol0003o00002Ook1?/00ol0003ol0o`oo0?l00=oo0?l003o`000?oi1_Wo
n@Ki00gon@Ki00Go0000on@Ki?oT6nCoi1_To`00000=ooH9mP03o`000?of2OKomPWf00[omPWf00?o
0000oo@;m?od2o@02Ood2o@00ol0003om`SgooL8m`0<ooL8m`03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003on@KiooT6n@0<ooT6n@03o`000?o[5>_ojaC[00;ojaC[0_l00007oo/4n`03o`000?o`3o3o
l0o`00col0o`00?o0000ooT6nOoi1_T03Ooi1_T00ol0003oi1_Ton@Ki003on@Ki003o`000?of2OKo
mPWf00[omPWf00?o0000ooH9m_of2OH02_of2OH00ol0003om0_doo@;m009oo@;m003o`000?og2?Oo
m`Sg00com`Sg00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oi1_Won@Ki00_on@Ki00?o0000on/D
joo[5>/01Oo[5>/00ol0003on`Ckoo/4n`03oo/4n`03o`000?o`3o3ol0o`00gol0o`00?o0000ooT6
nOoi1_T03Ooi1_T00ol0003oi1_Ton@Ki004on@Ki003o`000?of2OKomPWf00WomPWf00?o0000ooH9
m_of2OH02Oof2OH00ol0003om0_doo@;m00:oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oi1_Won@Ki00_on@Ki00?o0000on/Djoo[5>/01_o[5>/2o`0000?o
n`Ck00?o0000oo0?l?o`3o003Oo`3o000ol0003on@KiooT6n@0<ooT6n@03o`000?oT6nCoi1_T00Ko
i1_T00?o0000ooH9m_of2OH02?of2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00[o
m0_d00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003on@KiooT6n@0:ooT6n@03o`00
0?o[5>_ojaC[00WojaC[0_l000000ook1?_o0000oo0?l00<oo0?l0?o00003_oi1_T00ol0003oi1_T
on@Ki007on@Ki003o`000?of2OKomPWf00OomPWf00?o0000ooH9m_of2OH02Oof2OH00ol0003om0_d
oo@;m00;oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003on@KiooT6
n@09ooT6n@03o`000?o[5>_ojaC[00_ojaC[00?o0000oo0?l?o`3o002_o`3o02o`0000?ofbCK00?o
0000ooT6nOoi1_T02_oi1_T00ol0003oi1_Ton@Ki009on@Ki003o`000?of2OKomPWf00KomPWf00?o
0000ooH9m_of2OH02?of2OH00ol0003om0_doo@;m00<oo@;m003o`000?og2?Oom`Sg00com`Sg00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ojaC[on/Dj`0<on/Dj`03o`000?o`3o3ol0o`00Sol0o`0_l00006om/Tf`;o00002_oi1_T0
0ol0003oi1_Ton@Ki00:on@Ki003o`000?of2OKomPWf00GomPWf00?o0000ooH9m_of2OH02?of2OH0
0ol0003om0_doo@;m00<oo@;m003o`000?og2?Oom`Sg00com`Sg00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[5>/03_o[5>/00ol0003ol0o`oo0?l004
oo0?l0?o00002_oK9=/00ol0003on@KiooT6n@07ooT6n@03o`000?oT6nCoi1_T00_oi1_T00?o0000
ooH9m_of2OH00oof2OH00ol0003omPWfooH9mP09ooH9mP03o`000?od2oCom0_d00com0_d00?o0000
ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oi1_Won@Ki00Oon@Ki00?o0000on/Djoo[5>/03oo[5>/01?l0
003ol0o`oo0?l?o`3o02o`0000kofbCK0_l00006ooT6n@03o`000?oT6nCoi1_T00goi1_T00?o0000
ooH9m_of2OH00_of2OH00ol0003omPWfooH9mP08ooH9mP03o`000?od2oCom0_d00com0_d0ol0000=
ooL8m`03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooT6nOoi1_T01_oi1_T00ol0003ojaC[on/Dj`0@on/Dj`Co00004_oK9=/00ol0
003on@KiooT6n@03ooT6n@03o`000?oT6nCoi1_T00koi1_T00Go0000ooH9m_of2OKomPWfo`000005
ooH9mPOo00003?od2o@01Ol0003oka3_onl@koo_4>oo000000com`Sg00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooT6nOoi1_T01_oi1_T00ol0003ojaC[on/Dj`0=
on/Dj`?o000000CoebSGo`000?l0003o00004ooK9=/2o`0000;on@Ki00?o0000on@Ki?oT6n@04?oT
6n@00ol0003omPWfo`000006o`0000OogB;M00?o0000oo@;m?od2o@02?od2o@00ol0003oka3_onl@
k`03onl@k`;o00002?og2?L3o`0000Koo@;m1?l00002oo/4n`03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?of2OH3o`0000goo@;m00?o0000ooT6nOoi1_T01?oi1_T00ol0003ojaC[on/D
j`0;on/Dj`?o00000ooG:=L01Ol0003ocS7>o`000?nVFJKo000001CofbCK00?o0000ooT6nOl00000
4ooT6n@00ol0003ogB;MomdRg@0=omdRg@03o`000?od2oCom0_d00Gom0_d0_l00008onl@k`03o`00
0?og2?Oom`Sg00Go00000ooe2_D00ol0003oo@;mood2o@03o`0000Oon`Ck00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000ComPWf0ol0000:ood2o@03o`000?oi1_Won@Ki00?on@Ki
00?o0000on/Djoo[5>/02Oo[5>/3o`0000GoebSG00Co0000olhac_o><Lko00000_nVFJH00ol0003o
fbCKom/Tf`0Bom/Tf`03o`000?oT6nCoi1_T01;oi1_T00?o0000omdRgOoM8]d03_oM8]d00ol0003o
m0_doo@;m003oo@;m003o`000?o_4>ooka3_00Woka3_0_l00009ooD:m@;o00002_ok1?/00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooH9mP;o00001oom0_d5o`0000;o
n@Ki00?o0000on/Djoo[5>/01_o[5>/3o`0000SoebSG00Co0000olhac_o><Lko00000onVFJH00ol0
003ofbCKom/Tf`0Aom/Tf`03o`000?oT6nCoi1_T017oi1_T00?o0000omdRgOoM8]d04?oM8]d01Ol0
003om0_doo@;m?od2oCo000000coka3_00?o0000ooD:mOoe2_D02?oe2_D00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooH9m_of2OH01oof2OH3o`00
0004ood2oOl0003o0000o`0000Goka3_0_l00006on/Dj`?o00002_oG:=L01Ol0003ocS7>olhac_o>
<Lko000000CoYUVV00?o0000om/TfooK9=/04?oK9=/00ol0003oi1_Ton@Ki00Aon@Ki003o`000?oM
8]gogB;M017ogB;M00?o0000oo@;m?l000003Oo_4>l00ol0003om@[eooD:m@08ooD:m@03o`000?ok
1?_on`Ck00[on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooH9m_of2OH02_of2OH00ol0003oka3_onl@k`08onl@k`03o`000?o[5>_ojaC[00?o00003OoG:=L0
1Ol0003ocS7>olhac_o><Lko000000GoYUVV00?o0000om/TfooK9=/03ooK9=/00ol0003oi1_Ton@K
i00Aon@Ki003o`000?oM8]gogB;M01;ogB;M00?o0000onl@koo_4>l03?o_4>l00ol0003om@[eooD:
m@08ooD:m@03o`000?ok1?_on`Ck00_on`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o_4>ooka3_00Woka3_0_l0000?omLXe`03o`000?o><Lko
cS7>00;ocS7>00?o0000ojIIY_nVFJH01?nVFJH00ol0003ofbCKom/Tf`0=om/Tf`?o00004OoT6n@0
0ol0003ogB;MomdRg@0ComdRg@03o`000?o_4>ooka3_00_oka3_00?o0000ooD:mOoe2_D02Ooe2_D0
0ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003omPWfooH9mP0:ooH9mP03o`000?o_4>ooka3_00Woka3_00?o0000omLXeooG:=L03OoG:=L0
0ol0003ocS7>olhacP03olhacP03o`000?nVFJKoYUVV00GoYUVV00?o0000om/TfooK9=/02_oK9=/2
o`0000?oW6>L00?o0000on@Ki?oT6n@03_oT6n@00ol0003ogB;MomdRg@0ComdRg@03o`000?o_4>oo
ka3_00_oka3_00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_omPWf00?o0000onl@
koo_4>l02oo_4>l00ol0003oebSGomLXe`0<omLXe`03o`000?o><LkocS7>00?ocS7>00?o0000ojII
Y_nVFJH01_nVFJH00ol0003ofbCKom/Tf`07om/Tf`;o00001_nLHi`2o`0000koi1_T00?o0000omdR
gOoM8]d04ooM8]d00ol0003oka3_onl@k`0;onl@k`03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4
nook1?/03?ok1?/00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_omPWf00?o0000onl@koo_4>l02oo_4>l00ol0003oebSGomLXe`0;omLX
e`03o`000?o><LkocS7>00CocS7>00?o0000ojIIY_nVFJH01onVFJH00ol0003ofbCKom/Tf`05om/T
f`03o`000?nLHicoW6>L00SoW6>L00?o0000on@Ki?oT6n@02_oT6n@00ol0003ogB;MomdRg@0DomdR
g@03o`000?o_4>ooka3_00_oka3_00?o0000ooD:mOoe2_D02Ooe2_D00ol0003on`Ckoo/4n`0<oo/4
n`03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_omPWf00?o0000onl@koo_4>l02oo_4>l00ol0003oebSGomLXe`0;omLXe`03o`000?o><LkocS7>
00CocS7>00?o0000ojIIY_nVFJH02?nVFJH00ol0003ofbCKom/Tf`02om/Tf`;o00003?nLHi`2o`00
00[oi1_T00?o0000omdRgOoM8]d05?oM8]d00ol0003oka3_onl@k`0;onl@k`03o`000?oe2_Gom@[e
00Wom@[e00?o0000oo/4nook1?/03Ook1?/00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooH9m_of2OH02?of2OH00ol0003oka3_onl@k`0<onl@k`03
o`000?oG:=OoebSG00WoebSG00?o0000olhac_o><Lh01Oo><Lh00ol0003oYUVVojIIYP09ojIIYP04
o`000?oK9=_o0000o`00013oW6>L0_l00008on@Ki003o`000?oM8]gogB;M01CogB;M0ol0000;onl@
k`03o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4nook1?/03Ook1?/01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooH9
m_of2OH02?of2OH00ol0003oka3_onl@k`0;onl@k`;o00002_oG:=L00ol0003ocS7>olhacP06olha
cP03o`000?nVFJKoYUVV00[oYUVV00?o0000oiaSW?nLHi`04_nLHi`00ol0003oi1_Ton@Ki004on@K
i003o`000?oM8]gogB;M01GogB;M00?o0000omHYe_oF:MH01Ol00005onl@k`03o`000?oe2_Gom@[e
00[om@[e00?o0000oo/4nook1?/03_ok1?/3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooH9m_of2OH01oof2OH00ol0003oka3_onl@k`0;onl@k`04
o`000?o6>LKoaSW6o`0000WoebSG00?o0000olhac_o><Lh01_o><Lh00ol0003oYUVVojIIYP0:ojII
YP03o`000?nLHicoW6>L01?oW6>L0_l00003on@Ki0Co00005?oM8]d00ol0003oeRWFomHYeP06omHY
ePCo000000?oka3_o`000?oe2_D02ooe2_D00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooH9m_of
2OH01oof2OH00ol0003oka3_onl@k`09onl@k`;o00001?o6>LH00ol0003oebSGomLXe`05omLXe`03
o`000?o><LkocS7>00OocS7>00?o0000ojIIY_nVFJH02_nVFJH00ol0003oW6>LoiaSW00EoiaSW003
o`000?oT6nCo000000Co/Tfb0ol0000@omdRg@03o`000?oF:MKoeRWF00_oeRWF0_l0000<ooD:m@03
o`000?ok1?_on`Ck00con`Ck0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?of2OKomPWf00OomPWf00?o0000onl@koo_4>l02?o_4>l00ol0003oaSW6
olHiaP05olHiaP03o`000?oG:=OoebSG00CoebSG00?o0000olhac_o><Lh01oo><Lh00ol0003oYUVV
ojIIYP0:ojIIYP03o`000?nLHicoW6>L01KoW6>L00?o0000ok9=/_nbCK801_nbCK83o`0000cogB;M
00?o0000omHYe_oF:MH03OoF:MH00ol0003om@[eooD:m@09ooD:m@Go00002Ook1?/2o`000003ood2
oOl0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooH9m_of2OH01_of
2OH00ol0003oka3_onl@k`07onl@k`03o`000?o6>LKoaSW600OoaSW600?o0000omLXeooG:=L00_oG
:=L00ol0003ocS7>olhacP08olhacP03o`000?nVFJKoYUVV00WoYUVV00?o0000oiaSW?nLHi`05onL
Hi`00ol0003o/Tfbok9=/P09ok9=/P?o00002OoM8]d00ol0003oeRWFomHYeP0>omHYePKo00001?oe
2_D00ol0003onPGjooX5nP03ooX5nPGo00000_ok1?/2o`0000Coo@;m00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?ol0ocoo0?loo`3o?l000002ook1?/00ol0003omPWfooH9mP06ooH9mP03o`000?o_
4>ooka3_00Goka3_0_l0000;olHiaP04o`000?oG:=OoebSGo`0000_ocS7>00?o0000ojIIY_nVFJH0
2OnVFJH00ol0003oW6>LoiaSW00FoiaSW003o`000?nbCK;o/Tfb00go/Tfb0ol00005omdRg@03o`00
0?oF:MKoeRWF00ooeRWF00?o0000onDJiOoU6^D00ooU6^D4o`0000_onPGj0_l00006ood2o@03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o002oo`3o0ko00001_of2OH00ol0003oka3_onl@
k`05onl@k`03o`000?o6>LKoaSW600coaSW600?o0000omLXeol000002oo><Lh00ol0003oYUVVojII
YP07ojIIYP?o00006?nLHi`00ol0003o/Tfbok9=/P0@ok9=/P?o000000?ogB;Mo`000?oF:MH04?oF
:MH00ol0003oiA[UonDJi@07onDJi@03o`000?oj1O[onPGj00[onPGj00?o0000ood2oOom0_d01Oom
0_d00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005oo`3o003o`000?og2?Oom`Sg00_om`Sg0_l00004
ooH9mP03o`000?o_4>ooka3_00?oka3_0_l0000@olHiaP03o`000?o><LkocS7>00[ocS7>00?o0000
ojIIY_nVFJH00onVFJH4o`0000;oMXUf00?o0000oiaSW?nLHi`05OnLHi`00ol0003o/Tfbok9=/P0D
ok9=/P03o`000?oF:MKoeRWF013oeRWF00?o0000onDJiOoU6^D01ooU6^D00ol0003onPGjooX5nP0:
ooX5nP03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Goo0?l00?o0000ooL8moog2?L03Oog2?L6o`0000?oka3_00?o0000olHia_o6>LH04?o6>LH00ol0
003ocS7>olhacP0:olhacP03o`000?nVFJKo000000?o00001omfRGH00ol0003oW6>LoiaSW00DoiaS
W003o`000?nbCK;o/Tfb01Co/Tfb00?o0000omHYe_oF:MH03ooF:MH00ol0003oiA[UonDJi@08onDJ
i@03o`000?oj1O[onPGj00[onPGj00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oW6>OoiaSW00?o
iaSW00?o0000onl@kol000004oo6>LH4o`0000WocS7>0_l0000<ogJ9MP03o`000?nLHicoW6>L01?o
W6>L00?o0000ok9=/_nbCK805OnbCK800ol0003oeRWFomHYeP0>omHYeP03o`000?oU6^GoiA[U00So
iA[U00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooL8moog2?L02oog2?L00ol0003oiaSWonLHi`05onLHi`03o`00
0?o6>LKoaSW601;oaSW600Co0000ogj1O_mnPGkoOX5n1Ol00003olhacP03o`000?mfRGKoMXUf00go
MXUf0ol0000@oiaSW0;o00006?nbCK800ol0003oeRWFomHYeP0=omHYeP03o`000?oU6^GoiA[U00Wo
iA[U00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo0?l00?o0000ooL8moog2?L02_og2?L00ol0003oiaSWonLHi`06onLHi`03o`00
0?o6>LKoaSW6017oaSW600?o0000ogj1O_mnPGh01omnPGh3o`00013oMXUf00?o0000odFjAOm5^TD0
1Ol00009oiaSW0;o000000?oKY5^o`000?nbCK805onbCK800ol0003oeRWFomHYeP0=omHYeP03o`00
0?oU6^GoiA[U00WoiA[U00?o0000ooX5n_oj1OX02?oj1OX2o`0000[oo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02Ool0o`00ol0003om`SgooL8
m`0:ooL8m`03o`000?oW6>OoiaSW00OoiaSW00?o0000olHia_o6>LH03oo6>LH00ol0003oOX5nogj1
OP0:ogj1OP03o`000?mfRGKoMXUf00goMXUf00?o0000odFjAOm5^TD01_m5^TD4o`0000CoW6>L00?o
0000ofjAK_m^TFh00_m^TFh00ol0003o/Tfbok9=/P0Fok9=/P03o`000?oF:MKoeRWF00_oeRWF00?o
0000onDJiOoU6^D02ooU6^D00ol0003onPGjooX5nP06ooX5nP03o`000?ol0oco000000[oo@;m00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02?ol0o`=
o`0000[oiaSW00?o0000olHia_o6>LH03oo6>LH00ol0003oOX5nogj1OP0;ogj1OP03o`000?mfRGKo
MXUf00coMXUf00?o0000odFjAOm5^TD02_m5^TD4o`0000GoKY5^00?o0000ok9=/_nbCK805_nbCK80
0ol0003oeRWFomHYeP0:omHYeP03o`000?oU6^GoiA[U00coiA[U00?o0000ooX5n_oj1OX01?oj1OX2
o`0000?oo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?og2?Oom`Sg00Wom`Sg00?o0000onLH
iooW6>L02OoW6>L00ol0003oaSW6olHiaP0=olHiaP03o`000?mnPGkoOX5n00coOX5n00?o0000ogJ9
M_mfRGH03?mfRGH00ol0003oAKY5odFjA@0;odFjA@03o`000?m9]TWo000000KoKY5^00?o0000ok9=
/_nbCK805_nbCK800ol0003oeRWFomHYeP09omHYeP03o`000?oU6^GoiA[U00coiA[U00?o0000ooX5
n_oj1OX00ooj1OX00ol0003oo0?loo`3o003oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003o
m`SgooL8m`08ooL8m`03o`000?oW6>OoiaSW00_oiaSW00?o0000olHia_o6>LH02?o6>LH4o`0000oo
OX5n00?o0000ogJ9M_mfRGH02omfRGH00ol0003oAKY5odFjA@0;odFjA@04o`000?m9]TWoBKI9o`00
00OoKY5^00?o0000ok9=/_nbCK805OnbCK800ol0003oeRWFomHYeP08omHYeP03o`000?oU6^GoiA[U
00goiA[U00?o0000ooX5n_oj1OX00_oj1OX00ol0003oo0?loo`3o005oo`3o003o`000?om0_goo@;m
00Ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo`3o?ol
0o`01Ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oW6>OoiaSW00_oiaSW00?o0000olHia_o6
>LH00oo6>LH5o`0000?oPWf200?o0000ogj1O_mnPGh03_mnPGh00ol0003oMXUfogJ9MP0:ogJ9MP03
o`000?m5^TGoAKY500[oAKY500Go0000odVfBOm9]TWoBKI9o`000007ofjAKP03o`000?nbCK;o/Tfb
01Go/Tfb00?o0000omHYe_oF:MH02?oF:MH00ol0003oiA[UonDJi@0=onDJi@03o`000?oj1O[onPGj
00;o00002?ol0o`00ol0003oo@;mood2o@08ood2o@Wo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiaSWonLHi`0<onLHi`Go00002On2OH800ol0003o
OX5nogj1OP0<ogj1OP;o00003?mfRGH00ol0003oAKY5odFjA@0:odFjA@05o`000?m9]TWoBKI9odVf
BOl000002?m^TFh00ol0003o/Tfbok9=/P0Dok9=/P?o00001ooF:MH00ol0003oiA[UonDJi@0>onDJ
i@03o`000?oj1O[o000000_oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o004oo`3o003o`000?og2?Oom`Sg00Oo
m`Sg00?o0000onLHiooW6>L03?oW6>L01?l0003o`Sg2ol8m`_l0000;oh9mPP03o`000?mnPGkoOX5n
00_oOX5n00Co0000ocK9=_lfbCKo00002_mfRGH00ol0003oAKY5odFjA@0:odFjA@03o`000?m9]TWo
BKI900;oBKI900?o0000ofjAK_m^TFh01_m^TFh00ol0003o/Tfbok9=/P0Aok9=/P?o00000oniA[T0
0ol0003oeRWFomHYeP04omHYeP03o`000?oU6^GoiA[U00goiA[U1?l0000;oo`3o003o`000?om0_go
o@;m00Goo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000oo`3
o?ol0ocoo0?l1?l00008ooL8m`03o`000?oW6>OoiaSW00_oiaSW00?o0000ol8m`_o2?L800_o2?L80
0ol0003oPWf2oh9mPP08oh9mPP03o`000?mnPGkoOX5n00[oOX5n00?o0000ocK9=_lfbCH00_lfbCH0
0ol0003oMXUfogJ9MP03ogJ9MPGo00002om5^TD00ol0003oBKI9odVfB@03odVfB@03o`000?m^TFko
KY5^00OoKY5^00?o0000ok9=/_nbCK803_nbCK82o`0000Oo^DJi00?o0000omHYe_oF:MH00_oF:MH0
0ol0003oiA[UonDJi@0=onDJi@03o`000?oh1oSon0Oh00;on0Oh00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo@;mood2o@03ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oh1oP00ol0003om`SgooL8m`05ooL8m`03o`000?oW6>OoiaSW00[oiaSW00?o0000ol8m
`_o2?L800oo2?L800ol0003oPWf2oh9mPP09oh9mPP03o`000?mnPGkoOX5n00SoOX5n00?o0000ocK9
=_lfbCH01?lfbCH5o`0000Co=LXe00?o0000odFjAOm5^TD02Om5^TD00ol0003oBKI9odVfB@03odVf
B@03o`000?m^TFkoKY5^00SoKY5^00?o0000ok9=/_nbCK802_nbCK83o`0000[o^DJi00Go0000omHY
e_oF:MKoeRWFo`00000>onDJi@03o`000?oh1oSon0Oh00Con0Oh0_l00009oo`3o003o`000?om0_go
o@;m00;oo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooP7
n?oh1oP01Ooh1oP00ol0003om`SgooL8m`03ooL8m`03o`000?oW6>OoiaSW00[oiaSW00?o0000ol8m
`_o2?L801?o2?L800ol0003oPWf2oh9mPP09oh9mPP03o`000?mnPGkoOX5n00OoOX5n00?o0000ocK9
=_lfbCH01OlfbCH00ol0003o=LXeocG:=@07ocG:=@03o`000?m5^TGoAKY500OoAKY500?o0000odVf
BOm9]TT01?m9]TT00ol0003oKY5^ofjAKP08ofjAKP03o`000?nbCK;o/Tfb00So/Tfb0_l0000>okU6
^@Co00003?oU6^D2o`0000Won0Oh00?o0000oo`3o?ol0o`01ool0o`01?l0003oo@;mood2oOl0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on0OhooP7n007ooP7n0;o00000oog2?L00ol0
003oiaSWonLHi`09onLHi`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oh9mP_n2OH802On2OH800ol0
003oOX5nogj1OP05ogj1OP03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000ocG:=OlebSD02?lebSD00ol0
003oAKY5odFjA@06odFjA@03o`000?m9]TWoBKI900CoBKI900?o0000ofjAK_m^TFh02Om^TFh4o`00
00?o/Tfb0ol0000@okU6^@05o`000?oS7>?ohacSon<Lhol000002_oU6^D00ol0003on0OhooP7n00:
ooP7n0Ko00000ool0o`00ol0003oo@;mo`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003on0OhooP7n00:ooP7n004o`000?og2?Oom`Sgo`0000[oiaSW00?o0000ol8m`_o2?L801oo2?L80
0ol0003oPWf2oh9mPP09oh9mPP03o`000?mnPGkoOX5n00CoOX5n00?o0000ocK9=_lfbCH01olfbCH0
0ol0003o=LXeocG:=@08ocG:=@;o00001_m5^TD00ol0003oBKI9odVfB@05odVfB@03o`000?m^TFko
KY5^00WoKY5^00Co0000ohUfROn9MXWoRGJ90ol0000BokU6^@03o`000?oS7>?ohacS00?ohacS0_l0
0006onDJi@;o00003Ooh1oP00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on0OhooP7n00<ooP7n0;o00002_oW6>L00ol0003o`Sg2ol8m`P08ol8m`P03o`000?n2OH;o
PWf200[oPWf200?o0000ogj1O_mnPGh00_mnPGh00ol0003o=/TfocK9=P08ocK9=P03o`000?lebSGo
=LXe00Ko=LXe0_l00002oacS7003o`000?m5^TGoAKY500;oAKY500?o0000odVfBOm9]TT01_m9]TT0
0ol0003oKY5^ofjAKP08ofjAKP03o`000?n9MXWoRGJ900CoRGJ900?o0000okU6^OniA[T03oniA[T0
0ol0003ohacSon<Lh`06on<Lh`;o00000ooU6^D00ol0003on0OhooP7n00=ooP7n003o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oh1oSon0Oh
00kon0Oh00?o0000onLHiooW6>L01ooW6>L00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?n2OH;oPWf2
00WoPWf200Go0000ogj1O_mnPGkoOX5no`00000;ocK9=P03o`000?lebSGo=LXe00Co=LXe0_l00005
oacS7005o`000?m5^TGoAKY5odFjAOl000002?m9]TT00ol0003oKY5^ofjAKP08ofjAKP03o`000?n9
MXWoRGJ900GoRGJ900?o0000okU6^OniA[T03_niA[T00ol0003ohacSon<Lh`08on<Lh`03o`000?oU
6^Go000000oon0Oh00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017on0Oh00?o0000onLHiooW6>L01_oW6>L00ol0003o`Sg2
ol8m`P0;ol8m`P03o`000?n2OH;oPWf200WoPWf200Co0000ogj1O_mnPGko00003?lfbCH00ol0003o
=LXeocG:=@02ocG:=@;o00002?lLha`00ol0003oAKY5o`000009odVfB@03o`000?m^TFkoKY5^00So
KY5^00?o0000ohUfROn9MXT01On9MXT00ol0003o^DJiokU6^@0=okU6^@03o`000?oS7>?ohacS00[o
hacS00?o0000ooP7n?oh1oP03_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooP7n003o`00
0?oW6>OoiaSW00CoiaSW00?o0000ol8m`_o2?L803?o2?L800ol0003oPWf2oh9mPP0:oh9mPP?o0000
3?lfbCH00ol0003o=LXeocG:=@02o`0000_o7><L00?o0000odVfBOm9]TT02?m9]TT00ol0003oKY5^
ofjAKP07ofjAKP03o`000?n9MXWoRGJ900OoRGJ900?o0000okU6^OniA[T03?niA[T00ol0003ohacS
on<Lh`0;on<Lh`;o00003_oh1oP00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003on0OhooP7n00?ooP7n0?o00000ooW
6>L00ol0003o`Sg2ol8m`P0>ol8m`P03o`000?n2OH;oPWf200SoPWf200Co0000ocg2?Olm`Sgo?L8m
0_l0000:ocK9=P?o00003OlLha`00ol0003oBKI9odVfB@08odVfB@03o`000?m^TFkoKY5^00OoKY5^
00?o0000ohUfROn9MXT01on9MXT00ol0003o^DJiokU6^@0;okU6^@03o`000?oS7>?ohacS00cohacS
00?o0000oo`3o?l000000_l0000:ooP7n003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oh1oSon0Oh00con0Oh0_l0
0003oo8=lP03o`000?oW6>Oo0000017o`Sg200?o0000oh9mP_n2OH801on2OH800ol0003o?L8mocg2
?@04ocg2?@;o00002?lfbCH00ol0003o7><LoacS700>oacS70;o00002?m9]TT00ol0003oKY5^ofjA
KP06ofjAKP03o`000?n9MXWoRGJ900WoRGJ900?o0000okU6^OniA[T02OniA[T00ol0003ohacSon<L
h`0=on<Lh`03o`000?ol0ocoo0?l00;oo0?l0ol00007ooP7n003o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oh1oSo
n0Oh00Won0Oh0_l00006oo8=lP03o`000?o2?L;o`Sg2013o`Sg200?o0000oh9mP_n2OH801_n2OH80
0ol0003o?L8mocg2?@07ocg2?@03o`000?lfbCKo=/Tf00Co=/Tf0ol0000>oacS7003o`000?lMhQgo
7N8M00?o00001Om9]TT00ol0003oKY5^ofjAKP06ofjAKP03o`000?n9MXWoRGJ900[oRGJ900?o0000
okU6^OniA[T02?niA[T00ol0003ohacSon<Lh`0=on<Lh`03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oh1oSon0Oh00Gon0Oh0ol00008oo8=lP03o`000?o2?L;o`Sg2
017o`Sg200Co0000oh9mP_n2OH;oPWf21?l0000;ocg2?@;o000000Co=/Tfo`000?l0003o00000ol;
m0/2o`0000_o7><L00?o0000oagR7OlMhQd01?lMhQd2o`0000?oBKI900?o0000ofjAK_m^TFh01_m^
TFh00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?niA[Wo^DJi00Oo^DJi00?o0000on<LhooS7><03_oS
7><00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oh1oSon0Oh00;on0Oh0_l0000<oo8=lP03o`000?o2?L;o
`Sg2013o`Sg21?l00003ogJ9MP03o`000?lm`Sgo?L8m00_o?L8m00?o0000o`_d2ol;m0/01_l;m0/0
0ol0003o7><LoacS7007oacS7003o`000?lMhQgo7N8M00Oo7N8M3?l0000>ohUfR@03o`000?niA[Wo
^DJi00Ko^DJi00?o0000on<LhooS7><03_oS7><00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooP7
n?l0003o00003_ob3O800ol0003o`Sg2ol8m`P0?ol8m`P03o`000?mfRGKoMXUf00KoMXUf00?o0000
ocg2?Olm`Sd02_lm`Sd00ol0003o2o@;o`_d2`07o`_d2`;o00001_lLha`00ol0003o7N8MoagR7@08
oagR7@03o`000?m=/TgoCK9=00SoCK9=00?o0000ohUfROn9MXT03?n9MXT00ol0003o^DJiokU6^@05
okU6^@03o`000?oS7>?ohacS00oohacS0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O803_ob3O800ol0
003o`Sg2ol8m`P0>ol8m`P03o`000?mfRGKoMXUf00OoMXUf00?o0000ocg2?Olm`Sd02_lm`Sd00ol0
003o2o@;o`_d2`09o`_d2`;o00000olLha`00ol0003o7N8MoagR7@09oagR7@03o`000?m=/TgoCK9=
00WoCK9=00?o0000ohUfROn9MXT02_n9MXT4o`0000Co^DJi00?o0000on<LhooS7><04?oS7><01?l0
003on`Cko`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo8=l_ob3O803oob3O8@o`0000[oMXUf00?o0000ocg2
?Olm`Sd02Olm`Sd00ol0003o2_D:o`00000<o`_d2`05o`000?lLhaco0000o`Gj1Ol000002_lMhQd0
0ol0003oCK9=odfbC@09odfbC@03o`000?n9MXWoRGJ900OoRGJ90ol00004ojAKY0?o000000?o^DJi
o`000?oS7><04OoS7><01?l0003on`Ckoo/4nook1?/2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003olPgboo8=lP0?
oo8=lP03o`000?nhAkSo^4Nh00co^4Nh00?o0000ogJ9M_mfRGH02OmfRGH00ol0003o?L8mocg2?@07
ocg2?@04o`000?l:m@[o2_D:o`0000go2o@;00Go0000o`Gj1Ol5nPGo1OX5o`000009oagR7@03o`00
0?m=/TgoCK9=00[oCK9=00?o0000ohUfROn9MXT00on9MXT3o`0000[oY5^T00?o0000on<LhooS7><0
4?oS7><00ol0003on`Ckoo/4n`04oo/4n`;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo8=l_ob3O803oob3O800ol0003o^4NhokQ7^00<okQ7^003o`000?mf
RGKoMXUf00WoMXUf00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003o2_D:o`[e2P02o`[e2P03o`000?l;
m0_o2o@;00[o2o@;00?o0000o`Gj1Ol5nPD00_l5nPD00ol0003o7N8MoagR7@06oagR7@03o`000?m=
/TgoCK9=00[oCK9=00?o0000ohUfROn9MXT00ol0000=ojAKY003o`000?oS7>?ohacS013ohacS00?o
0000oo/4nook1?/01_ok1?/2o`0000Woo0?l0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003olPgboo8=lP0=oo8=lP?o00003onhAkP0
0ol0003oMXUfogJ9MP08ogJ9MP03o`000?lm`Sgo?L8m00Go?L8m00?o0000o`[e2_l:m@X00ol:m@X0
0ol0003o2o@;o`_d2`0:o`_d2`03o`000?l5nPGo1OX500?o1OX500?o0000oagR7OlMhQd01OlMhQd0
0ol0003oCK9=odfbC@0;odfbC@;o00004OnTFj@00ol0003ohacSon<Lh`0?on<Lh`03o`000?ok1?_o
n`Ck00Son`Ck0_l00007oo`3o003o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003olPgboo8=lP09oo8=lPGo00000_oT6n@00ol0
003o^4NhokQ7^00=okQ7^003o`000?mfRGKoMXUf00WoMXUf00?o0000ocg2?Olm`Sd01?lm`Sd00ol0
003o2_D:o`[e2P04o`[e2P03o`000?l;m0_o2o@;00So2o@;00?o0000o`Gj1Ol5nPD01Ol5nPD00ol0
003o7N8MoagR7@04oagR7@03o`000?m=/TgoCK9=00_oCK9=00?o0000ojAKY?nTFj@04?nTFj@00ol0
003ohacSon<Lh`0?on<Lh`03o`000?ok1?_on`Ck00[on`Ck0_l00004oo`3o003o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?ob3O;olPgb00ColPgb1Ol00007on@Ki003
o`000?nhAkSo^4Nh00go^4Nh00?o0000ogJ9M_mfRGH02OmfRGH00ol0003o?L8mocg2?@03ocg2?@03
o`000?l:m@[o2_D:00Go2_D:00?o0000o`_d2ol;m0/02?l;m0/00ol0003o1OX5o`Gj1@06o`Gj1@03
o`000?lMhQgo7N8M00?o7N8M00?o0000odfbCOm=/Td02om=/Td00ol0003oY5^TojAKY00@ojAKY003
o`000?oS7>?ohacS00oohacS00?o0000oo/4nook1?/03?ok1?/2o`000003oo`3o?l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo8=l_l00000
1?l0000<on@Ki003o`000?nhAkSo^4Nh00ko^4Nh00?o0000ogJ9M_mfRGH02?mfRGH00ol0003o?L8m
ocg2?@02ocg2?@03o`000?l:m@[o2_D:00Oo2_D:00?o0000o`_d2ol;m0/01ol;m0/00ol0003o1OX5
o`Gj1@07o`Gj1@03o`000?lMhQgo7N8M00;o7N8M00?o0000odfbCOm=/Td02om=/Td00ol0003oY5^T
ojAKY00AojAKY003o`000?oS7>?ohacS00gohacS00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oi1_T00?o0000okQ7^?nhAkP03_nh
AkP00ol0003oMXUfogJ9MP09ogJ9MP04o`000?lm`Sgo?L8mo`0000[o2_D:00?o0000o`_d2ol;m0/0
1ol;m0/00ol0003o1OX5o`Gj1@08o`Gj1@05o`000?lMhQgo7N8MoagR7Ol000003Om=/Td00ol0003o
Y5^TojAKY00AojAKY0?o00003OoS7><00ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;onPGj00?o0000on@Ki?oT6n@03ooT6n@00ol0003o
^4NhokQ7^00>okQ7^003o`000?mfRGKoMXUf00SoMXUf1Ol0000;o`[e2P03o`000?l;m0_o2o@;00Ko
2o@;00?o0000o`Gj1Ol5nPD02Ol5nPD01?l0003o7N8MoagR7Ol0000=odfbC@03o`000?nTFjCoY5^T
017oY5^T00?o0000om0_d?o@;m000ol0000:on<Lh`Co00003Ook1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooX5nP03o`000?oT6nCoi1_T00koi1_T00?o0000okQ7
^?nhAkP03_nhAkP00ol0003oMXUfogJ9MP07ogJ9MP03o`000?lTfbCo9=/T00?o9=/T00?o0000o`[e
2_l:m@X02?l:m@X00ol0003o2o@;o`_d2`05o`_d2`03o`000?l5nPGo1OX500[o1OX51Ol0000<odfb
C@03o`000?nTFjCoY5^T013oY5^T00?o0000om0_d?o@;m001?o@;m03o`0000KohacS00?o0000ooT6
nOoi1_T00_oi1_T5o`0000Son`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0003oi1_Ton@Ki00=on@Ki003o`000?nhAkSo^4Nh00oo
^4Nh00?o0000ogJ9M_mfRGH01?mfRGH2o`0000Oo9=/T00?o0000o`[e2_l:m@X01ol:m@XEo`0000Go
7^4N00?o0000odfbCOm=/Td02?m=/Td3o`00013oY5^T00?o0000om0_d?o@;m002?o@;m03o`0000;o
hacS00?o0000ooT6nOoi1_T02?oi1_T5o`0000?on`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oi1_Ton@Ki00;on@Ki0Co0000
3onhAkP00ol0003oMXUfogJ9MP03ogJ9MP03o`000?lTfbCo9=/T00So9=/T00?o0000o`[e2_l:m@X0
1?l:m@X2o`0000So0?l000?o0000o`3o0?l0o`002?l0o`000ol0003o7^4NoakQ7P05oakQ7P;o0000
1_m=/Td2o`0000?oHiaS00?o0000ojAKY?nTFj@03?nTFj@00ol0003od2o@om0_d00<om0_d0;o0000
4?oi1_T3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00KonPGj00?o
0000on@Ki?oT6n@02OoT6n@00ol0003ok1?/o`000002oki1_P?o00003?nhAkP01?l0003oMXUfogJ9
M_mfRGH2o`0000co9=/T00?o0000o`[e2_l:m@X00_l:m@X00ol0003o0?l0o`3o0008o`3o0003o`00
0?l0o`3o0?l000So0?l000?o0000oakQ7_lNhAh01olNhAh00ol0003oCK9=odfbC@02odfbC@03o`00
0?mSW6?oHiaS00CoHiaS0_l0000;ojAKY003o`000?o@;m3od2o@00cod2o@00?o0000on`Ck?l00000
4_oi1_T00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00OonPGj00?o
0000on@Ki?oT6n@01_oT6n@2o`0000;ok1?/00?o0000oki1__nn@Kh00onn@Kh3o`0000[o^4Nh00?o
0000ogJ9M_l000003olTfb@01?l0003o2_D:o`000?l0000;o`3o0003o`000?l0o`3o0?l000So0?l0
00?o0000oakQ7_lNhAh02?lNhAh01?l0003oCK9=o`000?l00009of>LH`03o`000?nTFjCoY5^T00Oo
Y5^T00?o0000om0_d?o@;m003?o@;m001?l0003ok1?/on`Ck?l0000CooT6n@03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oT6nCoi1_T00Co
i1_T00?o0000on`Ck?o/4n`00oo/4n`00ol0003o_T6noki1_P05oki1_P?o00001_nhAkP4o`00013o
9=/T00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lNhAko7^4N00Wo
7^4N00?o0000of>LHomSW6<02_mSW6<2o`0000KoY5^T00?o0000om0_d?o@;m003?o@;m000ol0003o
k1?/on`Ck002on`Ck003o`000?oi1_Won@Ki00oon@Ki00?o0000ooh1o_l000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00WonPGj00Co0000on@Ki?oT6nCo
i1_T0_l00006on`Ck003o`000?nn@Kko_T6n00So_T6n0ol000000onhAkSo0000o`000004of^DJ`03
o`000?lTfbCo9=/T00go9=/T00?o0000o`3o0?l0o`003?l0o`000ol0003o0?l0o`3o0007o`3o0003
o`000?lNhAko7^4N00Wo7^4N00?o0000of>LHomSW6<03?mSW6<00ol0003oY5^TojAKY003o`0000ko
d2o@00?o0000on`Ck?o/4n`00oo/4n`00ol0003on@KiooT6n@0>ooT6n@05o`000?on0OkooP7nooh1
o_l000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00[o
nPGj00?o0000on@Ki?l000002?o/4n`00ol0003o_T6noki1_P0;oki1_P03o`000?m[U6_oJiA[00Go
JiA[00?o0000obCK9?lTfb@03?lTfb@00ol0003o0?l0o`3o000<o`3o0003o`000?l0o`3o0?l000Oo
0?l000?o0000oakQ7_lNhAh02?lNhAh2o`0000ooHiaS0_l00002ol4n`@03o`000?o@;m3od2o@00_o
d2o@00?o0000on`Ck?o/4n`01?o/4n`00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n00?o
oP7n00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000on`Ck?o/4n`0
1oo/4n`00ol0003o_T6noki1_P0;oki1_P03o`000?m[U6_oJiA[00KoJiA[00?o0000obCK9?lTfb@0
2olTfb@2o`0000go0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7^4NoakQ7P07oakQ7P04o`00
0?lbcC;o</dbo`0000koHiaS00?o0000ol4n`Oo1?/400_o1?/400ol0003od2o@om0_d009om0_d003
o`000?o/4ncok1?/00Kok1?/00?o0000ooT6nOoi1_T02ooi1_T00ol0003ooP7nooh1oP05ooh1oP04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooX5n_oj1OX02_oj1OX2o`0000Wo
k1?/00?o0000oki1__nn@Kh02onn@Kh00ol0003oJiA[of^DJ`07of^DJ`03o`000?lTfbCo9=/T00Wo
9=/T00Co0000o`Ki1_l6n@Ko00003?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lNhAko7^4N
00Ko7^4N00Go0000oc;=<_lbcC;o</dbo`00000>of>LH`03o`000?o1?/7o`Ck100?o`Ck100?o0000
om0_d?o@;m001oo@;m000ol0003ok1?/on`Ck007on`Ck003o`000?oi1_Won@Ki00[on@Ki00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oj1O[onPGj
00WonPGj00Co0000ooP7n?oh1oSo00002Oo/4n`00ol0003o_T6noki1_P09oki1_P03o`000?m[U6_o
JiA[00WoJiA[00?o0000obCK9?lTfb@01olTfb@00ol0003o1_T6o`Ki1P02o`Ki1P03o`000?l0o`3o
0?l000Wo0?l000?o0000o`3o0?l0o`001ol0o`000ol0003o7^4NoakQ7P05oakQ7P03o`000?lbcC;o
</db00?o</db00?o0000of>LHomSW6<02_mSW6<00ol0003o`Ck1ol4n`@05ol4n`@03o`000?o@;m3o
d2o@00God2o@00?o0000on`Ck?o/4n`02?o/4n`00ol0003on@KiooT6n@09ooT6n@03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000WonPGj00?o0000ooP7
n?oh1oP00_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`000?nn@Kko_T6n00Wo_T6n00?o0000of^D
Jom[U6/02_m[U6/00ol0003o9=/TobCK9005obCK9003o`000?l6n@Ko1_T600Co1_T600?o0000o`3o
0?l0o`002?l0o`000ol0003o0?l0o`3o0007o`3o0003o`000?lNhAko7^4N00Co7^4N00?o0000oc;=
<_lbcC801?lbcC800ol0003oHiaSof>LH`0:of>LH`03o`000?o1?/7o`Ck100Ko`Ck100?o0000om0_
d?o@;m000oo@;m000ol0003ok1?/on`Ck009on`Ck003o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooj1OX00ol0003o
n0OhooP7n003ooP7n003o`000?o/4ncok1?/00Kok1?/00?o0000oki1__nn@Kh02Onn@Kh00ol0003o
JiA[of^DJ`0;of^DJ`03o`000?lTfbCo9=/T00?o9=/T00?o0000o`Ki1_l6n@H01_l6n@H00ol0003o
0?l0o`3o0008o`3o0003o`000?l0o`3o0?l000Ko0?l000?o0000oakQ7_lNhAh00_lNhAh2o`0000So
</db00?o0000of>LHomSW6<02OmSW6<00ol0003o`Ck1ol4n`@07ol4n`@05o`000?o@;m3od2o@om0_
d?l000003Oo/4n`00ol0003on@KiooT6n@06ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooj1O[o0000ooP7n006ooP7n003
o`000?o/4ncok1?/00Gok1?/00?o0000oki1__nn@Kh02Onn@Kh00ol0003oJiA[of^DJ`0<of^DJ`05
o`000?lTfbCo9=/TobCK9?l000002_l6n@H00ol0003o0?l0o`3o0007o`3o0003o`000?l0o`3o0?l0
00Ko0?l000?o0000oakQ7_l000000_l000000ol?l0oo0000oc;=<P07oc;=<P03o`000?mSW6?oHiaS
00SoHiaS00?o0000ol4n`Oo1?/402Oo1?/400ol0003od2o@o`00000=on`Ck0Co00001Ooi1_T00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oh1oSon0Oh00Oon0Oh00?o0000on`Ck?o/4n`01?o/4n`00ol0003o_T6noki1_P09oki1_P03
o`000?m[U6_oJiA[00goJiA[00?o0000obCK9?l000003?l6n@H:o`0000Oo0?l00ol00005o`o`3`03
o`000?lbcC;o</db00Ko</db00?o0000of>LHomSW6<01omSW6<00ol0003o`Ck1ol4n`@0:ol4n`@03
o`000?o/4ncok1?/00_ok1?/00?o0000oo/4nook1?/00_ok1?/3o`000003ooT6nOl0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7n007ooP7n003o`00
0?o/4ncok1?/00Gok1?/00?o0000oki1__nn@Kh01onn@Kh00ol0003oJiA[of^DJ`0?of^DJ`;o0000
2ol6n@H00ol0003o1oP7o`Oh1`07o`Oh1`03o`000?l0o`3o0?l000;o0?l00ol00008o`o`3`03o`00
0?lbcC;o</db00Ko</db00?o0000of>LHomSW6<01omSW6<00ol0003o`Ck1ol4n`@0:ol4n`@03o`00
0?o/4ncok1?/00[ok1?/00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n008ooP7n003o`000?o/4ncok1?/00Cok1?/00?o0000oki1__nn@Kh01onn@Kh00ol0003oJiA[of^D
J`0>of^DJ`04o`000?l_d2oo;m0_o`0000Wo1_T600?o0000o`Oh1ol7n0L02Ol7n0L01?l0003o0?l0
o`000?l0000<o`o`3`03o`000?lbcC;o</db00Ko</db00?o0000of>LHomSW6<01_mSW6<00ol0003o
`Ck1ol4n`@0;ol4n`@03o`000?o/4ncok1?/00Ook1?/0_l00009oo/4n`03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oh1oSon0Oh00Son0Oh00?o0000on`Ck?o/4n`00oo/4n`>o`0000goJiA[00?o0000obo@;ol_d2l0
0_l_d2l00ol0003o1_T6o`Ki1P05o`Ki1P03o`000?l7n0Oo1oP700_o1oP700?o0000o`o`3ol?l0l0
3?l?l0l00ol0003o</dboc;=<P06oc;=<P03o`000?mSW6?oHiaS00GoHiaS00?o0000ol4n`Oo1?/40
3?o1?/400ol0003ok1?/on`Ck006on`Ck003o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP01Ol0003ok1?/on`Ck?o/4nco000000_obSG:00?o0000offBKOm]TVd00ol00009of^DJ`03o`00
0?l_d2oo;m0_00Co;m0_00?o0000o`Ki1_l6n@H00ol6n@H00ol0003o1oP7o`Oh1`0<o`Oh1`03o`00
0?l?l0oo3o0?00go3o0?00?o0000oc;=<_lbcC801_lbcC800ol0003oHiaSof>LH`03of>LH`?o0000
3Oo1?/400ol0003ok1?/on`Ck005on`Ck003o`000?ok1?_on`Ck00con`Ck0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooP7n?oh1oP02?oh
1oP4o`0000cobSG:00?o0000offBKOm]TVd00om]TVd3o`0000GoJiA[00?o0000obo@;ol_d2l01_l_
d2l01Ol0003o1_T6o`Ki1_l6n@Ko000000oo1oP700?o0000o`o`3ol?l0l03Ol?l0l00ol0003o</db
oc;=<P06oc;=<P03o`000?mSW6?oHiaS00?o00000on1OX400ol0003o`Ck1ol4n`@0;ol4n`@03o`00
0?o/4ncok1?/00?ok1?/00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon0Oh0ol0
0003oo<<l`03o`000?o:=L[obSG:00[obSG:00?o0000offBKOm]TVd01_m]TVd3o`000003of^DJol0
003o;m0_00Wo;m0_00?o0000o`Ki1_l000004?l7n0L00ol0003o3o0?o`o`3`0=o`o`3`03o`000?lb
cC;o</db00Oo</db0_l00007oh5nP@03o`000?o1?/7o`Ck100[o`Ck100Co0000on`Ck?o/4ncok1?/
0ol0000?oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003on`Ckoo/4nook1?/2o`000004ooP7n?l0003o0000o`0000Kol`cc00?o0000olXeb_o:
=LX02_o:=LX00ol0003oKI9]offBK@09offBK@03o`000?l_d2oo;m0_00[o;m0_00?o0000o`Oh1ol7
n0L03ol7n0L00ol0003o3o0?o`o`3`0>o`o`3`03o`000?lbcC;o</db00Ko</db00?o0000oh5nPOn1
OX401on1OX44o`0000So`Ck100Co0000on`Ck?o/4nco00000ood2o@2o`0000gon`Ck00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
n`Ckoo/4n`04oo/4n`03o`000?oc3??ol`cc00Ool`cc00?o0000olXeb_o:=LX02Oo:=LX00ol0003o
KI9]offBK@0:offBK@03o`000?l_d2oo;m0_00[o;m0_00?o0000o`Oh1ol7n0L03ol7n0L00ol0003o
3o0?o`o`3`0>o`o`3`03o`000?lbcC;o</db00Go</db00?o0000oh5nPOn1OX402?n1OX401?l0003o
b3O8olPgb?o8=lP7o`0000;o`Ck10_l00006oo@;m0;o00003?ok1?/00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<02?oc3?<00ol0003obSG:olXebP08olXebP03o`000?m]TVgoKI9]00[o
KI9]00?o0000obo@;ol_d2l02ol_d2l00ol0003o1oP7o`Oh1`0>o`Oh1`03o`000?l?l0oo3o0?00ko
3o0?1Ol00002oc;=<P03o`000?n1OX7oPGj100WoPGj100?o0000olPgb?o8=lP02?o8=lP3o`0000Wo
m0_d0_l0000:oo/4n`03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`07oo<<l`03o`00
0?o:=L[obSG:00SobSG:00?o0000offBKOm]TVd02_m]TVd00ol0003o;m0_obo@;`0:obo@;`;o0000
3_l7n0L3o`0000go3o0?0ol00005od6n@@;o00002on1OX400ol0003ob3O8olPgb00;olPgb0;o0000
2_od2o@2o`0000Oon`Ck0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo/4n`03o`00
0?oc3??ol`cc00Ool`cc00?o0000olXeb_o:=LX02?o:=LX>o`0000Wo;m0_0ol000000olVfBKo0000
o`Oh1`0:o`Oh1`?o00000_lIiQT00ol0003o3o0?o`o`3`09o`o`3`;o00002Om1_T400ol0003oPGj1
oh5nP@09oh5nP@03o`000?o8=lSob3O800_ob3O800?o0000omlOgol000002ood2o@2o`0000Con`Ck
00Co0000oo`3o?ol0ocoo0?l0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003on`Ck
oo/4n`09oo/4n`03o`000?oc3??ol`cc00Kol`cc00?o0000olXeb_o:=LX02?o:=LX00ol0003oK9=/
ofbCK00:ofbCK003o`000?l_d2oo;m0_00Co;m0_0ol00005obKI9P03o`000?l7n0Oo1oP700Co1oP7
1?l00006oaWV6@03o`000?l?l0oo3o0?00Ko3o0?0_l0000;od6n@@03o`000?n1OX7oPGj100WoPGj1
00?o0000olPgb?o8=lP02_o8=lP01Ol0003ogaoOomlOgooO7moo000000com0_d0_l000000ook1?_o
0000oo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Son`Ck00?o0000oo<<looc3?<01_oc3?<00ol0003obSG:olXebP07olXebP03o`00
0?m/TfcoK9=/00_oK9=/00?o0000obo@;ol_d2l00_l_d2l2o`0000Wo9]TV00?o0000o`Oh1ol7n0L0
0ol0000;oaWV6@03o`000?l?l0oo3o0?00;o3o0?0ol0000>od6n@@03o`000?n1OX7oPGj100OoPGj1
00?o0000olPgb?o8=lP02oo8=lP00ol0003ogaoOomlOg`02omlOg`03o`000?od2oCom0_d00_om0_d
00?o0000oo`3o?ol0o`01_ol0o`2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok
1?_on`Ck00Oon`Ck00?o0000oo<<looc3?<01ooc3?<00ol0003obSG:olXebP05olXebP?o00003Om/
Tf`4o`0000_o9]TV0ol0000?oaWV6@04o`000?l?l0oo0000o`00017o@Ki100?o0000oh5nPOn1OX40
1on1OX400ol0003ob3O8olPgb00:olPgb003o`000?oO7moogaoO00CogaoO00?o0000oo@;m?od2o@0
1ood2o@3o`0000_oo0?l1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ol`ccoo<<
l`06oo<<l`03o`000?o:=L[obSG:00;obSG:0ol00003oj]DZ`03o`000?m/TfcoK9=/00[oK9=/00?o
0000obKI9_lVfBH02olVfBH00ol0003o8MhQo`00000AoaWV6@03o`000?m1_T7o@Ki1017o@Ki100?o
0000oh5nPOn1OX401on1OX400ol0003ob3O8olPgb00:olPgb003o`000?oO7moogaoO00GogaoO00Co
0000oo@;m?od2oCom0_d1Ol00002ooL8m`03o`000?ol0ocoo0?l00Woo0?l00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook1?/00ol0003ol`ccoo<<l`05oo<<l`?o0000
00?obSG:o`000?l000001on[E:/00ol0003oK9=/ofbCK008ofbCK0?o00002_lVfBH2o`0000;o8MhQ
00?o0000oaWV6OlIiQT03olIiQT00ol0003o@Ki1od6n@@0Aod6n@@03o`000?n1OX7oPGj100OoPGj1
00?o0000olPgb?o8=lP02Oo8=lP00ol0003ogaoOomlOg`07omlOg`?o00001oog2?L00ol0003oo0?l
oo`3o009oo`3o003o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo/4nook1?/01ook
1?/4o`0000;ol`cc0_l00003on`Ck003o`000?n[E:_oZeB[00SoZeB[0_l00006ofbCK0;o00000omJ
YEX00ol0003o9]TVobKI9P06obKI9P03o`000?lQgR7o8MhQ00?o8MhQ00?o0000oaWV6OlIiQT03_lI
iQT00ol0003o@Ki1od6n@@0Bod6n@@03o`000?n1OX7oPGj100GoPGj100?o0000olPgb?o8=lP02Oo8
=lP00ol0003ogaoOomlOg`08omlOg`03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol
0o`00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00Con`Ck0_l00004
ooX5nP;o00001Oo/4n`00ol0003oZeB[oj]DZ`0:oj]DZ`03o`000?m/TfcoK9=/00;oK9=/00?o0000
oeZUF_mJYEX01?mJYEX00ol0003o9]TVobKI9P04obKI9P03o`000?lQgR7o8MhQ00Co8MhQ00?o0000
oaWV6OlIiQT03_lIiQT00ol0003o@Ki1od6n@@0Bod6n@@[o00002_o8=lP00ol0003ogaoOomlOg`08
omlOg`03o`000?og2?Oom`Sg00Oom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003on`Ckoo/4nook1?/2o`0000OonPGj00?o0000on`Ck?o/4n`01?o/4n`0
0ol0003oZeB[oj]DZ`0:oj]DZ`04o`000?m/Tfco0000o`0000SoFZEJ00Co0000obKI9_lVfBKo9]TV
0_l00007ob7N8@03o`000?lIiQWo6NHI00ko6NHI00?o0000od6n@Om1_T404_m1_T400ol0003oWf2O
oimPW`07oimPW`03o`000?o8=lSob3O800Kob3O800?o0000omlOgooO7ml02_oO7ml00ol0003om`Sg
ooL8m`06ooL8m`03o`000?ol0ocoo0?l00Soo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ok
1?_o0000o`0000WonPGj00?o0000on`Ck?o/4n`01?o/4n`00ol0003oZeB[oj]DZ`0;oj]DZ`03o`00
0?mJYE[oFZEJ00WoFZEJ00?o0000obKI9_l000002OlQgR400ol0003o6NHIoaWV6@0>oaWV6@;o0000
4_m1_T400ol0003oWf2OoimPW`09oimPW`;o00001_o8=lP00ol0003ogaoOomlOg`0:omlOg`03o`00
0?og2?Oom`Sg00Kom`Sg00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000ooX5n_oj1OX02Ooj1OX00ol0003ok1?/on`Ck005on`Ck003o`000?n[E:_oZeB[00[oZeB[00?o
0000oeZUF_mJYEX02_mJYEX2o`0000Wo8MhQ00?o0000oaWV6OlIiQT03_lIiQT00ol0003o=/Tfo`00
0002o`0000oo@Ki100?o0000oimPWonOH9l02onOH9l00ol0003ob3O8olPgb003o`0000gogaoO00?o
0000ooL8moog2?L01_og2?L00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003onPGjooX5nP09ooX5nP03o`000?o/4ncok1?/00Gok1?/00?o0000oj]DZon[E:/02On[E:/2
o`0000_oFZEJ0_l0000;ob7N8@03o`000?lIiQWo6NHI00co6NHI00?o0000ocK9=_lfbCH00olfbCH3
o`0000co@Ki100?o0000oimPWonOH9l03?nOH9l2o`0000;ogR7N00?o0000omlOgooO7ml03?oO7ml0
0ol0003om`SgooL8m`05ooL8m`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00[onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oZeB[oj]DZ`07oj]D
Z`03o`000?n^DJko000000[oFZEJ00Co0000oe2_D?m@[e3o00002_lQgR400ol0003o6NHIoaWV6@0<
oaWV6@03o`000?lfbCKo=/Tf00Ko=/Tf0_l00008od6n@@;o00003onOH9l00ol0003ogR7NomhQgP02
omhQgP03o`000?oO7moogaoO00_ogaoO00?o0000ooL8moog2?L01Oog2?L00ol0003oo0?loo`3o007
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o/4ncok1?/
00Kok1?/00?o0000oj]DZon[E:/01_n[E:/01Ol0003o[U6^ojiA[_n^DJko000000SoFZEJ00?o0000
oe2_D?m@[e000_m@[e000ol0003o8MhQob7N8@06ob7N8@Co00003?lIiQT00ol0003o=/TfocK9=P08
ocK9=P?o00000_m1_T43o`000003ogmoOol0003oWf2O00goWf2O00?o0000omhQg_oN8Mh01?oN8Mh0
0ol0003ogaoOomlOg`0:omlOg`03o`000?og2?Oom`Sg00Gom`Sg00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ok1?/on`Ck007on`C
k003o`000?n[E:_oZeB[00?oZeB[0_l00005ojiA[P03o`000?mJYE[oFZEJ00CoFZEJ00?o0000oe2_
D?m@[e000om@[e000ol0003o8MhQob7N8@05ob7N8@03o`000?lJiA[o6^DJ00;o6^DJ0ol00007oaWV
6@;o00003_lfbCH2o`0000GoOgmo00?o0000oimPWonOH9l02_nOH9l00ol0003ogR7NomhQgP05omhQ
gP03o`000?oO7moogaoO00_ogaoO00?o0000ooL8moog2?L01?og2?L00ol0003oo0?loo`3o006oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?o/4ncok1?/00Oo
k1?/00?o0000oj]DZon[E:/00_n[E:/00ol0003o[U6^ojiA[P06ojiA[P03o`000?mJYE[oFZEJ00;o
FZEJ00?o0000oe2_D?m@[e001Om@[e000ol0003o8MhQob7N8@02ob7N8@;o00002?lJiAX3o`0000;o
6NHI0_l000000olMhQgo0000ocK9=P0=ocK9=P03o`000?moOgooOgmo00GoOgmo00?o0000oimPWonO
H9l02?nOH9l00ol0003ogR7NomhQgP07omhQgP03o`000?oO7moogaoO00[ogaoO00?o0000ooL8moog
2?L01?og2?L00ol0003oo0?loo`3o006oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003onPGj
ooX5nP0<ooX5nP03o`000?o/4ncok1?/00Sok1?/00Co0000oj]DZon[E:_o00002On^DJh01Ol0003o
FZEJoeZUF_mJYE[o000000SoD:m@00Go0000ob7N8OlQgR7o8MhQo`00000=oa[U6P;o00001?lMhQd0
0ol0003o=/TfocK9=P0;ocK9=P03o`000?moOgooOgmo00KoOgmo00?o0000oimPWonOH9l01onOH9l0
0ol0003ogR7NomhQgP08omhQgPCo00002?oO7ml00ol0003om`SgooL8m`04ooL8m`03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oj1O[onPGj00_onPGj0ol00009on`C
k003o`000?n[E:_o000000_o[U6^00?o0000oeZUF_l000002_m@[e000ol0003o8MhQo`00000?oa[U
6P03o`000?lMhQgo7N8M00;o7N8M00?o0000ocK9=_lfbCH02olfbCH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nOH9ooWf2O00KoWf2O00?o0000omhQg_oN8Mh02OoN8Mh01?l0003oka3_onl@koo_4>l7
o`0000;ogaoO00?o0000ooL8moog2?L00oog2?L00ol0003oo0?loo`3o005oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?oj1O[onPGj00SonPGj0ol00003ooX5nP03o`000?o/4ncok1?/00Ook1?/00?o0000ojiA
[_n^DJh02on^DJh00ol0003oD:m@oe2_D00:oe2_D003o`000?lJiA[o6^DJ00go6^DJ00?o0000oagR
7OlMhQd01?lMhQd00ol0003o=/TfocK9=P09ocK9=P03o`000?moOgooOgmo00SoOgmo00?o0000oimP
WonOH9l00onOH9l2o`0000cogR7N00?o0000onl@koo_4>l02?o_4>l<o`0000?oo0?l0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000ooX5n_oj1OX01_oj1OX3o`0000OonPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003o
[U6^ojiA[P0;ojiA[P03o`000?m@[e3oD:m@00WoD:m@0_l0000>oa[U6P03o`000?lMhQgo7N8M00Go
7N8M00?o0000ocK9=_lfbCH02OlfbCH00ol0003oOgmoogmoO`09ogmoO`03o`000?nOH9oo000000;o
00000_oC;=<00ol0003ogR7NomhQgP08omhQgP03o`000?o_4>ooka3_00coka3_00?o0000ooT6nOoi
1_T01_oi1_T3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003onPGjooX5nP03ooX5nP?o00002ooj1OX00ol0003ok1?/
on`Ck004on`Ck003o`000?n^DJko[U6^00_o[U6^0ol00007oe2_D0?o000000?o><Lho`000?lJiAX0
3OlJiAX00ol0003o7N8MoagR7@06oagR7@03o`000?lfbCKo=/Tf00So=/Tf00?o0000ogmoOomoOgl0
2_moOgl00ol0003odbcCom</d`04om</d`03o`000?oN8MkogR7N00OogR7N00?o0000onl@koo_4>l0
2oo_4>l00ol0003on@KiooT6n@08ooT6n@03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004ooX5n_l0
003o0000o`0000oonPGj00?o0000on`Ck?o/4n`00oo/4n`>o`0000?oV6NH0_l00002oe2_D0?o0000
1OlhacP00ol0003o6^DJoa[U6P0:oa[U6P03o`000?lMhQgo7N8M00Oo7N8M00?o0000ocK9=_lfbCH0
2?lfbCH00ol0003oOgmoogmoO`0:ogmoO`03o`000?oC;=?odbcC00GodbcC00?o0000omhQg_oN8Mh0
1_oN8Mh00ol0003oka3_onl@k`0;onl@k`03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;onPGj00?o0000on`Ck?o/4n`00_o/4n`00ol0003ogb3OomlP
g`0:omlPg`03o`000?nHIiSoV6NH00?oV6NH0_l00009ocS7>003o`000?lJiA[o6^DJ00Wo6^DJ00?o
0000oagR7OlMhQd02?lMhQd2o`0000So=/Tf00?o0000ogmoOomoOgl02OmoOgl00ol0003odbcCom</
d`07om</d`03o`000?oN8MkogR7N00CogR7N00?o0000onl@koo_4>l02oo_4>l00ol0003on@KiooT6
n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o000000?ok1?/
o`000?oO8=l02ooO8=l00ol0003oV6NHoiQWV004oiQWV003o`000?lhacSo><Lh00Wo><Lh00?o0000
oa[U6_lJiAX01olJiAX00ol0003o7N8MoagR7@09oagR7@04o`000?ln`Cko0000o`0000Ko=/Tf00?o
0000ogmoOomoOgl02OmoOgl00ol0003odbcCom</d`08om</d`03o`000?oN8MkogR7N00?ogR7N00?o
0000onl@koo_4>l02oo_4>l00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00000ooi1_T2o`0000cogb3O00?o0000oiQWV?nHIiP01?nHIiP0
0ol0003o><LhocS7>00:ocS7>0Wo00002olMhQd00ol0003o?/4nock1?P02ock1?P?o00000_lfbCH0
0ol0003oOgmoogmoO`0:ogmoO`03o`000?oC;=?odbcC00WodbcC00?o0000omhQg_oN8Mh00_oN8Mh0
0ol0003oka3_onl@k`0:onl@k`03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_oj1OX2o`0000Gon@Ki00?o0000on`Ck?l000002_oO8=l00ol0003oV6NHoiQWV006oiQW
V003o`000?lhacSo><Lh00Wo><Lh00?o0000ob?L8olSg2<01OlSg2<00ol0003o7N8MoagR7@09oagR
7@03o`000?ln`Cko?/4n00Go?/4n0ol00009ogmoO`?o00003OoC;=<01Ol0003ogR7NomhQg_oN8Mko
000000coka3_00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX01Ooj1OX2o`0000Oon@Ki00Co0000on`Ck?o/4nco00002OoO8=l00ol0003oV6NHoiQWV006
oiQWV003o`000?lhacSo><Lh00So><Lh00?o0000ob?L8olSg2<01olSg2<00ol0003o7N8MoagR7@07
oagR7@03o`000?ln`Cko?/4n00So?/4n0ol00002ogmoO`Go00000_nm@[d00ol0003odbcCom</d`0<
om</d`03o`000?oN8Mko000000coka3_00?o0000ooT6nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000ooX5n_oj1OX00_oj1OX2o`0000Son@Ki00?o0000on`Ck?o/4n`00_o/4n`5o`00
00Cogb3O00?o0000oiQWV?nHIiP01_nHIiP00ol0003o><LhocS7>008ocS7>003o`000?lSg2?o8m`S
00Oo8m`S00?o0000oagR7OlMhQd01olMhQd00ol0003o?/4nock1?P08ock1?P03o`000?n6NHKoQWV6
00;o00002?nm@[d00ol0003odbcCom</d`0<om</d`Co00002_o_4>l00ol0003on@KiooT6n@0:ooT6
n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003onPGjo`000?l0000:ooT6n@03o`000?o/4ncok1?/
00;ok1?/00?o0000olLhaoo7><L00_o7><L4o`0000WoV6NH00?o0000ocS7>?lhacP02?lhacP00ol0
003o8m`Sob?L8`08ob?L8`03o`000?lMhQgo7N8M00Go7N8M00?o0000ock1?_ln`Ch02?ln`Ch01Ol0
003oQWV6ohIiQ_n6NHKo000000[o_D:m0ol0000;om</d`04o`000?oe2_Gom@[eooD:m@Co00001Oo_
4>l00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o/4ncok1?/00?ok1?/00?o0000olLhaoo7><L01?o7><L00ol0003oV6NHoiQWV007
oiQWV003o`000?lhacSo><Lh00Ko><Lh0_l0000;ob?L8`03o`000?lMhQgo7N8M00Go7N8M00?o0000
ock1?_ln`Ch02?ln`Ch00ol0003oQWV6ohIiQP02ohIiQP03o`000?nm@[go_D:m00Oo_D:m00?o0000
onPGj?oX5nP01?l00006om</d`03o`000?oe2_Gom@[e00Kom@[e0ol00002onl@k`03o`000?oi1_Wo
n@Ki00_on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000on`C
k?o/4n`01?o/4n`00ol0003oacS7olLha`05olLha`03o`000?nHIiSoV6NH00OoV6NH00?o0000ocS7
>?lhacP00_lhacP3o`000003oe6^DOl0003o8m`S00[o8m`S00?o0000oagR7OlMhQd01OlMhQd00ol0
003o?/4nock1?P07ock1?P03o`000?n6NHKoQWV600?oQWV600?o0000oke2_Onm@[d01onm@[d00ol0
003oj1OXonPGj004onPGj0?o00000_oC;=<00ol0003om@[eooD:m@0:ooD:m@;o00003_oi1_T00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003ok1?/on`Ck004on`Ck003
o`000?o7><OoacS700KoacS70_l00007oiQWV003o`000?lhacSo000000;o00001OmA[U400ol0003o
8m`Sob?L8`08ob?L8`?o00001?lMhQd00ol0003o?/4nock1?P08ock1?P03o`000?n6NHKoQWV600Co
QWV600?o0000oke2_Onm@[d01_nm@[d00ol0003oj1OXonPGj007onPGj0;o00003_oe2_D00ol0003o
n@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o/4ncok1?/00Gok1?/00?o0000olLhaoo7><L01?o7><L00ol0003obSG:olXebP03o`0000CoV6NH
0_l00008oe6^D@03o`000?lSg2?o8m`S00Oo8m`S00Co0000odFjAOm5^TGoAKY50ol000000olMhQgo
0000ock1?P09ock1?P03o`000?n6NHKoQWV600CoQWV600?o0000oke2_Onm@[d01Onm@[d00ol0003o
j1OXonPGj009onPGj003o`000?oe2_Gom@[e00gom@[e00?o0000ooT6nOoi1_T02_oi1_T00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003ok1?/on`Ck006on`Ck003o`00
0?o7><OoacS700?oacS700?o0000olXeb_o:=LX01?o:=LX2o`000003oiQWV?l0003oDJiA00[oDJiA
00?o0000ob?L8olSg2<01OlSg2<00ol0003oAKY5odFjA@05odFjA@03o`000?ln`Cko?/4n00Oo?/4n
0ol00007ohIiQP03o`000?nm@[go_D:m00Co_D:m00?o0000onPGj?oX5nP02OoX5nP00ol0003om@[e
ooD:m@0=ooD:m@03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009on`Ck005o`000?o7><OoacS7olLhaol000002Oo:=LX00ol0003oDJiA
oe6^D@0;oe6^D@03o`000?lSg2?o8m`S00?o8m`S00?o0000odFjAOm5^TD01_m5^TD00ol0003o?/4n
ock1?P06ock1?P05o`000?mnPGkoOX5nogj1O_l000001on6NHH00ol0003o_D:moke2_@03oke2_@03
o`000?oX5nSoj1OX00Woj1OX00?o0000ooD:mOoe2_D03_oe2_D00ol0003on@KiooT6n@09ooT6n@03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;on`Ck00?o0000on`Ck?o/4n`0
1oo/4n`01?l0003oacS7olLhaol00009olXebP;o00003OmA[U400ol0003o8m`Sob?L8`02ob?L8`03
o`000?m5^TGoAKY500SoAKY500?o0000ock1?_ln`Ch00oln`Ch2o`0000GoOX5n00?o0000ohIiQ_n6
NHH01?n6NHH00ol0003o_D:moke2_@03oke2_@03o`000?oX5nSoj1OX00Woj1OX00?o0000ooD:mOoe
2_D03_oe2_D00ol0003on@KiooT6n@09ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Son`Ck
00?o0000on`Ck?o/4n`01_o/4n`00ol0003oacS7o`000009olXebP04o`000?nUFZGoYEZUo`0000go
DJiA00Co0000ob?L8olSg2?o00003?m5^TD01Ol0003o?/4nock1?_ln`Cko000000SoOX5n0_l00005
ohIiQP03o`000?nm@[go_D:m00;o_D:m00?o0000onPGj?oX5nP02OoX5nP00ol0003om@[eooD:m@0>
ooD:m@03o`000?oi1_Won@Ki00Won@Ki00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck
00Oon`Ck00?o0000on`Ck?o/4n`01oo/4n`00ol0003obSG:olXebP07olXebP03o`000?nUFZGoYEZU
00;oYEZU00?o0000oe6^DOmA[U402_mA[U400ol0003o8m`So`00000>odFjA@03o`000?ln`Cko0000
00_oOX5n00?o0000ohIiQ_n6NHH00_n6NHH01Ol0003o_D:moke2_Onm@[go000000coj1OX00?o0000
ooD:mOoe2_D03_oe2_D3o`0000Won@Ki00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000on`Ck?o/4n`01_o/4n`00ol0003obSG:olXebP06olXebP03o`000?nUFZGoYEZU
00?oYEZU00?o0000oe6^DOmA[U402omA[U400ol0003oAKY5odFjA@0>odFjA@03o`000?mnPGkoOX5n
00_oOX5n0_l00003ohIiQP04o`000?nm@[go_D:mo`0000[oj1OX0ol0000>ooD:m@;o00000oon0Oh2
o`0000Oon@Ki00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000on`C
k?o/4n`01?o/4n`00ol0003obSG:olXebP06olXebP03o`000?nUFZGoYEZU00GoYEZU00?o0000oe6^
DOmA[U401omA[U43o`00017oAKY500?o0000ogj1O_mnPGh03OmnPGh01Ol0003oQWV6ohIiQ_l0003o
_D:m00Co00000ooX5nP5o`0000;onPGj00?o0000ooD:mOoe2_D02_oe2_D2o`0000OooP7n0_l00004
ooT6n@03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o/4ncok1?/
00Cok1?/00?o0000olXeb_o:=LX01Oo:=LX00ol0003oYEZUojEJY@06ojEJY@03o`000?mA[U7oDJiA
00CoDJiA0ol00002oeVVF@03o`000?m5^TGoAKY500ooAKY50_l0000?ogj1OP04o`000?n6NHKo0000
o`0000Cog2?L0ol00008ooX5nP03o`000?oe2_Gom@[e00Oom@[e0_l0000;ooh1oP;o00000_oi1_T0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo/4nook1?/03?ok1?/6o`0000OobSG:00?o0000ojEJ
YOnUFZD02?nUFZD00ol0003oDJiAoe6^D@03o`0000KoFJII00?o0000odFjAOm5^TD03Om5^TD01?l0
003oQ7^4ohAkQ?l0000?ogj1OP03o`000?oL8mcog2?L00Gog2?L00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003om@[eooD:m@05ooD:m@03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ok1?/00ol0003okQ7^onhAkP04onhA
kP03o`000?o:=L[obSG:00?obSG:00?o0000ojEJYOnUFZD02_nUFZD2o`0000[oFJII00?o0000odFj
AOm5^TD02om5^TD00ol0003oQ7^4ohAkQ002ohAkQ003o`000?mnPGkoOX5n00_oOX5n0_l00007om`S
g003o`000?oj1O[onPGj00WonPGj00?o0000ooD:mOoe2_D00_oe2_D2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP06onhAkP05o`000?o:=L[obSG:olXe
b_l000003OnUFZD00ol0003oFJIIoeVVF@0:oeVVF@03o`000?m5^TGoAKY500WoAKY500?o0000ohAk
Q?n4Nh@01?n4Nh@00ol0003oOX5nogj1OP08ogj1OP;o000000?o[E:]o`000?oL8m`01ooL8m`00ol0
003onPGjooX5nP09ooX5nP04o`000?oe2_Go0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00?o0000onhAk_o^4Nh02?o^4Nh00ol0003obSG:o`00000=ojEJY@03o`000?mIYUWoFJII
00_oFJII00?o0000odFjAOm5^TD02?m5^TD00ol0003oQ7^4ohAkQ006ohAkQ003o`000?mnPGkoOX5n
00GoOX5n0_l00003ojeB[@03o`000?oL8mcog2?L00Kog2?L00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?o^4NkokQ7^00[okQ7^00?o0000ojEJYOnU
FZD03?nUFZD00ol0003oFJIIoeVVF@0<oeVVF@03o`000?m5^TGoAKY500KoAKY500?o0000ohAkQ?n4
Nh@02?n4Nh@00ol0003oOX5nogj1OP02ogj1OP;o00001_n]DZd00ol0003og2?Lom`Sg005om`Sg003
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck00Gon`Ck
00?o0000onhAk_o^4Nh03?o^4Nh2o`0000coYEZU00?o0000oeVVFOmIYUT03OmIYUT00ol0003oAKY5
odFjA@04odFjA@03o`000?n4NhCoQ7^400[oQ7^400Co0000ogj1O_l0003o00002?n]DZd00ol0003o
g2?Lom`Sg006om`Sg003o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ok1?/00ol0003okQ7^onhAkP0=onhAkP03o`000?o><Lko000000;o00002?nUFZD00ol0003oFJII
oeVVF@0?oeVVF@Ko00003_n4Nh@00ol0003o[E:]ojeB[@08ojeB[@03o`000?oL8mcog2?L00Kog2?L
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?onhAkP03o`000?o><LkocS7>00?ocS7>0ol00005ojEJY@;o00004?mIYUT01_l0003oKI9]
offBKOl0003oIIYUo`0000koQ7^400?o0000ojeB[On]DZd02On]DZd00ol0003og2?Lom`Sg005om`S
g003o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
kQ7^onhAkP0=onhAkP03o`000?o><LkocS7>00KocS7>0ol000001?nUFZGo0000ohUfROn9MXT3o`00
00coFJII00Go0000offBKOm]TVgoKI9]o`000002ofFJI@03o`000?n4NhCoQ7^400_oQ7^400?o0000
ojeB[On]DZd02On]DZd00ol0003og2?Lom`Sg006om`Sg003o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?o><Lh00ol0003oRGJ9ohUfR@04ohUf
R@?o00002?mIYUT00ol0003oKI9]offBK@02offBK@05o`000?mUVVGoIIYUofFJIOl000003?n4Nh@0
0ol0003o[E:]ojeB[@09ojeB[@03o`000?oL8mcog2?L00Gog2?L3?l00002ood2o@;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000olha
c_o><Lh02_o><Lh00ol0003oRGJ9ohUfR@07ohUfR@;o00001OmIYUT00ol0003oKI9]offBK@03offB
K@03o`000?mUVVGoIIYU00;oIIYU00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o[E:]ojeB[@0:ojeB
[@03o`000?oL8mcog2?L00?og2?L00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@02ood2
o@;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000olhac_o><Lh02oo><Lh00ol0003oRGJ9ohUfR@09ohUfR@?o000000?oFJIIo`000?m]
TVd01Om]TVd00ol0003oIIYUofFJI@03ofFJI@03o`000?n4NhCoQ7^400SoQ7^43_l00003om`Sg0;o
00002oof2OH00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om0_do`00000;oo0?l003o`000?o><LkocS7>00[ocS7>
0_l0000>ohUfR@03o`000?m]TVgoKI9]00GoKI9]00?o0000ofFJIOmUVVD00omUVVD00ol0003oQ7^4
ohAkQ008ohAkQ003o`000?oM8]gogB;M00_ogB;M00?o0000om`Sg?l000003Oof2OH00ol0003oo@;m
ood2o@06ood2o@;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000oo@;m?od2oCo00002_o`3o000ol0003ocS7>olhacP09olhacP03o`000?njAK[o000000koRGJ9
00?o0000offBKOm]TVd01Om]TVd00ol0003oIIYUofFJI@04ofFJI@03o`000?n4NhCoQ7^400KoQ7^4
00?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@00_od
2o@00ol0003ol0o`oo0?l006oo0?l003o`000?o><LkocS7>00SocS7>0_l00003okY5^P03o`000?n9
MXWoRGJ900_oRGJ900?o0000offBKOm]TVd01Om]TVd00ol0003oIIYUofFJI@05ofFJI@03o`000?n4
NhCoQ7^400GoQ7^400?o0000omdRgOoM8]d03OoM8]d00ol0003omPWfooH9mP0;ooH9mP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
oo@;m?od2o@00ood2o@00ol0003ol0o`oo0?l005oo0?l003o`000?o><LkocS7>00OocS7>00?o0000
okY5^_njAKX00onjAKX00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?m]TVgoKI9]00KoKI9]00?o0000
ofFJIOmUVVD01_mUVVD00ol0003oQ7^4ohAkQ004ohAkQ003o`000?oM8]gogB;M00gogB;M3ol0000;
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01Ood2o@00ol0
003ol0o`oo0?l004oo0?l003o`000?o><LkocS7>00GocS7>0_l00006okY5^P03o`000?n9MXWoRGJ9
00WoRGJ90_l00008offBK@03o`000?mUVVGoIIYU00KoIIYU1Ol000000on4NhCo0000omdRg@0?omdR
g@03o`000?og2?Oom`Sg00_om`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003o
l0o`oo0?l004o`0000KocS7>00?o0000okY5^_njAKX01onjAKX00ol0003oRGJ9ohUfR@05ohUfR@?o
000000?oRGJ9o`000?m]TVd01om]TVd00ol0003oIIYUofFJI@05ofFJI@03o`000?nSG:?oXebS00?o
XebS0_l0000?omdRg@;o00003Oog2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000oo@;m?od2o@01ood2o@2o`0000Coi1_T00Co0000olhac_o><Lko
cS7>0_l0000:okY5^P03o`000?n9MXWoRGJ900;oRGJ90ol00005ohUfR@03o`000?m]TVgoKI9]00Go
KI9]00?o0000ofFJIOmUVVD01?mUVVD00ol0003oXebSoj=LX`06oj=LX`03o`000?oM8]gogB;M00[o
gB;M0_l00002oo4>l@03o`000?og2?Oom`Sg00[om`Sg00?o0000ood2oOom0_d02?om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om0_doo@;m008oo@;m003o`00
0?oT6nCoi1_T00Coi1_T00?o0000olhac_l000003?njAKX00ol0003oRGJ9o`000002o`0000WoRGJ9
00?o0000offBKOm]TVd01?m]TVd00ol0003oIIYUofFJI@03ofFJI@03o`000?nSG:?oXebS00SoXebS
1_l00004omdRg@;o00001Ooa3_400ol0003om`SgooL8m`09ooL8m`03o`000?om0_goo@;m00Soo@;m
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo@;m?od2o@01ood
2o@00ol0003oi1_Ton@Ki006on@Ki003o`000?njAK[o^TFj00co^TFj00?o0000ohUfROn9MXT02_n9
MXT00ol0003oKI9]offBK@04offBK@04o`000?mUVVGoIIYUofFJI@;o00002onSG:<00ol0003ohacS
on<Lh`03on<Lh`Co00002?oa3_400ol0003om`SgooL8m`08ooL8m`03o`000?om0_goo@;m00Ooo@;m
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om0_doo@;m007oo@;m003o`000?oT
6nCoi1_T00Ooi1_T00?o0000okY5^_njAKX03?njAKX00ol0003oRGJ9ohUfR@0;ohUfR@03o`000?m]
TVgoKI9]00?oKI9]00Co0000ofFJIOmUVVGo00003OnSG:<00ol0003ohacSon<Lh`06on<Lh`03o`00
0?oa3_7ol@ka00Ool@ka00?o0000ooL8moog2?L01oog2?L00ol0003oo@;mood2o@06ood2o@04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000oo@;m?od2o@0
1_od2o@00ol0003oi1_Ton@Ki009on@Ki003o`000?njAK[o^TFj00Wo^TFj0_l0000>ohUfR@?o0000
0om]TVd00ol0003oIIYUo`00000=oj=LX`03o`000?oS7>?ohacS00OohacS00?o0000oo4>lOoa3_40
2?oa3_4:o`0000Koo@;m0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom0_d00?o
0000on@Ki?oT6n@02_oT6n@00ol0003o^TFjokY5^P06okY5^P;o000000?o^TFjo`000?n9MXT02on9
MXT2o`0000?oTfbC1Ol0000>oj=LX`03o`000?oS7>?ohacS00OohacS00?o0000oo4>lOoa3_402?oa
3_400ol0003on`Ckoo/4n`06oo/4n`03o`000?om0_goo@;m00?oo@;m00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP03ooX5nPCo00000_od2o@00ol0003oi1_Ton@Ki00;
on@Ki003o`000?njAK[o^TFj00?o^TFj0ol00004okY5^P03o`000?n9MXWoRGJ900OoRGJ90_l00008
oi=/T`03o`000?nSG:?oXebS00goXebS00?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@07
oo4>l@03o`000?ok1?_on`Ck00Oon`Ck0ol000000oom0_go0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00OonPGj0_l0000?on@Ki003o`000?njAK[o^TFj00;o00002?njAKX00ol0
003oRGJ9ohUfR@05ohUfR@03o`000?nCK9?oTfbC00SoTfbC00?o0000oj=LXonSG:<03OnSG:<00ol0
003ohacSon<Lh`08on<Lh`03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5
nP03o`000?oT6nCoi1_T00koi1_T0_l0000;okY5^P03o`000?n9MXWoRGJ900;oRGJ90_l0000;oi=/
T`03o`000?nSG:?oXebS00goXebS00?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@06oo4>
l@03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003onPGjooX5nP0:ooX5nP03o`000?oT6nCoi1_T00goi1_T0_l0000<okY5^P04o`000?n9MXWo0000
o`0000goTfbC00?o0000oj=LXonSG:<03?nSG:<00ol0003ohacSon<Lh`09on<Lh`03o`000?oa3_7o
l@ka00Kol@ka00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oT6nCoi1_T00coi1_T00Co0000on4N
hOoQ7^7o00003?njAKX00ol0003oTfbCoi=/T`0>oi=/T`03o`000?nSG:?oXebS00SoXebS1?l0000;
on<Lh`03o`000?oa3_7ol@ka00Kol@ka00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oT6nCoi1_T
00_oi1_T00?o0000on4NhOoQ7^400_oQ7^400ol0003o^TFjokY5^P09okY5^P03o`000?nCK9?oTfbC
00koTfbC00Co0000oj=LXonSG:?oXebS1ol00003olHiaP03o`000?oS7>?ohacS00WohacS00?o0000
oo4>lOoa3_401_oa3_400ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00conPGj00?o0000on@Ki?oT6n@02_oT6n@00ol0
003ohAkQon4Nh@03on4Nh@03o`000?njAK[o^TFj00So^TFj00?o0000oi=/TonCK9<03_nCK9<4o`00
00_oaSW600?o0000on<LhooS7><02?oS7><00ol0003ol@kaoo4>l@05oo4>l@03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj
1OX03?oj1OX7o`0000Goi1_T00?o0000on4NhOoQ7^401OoQ7^400ol0003o^TFjokY5^P07okY5^P03
o`000?nCK9?oTfbC00koTfbC00?o0000olHia_o6>LH03Oo6>LH00ol0003ohacSon<Lh`08on<Lh`03
o`000?oa3_7ol@ka00Col@ka00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003onPGjooX5nP0=ooX5nP03o`000?ob3O;olPgb00ColPgb
1Ol00009on4Nh@03o`000?njAK[o^TFj00Ko^TFj00?o0000oi=/TonCK9<03_nCK9<00ol0003oaSW6
olHiaP0=olHiaP03o`000?oS7>?ohacS00SohacS00Co0000oo4>lOoa3_7ol@ka1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooX5nP03o`000?ob3O;olPgb00WolPgb
0_l00009on4Nh@03o`000?njAK[o^TFj00Ko^TFj00?o0000oi=/TonCK9<03?nCK9<00ol0003oaSW6
olHiaP0?olHiaPKo00001?oS7><4o`0000GonPGj0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_oj1OX00ol0003o
lPgboo8=lP09oo8=lP03o`000?o[5>_o000000;o00001ooQ7^400ol0003o^TFjokY5^P05okY5^P03
o`000?nCK9?oTfbC00SoTfbC1Ol0000AolHiaP03o`000?o[5>_ojaC[00?ojaC[1?l0000;ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000OonPGj
00?o0000oo8=l_ob3O802_ob3O800ol0003ojaC[on/Dj`02on/Dj`?o00001OoQ7^400ol0003o^TFj
okY5^P04okY5^P04o`000?nCK9?oTfbCoi=/T`Oo00001?o7><L00ol0003oaSW6olHiaP0>olHiaP03
o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?oj1OX00ol0003olPgb
oo8=lP0;oo8=lP03o`000?o[5>_ojaC[00GojaC[0ol00003on4Nh@04o`000?njAK[o^TFjokY5^PKo
00003?o7><L00ol0003oaSW6olHiaP0=olHiaP03o`000?o[5>_ojaC[00OojaC[00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?onPGjo`000?ob3O80
3?ob3O800ol0003ojaC[on/Dj`08on/Dj`?o000000CohAkQo`000?l0003o00000_oT6n@00ol0003o
acS7olLha`0=olLha`03o`000?o6>LKoaSW600coaSW600?o0000on/Djoo[5>/02?o[5>/00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo8=l_ob3O803?ob3O800ol0003ojaC[on/Dj`0;on/Dj`03o`000?oT6nCoi1_T00?o
i1_T00?o0000olLhaoo7><L03?o7><L00ol0003odbcCo`00000=olHiaP03o`000?o[5>_ojaC[00So
jaC[00?o0000ooX5n_oj1OX03?oj1OX3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo8=l_ob3O803?ob3O800ol0003ojaC[on/Dj`0:on/Dj`03o`00
0?oT6nCoi1_T00Goi1_T00?o0000olLhaoo7><L02_o7><L01?l0003odbcCom</dooC;=<2o`0000[o
aSW600?o0000on/Djoo[5>/02Oo[5>/00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo8=l_ob3O80
3?ob3O800ol0003ojaC[on/Dj`09on/Dj`03o`000?oT6nCoi1_T00Koi1_T00?o0000olLhaoo7><L0
2Oo7><L00ol0003odbcCom</d`02om</d`03o`000?oV6NKo000000;o00001oo6>LH00ol0003ojaC[
on/Dj`09on/Dj`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003olPgboo8=lP0;oo8=lP03o`000?o[
5>_ojaC[00SojaC[00?o0000on@Ki?oT6n@01ooT6n@00ol0003oacS7olLha`08olLha`03o`000?oC
;=?odbcC00?odbcC00?o0000onHIi_oV6NH00_oV6NH2o`0000CoaSW600?o0000on/Djoo[5>/02_o[
5>/00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo8=lPKo00001?o[5>/00ol0003oi1_Ton@Ki008
on@Ki003o`000?o7><OoacS700OoacS700?o0000om</dooC;=<00ooC;=<00ol0003oiQWVonHIiP05
onHIiP?o000000?oaSW6o`000?o[5>/02oo[5>/00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo8=lP03o`000?od2oCom0_d00Com0_d1?l0000<on@Ki003o`000?o7><OoacS7
00GoacS700?o0000om</dooC;=<01?oC;=<00ol0003oiQWVonHIiP08onHIiP03o`000?o[5>_ojaC[
00_ojaC[00?o0000ooX5n_oj1OX02?oj1OX00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;olPgb00?o0000oo@;m?od
2o@02?od2o@00ol0003oi1_Ton@Ki00:on@Ki003o`000?o7><OoacS700CoacS700?o0000om</dooC
;=<01OoC;=<00ol0003oiQWVonHIiP08onHIiP03o`000?o[5>_ojaC[00WojaC[1?l00008ooX5nP03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<oo@;m003o`000?oT6nCoi1_T00Woi1_T
00?o0000olLhaoo7><L00oo7><L00ol0003odbcCom</d`05om</d`03o`000?oV6NKoiQWV00[oiQWV
00?o0000on/Djoo[5>/01?o[5>/4o`0000Con0Oh00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003om0_doo@;m00:oo@;m003o`000?oT6nCoi1_T00Woi1_T00?o0000olLhaoo7><L00_o7
><L00ol0003odbcCom</d`06om</d`03o`000?oV6NKoiQWV00[oiQWV00?o0000on/Djoo[5>/01?l0
0009ooP7n0Ko00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?od2oCom0_d00[om0_d00?o0000on@Ki?oT6n@02OoT6n@01Ol0003oacS7olLh
aoo7><Oo000000WodbcC00?o0000onHIi_oV6NH02ooV6NH2o`0000gon0Oh00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003om0_doo@;m00;oo@;m003o`000?oT6nCoi1_T00Woi1_T00?o
0000olLhaol000002OoC;=<00ol0003oiQWVonHIiP0<onHIiP03o`000?oh1oSon0Oh00con0Oh00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003om0_doo@;m00:oo@;m003o`000?oT6nCo
i1_T00Soi1_T1Ol00008om</d`03o`000?oV6NKoiQWV00coiQWV00?o0000ooP7n?oh1oP02ooh1oP0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000oo@;m?od2o@02_od2o@00ol0003oi1_Ton@Ki007on@K
i003o`000?oY5^WojAKY00?ojAKY0ol00005om</d`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooP7
n?oh1oP03?oh1oP00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
m0_d00?o0000on@Ki?oT6n@01OoT6n@00ol0003ojAKYonTFj@07onTFj@?o000000?odbcCo`000?oV
6NH03OoV6NH00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_od2o@00ol0003oi1_Ton@Ki003on@Ki0;o0000
3OoY5^T2o`0000goiQWV0ol0000=ooP7n003o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?od2oCom0_d00Oom0_d00Co0000on@Ki?oT6nCoi1_T
0_l00002ooH9mP03o`000?oY5^WojAKY00cojAKY3Ol00003ooT6n@03o`000?oh1oSon0Oh00[on0Oh
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008oo@;m003o`000?oT6nCo000000GomPWf
00?o0000onTFjOoY5^T02ooY5^T00ol0003oka3_onl@k`09onl@k`03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooP7n003o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om0_d0ol0
0007ooH9mP03o`000?oY5^WojAKY00[ojAKY00?o0000onl@koo_4>l02Oo_4>l00ol0003on@KiooT6
n@04ooT6n@;o00001ooh1oP00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo0?loo`3o?ol0o`3o`0000;onPGj00?o0000ooH9m_of2OH01_of2OH00ol0003ojAKYonTF
j@08onTFj@03o`000?o_4>ooka3_00[oka3_00?o0000ooT6nOoi1_T01_oi1_T00ol0003on0OhooP7
n004ooP7n003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?ol0oco
o0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`000008ooH9mP03o`000?oY5^WojAKY00OojAKY00?o
0000onl@koo_4>l02_o_4>l00ol0003on@KiooT6n@07ooT6n@;o00001?oh1oP00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l00Coo0?l00?o0000ooX5n_oj1OX00_oj1OX0
0ol0003omPWfooH9mP07ooH9mP03o`000?oY5^WojAKY00KojAKY00?o0000onl@koo_4>l02_o_4>l0
0ol0003on@KiooT6n@09ooT6n@05o`000?oh1oSon0OhooP7n?l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003onPGjooX5nP03
ooX5nP03o`000?of2OKomPWf00OomPWf00?o0000onTFjOoY5^T01OoY5^T00ol0003oka3_onl@k`0:
onl@k`03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?on0OkooP7n
ooh1o_l000002_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?oj1O[onPGj00?onPGj00?o0000
ooH9m_of2OH02?of2OH00ol0003ojAKYonTFj@04onTFj@03o`000?o_4>ooka3_00Woka3_00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?ol0ocoo0?l
00Goo0?l00?o0000ooX5n_oj1OX01?oj1OX00ol0003omPWfooH9mP09ooH9mP03o`000?oY5^WojAKY
00;ojAKY00?o0000onl@koo_4>l02_o_4>l00ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`01Ool0o`00ol0003onPGjooX5nP05ooX5nP03o`000?of2OKomPWf00WomPWf00Go0000onTFjOoY
5^WojAKYo`00000<onl@k`03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?oj1O[onPGj00GonPGj00?o0000ooH9m_of
2OH02_of2OH00ol0003ojAKYo`000004o`0000Woka3_00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`00
0?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003onPGjooX5nP07ooX5nP;o0000
2oof2OH00ol0003on`Ckoo/4n`03oo/4n`Oo00000_o_4>l00ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02Oon
0Oh01Ol0003oo0?loo`3o?ol0oco000000Soo0?l00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;m
o`000002o`0000SomPWf00?o0000oo/4nook1?/02_ok1?/5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ooh1oP03o`000?ol0oco000000Woo0?l00?o
0000ooX5n_oj1OX01_oj1OX00ol0003oo@;mood2o@03ood2o@?o00001?of2OH00ol0003on`Ckoo/4
n`0=oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_ooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP07
ooX5nP03o`000?om0_goo@;m00Koo@;m0ol000000oof2OKo0000oo/4n`0>oo/4n`03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ooh1
oP03o`000?ol0ocoo0?l00;oo0?l1_l00008ooX5nP03o`000?om0_goo@;m00[oo@;m00?o0000oo/4
nook1?/03ook1?/00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ooh1oPGo00001_on0Oh00ol0003onPGjooX5nP05ooX5nP03o`000?om0_goo@;m00[o
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj
1OX00ooj1OX00ol0003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?ooP7no`000?l00000
3Oon0Oh00ol0003onPGjooX5nP02ooX5nP03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?oj1O[onPGjo`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003onPGjo`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool02_l00?l2oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001ol00?l2oooo00Co003o0_ooo`09o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo0006o`00o`;oool01_l00?l2oooo00So003o0_ooo`05o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`08o`00o`;oool01Ol00?l2oooo
00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?oo
ool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Co
ool000?o003ooooo0?ooo`001_l00?l2oooo00Ko003o0_ooo`000ol00?ooool0oooo000:oooo00;o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool01_l00?l2oooo00Go003o0oooo`000ol00?ooool0
oooo000:oooo0003o`00ooooo`3oool000Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l0
0?l2oooo00;o003o00Coool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o
0_ooo`04o`00o`?oool01?l00?l2oooo00Oo003o0_ooo`03o`00o`?oool00_l00?l00oooo`3o003o
o`00o`04o`00o`;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l0
0?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_oo
o`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool02?l00?l00oooo`3o003o
o`00o`03oooo00Co003o00?oool0o`00ool00?l00ol00?l2oooo00Co003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00Wo003o1?ooo`06o`00o`03oooo0?l00?oo003o00;o003o0_ooo`04o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000So003o1?ooo`07o`00o`;oool00ol00?l2oooo00Co003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00Oo003o0oooo`02o`00o`;oool01_l00?l01?ooo`3o003oo`00ool00?l2oooo00Co003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`0Go`00o`;oool01_l00?l3oooo00Co003o0_ooo`06o`00o`03oooo0?l00?oo
003o00;oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J?l00?l3oooo
00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo
00Ko003o00Coool0o`00ooooo`3oool01?l00?l2oooo00Ko003o00?oool0o`00ool00?l01Ol00?l2
oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o0_ooo`06o`00
o`;oool01_l00?l2oooo00Ko003o00Coool0o`00ooooo`3oool01Ol00?l2oooo00Co003o0_ooo`07
o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o
01Ko003o0_ooo`000olb</co003oo`00o`03o`00o`;oool01_l00?l2oooo00Oo003o0oooo`05o`00
o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go
003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`04o`00o`;oool01?l00?l2oooo00Wo
003o0_ooo`06o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00o`Koool0
00?o003ooooo0?ooo`001Oooo`03o`00o`Goool08Ol00?l5oooo00[o003o0_ooo`07o`00o`Coool0
L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(850) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.997 .003 .997 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.989 .011 .989 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.972 .028 .972 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.977 .023 .977 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.948 .052 .948 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.985 .015 .985 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.893 .107 .893 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.968 .032 .968 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.966 .034 .966 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.971 .029 .971 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.98 .02 .98 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.954 .046 .954 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.979 .021 .979 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.923 .077 .923 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.978 .022 .978 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.965 .035 .965 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.974 .026 .974 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.905 .095 .905 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.984 .016 .984 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.957 .043 .957 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.926 .074 .926 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.746 .254 .746 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.793 .207 .793 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.981 .019 .981 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.934 .066 .934 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.938 .062 .938 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.765 .235 .765 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.725 .275 .725 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.67 .33 .67 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.925 .075 .925 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.948 .052 .948 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.937 .063 .937 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.895 .105 .895 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.993 .007 .993 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.78 .22 .78 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.974 .026 .974 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.778 .222 .778 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.683 .317 .683 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.873 .127 .873 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.431 .569 .431 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.425 .575 .425 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.516 .484 .516 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.792 .208 .792 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.809 .191 .809 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.987 .013 .987 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.467 .533 .467 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.422 .578 .422 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.957 .043 .957 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.599 .401 .599 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.73 .27 .73 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.919 .081 .919 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.922 .078 .922 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.648 .352 .648 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.883 .117 .883 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.356 .644 .356 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.845 .155 .845 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.731 .269 .731 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.145 .855 .145 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.316 .684 .316 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.98 .02 .98 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.245 .755 .245 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.188 .812 .188 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.894 .106 .894 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.982 .018 .982 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.499 .501 .499 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.15 .85 .15 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.223 .777 .223 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.811 .189 .811 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.321 .679 .321 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.54 .46 .54 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.216 .784 .216 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.043 .957 .043 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.132 .868 .132 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.027 .973 .027 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.354 .646 .354 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.542 .458 .542 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.964 .036 .964 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.58 .42 .58 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.654 .346 .654 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.048 .952 .048 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.001 .999 .001 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.029 .971 .029 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.104 .896 .104 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.139 .861 .139 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.782 .218 .782 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.914 .086 .914 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.942 .058 .942 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.47 .53 .47 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.099 .901 .099 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.83 .17 .83 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.213 .787 .213 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.429 .571 .429 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.115 .885 .115 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.275 .725 .275 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.861 .139 .861 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.398 .602 .398 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.116 .884 .116 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.982 .018 .982 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.902 .098 .902 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.935 .065 .935 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.276 .724 .276 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.974 .026 .974 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.025 .975 .025 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.644 .356 .644 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.615 .385 .615 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.119 .881 .119 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.247 .753 .247 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.523 .477 .523 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.779 .221 .779 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.122 .878 .122 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.987 .013 .987 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.063 .937 .063 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.216 .784 .216 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.291 .709 .291 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.974 .026 .974 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.498 .502 .498 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.436 .564 .436 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.307 .693 .307 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.257 .743 .257 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.921 .079 .921 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.895 .105 .895 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.892 .108 .892 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.202 .798 .202 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.529 .471 .529 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.681 .319 .681 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.868 .132 .868 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.973 .027 .973 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.503 .497 .503 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.741 .259 .741 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.394 .606 .394 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.963 .037 .963 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.946 .054 .946 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.862 .138 .862 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.978 .022 .978 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.51 .49 .51 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.625 .375 .625 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.99 .01 .99 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.544 .456 .544 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.908 .092 .908 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.701 .299 .701 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.83 .17 .83 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.646 .354 .646 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.978 .022 .978 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.968 .032 .968 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.982 .018 .982 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.786 .214 .786 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.964 .036 .964 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.728 .272 .728 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.757 .243 .757 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.869 .131 .869 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.87 .13 .87 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.96 .04 .96 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.817 .183 .817 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.986 .014 .986 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.957 .043 .957 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.937 .063 .937 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.923 .077 .923 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.877 .123 .877 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.888 .112 .888 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.841 .159 .841 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.935 .065 .935 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.997 .003 .997 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.957 .043 .957 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.981 .019 .981 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.968 .032 .968 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.974 .026 .974 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.986 .014 .986 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.967 .033 .967 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.897 .103 .897 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.961 .039 .961 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.974 .026 .974 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.987 .013 .987 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.983 .017 .983 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.986 .014 .986 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.972 .028 .972 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.977 .023 .977 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.985 .015 .985 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(860) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.989 .011 .989 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.973 .027 .973 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.978 .022 .978 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.948 .052 .948 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.985 .015 .985 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.895 .105 .895 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.968 .032 .968 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.966 .034 .966 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.972 .028 .972 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.981 .019 .981 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.954 .046 .954 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.979 .021 .979 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.924 .076 .924 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.978 .022 .978 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.966 .034 .966 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.975 .025 .975 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.907 .093 .907 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.984 .016 .984 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.958 .042 .958 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.927 .073 .927 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.749 .251 .749 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.795 .205 .795 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.981 .019 .981 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.935 .065 .935 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.938 .062 .938 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.768 .232 .768 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.728 .272 .728 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.672 .328 .672 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.925 .075 .925 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.949 .051 .949 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.938 .062 .938 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.781 .219 .781 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.975 .025 .975 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.781 .219 .781 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.685 .315 .685 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.873 .127 .873 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.433 .567 .433 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.427 .573 .427 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.521 .479 .521 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.793 .207 .793 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.811 .189 .811 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.987 .013 .987 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.471 .529 .471 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.426 .574 .426 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.957 .043 .957 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.601 .399 .601 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.732 .268 .732 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.92 .08 .92 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.924 .076 .924 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.651 .349 .651 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.884 .116 .884 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.357 .643 .357 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.848 .152 .848 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.734 .266 .734 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.148 .852 .148 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.317 .683 .317 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.98 .02 .98 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.249 .751 .249 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.19 .81 .19 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.896 .104 .896 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.982 .018 .982 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.504 .496 .504 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.152 .848 .152 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.225 .775 .225 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.814 .186 .814 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.323 .677 .323 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.543 .457 .543 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.22 .78 .22 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.046 .954 .046 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.133 .867 .133 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.028 .972 .028 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.357 .643 .357 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.545 .455 .545 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.965 .035 .965 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.584 .416 .584 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.659 .341 .659 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.05 .95 .05 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.002 .998 .002 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.03 .97 .03 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.105 .895 .105 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.14 .86 .14 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.785 .215 .785 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.915 .085 .915 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.943 .057 .943 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.475 .525 .475 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.1 .9 .1 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.832 .168 .832 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.216 .784 .216 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.432 .568 .432 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.119 .881 .119 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.277 .723 .277 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.863 .137 .863 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.4 .6 .4 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.118 .882 .118 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.982 .018 .982 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.904 .096 .904 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.936 .064 .936 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.281 .719 .281 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.974 .026 .974 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.027 .973 .027 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.648 .352 .648 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.619 .381 .619 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.122 .878 .122 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.249 .751 .249 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.526 .474 .526 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.783 .217 .783 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.125 .875 .125 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.987 .013 .987 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.065 .935 .065 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.218 .782 .218 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.297 .703 .297 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.974 .026 .974 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.501 .499 .501 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.442 .558 .442 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.311 .689 .311 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.259 .741 .259 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.923 .077 .923 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.897 .103 .897 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.893 .107 .893 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.206 .794 .206 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.531 .469 .531 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.682 .318 .682 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.87 .13 .87 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.973 .027 .973 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.506 .494 .506 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.742 .258 .742 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.399 .601 .399 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.964 .036 .964 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.946 .054 .946 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.863 .137 .863 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.978 .022 .978 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.514 .486 .514 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.629 .371 .629 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.99 .01 .99 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.551 .449 .551 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.909 .091 .909 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.704 .296 .704 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.831 .169 .831 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.651 .349 .651 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.979 .021 .979 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.789 .211 .789 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.965 .035 .965 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.733 .267 .733 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.761 .239 .761 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.872 .128 .872 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.872 .128 .872 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.961 .039 .961 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.82 .18 .82 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.987 .013 .987 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.959 .041 .959 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.938 .062 .938 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.925 .075 .925 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.879 .121 .879 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.89 .11 .89 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.995 .005 .995 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.844 .156 .844 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.937 .063 .937 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.957 .043 .957 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.981 .019 .981 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.968 .032 .968 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.974 .026 .974 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.986 .014 .986 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.968 .032 .968 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.899 .101 .899 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.962 .038 .962 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.987 .013 .987 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.983 .017 .983 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.986 .014 .986 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.973 .027 .973 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.978 .022 .978 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.985 .015 .985 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.997 .003 .997 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(870) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.99 .01 .99 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.988 .012 .988 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.973 .027 .973 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.978 .022 .978 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.949 .051 .949 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.985 .015 .985 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.896 .104 .896 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.968 .032 .968 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.966 .034 .966 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.972 .028 .972 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.981 .019 .981 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.955 .045 .955 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.98 .02 .98 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.925 .075 .925 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.978 .022 .978 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.966 .034 .966 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.975 .025 .975 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.908 .092 .908 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.985 .015 .985 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.958 .042 .958 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.928 .072 .928 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.752 .248 .752 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.797 .203 .797 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.982 .018 .982 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.935 .065 .935 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.939 .061 .939 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.771 .229 .771 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.732 .268 .732 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.674 .326 .674 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.926 .074 .926 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.95 .05 .95 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.94 .06 .94 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.899 .101 .899 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.781 .219 .781 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.975 .025 .975 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.785 .215 .785 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.686 .314 .686 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.874 .126 .874 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.435 .565 .435 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.429 .571 .429 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.525 .475 .525 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.794 .206 .794 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.813 .187 .813 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.475 .525 .475 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.429 .571 .429 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.958 .042 .958 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.602 .398 .602 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.735 .265 .735 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.921 .079 .921 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.926 .074 .926 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.653 .347 .653 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.885 .115 .885 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.359 .641 .359 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.85 .15 .85 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.736 .264 .736 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.151 .849 .151 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.318 .682 .318 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.98 .02 .98 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.253 .747 .253 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.192 .808 .192 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.897 .103 .897 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.983 .017 .983 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.509 .491 .509 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.153 .847 .153 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.226 .774 .226 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.817 .183 .817 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.326 .674 .326 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.546 .454 .546 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.224 .776 .224 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.048 .952 .048 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.134 .866 .134 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.029 .971 .029 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.36 .64 .36 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.548 .452 .548 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.965 .035 .965 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.588 .412 .588 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.664 .336 .664 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.052 .948 .052 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.003 .997 .003 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.031 .969 .031 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.107 .893 .107 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.142 .858 .142 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.788 .212 .788 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.917 .083 .917 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.944 .056 .944 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.48 .52 .48 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.1 .9 .1 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.834 .166 .834 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.22 .78 .22 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.435 .565 .435 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.122 .878 .122 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.28 .72 .28 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.865 .135 .865 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.403 .597 .403 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.12 .88 .12 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.982 .018 .982 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.905 .095 .905 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.937 .063 .937 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.285 .715 .285 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.975 .025 .975 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.029 .971 .029 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.651 .349 .651 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.622 .378 .622 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.125 .875 .125 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.252 .748 .252 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.529 .471 .529 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.786 .214 .786 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.128 .872 .128 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.988 .012 .988 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.066 .934 .066 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.221 .779 .221 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.302 .698 .302 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.974 .026 .974 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.503 .497 .503 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.448 .552 .448 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.316 .684 .316 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.262 .738 .262 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.924 .076 .924 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.898 .102 .898 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.895 .105 .895 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.209 .791 .209 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.533 .467 .533 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.684 .316 .684 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.871 .129 .871 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.974 .026 .974 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.992 .008 .992 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.509 .491 .509 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.744 .256 .744 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.403 .597 .403 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.964 .036 .964 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.947 .053 .947 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.864 .136 .864 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.979 .021 .979 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.518 .482 .518 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.632 .368 .632 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.99 .01 .99 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.557 .443 .557 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.91 .09 .91 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.707 .293 .707 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.833 .167 .833 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.655 .345 .655 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.979 .021 .979 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.792 .208 .792 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.966 .034 .966 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.738 .262 .738 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.764 .236 .764 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.874 .126 .874 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.874 .126 .874 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.962 .038 .962 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.823 .177 .823 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.987 .013 .987 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.96 .04 .96 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.939 .061 .939 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.926 .074 .926 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.882 .118 .882 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.892 .108 .892 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.847 .153 .847 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.938 .062 .938 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.958 .042 .958 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.982 .018 .982 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.969 .031 .969 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.975 .025 .975 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.986 .014 .986 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.969 .031 .969 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.902 .098 .902 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.963 .037 .963 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.987 .013 .987 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.983 .017 .983 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.986 .014 .986 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.973 .027 .973 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.995 .005 .995 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.978 .022 .978 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.985 .015 .985 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(880) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.99 .01 .99 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.974 .026 .974 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.978 .022 .978 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.95 .05 .95 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.985 .015 .985 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.994 .006 .994 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.898 .102 .898 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.969 .031 .969 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.967 .033 .967 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.972 .028 .972 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.981 .019 .981 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.99 .01 .99 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.955 .045 .955 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.98 .02 .98 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.926 .074 .926 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.979 .021 .979 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.967 .033 .967 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.975 .025 .975 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.91 .09 .91 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.985 .015 .985 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.958 .042 .958 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.928 .072 .928 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.755 .245 .755 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.799 .201 .799 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.982 .018 .982 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.936 .064 .936 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.939 .061 .939 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.774 .226 .774 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.735 .265 .735 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.676 .324 .676 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.927 .073 .927 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.951 .049 .951 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.941 .059 .941 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.9 .1 .9 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.781 .219 .781 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.987 .013 .987 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.976 .024 .976 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.788 .212 .788 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.687 .313 .687 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.874 .126 .874 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.436 .564 .436 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.43 .57 .43 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.53 .47 .53 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.795 .205 .795 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.814 .186 .814 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.479 .521 .479 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.433 .567 .433 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.959 .041 .959 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.604 .396 .604 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.737 .263 .737 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.921 .079 .921 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.927 .073 .927 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.655 .345 .655 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.885 .115 .885 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.36 .64 .36 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.853 .147 .853 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.739 .261 .739 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.153 .847 .153 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.319 .681 .319 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.981 .019 .981 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.256 .744 .256 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.194 .806 .194 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.899 .101 .899 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.983 .017 .983 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.513 .487 .513 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.154 .846 .154 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.228 .772 .228 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.82 .18 .82 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.328 .672 .328 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.549 .451 .549 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.227 .773 .227 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.05 .95 .05 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.135 .865 .135 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.031 .969 .031 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.363 .637 .363 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.551 .449 .551 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.966 .034 .966 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.591 .409 .591 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.668 .332 .668 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.054 .946 .054 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.005 .995 .005 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.032 .968 .032 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.108 .892 .108 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.144 .856 .144 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.79 .21 .79 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.918 .082 .918 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.945 .055 .945 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.484 .516 .484 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.101 .899 .101 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.836 .164 .836 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.223 .777 .223 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.438 .562 .438 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.125 .875 .125 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.282 .718 .282 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.867 .133 .867 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.405 .595 .405 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.122 .878 .122 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.983 .017 .983 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.995 .005 .995 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.907 .093 .907 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.938 .062 .938 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.29 .71 .29 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.975 .025 .975 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.032 .968 .032 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.654 .346 .654 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.626 .374 .626 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.128 .872 .128 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.254 .746 .254 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.532 .468 .532 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.789 .211 .789 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.131 .869 .131 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.988 .012 .988 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.067 .933 .067 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.223 .777 .223 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.306 .694 .306 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.975 .025 .975 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.506 .494 .506 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.454 .546 .454 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.32 .68 .32 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.264 .736 .264 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.925 .075 .925 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.9 .1 .9 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.896 .104 .896 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.212 .788 .212 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.535 .465 .535 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.685 .315 .685 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.872 .128 .872 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.974 .026 .974 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.512 .488 .512 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.745 .255 .745 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.408 .592 .408 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.965 .035 .965 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.948 .052 .948 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.865 .135 .865 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.979 .021 .979 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.522 .478 .522 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.635 .365 .635 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.991 .009 .991 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.562 .438 .562 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.911 .089 .911 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.711 .289 .711 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.835 .165 .835 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.659 .341 .659 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.979 .021 .979 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.964 .036 .964 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.794 .206 .794 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.995 .005 .995 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.967 .033 .967 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.742 .258 .742 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.767 .233 .767 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.876 .124 .876 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.875 .125 .875 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.962 .038 .962 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.826 .174 .826 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.987 .013 .987 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.961 .039 .961 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.94 .06 .94 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.927 .073 .927 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.884 .116 .884 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.893 .107 .893 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.849 .151 .849 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.94 .06 .94 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.958 .042 .958 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.982 .018 .982 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.969 .031 .969 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.975 .025 .975 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.987 .013 .987 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.97 .03 .97 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.904 .096 .904 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.964 .036 .964 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.976 .024 .976 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.984 .016 .984 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.986 .014 .986 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.974 .026 .974 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.99 .01 .99 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.979 .021 .979 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.986 .014 .986 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.997 .003 .997 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(890) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.99 .01 .99 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.974 .026 .974 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.979 .021 .979 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.951 .049 .951 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.985 .015 .985 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.899 .101 .899 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.969 .031 .969 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.967 .033 .967 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.972 .028 .972 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.982 .018 .982 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.955 .045 .955 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.98 .02 .98 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.926 .074 .926 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.979 .021 .979 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.968 .032 .968 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.975 .025 .975 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.912 .088 .912 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.985 .015 .985 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.959 .041 .959 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.929 .071 .929 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.757 .243 .757 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.8 .2 .8 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.982 .018 .982 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.936 .064 .936 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.939 .061 .939 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.777 .223 .777 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.738 .262 .738 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.677 .323 .677 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.927 .073 .927 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.952 .048 .952 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.942 .058 .942 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.901 .099 .901 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.976 .024 .976 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.791 .209 .791 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.688 .312 .688 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.875 .125 .875 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.438 .562 .438 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.432 .568 .432 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.534 .466 .534 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.796 .204 .796 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.816 .184 .816 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.483 .517 .483 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.436 .564 .436 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.96 .04 .96 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.605 .395 .605 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.739 .261 .739 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.922 .078 .922 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.928 .072 .928 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.657 .343 .657 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.886 .114 .886 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.361 .639 .361 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.856 .144 .856 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.741 .259 .741 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.156 .844 .156 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.32 .68 .32 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.981 .019 .981 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.26 .74 .26 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.196 .804 .196 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.901 .099 .901 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.983 .017 .983 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.518 .482 .518 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.155 .845 .155 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.229 .771 .229 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.823 .177 .823 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.33 .67 .33 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.552 .448 .552 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.231 .769 .231 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.051 .949 .051 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.136 .864 .136 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.032 .968 .032 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.365 .635 .365 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.553 .447 .553 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.966 .034 .966 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.595 .405 .595 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.673 .327 .673 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.056 .944 .056 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.006 .994 .006 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.033 .967 .033 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.109 .891 .109 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.145 .855 .145 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.793 .207 .793 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.919 .081 .919 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.946 .054 .946 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.489 .511 .489 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.102 .898 .102 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.837 .163 .837 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.225 .775 .225 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.441 .559 .441 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.128 .872 .128 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.285 .715 .285 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.87 .13 .87 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.407 .593 .407 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.123 .877 .123 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.983 .017 .983 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.908 .092 .908 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.939 .061 .939 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.294 .706 .294 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.976 .024 .976 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.034 .966 .034 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.657 .343 .657 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.629 .371 .629 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.131 .869 .131 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.256 .744 .256 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.535 .465 .535 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.791 .209 .791 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.134 .866 .134 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.988 .012 .988 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.068 .932 .068 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.225 .775 .225 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.311 .689 .311 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.975 .025 .975 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.508 .492 .508 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.46 .54 .46 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.325 .675 .325 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.267 .733 .267 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.927 .073 .927 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.901 .099 .901 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.898 .102 .898 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.216 .784 .216 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.536 .464 .536 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.687 .313 .687 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.874 .126 .874 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.975 .025 .975 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.515 .485 .515 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.746 .254 .746 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.412 .588 .412 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.966 .034 .966 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.948 .052 .948 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.866 .134 .866 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.979 .021 .979 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.525 .475 .525 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.639 .361 .639 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.991 .009 .991 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.568 .432 .568 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.911 .089 .911 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.714 .286 .714 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.836 .164 .836 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.663 .337 .663 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.979 .021 .979 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.797 .203 .797 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.968 .032 .968 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.746 .254 .746 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.77 .23 .77 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.878 .122 .878 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.877 .123 .877 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.963 .037 .963 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.992 .008 .992 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.829 .171 .829 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.962 .038 .962 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.941 .059 .941 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.929 .071 .929 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.885 .115 .885 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.895 .105 .895 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.852 .148 .852 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.941 .059 .941 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.959 .041 .959 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.982 .018 .982 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.969 .031 .969 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.976 .024 .976 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.987 .013 .987 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.97 .03 .97 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.905 .095 .905 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.965 .035 .965 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.976 .024 .976 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.984 .016 .984 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.974 .026 .974 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.979 .021 .979 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.986 .014 .986 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.992 .008 .992 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.997 .003 .997 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(900) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.993 .007 .993 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.99 .01 .99 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.975 .025 .975 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.979 .021 .979 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.952 .048 .952 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.9 .1 .9 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.982 .018 .982 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.969 .031 .969 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.967 .033 .967 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.973 .027 .973 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.982 .018 .982 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.956 .044 .956 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.98 .02 .98 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.927 .073 .927 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.987 .013 .987 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.979 .021 .979 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.968 .032 .968 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.975 .025 .975 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.913 .087 .913 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.985 .015 .985 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.959 .041 .959 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.93 .07 .93 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.76 .24 .76 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.802 .198 .802 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.996 .004 .996 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.982 .018 .982 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.936 .064 .936 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.94 .06 .94 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.78 .22 .78 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.741 .259 .741 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.679 .321 .679 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.928 .072 .928 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.953 .047 .953 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.943 .057 .943 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.903 .097 .903 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.977 .023 .977 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.794 .206 .794 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.689 .311 .689 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.875 .125 .875 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.439 .561 .439 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.433 .567 .433 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.538 .462 .538 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.797 .203 .797 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.817 .183 .817 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.487 .513 .487 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.439 .561 .439 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.96 .04 .96 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.606 .394 .606 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.741 .259 .741 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.922 .078 .922 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.93 .07 .93 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.66 .34 .66 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.886 .114 .886 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.363 .637 .363 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.858 .142 .858 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.744 .256 .744 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.158 .842 .158 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.32 .68 .32 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.981 .019 .981 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.263 .737 .263 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.197 .803 .197 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.902 .098 .902 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.984 .016 .984 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.522 .478 .522 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.156 .844 .156 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.23 .77 .23 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.825 .175 .825 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.331 .669 .331 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.554 .446 .554 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.991 .009 .991 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.234 .766 .234 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.053 .947 .053 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.137 .863 .137 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.033 .967 .033 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.368 .632 .368 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.555 .445 .555 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.967 .033 .967 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.599 .401 .599 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.677 .323 .677 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.058 .942 .058 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.007 .993 .007 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.033 .967 .033 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.11 .89 .11 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.146 .854 .146 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.795 .205 .795 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.92 .08 .92 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.947 .053 .947 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.494 .506 .494 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.102 .898 .102 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.839 .161 .839 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.228 .772 .228 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.444 .556 .444 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.131 .869 .131 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.287 .713 .287 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.872 .128 .872 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.409 .591 .409 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.125 .875 .125 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.983 .017 .983 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.91 .09 .91 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.94 .06 .94 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.299 .701 .299 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.976 .024 .976 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.035 .965 .035 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.66 .34 .66 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.633 .367 .633 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.134 .866 .134 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.258 .742 .258 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.538 .462 .538 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.794 .206 .794 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.137 .863 .137 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.988 .012 .988 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.069 .931 .069 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.227 .773 .227 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.316 .684 .316 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.975 .025 .975 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.511 .489 .511 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.465 .535 .465 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.329 .671 .329 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.269 .731 .269 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.928 .072 .928 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.903 .097 .903 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.899 .101 .899 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.219 .781 .219 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.538 .462 .538 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.688 .312 .688 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.875 .125 .875 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.975 .025 .975 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.518 .482 .518 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.747 .253 .747 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.416 .584 .416 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.967 .033 .967 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.949 .051 .949 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.867 .133 .867 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.98 .02 .98 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.529 .471 .529 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.642 .358 .642 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.991 .009 .991 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.574 .426 .574 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.912 .088 .912 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.717 .283 .717 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.837 .163 .837 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.668 .332 .668 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.799 .201 .799 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.968 .032 .968 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.75 .25 .75 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.773 .227 .773 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.88 .12 .88 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.878 .122 .878 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.994 .006 .994 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.963 .037 .963 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.831 .169 .831 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.963 .037 .963 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.942 .058 .942 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.93 .07 .93 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.887 .113 .887 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.896 .104 .896 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.855 .145 .855 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.943 .057 .943 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.959 .041 .959 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.983 .017 .983 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.97 .03 .97 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.976 .024 .976 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.987 .013 .987 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.971 .029 .971 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.907 .093 .907 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.966 .034 .966 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.977 .023 .977 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.984 .016 .984 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.975 .025 .975 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.997 .003 .997 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.98 .02 .98 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.986 .014 .986 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(910) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.99 .01 .99 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.975 .025 .975 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.979 .021 .979 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.953 .047 .953 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.902 .098 .902 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.969 .031 .969 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.968 .032 .968 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.973 .027 .973 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.982 .018 .982 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.956 .044 .956 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.981 .019 .981 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.927 .073 .927 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.98 .02 .98 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.969 .031 .969 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.915 .085 .915 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.985 .015 .985 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.959 .041 .959 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.99 .01 .99 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.931 .069 .931 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.762 .238 .762 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.804 .196 .804 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.982 .018 .982 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.937 .063 .937 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.94 .06 .94 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.783 .217 .783 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.744 .256 .744 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.68 .32 .68 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.928 .072 .928 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.954 .046 .954 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.944 .056 .944 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.904 .096 .904 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.977 .023 .977 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.797 .203 .797 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.69 .31 .69 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.875 .125 .875 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.44 .56 .44 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.434 .566 .434 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.542 .458 .542 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.797 .203 .797 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.819 .181 .819 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.491 .509 .491 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.443 .557 .443 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.961 .039 .961 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.607 .393 .607 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.743 .257 .743 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.923 .077 .923 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.931 .069 .931 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.662 .338 .662 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.887 .113 .887 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.364 .636 .364 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.86 .14 .86 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.746 .254 .746 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.16 .84 .16 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.981 .019 .981 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.266 .734 .266 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.199 .801 .199 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.904 .096 .904 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.984 .016 .984 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.526 .474 .526 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.156 .844 .156 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.231 .769 .231 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.828 .172 .828 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.333 .667 .333 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.556 .444 .556 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.237 .763 .237 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.055 .945 .055 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.137 .863 .137 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.034 .966 .034 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.37 .63 .37 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.558 .442 .558 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.967 .033 .967 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.602 .398 .602 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.681 .319 .681 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.06 .94 .06 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.008 .992 .008 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.034 .966 .034 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.111 .889 .111 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.147 .853 .147 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.797 .203 .797 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.921 .079 .921 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.948 .052 .948 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.498 .502 .498 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.103 .897 .103 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.84 .16 .84 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.231 .769 .231 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.446 .554 .446 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.134 .866 .134 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.289 .711 .289 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.874 .126 .874 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.411 .589 .411 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.126 .874 .126 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.984 .016 .984 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.911 .089 .911 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.941 .059 .941 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.303 .697 .303 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.977 .023 .977 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.037 .963 .037 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.663 .337 .663 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.636 .364 .636 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.137 .863 .137 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.26 .74 .26 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.541 .459 .541 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.796 .204 .796 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.139 .861 .139 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.989 .011 .989 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.071 .929 .071 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.229 .771 .229 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.32 .68 .32 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.975 .025 .975 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.513 .487 .513 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.994 .006 .994 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.471 .529 .471 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.333 .667 .333 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.272 .728 .272 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.929 .071 .929 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.904 .096 .904 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.9 .1 .9 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.221 .779 .221 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.539 .461 .539 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.689 .311 .689 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.876 .124 .876 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.976 .024 .976 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.521 .479 .521 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.748 .252 .748 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.42 .58 .42 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.967 .033 .967 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.949 .051 .949 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.868 .132 .868 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.98 .02 .98 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.532 .468 .532 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.645 .355 .645 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.991 .009 .991 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.579 .421 .579 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.913 .087 .913 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.72 .28 .72 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.839 .161 .839 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.672 .328 .672 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.802 .198 .802 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.969 .031 .969 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.754 .246 .754 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.776 .224 .776 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.882 .118 .882 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.88 .12 .88 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.964 .036 .964 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.834 .166 .834 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.963 .037 .963 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.943 .057 .943 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.931 .069 .931 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.889 .111 .889 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.898 .102 .898 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.857 .143 .857 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.944 .056 .944 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.959 .041 .959 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.983 .017 .983 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.97 .03 .97 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.977 .023 .977 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.988 .012 .988 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.972 .028 .972 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.909 .091 .909 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.966 .034 .966 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.977 .023 .977 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.988 .012 .988 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.984 .016 .984 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.975 .025 .975 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.98 .02 .98 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.987 .013 .987 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.987 .013 .987 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?ol0ocoo0?loo`3o0;o00002_oo0?l2o`000003oo`3o?l0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?ol0oco
o0?l00Coo0?l0_l00005ool0o`?o00001?ol0o`00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo0?l0_l000000ooo
0?oo0000o`000007oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00_oo0?l00?o0000oo`3o?ol
0o`01ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_ol0o`00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ok1?_on`Cko`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003ool0o`00ol0003oo0?loo`3o008oo`3
o003o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo/4n`03o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o
o0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`0
2_ol0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo/4n`03o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_on`Ck1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooL8m`;o00003?om0_d2o`00013oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo/4nook1?/02ook1?/01?l0003olPgb
oo8=l_ob3O85o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?og2?Oom`Sg00Gom`Sg0_l00008ood2o@;o00000_oh1oP00ol0003oo0?loo`3o00=oo`3o003
o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ook1?/00ol0003olPgboo8=lP07oo8=lPKo00000_oo0?l4o`0000goo@;m00?o0000ooL8moog2?L0
1oog2?L2o`0000Goo@;m00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?loo`3o00<oo`3o003o`00
0?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ook1?/00ol0003olPgboo8=lP0<oo8=lP?o00001?oj1OX3o`0000Woo@;m00?o
0000ooL8moog2?L02_og2?L2o`000003ood2oOl0003o000000Oon0Oh00?o0000oo`3o?ol0o`02ool
0o`00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo/4nook1?/03_ok1?/00ol0003olPgboo8=lP0=oo8=lP03o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?og2?Oom`Sg00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo0?loo`3o009
oo`3o003o`000?ol0ocoo0?l00goo0?l00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000oon`Ck00?o0000oo8=l_ob3O803Oob3O800ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?og2?L03oog2?L00ol0003on0OhooP7n009ooP7n003o`000?ol0oco
o0?l00Soo0?l00?o0000oo`3o?ol0o`03_ol0o`3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo/4n`0>oo/4n`03o`000?ob3O;olPgb00golPgb00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003om`SgooL8m`0?ooL8m`03o`000?oh1oSon0Oh00[on0Oh2ol0000;oo`3o0Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ok1?_on`Ck00con`Ck00?o0000oo8=l_ob3O803Oob3O800ol0
003onPGjooX5nP0=ooX5nP;o00004?og2?L00ol0003on0OhooP7n00:ooP7n003o`000?of2OKomPWf
00OomPWf00?o0000oo`3o?ol0o`00_ol0o`7o`0000Con0Oh00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ook1?/00ol0003olPgboo8=lP0=oo8=lP03o`000?oj1O[onPGj
00gonPGj00Co0000onLHiooW6>Oo00003oog2?L00ol0003on0OhooP7n009ooP7n003o`000?of2OKo
mPWf00WomPWf1?l0000;ooP7n003o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000onhAk_l0003o00002Ook1?/00ol0003olPgboo8=lP0=oo8=lP03o`000?oj1O[o
nPGj00gonPGj00Go0000onLHiooW6>OoiaSWo`00000=ooL8m`03o`000?oh1oSon0Oh00[on0Oh00?o
0000ooH9m_of2OH02Oof2OH00ol0003on0OhooP7n00<ooP7n003o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o^4NkokQ7^00;okQ7^0_l00007oo/4n`03o`000?ob3O;o
lPgb00colPgb00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oiaSWonLHi`03onLHi`03o`000?og2?Oo
m`Sg00[om`Sg00?o0000ooP7n?oh1oP02_oh1oP00ol0003omPWfooH9mP09ooH9mP03o`000?oh1oSo
n0Oh00con0Oh00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onhA
k_o^4Nh01Oo^4Nh00ol0003on`Ckoo/4n`03oo/4n`03o`000?ob3O;olPgb00golPgb00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oiaSWonLHi`04onLHi`03o`000?og2?Oom`Sg00Wom`Sg00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003omPWfooH9mP0:ooH9mP03o`000?oh1oSon0Oh00con0Oh00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onhAk_o^4Nh01_o^4Nh2o`0000?o
n`Ck00?o0000oo8=l_ob3O803Oob3O800ol0003onPGjooX5nP0<ooX5nP03o`000?oW6>OoiaSW00Ko
iaSW00?o0000ooL8moog2?L02?og2?L00ol0003on0OhooP7n009ooP7n003o`000?of2OKomPWf00[o
mPWf00?o0000ooP7n?oh1oP03?oh1oP00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o^4NkokQ7^00WokQ7^0_l000000ook1?_o0000oo8=lP0<oo8=lP?o00003_oj1OX00ol0003oiaSW
onLHi`07onLHi`03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooP7n?oh1oP02Ooh1oP00ol0003omPWf
ooH9mP0;ooH9mP03o`000?oh1oSon0Oh00con0Oh00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o^4NkokQ7^00_okQ7^00?o0000oo8=l_ob3O802_ob3O82o`0000?ogb3O00?o
0000ooX5n_oj1OX02_oj1OX00ol0003oiaSWonLHi`09onLHi`03o`000?og2?Oom`Sg00Kom`Sg00?o
0000ooP7n?oh1oP02?oh1oP00ol0003omPWfooH9mP0<ooH9mP03o`000?oh1oSon0Oh00con0Oh00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003okQ7^onhAkP0<onhAkP03o`000?ob3O;olPgb00SolPgb0_l00006omlPg`;o00002_oj1OX0
0ol0003oiaSWonLHi`0:onLHi`03o`000?og2?Oom`Sg00Gom`Sg00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oh1oSon0Oh00con0Oh00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onhAk_o^4Nh03_o^4Nh00ol0003olPgboo8=lP04
oo8=lP?o00002_oO8=l00ol0003onPGjooX5nP07ooX5nP03o`000?oW6>OoiaSW00_oiaSW00?o0000
ooL8moog2?L00oog2?L00ol0003on0OhooP7n009ooP7n003o`000?of2OKomPWf00comPWf00?o0000
ooP7n?oh1oP03?oh1oP00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onhAk_o^4Nh03oo^4Nh01?l0
003olPgboo8=l_ob3O82o`0000kogb3O0_l00006ooX5nP03o`000?oW6>OoiaSW00goiaSW00?o0000
ooL8moog2?L00_og2?L00ol0003on0OhooP7n008ooP7n003o`000?of2OKomPWf00comPWf0ol0000=
ooP7n003o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003okQ7^onhAkP0@onhAkPCo00004_oO8=l00ol0
003onPGjooX5nP03ooX5nP03o`000?oW6>OoiaSW00koiaSW00Go0000ooL8moog2?Oom`Sgo`000005
ooP7n0Oo00003?of2OH01Ol0003ol@kaoo4>lOoa3_7o000000con0Oh00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003okQ7^onhAkP0=
onhAkP?o000000Cog2?Lo`000?l0003o00004ooO8=l2o`0000;onPGj00?o0000onLHiooW6>L04?oW
6>L00ol0003om`Sgo`000006o`0000OohAkQ00?o0000ooH9m_of2OH02?of2OH00ol0003ol@kaoo4>
l@03oo4>l@;o00002?oh1oP3o`0000Koo@;m1?l00002oo`3o003o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oh1oP3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003okQ7^onhA
kP0;onhAkP?o00000ooL8m`01Ol0003odbcCo`000?n^DJko000001Cogb3O00?o0000ooX5n_l00000
4ooW6>L00ol0003ohAkQon4Nh@0=on4Nh@03o`000?of2OKomPWf00GomPWf0_l00008oo4>l@03o`00
0?oh1oSon0Oh00Go00000oog2?L00ol0003oo@;mood2o@03o`0000Ooo0?l00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con0Oh0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000onhAk_o^4Nh02Oo^4Nh3o`0000Gog2?L00Co0000om</dooC;=?o00000_n^DJh00ol0003o
gb3OomlPg`0BomlPg`03o`000?oW6>OoiaSW01;oiaSW00?o0000on4NhOoQ7^403_oQ7^400ol0003o
mPWfooH9mP03ooH9mP03o`000?oa3_7ol@ka00Wol@ka0_l00009ooL8m`;o00002_ol0o`00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooP7n0;o00001oom0_d5o`0000;o
nPGj00?o0000onhAk_o^4Nh01_o^4Nh3o`0000Sog2?L00Co0000om</dooC;=?o00000on^DJh00ol0
003ogb3OomlPg`0AomlPg`03o`000?oW6>OoiaSW017oiaSW00?o0000on4NhOoQ7^404?oQ7^401Ol0
003omPWfooH9m_of2OKo000000col@ka00?o0000ooL8moog2?L02?og2?L00ol0003oo0?loo`3o00:
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooP7n?oh1oP01ooh1oP3o`00
0004ood2oOl0003o0000o`0000Gol@ka0_l00006onhAkP?o00002_oL8m`01Ol0003odbcCom</dooC
;=?o000000Co[U6^00?o0000omlPgooO8=l04?oO8=l00ol0003oiaSWonLHi`0AonLHi`03o`000?oQ
7^7ohAkQ017ohAkQ00?o0000ooH9m_l000003Ooa3_400ol0003om`SgooL8m`08ooL8m`03o`000?ol
0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP02_oh1oP00ol0003ol@kaoo4>l@08oo4>l@03o`000?o^4NkokQ7^00?o00003OoL8m`0
1Ol0003odbcCom</dooC;=?o000000Go[U6^00?o0000omlPgooO8=l03ooO8=l00ol0003oiaSWonLH
i`0AonLHi`03o`000?oQ7^7ohAkQ01;ohAkQ00?o0000oo4>lOoa3_403?oa3_400ol0003om`SgooL8
m`08ooL8m`03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?oa3_7ol@ka00Wol@ka0_l0000?om`Sg003o`000?oC;=?o
dbcC00;odbcC00?o0000ojiA[_n^DJh01?n^DJh00ol0003ogb3OomlPg`0=omlPg`?o00004OoW6>L0
0ol0003ohAkQon4Nh@0Con4Nh@03o`000?oa3_7ol@ka00_ol@ka00?o0000ooL8moog2?L02Oog2?L0
0ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?oa3_7ol@ka00Wol@ka00?o0000om`Sg?oL8m`03OoL8m`0
0ol0003odbcCom</d`03om</d`03o`000?n^DJko[U6^00Go[U6^00?o0000omlPgooO8=l02_oO8=l2
o`0000?oXUfR00?o0000onLHiooW6>L03_oW6>L00ol0003ohAkQon4Nh@0Con4Nh@03o`000?oa3_7o
l@ka00_ol@ka00?o0000ooL8moog2?L02Oog2?L00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on0Oh00?o0000oo4>
lOoa3_402ooa3_400ol0003og2?Lom`Sg00<om`Sg003o`000?oC;=?odbcC00?odbcC00?o0000ojiA
[_n^DJh01_n^DJh00ol0003ogb3OomlPg`07omlPg`;o00001_nRGJ82o`0000koiaSW00?o0000on4N
hOoQ7^404ooQ7^400ol0003ol@kaoo4>l@0;oo4>l@03o`000?og2?Oom`Sg00Wom`Sg00?o0000oo`3
o?ol0o`03?ol0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on0Oh00?o0000oo4>lOoa3_402ooa3_400ol0003og2?Lom`Sg00;om`S
g003o`000?oC;=?odbcC00CodbcC00?o0000ojiA[_n^DJh01on^DJh00ol0003ogb3OomlPg`05omlP
g`03o`000?nRGJ;oXUfR00SoXUfR00?o0000onLHiooW6>L02_oW6>L00ol0003ohAkQon4Nh@0Don4N
h@03o`000?oa3_7ol@ka00_ol@ka00?o0000ooL8moog2?L02Oog2?L00ol0003oo0?loo`3o00<oo`3
o003o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on0Oh00?o0000oo4>lOoa3_402ooa3_400ol0003og2?Lom`Sg00;om`Sg003o`000?oC;=?odbcC
00CodbcC00?o0000ojiA[_n^DJh02?n^DJh00ol0003ogb3OomlPg`02omlPg`;o00003?nRGJ82o`00
00[oiaSW00?o0000on4NhOoQ7^405?oQ7^400ol0003ol@kaoo4>l@0;oo4>l@03o`000?og2?Oom`Sg
00Wom`Sg00?o0000oo`3o?ol0o`03Ool0o`00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003ol@kaoo4>l@0<oo4>l@03
o`000?oL8mcog2?L00Wog2?L00?o0000om</dooC;=<01OoC;=<00ol0003o[U6^ojiA[P09ojiA[P04
o`000?oO8=oo0000o`00013oXUfR0_l00008onLHi`03o`000?oQ7^7ohAkQ01CohAkQ0ol0000;oo4>
l@03o`000?og2?Oom`Sg00Wom`Sg00?o0000oo`3o?ol0o`03Ool0o`01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7
n?oh1oP02?oh1oP00ol0003ol@kaoo4>l@0;oo4>l@;o00002_oL8m`00ol0003odbcCom</d`06om</
d`03o`000?n^DJko[U6^00[o[U6^00?o0000oj9MX_nRGJ804_nRGJ800ol0003oiaSWonLHi`04onLH
i`03o`000?oQ7^7ohAkQ01GohAkQ00?o0000om/TfooK9=/01Ol00005oo4>l@03o`000?og2?Oom`Sg
00[om`Sg00?o0000oo`3o?ol0o`03_ol0o`3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooP7n?oh1oP01ooh1oP00ol0003ol@kaoo4>l@0;oo4>l@04
o`000?o<<lcoc3?<o`0000Wog2?L00?o0000om</dooC;=<01_oC;=<00ol0003o[U6^ojiA[P0:ojiA
[P03o`000?nRGJ;oXUfR01?oXUfR0_l00003onLHi`Co00005?oQ7^400ol0003ofbCKom/Tf`06om/T
f`Co000000?ol@kao`000?og2?L02oog2?L00ol0003oo0?loo`3o00>oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP01ooh1oP00ol0003ol@kaoo4>l@09oo4>l@;o00001?o<<l`00ol0003og2?Lom`Sg005om`Sg003
o`000?oC;=?odbcC00OodbcC00?o0000ojiA[_n^DJh02_n^DJh00ol0003oXUfRoj9MXP0Eoj9MXP03
o`000?oW6>Oo000000Co^4Nh0ol0000@on4Nh@03o`000?oK9=_ofbCK00_ofbCK0_l0000<ooL8m`03
o`000?ol0ocoo0?l00coo0?l0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo4>lOoa3_402?oa3_400ol0003oc3?<
ol`cc005ol`cc003o`000?oL8mcog2?L00Cog2?L00?o0000om</dooC;=<01ooC;=<00ol0003o[U6^
ojiA[P0:ojiA[P03o`000?nRGJ;oXUfR01KoXUfR00?o0000okQ7^?nhAkP01_nhAkP3o`0000cohAkQ
00?o0000om/TfooK9=/03OoK9=/00ol0003om`SgooL8m`09ooL8m`Go00002Ool0o`2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ol@kaoo4>l@07oo4>l@03o`000?o<<lcoc3?<00Ooc3?<00?o0000om`Sg?oL8m`00_oL
8m`00ol0003odbcCom</d`08om</d`03o`000?n^DJko[U6^00Wo[U6^00?o0000oj9MX_nRGJ805onR
GJ800ol0003o^4NhokQ7^009okQ7^0?o00002OoQ7^400ol0003ofbCKom/Tf`0>om/Tf`Ko00001?og
2?L00ol0003onPGjooX5nP03ooX5nPGo00000_ol0o`2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on0OhooP7n006ooP7n003o`000?oa
3_7ol@ka00Gol@ka0_l0000;ol`cc004o`000?oL8mcog2?Lo`0000_odbcC00?o0000ojiA[_n^DJh0
2On^DJh00ol0003oXUfRoj9MXP0Foj9MXP03o`000?nhAkSo^4Nh00go^4Nh0ol00005on4Nh@03o`00
0?oK9=_ofbCK00oofbCK00?o0000onPGj?oX5nP00ooX5nP4o`0000_onPGj0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oh1oP00ol0003ol@kaoo4>
l@05oo4>l@03o`000?o<<lcoc3?<00coc3?<00?o0000om`Sg?l000002ooC;=<00ol0003o[U6^ojiA
[P07ojiA[P?o00006?nRGJ800ol0003o^4NhokQ7^00@okQ7^0?o000000?ohAkQo`000?oK9=/04?oK
9=/00ol0003oj1OXonPGj007onPGj003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooP7n003o`000?oa3_7ol@ka00?ol@ka0_l0000@ol`cc003o`000?oC;=?odbcC00[odbcC00?o0000
ojiA[_n^DJh00on^DJh4o`0000;oOh1o00?o0000oj9MX_nRGJ805OnRGJ800ol0003o^4NhokQ7^00D
okQ7^003o`000?oK9=_ofbCK013ofbCK00?o0000onPGj?oX5nP01ooX5nP00ol0003onPGjooX5nP0:
ooX5nP03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?ol@ka00?o0000ol`cc?o<<l`04?o<<l`00ol0
003odbcCom</d`0:om</d`03o`000?n^DJko000000?o00001omoP7l00ol0003oXUfRoj9MXP0Doj9M
XP03o`000?nhAkSo^4Nh01Co^4Nh00?o0000om/TfooK9=/03ooK9=/00ol0003oj1OXonPGj008onPG
j003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?oZ5N[ojQGZ00?o
jQGZ00?o0000oo4>lOl000004oo<<l`4o`0000WodbcC0_l0000<ogn0O`03o`000?nRGJ;oXUfR01?o
XUfR00?o0000okQ7^?nhAkP05OnhAkP00ol0003ofbCKom/Tf`0>om/Tf`03o`000?oX5nSoj1OX00So
j1OX00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ojQGZonXEjP05onXEjP03o`00
0?o<<lcoc3?<01;oc3?<00Co0000ohIiQ_n6NHKoQWV61Ol00003om</d`03o`000?moP7ooOh1o00go
Oh1o0ol0000@oj9MXP;o00006?nhAkP00ol0003ofbCKom/Tf`0=om/Tf`03o`000?oX5nSoj1OX00Wo
j1OX00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ojQGZonXEjP06onXEjP03o`00
0?o<<lcoc3?<017oc3?<00?o0000ohIiQ_n6NHH01on6NHH3o`00013oOh1o00?o0000odfbCOm=/Td0
1Ol00009oj9MXP;o000000?oN8Mho`000?nhAkP05onhAkP00ol0003ofbCKom/Tf`0=om/Tf`03o`00
0?oX5nSoj1OX00Woj1OX00?o0000ooX5n_oj1OX02?oj1OX2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?oZ5N[ojQGZ00OojQGZ00?o0000ol`cc?o<<l`03oo<<l`00ol0003oQWV6ohIi
QP0:ohIiQP03o`000?moP7ooOh1o00goOh1o00?o0000odfbCOm=/Td01_m=/Td4o`0000CoXUfR00?o
0000ogR7N?mhQgP00_mhQgP00ol0003o^4NhokQ7^00FokQ7^003o`000?oK9=_ofbCK00_ofbCK00?o
0000onPGj?oX5nP02ooX5nP00ol0003onPGjooX5nP06ooX5nP03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ojQGZ00?o0000ol`cc?o<<l`03oo<<l`00ol0003oQWV6ohIiQP0;ohIiQP03o`000?moP7oo
Oh1o00coOh1o00?o0000odfbCOm=/Td02_m=/Td4o`0000GoN8Mh00?o0000okQ7^?nhAkP05_nhAkP0
0ol0003ofbCKom/Tf`0:om/Tf`03o`000?oX5nSoj1OX00coj1OX00?o0000ooX5n_oj1OX01?oj1OX2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?og2?Oom`Sg00Wom`Sg00?o0000onXE
j_oZ5NX02OoZ5NX00ol0003oc3?<ol`cc00=ol`cc003o`000?n6NHKoQWV600coQWV600?o0000ogn0
OomoP7l03?moP7l00ol0003oCK9=odfbC@0;odfbC@03o`000?mA[U7o000000KoN8Mh00?o0000okQ7
^?nhAkP05_nhAkP00ol0003ofbCKom/Tf`09om/Tf`03o`000?oX5nSoj1OX00coj1OX00?o0000ooX5
n_oj1OX00ooj1OX00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
m`SgooL8m`08ooL8m`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ol`cc?o<<l`02?o<<l`4o`0000oo
QWV600?o0000ogn0OomoP7l02omoP7l00ol0003oCK9=odfbC@0;odfbC@04o`000?mA[U7oDJiAo`00
00OoN8Mh00?o0000okQ7^?nhAkP05OnhAkP00ol0003ofbCKom/Tf`08om/Tf`03o`000?oX5nSoj1OX
00goj1OX00?o0000ooX5n_oj1OX00_oj1OX00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003om`SgooL8m`08ooL8m`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ol`cc?o<
<l`00oo<<l`5o`0000?oRWF:00?o0000ohIiQ_n6NHH03_n6NHH00ol0003oOh1oogn0O`0:ogn0O`03
o`000?m=/TgoCK9=00[oCK9=00Go0000oe6^DOmA[U7oDJiAo`000007ogR7N003o`000?nhAkSo^4Nh
01Go^4Nh00?o0000om/TfooK9=/02?oK9=/00ol0003oj1OXonPGj00=onPGj003o`000?oj1O[onPGj
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooL8moog2?L02?og2?L00ol0003ojQGZonXEjP0<onXEjPGo00002On:MHX00ol0003o
QWV6ohIiQP0<ohIiQP;o00003?moP7l00ol0003oCK9=odfbC@0:odfbC@05o`000?mA[U7oDJiAoe6^
DOl000002?mhQgP00ol0003o^4NhokQ7^00DokQ7^0?o00001ooK9=/00ol0003oj1OXonPGj00>onPG
j003o`000?oj1O[o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?og2?Oom`Sg00Oo
m`Sg00?o0000onXEj_oZ5NX03?oZ5NX01?l0003ob3O8olPgb?l0000;ohYeRP03o`000?n6NHKoQWV6
00_oQWV600Co0000occ3??ll`cco00002_moP7l00ol0003oCK9=odfbC@0:odfbC@03o`000?mA[U7o
DJiA00;oDJiA00?o0000ogR7N?mhQgP01_mhQgP00ol0003o^4NhokQ7^00AokQ7^0?o00000oo1?/40
0ol0003ofbCKom/Tf`04om/Tf`03o`000?oX5nSoj1OX00goj1OX1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooL8m`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000olPgb?o8=lP00_o8=lP0
0ol0003oRWF:ohYeRP08ohYeRP03o`000?n6NHKoQWV600[oQWV600?o0000occ3??ll`c`00_ll`c`0
0ol0003oOh1oogn0O`03ogn0O`Go00002om=/Td00ol0003oDJiAoe6^D@03oe6^D@03o`000?mhQgSo
N8Mh00OoN8Mh00?o0000okQ7^?nhAkP03_nhAkP2o`0000Oo`Ck100?o0000om/TfooK9=/00_oK9=/0
0ol0003oj1OXonPGj00=onPGj003o`000?oi1_Won@Ki00;on@Ki00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oi1_T00ol0003om`SgooL8m`05ooL8m`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000olPg
b?o8=lP00oo8=lP00ol0003oRWF:ohYeRP09ohYeRP03o`000?n6NHKoQWV600SoQWV600?o0000occ3
??ll`c`01?ll`c`5o`0000Co>l@k00?o0000odfbCOm=/Td02Om=/Td00ol0003oDJiAoe6^D@03oe6^
D@03o`000?mhQgSoN8Mh00SoN8Mh00?o0000okQ7^?nhAkP02_nhAkP3o`0000[o`Ck100Go0000om/T
fooK9=_ofbCKo`00000>onPGj003o`000?oi1_Won@Ki00Con@Ki0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooT6
nOoi1_T01Ooi1_T00ol0003om`SgooL8m`03ooL8m`03o`000?oZ5N[ojQGZ00[ojQGZ00?o0000olPg
b?o8=lP01?o8=lP00ol0003oRWF:ohYeRP09ohYeRP03o`000?n6NHKoQWV600OoQWV600?o0000occ3
??ll`c`01Oll`c`00ol0003o>l@koc_4>`07oc_4>`03o`000?m=/TgoCK9=00OoCK9=00?o0000oe6^
DOmA[U401?mA[U400ol0003oN8MhogR7N008ogR7N003o`000?nhAkSo^4Nh00So^4Nh0_l0000>ol4n
`@Co00003?oX5nP2o`0000Won@Ki00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003on@KiooT6n@07ooT6n@;o00000oog2?L00ol0
003ojQGZonXEjP09onXEjP03o`000?o8=lSob3O800Kob3O800?o0000ohYeR_n:MHX02On:MHX00ol0
003oQWV6ohIiQP05ohIiQP03o`000?ll`cco?<<l00Ko?<<l00?o0000oc_4>olka3/02?lka3/00ol0
003oCK9=odfbC@06odfbC@03o`000?mA[U7oDJiA00CoDJiA00?o0000ogR7N?mhQgP02OmhQgP4o`00
00?o^4Nh0ol0000@ol4n`@05o`000?oU6^GoiA[UonDJiOl000002_oX5nP00ol0003on@KiooT6n@0:
ooT6n@Ko00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003on@KiooT6n@0:ooT6n@04o`000?og2?Oom`Sgo`0000[ojQGZ00?o0000olPgb?o8=lP01oo8=lP0
0ol0003oRWF:ohYeRP09ohYeRP03o`000?n6NHKoQWV600CoQWV600?o0000occ3??ll`c`01oll`c`0
0ol0003o>l@koc_4>`08oc_4>`;o00001_m=/Td00ol0003oDJiAoe6^D@05oe6^D@03o`000?mhQgSo
N8Mh00WoN8Mh00Co0000oiA[U?nDJiCoU6^D0ol0000Bol4n`@03o`000?oU6^GoiA[U00?oiA[U0_l0
0006onPGj0;o00003Ooi1_T00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003on@KiooT6n@0<ooT6n@;o00002_oZ5NX00ol0003ob3O8olPgb008olPgb003o`000?n:MH[o
RWF:00[oRWF:00?o0000ohIiQ_n6NHH00_n6NHH00ol0003o?<<locc3?008occ3?003o`000?lka3_o
>l@k00Ko>l@k0_l00002ob;M8P03o`000?m=/TgoCK9=00;oCK9=00?o0000oe6^DOmA[U401_mA[U40
0ol0003oN8MhogR7N008ogR7N003o`000?nDJiCoU6^D00CoU6^D00?o0000ol4n`Oo1?/403oo1?/40
0ol0003oiA[UonDJi@06onDJi@;o00000ooX5nP00ol0003on@KiooT6n@0=ooT6n@03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oi1_Won@Ki
00kon@Ki00?o0000onXEj_oZ5NX01ooZ5NX00ol0003ob3O8olPgb00:olPgb003o`000?n:MH[oRWF:
00WoRWF:00Go0000ohIiQ_n6NHKoQWV6o`00000;occ3?003o`000?lka3_o>l@k00Co>l@k0_l00005
ob;M8P05o`000?m=/TgoCK9=odfbCOl000002?mA[U400ol0003oN8MhogR7N008ogR7N003o`000?nD
JiCoU6^D00GoU6^D00?o0000ol4n`Oo1?/403_o1?/400ol0003oiA[UonDJi@08onDJi@03o`000?oX
5nSo000000oon@Ki00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017on@Ki00?o0000onXEj_oZ5NX01_oZ5NX00ol0003ob3O8
olPgb00;olPgb003o`000?n:MH[oRWF:00WoRWF:00Co0000ohIiQ_n6NHKo00003?ll`c`00ol0003o
>l@koc_4>`02oc_4>`;o00002?lRgB800ol0003oCK9=o`000009oe6^D@03o`000?mhQgSoN8Mh00So
N8Mh00?o0000oiA[U?nDJi@01OnDJi@00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?oU6^GoiA[U00[o
iA[U00?o0000ooT6nOoi1_T03_oi1_T00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooT6n@03o`00
0?oZ5N[ojQGZ00CojQGZ00?o0000olPgb?o8=lP03?o8=lP00ol0003oRWF:ohYeRP0:ohYeRP?o0000
3?ll`c`00ol0003o>l@koc_4>`02o`0000_o8]dR00?o0000oe6^DOmA[U402?mA[U400ol0003oN8Mh
ogR7N007ogR7N003o`000?nDJiCoU6^D00OoU6^D00?o0000ol4n`Oo1?/403?o1?/400ol0003oiA[U
onDJi@0;onDJi@;o00003_oi1_T00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003on@KiooT6n@0?ooT6n@?o00000ooZ
5NX00ol0003ob3O8olPgb00>olPgb003o`000?n:MH[oRWF:00SoRWF:00Co0000odBkA?m4^dCoA;]4
0_l0000:occ3?0?o00003OlRgB800ol0003oDJiAoe6^D@08oe6^D@03o`000?mhQgSoN8Mh00OoN8Mh
00?o0000oiA[U?nDJi@01onDJi@00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?oU6^GoiA[U00coiA[U
00?o0000oo`3o?l000000_l0000:ooT6n@03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oi1_Won@Ki00con@Ki0_l0
0003oo<<l`03o`000?oZ5N[o0000017ob3O800?o0000ohYeR_n:MHX01on:MHX00ol0003oA;]4odBk
A004odBkA0;o00002?ll`c`00ol0003o8]dRob;M8P0>ob;M8P;o00002?mA[U400ol0003oN8MhogR7
N006ogR7N003o`000?nDJiCoU6^D00WoU6^D00?o0000ol4n`Oo1?/402Oo1?/400ol0003oiA[UonDJ
i@0=onDJi@03o`000?ol0ocoo0?l00;oo0?l0ol00007ooT6n@03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oi1_Wo
n@Ki00Won@Ki0_l00006oo<<l`03o`000?o8=lSob3O8013ob3O800?o0000ohYeR_n:MHX01_n:MHX0
0ol0003oA;]4odBkA007odBkA003o`000?ll`cco?<<l00Co?<<l0ol0000>ob;M8P03o`000?lSg2?o
8m`S00?o00001OmA[U400ol0003oN8MhogR7N006ogR7N003o`000?nDJiCoU6^D00[oU6^D00?o0000
ol4n`Oo1?/402?o1?/400ol0003oiA[UonDJi@0=onDJi@03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooT6n@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oi1_Won@Ki00Gon@Ki0ol00008oo<<l`03o`000?o8=lSob3O8
017ob3O800Co0000ohYeR_n:MH[oRWF:1?l0000;odBkA0;o000000Co?<<lo`000?l0003o00000ol?
l0l2o`0000_o8]dR00?o0000ob?L8olSg2<01?lSg2<2o`0000?oDJiA00?o0000ogR7N?mhQgP01_mh
QgP00ol0003oU6^DoiA[U00:oiA[U003o`000?o1?/7o`Ck100Oo`Ck100?o0000onDJiOoU6^D03_oU
6^D00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oi1_Won@Ki00;on@Ki0_l0000<oo<<l`03o`000?o8=lSo
b3O8013ob3O81?l00003ogf2O@03o`000?m4^dCoA;]400_oA;]400?o0000o`o`3ol?l0l01_l?l0l0
0ol0003o8]dRob;M8P07ob;M8P03o`000?lSg2?o8m`S00Oo8m`S3?l0000>oiA[U003o`000?o1?/7o
`Ck100Ko`Ck100?o0000onDJiOoU6^D03_oU6^D00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooT6
nOl0003o00003_oc3?<00ol0003ob3O8olPgb00?olPgb003o`000?mmPWgoOH9m00KoOH9m00?o0000
odBkA?m4^d@02_m4^d@00ol0003o3o0?o`o`3`07o`o`3`;o00001_lRgB800ol0003o8m`Sob?L8`08
ob?L8`03o`000?mEZUGoEJYE00SoEJYE00?o0000oiA[U?nDJi@03?nDJi@00ol0003o`Ck1ol4n`@05
ol4n`@03o`000?oU6^GoiA[U00ooiA[U0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<03_oc3?<00ol0
003ob3O8olPgb00>olPgb003o`000?mmPWgoOH9m00OoOH9m00?o0000odBkA?m4^d@02_m4^d@00ol0
003o3o0?o`o`3`09o`o`3`;o00000olRgB800ol0003o8m`Sob?L8`09ob?L8`03o`000?mEZUGoEJYE
00WoEJYE00?o0000oiA[U?nDJi@02_nDJi@4o`0000Co`Ck100?o0000onDJiOoU6^D04?oU6^D01?l0
003on`Cko`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo<<looc3?<03ooc3?<@o`0000[oOH9m00?o0000odBk
A?m4^d@02Om4^d@00ol0003o3_4>o`00000<o`o`3`05o`000?lRgB;o0000o`Wf2Ol000002_lSg2<0
0ol0003oEJYEoeFZE@09oeFZE@03o`000?nDJiCoU6^D00OoU6^D0ol00004ojaC[0?o000000?o`Ck1
o`000?oU6^D04OoU6^D01?l0003on`Ckoo/4nook1?/2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003ol`ccoo<<l`0?
oo<<l`03o`000?nn@Kko_T6n00co_T6n00?o0000ogf2OOmmPWd02OmmPWd00ol0003oA;]4odBkA007
odBkA004o`000?l>l@ko3_4>o`0000go3o0?00Go0000o`Wf2Ol9mPWo2OH9o`000009ob?L8`03o`00
0?mEZUGoEJYE00[oEJYE00?o0000oiA[U?nDJi@00onDJi@3o`0000[o[5>/00?o0000onDJiOoU6^D0
4?oU6^D00ol0003on`Ckoo/4n`04oo/4n`;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo<<looc3?<03ooc3?<00ol0003o_T6noki1_P0<oki1_P03o`000?mm
PWgoOH9m00WoOH9m00?o0000odBkA?m4^d@01_m4^d@00ol0003o3_4>o`ka3P02o`ka3P03o`000?l?
l0oo3o0?00[o3o0?00?o0000o`Wf2Ol9mPT00_l9mPT00ol0003o8m`Sob?L8`06ob?L8`03o`000?mE
ZUGoEJYE00[oEJYE00?o0000oiA[U?nDJi@00ol0000=ojaC[003o`000?oU6^GoiA[U013oiA[U00?o
0000oo/4nook1?/01_ok1?/2o`0000Woo0?l0_l00004ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003ol`ccoo<<l`0=oo<<l`?o00003onn@Kh0
0ol0003oOH9mogf2O@08ogf2O@03o`000?m4^dCoA;]400GoA;]400?o0000o`ka3_l>l@h00ol>l@h0
0ol0003o3o0?o`o`3`0:o`o`3`03o`000?l9mPWo2OH900?o2OH900?o0000ob?L8olSg2<01OlSg2<0
0ol0003oEJYEoeFZE@0;oeFZE@;o00004On/Dj`00ol0003oiA[UonDJi@0?onDJi@03o`000?ok1?_o
n`Ck00Son`Ck0_l00007oo`3o003o`000?on0OkooP7n00CooP7n00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003ol`ccoo<<l`09oo<<l`Go00000_oV6NH00ol0
003o_T6noki1_P0=oki1_P03o`000?mmPWgoOH9m00WoOH9m00?o0000odBkA?m4^d@01?m4^d@00ol0
003o3_4>o`ka3P04o`ka3P03o`000?l?l0oo3o0?00So3o0?00?o0000o`Wf2Ol9mPT01Ol9mPT00ol0
003o8m`Sob?L8`04ob?L8`03o`000?mEZUGoEJYE00_oEJYE00?o0000ojaC[?n/Dj`04?n/Dj`00ol0
003oiA[UonDJi@0?onDJi@03o`000?ok1?_on`Ck00[on`Ck0_l00004oo`3o003o`000?on0OkooP7n
00KooP7n0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oc3??ol`cc00Col`cc1Ol00007onHIiP03
o`000?nn@Kko_T6n00go_T6n00?o0000ogf2OOmmPWd02OmmPWd00ol0003oA;]4odBkA003odBkA003
o`000?l>l@ko3_4>00Go3_4>00?o0000o`o`3ol?l0l02?l?l0l00ol0003o2OH9o`Wf2@06o`Wf2@03
o`000?lSg2?o8m`S00?o8m`S00?o0000oeFZEOmEZUD02omEZUD00ol0003o[5>/ojaC[00@ojaC[003
o`000?oU6^GoiA[U00ooiA[U00?o0000oo/4nook1?/03?ok1?/2o`000003oo`3o?l0003ooP7n00[o
oP7n00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo<<lol00000
1?l0000<onHIiP03o`000?nn@Kko_T6n00ko_T6n00?o0000ogf2OOmmPWd02?mmPWd00ol0003oA;]4
odBkA002odBkA003o`000?l>l@ko3_4>00Oo3_4>00?o0000o`o`3ol?l0l01ol?l0l00ol0003o2OH9
o`Wf2@07o`Wf2@03o`000?lSg2?o8m`S00;o8m`S00?o0000oeFZEOmEZUD02omEZUD00ol0003o[5>/
ojaC[00AojaC[003o`000?oU6^GoiA[U00goiA[U00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP0;ooh1oP;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oiQWV00?o0000oki1__nn@Kh03_nn
@Kh00ol0003oOH9mogf2O@09ogf2O@04o`000?m4^dCoA;]4o`0000[o3_4>00?o0000o`o`3ol?l0l0
1ol?l0l00ol0003o2OH9o`Wf2@08o`Wf2@05o`000?lSg2?o8m`Sob?L8ol000003OmEZUD00ol0003o
[5>/ojaC[00AojaC[0?o00003OoU6^D00ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00go
oP7n00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;onPGj00?o0000onHIi_oV6NH03ooV6NH00ol0003o
_T6noki1_P0>oki1_P03o`000?mmPWgoOH9m00SoOH9m1Ol0000;o`ka3P03o`000?l?l0oo3o0?00Ko
3o0?00?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o8m`Sob?L8ol0000=oeFZE@03o`000?n/Djco[5>/
017o[5>/00?o0000omDZeOoE:]D00ol0000:onDJi@Co00003Ook1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooX5nP03o`000?oV6NKoiQWV00koiQWV00?o0000oki1
__nn@Kh03_nn@Kh00ol0003oOH9mogf2O@07ogf2O@03o`000?lXebSo:=LX00?o:=LX00?o0000o`ka
3_l>l@h02?l>l@h00ol0003o3o0?o`o`3`05o`o`3`03o`000?l9mPWo2OH900[o2OH91Ol0000<oeFZ
E@03o`000?n/Djco[5>/013o[5>/00?o0000omDZeOoE:]D01?oE:]D3o`0000KoiA[U00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Son`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0003oiQWVonHIiP0=onHIiP03o`000?nn@Kko_T6n00oo
_T6n00?o0000ogf2OOmmPWd01?mmPWd2o`0000Oo:=LX00?o0000o`ka3_l>l@h01ol>l@hEo`0000Go
8m`S00?o0000oeFZEOmEZUD02?mEZUD3o`00013o[5>/00?o0000omDZeOoE:]D02?oE:]D3o`0000;o
iA[U00?o0000ooX5n_oj1OX02?oj1OX5o`0000?on`Ck00?o0000ooh1o_on0Oh04?on0Oh00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oiQWVonHIiP0;onHIiPCo0000
3onn@Kh00ol0003oOH9mogf2O@03ogf2O@03o`000?lXebSo:=LX00So:=LX00?o0000o`ka3_l>l@h0
1?l>l@h2o`0000So0_d200?o0000o`3o0?l0o`002?l0o`000ol0003o8m`Sob?L8`05ob?L8`;o0000
1_mEZUD2o`0000?oJiA[00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oeB[EomDZe@0<omDZe@;o0000
4?oj1OX3o`0001?ooP7n00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00KonPGj00?o
0000onHIi_oV6NH02OoV6NH00ol0003okA;]o`000002ol<l``?o00003?nn@Kh01?l0003oOH9mogf2
OOmmPWd2o`0000co:=LX00?o0000o`ka3_l>l@h00_l>l@h00ol0003o0_d2o`;m0P08o`;m0P03o`00
0?l0o`3o0?l000So0?l000?o0000ob?L8olSg2<01olSg2<00ol0003oEJYEoeFZE@02oeFZE@03o`00
0?m[U6_oJiA[00CoJiA[0_l0000;ojaC[003o`000?oE:]GoeB[E00coeB[E00?o0000onhAk_l00000
4_oj1OX00ol0003ooP7nooh1oP0@ooh1oP;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00OonPGj00?o
0000onHIi_oV6NH01_oV6NH2o`0000;okA;]00?o0000ol<l`oo3?<<00oo3?<<3o`0000[o_T6n00?o
0000ogf2OOl000003olXebP01?l0003o3_4>o`000?l0000;o`;m0P03o`000?l0o`3o0?l000So0?l0
00?o0000ob?L8olSg2<02?lSg2<01?l0003oEJYEo`000?l00009of^DJ`03o`000?n/Djco[5>/00Oo
[5>/00?o0000omDZeOoE:]D03?oE:]D01?l0003okQ7^onhAk_l0000CooX5nP03o`000?on0OkooP7n
00cooP7n0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oV6NKoiQWV00Co
iQWV00?o0000ondBkOo]4^d00oo]4^d00ol0003o`cc3ol<l``05ol<l``?o00001_nn@Kh4o`00013o
:=LX00?o0000o`;m0_l2o@803?l2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lSg2?o8m`S00Wo
8m`S00?o0000of^DJom[U6/02_m[U6/2o`0000Ko[5>/00?o0000omDZeOoE:]D03?oE:]D00ol0003o
kQ7^onhAkP02onhAkP03o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002oon0Oh2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00WonPGj00Co0000onHIi_oV6NKo
iQWV0_l00006ondBk@03o`000?o3?<?o`cc300So`cc30ol000000onn@Kko0000o`000004og6>L@03
o`000?lXebSo:=LX00go:=LX00?o0000o`;m0_l2o@803?l2o@800ol0003o0?l0o`3o0007o`3o0003
o`000?lSg2?o8m`S00Wo8m`S00?o0000of^DJom[U6/03?m[U6/00ol0003o[5>/ojaC[003o`0000ko
eB[E00?o0000onhAk_o^4Nh00oo^4Nh00ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?on0Oh2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00[o
nPGj00?o0000onHIi_l000002?o]4^d00ol0003o`cc3ol<l``0;ol<l``03o`000?maSW7oLHia00Go
LHia00?o0000obSG:?lXebP03?lXebP00ol0003o0_d2o`;m0P0<o`;m0P03o`000?l0o`3o0?l000Oo
0?l000?o0000ob?L8olSg2<02?lSg2<2o`0000ooJiA[0_l00002olHiaP03o`000?oE:]GoeB[E00_o
eB[E00?o0000onhAk_o^4Nh01?o^4Nh00ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ooh1o_on0Oh00_on0Oh3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000ondBkOo]4^d0
1oo]4^d00ol0003o`cc3ol<l``0;ol<l``03o`000?maSW7oLHia00KoLHia00?o0000obSG:?lXebP0
2olXebP2o`0000go0_d200?o0000o`3o0?l0o`001ol0o`000ol0003o8m`Sob?L8`07ob?L8`04o`00
0?lhacSo><Lho`0000koJiA[00?o0000olHia_o6>LH00_o6>LH00ol0003oeB[EomDZe@09omDZe@03
o`000?o^4NkokQ7^00KokQ7^00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?on0Oko0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooX5n_oj1OX02_oj1OX2o`0000Wo
kA;]00?o0000ol<l`oo3?<<02oo3?<<00ol0003oLHiaog6>L@07og6>L@03o`000?lXebSo:=LX00Wo
:=LX00Co0000o`Sg2?l8m`So00003?l2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lSg2?o8m`S
00Ko8m`S00Go0000ocS7>?lhacSo><Lho`00000>of^DJ`03o`000?o6>LKoaSW600?oaSW600?o0000
omDZeOoE:]D01ooE:]D00ol0003okQ7^onhAkP07onhAkP03o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oj1O[onPGj
00WonPGj00Co0000ooT6nOoi1_Wo00002Oo]4^d00ol0003o`cc3ol<l``09ol<l``03o`000?maSW7o
LHia00WoLHia00?o0000obSG:?lXebP01olXebP00ol0003o2?L8o`Sg2002o`Sg2003o`000?l2o@;o
0_d200Wo0_d200?o0000o`3o0?l0o`001ol0o`000ol0003o8m`Sob?L8`05ob?L8`03o`000?lhacSo
><Lh00?o><Lh00?o0000of^DJom[U6/02_m[U6/00ol0003oaSW6olHiaP05olHiaP03o`000?oE:]Go
eB[E00GoeB[E00?o0000onhAk_o^4Nh02?o^4Nh00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000WonPGj00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okA;]ondBk@06ondBk@03o`000?o3?<?o`cc300Wo`cc300?o0000og6>
LOmaSW402_maSW400ol0003o:=LXobSG:005obSG:003o`000?l8m`So2?L800Co2?L800?o0000o`;m
0_l2o@802?l2o@800ol0003o0?l0o`3o0007o`3o0003o`000?lSg2?o8m`S00Co8m`S00?o0000ocS7
>?lhacP01?lhacP00ol0003oJiA[of^DJ`0:of^DJ`03o`000?o6>LKoaSW600KoaSW600?o0000omDZ
eOoE:]D00ooE:]D00ol0003okQ7^onhAkP09onhAkP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooj1OX00ol0003o
n@KiooT6n@03ooT6n@03o`000?o]4^gokA;]00KokA;]00?o0000ol<l`oo3?<<02Oo3?<<00ol0003o
LHiaog6>L@0;og6>L@03o`000?lXebSo:=LX00?o:=LX00?o0000o`Sg2?l8m`P01_l8m`P00ol0003o
0_d2o`;m0P08o`;m0P03o`000?l0o`3o0?l000Ko0?l000?o0000ob?L8olSg2<00_lSg2<2o`0000So
><Lh00?o0000of^DJom[U6/02Om[U6/00ol0003oaSW6olHiaP07olHiaP05o`000?oE:]GoeB[EomDZ
eOl000003Oo^4Nh00ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooj1O[o0000ooT6n@06ooT6n@03
o`000?o]4^gokA;]00GokA;]00?o0000ol<l`oo3?<<02Oo3?<<00ol0003oLHiaog6>L@0<og6>L@05
o`000?lXebSo:=LXobSG:?l000002_l8m`P00ol0003o0_d2o`;m0P07o`;m0P03o`000?l0o`3o0?l0
00Ko0?l000?o0000ob?L8ol000000_l000000olBkA;o0000ocS7>007ocS7>003o`000?m[U6_oJiA[
00SoJiA[00?o0000olHia_o6>LH02Oo6>LH00ol0003oeB[Eo`00000=onhAkPCo00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000ondBkOo]4^d01?o]4^d00ol0003o`cc3ol<l``09ol<l``03
o`000?maSW7oLHia00goLHia00?o0000obSG:?l000003?l8m`P:o`0000Oo0?l00ol00005oa;]4P03
o`000?lhacSo><Lh00Ko><Lh00?o0000of^DJom[U6/01om[U6/00ol0003oaSW6olHiaP0:olHiaP03
o`000?o^4NkokQ7^00_okQ7^00?o0000oo/4nook1?/00_ok1?/3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o]4^gokA;]00GokA;]00?o0000ol<l`oo3?<<01oo3?<<00ol0003oLHiaog6>L@0?og6>L@;o0000
2ol8m`P00ol0003o2?L8o`Sg2007o`Sg2003o`000?l0o`3o0?l000;o0?l00ol00008oa;]4P03o`00
0?lhacSo><Lh00Ko><Lh00?o0000of^DJom[U6/01om[U6/00ol0003oaSW6olHiaP0:olHiaP03o`00
0?o^4NkokQ7^00[okQ7^00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o]4^gokA;]00CokA;]00?o0000ol<l`oo3?<<01oo3?<<00ol0003oLHiaog6>
L@0>og6>L@04o`000?lbcC;o</dbo`0000Wo2?L800?o0000o`Sg2?l8m`P02Ol8m`P01?l0003o0?l0
o`000?l0000<oa;]4P03o`000?lhacSo><Lh00Ko><Lh00?o0000of^DJom[U6/01_m[U6/00ol0003o
aSW6olHiaP0;olHiaP03o`000?o^4NkokQ7^00OokQ7^0_l00009oo/4n`03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000ondBkOo]4^d00oo]4^d>o`0000goLHia00?o0000oc;=<_lbcC80
0_lbcC800ol0003o2?L8o`Sg2005o`Sg2003o`000?l8m`So2?L800_o2?L800?o0000oa;]4_lBkA80
3?lBkA800ol0003o><LhocS7>006ocS7>003o`000?m[U6_oJiA[00GoJiA[00?o0000olHia_o6>LH0
3?o6>LH00ol0003okQ7^onhAkP06onhAkP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okA;]ondBkOo]4^go000000_ocC;=00?o0000og2?L?m`Sg000ol00009og6>L@03o`00
0?lbcC;o</db00Co</db00?o0000o`Sg2?l8m`P00ol8m`P00ol0003o2?L8o`Sg200<o`Sg2003o`00
0?lBkA;o4^dB00go4^dB00?o0000ocS7>?lhacP01_lhacP00ol0003oJiA[of^DJ`03of^DJ`?o0000
3Oo6>LH00ol0003okQ7^onhAkP05onhAkP03o`000?ok1?_on`Ck00con`Ck0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cocC;=00?o0000og2?L?m`Sg000om`Sg03o`0000GoLHia00?o0000oc;=<_lbcC801_lb
cC801Ol0003o2?L8o`Sg2?l8m`So000000oo2?L800?o0000oa;]4_lBkA803OlBkA800ol0003o><Lh
ocS7>006ocS7>003o`000?m[U6_oJiA[00?o00000on8MhP00ol0003oaSW6olHiaP0;olHiaP03o`00
0?o^4NkokQ7^00?okQ7^00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003oo@;m003o`000?o=</gocC;=00[ocC;=00?o0000og2?L?m`Sg001_m`Sg03o`000003og6>LOl0
003o</db00Wo</db00?o0000o`Sg2?l000004?l8m`P00ol0003o4^dBoa;]4P0=oa;]4P03o`000?lh
acSo><Lh00Oo><Lh0_l00007ohQgR003o`000?o6>LKoaSW600[oaSW600Co0000onhAk_o^4NkokQ7^
0ol0000?oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom0_d00?o0000oldbcOo=
</d02_o=</d00ol0003oL8m`og2?L009og2?L003o`000?lbcC;o</db00[o</db00?o0000o`Sg2?l8
m`P03ol8m`P00ol0003o4^dBoa;]4P0>oa;]4P03o`000?lhacSo><Lh00Ko><Lh00?o0000ohQgR?n8
MhP01on8MhP4o`0000SoaSW600Co0000onhAk_o^4Nko00000ooe2_D2o`0000gon`Ck00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?od2oCom0_d00Oom0_d00?o0000oldbcOo=</d02Oo=</d00ol0003o
L8m`og2?L00:og2?L003o`000?lbcC;o</db00[o</db00?o0000o`Sg2?l8m`P03ol8m`P00ol0003o
4^dBoa;]4P0>oa;]4P03o`000?lhacSo><Lh00Go><Lh00?o0000ohQgR?n8MhP02?n8MhP01?l0003o
cC;=oldbcOo=</d7o`0000;oaSW60_l00006ooD:m@;o00003?ok1?/00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000oo@;m?od2o@02?od2o@00ol0003ocC;=oldbc@08oldbc@03o`000?m`Sg3oL8m`00[o
L8m`00?o0000oc;=<_lbcC802olbcC800ol0003o2?L8o`Sg200>o`Sg2003o`000?lBkA;o4^dB00ko
4^dB1Ol00002ocS7>003o`000?n8MhSoR7N800WoR7N800?o0000oldbcOo=</d02?o=</d3o`0000Wo
m@[e0_l0000:oo/4n`03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om0_doo@;m007oo@;m003o`00
0?o=</gocC;=00SocC;=00?o0000og2?L?m`Sg002_m`Sg000ol0003o</dboc;=<P0:oc;=<P;o0000
3_l8m`P3o`0000go4^dB0ol00005odFjA@;o00002on8MhP00ol0003ocC;=oldbc@0;oldbc@;o0000
2_oe2_D2o`0000Oon`Ck0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?od2oCom0_d00Oom0_d00?o0000oldbcOo=</d02?o=</d>o`0000Wo</db0ol000000olWf2Oo0000
o`Sg200:o`Sg20?o00000_lJiAX00ol0003o4^dBoa;]4P09oa;]4P;o00002Om5^TD00ol0003oR7N8
ohQgR009ohQgR003o`000?o=</gocC;=00_ocC;=00?o0000on<Lhol000002ooe2_D2o`0000Con`Ck
00Co0000oo`3o?ol0ocoo0?l0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?od2oCom0_d00Kom0_d00?o0000oldbcOo=</d02?o=</d00ol0003oKi1_
ofn@K`0:ofn@K`03o`000?lbcC;o</db00Co</db0ol00005obOH9`03o`000?l8m`So2?L800Co2?L8
1?l00006oa[U6P03o`000?lBkA;o4^dB00Ko4^dB0_l0000;odFjA@03o`000?n8MhSoR7N800WoR7N8
00?o0000oldbcOo=</d02_o=</d01Ol0003ohacSon<LhooS7>?o000000com@[e0_l000000ook1?_o
0000oo`3o005oo`3o003o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003ocC;=oldbc@07oldbc@03o`00
0?m_T6ooKi1_00_oKi1_00?o0000oc;=<_lbcC800_lbcC82o`0000Wo9mPW00?o0000o`Sg2?l8m`P0
0ol0000;oa[U6P03o`000?lBkA;o4^dB00;o4^dB0ol0000>odFjA@03o`000?n8MhSoR7N800OoR7N8
00?o0000oldbcOo=</d02oo=</d00ol0003ohacSon<Lh`02on<Lh`03o`000?oe2_Gom@[e00_om@[e
00?o0000oo`3o?ol0o`01_ol0o`2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000oo@;m?od2o@01ood2o@00ol0003ocC;=oldbc@05oldbc@?o00003Om_
T6l4o`0000_o9mPW0ol0000?oa[U6P04o`000?lBkA;o0000o`00017oAKY500?o0000ohQgR?n8MhP0
1on8MhP00ol0003ocC;=oldbc@0:oldbc@03o`000?oS7>?ohacS00CohacS00?o0000ooD:mOoe2_D0
1ooe2_D3o`0000_oo0?l1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om0_doo@;
m006oo@;m003o`000?o=</gocC;=00;ocC;=0ol00003ojiA[P03o`000?m_T6ooKi1_00[oKi1_00?o
0000obOH9olWf2L02olWf2L00ol0003o8m`So`00000Aoa[U6P03o`000?m5^TGoAKY5017oAKY500?o
0000ohQgR?n8MhP01on8MhP00ol0003ocC;=oldbc@0:oldbc@03o`000?oS7>?ohacS00GohacS00Co
0000ooD:mOoe2_Gom@[e1Ol00002ooP7n003o`000?ol0ocoo0?l00Woo0?l00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om0_doo@;m005oo@;m0?o0000
00?ocC;=o`000?l000001on^DJh00ol0003oKi1_ofn@K`08ofn@K`?o00002_lWf2L2o`0000;o8m`S
00?o0000oa[U6_lJiAX03olJiAX00ol0003oAKY5odFjA@0AodFjA@03o`000?n8MhSoR7N800OoR7N8
00?o0000oldbcOo=</d02Oo=</d00ol0003ohacSon<Lh`07on<Lh`?o00001ooh1oP00ol0003oo0?l
oo`3o009oo`3o003o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om0_d0_l00003onhAkP03o`000?n^DJko[U6^00So[U6^0_l00006ofn@K`;o00000omM
XUd00ol0003o9mPWobOH9`06obOH9`03o`000?lSg2?o8m`S00?o8m`S00?o0000oa[U6_lJiAX03_lJ
iAX00ol0003oAKY5odFjA@0BodFjA@03o`000?n8MhSoR7N800GoR7N800?o0000oldbcOo=</d02Oo=
</d00ol0003ohacSon<Lh`08on<Lh`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo`3o?ol0o`02?ol
0o`00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo^4Nh00ol0003o[U6^ojiA[P0:ojiA[P03o`000?m_T6ooKi1_00;oKi1_00?o0000
oefRGOmMXUd01?mMXUd00ol0003o9mPWobOH9`04obOH9`03o`000?lSg2?o8m`S00Co8m`S00?o0000
oa[U6_lJiAX03_lJiAX00ol0003oAKY5odFjA@0BodFjA@[o00002_o=</d00ol0003ohacSon<Lh`08
on<Lh`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onhAk_o^4Nh01?o^4Nh0
0ol0003o[U6^ojiA[P0:ojiA[P04o`000?m_T6oo0000o`0000SoGJ9M00Co0000obOH9olWf2Oo9mPW
0_l00007ob?L8`03o`000?lJiA[o6^DJ00ko6^DJ00?o0000odFjAOm5^TD04_m5^TD00ol0003oYEZU
ojEJY@07ojEJY@03o`000?o=</gocC;=00KocC;=00?o0000on<LhooS7><02_oS7><00ol0003on0Oh
ooP7n006ooP7n003o`000?ol0ocoo0?l00Soo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onhAk_o^4Nh01?o^4Nh00ol0003o[U6^ojiA[P0;ojiA[P03o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obOH9ol000002OlSg2<00ol0003o6^DJoa[U6P0>oa[U6P;o0000
4_m5^TD00ol0003oYEZUojEJY@09ojEJY@;o00001_o=</d00ol0003ohacSon<Lh`0:on<Lh`03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003okQ7^onhAkP05onhAkP03o`000?n^DJko[U6^00[o[U6^00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa[U6_lJiAX03_lJiAX00ol0003o>/Djo`00
0002o`0000ooAKY500?o0000ojEJYOnUFZD02onUFZD00ol0003ocC;=oldbc@03o`0000gohacS00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o^4NkokQ7^00GokQ7^00?o0000ojiA[_n^DJh02On^DJh2
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lJiA[o6^DJ00co6^DJ00?o0000oc[5>_ljaCX00oljaCX3
o`0000coAKY500?o0000ojEJYOnUFZD03?nUFZD2o`0000;ohAkQ00?o0000on<LhooS7><03?oS7><0
0ol0003on0OhooP7n005ooP7n003o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o[U6^ojiA[P07ojiA
[P03o`000?n`Ck3o000000[oGJ9M00Co0000oe:]D_mB[E;o00002_lSg2<00ol0003o6^DJoa[U6P0<
oa[U6P03o`000?ljaC[o>/Dj00Ko>/Dj0_l00008odFjA@;o00003onUFZD00ol0003ohAkQon4Nh@02
on4Nh@03o`000?oS7>?ohacS00_ohacS00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo0?loo`3o007
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o^4NkokQ7^
00KokQ7^00?o0000ojiA[_n^DJh01_n^DJh01Ol0003o/4n`ok1?/?n`Ck3o000000SoGJ9M00?o0000
oe:]D_mB[E800_mB[E800ol0003o8m`Sob?L8`06ob?L8`Co00003?lJiAX00ol0003o>/Djoc[5>P08
oc[5>P?o00000_m5^TD3o`000003ohEjQOl0003oYEZU00goYEZU00?o0000on4NhOoQ7^401?oQ7^40
0ol0003ohacSon<Lh`0:on<Lh`03o`000?oh1oSon0Oh00Gon0Oh00?o0000oo`3o?ol0o`01_ol0o`0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP07onhA
kP03o`000?n^DJko[U6^00?o[U6^0_l00005ok1?/003o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe:]
D_mB[E800omB[E800ol0003o8m`Sob?L8`05ob?L8`03o`000?lLhaco7><L00;o7><L0ol00007oa[U
6P;o00003_ljaCX2o`0000GoQGZ500?o0000ojEJYOnUFZD02_nUFZD00ol0003ohAkQon4Nh@05on4N
h@03o`000?oS7>?ohacS00_ohacS00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo0?loo`3o006oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o^4NkokQ7^00Oo
kQ7^00?o0000ojiA[_n^DJh00_n^DJh00ol0003o/4n`ok1?/006ok1?/003o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe:]D_mB[E801OmB[E800ol0003o8m`Sob?L8`02ob?L8`;o00002?lLha`3o`0000;o
6^DJ0_l000000olPgb3o0000oc[5>P0=oc[5>P03o`000?n5NXGoQGZ500GoQGZ500?o0000ojEJYOnU
FZD02?nUFZD00ol0003ohAkQon4Nh@07on4Nh@03o`000?oS7>?ohacS00[ohacS00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo0?loo`3o006oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o^4NkokQ7^00SokQ7^00Co0000ojiA[_n^DJko00002On`Ck001Ol0003o
GJ9MoefRGOmMXUgo000000SoDZeB00Go0000ob?L8olSg2?o8m`So`00000=oacS70;o00001?lPgb00
0ol0003o>/Djoc[5>P0;oc[5>P03o`000?n5NXGoQGZ500KoQGZ500?o0000ojEJYOnUFZD01onUFZD0
0ol0003ohAkQon4Nh@08on4Nh@Co00002?oS7><00ol0003on0OhooP7n004ooP7n003o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onhA
kP03o`000?n^DJko000000_o/4n`00?o0000oefRGOl000002_mB[E800ol0003o8m`So`00000?oacS
7003o`000?lPgb3o8=lP00;o8=lP00?o0000oc[5>_ljaCX02oljaCX00ol0003oQGZ5ohEjQ@06ohEj
Q@03o`000?nUFZGoYEZU00KoYEZU00?o0000on4NhOoQ7^402OoQ7^401?l0003ol@kaoo4>lOoa3_47
o`0000;ohacS00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?loo`3o005oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o^4NkokQ7^00OokQ7^00?o0000ok1?
/?n`Ck002on`Ck000ol0003oDZeBoe:]DP0:oe:]DP03o`000?lLhaco7><L00go7><L00?o0000ob3O
8?lPgb001?lPgb000ol0003o>/Djoc[5>P09oc[5>P03o`000?n5NXGoQGZ500SoQGZ500?o0000ojEJ
YOnUFZD00onUFZD2o`0000cohAkQ00?o0000oo4>lOoa3_402?oa3_4<o`0000?oo0?l0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o
/4n`ok1?/00;ok1?/003o`000?mB[E;oDZeB00WoDZeB0_l0000>oacS7003o`000?lPgb3o8=lP00Go
8=lP00?o0000oc[5>_ljaCX02OljaCX00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?nUFZGo000000;o
00000_oF:MH00ol0003ohAkQon4Nh@08on4Nh@03o`000?oa3_7ol@ka00col@ka00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003okQ7^
onhAkP04onhAkP03o`000?n`Ck3o/4n`00_o/4n`0ol00007oe:]DP?o000000?o>l@ko`000?lLha`0
3OlLha`00ol0003o8=lPob3O8006ob3O8003o`000?ljaC[o>/Dj00So>/Dj00?o0000ohEjQOn5NXD0
2_n5NXD00ol0003oeRWFomHYeP04omHYeP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000oo4>lOoa3_40
2ooa3_400ol0003onPGjooX5nP08ooX5nP03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onhAk_o^4Nh00oo^4Nh>o`0000?oVfBK0_l00002oe:]DP?o0000
1Olka3/00ol0003o7><LoacS700:oacS7003o`000?lPgb3o8=lP00Oo8=lP00?o0000oc[5>_ljaCX0
2?ljaCX00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?oF:MKoeRWF00GoeRWF00?o0000on4NhOoQ7^40
1_oQ7^400ol0003ol@kaoo4>l@0;oo4>l@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onhAk_o^4Nh00_o^4Nh00ol0003ogaoOomlO
g`0:omlOg`03o`000?nKI9_oVfBK00?oVfBK0_l00009oc_4>`03o`000?lLhaco7><L00Wo7><L00?o
0000ob3O8?lPgb002?lPgb02o`0000So>/Dj00?o0000ohEjQOn5NXD02On5NXD00ol0003oeRWFomHY
eP07omHYeP03o`000?oQ7^7ohAkQ00CohAkQ00?o0000oo4>lOoa3_402ooa3_400ol0003onPGjooX5
nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?okQ7^
o`000?oO7ml02ooO7ml00ol0003oVfBKoi]TV`04oi]TV`03o`000?lka3_o>l@k00Wo>l@k00?o0000
oacS7?lLha`01olLha`00ol0003o8=lPob3O8009ob3O8004o`000?m2_D;o0000o`0000Ko>/Dj00?o
0000ohEjQOn5NXD02On5NXD00ol0003oeRWFomHYeP08omHYeP03o`000?oQ7^7ohAkQ00?ohAkQ00?o
0000oo4>lOoa3_402ooa3_400ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooi1_T2o`0000cogaoO00?o0000oi]TVonKI9/01?nKI9/0
0ol0003o>l@koc_4>`0:oc_4>`Wo00002olPgb000ol0003o@[e2od:m@P02od:m@P?o00000_ljaCX0
0ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?oF:MKoeRWF00WoeRWF00?o0000on4NhOoQ7^400_oQ7^40
0ol0003ol@kaoo4>l@0:oo4>l@03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000Gon@Ki00?o0000ondBkOl000002_oO7ml00ol0003oVfBKoi]TV`06oi]T
V`03o`000?lka3_o>l@k00Wo>l@k00?o0000obGJ9OlUfRD01OlUfRD00ol0003o8=lPob3O8009ob3O
8003o`000?m2_D;o@[e200Go@[e20ol00009ohEjQ@?o00003OoF:MH01Ol0003ohAkQon4NhOoQ7^7o
000000col@ka00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000Oon@Ki00Co0000ondBkOo]4^go00002OoO7ml00ol0003oVfBKoi]TV`06
oi]TV`03o`000?lka3_o>l@k00So>l@k00?o0000obGJ9OlUfRD01olUfRD00ol0003o8=lPob3O8007
ob3O8003o`000?m2_D;o@[e200So@[e20ol00002ohEjQ@Go00000_no@;l00ol0003oeRWFomHYeP0<
omHYeP03o`000?oQ7^7o000000col@ka00?o0000ooX5n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000Son@Ki00?o0000ondBkOo]4^d00_o]4^d5o`00
00CogaoO00?o0000oi]TVonKI9/01_nKI9/00ol0003o>l@koc_4>`08oc_4>`03o`000?lUfRGo9MXU
00Oo9MXU00?o0000ob3O8?lPgb001olPgb000ol0003o@[e2od:m@P08od:m@P03o`000?n9MXWoRGJ9
00;o00002?no@;l00ol0003oeRWFomHYeP0<omHYePCo00002_oa3_400ol0003onPGjooX5nP0:ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooT6n@03o`000?o]4^gokA;]
00;okA;]00?o0000olPgb?o8=lP00_o8=lP4o`0000WoVfBK00?o0000oc_4>olka3/02?lka3/00ol0
003o9MXUobGJ9@08obGJ9@03o`000?lPgb3o8=lP00Go8=lP00?o0000od:m@_m2_D802?m2_D801Ol0
003oRGJ9ohUfROn9MXWo000000[o_d2o0ol0000;omHYeP04o`000?of2OKomPWfooH9mPCo00001Ooa
3_400ol0003onPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o]4^gokA;]00?okA;]00?o0000olPgb?o8=lP01?o8=lP00ol0003oVfBKoi]TV`07
oi]TV`03o`000?lka3_o>l@k00Ko>l@k0_l0000;obGJ9@03o`000?lPgb3o8=lP00Go8=lP00?o0000
od:m@_m2_D802?m2_D800ol0003oRGJ9ohUfR@02ohUfR@03o`000?no@;oo_d2o00Oo_d2o00?o0000
onTFjOoY5^T01?l00006omHYeP03o`000?of2OKomPWf00KomPWf0ol00002oo4>l@03o`000?oj1O[o
nPGj00_onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000ondB
kOo]4^d01?o]4^d00ol0003ob3O8olPgb005olPgb003o`000?nKI9_oVfBK00OoVfBK00?o0000oc_4
>olka3/00_lka3/3o`000003oeFZEOl0003o9MXU00[o9MXU00?o0000ob3O8?lPgb001OlPgb000ol0
003o@[e2od:m@P07od:m@P03o`000?n9MXWoRGJ900?oRGJ900?o0000okm0_ono@;l01ono@;l00ol0
003ojAKYonTFj@04onTFj@?o00000_oF:MH00ol0003omPWfooH9mP0:ooH9mP;o00003_oj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003okA;]ondBk@04ondBk@03
o`000?o8=lSob3O800Kob3O80_l00007oi]TV`03o`000?lka3_o000000;o00001OmEZUD00ol0003o
9MXUobGJ9@08obGJ9@?o00001?lPgb000ol0003o@[e2od:m@P08od:m@P03o`000?n9MXWoRGJ900Co
RGJ900?o0000okm0_ono@;l01_no@;l00ol0003ojAKYonTFj@07onTFj@;o00003_of2OH00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o]4^gokA;]00GokA;]00?o0000olPgb?o8=lP01?o8=lP00ol0003oc3?<ol`cc003o`0000CoVfBK
0_l00008oeFZE@03o`000?lUfRGo9MXU00Oo9MXU00Co0000odVfBOm9]TWoBKI90ol000000olPgb3o
0000od:m@P09od:m@P03o`000?n9MXWoRGJ900CoRGJ900?o0000okm0_ono@;l01Ono@;l00ol0003o
jAKYonTFj@09onTFj@03o`000?of2OKomPWf00gomPWf00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003okA;]ondBk@06ondBk@03o`00
0?o8=lSob3O800?ob3O800?o0000ol`cc?o<<l`01?o<<l`2o`000003oi]TVol0003oEJYE00[oEJYE
00?o0000obGJ9OlUfRD01OlUfRD00ol0003oBKI9odVfB@05odVfB@03o`000?m2_D;o@[e200Oo@[e2
0ol00007ohUfR@03o`000?no@;oo_d2o00Co_d2o00?o0000onTFjOoY5^T02OoY5^T00ol0003omPWf
ooH9mP0=ooH9mP03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009ondBk@05o`000?o8=lSob3O8olPgb?l000002Oo<<l`00ol0003oEJYE
oeFZE@0;oeFZE@03o`000?lUfRGo9MXU00?o9MXU00?o0000odVfBOm9]TT01_m9]TT00ol0003o@[e2
od:m@P06od:m@P05o`000?n3O8?oPgb3oh=lPol000001on9MXT00ol0003o_d2ookm0_`03okm0_`03
o`000?oY5^WojAKY00WojAKY00?o0000ooH9m_of2OH03_of2OH00ol0003onPGjooX5nP09ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;oo0?l00?o0000ondBkOo]4^d0
1oo]4^d01?l0003ob3O8olPgb?l00009ol`cc0;o00003OmEZUD00ol0003o9MXUobGJ9@02obGJ9@03
o`000?m9]TWoBKI900SoBKI900?o0000od:m@_m2_D800om2_D82o`0000GoPgb300?o0000ohUfROn9
MXT01?n9MXT00ol0003o_d2ookm0_`03okm0_`03o`000?oY5^WojAKY00WojAKY00?o0000ooH9m_of
2OH03_of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000ondBkOo]4^d01_o]4^d00ol0003ob3O8o`000009ol`cc004o`000?nYEZWoZEJYo`0000go
EJYE00Co0000obGJ9OlUfRGo00003?m9]TT01Ol0003o@[e2od:m@_m2_D;o000000SoPgb30_l00005
ohUfR@03o`000?no@;oo_d2o00;o_d2o00?o0000onTFjOoY5^T02OoY5^T00ol0003omPWfooH9mP0>
ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000ondBkOo]4^d01oo]4^d00ol0003oc3?<ol`cc007ol`cc003o`000?nYEZWoZEJY
00;oZEJY00?o0000oeFZEOmEZUD02_mEZUD00ol0003o9MXUo`00000>odVfB@03o`000?m2_D;o0000
00_oPgb300?o0000ohUfROn9MXT00_n9MXT01Ol0003o_d2ookm0_ono@;oo000000cojAKY00?o0000
ooH9m_of2OH03_of2OH3o`0000WonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000ondBkOo]4^d01_o]4^d00ol0003oc3?<ol`cc006ol`cc003o`000?nYEZWoZEJY
00?oZEJY00?o0000oeFZEOmEZUD02omEZUD00ol0003oBKI9odVfB@0>odVfB@03o`000?n3O8?oPgb3
00_oPgb30_l00003ohUfR@04o`000?no@;oo_d2oo`0000[ojAKY0ol0000>ooH9mP;o00000oon0Oh2
o`0000OonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ondB
kOo]4^d01?o]4^d00ol0003oc3?<ol`cc006ol`cc003o`000?nYEZWoZEJY00GoZEJY00?o0000oeFZ
EOmEZUD01omEZUD3o`00017oBKI900?o0000oh=lPon3O8<03On3O8<01Ol0003oRGJ9ohUfROl0003o
_d2o00Co00000ooY5^T5o`0000;onPGj00?o0000ooH9m_of2OH02_of2OH2o`0000OooP7n0_l00004
ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o]4^gokA;]
00CokA;]00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oZEJYojUFZ@06ojUFZ@03o`000?mEZUGoEJYE
00CoEJYE0ol00002oejQGP03o`000?m9]TWoBKI900ooBKI90_l0000?oh=lP`04o`000?n9MXWo0000
o`0000CogR7N0ol00008ooX5nP03o`000?of2OKomPWf00OomPWf0_l0000;ooh1oP;o00000_oj1OX0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000Ooc3?<00?o0000ojUF
ZOnYEZT02?nYEZT00ol0003oEJYEoeFZE@03o`0000KoGZ5N00?o0000odVfBOm9]TT03Om9]TT01?l0
003oRWF:ohYeR_l0000?oh=lP`03o`000?oN8MkogR7N00GogR7N00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003omPWfooH9mP05ooH9mP03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003oka3_onl@k`04onl@
k`03o`000?o<<lcoc3?<00?oc3?<00?o0000ojUFZOnYEZT02_nYEZT2o`0000[oGZ5N00?o0000odVf
BOm9]TT02om9]TT00ol0003oRWF:ohYeRP02ohYeRP03o`000?n3O8?oPgb300_oPgb30_l00007omhQ
gP03o`000?oj1O[onPGj00WonPGj00?o0000ooH9m_of2OH00_of2OH2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003oka3_onl@k`06onl@k`05o`000?o<<lcoc3?<ol`c
c?l000003OnYEZT00ol0003oGZ5NoejQGP0:oejQGP03o`000?m9]TWoBKI900WoBKI900?o0000ohYe
R_n:MHX01?n:MHX00ol0003oPgb3oh=lP`08oh=lP`;o000000?o/4n`o`000?oN8Mh01ooN8Mh00ol0
003onPGjooX5nP09ooX5nP04o`000?of2OKo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onl@koo_4>l02?o_4>l00ol0003oc3?<o`00000=ojUFZ@03o`000?mNXEkoGZ5N
00_oGZ5N00?o0000odVfBOm9]TT02?m9]TT00ol0003oRWF:ohYeRP06ohYeRP03o`000?n3O8?oPgb3
00GoPgb30_l00003ok1?/003o`000?oN8MkogR7N00KogR7N00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o_4>ooka3_00[oka3_00?o0000ojUFZOnY
EZT03?nYEZT00ol0003oGZ5NoejQGP0<oejQGP03o`000?m9]TWoBKI900KoBKI900?o0000ohYeR_n:
MHX02?n:MHX00ol0003oPgb3oh=lP`02oh=lP`;o00001_n`Ck000ol0003ogR7NomhQgP05omhQgP03
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000onl@koo_4>l03?o_4>l2o`0000coZEJY00?o0000oejQG_mNXEh03OmNXEh00ol0003oBKI9
odVfB@04odVfB@03o`000?n:MH[oRWF:00[oRWF:00Co0000oh=lPol0003o00002?n`Ck000ol0003o
gR7NomhQgP06omhQgP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003oka3_onl@k`0=onl@k`03o`000?oA;]7o000000;o00002?nYEZT00ol0003oGZ5N
oejQGP0?oejQGPKo00003_n:MHX00ol0003o/4n`ok1?/008ok1?/003o`000?oN8MkogR7N00KogR7N
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?onl@k`03o`000?oA;]7odBkA00?odBkA0ol00005ojUFZ@;o00004?mNXEh01_l0003oLXeb
og:=L_l0003oJIIYo`0000koRWF:00?o0000ok1?/?n`Ck002On`Ck000ol0003ogR7NomhQgP05omhQ
gP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
ka3_onl@k`0=onl@k`03o`000?oA;]7odBkA00KodBkA0ol000001?nYEZWo0000ohiaS_n>LHh3o`00
00coGZ5N00Go0000og:=L_mbSG;oLXebo`000002ofVFJ@03o`000?n:MH[oRWF:00_oRWF:00?o0000
ok1?/?n`Ck002On`Ck000ol0003ogR7NomhQgP06omhQgP03o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oA;]400ol0003oSW6>ohiaSP04ohia
SP?o00002?mNXEh00ol0003oLXebog:=LP02og:=LP05o`000?mYUVWoJIIYofVFJOl000003?n:MHX0
0ol0003o/4n`ok1?/009ok1?/003o`000?oN8MkogR7N00GogR7N3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om4^
dOoA;]402_oA;]400ol0003oSW6>ohiaSP07ohiaSP;o00001OmNXEh00ol0003oLXebog:=LP03og:=
LP03o`000?mYUVWoJIIY00;oJIIY00?o0000ohYeR_n:MHX02On:MHX00ol0003o/4n`ok1?/00:ok1?
/003o`000?oN8MkogR7N00?ogR7N00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om4^dOoA;]402ooA;]400ol0003oSW6>ohiaSP09ohiaSP?o000000?oGZ5No`000?mb
SG801OmbSG800ol0003oJIIYofVFJ@03ofVFJ@03o`000?n:MH[oRWF:00SoRWF:3_l00003omhQgP;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om@[eo`00000;oo0?l003o`000?oA;]7odBkA00[odBkA
0_l0000>ohiaSP03o`000?mbSG;oLXeb00GoLXeb00?o0000ofVFJOmYUVT00omYUVT00ol0003oRWF:
ohYeRP08ohYeRP03o`000?oP7n3oh1oP00_oh1oP00?o0000omhQg_l000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooD:mOoe2_Go00002_o`3o000ol0003odBkAom4^d@09om4^d@03o`000?nn@Kko000000koSW6>
00?o0000og:=L_mbSG801OmbSG800ol0003oJIIYofVFJ@04ofVFJ@03o`000?n:MH[oRWF:00KoRWF:
00?o0000on0Oh?oP7n003OoP7n000ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D00_oe
2_D00ol0003ol0o`oo0?l006oo0?l003o`000?oA;]7odBkA00SodBkA0_l00003oki1_P03o`000?n>
LHkoSW6>00_oSW6>00?o0000og:=L_mbSG801OmbSG800ol0003oJIIYofVFJ@05ofVFJ@03o`000?n:
MH[oRWF:00GoRWF:00?o0000on0Oh?oP7n003OoP7n000ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooD:mOoe2_D00ooe2_D00ol0003ol0o`oo0?l005oo0?l003o`000?oA;]7odBkA00OodBkA00?o0000
oki1__nn@Kh00onn@Kh00ol0003oSW6>ohiaSP0:ohiaSP03o`000?mbSG;oLXeb00KoLXeb00?o0000
ofVFJOmYUVT01_mYUVT00ol0003oRWF:ohYeRP04ohYeRP03o`000?oP7n3oh1oP00goh1oP3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01Ooe2_D00ol0
003ol0o`oo0?l004oo0?l003o`000?oA;]7odBkA00GodBkA0_l00006oki1_P03o`000?n>LHkoSW6>
00WoSW6>0_l00008og:=LP03o`000?mYUVWoJIIY00KoJIIY1Ol000000on:MH[o0000on0Oh00?on0O
h003o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003o
l0o`oo0?l004o`0000KodBkA00?o0000oki1__nn@Kh01onn@Kh00ol0003oSW6>ohiaSP05ohiaSP?o
000000?oSW6>o`000?mbSG801ombSG800ol0003oJIIYofVFJ@05ofVFJ@03o`000?nYEZWoZEJY00?o
ZEJY0_l0000?on0Oh0;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000ooD:mOoe2_D01ooe2_D2o`0000CoiaSW00Co0000om4^dOoA;]7o
dBkA0_l0000:oki1_P03o`000?n>LHkoSW6>00;oSW6>0ol00005ohiaSP03o`000?mbSG;oLXeb00Go
LXeb00?o0000ofVFJOmYUVT01?mYUVT00ol0003oZEJYojUFZ@06ojUFZ@03o`000?oP7n3oh1oP00[o
h1oP0_l00002oo8=lP03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om@[eooD:m@08ooD:m@03o`00
0?oW6>OoiaSW00CoiaSW00?o0000om4^dOl000003?nn@Kh00ol0003oSW6>o`000002o`0000WoSW6>
00?o0000og:=L_mbSG801?mbSG800ol0003oJIIYofVFJ@03ofVFJ@03o`000?nYEZWoZEJY00SoZEJY
1_l00004on0Oh0;o00001Oob3O800ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D01ooe
2_D00ol0003oiaSWonLHi`06onLHi`03o`000?nn@Kko_T6n00co_T6n00?o0000ohiaS_n>LHh02_n>
LHh00ol0003oLXebog:=LP04og:=LP04o`000?mYUVWoJIIYofVFJ@;o00002onYEZT00ol0003oiQWV
onHIiP03onHIiPCo00002?ob3O800ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om@[eooD:m@07ooD:m@03o`000?oW
6>OoiaSW00OoiaSW00?o0000oki1__nn@Kh03?nn@Kh00ol0003oSW6>ohiaSP0;ohiaSP03o`000?mb
SG;oLXeb00?oLXeb00Co0000ofVFJOmYUVWo00003OnYEZT00ol0003oiQWVonHIiP06onHIiP03o`00
0?ob3O;olPgb00OolPgb00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000ooD:mOoe2_D0
1_oe2_D00ol0003oiaSWonLHi`09onLHi`03o`000?nn@Kko_T6n00Wo_T6n0_l0000>ohiaSP?o0000
0ombSG800ol0003oJIIYo`00000=ojUFZ@03o`000?oV6NKoiQWV00OoiQWV00?o0000oo8=l_ob3O80
2?ob3O8:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom@[e00?o
0000onLHiooW6>L02_oW6>L00ol0003o_T6noki1_P06oki1_P;o000000?o_T6no`000?n>LHh02on>
LHh2o`0000?oVVFJ1Ol0000>ojUFZ@03o`000?oV6NKoiQWV00OoiQWV00?o0000oo8=l_ob3O802?ob
3O800ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP03ooX5nPCo00000_oe2_D00ol0003oiaSWonLHi`0;
onLHi`03o`000?nn@Kko_T6n00?o_T6n0ol00004oki1_P03o`000?n>LHkoSW6>00OoSW6>0_l00008
oiYUVP03o`000?nYEZWoZEJY00goZEJY00?o0000onHIi_oV6NH02?oV6NH00ol0003olPgboo8=lP07
oo8=lP03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oj1O[onPGj00OonPGj0_l0000?onLHi`03o`000?nn@Kko_T6n00;o00002?nn@Kh00ol0
003oSW6>ohiaSP05ohiaSP03o`000?nJII[oVVFJ00SoVVFJ00?o0000ojUFZOnYEZT03OnYEZT00ol0
003oiQWVonHIiP08onHIiP03o`000?ob3O;olPgb00KolPgb00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5
nP03o`000?oW6>OoiaSW00koiaSW0_l0000;oki1_P03o`000?n>LHkoSW6>00;oSW6>0_l0000;oiYU
VP03o`000?nYEZWoZEJY00goZEJY00?o0000onHIi_oV6NH02?oV6NH00ol0003olPgboo8=lP06oo8=
lP03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003onPGjooX5nP0:ooX5nP03o`000?oW6>OoiaSW00goiaSW0_l0000<oki1_P04o`000?n>LHko0000
o`0000goVVFJ00?o0000ojUFZOnYEZT03?nYEZT00ol0003oiQWVonHIiP09onHIiP03o`000?ob3O;o
lPgb00KolPgb00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oW6>OoiaSW00coiaSW00Co0000on<L
hooS7>?o00003?nn@Kh00ol0003oVVFJoiYUVP0>oiYUVP03o`000?nYEZWoZEJY00SoZEJY1?l0000;
onHIiP03o`000?ob3O;olPgb00KolPgb00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oW6>OoiaSW
00_oiaSW00?o0000on<LhooS7><00_oS7><00ol0003o_T6noki1_P09oki1_P03o`000?nJII[oVVFJ
00koVVFJ00Co0000ojUFZOnYEZWoZEJY1ol00003ol/db`03o`000?oV6NKoiQWV00WoiQWV00?o0000
oo8=l_ob3O801_ob3O800ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oj1O[onPGj00conPGj00?o0000onLHiooW6>L02_oW6>L00ol0
003ohacSon<Lh`03on<Lh`03o`000?nn@Kko_T6n00So_T6n00?o0000oiYUV_nJIIX03_nJIIX4o`00
00_obcC;00?o0000onHIi_oV6NH02?oV6NH00ol0003olPgboo8=lP05oo8=lP03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj
1OX03?oj1OX7o`0000GoiaSW00?o0000on<LhooS7><01OoS7><00ol0003o_T6noki1_P07oki1_P03
o`000?nJII[oVVFJ00koVVFJ00?o0000ol/dboo;=</03Oo;=</00ol0003oiQWVonHIiP08onHIiP03
o`000?ob3O;olPgb00ColPgb00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003onPGjooX5nP0=ooX5nP03o`000?od2oCom0_d00Com0_d
1Ol00009on<Lh`03o`000?nn@Kko_T6n00Ko_T6n00?o0000oiYUV_nJIIX03_nJIIX00ol0003obcC;
ol/db`0=ol/db`03o`000?oV6NKoiQWV00SoiQWV00Co0000oo8=l_ob3O;olPgb1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=ooX5nP03o`000?od2oCom0_d00Wom0_d
0_l00009on<Lh`03o`000?nn@Kko_T6n00Ko_T6n00?o0000oiYUV_nJIIX03?nJIIX00ol0003obcC;
ol/db`0?ol/db`Ko00001?oV6NH4o`0000GonPGj0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_oj1OX00ol0003o
m0_doo@;m009oo@;m003o`000?o/4nco000000;o00001ooS7><00ol0003o_T6noki1_P05oki1_P03
o`000?nJII[oVVFJ00SoVVFJ1Ol0000Aol/db`03o`000?o]4^gokA;]00?okA;]1?l0000;ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000OonPGj
00?o0000oo@;m?od2o@02_od2o@00ol0003ok1?/on`Ck002on`Ck0?o00001OoS7><00ol0003o_T6n
oki1_P04oki1_P04o`000?nJII[oVVFJoiYUVPOo00001?o<<l`00ol0003obcC;ol/db`0>ol/db`03
o`000?o]4^gokA;]00OokA;]00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?oj1OX00ol0003om0_d
oo@;m00;oo@;m003o`000?o/4ncok1?/00Gok1?/0ol00003on<Lh`04o`000?nn@Kko_T6noki1_PKo
00003?o<<l`00ol0003obcC;ol/db`0=ol/db`03o`000?o]4^gokA;]00OokA;]00?o0000ooX5n_oj
1OX02_oj1OX00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?onPGjo`000?od2o@0
3?od2o@00ol0003ok1?/on`Ck008on`Ck0?o000000CohacSo`000?l0003o00000_oW6>L00ol0003o
c3?<ol`cc00=ol`cc003o`000?o;=<_obcC;00cobcC;00?o0000ondBkOo]4^d02?o]4^d00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00;on`Ck003o`000?oW6>OoiaSW00?o
iaSW00?o0000ol`cc?o<<l`03?o<<l`00ol0003oebSGo`00000=ol/db`03o`000?o]4^gokA;]00So
kA;]00?o0000ooX5n_oj1OX03?oj1OX3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00:on`Ck003o`00
0?oW6>OoiaSW00GoiaSW00?o0000ol`cc?o<<l`02_o<<l`01?l0003oebSGomLXeooG:=L2o`0000[o
bcC;00?o0000ondBkOo]4^d02Oo]4^d00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo@;m?od2o@0
3?od2o@00ol0003ok1?/on`Ck009on`Ck003o`000?oW6>OoiaSW00KoiaSW00?o0000ol`cc?o<<l`0
2Oo<<l`00ol0003oebSGomLXe`02omLXe`03o`000?oY5^Wo000000;o00001oo;=</00ol0003okA;]
ondBk@09ondBk@03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m00;oo@;m003o`000?o/
4ncok1?/00Sok1?/00?o0000onLHiooW6>L01ooW6>L00ol0003oc3?<ol`cc008ol`cc003o`000?oG
:=OoebSG00?oebSG00?o0000onTFjOoY5^T00_oY5^T2o`0000CobcC;00?o0000ondBkOo]4^d02_o]
4^d00ol0003onPGjooX5nP0:ooX5nP03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo@;m0Ko00001?o/4n`00ol0003oiaSWonLHi`08
onLHi`03o`000?o<<lcoc3?<00Ooc3?<00?o0000omLXeooG:=L00ooG:=L00ol0003ojAKYonTFj@05
onTFj@?o000000?obcC;o`000?o]4^d02oo]4^d00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo@;m003o`000?of2OKomPWf00ComPWf1?l0000<onLHi`03o`000?o<<lcoc3?<
00Goc3?<00?o0000omLXeooG:=L01?oG:=L00ol0003ojAKYonTFj@08onTFj@03o`000?o]4^gokA;]
00_okA;]00?o0000ooX5n_oj1OX02?oj1OX00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om0_d00?o0000ooH9m_of
2OH02?of2OH00ol0003oiaSWonLHi`0:onLHi`03o`000?o<<lcoc3?<00Coc3?<00?o0000omLXeooG
:=L01OoG:=L00ol0003ojAKYonTFj@08onTFj@03o`000?o]4^gokA;]00WokA;]1?l00008ooX5nP03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooH9mP03o`000?oW6>OoiaSW00WoiaSW
00?o0000ol`cc?o<<l`00oo<<l`00ol0003oebSGomLXe`05omLXe`03o`000?oY5^WojAKY00[ojAKY
00?o0000ondBkOo]4^d01?o]4^d4o`0000Con@Ki00?o0000ooX5n_oj1OX01?oj1OX00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oW6>OoiaSW00WoiaSW00?o0000ol`cc?o<<l`00_o<
<l`00ol0003oebSGomLXe`06omLXe`03o`000?oY5^WojAKY00[ojAKY00?o0000ondBkOo]4^d01?l0
0009ooT6n@Ko00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?of2OKomPWf00[omPWf00?o0000onLHiooW6>L02OoW6>L01Ol0003oc3?<ol`c
c?o<<lco000000WoebSG00?o0000onTFjOoY5^T02ooY5^T2o`0000gon@Ki00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003omPWfooH9mP0;ooH9mP03o`000?oW6>OoiaSW00WoiaSW00?o
0000ol`cc?l000002OoG:=L00ol0003ojAKYonTFj@0<onTFj@03o`000?oi1_Won@Ki00con@Ki00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oW6>Oo
iaSW00SoiaSW1Ol00008omLXe`03o`000?oY5^WojAKY00cojAKY00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooH9m_of2OH02_of2OH00ol0003oiaSWonLHi`07onLH
i`03o`000?o[5>_ojaC[00?ojaC[0ol00005omLXe`03o`000?oY5^WojAKY00_ojAKY00?o0000ooT6
nOoi1_T03?oi1_T00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
mPWf00?o0000onLHiooW6>L01OoW6>L00ol0003ojaC[on/Dj`07on/Dj`?o000000?oebSGo`000?oY
5^T03OoY5^T00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_of2OH00ol0003oiaSWonLHi`03onLHi`;o0000
3Oo[5>/2o`0000gojAKY0ol0000=ooT6n@03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?of2OKomPWf00OomPWf00Co0000onLHiooW6>OoiaSW
0_l00002ooL8m`03o`000?o[5>_ojaC[00cojaC[3Ol00003ooT6n@03o`000?oi1_Won@Ki00[on@Ki
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooH9mP03o`000?oW6>Oo000000Gom`Sg
00?o0000on/Djoo[5>/02oo[5>/00ol0003ol0o`oo0?l009oo0?l003o`000?oi1_Won@Ki00;on@Ki
0_l00009ooT6n@03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?omPWf0ol0
0007ooL8m`03o`000?o[5>_ojaC[00[ojaC[00?o0000oo0?l?o`3o002Oo`3o000ol0003on@KiooT6
n@04ooT6n@;o00001ooi1_T00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo0?loo`3o?ol0o`3o`0000;on`Ck00?o0000ooL8moog2?L01_og2?L00ol0003ojaC[on/D
j`08on/Dj`03o`000?o`3o3ol0o`00[ol0o`00?o0000ooT6nOoi1_T01_oi1_T00ol0003on@KiooT6
n@04ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?ol0oco
o0?l00Coo0?l00Go0000oo/4nook1?_on`Cko`000008ooL8m`03o`000?o[5>_ojaC[00OojaC[00?o
0000oo0?l?o`3o002_o`3o000ol0003on@KiooT6n@07ooT6n@;o00001?oi1_T00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?ol0ocoo0?l00Coo0?l00?o0000oo/4nook1?/00_ok1?/0
0ol0003om`SgooL8m`07ooL8m`03o`000?o[5>_ojaC[00KojaC[00?o0000oo0?l?o`3o002_o`3o00
0ol0003on@KiooT6n@09ooT6n@05o`000?oi1_Won@KiooT6nOl000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000oo`3o?ol0o`01?ol0o`00ol0003on`Ckoo/4n`03
oo/4n`03o`000?og2?Oom`Sg00Oom`Sg00?o0000on/Djoo[5>/01Oo[5>/00ol0003ol0o`oo0?l00:
oo0?l003o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo0?loo`3o005oo`3o003o`000?ok1?_on`Ck00?on`Ck00?o0000
ooL8moog2?L02?og2?L00ol0003ojaC[on/Dj`04on/Dj`03o`000?o`3o3ol0o`00Wol0o`00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?ol0ocoo0?l
00Goo0?l00?o0000oo/4nook1?/01?ok1?/00ol0003om`SgooL8m`09ooL8m`03o`000?o[5>_ojaC[
00;ojaC[00?o0000oo0?l?o`3o002_o`3o000ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000oo`3o?ol
0o`01Ool0o`00ol0003on`Ckoo/4n`05oo/4n`03o`000?og2?Oom`Sg00Wom`Sg00Go0000on/Djoo[
5>_ojaC[o`00000<oo0?l003o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo0?loo`3o006oo`3o003o`000?ok1?_on`Ck00Gon`Ck00?o0000ooL8moog
2?L02_og2?L00ol0003ojaC[o`000004o`0000Wol0o`00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`01_ol0o`00ol0003on`Ckoo/4n`07oo/4n`;o0000
2oog2?L00ol0003on`Ckoo/4n`03oo/4n`Oo00000_o`3o000ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo0?l00?o0000oo/4nook1?/01ook1?/00ol0003oo@;m
o`000002o`0000Som`Sg00?o0000oo/4nook1?/02_ok1?/5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo0?l00?o
0000oo/4nook1?/01_ok1?/00ol0003oo@;mood2o@03ood2o@?o00001?og2?L00ol0003on`Ckoo/4
n`0=oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003on`Ckoo/4n`07
oo/4n`03o`000?om0_goo@;m00Koo@;m0ol000000oog2?Oo0000oo/4n`0>oo/4n`03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?ol0ocoo0?l00;oo0?l1_l00008oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo/4
nook1?/03ook1?/00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?om0_goo@;m00[o
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool02ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l3oooo00_o003o0_ooo`08o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0oooo`09o`00o`;oool01ol00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00_o003o0oooo`08o`00o`;oool01ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`003?l00?l2oooo00So
003o0_ooo`07o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00go003o0_ooo`07o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00go003o0_ooo`07o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2?l00?l5oooo0003o`00ooooo`3oool000Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo
0?ooo`07o`00o`;oool01?l00?l3oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o
0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo0002oooo00?o003o00?o
ool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol00?l2oooo0003o`00oooo
o`3oool000Ko003o0oooo`05o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l0
0?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`03
o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02oooo00Ko003o0_ooo`06
o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool0
06Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo
00Ko003o0_ooo`06o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;o
ool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o
0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`07o`00o`;oool01?l00?l2oooo00Oo003o
0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l0
0?l2oooo0003oc8bc?l00?oo003o00Co003o00?oool0o`00ool00?l00ol00?l2oooo00Oo003o0_oo
o`07o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3
oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`04o`00o`;oool00ol00?l2
oooo00Ko003o1?ooo`08o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00
o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08Ol00?l4oooo00Wo003o0_ooo`09o`00
o`Coool0L_l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(920) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.976 .024 .976 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.979 .021 .979 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.953 .047 .953 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.903 .097 .903 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.968 .032 .968 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.973 .027 .973 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.983 .017 .983 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.956 .044 .956 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.981 .019 .981 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.928 .072 .928 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.98 .02 .98 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.97 .03 .97 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.916 .084 .916 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.96 .04 .96 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.931 .069 .931 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.765 .235 .765 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.805 .195 .805 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.937 .063 .937 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.94 .06 .94 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.785 .215 .785 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.746 .254 .746 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.682 .318 .682 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.928 .072 .928 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.954 .046 .954 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.945 .055 .945 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.905 .095 .905 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.978 .022 .978 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.8 .2 .8 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.691 .309 .691 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.876 .124 .876 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.441 .559 .441 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.435 .565 .435 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.546 .454 .546 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.798 .202 .798 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.82 .18 .82 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.494 .506 .494 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.446 .554 .446 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.962 .038 .962 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.994 .006 .994 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.608 .392 .608 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.745 .255 .745 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.923 .077 .923 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.932 .068 .932 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.663 .337 .663 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.887 .113 .887 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.364 .636 .364 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.862 .138 .862 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.748 .252 .748 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.162 .838 .162 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.269 .731 .269 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.2 .8 .2 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.905 .095 .905 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.984 .016 .984 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.53 .47 .53 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.157 .843 .157 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.232 .768 .232 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.83 .17 .83 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.335 .665 .335 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.558 .442 .558 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.24 .76 .24 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.056 .944 .056 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.035 .965 .035 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.372 .628 .372 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.56 .44 .56 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.968 .032 .968 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.605 .395 .605 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.685 .315 .685 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.062 .938 .062 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.009 .991 .009 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.035 .965 .035 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.112 .888 .112 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.148 .852 .148 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.799 .201 .799 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.922 .078 .922 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.949 .051 .949 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.502 .498 .502 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.104 .896 .104 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.841 .159 .841 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.233 .767 .233 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.448 .552 .448 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.137 .863 .137 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.291 .709 .291 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.876 .124 .876 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.413 .587 .413 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.128 .872 .128 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.984 .016 .984 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.913 .087 .913 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.942 .058 .942 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.307 .693 .307 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.977 .023 .977 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.039 .961 .039 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
0 1 0 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.666 .334 .666 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.64 .36 .64 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.14 .86 .14 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.262 .738 .262 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.544 .456 .544 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.799 .201 .799 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.142 .858 .142 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.989 .011 .989 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.072 .928 .072 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.231 .769 .231 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.324 .676 .324 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.515 .485 .515 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.476 .524 .476 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.337 .663 .337 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.274 .726 .274 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.93 .07 .93 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.906 .094 .906 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.901 .099 .901 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.224 .776 .224 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.54 .46 .54 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.69 .31 .69 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.877 .123 .877 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.976 .024 .976 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.523 .477 .523 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.749 .251 .749 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.424 .576 .424 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.968 .032 .968 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.95 .05 .95 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.869 .131 .869 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.981 .019 .981 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.994 .006 .994 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.535 .465 .535 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.647 .353 .647 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.991 .009 .991 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.584 .416 .584 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.914 .086 .914 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.723 .277 .723 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.84 .16 .84 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.675 .325 .675 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.804 .196 .804 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.97 .03 .97 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.758 .242 .758 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.779 .221 .779 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.884 .116 .884 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.881 .119 .881 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.965 .035 .965 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.836 .164 .836 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.964 .036 .964 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.944 .056 .944 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.932 .068 .932 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.891 .109 .891 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.899 .101 .899 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.86 .14 .86 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.945 .055 .945 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.96 .04 .96 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.983 .017 .983 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.97 .03 .97 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.977 .023 .977 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.988 .012 .988 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.973 .027 .973 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.911 .089 .911 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.967 .033 .967 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.978 .022 .978 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.984 .016 .984 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.976 .024 .976 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.981 .019 .981 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.987 .013 .987 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.996 .004 .996 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(930) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.976 .024 .976 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.98 .02 .98 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.954 .046 .954 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.904 .096 .904 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.968 .032 .968 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.973 .027 .973 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.983 .017 .983 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.957 .043 .957 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.981 .019 .981 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.928 .072 .928 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.98 .02 .98 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.97 .03 .97 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.918 .082 .918 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.96 .04 .96 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.932 .068 .932 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.767 .233 .767 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.807 .193 .807 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.937 .063 .937 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.94 .06 .94 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.788 .212 .788 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.749 .251 .749 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.683 .317 .683 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.929 .071 .929 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.955 .045 .955 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.946 .054 .946 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.906 .094 .906 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.978 .022 .978 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.802 .198 .802 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.692 .308 .692 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.876 .124 .876 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.442 .558 .442 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.436 .564 .436 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.55 .45 .55 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.798 .202 .798 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.821 .179 .821 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.988 .012 .988 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.497 .503 .497 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.448 .552 .448 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.962 .038 .962 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.609 .391 .609 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.746 .254 .746 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.924 .076 .924 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.934 .066 .934 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.665 .335 .665 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.888 .112 .888 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.365 .635 .365 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.865 .135 .865 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.75 .25 .75 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.164 .836 .164 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.272 .728 .272 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.201 .799 .201 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.907 .093 .907 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.985 .015 .985 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.534 .466 .534 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.157 .843 .157 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.233 .767 .233 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.833 .167 .833 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.336 .664 .336 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.56 .44 .56 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.243 .757 .243 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.057 .943 .057 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.036 .964 .036 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.374 .626 .374 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.561 .439 .561 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.968 .032 .968 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.608 .392 .608 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.689 .311 .689 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.064 .936 .064 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.01 .99 .01 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.036 .964 .036 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.113 .887 .113 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.149 .851 .149 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.801 .199 .801 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.923 .077 .923 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.95 .05 .95 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.506 .494 .506 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.104 .896 .104 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.842 .158 .842 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.235 .765 .235 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.451 .549 .451 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.139 .861 .139 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.293 .707 .293 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.878 .122 .878 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.414 .586 .414 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.129 .871 .129 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.984 .016 .984 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.914 .086 .914 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.942 .058 .942 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.311 .689 .311 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.978 .022 .978 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.04 .96 .04 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.001 .999 .001 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.669 .331 .669 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.643 .357 .643 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.142 .858 .142 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.263 .737 .263 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.546 .454 .546 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.801 .199 .801 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.144 .856 .144 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.989 .011 .989 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.073 .927 .073 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.233 .767 .233 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.328 .672 .328 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.517 .483 .517 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.481 .519 .481 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.342 .658 .342 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.276 .724 .276 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.931 .069 .931 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.907 .093 .907 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.903 .097 .903 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.227 .773 .227 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.541 .459 .541 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.691 .309 .691 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.878 .122 .878 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.976 .024 .976 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.526 .474 .526 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.75 .25 .75 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.428 .572 .428 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.969 .031 .969 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.95 .05 .95 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.87 .13 .87 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.981 .019 .981 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.538 .462 .538 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.65 .35 .65 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.589 .411 .589 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.914 .086 .914 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.726 .274 .726 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.841 .159 .841 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.679 .321 .679 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.983 .017 .983 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.806 .194 .806 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.97 .03 .97 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.762 .238 .762 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.782 .218 .782 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.886 .114 .886 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.882 .118 .882 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.965 .035 .965 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.838 .162 .838 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.965 .035 .965 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.945 .055 .945 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.933 .067 .933 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.892 .108 .892 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.901 .099 .901 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.862 .138 .862 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.947 .053 .947 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.96 .04 .96 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.971 .029 .971 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.978 .022 .978 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.988 .012 .988 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.973 .027 .973 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.913 .087 .913 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.968 .032 .968 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.978 .022 .978 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.976 .024 .976 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.981 .019 .981 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.987 .013 .987 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(940) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.977 .023 .977 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.98 .02 .98 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.955 .045 .955 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.905 .095 .905 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.968 .032 .968 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.973 .027 .973 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.983 .017 .983 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.957 .043 .957 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.981 .019 .981 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.929 .071 .929 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.981 .019 .981 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.971 .029 .971 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.919 .081 .919 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.96 .04 .96 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.932 .068 .932 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.769 .231 .769 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.808 .192 .808 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.938 .062 .938 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.791 .209 .791 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.752 .248 .752 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.684 .316 .684 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.929 .071 .929 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.956 .044 .956 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.947 .053 .947 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.908 .092 .908 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.979 .021 .979 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.805 .195 .805 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.693 .307 .693 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.876 .124 .876 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.442 .558 .442 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.436 .564 .436 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.554 .446 .554 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.799 .201 .799 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.822 .178 .822 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.501 .499 .501 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.451 .549 .451 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.963 .037 .963 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.609 .391 .609 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.748 .252 .748 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.924 .076 .924 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.935 .065 .935 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.667 .333 .667 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.888 .112 .888 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.867 .133 .867 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.751 .249 .751 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.166 .834 .166 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.322 .678 .322 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.274 .726 .274 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.202 .798 .202 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.908 .092 .908 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.985 .015 .985 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.537 .463 .537 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.158 .842 .158 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.234 .766 .234 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.835 .165 .835 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.337 .663 .337 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.562 .438 .562 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.246 .754 .246 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.059 .941 .059 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.036 .964 .036 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.376 .624 .376 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.563 .437 .563 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.969 .031 .969 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.611 .389 .611 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.692 .308 .692 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.065 .935 .065 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.011 .989 .011 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.036 .964 .036 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.114 .886 .114 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.15 .85 .15 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.803 .197 .803 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.924 .076 .924 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.951 .049 .951 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.51 .49 .51 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.105 .895 .105 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.844 .156 .844 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.238 .762 .238 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.453 .547 .453 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.142 .858 .142 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.295 .705 .295 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.88 .12 .88 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.416 .584 .416 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.13 .87 .13 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.984 .016 .984 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.915 .085 .915 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.943 .057 .943 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.315 .685 .315 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.978 .022 .978 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.042 .958 .042 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.002 .998 .002 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.671 .329 .671 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.646 .354 .646 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.144 .856 .144 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.265 .735 .265 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.548 .452 .548 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.804 .196 .804 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.146 .854 .146 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.989 .011 .989 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.074 .926 .074 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.235 .765 .235 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.332 .668 .332 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.519 .481 .519 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.486 .514 .486 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.346 .654 .346 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.279 .721 .279 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.932 .068 .932 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.908 .092 .908 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.904 .096 .904 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.229 .771 .229 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.542 .458 .542 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.692 .308 .692 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.879 .121 .879 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.977 .023 .977 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.993 .007 .993 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.528 .472 .528 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.751 .249 .751 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.432 .568 .432 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.97 .03 .97 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.951 .049 .951 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.87 .13 .87 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.981 .019 .981 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.541 .459 .541 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.652 .348 .652 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.594 .406 .594 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.915 .085 .915 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.729 .271 .729 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.842 .158 .842 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.683 .317 .683 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.969 .031 .969 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.808 .192 .808 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.971 .029 .971 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.766 .234 .766 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.784 .216 .784 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.888 .112 .888 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.883 .117 .883 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.966 .034 .966 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.841 .159 .841 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.966 .034 .966 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.946 .054 .946 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.934 .066 .934 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.894 .106 .894 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.902 .098 .902 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.865 .135 .865 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.948 .052 .948 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.96 .04 .96 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.971 .029 .971 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.978 .022 .978 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.989 .011 .989 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.974 .026 .974 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.914 .086 .914 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.969 .031 .969 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.978 .022 .978 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.977 .023 .977 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.981 .019 .981 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.994 .006 .994 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.988 .012 .988 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(950) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.977 .023 .977 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.98 .02 .98 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.996 .004 .996 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.955 .045 .955 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.906 .094 .906 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.983 .017 .983 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.991 .009 .991 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.957 .043 .957 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.981 .019 .981 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.929 .071 .929 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.981 .019 .981 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.971 .029 .971 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.92 .08 .92 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.96 .04 .96 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.933 .067 .933 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.771 .229 .771 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.809 .191 .809 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.938 .062 .938 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.793 .207 .793 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.754 .246 .754 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.685 .315 .685 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.93 .07 .93 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.956 .044 .956 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.948 .052 .948 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.909 .091 .909 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.994 .006 .994 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.979 .021 .979 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.808 .192 .808 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.693 .307 .693 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.876 .124 .876 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.443 .557 .443 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.437 .563 .437 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.557 .443 .557 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.799 .201 .799 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.823 .177 .823 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.504 .496 .504 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.454 .546 .454 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.963 .037 .963 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.61 .39 .61 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.749 .251 .749 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.925 .075 .925 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.936 .064 .936 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.668 .332 .668 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.888 .112 .888 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.869 .131 .869 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.753 .247 .753 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.168 .832 .168 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.322 .678 .322 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.277 .723 .277 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.203 .797 .203 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.909 .091 .909 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.985 .015 .985 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.541 .459 .541 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.158 .842 .158 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.234 .766 .234 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.837 .163 .837 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.338 .662 .338 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.564 .436 .564 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.248 .752 .248 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.06 .94 .06 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.378 .622 .378 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.565 .435 .565 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.969 .031 .969 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.614 .386 .614 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.696 .304 .696 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.067 .933 .067 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.012 .988 .012 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.037 .963 .037 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.114 .886 .114 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.15 .85 .15 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.805 .195 .805 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.925 .075 .925 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.951 .049 .951 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.514 .486 .514 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.105 .895 .105 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.845 .155 .845 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.239 .761 .239 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.454 .546 .454 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.144 .856 .144 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.297 .703 .297 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.881 .119 .881 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.417 .583 .417 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.131 .869 .131 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.984 .016 .984 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.916 .084 .916 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.944 .056 .944 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.318 .682 .318 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.978 .022 .978 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.043 .957 .043 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.003 .997 .003 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.673 .327 .673 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.649 .351 .649 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.147 .853 .147 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.266 .734 .266 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.551 .449 .551 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.806 .194 .806 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.148 .852 .148 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.989 .011 .989 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.075 .925 .075 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.237 .763 .237 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.336 .664 .336 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.52 .48 .52 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.491 .509 .491 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.349 .651 .349 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.281 .719 .281 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.933 .067 .933 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.91 .09 .91 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.905 .095 .905 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.231 .769 .231 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.543 .457 .543 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.693 .307 .693 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.879 .121 .879 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.977 .023 .977 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.53 .47 .53 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.751 .249 .751 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.435 .565 .435 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.97 .03 .97 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.951 .049 .951 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.871 .129 .871 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.981 .019 .981 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.544 .456 .544 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.655 .345 .655 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.599 .401 .599 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.915 .085 .915 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.732 .268 .732 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.843 .157 .843 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.687 .313 .687 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.98 .02 .98 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.81 .19 .81 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.972 .028 .972 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.769 .231 .769 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.787 .213 .787 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.889 .111 .889 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.885 .115 .885 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.966 .034 .966 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.843 .157 .843 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.989 .011 .989 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.967 .033 .967 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.947 .053 .947 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.935 .065 .935 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.895 .105 .895 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.904 .096 .904 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.867 .133 .867 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.997 .003 .997 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.949 .051 .949 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.96 .04 .96 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.971 .029 .971 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.979 .021 .979 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.989 .011 .989 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.975 .025 .975 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.916 .084 .916 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.969 .031 .969 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.979 .021 .979 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.989 .011 .989 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.987 .013 .987 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.977 .023 .977 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.982 .018 .982 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.988 .012 .988 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooP7n0;o00003?om0_d2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003ol`cc
oo<<looc3?<5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oh1oSon0Oh00Gon0Oh0_l00008ood2o@;o00000_oh1oP00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003ol`ccoo<<l`07oo<<l`Ko00000_oo0?l4o`0000goo@;m00?o0000ooP7n?oh1oP0
1ooh1oP2o`0000Goo@;m00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003ol`ccoo<<l`0<oo<<l`?o00001?oj1OX3o`0000Woo@;m00?o
0000ooP7n?oh1oP02_oh1oP2o`000003ood2oOl0003o000000Oon0Oh00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oh1oP03ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo`3o00>oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on0OhooP7n00?ooP7n003o`000?oh1oSon0Oh00[on0Oh2ol0000;ood2o@Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ol0ocoo0?l00coo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0
003onPGjooX5nP0=ooX5nP;o00004?oh1oP00ol0003on0OhooP7n00:ooP7n003o`000?og2?Oom`Sg
00Oom`Sg00?o0000ood2oOom0_d00_om0_d7o`0000Con@Ki00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj
00gonPGj00Co0000onPGj?oX5nSo00003ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oo
m`Sg00Wom`Sg1?l0000;ooT6n@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000onl@kol0003o00002Ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[o
nPGj00gonPGj00Go0000onPGj?oX5nSoj1OXo`00000=ooP7n003o`000?oh1oSon0Oh00[on0Oh00?o
0000ooL8moog2?L02Oog2?L00ol0003on@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o_4>ooka3_00;oka3_0_l00007oo`3o003o`000?oc3??o
l`cc00col`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oj1OXonPGj003onPGj003o`000?oh1oSo
n0Oh00[on0Oh00?o0000ooP7n?oh1oP02_oh1oP00ol0003om`SgooL8m`09ooL8m`03o`000?oi1_Wo
n@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onl@
koo_4>l01Oo_4>l00ol0003oo0?loo`3o003oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oj1OXonPGj004onPGj003o`000?oh1oSon0Oh00Won0Oh00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003om`SgooL8m`0:ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onl@koo_4>l01_o_4>l2o`0000?o
o0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0<ooX5nP03o`000?oX5nSoj1OX00Ko
j1OX00?o0000ooP7n?oh1oP02?oh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oom`Sg00[o
m`Sg00?o0000ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o_4>ooka3_00Woka3_0_l000000ool0oco0000oo<<l`0<oo<<l`?o00003_oj1OX00ol0003oj1OX
onPGj007onPGj003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooP7n?oh1oP02Ooh1oP00ol0003om`Sg
ooL8m`0;ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o_4>ooka3_00_oka3_00?o0000oo<<looc3?<02_oc3?<2o`0000?ohAkQ00?o
0000ooX5n_oj1OX02_oj1OX00ol0003oj1OXonPGj009onPGj003o`000?oh1oSon0Oh00Kon0Oh00?o
0000ooP7n?oh1oP02?oh1oP00ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oka3_onl@k`0<onl@k`03o`000?oc3??ol`cc00Sol`cc0_l00006on4Nh@;o00002_oj1OX0
0ol0003oj1OXonPGj00:onPGj003o`000?oh1oSon0Oh00Gon0Oh00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_4>l03_o_4>l00ol0003ol`ccoo<<l`04
oo<<l`?o00002_oQ7^400ol0003onPGjooX5nP07ooX5nP03o`000?oX5nSoj1OX00_oj1OX00?o0000
ooP7n?oh1oP00ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oom`Sg00com`Sg00?o0000
ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_4>l03oo_4>l01?l0
003ol`ccoo<<looc3?<2o`0000kohAkQ0_l00006ooX5nP03o`000?oX5nSoj1OX00goj1OX00?o0000
ooP7n?oh1oP00_oh1oP00ol0003on0OhooP7n008ooP7n003o`000?og2?Oom`Sg00com`Sg0ol0000=
ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003oka3_onl@k`0@onl@k`Co00004_oQ7^400ol0
003onPGjooX5nP03ooX5nP03o`000?oX5nSoj1OX00koj1OX00Go0000ooP7n?oh1oSon0Oho`000005
ooP7n0Oo00003?og2?L01Ol0003olPgboo8=l_ob3O;o000000con@Ki00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003oka3_onl@k`0=
onl@k`?o000000CogR7No`000?l0003o00004ooQ7^42o`0000;onPGj00?o0000onPGj?oX5nP04?oX
5nP00ol0003on0Oho`000006o`0000OohacS00?o0000ooL8moog2?L02?og2?L00ol0003olPgboo8=
lP03oo8=lP;o00002?oi1_T3o`0000Koo@;m1?l00002oo`3o003o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oh1oP3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003oka3_onl@
k`0;onl@k`?o00000ooN8Mh01Ol0003oeRWFo`000?nbCK;o000001CohAkQ00?o0000ooX5n_l00000
4ooX5nP00ol0003ohacSon<Lh`0=on<Lh`03o`000?og2?Oom`Sg00Gom`Sg0_l00008oo8=lP03o`00
0?oi1_Won@Ki00Go00000ooh1oP00ol0003oo@;mood2o@03o`0000Ooo0?l00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con0Oh0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000onl@koo_4>l02Oo_4>l3o`0000GogR7N00Co0000omHYe_oF:MKo00000_nbCK800ol0003o
hAkQon4Nh@0Bon4Nh@03o`000?oX5nSoj1OX01;oj1OX00?o0000on<LhooS7><03_oS7><00ol0003o
m`SgooL8m`03ooL8m`03o`000?ob3O;olPgb00WolPgb0_l00009ooP7n0;o00002_ol0o`00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooP7n0;o00001oom0_d5o`0000;o
nPGj00?o0000onl@koo_4>l01_o_4>l3o`0000SogR7N00Co0000omHYe_oF:MKo00000onbCK800ol0
003ohAkQon4Nh@0Aon4Nh@03o`000?oX5nSoj1OX017oj1OX00?o0000on<LhooS7><04?oS7><01Ol0
003om`SgooL8moog2?Oo000000colPgb00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo0?loo`3o00:
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooP7n?oh1oP01ooh1oP3o`00
0004ood2oOl0003o0000o`0000GolPgb0_l00006onl@k`?o00002_oN8Mh01Ol0003oeRWFomHYe_oF
:MKo000000Co/Tfb00?o0000on4NhOoQ7^404?oQ7^400ol0003oj1OXonPGj00AonPGj003o`000?oS
7>?ohacS017ohacS00?o0000ooL8mol000003Oob3O800ol0003on0OhooP7n008ooP7n003o`000?ol
0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP02_oh1oP00ol0003olPgboo8=lP08oo8=lP03o`000?o_4>ooka3_00?o00003OoN8Mh0
1Ol0003oeRWFomHYe_oF:MKo000000Go/Tfb00?o0000on4NhOoQ7^403ooQ7^400ol0003oj1OXonPG
j00AonPGj003o`000?oS7>?ohacS01;ohacS00?o0000oo8=l_ob3O803?ob3O800ol0003on0OhooP7
n008ooP7n003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?ob3O;olPgb00WolPgb0_l0000?omhQgP03o`000?oF:MKo
eRWF00;oeRWF00?o0000ok9=/_nbCK801?nbCK800ol0003ohAkQon4Nh@0=on4Nh@?o00004OoX5nP0
0ol0003ohacSon<Lh`0Con<Lh`03o`000?ob3O;olPgb00_olPgb00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?ob3O;olPgb00WolPgb00?o0000omhQg_oN8Mh03OoN8Mh0
0ol0003oeRWFomHYeP03omHYeP03o`000?nbCK;o/Tfb00Go/Tfb00?o0000on4NhOoQ7^402_oQ7^42
o`0000?oYUVV00?o0000onPGj?oX5nP03_oX5nP00ol0003ohacSon<Lh`0Con<Lh`03o`000?ob3O;o
lPgb00_olPgb00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on0Oh00?o0000oo8=
l_ob3O802oob3O800ol0003ogR7NomhQgP0<omhQgP03o`000?oF:MKoeRWF00?oeRWF00?o0000ok9=
/_nbCK801_nbCK800ol0003ohAkQon4Nh@07on4Nh@;o00001_nVFJH2o`0000koj1OX00?o0000on<L
hooS7><04ooS7><00ol0003olPgboo8=lP0;oo8=lP03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3
o?ol0o`03?ol0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on0Oh00?o0000oo8=l_ob3O802oob3O800ol0003ogR7NomhQgP0;omhQ
gP03o`000?oF:MKoeRWF00CoeRWF00?o0000ok9=/_nbCK801onbCK800ol0003ohAkQon4Nh@05on4N
h@03o`000?nVFJKoYUVV00SoYUVV00?o0000onPGj?oX5nP02_oX5nP00ol0003ohacSon<Lh`0Don<L
h`03o`000?ob3O;olPgb00_olPgb00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00<oo`3
o003o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on0Oh00?o0000oo8=l_ob3O802oob3O800ol0003ogR7NomhQgP0;omhQgP03o`000?oF:MKoeRWF
00CoeRWF00?o0000ok9=/_nbCK802?nbCK800ol0003ohAkQon4Nh@02on4Nh@;o00003?nVFJH2o`00
00[oj1OX00?o0000on<LhooS7><05?oS7><00ol0003olPgboo8=lP0;oo8=lP03o`000?oh1oSon0Oh
00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003olPgboo8=lP0<oo8=lP03
o`000?oN8MkogR7N00WogR7N00?o0000omHYe_oF:MH01OoF:MH00ol0003o/Tfbok9=/P09ok9=/P04
o`000?oQ7^7o0000o`00013oYUVV0_l00008onPGj003o`000?oS7>?ohacS01CohacS0ol0000;oo8=
lP03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7
n?oh1oP02?oh1oP00ol0003olPgboo8=lP0;oo8=lP;o00002_oN8Mh00ol0003oeRWFomHYeP06omHY
eP03o`000?nbCK;o/Tfb00[o/Tfb00?o0000ojIIY_nVFJH04_nVFJH00ol0003oj1OXonPGj004onPG
j003o`000?oS7>?ohacS01GohacS00?o0000omdRgOoM8]d01Ol00005oo8=lP03o`000?oh1oSon0Oh
00[on0Oh00?o0000oo`3o?ol0o`03_ol0o`3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooP7n?oh1oP01ooh1oP00ol0003olPgboo8=lP0;oo8=lP04
o`000?o><LkocS7>o`0000WogR7N00?o0000omHYe_oF:MH01_oF:MH00ol0003o/Tfbok9=/P0:ok9=
/P03o`000?nVFJKoYUVV01?oYUVV0_l00003onPGj0Co00005?oS7><00ol0003ogB;MomdRg@06omdR
g@Co000000?olPgbo`000?oh1oP02ooh1oP00ol0003oo0?loo`3o00>oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP01ooh1oP00ol0003olPgboo8=lP09oo8=lP;o00001?o><Lh00ol0003ogR7NomhQgP05omhQgP03
o`000?oF:MKoeRWF00OoeRWF00?o0000ok9=/_nbCK802_nbCK800ol0003oYUVVojIIYP0EojIIYP03
o`000?oX5nSo000000Co^dBk0ol0000@on<Lh`03o`000?oM8]gogB;M00_ogB;M0_l0000<ooP7n003
o`000?ol0ocoo0?l00coo0?l0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo8=l_ob3O802?ob3O800ol0003ocS7>
olhacP05olhacP03o`000?oN8MkogR7N00CogR7N00?o0000omHYe_oF:MH01ooF:MH00ol0003o/Tfb
ok9=/P0:ok9=/P03o`000?nVFJKoYUVV01KoYUVV00?o0000ok]4^onkA;/01_nkA;/3o`0000cohacS
00?o0000omdRgOoM8]d03OoM8]d00ol0003on0OhooP7n009ooP7n0Go00002Ool0o`2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooP7n?oh1oP01_oh
1oP00ol0003olPgboo8=lP07oo8=lP03o`000?o><LkocS7>00OocS7>00?o0000omhQg_oN8Mh00_oN
8Mh00ol0003oeRWFomHYeP08omHYeP03o`000?nbCK;o/Tfb00Wo/Tfb00?o0000ojIIY_nVFJH05onV
FJH00ol0003o^dBkok]4^`09ok]4^`?o00002OoS7><00ol0003ogB;MomdRg@0>omdRg@Ko00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_ol0o`2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on0OhooP7n006ooP7n003o`000?ob
3O;olPgb00GolPgb0_l0000;olhacP04o`000?oN8MkogR7No`0000_oeRWF00?o0000ok9=/_nbCK80
2OnbCK800ol0003oYUVVojIIYP0FojIIYP03o`000?nkA;_o^dBk00go^dBk0ol00005on<Lh`03o`00
0?oM8]gogB;M00oogB;M00?o0000onXEj_oZ5NX00ooZ5NX4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oh1oP00ol0003olPgboo8=
lP05oo8=lP03o`000?o><LkocS7>00cocS7>00?o0000omhQg_l000002ooF:MH00ol0003o/Tfbok9=
/P07ok9=/P?o00006?nVFJH00ol0003o^dBkok]4^`0@ok]4^`?o000000?ohacSo`000?oM8]d04?oM
8]d00ol0003ojQGZonXEjP07onXEjP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooP7n003o`000?ob3O;olPgb00?olPgb0_l0000@olhacP03o`000?oF:MKoeRWF00[oeRWF00?o0000
ok9=/_nbCK800onbCK84o`0000;oPgb300?o0000ojIIY_nVFJH05OnVFJH00ol0003o^dBkok]4^`0D
ok]4^`03o`000?oM8]gogB;M013ogB;M00?o0000onXEj_oZ5NX01ooZ5NX00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?olPgb00?o0000olhac_o><Lh04?o><Lh00ol0
003oeRWFomHYeP0:omHYeP03o`000?nbCK;o000000?o00001on3O8<00ol0003oYUVVojIIYP0DojII
YP03o`000?nkA;_o^dBk01Co^dBk00?o0000omdRgOoM8]d03ooM8]d00ol0003ojQGZonXEjP08onXE
jP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o[5>_ojaC[00?o
jaC[00?o0000oo8=l_l000004oo><Lh4o`0000WoeRWF0_l0000<oh=lP`03o`000?nVFJKoYUVV01?o
YUVV00?o0000ok]4^onkA;/05OnkA;/00ol0003ogB;MomdRg@0>omdRg@03o`000?oZ5N[ojQGZ00So
jQGZ00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ojaC[on/Dj`05on/Dj`03o`00
0?o><LkocS7>01;ocS7>00Co0000ohYeR_n:MH[oRWF:1Ol00003omHYeP03o`000?n3O8?oPgb300go
Pgb30ol0000@ojIIYP;o00006?nkA;/00ol0003ogB;MomdRg@0=omdRg@03o`000?oZ5N[ojQGZ00Wo
jQGZ00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ojaC[on/Dj`06on/Dj`03o`00
0?o><LkocS7>017ocS7>00?o0000ohYeR_n:MHX01on:MHX3o`00013oPgb300?o0000oe6^DOmA[U40
1Ol00009ojIIYP;o000000?oOH9mo`000?nkA;/05onkA;/00ol0003ogB;MomdRg@0=omdRg@03o`00
0?oZ5N[ojQGZ00WojQGZ00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o[5>_ojaC[00OojaC[00?o0000olhac_o><Lh03oo><Lh00ol0003oRWF:ohYe
RP0:ohYeRP03o`000?n3O8?oPgb300goPgb300?o0000oe6^DOmA[U401_mA[U44o`0000CoYUVV00?o
0000ogf2OOmmPWd00_mmPWd00ol0003o^dBkok]4^`0Fok]4^`03o`000?oM8]gogB;M00_ogB;M00?o
0000onXEj_oZ5NX02ooZ5NX00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ojaC[00?o0000olhac_o><Lh03oo><Lh00ol0003oRWF:ohYeRP0;ohYeRP03o`000?n3O8?o
Pgb300coPgb300?o0000oe6^DOmA[U402_mA[U44o`0000GoOH9m00?o0000ok]4^onkA;/05_nkA;/0
0ol0003ogB;MomdRg@0:omdRg@03o`000?oZ5N[ojQGZ00cojQGZ00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000on/D
joo[5>/02Oo[5>/00ol0003ocS7>olhacP0=olhacP03o`000?n:MH[oRWF:00coRWF:00?o0000oh=l
Pon3O8<03?n3O8<00ol0003oDJiAoe6^D@0;oe6^D@03o`000?mFZEKo000000KoOH9m00?o0000ok]4
^onkA;/05_nkA;/00ol0003ogB;MomdRg@09omdRg@03o`000?oZ5N[ojQGZ00cojQGZ00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o[5>_ojaC[00_ojaC[00?o0000olhac_o><Lh02?o><Lh4o`0000oo
RWF:00?o0000oh=lPon3O8<02on3O8<00ol0003oDJiAoe6^D@0;oe6^D@04o`000?mFZEKoEZUFo`00
00OoOH9m00?o0000ok]4^onkA;/05OnkA;/00ol0003ogB;MomdRg@08omdRg@03o`000?oZ5N[ojQGZ
00gojQGZ00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o[5>_ojaC[00_ojaC[00?o0000olhac_o>
<Lh00oo><Lh5o`0000?oSW6>00?o0000ohYeR_n:MHX03_n:MHX00ol0003oPgb3oh=lP`0:oh=lP`03
o`000?mA[U7oDJiA00[oDJiA00Go0000oeJYE_mFZEKoEZUFo`000007ogf2O@03o`000?nkA;_o^dBk
01Go^dBk00?o0000omdRgOoM8]d02?oM8]d00ol0003ojQGZonXEjP0=onXEjP03o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003ojaC[on/Dj`0<on/Dj`Go00002On>LHh00ol0003o
RWF:ohYeRP0<ohYeRP;o00003?n3O8<00ol0003oDJiAoe6^D@0:oe6^D@05o`000?mFZEKoEZUFoeJY
E_l000002?mmPWd00ol0003o^dBkok]4^`0Dok]4^`?o00001ooM8]d00ol0003ojQGZonXEjP0>onXE
jP03o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000on/Djoo[5>/03?o[5>/01?l0003obcC;ol/dbol0000;ohiaSP03o`000?n:MH[oRWF:
00_oRWF:00Co0000oco0?olo`3oo00002_n3O8<00ol0003oDJiAoe6^D@0:oe6^D@03o`000?mFZEKo
EZUF00;oEZUF00?o0000ogf2OOmmPWd01_mmPWd00ol0003o^dBkok]4^`0Aok]4^`?o00000oo4>l@0
0ol0003ogB;MomdRg@04omdRg@03o`000?oZ5N[ojQGZ00gojQGZ1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o[5>_ojaC[00_ojaC[00?o0000ol/dboo;=</00_o;=</0
0ol0003oSW6>ohiaSP08ohiaSP03o`000?n:MH[oRWF:00[oRWF:00?o0000oco0?olo`3l00_lo`3l0
0ol0003oPgb3oh=lP`03oh=lP`Go00002omA[U400ol0003oEZUFoeJYEP03oeJYEP03o`000?mmPWgo
OH9m00OoOH9m00?o0000ok]4^onkA;/03_nkA;/2o`0000Ooa3_400?o0000omdRgOoM8]d00_oM8]d0
0ol0003ojQGZonXEjP0=onXEjP03o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o[5>_ojaC[00[ojaC[00?o0000ol/d
boo;=</00oo;=</00ol0003oSW6>ohiaSP09ohiaSP03o`000?n:MH[oRWF:00SoRWF:00?o0000oco0
?olo`3l01?lo`3l5o`0000Co?L8m00?o0000oe6^DOmA[U402OmA[U400ol0003oEZUFoeJYEP03oeJY
EP03o`000?mmPWgoOH9m00SoOH9m00?o0000ok]4^onkA;/02_nkA;/3o`0000[oa3_400Go0000omdR
gOoM8]gogB;Mo`00000>onXEjP03o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o[5>_ojaC[00[ojaC[00?o0000ol/d
boo;=</01?o;=</00ol0003oSW6>ohiaSP09ohiaSP03o`000?n:MH[oRWF:00OoRWF:00?o0000oco0
?olo`3l01Olo`3l00ol0003o?L8mocg2?@07ocg2?@03o`000?mA[U7oDJiA00OoDJiA00?o0000oeJY
E_mFZEH01?mFZEH00ol0003oOH9mogf2O@08ogf2O@03o`000?nkA;_o^dBk00So^dBk0_l0000>ol@k
a0Co00003?oZ5NX2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003ojaC[on/Dj`09on/Dj`03o`000?o;=<_obcC;00KobcC;00?o0000ohiaS_n>LHh02On>LHh00ol0
003oRWF:ohYeRP05ohYeRP03o`000?lo`3oo?l0o00Ko?l0o00?o0000ocg2?Olm`Sd02?lm`Sd00ol0
003oDJiAoe6^D@06oe6^D@03o`000?mFZEKoEZUF00CoEZUF00?o0000ogf2OOmmPWd02OmmPWd4o`00
00?o^dBk0ol0000@ol@ka005o`000?oW6>OoiaSWonLHiol000002_oZ5NX00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[ojaC[00?o0000ol/dboo;=</01oo;=</0
0ol0003oSW6>ohiaSP09ohiaSP03o`000?n:MH[oRWF:00CoRWF:00?o0000oco0?olo`3l01olo`3l0
0ol0003o?L8mocg2?@08ocg2?@;o00001_mA[U400ol0003oEZUFoeJYEP05oeJYEP03o`000?mmPWgo
OH9m00WoOH9m00Co0000oiUVVOnIIYWoVFJI0ol0000Bol@ka003o`000?oW6>OoiaSW00?oiaSW0_l0
0006onXEjP;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o[5>/00ol0003obcC;ol/db`08ol/db`03o`000?n>LHko
SW6>00[oSW6>00?o0000ohYeR_n:MHX00_n:MHX00ol0003o?l0ooco0?`08oco0?`03o`000?lm`Sgo
?L8m00Ko?L8m0_l00002obCK9003o`000?mA[U7oDJiA00;oDJiA00?o0000oeJYE_mFZEH01_mFZEH0
0ol0003oOH9mogf2O@08ogf2O@03o`000?nIIYWoVFJI00CoVFJI00?o0000ol@ka?o4>l@03oo4>l@0
0ol0003oiaSWonLHi`06onLHi`;o00000ooZ5NX00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000on/Djoo[5>/01oo[5>/00ol0003obcC;ol/db`0:ol/db`03o`000?n>LHkoSW6>
00WoSW6>00Go0000ohYeR_n:MH[oRWF:o`00000;oco0?`03o`000?lm`Sgo?L8m00Co?L8m0_l00005
obCK9005o`000?mA[U7oDJiAoe6^DOl000002?mFZEH00ol0003oOH9mogf2O@08ogf2O@03o`000?nI
IYWoVFJI00GoVFJI00?o0000ol@ka?o4>l@03_o4>l@00ol0003oiaSWonLHi`08onLHi`03o`000?oZ
5N[o000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000on/Djoo[5>/01_o[5>/00ol0003obcC;
ol/db`0;ol/db`03o`000?n>LHkoSW6>00WoSW6>00Co0000ohYeR_n:MH[o00003?lo`3l00ol0003o
?L8mocg2?@02ocg2?@;o00002?lTfb@00ol0003oDJiAo`000009oeJYEP03o`000?mmPWgoOH9m00So
OH9m00?o0000oiUVVOnIIYT01OnIIYT00ol0003oa3_4ol@ka00=ol@ka003o`000?oW6>OoiaSW00[o
iaSW00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o[5>_ojaC[00CojaC[00?o0000ol/dboo;=</03?o;=</00ol0003oSW6>ohiaSP0:ohiaSP?o0000
3?lo`3l00ol0003o?L8mocg2?@02o`0000_o9=/T00?o0000oeJYE_mFZEH02?mFZEH00ol0003oOH9m
ogf2O@07ogf2O@03o`000?nIIYWoVFJI00OoVFJI00?o0000ol@ka?o4>l@03?o4>l@00ol0003oiaSW
onLHi`0;onLHi`;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo[
5>/00ol0003obcC;ol/db`0>ol/db`03o`000?n>LHkoSW6>00SoSW6>00Co0000odJiA_m6^DKoA[U6
0_l0000:oco0?`?o00003OlTfb@00ol0003oEZUFoeJYEP08oeJYEP03o`000?mmPWgoOH9m00OoOH9m
00?o0000oiUVVOnIIYT01onIIYT00ol0003oa3_4ol@ka00;ol@ka003o`000?oW6>OoiaSW00coiaSW
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003oo@;m003o`000?o[5>_o0000017obcC;00?o0000ohiaS_n>LHh01on>LHh00ol0003oA[U6odJi
AP04odJiAP;o00002?lo`3l00ol0003o9=/TobCK900>obCK90;o00002?mFZEH00ol0003oOH9mogf2
O@06ogf2O@03o`000?nIIYWoVFJI00WoVFJI00?o0000ol@ka?o4>l@02Oo4>l@00ol0003oiaSWonLH
i`0=onLHi`03o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006oo@;m003o`000?o;=<_obcC;013obcC;00?o0000ohiaS_n>LHh01_n>LHh0
0ol0003oA[U6odJiAP07odJiAP03o`000?lo`3oo?l0o00Co?l0o0ol0000>obCK9003o`000?lUfRGo
9MXU00?o00001OmFZEH00ol0003oOH9mogf2O@06ogf2O@03o`000?nIIYWoVFJI00[oVFJI00?o0000
ol@ka?o4>l@02?o4>l@00ol0003oiaSWonLHi`0=onLHi`03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008oo@;m003o`000?o;=<_obcC;
017obcC;00Co0000ohiaS_n>LHkoSW6>1?l0000;odJiAP;o000000Co?l0oo`000?l0003o00000olA
kQ42o`0000_o9=/T00?o0000obGJ9OlUfRD01?lUfRD2o`0000?oEZUF00?o0000ogf2OOmmPWd01_mm
PWd00ol0003oVFJIoiUVV@0:oiUVV@03o`000?o4>lCoa3_400Ooa3_400?o0000onLHiooW6>L03_oW
6>L00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<oo@;m003o`000?o;=<_o
bcC;013obcC;1?l00003oh5nP@03o`000?m6^DKoA[U600_oA[U600?o0000oa7^4OlAkQ401_lAkQ40
0ol0003o9=/TobCK9007obCK9003o`000?lUfRGo9MXU00Oo9MXU3?l0000>oiUVV@03o`000?o4>lCo
a3_400Koa3_400?o0000onLHiooW6>L03_oW6>L00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_od2o@00ol0003obcC;ol/db`0?ol/db`03o`000?n1OX7oPGj100KoPGj100?o0000
odJiA_m6^DH02_m6^DH00ol0003o4NhAoa7^4@07oa7^4@;o00001_lTfb@00ol0003o9MXUobGJ9@08
obGJ9@03o`000?mIYUWoFJII00SoFJII00?o0000oiUVVOnIIYT03?nIIYT00ol0003oa3_4ol@ka005
ol@ka003o`000?oW6>OoiaSW00ooiaSW0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03_od2o@00ol0
003obcC;ol/db`0>ol/db`03o`000?n1OX7oPGj100OoPGj100?o0000odJiA_m6^DH02_m6^DH00ol0
003o4NhAoa7^4@09oa7^4@;o00000olTfb@00ol0003o9MXUobGJ9@09obGJ9@03o`000?mIYUWoFJII
00WoFJII00?o0000oiUVVOnIIYT02_nIIYT4o`0000Coa3_400?o0000onLHiooW6>L04?oW6>L01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03ood2o@@o`0000[oPGj100?o0000odJi
A_m6^DH02Om6^DH00ol0003o3o0?o`00000<oa7^4@05o`000?lTfbCo0000o`_d2ol000002_lUfRD0
0ol0003oFJIIoeVVF@09oeVVF@03o`000?nIIYWoVFJI00OoVFJI0ol00004ojm@[`?o000000?oa3_4
o`000?oW6>L04OoW6>L01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00?
oo@;m003o`000?o1?/7o`Ck100co`Ck100?o0000oh5nPOn1OX402On1OX400ol0003oA[U6odJiAP07
odJiAP04o`000?l?l0oo3o0?o`0000go4NhA00Go0000o`_d2ol;m0_o2o@;o`000009obGJ9@03o`00
0?mIYUWoFJII00[oFJII00?o0000oiUVVOnIIYT00onIIYT3o`0000[o[e2_00?o0000onLHiooW6>L0
4?oW6>L00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo@;m?od2o@03ood2o@00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?n1
OX7oPGj100WoPGj100?o0000odJiA_m6^DH01_m6^DH00ol0003o3o0?o`o`3`02o`o`3`03o`000?lA
kQ7o4NhA00[o4NhA00?o0000o`_d2ol;m0/00_l;m0/00ol0003o9MXUobGJ9@06obGJ9@03o`000?mI
YUWoFJII00[oFJII00?o0000oiUVVOnIIYT00ol0000=ojm@[`03o`000?oW6>OoiaSW013oiaSW00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00=oo@;m0?o00003oo1?/40
0ol0003oPGj1oh5nP@08oh5nP@03o`000?m6^DKoA[U600GoA[U600?o0000o`o`3ol?l0l00ol?l0l0
0ol0003o4NhAoa7^4@0:oa7^4@03o`000?l;m0_o2o@;00?o2o@;00?o0000obGJ9OlUfRD01OlUfRD0
0ol0003oFJIIoeVVF@0;oeVVF@;o00004On_D:l00ol0003oiaSWonLHi`0?onLHi`03o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_doo@;m009oo@;m0Go00000_oW6>L00ol0
003o`Ck1ol4n`@0=ol4n`@03o`000?n1OX7oPGj100WoPGj100?o0000odJiA_m6^DH01?m6^DH00ol0
003o3o0?o`o`3`04o`o`3`03o`000?lAkQ7o4NhA00So4NhA00?o0000o`_d2ol;m0/01Ol;m0/00ol0
003o9MXUobGJ9@04obGJ9@03o`000?mIYUWoFJII00_oFJII00?o0000ojm@[on_D:l04?n_D:l00ol0
003oiaSWonLHi`0?onLHi`03o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?od2oCom0_d00Com0_d1Ol00007onLHi`03
o`000?o1?/7o`Ck100go`Ck100?o0000oh5nPOn1OX402On1OX400ol0003oA[U6odJiAP03odJiAP03
o`000?l?l0oo3o0?00Go3o0?00?o0000oa7^4OlAkQ402?lAkQ400ol0003o2o@;o`_d2`06o`_d2`03
o`000?lUfRGo9MXU00?o9MXU00?o0000oeVVFOmIYUT02omIYUT00ol0003o[e2_ojm@[`0@ojm@[`03
o`000?oW6>OoiaSW00ooiaSW00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?l00000
1?l0000<onLHi`03o`000?o1?/7o`Ck100ko`Ck100?o0000oh5nPOn1OX402?n1OX400ol0003oA[U6
odJiAP02odJiAP03o`000?l?l0oo3o0?00Oo3o0?00?o0000oa7^4OlAkQ401olAkQ400ol0003o2o@;
o`_d2`07o`_d2`03o`000?lUfRGo9MXU00;o9MXU00?o0000oeVVFOmIYUT02omIYUT00ol0003o[e2_
ojm@[`0Aojm@[`03o`000?oW6>OoiaSW00goiaSW00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oiaSW00?o0000ol4n`Oo1?/403_o1
?/400ol0003oPGj1oh5nP@09oh5nP@04o`000?m6^DKoA[U6o`0000[o3o0?00?o0000oa7^4OlAkQ40
1olAkQ400ol0003o2o@;o`_d2`08o`_d2`05o`000?lUfRGo9MXUobGJ9Ol000003OmIYUT00ol0003o
[e2_ojm@[`0Aojm@[`?o00003OoW6>L00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;onPGj00?o0000onLHiooW6>L03ooW6>L00ol0003o
`Ck1ol4n`@0>ol4n`@03o`000?n1OX7oPGj100SoPGj11Ol0000;o`o`3`03o`000?lAkQ7o4NhA00Ko
4NhA00?o0000o`_d2ol;m0/02Ol;m0/01?l0003o9MXUobGJ9Ol0000=oeVVF@03o`000?n_D:oo[e2_
017o[e2_00?o0000omLXeooG:=L00ol0000:onLHi`Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooX5nP03o`000?oW6>OoiaSW00koiaSW00?o0000ol4n
`Oo1?/403_o1?/400ol0003oPGj1oh5nP@07oh5nP@03o`000?l[e2_o:m@[00?o:m@[00?o0000o`o`
3ol?l0l02?l?l0l00ol0003o4NhAoa7^4@05oa7^4@03o`000?l;m0_o2o@;00[o2o@;1Ol0000<oeVV
F@03o`000?n_D:oo[e2_013o[e2_00?o0000omLXeooG:=L01?oG:=L3o`0000KoiaSW00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0003oiaSWonLHi`0=onLHi`03o`000?o1?/7o`Ck100oo
`Ck100?o0000oh5nPOn1OX401?n1OX42o`0000Oo:m@[00?o0000o`o`3ol?l0l01ol?l0lEo`0000Go
9MXU00?o0000oeVVFOmIYUT02?mIYUT3o`00013o[e2_00?o0000omLXeooG:=L02?oG:=L3o`0000;o
iaSW00?o0000ooX5n_oj1OX02?oj1OX5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oiaSWonLHi`0;onLHi`Co0000
3oo1?/400ol0003oPGj1oh5nP@03oh5nP@03o`000?l[e2_o:m@[00So:m@[00?o0000o`o`3ol?l0l0
1?l?l0l2o`0000So0o`300?o0000o`3o0?l0o`002?l0o`000ol0003o9MXUobGJ9@05obGJ9@;o0000
1_mIYUT2o`0000?oKi1_00?o0000ojm@[on_D:l03?n_D:l00ol0003oebSGomLXe`0<omLXe`;o0000
4?oj1OX3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00KonPGj00?o
0000onLHiooW6>L02OoW6>L00ol0003okA;]o`000002olDja@?o00003?o1?/401?l0003oPGj1oh5n
POn1OX42o`0000co:m@[00?o0000o`o`3ol?l0l00_l?l0l00ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l0o`3o0?l000So0?l000?o0000obGJ9OlUfRD01olUfRD00ol0003oFJIIoeVVF@02oeVVF@03o`00
0?m_T6ooKi1_00CoKi1_0_l0000;ojm@[`03o`000?oG:=OoebSG00coebSG00?o0000onl@kol00000
4_oj1OX00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00OonPGj00?o
0000onLHiooW6>L01_oW6>L2o`0000;okA;]00?o0000olDjaOo5>/D00oo5>/D3o`0000[o`Ck100?o
0000oh5nPOl000003ol[e2/01?l0003o3o0?o`000?l0000;o`?l0`03o`000?l0o`3o0?l000So0?l0
00?o0000obGJ9OlUfRD02?lUfRD01?l0003oFJIIo`000?l00009ofn@K`03o`000?n_D:oo[e2_00Oo
[e2_00?o0000omLXeooG:=L03?oG:=L01?l0003oka3_onl@kol0000CooX5nP03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oW6>OoiaSW00Co
iaSW00?o0000ondBkOo]4^d00oo]4^d00ol0003oaC[5olDja@05olDja@?o00001_o1?/44o`00013o
:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lUfRGo9MXU00Wo
9MXU00?o0000ofn@Kom_T6l02_m_T6l2o`0000Ko[e2_00?o0000omLXeooG:=L03?oG:=L00ol0003o
ka3_onl@k`02onl@k`03o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00WonPGj00Co0000onLHiooW6>Oo
iaSW0_l00006ondBk@03o`000?o5>/GoaC[500SoaC[50ol000000oo1?/7o0000o`000004ogB;M003
o`000?l[e2_o:m@[00go:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0?l0o`3o0007o`3o0003
o`000?lUfRGo9MXU00Wo9MXU00?o0000ofn@Kom_T6l03?m_T6l00ol0003o[e2_ojm@[`03o`0000ko
ebSG00?o0000onl@koo_4>l00oo_4>l00ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00[o
nPGj00?o0000onLHiol000002?o]4^d00ol0003oaC[5olDja@0;olDja@03o`000?mdRgCoM8]d00Go
M8]d00?o0000ob_D:ol[e2/03?l[e2/00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l0o`3o0?l000Oo
0?l000?o0000obGJ9OlUfRD02?lUfRD2o`0000ooKi1_0_l00002olTfb@03o`000?oG:=OoebSG00_o
ebSG00?o0000onl@koo_4>l01?o_4>l00ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000ondBkOo]4^d0
1oo]4^d00ol0003oaC[5olDja@0;olDja@03o`000?mdRgCoM8]d00KoM8]d00?o0000ob_D:ol[e2/0
2ol[e2/2o`0000go0o`300?o0000o`3o0?l0o`001ol0o`000ol0003o9MXUobGJ9@07obGJ9@04o`00
0?lka3_o>l@ko`0000koKi1_00?o0000olTfbOo9=/T00_o9=/T00ol0003oebSGomLXe`09omLXe`03
o`000?o_4>ooka3_00Koka3_00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooX5n_oj1OX02_oj1OX2o`0000Wo
kA;]00?o0000olDjaOo5>/D02oo5>/D00ol0003oM8]dogB;M007ogB;M003o`000?l[e2_o:m@[00Wo
:m@[00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lUfRGo9MXU
00Ko9MXU00Go0000oc_4>olka3_o>l@ko`00000>ofn@K`03o`000?o9=/WobCK900?obCK900?o0000
omLXeooG:=L01ooG:=L00ol0003oka3_onl@k`07onl@k`03o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oj1O[onPGj
00WonPGj00Co0000ooT6nOoi1_Wo00002Oo]4^d00ol0003oaC[5olDja@09olDja@03o`000?mdRgCo
M8]d00WoM8]d00?o0000ob_D:ol[e2/01ol[e2/00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`3o0?l0o`001ol0o`000ol0003o9MXUobGJ9@05obGJ9@03o`000?lka3_o
>l@k00?o>l@k00?o0000ofn@Kom_T6l02_m_T6l00ol0003obCK9olTfb@05olTfb@03o`000?oG:=Oo
ebSG00GoebSG00?o0000onl@koo_4>l02?o_4>l00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000WonPGj00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okA;]ondBk@06ondBk@03o`000?o5>/GoaC[500WoaC[500?o0000ogB;
M?mdRg@02_mdRg@00ol0003o:m@[ob_D:`05ob_D:`03o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0?l0o`3o0007o`3o0003o`000?lUfRGo9MXU00Co9MXU00?o0000oc_4
>olka3/01?lka3/00ol0003oKi1_ofn@K`0:ofn@K`03o`000?o9=/WobCK900KobCK900?o0000omLX
eooG:=L00ooG:=L00ol0003oka3_onl@k`09onl@k`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooj1OX00ol0003o
n@KiooT6n@03ooT6n@03o`000?o]4^gokA;]00KokA;]00?o0000olDjaOo5>/D02Oo5>/D00ol0003o
M8]dogB;M00;ogB;M003o`000?l[e2_o:m@[00?o:m@[00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l0o`3o0?l000Ko0?l000?o0000obGJ9OlUfRD00_lUfRD2o`0000So
>l@k00?o0000ofn@Kom_T6l02Om_T6l00ol0003obCK9olTfb@07olTfb@05o`000?oG:=OoebSGomLX
eol000003Oo_4>l00ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooj1O[o0000ooT6n@06ooT6n@03
o`000?o]4^gokA;]00GokA;]00?o0000olDjaOo5>/D02Oo5>/D00ol0003oM8]dogB;M00<ogB;M005
o`000?l[e2_o:m@[ob_D:ol000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l0o`3o0?l0
00Ko0?l000?o0000obGJ9Ol000000_l000000olCk1?o0000oc_4>`07oc_4>`03o`000?m_T6ooKi1_
00SoKi1_00?o0000olTfbOo9=/T02Oo9=/T00ol0003oebSGo`00000=onl@k`Co00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000ondBkOo]4^d01?o]4^d00ol0003oaC[5olDja@09olDja@03
o`000?mdRgCoM8]d00goM8]d00?o0000ob_D:ol000003?l9mPT:o`0000Oo0?l00ol00005oa?/4`03
o`000?lka3_o>l@k00Ko>l@k00?o0000ofn@Kom_T6l01om_T6l00ol0003obCK9olTfb@0:olTfb@03
o`000?o_4>ooka3_00_oka3_00?o0000oo/4nook1?/00_ok1?/3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o]4^gokA;]00GokA;]00?o0000olDjaOo5>/D01oo5>/D00ol0003oM8]dogB;M00?ogB;M0;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l0o`3o0?l000;o0?l00ol00008oa?/4`03o`00
0?lka3_o>l@k00Ko>l@k00?o0000ofn@Kom_T6l01om_T6l00ol0003obCK9olTfb@0:olTfb@03o`00
0?o_4>ooka3_00[oka3_00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o]4^gokA;]00CokA;]00?o0000olDjaOo5>/D01oo5>/D00ol0003oM8]dogB;
M00>ogB;M004o`000?lcc3?o<l`co`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0?l0
o`000?l0000<oa?/4`03o`000?lka3_o>l@k00Ko>l@k00?o0000ofn@Kom_T6l01_m_T6l00ol0003o
bCK9olTfb@0;olTfb@03o`000?o_4>ooka3_00Ooka3_0_l00009oo/4n`03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000ondBkOo]4^d00oo]4^d>o`0000goM8]d00?o0000oc?<<olcc3<0
0_lcc3<00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oa?/4olCk1<0
3?lCk1<00ol0003o>l@koc_4>`06oc_4>`03o`000?m_T6ooKi1_00GoKi1_00?o0000olTfbOo9=/T0
3?o9=/T00ol0003oka3_onl@k`06onl@k`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okA;]ondBkOo]4^go000000_occ3?00?o0000og6>LOmaSW400ol00009ogB;M003o`00
0?lcc3?o<l`c00Co<l`c00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lCk1?o4n`C00go4n`C00?o0000oc_4>olka3/01_lka3/00ol0003oKi1_ofn@K`03ofn@K`?o0000
3Oo9=/T00ol0003oka3_onl@k`05onl@k`03o`000?ok1?_on`Ck00con`Ck0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cocc3?00?o0000og6>LOmaSW400omaSW43o`0000GoM8]d00?o0000oc?<<olcc3<01_lc
c3<01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oa?/4olCk1<03OlCk1<00ol0003o>l@k
oc_4>`06oc_4>`03o`000?m_T6ooKi1_00?o00000on;M8/00ol0003obCK9olTfb@0;olTfb@03o`00
0?o_4>ooka3_00?oka3_00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003oo@;m003o`000?o?<<oocc3?00[occ3?00?o0000og6>LOmaSW401_maSW43o`000003ogB;M?l0
003o<l`c00Wo<l`c00?o0000o`Wf2Ol000004?l9mPT00ol0003o4n`Coa?/4`0=oa?/4`03o`000?lk
a3_o>l@k00Oo>l@k0_l00007oh]dR`03o`000?o9=/WobCK900[obCK900Co0000onl@koo_4>ooka3_
0ol0000?oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom0_d00?o0000oll`coo?
<<l02_o?<<l00ol0003oLHiaog6>L@09og6>L@03o`000?lcc3?o<l`c00[o<l`c00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o4n`Coa?/4`0>oa?/4`03o`000?lka3_o>l@k00Ko>l@k00?o0000oh]dRon;
M8/01on;M8/4o`0000SobCK900Co0000onl@koo_4>oo00000ooe2_D2o`0000gon`Ck00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?od2oCom0_d00Oom0_d00?o0000oll`coo?<<l02Oo?<<l00ol0003o
LHiaog6>L@0:og6>L@03o`000?lcc3?o<l`c00[o<l`c00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
4n`Coa?/4`0>oa?/4`03o`000?lka3_o>l@k00Go>l@k00?o0000oh]dRon;M8/02?n;M8/01?l0003o
cc3?oll`coo?<<l7o`0000;obCK90_l00006ooD:m@;o00003?ok1?/00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000oo@;m?od2o@02?od2o@00ol0003occ3?oll`c`08oll`c`03o`000?maSW7oLHia00[o
LHia00?o0000oc?<<olcc3<02olcc3<00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lCk1?o4n`C00ko
4n`C1Ol00002oc_4>`03o`000?n;M8_oRgB;00WoRgB;00?o0000oll`coo?<<l02?o?<<l3o`0000Wo
m@[e0_l0000:oo/4n`03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om0_doo@;m007oo@;m003o`00
0?o?<<oocc3?00Socc3?00?o0000og6>LOmaSW402_maSW400ol0003o<l`coc?<<`0:oc?<<`;o0000
3_l9mPT3o`0000go4n`C0ol00005odNhA`;o00002on;M8/00ol0003occ3?oll`c`0;oll`c`;o0000
2_oe2_D2o`0000Oon`Ck0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?od2oCom0_d00Oom0_d00?o0000oll`coo?<<l02?o?<<l>o`0000Wo<l`c0ol000000olXebSo0000
o`Wf2@0:o`Wf2@?o00000_lJiAX00ol0003o4n`Coa?/4`09oa?/4`;o00002Om7^4L00ol0003oRgB;
oh]dR`09oh]dR`03o`000?o?<<oocc3?00_occ3?00?o0000onDJiOl000002ooe2_D2o`0000Con`Ck
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?od2oCom0_d00Kom0_d00?o0000oll`coo?<<l02?o?<<l00ol0003oKi1_
ofn@K`0:ofn@K`03o`000?lcc3?o<l`c00Co<l`c0ol00005obSG:003o`000?l9mPWo2OH900Co2OH9
1?l00006oa[U6P03o`000?lCk1?o4n`C00Ko4n`C0_l0000;odNhA`03o`000?n;M8_oRgB;00WoRgB;
00?o0000oll`coo?<<l02_o?<<l01Ol0003oiA[UonDJiOoU6^Go000000com@[e0_l000000ook1?_o
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000oo@;m?od2o@01_od2o@00ol0003occ3?oll`c`07oll`c`03o`00
0?m_T6ooKi1_00_oKi1_00?o0000oc?<<olcc3<00_lcc3<2o`0000Wo:=LX00?o0000o`Wf2Ol9mPT0
0ol0000;oa[U6P03o`000?lCk1?o4n`C00;o4n`C0ol0000>odNhA`03o`000?n;M8_oRgB;00OoRgB;
00?o0000oll`coo?<<l02oo?<<l00ol0003oiA[UonDJi@02onDJi@03o`000?oe2_Gom@[e00_om@[e
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000oo@;m?od2o@01ood2o@00ol0003occ3?oll`c`05oll`c`?o00003Om_
T6l4o`0000_o:=LX0ol0000?oa[U6P04o`000?lCk1?o0000o`00017oAkQ700?o0000oh]dRon;M8/0
1on;M8/00ol0003occ3?oll`c`0:oll`c`03o`000?oU6^GoiA[U00CoiA[U00?o0000ooD:mOoe2_D0
1ooe2_D3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om0_doo@;
m006oo@;m003o`000?o?<<oocc3?00;occ3?0ol00003ojm@[`03o`000?m_T6ooKi1_00[oKi1_00?o
0000obSG:?lXebP02olXebP00ol0003o8m`So`00000Aoa[U6P03o`000?m7^4OoAkQ7017oAkQ700?o
0000oh]dRon;M8/01on;M8/00ol0003occ3?oll`c`0:oll`c`03o`000?oU6^GoiA[U00GoiA[U00Co
0000ooD:mOoe2_Gom@[e1Ol00002ooP7n003o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om0_doo@;m005oo@;m0?o0000
00?occ3?o`000?l000001on_D:l00ol0003oKi1_ofn@K`08ofn@K`?o00002_lXebP2o`0000;o8m`S
00?o0000oa[U6_lJiAX03olJiAX00ol0003oAkQ7odNhA`0AodNhA`03o`000?n;M8_oRgB;00OoRgB;
00?o0000oll`coo?<<l02Oo?<<l00ol0003oiA[UonDJi@07onDJi@?o00001ooh1oP00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om0_d0_l00003onhAkP03o`000?n_D:oo[e2_00So[e2_0_l00006ofn@K`;o00000omM
XUd00ol0003o:=LXobSG:006obSG:003o`000?lSg2?o8m`S00?o8m`S00?o0000oa[U6_lJiAX03_lJ
iAX00ol0003oAkQ7odNhA`0BodNhA`03o`000?n;M8_oRgB;00GoRgB;00?o0000oll`coo?<<l02Oo?
<<l00ol0003oiA[UonDJi@08onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo^4Nh00ol0003o[e2_ojm@[`0:ojm@[`03o`000?m_T6ooKi1_00;oKi1_00?o0000
oefRGOmMXUd01?mMXUd00ol0003o:=LXobSG:004obSG:003o`000?lSg2?o8m`S00Co8m`S00?o0000
oa[U6_lJiAX03_lJiAX00ol0003oAkQ7odNhA`0BodNhA`[o00002_o?<<l00ol0003oiA[UonDJi@08
onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onhAk_o^4Nh01?o^4Nh0
0ol0003o[e2_ojm@[`0:ojm@[`04o`000?m_T6oo0000o`0000SoGJ9M00Co0000obSG:?lXebSo:=LX
0_l00007ob?L8`03o`000?lJiA[o6^DJ00ko6^DJ00?o0000odNhAom7^4L04_m7^4L00ol0003oYeRW
ojMHY`07ojMHY`03o`000?o?<<oocc3?00Kocc3?00?o0000onDJiOoU6^D02_oU6^D00ol0003on0Oh
ooP7n006ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onhAk_o^4Nh01?o^4Nh00ol0003o[e2_ojm@[`0;ojm@[`03o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obSG:?l000002OlSg2<00ol0003o6^DJoa[U6P0>oa[U6P;o0000
4_m7^4L00ol0003oYeRWojMHY`09ojMHY`;o00001_o?<<l00ol0003oiA[UonDJi@0:onDJi@03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003okQ7^onhAkP05onhAkP03o`000?n_D:oo[e2_00[o[e2_00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa[U6_lJiAX03_lJiAX00ol0003o?<<lo`00
0002o`0000ooAkQ700?o0000ojMHYonWF:L02onWF:L00ol0003occ3?oll`c`03o`0000goiA[U00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o^4NkokQ7^00GokQ7^00?o0000ojm@[on_D:l02On_D:l2
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lJiA[o6^DJ00co6^DJ00?o0000occ3??ll`c`00oll`c`3
o`0000coAkQ700?o0000ojMHYonWF:L03?nWF:L2o`0000;ohQgR00?o0000onDJiOoU6^D03?oU6^D0
0ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o[e2_ojm@[`07ojm@
[`03o`000?naC[7o000000[oGJ9M00Co0000oe:]D_mB[E;o00002_lSg2<00ol0003o6^DJoa[U6P0<
oa[U6P03o`000?ll`cco?<<l00Ko?<<l0_l00008odNhA`;o00003onWF:L00ol0003ohQgRon8MhP02
on8MhP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o^4NkokQ7^
00KokQ7^00?o0000ojm@[on_D:l01_n_D:l01Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe:]D_mB[E800_mB[E800ol0003o8m`Sob?L8`06ob?L8`Co00003?lJiAX00ol0003o?<<locc3?008
occ3?0?o00000_m7^4L3o`000003ohMhQol0003oYeRW00goYeRW00?o0000on8Mh_oR7N801?oR7N80
0ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003okQ7^onhAkP07onhA
kP03o`000?n_D:oo[e2_00?o[e2_0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe:]
D_mB[E800omB[E800ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa[U
6P;o00003_ll`c`2o`0000GoQgR700?o0000ojMHYonWF:L02_nWF:L00ol0003ohQgRon8MhP05on8M
hP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o^4NkokQ7^00Oo
kQ7^00?o0000ojm@[on_D:l00_n_D:l00ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe:]D_mB[E801OmB[E800ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6^DJ0_l000000olQgR7o0000occ3?00=occ3?003o`000?n7N8OoQgR700GoQgR700?o0000ojMHYonW
F:L02?nWF:L00ol0003ohQgRon8MhP07on8MhP03o`000?oU6^GoiA[U00[oiA[U00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o^4NkokQ7^00SokQ7^00Co0000ojm@[on_D:oo00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDZeB00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lQgR40
0ol0003o?<<locc3?00;occ3?003o`000?n7N8OoQgR700KoQgR700?o0000ojMHYonWF:L01onWF:L0
0ol0003ohQgRon8MhP08on8MhPCo00002?oU6^D00ol0003on0OhooP7n004ooP7n003o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onhA
kP03o`000?n_D:oo000000_o/Dja00?o0000oefRGOl000002_mB[E800ol0003o8m`So`00000?oagR
7@03o`000?lQgR7o8MhQ00;o8MhQ00?o0000occ3??ll`c`02oll`c`00ol0003oQgR7ohMhQ`06ohMh
Q`03o`000?nWF:OoYeRW00KoYeRW00?o0000on8Mh_oR7N802OoR7N801?l0003olPgboo8=l_ob3O87
o`0000;oiA[U00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o^4NkokQ7^00OokQ7^00?o0000ok5>
/OnaC[402onaC[400ol0003oDZeBoe:]DP0:oe:]DP03o`000?lMhQgo7N8M00go7N8M00?o0000ob7N
8OlQgR401?lQgR400ol0003o?<<locc3?009occ3?003o`000?n7N8OoQgR700SoQgR700?o0000ojMH
YonWF:L00onWF:L2o`0000cohQgR00?o0000oo8=l_ob3O802?ob3O8<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mB[E;oDZeB00WoDZeB0_l0000>oagR7@03o`000?lQgR7o8MhQ00Go
8MhQ00?o0000occ3??ll`c`02Oll`c`00ol0003oQgR7ohMhQ`09ohMhQ`03o`000?nWF:Oo000000;o
00000_oG:=L00ol0003ohQgRon8MhP08on8MhP03o`000?ob3O;olPgb00colPgb00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003okQ7^
onhAkP04onhAkP03o`000?naC[7o/Dja00_o/Dja0ol00007oe:]DP?o000000?o>l@ko`000?lMhQd0
3OlMhQd00ol0003o8MhQob7N8@06ob7N8@03o`000?ll`cco?<<l00So?<<l00?o0000ohMhQon7N8L0
2_n7N8L00ol0003oebSGomLXe`04omLXe`03o`000?oR7N;ohQgR00OohQgR00?o0000oo8=l_ob3O80
2oob3O800ol0003onPGjooX5nP08ooX5nP03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onhAk_o^4Nh00oo^4Nh>o`0000?oW6>L0_l00002oe:]DP?o0000
1Olka3/00ol0003o7N8MoagR7@0:oagR7@03o`000?lQgR7o8MhQ00Oo8MhQ00?o0000occ3??ll`c`0
2?ll`c`00ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?oG:=OoebSG00GoebSG00?o0000on8Mh_oR7N80
1_oR7N800ol0003olPgboo8=lP0;oo8=lP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onhAk_o^4Nh00_o^4Nh00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009oc_4>`03o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob7N8OlQgR402?lQgR42o`0000So?<<l00?o0000ohMhQon7N8L02On7N8L00ol0003oebSGomLX
e`07omLXe`03o`000?oR7N;ohQgR00CohQgR00?o0000oo8=l_ob3O802oob3O800ol0003onPGjooX5
nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?okQ7^
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?lka3_o>l@k00Wo>l@k00?o0000
oagR7OlMhQd01olMhQd00ol0003o8MhQob7N8@09ob7N8@04o`000?m4^dCo0000o`0000Ko?<<l00?o
0000ohMhQon7N8L02On7N8L00ol0003oebSGomLXe`08omLXe`03o`000?oR7N;ohQgR00?ohQgR00?o
0000oo8=l_ob3O802oob3O800ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooi1_T2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o>l@koc_4>`0:oc_4>`Wo00002olQgR400ol0003oA;]4odBkA002odBkA0?o00000_ll`c`0
0ol0003oQgR7ohMhQ`0:ohMhQ`03o`000?oG:=OoebSG00WoebSG00?o0000on8Mh_oR7N800_oR7N80
0ol0003olPgboo8=lP0:oo8=lP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000Gon@Ki00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?lka3_o>l@k00Wo>l@k00?o0000obKI9_lVfBH01OlVfBH00ol0003o8MhQob7N8@09ob7N
8@03o`000?m4^dCoA;]400GoA;]40ol00009ohMhQ`?o00003OoG:=L01Ol0003ohQgRon8Mh_oR7N;o
000000colPgb00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000Oon@Ki00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?lka3_o>l@k00So>l@k00?o0000obKI9_lVfBH01olVfBH00ol0003o8MhQob7N8@07
ob7N8@03o`000?m4^dCoA;]400SoA;]40ol00002ohMhQ`Go00000_o0?l000ol0003oebSGomLXe`0<
omLXe`03o`000?oR7N;o000000colPgb00?o0000ooX5n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000Son@Ki00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o>l@koc_4>`08oc_4>`03o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob7N8OlQgR401olQgR400ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;
00;o00002?o0?l000ol0003oebSGomLXe`0<omLXe`Co00002_ob3O800ol0003onPGjooX5nP0:ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooT6n@03o`000?o^4NkokQ7^
00;okQ7^00?o0000olPgb?o8=lP00_o8=lP4o`0000WoW6>L00?o0000oc_4>olka3/02?lka3/00ol0
003o9]TVobKI9P08obKI9P03o`000?lQgR7o8MhQ00Go8MhQ00?o0000odBkA?m4^d@02?m4^d@01Ol0
003oRgB;oh]dRon;M8_o000000[o`3o00ol0000;omLXe`04o`000?og2?Oom`SgooL8m`Co00001Oob
3O800ol0003onPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o^4NkokQ7^00?okQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oW6>LoiaSW007
oiaSW003o`000?lka3_o>l@k00Ko>l@k0_l0000;obKI9P03o`000?lQgR7o8MhQ00Go8MhQ00?o0000
odBkA?m4^d@02?m4^d@00ol0003oRgB;oh]dR`02oh]dR`03o`000?o0?l3o`3o000Oo`3o000?o0000
onXEj_oZ5NX01?l00006omLXe`03o`000?og2?Oom`Sg00Kom`Sg0ol00002oo8=lP03o`000?oj1O[o
nPGj00_onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ob3O8olPgb005olPgb003o`000?nLHicoW6>L00OoW6>L00?o0000oc_4
>olka3/00_lka3/3o`000003oeJYE_l0003o9]TV00[o9]TV00?o0000ob7N8OlQgR401OlQgR400ol0
003oA;]4odBkA007odBkA003o`000?n;M8_oRgB;00?oRgB;00?o0000ol0o`?o0?l001oo0?l000ol0
003ojQGZonXEjP04onXEjP?o00000_oG:=L00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003okQ7^onhAkP04onhAkP03
o`000?o8=lSob3O800Kob3O80_l00007oiaSW003o`000?lka3_o000000;o00001OmFZEH00ol0003o
9]TVobKI9P08obKI9P?o00001?lQgR400ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;00Co
RgB;00?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP07onXEjP;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oc3?<ol`cc003o`0000CoW6>L
0_l00008oeJYEP03o`000?lVfBKo9]TV00Oo9]TV00Co0000odbcC?m</dcoC;=<0ol000000olQgR7o
0000odBkA009odBkA003o`000?n;M8_oRgB;00CoRgB;00?o0000ol0o`?o0?l001Oo0?l000ol0003o
jQGZonXEjP09onXEjP03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP06onhAkP03o`00
0?o8=lSob3O800?ob3O800?o0000ol`cc?o<<l`01?o<<l`2o`000003oiaSW?l0003oEZUF00[oEZUF
00?o0000obKI9_lVfBH01OlVfBH00ol0003oC;=<odbcC005odbcC003o`000?m4^dCoA;]400OoA;]4
0ol00007oh]dR`03o`000?o0?l3o`3o000Co`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009onhAkP05o`000?o8=lSob3O8olPgb?l000002Oo<<l`00ol0003oEZUF
oeJYEP0;oeJYEP03o`000?lVfBKo9]TV00?o9]TV00?o0000odbcC?m</d`01_m</d`00ol0003oA;]4
odBkA006odBkA005o`000?n5NXGoQGZ5ohEjQOl000001on;M8/00ol0003o`3o0ol0o`003ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003ob3O8olPgb?l00009ol`cc0;o00003OmFZEH00ol0003o9]TVobKI9P02obKI9P03
o`000?m</dcoC;=<00SoC;=<00?o0000odBkA?m4^d@00om4^d@2o`0000GoQGZ500?o0000oh]dRon;
M8/01?n;M8/00ol0003o`3o0ol0o`003ol0o`003o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ob3O8o`000009ol`cc004o`000?n[E:_oZeB[o`0000go
EZUF00Co0000obKI9_lVfBKo00003?m</d`01Ol0003oA;]4odBkA?m4^dCo000000SoQGZ50_l00005
oh]dR`03o`000?o0?l3o`3o000;o`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oc3?<ol`cc007ol`cc003o`000?n[E:_oZeB[
00;oZeB[00?o0000oeJYE_mFZEH02_mFZEH00ol0003o9]TVo`00000>odbcC003o`000?m4^dCo0000
00_oQGZ500?o0000oh]dRon;M8/00_n;M8/01Ol0003o`3o0ol0o`?o0?l3o000000cojQGZ00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[
00?oZeB[00?o0000oeJYE_mFZEH02omFZEH00ol0003oC;=<odbcC00>odbcC003o`000?n5NXGoQGZ5
00_oQGZ50_l00003oh]dR`04o`000?o0?l3o`3o0o`0000[ojQGZ0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[00GoZeB[00?o0000oeJY
E_mFZEH01omFZEH3o`00017oC;=<00?o0000ohEjQOn5NXD03On5NXD01Ol0003oRgB;oh]dRol0003o
`3o000Co00000ooZ5NX5o`0000;onPGj00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?mFZEKoEZUF
00CoEZUF0ol00002of2OH003o`000?m</dcoC;=<00ooC;=<0_l0000?ohEjQ@04o`000?n;M8_o0000
o`0000CogR7N0ol00008ooX5nP03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000Ooc3?<00?o0000oj]D
Zon[E:/02?n[E:/00ol0003oEZUFoeJYEP03o`0000KoH9mP00?o0000odbcC?m</d`03Om</d`01?l0
003oSG:=ohebSOl0000?ohEjQ@03o`000?oN8MkogR7N00GogR7N00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o<<lcoc3?<00?oc3?<00?o0000oj]DZon[E:/02_n[E:/2o`0000[oH9mP00?o0000odbc
C?m</d`02om</d`00ol0003oSG:=ohebS@02ohebS@03o`000?n5NXGoQGZ500_oQGZ50_l00007omhQ
gP03o`000?oj1O[onPGj00WonPGj00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o<<lcoc3?<ol`c
c?l000003On[E:/00ol0003oH9mPof2OH00:of2OH003o`000?m</dcoC;=<00WoC;=<00?o0000oheb
SOn=LXd01?n=LXd00ol0003oQGZ5ohEjQ@08ohEjQ@;o000000?o/Djao`000?oN8Mh01ooN8Mh00ol0
003onPGjooX5nP09ooX5nP04o`000?og2?Oo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003oc3?<o`00000=oj]DZ`03o`000?mPWf3oH9mP
00_oH9mP00?o0000odbcC?m</d`02?m</d`00ol0003oSG:=ohebS@06ohebS@03o`000?n5NXGoQGZ5
00GoQGZ50_l00003ok5>/@03o`000?oN8MkogR7N00KogR7N00?o0000ooX5n_oj1OX02_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000oj]DZon[
E:/03?n[E:/00ol0003oH9mPof2OH00<of2OH003o`000?m</dcoC;=<00KoC;=<00?o0000ohebSOn=
LXd02?n=LXd00ol0003oQGZ5ohEjQ@02ohEjQ@;o00001_naC[400ol0003ogR7NomhQgP05omhQgP03
o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000coZeB[00?o0000of2OH?mPWf003OmPWf000ol0003oC;=<
odbcC004odbcC003o`000?n=LXgoSG:=00[oSG:=00Co0000ohEjQOl0003o00002?naC[400ol0003o
gR7NomhQgP06omhQgP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oB;M;o000000;o00002?n[E:/00ol0003oH9mP
of2OH00?of2OH0Ko00003_n=LXd00ol0003o/Djaok5>/@08ok5>/@03o`000?oN8MkogR7N00KogR7N
00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oB;M;odRgB00?odRgB0ol00005oj]DZ`;o00004?mPWf001_l0003oM8]d
ogB;M?l0003oJYEZo`0000koSG:=00?o0000ok5>/OnaC[402OnaC[400ol0003ogR7NomhQgP05omhQ
gP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oB;M;odRgB00KodRgB0ol000001?n[E:_o0000oi1_T?n@Ki03o`00
00coH9mP00Go0000ogB;M?mdRgCoM8]do`000002ofZEJP03o`000?n=LXgoSG:=00_oSG:=00?o0000
ok5>/OnaC[402OnaC[400ol0003ogR7NomhQgP06omhQgP03o`000?oj1O[onPGj00SonPGj0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oB;M800ol0003oT6n@oi1_T004oi1_
T0?o00002?mPWf000ol0003oM8]dogB;M002ogB;M005o`000?mZUF[oJYEZofZEJ_l000003?n=LXd0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oN8MkogR7N00GogR7N3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om8]
d_oB;M802_oB;M800ol0003oT6n@oi1_T007oi1_T0;o00001OmPWf000ol0003oM8]dogB;M003ogB;
M003o`000?mZUF[oJYEZ00;oJYEZ00?o0000ohebSOn=LXd02On=LXd00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oN8MkogR7N00?ogR7N00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om8]d_oB;M802ooB;M800ol0003oT6n@oi1_T009oi1_T0?o000000?oH9mPo`000?md
Rg@01OmdRg@00ol0003oJYEZofZEJP03ofZEJP03o`000?n=LXgoSG:=00SoSG:=3_l00003omhQgP;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om@[eo`00000;oo0?l003o`000?oB;M;odRgB00[odRgB
0_l0000>oi1_T003o`000?mdRgCoM8]d00GoM8]d00?o0000ofZEJ_mZUFX00omZUFX00ol0003oSG:=
ohebS@08ohebS@03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omhQg_l000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooD:mOoe2_Go00002_o`3o000ol0003odRgBom8]dP09om8]dP03o`000?no@;oo000000koT6n@
00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJYEZofZEJP04ofZEJP03o`000?n=LXgoSG:=00KoSG:=
00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D00_oe
2_D00ol0003ol0o`oo0?l006oo0?l003o`000?oB;M;odRgB00SodRgB0_l00003okm0_`03o`000?n@
Ki3oT6n@00_oT6n@00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJYEZofZEJP05ofZEJP03o`000?n=
LXgoSG:=00GoSG:=00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooD:mOoe2_D00ooe2_D00ol0003ol0o`oo0?l005oo0?l003o`000?oB;M;odRgB00OodRgB00?o0000
okm0_ono@;l00ono@;l00ol0003oT6n@oi1_T00:oi1_T003o`000?mdRgCoM8]d00KoM8]d00?o0000
ofZEJ_mZUFX01_mZUFX00ol0003oSG:=ohebS@04ohebS@03o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01Ooe2_D00ol0
003ol0o`oo0?l004oo0?l003o`000?oB;M;odRgB00GodRgB0_l00006okm0_`03o`000?n@Ki3oT6n@
00WoT6n@0_l00008ogB;M003o`000?mZUF[oJYEZ00KoJYEZ1Ol000000on=LXgo0000on4Nh@0?on4N
h@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00;o
oP7n1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003o
l0o`oo0?l004o`0000KodRgB00?o0000okm0_ono@;l01ono@;l00ol0003oT6n@oi1_T005oi1_T0?o
000000?oT6n@o`000?mdRg@01omdRg@00ol0003oJYEZofZEJP05ofZEJP03o`000?n/Djco[5>/00?o
[5>/0_l0000?on4Nh@;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ooh1o_on0Oh0
1oon0Oh3o`0000Woo0?l00?o0000ooD:mOoe2_D01ooe2_D2o`0000Coj1OX00Co0000om8]d_oB;M;o
dRgB0_l0000:okm0_`03o`000?n@Ki3oT6n@00;oT6n@0ol00005oi1_T003o`000?mdRgCoM8]d00Go
M8]d00?o0000ofZEJ_mZUFX01?mZUFX00ol0003o[5>/ojaC[006ojaC[003o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?on0OkooP7n00WooP7n00?o0000oo`3o?ol0o`01_ol0o`00ol0003om@[eooD:m@08ooD:m@03o`00
0?oX5nSoj1OX00Coj1OX00?o0000om8]d_l000003?no@;l00ol0003oT6n@o`000002o`0000WoT6n@
00?o0000ogB;M?mdRg@01?mdRg@00ol0003oJYEZofZEJP03ofZEJP03o`000?n/Djco[5>/00So[5>/
1_l00004on4Nh@;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D01ooe
2_D00ol0003oj1OXonPGj006onPGj003o`000?no@;oo_d2o00co_d2o00?o0000oi1_T?n@Ki002_n@
Ki000ol0003oM8]dogB;M004ogB;M004o`000?mZUF[oJYEZofZEJP;o00002on/Dj`00ol0003oiaSW
onLHi`03onLHi`Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?on
0OkooP7n00_ooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003om@[eooD:m@07ooD:m@03o`000?oX
5nSoj1OX00Ooj1OX00?o0000okm0_ono@;l03?no@;l00ol0003oT6n@oi1_T00;oi1_T003o`000?md
RgCoM8]d00?oM8]d00Co0000ofZEJ_mZUF[o00003On/Dj`00ol0003oiaSWonLHi`06onLHi`03o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00;oo0?l00?o0000ooD:mOoe2_D0
1_oe2_D00ol0003oj1OXonPGj009onPGj003o`000?no@;oo_d2o00Wo_d2o0_l0000>oi1_T0?o0000
0omdRg@00ol0003oJYEZo`00000=ojaC[003o`000?oW6>OoiaSW00OoiaSW00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ooh1o_on0Oh03Oon0Oh6o`0000Oom@[e00?o
0000onPGj?oX5nP02_oX5nP00ol0003o_d2ookm0_`06okm0_`;o000000?o`3o0o`000?n@Ki002on@
Ki02o`0000?oWF:M1Ol0000>ojaC[003o`000?oW6>OoiaSW00OoiaSW00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`03oo/4n`Co00000_oe2_D00ol0003oj1OXonPGj00;
onPGj003o`000?no@;oo_d2o00?o_d2o0ol00004ol0o`003o`000?n@Ki3oT6n@00OoT6n@0_l00008
oieRW@03o`000?n/Djco[5>/00go[5>/00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onPGj003o`000?no@;oo_d2o00;o00002?o0?l000ol0
003oT6n@oi1_T005oi1_T003o`000?nMHYgoWF:M00SoWF:M00?o0000ojaC[?n/Dj`03On/Dj`00ol0
003oiaSWonLHi`08onLHi`03o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oX5nSoj1OX00koj1OX0_l0000;ol0o`003o`000?n@Ki3oT6n@00;oT6n@0_l0000;oieR
W@03o`000?n/Djco[5>/00go[5>/00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oX5nSoj1OX00goj1OX0_l0000<ol0o`004o`000?n@Ki3o0000
o`0000goWF:M00?o0000ojaC[?n/Dj`03?n/Dj`00ol0003oiaSWonLHi`09onLHi`03o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ooh1
o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oX5nSoj1OX00coj1OX00Co0000on<L
hooS7>?o00003?o0?l000ol0003oWF:MoieRW@0>oieRW@03o`000?n/Djco[5>/00So[5>/1?l0000;
onLHi`03o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oX5nSoj1OX
00_oj1OX00?o0000on<LhooS7><00_oS7><00ol0003o`3o0ol0o`009ol0o`003o`000?nMHYgoWF:M
00koWF:M00Co0000ojaC[?n/Djco[5>/1ol00003olhacP03o`000?oW6>OoiaSW00WoiaSW00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00con`Ck00?o0000onPGj?oX5nP02_oX5nP00ol0
003ohacSon<Lh`03on<Lh`03o`000?o0?l3o`3o000So`3o000?o0000oieRWOnMHYd03_nMHYd4o`00
00_ocS7>00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook
1?/03?ok1?/7o`0000Goj1OX00?o0000on<LhooS7><01OoS7><00ol0003o`3o0ol0o`007ol0o`003
o`000?nMHYgoWF:M00koWF:M00?o0000olhac_o><Lh03Oo><Lh00ol0003oiaSWonLHi`08onLHi`03
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ooh1o_on0Oh02_on0Oh00ol0003on`Ckoo/4n`0=oo/4n`03o`000?od2oCom0_d00Com0_d
1Ol00009on<Lh`03o`000?o0?l3o`3o000Ko`3o000?o0000oieRWOnMHYd03_nMHYd00ol0003ocS7>
olhacP0=olhacP03o`000?oW6>OoiaSW00SoiaSW00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?on0OkooP7n00SooP7n0ol0000=oo/4n`03o`000?od2oCom0_d00Wom0_d
0_l00009on<Lh`03o`000?o0?l3o`3o000Ko`3o000?o0000oieRWOnMHYd03?nMHYd00ol0003ocS7>
olhacP0?olhacPKo00001?oW6>L4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003ooP7nooh1oP06ooh1oP04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m0_doo@;m009oo@;m003o`000?o/4nco000000;o00001ooS7><00ol0003o`3o0ol0o`005ol0o`003
o`000?nMHYgoWF:M00SoWF:M1Ol0000AolhacP03o`000?o^4NkokQ7^00?okQ7^1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000oo@;m?od2o@02_od2o@00ol0003ok1?/on`Ck002on`Ck0?o00001OoS7><00ol0003o`3o0
ol0o`004ol0o`004o`000?nMHYgoWF:MoieRW@Oo00001?o><Lh00ol0003ocS7>olhacP0>olhacP03
o`000?o^4NkokQ7^00OokQ7^00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om0_d
oo@;m00;oo@;m003o`000?o/4ncok1?/00Gok1?/0ol00003on<Lh`04o`000?o0?l3o`3o0ol0o`0Ko
00003?o><Lh00ol0003ocS7>olhacP0=olhacP03o`000?o^4NkokQ7^00OokQ7^00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?od2o@0
3?od2o@00ol0003ok1?/on`Ck008on`Ck0?o000000CohacSo`000?l0003o00000_oX5nP00ol0003o
cS7>olhacP0=olhacP03o`000?o><LkocS7>00cocS7>00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00;on`Ck003o`000?oX5nSoj1OX00?o
j1OX00?o0000olhac_o><Lh03?o><Lh00ol0003of2OHo`00000=olhacP03o`000?o^4NkokQ7^00So
kQ7^00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00:on`Ck003o`00
0?oX5nSoj1OX00Goj1OX00?o0000olhac_o><Lh02_o><Lh01?l0003of2OHomPWf?oH9mP2o`0000[o
cS7>00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo@;m?od2o@0
3?od2o@00ol0003ok1?/on`Ck009on`Ck003o`000?oX5nSoj1OX00Koj1OX00?o0000olhac_o><Lh0
2Oo><Lh00ol0003of2OHomPWf002omPWf003o`000?oZ5N[o000000;o00001oo><Lh00ol0003okQ7^
onhAkP09onhAkP03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m00;oo@;m003o`000?o/
4ncok1?/00Sok1?/00?o0000onPGj?oX5nP01ooX5nP00ol0003ocS7>olhacP08olhacP03o`000?oH
9mSof2OH00?of2OH00?o0000onXEj_oZ5NX00_oZ5NX2o`0000CocS7>00?o0000onhAk_o^4Nh02_o^
4Nh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo@;m0Ko00001?o/4n`00ol0003oj1OXonPGj008
onPGj003o`000?o><LkocS7>00OocS7>00?o0000omPWf?oH9mP00ooH9mP00ol0003ojQGZonXEjP05
onXEjP?o000000?ocS7>o`000?o^4Nh02oo^4Nh00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo@;m003o`000?of2OKomPWf00ComPWf1?l0000<onPGj003o`000?o><LkocS7>
00GocS7>00?o0000omPWf?oH9mP01?oH9mP00ol0003ojQGZonXEjP08onXEjP03o`000?o^4NkokQ7^
00_okQ7^00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om0_d00?o0000ooH9m_of
2OH02?of2OH00ol0003oj1OXonPGj00:onPGj003o`000?o><LkocS7>00CocS7>00?o0000omPWf?oH
9mP01OoH9mP00ol0003ojQGZonXEjP08onXEjP03o`000?o^4NkokQ7^00WokQ7^1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooH9mP03o`000?oX5nSoj1OX00Woj1OX
00?o0000olhac_o><Lh00oo><Lh00ol0003of2OHomPWf005omPWf003o`000?oZ5N[ojQGZ00[ojQGZ
00?o0000onhAk_o^4Nh01?o^4Nh4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oX5nSoj1OX00Woj1OX00?o0000olhac_o><Lh00_o>
<Lh00ol0003of2OHomPWf006omPWf003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000onhAk_o^4Nh01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?of2OKomPWf00[omPWf00?o0000onPGj?oX5nP02OoX5nP01Ol0003ocS7>olha
c_o><Lko000000Wof2OH00?o0000onXEj_oZ5NX02ooZ5NX2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003omPWfooH9mP0;ooH9mP03o`000?oX5nSoj1OX00Woj1OX00?o
0000olhac_l000002OoH9mP00ol0003ojQGZonXEjP0<onXEjP03o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oX5nSo
j1OX00Soj1OX1Ol00008omPWf003o`000?oZ5N[ojQGZ00cojQGZ00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooH9m_of2OH02_of2OH00ol0003oj1OXonPGj007onPG
j003o`000?o/4ncok1?/00?ok1?/0ol00005omPWf003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
mPWf00?o0000onPGj?oX5nP01OoX5nP00ol0003ok1?/on`Ck007on`Ck0?o000000?of2OHo`000?oZ
5NX03OoZ5NX00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_of2OH00ol0003oj1OXonPGj003onPGj0;o0000
3Oo/4n`2o`0000gojQGZ0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?of2OKomPWf00OomPWf00Co0000onPGj?oX5nSoj1OX
0_l00002ooP7n003o`000?o/4ncok1?/00cok1?/3Ol00003ooT6n@03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooH9mP03o`000?oX5nSo000000Gon0Oh
00?o0000on`Ck?o/4n`02oo/4n`00ol0003ol@kaoo4>l@09oo4>l@03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?omPWf0ol0
0007ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000oo4>lOoa3_402Ooa3_400ol0003on@KiooT6
n@04ooT6n@;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k008on`Ck003o`000?oa3_7ol@ka00[ol@ka00?o0000ooT6nOoi1_T01_oi1_T00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o/4ncok1?/00Ook1?/00?o
0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@07ooT6n@;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o/4ncok1?/00Kok1?/00?o0000oo4>lOoa3_402_oa3_40
0ol0003on@KiooT6n@09ooT6n@05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000on`Ck?o/4n`01Oo/4n`00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck004on`Ck003o`000?oa3_7ol@ka00Wol@ka00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o/4ncok1?/
00;ok1?/00?o0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000on`Ck?o/
4ncok1?/o`00000<oo4>l@03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003ok1?/o`000004o`0000Wol@ka00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003on`Ckoo/4n`03oo/4n`Oo00000_oa3_400ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003oo@;m
o`000002o`0000Son0Oh00?o0000oo/4nook1?/02_ok1?/5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003oo@;mood2o@03ood2o@?o00001?oh1oP00ol0003on`Ckoo/4
n`0=oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?om0_goo@;m00Koo@;m0ol000000ooh1oSo0000oo/4n`0>oo/4n`03o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo/4
nook1?/03ook1?/00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?om0_goo@;m00[o
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool02Ol00?l6oooo00Wo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l3oooo00Oo003o0oooo`03o`00o`;oool01_l0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`?oool03?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01ol00?l2
oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo
0?l00?l01ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`000ol0
0?ooool0oooo000;o`00o`?oool03?l00?l00oooo`3o003oo`00o`02o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000<o`00o`;oool03?l00?l2oooo00?o003o00?oool0o`00ool00?l01?l00?l00oooo`3o
003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o
0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Go003o1?ooo`02o`00o`;oool0
3Ol00?l2oooo00_o003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo
001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00ool00?l2oooo00;o003o0_ooo`07o`00o`;oool0
1?l00?l2oooo00Co003o0oooo`04o`00o`;oool03Ol00?l2oooo00_o003o0_ooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`08o`00o`Goool000?o003ooooo0?ooo`002Ol00?l3oooo00;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Oo003o0_ooo`04o`00o`?oool02?l00?l3oooo00?o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`04o`00o`03oooo0?l0
0?ooool000;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`001_l00?l3oooo00Go003o0_ooo`06o`00o`Goool00ol0
0?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05
o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o
003o00;oool01_l00?l2oooo00Ko003o0_ooo`03o`00o`Koool01Ol00?l2oooo00Ko003o0_ooo`06
o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o
01Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo00?o003o1?ooo`07o`00o`;oool01_l00?l2oooo
00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool0
0?l05ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool01?l00?l00oooo`3o003oo`00o`07o`00o`;o
ool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o
0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`06o`00o`03oooo0?l00?oo003o00?o003o
00?oool0o`00ool00?l02?l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l0
0?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l00?oo003o01Ko003o0_ooo`000olb</co003oo`00
o`04o`00o`03oooo0?l00?oo003o00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00So003o0_oo
o`04o`00o`;oool01_l00?l00olb</coool0oooo001Wo`00o`7ooooo001Wo`00o`?oool01Ol00?l3
oooo00Oo003o00?oool0o`00ool00?l05_l00?l5oooo00Co003o0_ooo`03o`00o`;oool01ol00?l6
oooo00Go003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`000ol0
0?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00o`Coool02?l00?l7oooo00Go003o1?ooo`1bo`00
o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(960) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.989 .011 .989 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.977 .023 .977 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.98 .02 .98 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.956 .044 .956 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.986 .014 .986 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.994 .006 .994 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.907 .093 .907 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.97 .03 .97 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.984 .016 .984 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.992 .008 .992 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.958 .042 .958 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.982 .018 .982 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.93 .07 .93 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.981 .019 .981 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.972 .028 .972 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.922 .078 .922 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.96 .04 .96 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.934 .066 .934 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.773 .227 .773 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.811 .189 .811 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.938 .062 .938 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.795 .205 .795 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.757 .243 .757 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.686 .314 .686 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.93 .07 .93 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.957 .043 .957 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.949 .051 .949 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.91 .09 .91 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.995 .005 .995 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.979 .021 .979 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.81 .19 .81 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.694 .306 .694 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.877 .123 .877 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.443 .557 .443 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.437 .563 .437 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.56 .44 .56 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.8 .2 .8 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.824 .176 .824 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.507 .493 .507 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.456 .544 .456 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.964 .036 .964 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.611 .389 .611 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.751 .249 .751 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.925 .075 .925 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.937 .063 .937 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.67 .33 .67 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.889 .111 .889 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.871 .129 .871 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.754 .246 .754 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.17 .83 .17 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.982 .018 .982 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.279 .721 .279 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.204 .796 .204 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.91 .09 .91 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.985 .015 .985 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.545 .455 .545 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.158 .842 .158 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.235 .765 .235 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.839 .161 .839 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.339 .661 .339 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.566 .434 .566 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.251 .749 .251 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.061 .939 .061 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.379 .621 .379 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.566 .434 .566 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.969 .031 .969 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.617 .383 .617 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.699 .301 .699 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.068 .932 .068 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.013 .987 .013 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.037 .963 .037 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.115 .885 .115 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.151 .849 .151 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.806 .194 .806 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.926 .074 .926 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.952 .048 .952 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.518 .482 .518 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.106 .894 .106 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.846 .154 .846 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.241 .759 .241 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.456 .544 .456 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.146 .854 .146 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.298 .702 .298 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.883 .117 .883 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.418 .582 .418 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.132 .868 .132 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.985 .015 .985 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.917 .083 .917 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.944 .056 .944 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.322 .678 .322 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.979 .021 .979 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.044 .956 .044 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.004 .996 .004 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.676 .324 .676 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.653 .347 .653 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.149 .851 .149 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.268 .732 .268 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.553 .447 .553 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.808 .192 .808 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.15 .85 .15 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.99 .01 .99 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.076 .924 .076 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.238 .762 .238 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.34 .66 .34 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.522 .478 .522 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.496 .504 .496 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.353 .647 .353 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.283 .717 .283 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.934 .066 .934 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.911 .089 .911 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.906 .094 .906 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.234 .766 .234 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.544 .456 .544 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.693 .307 .693 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.88 .12 .88 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.978 .022 .978 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.532 .468 .532 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.752 .248 .752 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.439 .561 .439 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.971 .029 .971 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.952 .048 .952 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.872 .128 .872 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.982 .018 .982 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.546 .454 .546 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.657 .343 .657 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.603 .397 .603 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.916 .084 .916 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.735 .265 .735 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.844 .156 .844 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.69 .31 .69 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.981 .019 .981 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.812 .188 .812 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.972 .028 .972 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.773 .227 .773 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.789 .211 .789 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.891 .109 .891 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.886 .114 .886 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.967 .033 .967 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.845 .155 .845 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.967 .033 .967 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.947 .053 .947 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.936 .064 .936 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.897 .103 .897 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.905 .095 .905 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.869 .131 .869 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.95 .05 .95 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.972 .028 .972 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.979 .021 .979 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.989 .011 .989 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.975 .025 .975 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.918 .082 .918 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.97 .03 .97 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.979 .021 .979 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.988 .012 .988 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.977 .023 .977 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.982 .018 .982 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.988 .012 .988 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooP7n0;o00003?om0_d2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003ol`cc
oo<<looc3?<5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oh1oSon0Oh00Gon0Oh0_l00008ood2o@;o00000_oh1oP00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003ol`ccoo<<l`07oo<<l`Ko00000_oo0?l4o`0000goo@;m00?o0000ooP7n?oh1oP0
1ooh1oP2o`0000Goo@;m00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003ol`ccoo<<l`0<oo<<l`?o00001?oj1OX3o`0000Woo@;m00?o
0000ooP7n?oh1oP02_oh1oP2o`000003ood2oOl0003o000000Oon0Oh00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oh1oP03ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo`3o00>oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on0OhooP7n00?ooP7n003o`000?oh1oSon0Oh00[on0Oh2ol0000;ood2o@Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ol0ocoo0?l00coo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0
003onPGjooX5nP0=ooX5nP;o00004?oh1oP00ol0003on0OhooP7n00:ooP7n003o`000?og2?Oom`Sg
00Oom`Sg00?o0000ood2oOom0_d00_om0_d7o`0000Con@Ki00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj
00gonPGj00Co0000onTFjOoY5^Wo00003ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oo
m`Sg00Wom`Sg1?l0000;ooT6n@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000onl@kol0003o00002Ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[o
nPGj00gonPGj00Go0000onTFjOoY5^WojAKYo`00000=ooP7n003o`000?oh1oSon0Oh00[on0Oh00?o
0000ooL8moog2?L02Oog2?L00ol0003on@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o_4>ooka3_00;oka3_0_l00007oo`3o003o`000?oc3??o
l`cc00col`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@03onTFj@03o`000?oh1oSo
n0Oh00[on0Oh00?o0000ooP7n?oh1oP02_oh1oP00ol0003om`SgooL8m`09ooL8m`03o`000?oi1_Wo
n@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onl@
koo_4>l01Oo_4>l00ol0003oo0?loo`3o003oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@04onTFj@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooP7
n?oh1oP02Ooh1oP00ol0003om`SgooL8m`0:ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000onl@koo_4>l01_o_4>l2o`0000?o
o0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0<ooX5nP03o`000?oY5^WojAKY00Ko
jAKY00?o0000ooP7n?oh1oP02?oh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oom`Sg00[o
m`Sg00?o0000ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o_4>ooka3_00Woka3_0_l000000ool0oco0000oo<<l`0<oo<<l`?o00003_oj1OX00ol0003ojAKY
onTFj@07onTFj@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooP7n?oh1oP02Ooh1oP00ol0003om`Sg
ooL8m`0;ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o_4>ooka3_00_oka3_00?o0000oo<<looc3?<02_oc3?<2o`0000?ohQgR00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ojAKYonTFj@09onTFj@03o`000?oh1oSon0Oh00Kon0Oh00?o
0000ooP7n?oh1oP02?oh1oP00ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003oka3_onl@k`0<onl@k`03o`000?oc3??ol`cc00Sol`cc0_l00006on8MhP;o00002_oj1OX0
0ol0003ojAKYonTFj@0:onTFj@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_4>l03_o_4>l00ol0003ol`ccoo<<l`04
oo<<l`?o00002_oR7N800ol0003onPGjooX5nP07ooX5nP03o`000?oY5^WojAKY00_ojAKY00?o0000
ooP7n?oh1oP00ooh1oP00ol0003on0OhooP7n009ooP7n003o`000?og2?Oom`Sg00com`Sg00?o0000
ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000onl@koo_4>l03oo_4>l01?l0
003ol`ccoo<<looc3?<2o`0000kohQgR0_l00006ooX5nP03o`000?oY5^WojAKY00gojAKY00?o0000
ooP7n?oh1oP00_oh1oP00ol0003on0OhooP7n008ooP7n003o`000?og2?Oom`Sg00com`Sg0ol0000=
ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003oka3_onl@k`0@onl@k`Co00004_oR7N800ol0
003onPGjooX5nP03ooX5nP03o`000?oY5^WojAKY00kojAKY00Go0000ooP7n?oh1oSon0Oho`000005
ooP7n0Oo00003?og2?L01Ol0003ol`ccoo<<looc3??o000000con@Ki00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003oka3_onl@k`0=
onl@k`?o000000CogR7No`000?l0003o00004ooR7N82o`0000;onPGj00?o0000onTFjOoY5^T04?oY
5^T00ol0003on0Oho`000006o`0000Ooi1_T00?o0000ooL8moog2?L02?og2?L00ol0003ol`ccoo<<
l`03oo<<l`;o00002?oi1_T3o`0000Koo@;m1?l00002oo`3o003o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oh1oP3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003oka3_onl@
k`0;onl@k`?o00000ooN8Mh01Ol0003oeRWFo`000?nbCK;o000001CohQgR00?o0000ooX5n_l00000
4ooY5^T00ol0003oi1_Ton@Ki00=on@Ki003o`000?og2?Oom`Sg00Gom`Sg0_l00008oo<<l`03o`00
0?oi1_Won@Ki00Go00000ooh1oP00ol0003oo@;mood2o@03o`0000Ooo0?l00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con0Oh0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000onl@koo_4>l02Oo_4>l3o`0000GogR7N00Co0000omHYe_oF:MKo00000_nbCK800ol0003o
hQgRon8MhP0Bon8MhP03o`000?oY5^WojAKY01;ojAKY00?o0000on@Ki?oT6n@03_oT6n@00ol0003o
m`SgooL8m`03ooL8m`03o`000?oc3??ol`cc00Wol`cc0_l00009ooP7n0;o00002_ol0o`00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooP7n0;o00001oom0_d5o`0000;o
nPGj00?o0000onl@koo_4>l01_o_4>l3o`0000SogR7N00Co0000omHYe_oF:MKo00000onbCK800ol0
003ohQgRon8MhP0Aon8MhP03o`000?oY5^WojAKY017ojAKY00?o0000on@Ki?oT6n@04?oT6n@01Ol0
003om`SgooL8moog2?Oo000000col`cc00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo0?loo`3o00:
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooP7n?oh1oP01ooh1oP3o`00
0004ood2oOl0003o0000o`0000GolPgb0_l00006onl@k`?o00002_oN8Mh01Ol0003oeRWFomHYe_oF
:MKo000000Co/Tfb00?o0000on8Mh_oR7N804?oR7N800ol0003ojAKYonTFj@0AonTFj@03o`000?oT
6nCoi1_T017oi1_T00?o0000ooL8mol000003Ooc3?<00ol0003on0OhooP7n008ooP7n003o`000?ol
0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP02_oh1oP00ol0003olPgboo8=lP08oo8=lP03o`000?o_4>ooka3_00?o00003OoN8Mh0
1Ol0003oeRWFomHYe_oF:MKo000000Go/Tfb00?o0000on8Mh_oR7N803ooR7N800ol0003ojAKYonTF
j@0AonTFj@03o`000?oT6nCoi1_T01;oi1_T00?o0000oo<<looc3?<03?oc3?<00ol0003on0OhooP7
n008ooP7n003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?ob3O;olPgb00WolPgb0_l0000?omhQgP03o`000?oF:MKo
eRWF00;oeRWF00?o0000ok9=/_nbCK801?nbCK800ol0003ohQgRon8MhP0=on8MhP?o00004OoY5^T0
0ol0003oi1_Ton@Ki00Con@Ki003o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?ob3O;olPgb00WolPgb00?o0000omhQg_oN8Mh03OoN8Mh0
0ol0003oeRWFomHYeP03omHYeP03o`000?nbCK;o/Tfb00Go/Tfb00?o0000on8Mh_oR7N802_oR7N82
o`0000?oYeRW00?o0000onTFjOoY5^T03_oY5^T00ol0003oi1_Ton@Ki00Con@Ki003o`000?oc3??o
l`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on0Oh00?o0000oo8=
l_ob3O802oob3O800ol0003ogR7NomhQgP0<omhQgP03o`000?oF:MKoeRWF00?oeRWF00?o0000ok9=
/_nbCK801_nbCK800ol0003ohQgRon8MhP07on8MhP;o00001_nWF:L2o`0000kojAKY00?o0000on@K
i?oT6n@04ooT6n@00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3
o?ol0o`03?ol0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on0Oh00?o0000oo8=l_ob3O802oob3O800ol0003ogR7NomhQgP0;omhQ
gP03o`000?oF:MKoeRWF00CoeRWF00?o0000ok9=/_nbCK801onbCK800ol0003ohQgRon8MhP05on8M
hP03o`000?nWF:OoYeRW00SoYeRW00?o0000onTFjOoY5^T02_oY5^T00ol0003oi1_Ton@Ki00Don@K
i003o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00<oo`3
o003o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on0Oh00?o0000oo8=l_ob3O802oob3O800ol0003ogR7NomhQgP0;omhQgP03o`000?oF:MKoeRWF
00CoeRWF00?o0000ok9=/_nbCK802?nbCK800ol0003ohQgRon8MhP02on8MhP;o00003?nWF:L2o`00
00[ojAKY00?o0000on@Ki?oT6n@05?oT6n@00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh
00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003olPgboo8=lP0<oo8=lP03
o`000?oN8MkogR7N00WogR7N00?o0000omHYe_oF:MH01OoF:MH00ol0003o/Tfbok9=/P09ok9=/P04
o`000?oR7N;o0000o`00013oYeRW0_l00008onTFj@03o`000?oT6nCoi1_T01Coi1_T0ol0000;oo<<
l`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7
n?oh1oP02?oh1oP00ol0003olPgboo8=lP0;oo8=lP;o00002_oN8Mh00ol0003oeRWFomHYeP06omHY
eP03o`000?nbCK;o/Tfb00[o/Tfb00?o0000ojMHYonWF:L04_nWF:L00ol0003ojAKYonTFj@04onTF
j@03o`000?oT6nCoi1_T01Goi1_T00?o0000omhQg_oN8Mh01Ol00005oo<<l`03o`000?oh1oSon0Oh
00[on0Oh00?o0000oo`3o?ol0o`03_ol0o`3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooP7n?oh1oP01ooh1oP00ol0003olPgboo8=lP0;oo8=lP04
o`000?o?<<oocc3?o`0000WogR7N00?o0000omHYe_oF:MH01_oF:MH00ol0003o/Tfbok9=/P0:ok9=
/P03o`000?nWF:OoYeRW01?oYeRW0_l00003onTFj@Co00005?oT6n@00ol0003ogR7NomhQgP06omhQ
gPCo000000?ol`cco`000?oh1oP02ooh1oP00ol0003oo0?loo`3o00>oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP01ooh1oP00ol0003olPgboo8=lP09oo8=lP;o00001?o?<<l00ol0003ogR7NomhQgP05omhQgP03
o`000?oF:MKoeRWF00OoeRWF00?o0000ok9=/_nbCK802_nbCK800ol0003oYeRWojMHY`0EojMHY`03
o`000?oY5^Wo000000Co_4>l0ol0000@on@Ki003o`000?oN8MkogR7N00_ogR7N0_l0000<ooP7n003
o`000?ol0ocoo0?l00coo0?l0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo8=l_ob3O802?ob3O800ol0003occ3?
oll`c`05oll`c`03o`000?oN8MkogR7N00CogR7N00?o0000omHYe_oF:MH01ooF:MH00ol0003o/Tfb
ok9=/P0:ok9=/P03o`000?nWF:OoYeRW01KoYeRW00?o0000oka3_?nl@k`01_nl@k`3o`0000coi1_T
00?o0000omhQg_oN8Mh03OoN8Mh00ol0003on0OhooP7n009ooP7n0Go00002Ool0o`2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooP7n?oh1oP01_oh
1oP00ol0003olPgboo8=lP07oo8=lP03o`000?o?<<oocc3?00Oocc3?00?o0000omhQg_oN8Mh00_oN
8Mh00ol0003oeRWFomHYeP08omHYeP03o`000?nbCK;o/Tfb00Wo/Tfb00?o0000ojMHYonWF:L05onW
F:L00ol0003o_4>loka3_009oka3_0?o00002OoT6n@00ol0003ogR7NomhQgP0>omhQgPKo00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_ol0o`2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on0OhooP7n006ooP7n003o`000?ob
3O;olPgb00GolPgb0_l0000;oll`c`04o`000?oN8MkogR7No`0000_oeRWF00?o0000ok9=/_nbCK80
2OnbCK800ol0003oYeRWojMHY`0FojMHY`03o`000?nl@kco_4>l00go_4>l0ol00005on@Ki003o`00
0?oN8MkogR7N00oogR7N00?o0000on/Djoo[5>/00oo[5>/4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oh1oP00ol0003olPgboo8=
lP05oo8=lP03o`000?o?<<oocc3?00cocc3?00?o0000omhQg_l000002ooF:MH00ol0003o/Tfbok9=
/P07ok9=/P?o00006?nWF:L00ol0003o_4>loka3_00@oka3_0?o000000?oi1_To`000?oN8Mh04?oN
8Mh00ol0003ojaC[on/Dj`07on/Dj`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooP7n003o`000?ob3O;olPgb00?olPgb0_l0000@oll`c`03o`000?oF:MKoeRWF00[oeRWF00?o0000
ok9=/_nbCK800onbCK84o`0000;oQ7^400?o0000ojMHYonWF:L05OnWF:L00ol0003o_4>loka3_00D
oka3_003o`000?oN8MkogR7N013ogR7N00?o0000on/Djoo[5>/01oo[5>/00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?olPgb00?o0000oll`coo?<<l04?o?<<l00ol0
003oeRWFomHYeP0:omHYeP03o`000?nbCK;o000000?o00001on4Nh@00ol0003oYeRWojMHY`0DojMH
Y`03o`000?nl@kco_4>l01Co_4>l00?o0000omhQg_oN8Mh03ooN8Mh00ol0003ojaC[on/Dj`08on/D
j`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00?o
k1?/00?o0000oo8=l_l000004oo?<<l4o`0000WoeRWF0_l0000<ohAkQ003o`000?nWF:OoYeRW01?o
YeRW00?o0000oka3_?nl@k`05Onl@k`00ol0003ogR7NomhQgP0>omhQgP03o`000?o[5>_ojaC[00So
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ok1?/on`Ck005on`Ck003o`00
0?o?<<oocc3?01;occ3?00Co0000oh]dRon;M8_oRgB;1Ol00003omHYeP03o`000?n4NhCoQ7^400go
Q7^40ol0000@ojMHY`;o00006?nl@k`00ol0003ogR7NomhQgP0=omhQgP03o`000?o[5>_ojaC[00Wo
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`00
0?o?<<oocc3?017occ3?00?o0000oh]dRon;M8/01on;M8/3o`00013oQ7^400?o0000oe:]D_mB[E80
1Ol00009ojMHY`;o000000?oOX5no`000?nl@k`05onl@k`00ol0003ogR7NomhQgP0=omhQgP03o`00
0?o[5>_ojaC[00WojaC[00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000oll`coo?<<l03oo?<<l00ol0003oRgB;oh]d
R`0:oh]dR`03o`000?n4NhCoQ7^400goQ7^400?o0000oe:]D_mB[E801_mB[E84o`0000CoYeRW00?o
0000ogj1O_mnPGh00_mnPGh00ol0003o_4>loka3_00Foka3_003o`000?oN8MkogR7N00_ogR7N00?o
0000on/Djoo[5>/02oo[5>/00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ok1?/00?o0000oll`coo?<<l03oo?<<l00ol0003oRgB;oh]dR`0;oh]dR`03o`000?n4NhCo
Q7^400coQ7^400?o0000oe:]D_mB[E802_mB[E84o`0000GoOX5n00?o0000oka3_?nl@k`05_nl@k`0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000on`C
k?o/4n`02Oo/4n`00ol0003occ3?oll`c`0=oll`c`03o`000?n;M8_oRgB;00coRgB;00?o0000ohAk
Q?n4Nh@03?n4Nh@00ol0003oDZeBoe:]DP0;oe:]DP03o`000?mGZ5Oo000000KoOX5n00?o0000oka3
_?nl@k`05_nl@k`00ol0003ogR7NomhQgP09omhQgP03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000oll`coo?<<l02?o?<<l4o`0000oo
RgB;00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003oDZeBoe:]DP0;oe:]DP04o`000?mGZ5OoEjQGo`00
00OoOX5n00?o0000oka3_?nl@k`05Onl@k`00ol0003ogR7NomhQgP08omhQgP03o`000?o[5>_ojaC[
00gojaC[00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000oll`coo?
<<l00oo?<<l5o`0000?oSg2?00?o0000oh]dRon;M8/03_n;M8/00ol0003oQ7^4ohAkQ00:ohAkQ003
o`000?mB[E;oDZeB00[oDZeB00Go0000oeNXEomGZ5OoEjQGo`000007ogj1OP03o`000?nl@kco_4>l
01Go_4>l00?o0000omhQg_oN8Mh02?oN8Mh00ol0003ojaC[on/Dj`0=on/Dj`03o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00<on`Ck0Go00002On?L8l00ol0003o
RgB;oh]dR`0<oh]dR`;o00003?n4Nh@00ol0003oDZeBoe:]DP0:oe:]DP05o`000?mGZ5OoEjQGoeNX
Eol000002?mnPGh00ol0003o_4>loka3_00Doka3_0?o00001ooN8Mh00ol0003ojaC[on/Dj`0>on/D
j`03o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000on`Ck?o/4n`03?o/4n`01?l0003obcC;ol/dbol0000;ohm`S`03o`000?n;M8_oRgB;
00_oRgB;00Co0000od2o@?m0_d3o00002_n4Nh@00ol0003oDZeBoe:]DP0:oe:]DP03o`000?mGZ5Oo
EjQG00;oEjQG00?o0000ogj1O_mnPGh01_mnPGh00ol0003o_4>loka3_00Aoka3_0?o00000oo5>/D0
0ol0003ogR7NomhQgP04omhQgP03o`000?o[5>_ojaC[00gojaC[1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000ol/dboo;=</00_o;=</0
0ol0003oSg2?ohm`S`08ohm`S`03o`000?n;M8_oRgB;00[oRgB;00?o0000od2o@?m0_d000_m0_d00
0ol0003oQ7^4ohAkQ003ohAkQ0Go00002omB[E800ol0003oEjQGoeNXE`03oeNXE`03o`000?mnPGko
OX5n00OoOX5n00?o0000oka3_?nl@k`03_nl@k`2o`0000OoaC[500?o0000omhQg_oN8Mh00_oN8Mh0
0ol0003ojaC[on/Dj`0=on/Dj`03o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol/d
boo;=</00oo;=</00ol0003oSg2?ohm`S`09ohm`S`03o`000?n;M8_oRgB;00SoRgB;00?o0000od2o
@?m0_d001?m0_d05o`0000Co?L8m00?o0000oe:]D_mB[E802OmB[E800ol0003oEjQGoeNXE`03oeNX
E`03o`000?mnPGkoOX5n00SoOX5n00?o0000oka3_?nl@k`02_nl@k`3o`0000[oaC[500Go0000omhQ
g_oN8MkogR7No`00000>on/Dj`03o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol/d
boo;=</01?o;=</00ol0003oSg2?ohm`S`09ohm`S`03o`000?n;M8_oRgB;00OoRgB;00?o0000od2o
@?m0_d001Om0_d000ol0003o?L8mocg2?@07ocg2?@03o`000?mB[E;oDZeB00OoDZeB00?o0000oeNX
EomGZ5L01?mGZ5L00ol0003oOX5nogj1OP08ogj1OP03o`000?nl@kco_4>l00So_4>l0_l0000>olDj
a@Co00003?o[5>/2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003ok1?/on`Ck009on`Ck003o`000?o;=<_obcC;00KobcC;00?o0000ohm`Son?L8l02On?L8l00ol0
003oRgB;oh]dR`05oh]dR`03o`000?m0_d3o@;m000Ko@;m000?o0000ocg2?Olm`Sd02?lm`Sd00ol0
003oDZeBoe:]DP06oe:]DP03o`000?mGZ5OoEjQG00CoEjQG00?o0000ogj1O_mnPGh02OmnPGh4o`00
00?o_4>l0ol0000@olDja@05o`000?oW6>OoiaSWonLHiol000002_o[5>/00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[ok1?/00?o0000ol/dboo;=</01oo;=</0
0ol0003oSg2?ohm`S`09ohm`S`03o`000?n;M8_oRgB;00CoRgB;00?o0000od2o@?m0_d001om0_d00
0ol0003o?L8mocg2?@08ocg2?@;o00001_mB[E800ol0003oEjQGoeNXE`05oeNXE`03o`000?mnPGko
OX5n00WoOX5n00Co0000oiYUV_nJII[oVVFJ0ol0000BolDja@03o`000?oW6>OoiaSW00?oiaSW0_l0
0006on/Dj`;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o/4n`00ol0003obcC;ol/db`08ol/db`03o`000?n?L8oo
Sg2?00[oSg2?00?o0000oh]dRon;M8/00_n;M8/00ol0003o@;m0od2o@008od2o@003o`000?lm`Sgo
?L8m00Ko?L8m0_l00002obGJ9@03o`000?mB[E;oDZeB00;oDZeB00?o0000oeNXEomGZ5L01_mGZ5L0
0ol0003oOX5nogj1OP08ogj1OP03o`000?nJII[oVVFJ00CoVVFJ00?o0000olDjaOo5>/D03oo5>/D0
0ol0003oiaSWonLHi`06onLHi`;o00000oo[5>/00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003obcC;ol/db`0:ol/db`03o`000?n?L8ooSg2?
00WoSg2?00Go0000oh]dRon;M8_oRgB;o`00000;od2o@003o`000?lm`Sgo?L8m00Co?L8m0_l00005
obGJ9@05o`000?mB[E;oDZeBoe:]D_l000002?mGZ5L00ol0003oOX5nogj1OP08ogj1OP03o`000?nJ
II[oVVFJ00GoVVFJ00?o0000olDjaOo5>/D03_o5>/D00ol0003oiaSWonLHi`08onLHi`03o`000?o[
5>_o000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003obcC;
ol/db`0;ol/db`03o`000?n?L8ooSg2?00WoSg2?00Co0000oh]dRon;M8_o00003?m0_d000ol0003o
?L8mocg2?@02ocg2?@;o00002?lUfRD00ol0003oDZeBo`000009oeNXE`03o`000?mnPGkoOX5n00So
OX5n00?o0000oiYUV_nJIIX01OnJIIX00ol0003oaC[5olDja@0=olDja@03o`000?oW6>OoiaSW00[o
iaSW00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o/4ncok1?/00Cok1?/00?o0000ol/dboo;=</03?o;=</00ol0003oSg2?ohm`S`0:ohm`S`?o0000
3?m0_d000ol0003o?L8mocg2?@02o`0000_o9MXU00?o0000oeNXEomGZ5L02?mGZ5L00ol0003oOX5n
ogj1OP07ogj1OP03o`000?nJII[oVVFJ00OoVVFJ00?o0000olDjaOo5>/D03?o5>/D00ol0003oiaSW
onLHi`0;onLHi`;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo/
4n`00ol0003obcC;ol/db`0>ol/db`03o`000?n?L8ooSg2?00SoSg2?00Co0000odNhAom7^4OoAkQ7
0_l0000:od2o@0?o00003OlUfRD00ol0003oEjQGoeNXE`08oeNXE`03o`000?mnPGkoOX5n00OoOX5n
00?o0000oiYUV_nJIIX01onJIIX00ol0003oaC[5olDja@0;olDja@03o`000?oW6>OoiaSW00coiaSW
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003oo@;m003o`000?o/4nco0000017obcC;00?o0000ohm`Son?L8l01on?L8l00ol0003oAkQ7odNh
A`04odNhA`;o00002?m0_d000ol0003o9MXUobGJ9@0>obGJ9@;o00002?mGZ5L00ol0003oOX5nogj1
OP06ogj1OP03o`000?nJII[oVVFJ00WoVVFJ00?o0000olDjaOo5>/D02Oo5>/D00ol0003oiaSWonLH
i`0=onLHi`03o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006oo@;m003o`000?o;=<_obcC;013obcC;00?o0000ohm`Son?L8l01_n?L8l0
0ol0003oAkQ7odNhA`07odNhA`03o`000?m0_d3o@;m000Co@;m00ol0000>obGJ9@03o`000?lVfBKo
9]TV00?o00001OmGZ5L00ol0003oOX5nogj1OP06ogj1OP03o`000?nJII[oVVFJ00[oVVFJ00?o0000
olDjaOo5>/D02?o5>/D00ol0003oiaSWonLHi`0=onLHi`03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008oo@;m003o`000?o;=<_obcC;
017obcC;00Co0000ohm`Son?L8ooSg2?1?l0000;odNhA`;o000000Co@;m0o`000?l0003o00000olA
kQ42o`0000_o9MXU00?o0000obKI9_lVfBH01?lVfBH2o`0000?oEjQG00?o0000ogj1O_mnPGh01_mn
PGh00ol0003oVVFJoiYUVP0:oiYUVP03o`000?o5>/GoaC[500OoaC[500?o0000onLHiooW6>L03_oW
6>L00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<oo@;m003o`000?o;=<_o
bcC;013obcC;1?l00003oh5nP@03o`000?m7^4OoAkQ700_oAkQ700?o0000oa7^4OlAkQ401_lAkQ40
0ol0003o9MXUobGJ9@07obGJ9@03o`000?lVfBKo9]TV00Oo9]TV3?l0000>oiYUVP03o`000?o5>/Go
aC[500KoaC[500?o0000onLHiooW6>L03_oW6>L00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_od2o@00ol0003obcC;ol/db`0?ol/db`03o`000?n1OX7oPGj100KoPGj100?o0000
odNhAom7^4L02_m7^4L00ol0003o4NhAoa7^4@07oa7^4@;o00001_lUfRD00ol0003o9]TVobKI9P08
obKI9P03o`000?mJYE[oFZEJ00SoFZEJ00?o0000oiYUV_nJIIX03?nJIIX00ol0003oaC[5olDja@05
olDja@03o`000?oW6>OoiaSW00ooiaSW0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03_od2o@00ol0
003obcC;ol/db`0>ol/db`03o`000?n1OX7oPGj100OoPGj100?o0000odNhAom7^4L02_m7^4L00ol0
003o4NhAoa7^4@09oa7^4@;o00000olUfRD00ol0003o9]TVobKI9P09obKI9P03o`000?mJYE[oFZEJ
00WoFZEJ00?o0000oiYUV_nJIIX02_nJIIX4o`0000CoaC[500?o0000onLHiooW6>L04?oW6>L01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03ood2o@@o`0000[oPGj100?o0000odNh
Aom7^4L02Om7^4L00ol0003o3o0?o`00000<oa7^4@05o`000?lUfRGo0000o`_d2ol000002_lVfBH0
0ol0003oFZEJoeZUFP09oeZUFP03o`000?nJII[oVVFJ00OoVVFJ0ol00004ok1?/0?o000000?oaC[5
o`000?oW6>L04OoW6>L01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00?
oo@;m003o`000?o1?/7o`Ck100co`Ck100?o0000oh5nPOn1OX402On1OX400ol0003oAkQ7odNhA`07
odNhA`04o`000?l?l0oo3o0?o`0000go4NhA00Go0000o`_d2ol;m0_o2o@;o`000009obKI9P03o`00
0?mJYE[oFZEJ00[oFZEJ00?o0000oiYUV_nJIIX00onJIIX3o`0000[o/4n`00?o0000onLHiooW6>L0
4?oW6>L00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo@;m?od2o@03ood2o@00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?n1
OX7oPGj100WoPGj100?o0000odNhAom7^4L01_m7^4L00ol0003o3o0?o`o`3`02o`o`3`03o`000?lA
kQ7o4NhA00[o4NhA00?o0000o`_d2ol;m0/00_l;m0/00ol0003o9]TVobKI9P06obKI9P03o`000?mJ
YE[oFZEJ00[oFZEJ00?o0000oiYUV_nJIIX00ol0000=ok1?/003o`000?oW6>OoiaSW013oiaSW00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00=oo@;m0?o00003oo1?/40
0ol0003oPGj1oh5nP@08oh5nP@03o`000?m7^4OoAkQ700GoAkQ700?o0000o`o`3ol?l0l00ol?l0l0
0ol0003o4NhAoa7^4@0:oa7^4@03o`000?l;m0_o2o@;00?o2o@;00?o0000obKI9_lVfBH01OlVfBH0
0ol0003oFZEJoeZUFP0;oeZUFP;o00004On`Ck000ol0003oiaSWonLHi`0?onLHi`03o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_doo@;m009oo@;m0Go00000_oX5nP00ol0
003o`Ck1ol4n`@0=ol4n`@03o`000?n1OX7oPGj100WoPGj100?o0000odNhAom7^4L01?m7^4L00ol0
003o3o0?o`o`3`04o`o`3`03o`000?lAkQ7o4NhA00So4NhA00?o0000o`_d2ol;m0/01Ol;m0/00ol0
003o9]TVobKI9P04obKI9P03o`000?mJYE[oFZEJ00_oFZEJ00?o0000ok1?/?n`Ck004?n`Ck000ol0
003oiaSWonLHi`0?onLHi`03o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?od2oCom0_d00Com0_d1Ol00007onPGj003
o`000?o1?/7o`Ck100go`Ck100?o0000oh5nPOn1OX402On1OX400ol0003oAkQ7odNhA`03odNhA`03
o`000?l?l0oo3o0?00Go3o0?00?o0000oa7^4OlAkQ402?lAkQ400ol0003o2o@;o`_d2`06o`_d2`03
o`000?lVfBKo9]TV00?o9]TV00?o0000oeZUF_mJYEX02omJYEX00ol0003o/4n`ok1?/00@ok1?/003
o`000?oW6>OoiaSW00ooiaSW00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?l00000
1?l0000<onPGj003o`000?o1?/7o`Ck100ko`Ck100?o0000oh5nPOn1OX402?n1OX400ol0003oAkQ7
odNhA`02odNhA`03o`000?l?l0oo3o0?00Oo3o0?00?o0000oa7^4OlAkQ401olAkQ400ol0003o2o@;
o`_d2`07o`_d2`03o`000?lVfBKo9]TV00;o9]TV00?o0000oeZUF_mJYEX02omJYEX00ol0003o/4n`
ok1?/00Aok1?/003o`000?oW6>OoiaSW00goiaSW00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oj1OX00?o0000ol4n`Oo1?/403_o1
?/400ol0003oPGj1oh5nP@09oh5nP@04o`000?m7^4OoAkQ7o`0000[o3o0?00?o0000oa7^4OlAkQ40
1olAkQ400ol0003o2o@;o`_d2`08o`_d2`05o`000?lVfBKo9]TVobKI9_l000003OmJYEX00ol0003o
/4n`ok1?/00Aok1?/0?o00003OoW6>L00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;onPGj00?o0000onPGj?oX5nP03ooX5nP00ol0003o
`Ck1ol4n`@0>ol4n`@03o`000?n1OX7oPGj100SoPGj11Ol0000;o`o`3`03o`000?lAkQ7o4NhA00Ko
4NhA00?o0000o`_d2ol;m0/02Ol;m0/01?l0003o9]TVobKI9_l0000=oeZUFP03o`000?n`Ck3o/4n`
017o/4n`00?o0000omPWf?oH9mP00ol0000:onLHi`Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005ooX5nP03o`000?oX5nSoj1OX00koj1OX00?o0000ol4n
`Oo1?/403_o1?/400ol0003oPGj1oh5nP@07oh5nP@03o`000?l[e2_o:m@[00?o:m@[00?o0000o`o`
3ol?l0l02?l?l0l00ol0003o4NhAoa7^4@05oa7^4@03o`000?l;m0_o2o@;00[o2o@;1Ol0000<oeZU
FP03o`000?n`Ck3o/4n`013o/4n`00?o0000omPWf?oH9mP01?oH9mP3o`0000KoiaSW00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000ooX5n_oj1OX01?oj1OX00ol0003oj1OXonPGj00=onPGj003o`000?o1?/7o`Ck100oo
`Ck100?o0000oh5nPOn1OX401?n1OX42o`0000Oo:m@[00?o0000o`o`3ol?l0l01ol?l0lEo`0000Go
9]TV00?o0000oeZUF_mJYEX02?mJYEX3o`00013o/4n`00?o0000omPWf?oH9mP02?oH9mP3o`0000;o
iaSW00?o0000ooX5n_oj1OX02?oj1OX5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000ooX5n_oj1OX01Ooj1OX00ol0003oj1OXonPGj00;onPGj0Co0000
3oo1?/400ol0003oPGj1oh5nP@03oh5nP@03o`000?l[e2_o:m@[00So:m@[00?o0000o`o`3ol?l0l0
1?l?l0l2o`0000So0o`300?o0000o`7n0Ol1oP402?l1oP400ol0003o9]TVobKI9P05obKI9P;o0000
1_mJYEX2o`0000?oL8m`00?o0000ok1?/?n`Ck003?n`Ck000ol0003of2OHomPWf00<omPWf0;o0000
4?oj1OX3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00KonPGj00?o
0000onPGj?oX5nP02OoX5nP00ol0003okQ7^o`000002olDja@?o00003?o1?/401?l0003oPGj1oh5n
POn1OX42o`0000co:m@[00?o0000o`o`3ol?l0l00_l?l0l00ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l1oP7o0Oh100So0Oh100?o0000obKI9_lVfBH01olVfBH00ol0003oFZEJoeZUFP02oeZUFP03o`00
0?m`Sg3oL8m`00CoL8m`0_l0000;ok1?/003o`000?oH9mSof2OH00cof2OH00?o0000onl@kol00000
4_oj1OX00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00OonPGj00?o
0000onPGj?oX5nP01_oX5nP2o`0000;okQ7^00?o0000olDjaOo5>/D00oo5>/D3o`0000[o`Ck100?o
0000oh5nPOl000003ol[e2/01?l0003o3o0?o`000?l0000;o`?l0`03o`000?l1oP7o0Oh100So0Oh1
00?o0000obKI9_lVfBH02?lVfBH01?l0003oFZEJo`000?l00009og2?L003o`000?n`Ck3o/4n`00Oo
/4n`00?o0000omPWf?oH9mP03?oH9mP01?l0003oka3_onl@kol0000CooX5nP03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oX5nSoj1OX00Co
j1OX00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oaC[5olDja@05olDja@?o00001_o1?/44o`00013o
:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV00Wo
9]TV00?o0000og2?L?m`Sg002_m`Sg02o`0000Ko/4n`00?o0000omPWf?oH9mP03?oH9mP00ol0003o
ka3_onl@k`02onl@k`03o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?oj1O[onPGj00WonPGj00Co0000onPGj?oX5nSo
j1OX0_l00006onhAkP03o`000?o5>/GoaC[500SoaC[50ol000000oo1?/7o0000o`000004ogB;M003
o`000?l[e2_o:m@[00go:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03
o`000?lVfBKo9]TV00Wo9]TV00?o0000og2?L?m`Sg003?m`Sg000ol0003o/4n`ok1?/003o`0000ko
f2OH00?o0000onl@koo_4>l00oo_4>l00ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00[o
nPGj00?o0000onPGj?l000002?o^4Nh00ol0003oaC[5olDja@0;olDja@03o`000?mdRgCoM8]d00Go
M8]d00?o0000ob_D:ol[e2/03?l[e2/00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l1oP7o0Oh100Oo
0Oh100?o0000obKI9_lVfBH02?lVfBH2o`0000ooL8m`0_l00002olTfb@03o`000?oH9mSof2OH00_o
f2OH00?o0000onl@koo_4>l01?o_4>l00ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003oaC[5olDja@0;olDja@03o`000?mdRgCoM8]d00KoM8]d00?o0000ob_D:ol[e2/0
2ol[e2/2o`0000go0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9]TVobKI9P07obKI9P04o`00
0?lka3_o>l@ko`0000koL8m`00?o0000olTfbOo9=/T00_o9=/T00ol0003of2OHomPWf009omPWf003
o`000?o_4>ooka3_00Koka3_00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000ooX5n_oj1OX02_oj1OX2o`0000Wo
kQ7^00?o0000olDjaOo5>/D02oo5>/D00ol0003oM8]dogB;M007ogB;M003o`000?l[e2_o:m@[00Wo
:m@[00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV
00Ko9]TV00Go0000oc_4>olka3_o>l@ko`00000>og2?L003o`000?o9=/WobCK900?obCK900?o0000
omPWf?oH9mP01ooH9mP00ol0003oka3_onl@k`07onl@k`03o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?oj1O[onPGj
00WonPGj00Co0000ooT6nOoi1_Wo00002Oo^4Nh00ol0003oaC[5olDja@09olDja@03o`000?mdRgCo
M8]d00WoM8]d00?o0000ob_D:ol[e2/01ol[e2/00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9]TVobKI9P05obKI9P03o`000?lka3_o
>l@k00?o>l@k00?o0000og2?L?m`Sg002_m`Sg000ol0003obCK9olTfb@05olTfb@03o`000?oH9mSo
f2OH00Gof2OH00?o0000onl@koo_4>l02?o_4>l00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000WonPGj00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okQ7^onhAkP06onhAkP03o`000?o5>/GoaC[500WoaC[500?o0000ogB;
M?mdRg@02_mdRg@00ol0003o:m@[ob_D:`05ob_D:`03o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV00Co9]TV00?o0000oc_4
>olka3/01?lka3/00ol0003oL8m`og2?L00:og2?L003o`000?o9=/WobCK900KobCK900?o0000omPW
f?oH9mP00ooH9mP00ol0003oka3_onl@k`09onl@k`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ooj1OX00ol0003o
n@KiooT6n@03ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000olDjaOo5>/D02Oo5>/D00ol0003o
M8]dogB;M00;ogB;M003o`000?l[e2_o:m@[00?o:m@[00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l1oP7o0Oh100Ko0Oh100?o0000obKI9_lVfBH00_lVfBH2o`0000So
>l@k00?o0000og2?L?m`Sg002Om`Sg000ol0003obCK9olTfb@07olTfb@05o`000?oH9mSof2OHomPW
f?l000003Oo_4>l00ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ooj1O[o0000ooT6n@06ooT6n@03
o`000?o^4NkokQ7^00GokQ7^00?o0000olDjaOo5>/D02Oo5>/D00ol0003oM8]dogB;M00<ogB;M005
o`000?l[e2_o:m@[ob_D:ol000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh1
00Ko0Oh100?o0000obKI9_l000000_l000000olCk1?o0000oc_4>`07oc_4>`03o`000?m`Sg3oL8m`
00SoL8m`00?o0000olTfbOo9=/T02Oo9=/T00ol0003of2OHo`00000=onl@k`Co00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oaC[5olDja@09olDja@03
o`000?mdRgCoM8]d00goM8]d00?o0000ob_D:ol000003?l9mPT:o`0000Oo0Oh10ol00005oa?/4`03
o`000?lka3_o>l@k00Ko>l@k00?o0000og2?L?m`Sg001om`Sg000ol0003obCK9olTfb@0:olTfb@03
o`000?o_4>ooka3_00_oka3_00?o0000oo/4nook1?/00_ok1?/3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olDjaOo5>/D01oo5>/D00ol0003oM8]dogB;M00?ogB;M0;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100;o0Oh10ol00008oa?/4`03o`00
0?lka3_o>l@k00Ko>l@k00?o0000og2?L?m`Sg001om`Sg000ol0003obCK9olTfb@0:olTfb@03o`00
0?o_4>ooka3_00[oka3_00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o^4NkokQ7^00CokQ7^00?o0000olDjaOo5>/D01oo5>/D00ol0003oM8]dogB;
M00>ogB;M004o`000?ldbcCo=</do`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0Oh1
o`000?l0000<oa?/4`03o`000?lka3_o>l@k00Ko>l@k00?o0000og2?L?m`Sg001_m`Sg000ol0003o
bCK9olTfb@0;olTfb@03o`000?o_4>ooka3_00Ooka3_0_l00009oo/4n`03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh00oo^4Nh>o`0000goM8]d00?o0000ocC;=?ldbc@0
0_ldbc@00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oa?/4olCk1<0
3?lCk1<00ol0003o>l@koc_4>`06oc_4>`03o`000?m`Sg3oL8m`00GoL8m`00?o0000olTfbOo9=/T0
3?o9=/T00ol0003oka3_onl@k`06onl@k`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okQ7^onhAk_o^4Nko000000_occ3?00?o0000og6>LOmaSW400ol00009ogB;M003o`00
0?ldbcCo=</d00Co=</d00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lCk1?o4n`C00go4n`C00?o0000oc_4>olka3/01_lka3/00ol0003oL8m`og2?L003og2?L0?o0000
3Oo9=/T00ol0003oka3_onl@k`05onl@k`03o`000?ok1?_on`Ck00con`Ck0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cocc3?00?o0000og6>LOmaSW400omaSW43o`0000GoM8]d00?o0000ocC;=?ldbc@01_ld
bc@01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oa?/4olCk1<03OlCk1<00ol0003o>l@k
oc_4>`06oc_4>`03o`000?m`Sg3oL8m`00?o00000on;M8/00ol0003obCK9olTfb@0;olTfb@03o`00
0?o_4>ooka3_00?oka3_00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003ooD:m@03o`000?o?<<oocc3?00[occ3?00?o0000og6>LOmaSW401_maSW43o`000003ogB;M?l0
003o=</d00Wo=</d00?o0000o`Wf2Ol000004?l9mPT00ol0003o4n`Coa?/4`0=oa?/4`03o`000?lk
a3_o>l@k00Oo>l@k0_l00007oh]dR`03o`000?o9=/WobCK900[obCK900Co0000onl@koo_4>ooka3_
0ol0000?oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom@[e00?o0000oll`coo?
<<l02_o?<<l00ol0003oLHiaog6>L@09og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o4n`Coa?/4`0>oa?/4`03o`000?lka3_o>l@k00Ko>l@k00?o0000oh]dRon;
M8/01on;M8/4o`0000SobCK900Co0000onl@koo_4>oo00000oof2OH2o`0000gon`Ck00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000oll`coo?<<l02Oo?<<l00ol0003o
LHiaog6>L@0:og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
4n`Coa?/4`0>oa?/4`03o`000?lka3_o>l@k00Go>l@k00?o0000oh]dRon;M8/02?n;M8/01?l0003o
cc3?oll`coo?<<l7o`0000;obCK90_l00006ooH9mP;o00003?ok1?/00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003occ3?oll`c`08oll`c`03o`000?maSW7oLHia00[o
LHia00?o0000ocC;=?ldbc@02oldbc@00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lCk1?o4n`C00ko
4n`C1Ol00002oc_4>`03o`000?n;M8_oRgB;00WoRgB;00?o0000oll`coo?<<l02?o?<<l3o`0000Wo
mPWf0_l0000:oo/4n`03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@07ooD:m@03o`00
0?o?<<oocc3?00Socc3?00?o0000og6>LOmaSW402_maSW400ol0003o=</docC;=00:ocC;=0;o0000
3_l9mPT3o`0000go4n`C0ol00005odRgB0;o00002on;M8/00ol0003occ3?oll`c`0;oll`c`;o0000
2_of2OH2o`0000Oon`Ck0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?oe2_Gom@[e00Oom@[e00?o0000oll`coo?<<l02?o?<<l>o`0000Wo=</d0ol000000olXebSo0000
o`Wf2@0:o`Wf2@?o00000_lKi1/00ol0003o4n`Coa?/4`09oa?/4`;o00002Om8]dP00ol0003oRgB;
oh]dR`09oh]dR`03o`000?o?<<oocc3?00_occ3?00?o0000onDJiOl000002oof2OH2o`0000Con`Ck
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oe2_Gom@[e00Kom@[e00?o0000oll`coo?<<l02?o?<<l00ol0003oKi1_
ofn@K`0:ofn@K`03o`000?ldbcCo=</d00Co=</d0ol00005obSG:003o`000?l9mPWo2OH900Co2OH9
1?l00006oa_T6`03o`000?lCk1?o4n`C00Ko4n`C0_l0000;odRgB003o`000?n;M8_oRgB;00WoRgB;
00?o0000oll`coo?<<l02_o?<<l01Ol0003oiA[UonDJiOoU6^Go000000comPWf0_l000000ook1?_o
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003occ3?oll`c`07oll`c`03o`00
0?m_T6ooKi1_00_oKi1_00?o0000ocC;=?ldbc@00_ldbc@2o`0000Wo:=LX00?o0000o`Wf2Ol9mPT0
0ol0000;oa_T6`03o`000?lCk1?o4n`C00;o4n`C0ol0000>odRgB003o`000?n;M8_oRgB;00OoRgB;
00?o0000oll`coo?<<l02oo?<<l00ol0003oiA[UonDJi@02onDJi@03o`000?of2OKomPWf00_omPWf
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000ooD:mOoe2_D01ooe2_D00ol0003occ3?oll`c`05oll`c`?o00003Om_
T6l4o`0000_o:=LX0ol0000?oa_T6`04o`000?lCk1?o0000o`00017oB;M800?o0000oh]dRon;M8/0
1on;M8/00ol0003occ3?oll`c`0:oll`c`03o`000?oU6^GoiA[U00CoiA[U00?o0000ooH9m_of2OH0
1oof2OH3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om@[eooD:
m@06ooD:m@03o`000?o?<<oocc3?00;occ3?0ol00003ojm@[`03o`000?m_T6ooKi1_00[oKi1_00?o
0000obSG:?lXebP02olXebP00ol0003o8m`So`00000Aoa_T6`03o`000?m8]dSoB;M8017oB;M800?o
0000oh]dRon;M8/01on;M8/00ol0003occ3?oll`c`0:oll`c`03o`000?oU6^GoiA[U00GoiA[U00Co
0000ooH9m_of2OKomPWf1Ol00002ooP7n003o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@05ooD:m@?o0000
00?occ3?o`000?l000001on_D:l00ol0003oKi1_ofn@K`08ofn@K`?o00002_lXebP2o`0000;o8m`S
00?o0000oa_T6olKi1/03olKi1/00ol0003oB;M8odRgB00AodRgB003o`000?n;M8_oRgB;00OoRgB;
00?o0000oll`coo?<<l02Oo?<<l00ol0003oiA[UonDJi@07onDJi@?o00001ooh1oP00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om@[e0_l00003onl@k`03o`000?n_D:oo[e2_00So[e2_0_l00006ofn@K`;o00000omM
XUd00ol0003o:=LXobSG:006obSG:003o`000?lSg2?o8m`S00?o8m`S00?o0000oa_T6olKi1/03_lK
i1/00ol0003oB;M8odRgB00BodRgB003o`000?n;M8_oRgB;00GoRgB;00?o0000oll`coo?<<l02Oo?
<<l00ol0003oiA[UonDJi@08onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo_4>l00ol0003o[e2_ojm@[`0:ojm@[`03o`000?m_T6ooKi1_00;oKi1_00?o0000
oefRGOmMXUd01?mMXUd00ol0003o:=LXobSG:004obSG:003o`000?lSg2?o8m`S00Co8m`S00?o0000
oa_T6olKi1/03_lKi1/00ol0003oB;M8odRgB00BodRgB0[o00002_o?<<l00ol0003oiA[UonDJi@08
onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onl@koo_4>l01?o_4>l0
0ol0003o[e2_ojm@[`0:ojm@[`04o`000?m_T6oo0000o`0000SoGJ9M00Co0000obSG:?lXebSo:=LX
0_l00007ob?L8`03o`000?lKi1_o6n@K00ko6n@K00?o0000odRgB?m8]dP04_m8]dP00ol0003oZ5NX
ojQGZ007ojQGZ003o`000?o?<<oocc3?00Kocc3?00?o0000onDJiOoU6^D02_oU6^D00ol0003on0Oh
ooP7n006ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onl@koo_4>l01?o_4>l00ol0003o[e2_ojm@[`0;ojm@[`03o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obSG:?l000002OlSg2<00ol0003o6n@Koa_T6`0>oa_T6`;o0000
4_m8]dP00ol0003oZ5NXojQGZ009ojQGZ0;o00001_o?<<l00ol0003oiA[UonDJi@0:onDJi@03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?n_D:oo[e2_00[o[e2_00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa_T6olKi1/03_lKi1/00ol0003o?<<lo`00
0002o`0000ooB;M800?o0000ojQGZ?nXEjP02onXEjP00ol0003occ3?oll`c`03o`0000goiA[U00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o_4>ooka3_00Goka3_00?o0000ojm@[on_D:l02On_D:l2
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lKi1_o6n@K00co6n@K00?o0000occ3??ll`c`00oll`c`3
o`0000coB;M800?o0000ojQGZ?nXEjP03?nXEjP2o`0000;ohQgR00?o0000onDJiOoU6^D03?oU6^D0
0ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o[e2_ojm@[`07ojm@
[`03o`000?naC[7o000000[oGJ9M00Co0000oe:]D_mB[E;o00002_lSg2<00ol0003o6n@Koa_T6`0<
oa_T6`03o`000?ll`cco?<<l00Ko?<<l0_l00008odRgB0;o00003onXEjP00ol0003ohQgRon8MhP02
on8MhP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o_4>ooka3_
00Koka3_00?o0000ojm@[on_D:l01_n_D:l01Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe:]D_mB[E800_mB[E800ol0003o8m`Sob?L8`06ob?L8`Co00003?lKi1/00ol0003o?<<locc3?008
occ3?0?o00000_m8]dP3o`000003ohQgR?l0003oZ5NX00goZ5NX00?o0000on8Mh_oR7N801?oR7N80
0ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`07onl@
k`03o`000?n_D:oo[e2_00?o[e2_0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe:]
D_mB[E800omB[E800ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa_T
6`;o00003_ll`c`2o`0000GoR7N800?o0000ojQGZ?nXEjP02_nXEjP00ol0003ohQgRon8MhP05on8M
hP03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o_4>ooka3_00Oo
ka3_00?o0000ojm@[on_D:l00_n_D:l00ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe:]D_mB[E801OmB[E800ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6n@K0_l000000olQgR7o0000occ3?00=occ3?003o`000?n8MhSoR7N800GoR7N800?o0000ojQGZ?nX
EjP02?nXEjP00ol0003ohQgRon8MhP07on8MhP03o`000?oU6^GoiA[U00[oiA[U00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o_4>ooka3_00Soka3_00Co0000ojm@[on_D:oo00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDZeB00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lQgR40
0ol0003o?<<locc3?00;occ3?003o`000?n8MhSoR7N800KoR7N800?o0000ojQGZ?nXEjP01onXEjP0
0ol0003ohQgRon8MhP08on8MhPCo00002?oU6^D00ol0003on0OhooP7n004ooP7n003o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onl@
k`03o`000?n_D:oo000000_o/Dja00?o0000oefRGOl000002_mB[E800ol0003o8m`So`00000?oagR
7@03o`000?lQgR7o8MhQ00;o8MhQ00?o0000occ3??ll`c`02oll`c`00ol0003oR7N8ohQgR006ohQg
R003o`000?nXEjSoZ5NX00KoZ5NX00?o0000on8Mh_oR7N802OoR7N801?l0003olPgboo8=l_ob3O87
o`0000;oiA[U00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o_4>ooka3_00Ooka3_00?o0000ok5>
/OnaC[402onaC[400ol0003oDZeBoe:]DP0:oe:]DP03o`000?lMhQgo7N8M00go7N8M00?o0000ob7N
8OlQgR401?lQgR400ol0003o?<<locc3?009occ3?003o`000?n8MhSoR7N800SoR7N800?o0000ojQG
Z?nXEjP00onXEjP2o`0000cohQgR00?o0000oo8=l_ob3O802?ob3O8<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mB[E;oDZeB00WoDZeB0_l0000>oagR7@03o`000?lQgR7o8MhQ00Go
8MhQ00?o0000occ3??ll`c`02Oll`c`00ol0003oR7N8ohQgR009ohQgR003o`000?nXEjSo000000;o
00000_oH9mP00ol0003ohQgRon8MhP08on8MhP03o`000?ob3O;olPgb00colPgb00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003oka3_
onl@k`04onl@k`03o`000?naC[7o/Dja00_o/Dja0ol00007oe:]DP?o000000?o?<<lo`000?lMhQd0
3OlMhQd00ol0003o8MhQob7N8@06ob7N8@03o`000?ll`cco?<<l00So?<<l00?o0000ohQgR?n8MhP0
2_n8MhP00ol0003of2OHomPWf004omPWf003o`000?oR7N;ohQgR00OohQgR00?o0000oo8=l_ob3O80
2oob3O800ol0003onPGjooX5nP08ooX5nP03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onl@koo_4>l00oo_4>l>o`0000?oW6>L0_l00002oe:]DP?o0000
1Oll`c`00ol0003o7N8MoagR7@0:oagR7@03o`000?lQgR7o8MhQ00Oo8MhQ00?o0000occ3??ll`c`0
2?ll`c`00ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Gof2OH00?o0000on8Mh_oR7N80
1_oR7N800ol0003olPgboo8=lP0;oo8=lP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onl@koo_4>l00_o_4>l00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009occ3?003o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob7N8OlQgR402?lQgR42o`0000So?<<l00?o0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPW
f007omPWf003o`000?oR7N;ohQgR00CohQgR00?o0000oo8=l_ob3O802oob3O800ol0003onPGjooX5
nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?oka3_
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?ll`cco?<<l00Wo?<<l00?o0000
oagR7OlMhQd01olMhQd00ol0003o8MhQob7N8@09ob7N8@04o`000?m4^dCo0000o`0000Ko?<<l00?o
0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPWf008omPWf003o`000?oR7N;ohQgR00?ohQgR00?o
0000oo8=l_ob3O802oob3O800ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooi1_T2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o?<<locc3?00:occ3?0Wo00002olQgR400ol0003oA;]4odBkA002odBkA0?o00000_ll`c`0
0ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Wof2OH00?o0000on8Mh_oR7N800_oR7N80
0ol0003olPgboo8=lP0:oo8=lP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000Gon@Ki00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?ll`cco?<<l00Wo?<<l00?o0000obKI9_lVfBH01OlVfBH00ol0003o8MhQob7N8@09ob7N
8@03o`000?m4^dCoA;]400GoA;]40ol00009ohQgR0?o00003OoH9mP01Ol0003ohQgRon8Mh_oR7N;o
000000colPgb00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000Oon@Ki00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?ll`cco?<<l00So?<<l00?o0000obKI9_lVfBH01olVfBH00ol0003o8MhQob7N8@07
ob7N8@03o`000?m4^dCoA;]400SoA;]40ol00002ohQgR0Go00000_o0?l000ol0003of2OHomPWf00<
omPWf003o`000?oR7N;o000000colPgb00?o0000ooX5n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000Son@Ki00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o?<<locc3?008occ3?003o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob7N8OlQgR401olQgR400ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;
00;o00002?o0?l000ol0003of2OHomPWf00<omPWf0Co00002_ob3O800ol0003onPGjooX5nP0:ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooT6n@03o`000?o^4NkokQ7^
00;okQ7^00?o0000olPgb?o8=lP00_o8=lP4o`0000WoW6>L00?o0000occ3??ll`c`02?ll`c`00ol0
003o9]TVobKI9P08obKI9P03o`000?lQgR7o8MhQ00Go8MhQ00?o0000odBkA?m4^d@02?m4^d@01Ol0
003oRgB;oh]dRon;M8_o000000[o`3o00ol0000;omPWf004o`000?og2?Oom`SgooL8m`Co00001Oob
3O800ol0003onPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o^4NkokQ7^00?okQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oW6>LoiaSW007
oiaSW003o`000?ll`cco?<<l00Ko?<<l0_l0000;obKI9P03o`000?lQgR7o8MhQ00Go8MhQ00?o0000
odBkA?m4^d@02?m4^d@00ol0003oRgB;oh]dR`02oh]dR`03o`000?o0?l3o`3o000Oo`3o000?o0000
onXEj_oZ5NX01?l00006omPWf003o`000?og2?Oom`Sg00Kom`Sg0ol00002oo8=lP03o`000?oj1O[o
nPGj00_onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ob3O8olPgb005olPgb003o`000?nLHicoW6>L00OoW6>L00?o0000occ3
??ll`c`00_ll`c`3o`000003oeJYE_l0003o9]TV00[o9]TV00?o0000ob7N8OlQgR401OlQgR400ol0
003oA;]4odBkA007odBkA003o`000?n;M8_oRgB;00?oRgB;00?o0000ol0o`?o0?l001oo0?l000ol0
003ojQGZonXEjP04onXEjP?o00000_oH9mP00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003okQ7^onhAkP04onhAkP03
o`000?o8=lSob3O800Kob3O80_l00007oiaSW003o`000?ll`cco000000;o00001OmFZEH00ol0003o
9]TVobKI9P08obKI9P?o00001?lQgR400ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;00Co
RgB;00?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP07onXEjP;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oc3?<ol`cc003o`0000CoW6>L
0_l00008oeJYEP03o`000?lVfBKo9]TV00Oo9]TV00Co0000odbcC?m</dcoC;=<0ol000000olQgR7o
0000odBkA009odBkA003o`000?n;M8_oRgB;00CoRgB;00?o0000ol0o`?o0?l001Oo0?l000ol0003o
jQGZonXEjP09onXEjP03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP06onhAkP03o`00
0?o8=lSob3O800?ob3O800?o0000ol`cc?o<<l`01?o<<l`2o`000003oiaSW?l0003oEZUF00[oEZUF
00?o0000obKI9_lVfBH01OlVfBH00ol0003oC;=<odbcC005odbcC003o`000?m4^dCoA;]400OoA;]4
0ol00007oh]dR`03o`000?o0?l3o`3o000Co`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009onhAkP05o`000?o8=lSob3O8olPgb?l000002Oo<<l`00ol0003oEZUF
oeJYEP0;oeJYEP03o`000?lVfBKo9]TV00?o9]TV00?o0000odbcC?m</d`01_m</d`00ol0003oA;]4
odBkA006odBkA005o`000?n5NXGoQGZ5ohEjQOl000001on;M8/00ol0003o`3o0ol0o`003ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003ob3O8olPgb?l00009ol`cc0;o00003OmFZEH00ol0003o9]TVobKI9P02obKI9P03
o`000?m</dcoC;=<00SoC;=<00?o0000odBkA?m4^d@00om4^d@2o`0000GoQGZ500?o0000oh]dRon;
M8/01?n;M8/00ol0003o`3o0ol0o`003ol0o`003o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ob3O8o`000009ol`cc004o`000?n[E:_oZeB[o`0000go
EZUF00Co0000obKI9_lVfBKo00003?m</d`01Ol0003oA;]4odBkA?m4^dCo000000SoQGZ50_l00005
oh]dR`03o`000?o0?l3o`3o000;o`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oc3?<ol`cc007ol`cc003o`000?n[E:_oZeB[
00;oZeB[00?o0000oeJYE_mFZEH02_mFZEH00ol0003o9]TVo`00000>odbcC003o`000?m4^dCo0000
00_oQGZ500?o0000oh]dRon;M8/00_n;M8/01Ol0003o`3o0ol0o`?o0?l3o000000cojQGZ00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[
00?oZeB[00?o0000oeJYE_mFZEH02omFZEH00ol0003oC;=<odbcC00>odbcC003o`000?n5NXGoQGZ5
00_oQGZ50_l00003oh]dR`04o`000?o0?l3o`3o0o`0000[ojQGZ0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[00GoZeB[00?o0000oeJY
E_mFZEH01omFZEH3o`00017oC;=<00?o0000ohEjQOn5NXD03On5NXD01Ol0003oRgB;oh]dRol0003o
`3o000Co00000ooZ5NX5o`0000;on`Ck00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?mFZEKoEZUF
00CoEZUF0ol00002of6NH@03o`000?m</dcoC;=<00ooC;=<0_l0000?ohEjQ@04o`000?n;M8_o0000
o`0000Cogb3O0ol00008oo/4n`03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000Ooc3?<00?o0000oj]D
Zon[E:/02?n[E:/00ol0003oEZUFoeJYEP03o`0000KoHIiQ00?o0000odbcC?m</d`03Om</d`01?l0
003oSG:=ohebSOl0000?ohEjQ@03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/02?ok1?/0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o<<lcoc3?<00?oc3?<00?o0000oj]DZon[E:/02_n[E:/2o`0000[oHIiQ00?o0000odbc
C?m</d`02om</d`00ol0003oSG:=ohebS@02ohebS@03o`000?n5NXGoQGZ500_oQGZ50_l00007omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o<<lcoc3?<ol`c
c?l000003On[E:/00ol0003oHIiQof6NH@0:of6NH@03o`000?m</dcoC;=<00WoC;=<00?o0000oheb
SOn=LXd01?n=LXd00ol0003oQGZ5ohEjQ@08ohEjQ@;o000000?o/Djao`000?oO8=l01ooO8=l00ol0
003on`Ckoo/4n`09oo/4n`04o`000?og2?Oo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003oc3?<o`00000=oj]DZ`03o`000?mQWV7oHIiQ
00_oHIiQ00?o0000odbcC?m</d`02?m</d`00ol0003oSG:=ohebS@06ohebS@03o`000?n5NXGoQGZ5
00GoQGZ50_l00003ok5>/@03o`000?oO8=oogb3O00Kogb3O00?o0000oo/4nook1?/02_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000oj]DZon[
E:/03?n[E:/00ol0003oHIiQof6NH@0<of6NH@03o`000?m</dcoC;=<00KoC;=<00?o0000ohebSOn=
LXd02?n=LXd00ol0003oQGZ5ohEjQ@02ohEjQ@;o00001_naC[400ol0003ogb3OomlPg`05omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000coZeB[00?o0000of6NHOmQWV403OmQWV400ol0003oC;=<
odbcC004odbcC003o`000?n=LXgoSG:=00[oSG:=00Co0000ohEjQOl0003o00002?naC[400ol0003o
gb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oB;M;o000000;o00002?n[E:/00ol0003oHIiQ
of6NH@0?of6NH@Ko00003_n=LXd00ol0003o/Djaok5>/@08ok5>/@03o`000?oO8=oogb3O00Kogb3O
00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oB;M;odRgB00?odRgB0ol00005oj]DZ`;o00004?mQWV401_l0003oM8]d
ogB;M?l0003oJiA[o`0000koSG:=00?o0000ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`05omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oB;M;odRgB00KodRgB0ol000001?n[E:_o0000oi1_T?n@Ki03o`00
00coHIiQ00Go0000ogB;M?mdRgCoM8]do`000002of^DJ`03o`000?n=LXgoSG:=00_oSG:=00?o0000
ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Son`Ck0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oB;M800ol0003oT6n@oi1_T004oi1_
T0?o00002?mQWV400ol0003oM8]dogB;M002ogB;M005o`000?m[U6_oJiA[of^DJol000003?n=LXd0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oO8=oogb3O00Gogb3O3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om8]
d_oB;M802_oB;M800ol0003oT6n@oi1_T007oi1_T0;o00001OmQWV400ol0003oM8]dogB;M003ogB;
M003o`000?m[U6_oJiA[00;oJiA[00?o0000ohebSOn=LXd02On=LXd00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om8]d_oB;M802ooB;M800ol0003oT6n@oi1_T009oi1_T0?o000000?oHIiQo`000?md
Rg@01OmdRg@00ol0003oJiA[of^DJ`03of^DJ`03o`000?n=LXgoSG:=00SoSG:=3_l00003omlPg`;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003om@[eo`00000;oo0?l003o`000?oB;M;odRgB00[odRgB
0_l0000>oi1_T003o`000?mdRgCoM8]d00GoM8]d00?o0000of^DJom[U6/00om[U6/00ol0003oSG:=
ohebS@08ohebS@03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omlPgol000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooD:mOoe2_Go00002_o`3o000ol0003odRgBom8]dP09om8]dP03o`000?o0?l3o000000koT6n@
00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJiA[of^DJ`04of^DJ`03o`000?n=LXgoSG:=00KoSG:=
00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D00_oe
2_D00ol0003ol0o`oo0?l006oo0?l003o`000?oB;M;odRgB00SodRgB0_l00003ol0o`003o`000?n@
Ki3oT6n@00_oT6n@00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJiA[of^DJ`05of^DJ`03o`000?n=
LXgoSG:=00GoSG:=00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooD:mOoe2_D00ooe2_D00ol0003ol0o`oo0?l005oo0?l003o`000?oB;M;odRgB00OodRgB00?o0000
ol0o`?o0?l000oo0?l000ol0003oT6n@oi1_T00:oi1_T003o`000?mdRgCoM8]d00KoM8]d00?o0000
of^DJom[U6/01_m[U6/00ol0003oSG:=ohebS@04ohebS@03o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01Ooe2_D00ol0
003ol0o`oo0?l004oo0?l003o`000?oB;M;odRgB00GodRgB0_l00006ol0o`003o`000?n@Ki3oT6n@
00WoT6n@0_l00008ogB;M003o`000?m[U6_oJiA[00KoJiA[1Ol000000on=LXgo0000on4Nh@0?on4N
h@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003o
l0o`oo0?l004o`0000KodRgB00?o0000ol0o`?o0?l001oo0?l000ol0003oT6n@oi1_T005oi1_T0?o
000000?oT6n@o`000?mdRg@01omdRg@00ol0003oJiA[of^DJ`05of^DJ`03o`000?n]DZgo[E:]00?o
[E:]0_l0000?on4Nh@;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo0?l00?o0000ooD:mOoe2_D01ooe2_D2o`0000Coj1OX00Co0000om8]d_oB;M;o
dRgB0_l0000:ol0o`003o`000?n@Ki3oT6n@00;oT6n@0ol00005oi1_T003o`000?mdRgCoM8]d00Go
M8]d00?o0000of^DJom[U6/01?m[U6/00ol0003o[E:]ojeB[@06ojeB[@03o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003om@[eooD:m@08ooD:m@03o`00
0?oX5nSoj1OX00Coj1OX00?o0000om8]d_l000003?o0?l000ol0003oT6n@o`000002o`0000WoT6n@
00?o0000ogB;M?mdRg@01?mdRg@00ol0003oJiA[of^DJ`03of^DJ`03o`000?n]DZgo[E:]00So[E:]
1_l00004on4Nh@;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooD:mOoe2_D01ooe
2_D00ol0003oj1OXonPGj006onPGj003o`000?o0?l3o`3o000co`3o000?o0000oi1_T?n@Ki002_n@
Ki000ol0003oM8]dogB;M004ogB;M004o`000?m[U6_oJiA[of^DJ`;o00002on]DZd00ol0003oiaSW
onLHi`03onLHi`Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003om@[eooD:m@07ooD:m@03o`000?oX
5nSoj1OX00Ooj1OX00?o0000ol0o`?o0?l003?o0?l000ol0003oT6n@oi1_T00;oi1_T003o`000?md
RgCoM8]d00?oM8]d00Co0000of^DJom[U6_o00003On]DZd00ol0003oiaSWonLHi`06onLHi`03o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000ooD:mOoe2_D0
1_oe2_D00ol0003oj1OXonPGj009onPGj003o`000?o0?l3o`3o000Wo`3o00_l0000>oi1_T0?o0000
0omdRg@00ol0003oJiA[o`00000=ojeB[@03o`000?oW6>OoiaSW00OoiaSW00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000Oom@[e00?o
0000onPGj?oX5nP02_oX5nP00ol0003o`3o0ol0o`006ol0o`0;o000000?o`Ck1o`000?n@Ki002on@
Ki02o`0000?oWF:M1Ol0000>ojeB[@03o`000?oW6>OoiaSW00OoiaSW00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`03oo/4n`Co00000_oe2_D00ol0003oj1OXonPGj00;
onPGj003o`000?o0?l3o`3o000?o`3o00ol00004ol4n`@03o`000?n@Ki3oT6n@00OoT6n@0_l00008
oieRW@03o`000?n]DZgo[E:]00go[E:]00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onPGj003o`000?o0?l3o`3o000;o00002?o1?/400ol0
003oT6n@oi1_T005oi1_T003o`000?nMHYgoWF:M00SoWF:M00?o0000ojeB[On]DZd03On]DZd00ol0
003oiaSWonLHi`08onLHi`03o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oX5nSoj1OX00koj1OX0_l0000;ol4n`@03o`000?n@Ki3oT6n@00;oT6n@0_l0000;oieR
W@03o`000?n]DZgo[E:]00go[E:]00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oX5nSoj1OX00goj1OX0_l0000<ol4n`@04o`000?n@Ki3o0000
o`0000goWF:M00?o0000ojeB[On]DZd03?n]DZd00ol0003oiaSWonLHi`09onLHi`03o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oX5nSoj1OX00coj1OX00Co0000on<L
hooS7>?o00003?o1?/400ol0003oWF:MoieRW@0>oieRW@03o`000?n]DZgo[E:]00So[E:]1?l0000;
onLHi`03o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oX5nSoj1OX
00_oj1OX00?o0000on<LhooS7><00_oS7><00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nMHYgoWF:M
00koWF:M00Co0000ojeB[On]DZgo[E:]1ol00003olhacP03o`000?oW6>OoiaSW00WoiaSW00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000onPGj?oX5nP02_oX5nP00ol0
003ohacSon<Lh`03on<Lh`03o`000?o1?/7o`Ck100So`Ck100?o0000oieRWOnMHYd03_nMHYd4o`00
00_ocS7>00?o0000onLHiooW6>L02?oW6>L00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook
1?/03?ok1?/7o`0000Goj1OX00?o0000on<LhooS7><01OoS7><00ol0003o`Ck1ol4n`@07ol4n`@03
o`000?nMHYgoWF:M00koWF:M00?o0000olhac_o><Lh03Oo><Lh00ol0003oiaSWonLHi`08onLHi`03
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?od2oCom0_d00Com0_d
1Ol00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oieRWOnMHYd03_nMHYd00ol0003ocS7>
olhacP0=olhacP03o`000?oW6>OoiaSW00SoiaSW00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=oo/4n`03o`000?od2oCom0_d00Wom0_d
0_l00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oieRWOnMHYd03?nMHYd00ol0003ocS7>
olhacP0?olhacPKo00001?oW6>L4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m0_doo@;m009oo@;m003o`000?o/4nco000000;o00001ooS7><00ol0003o`Ck1ol4n`@05ol4n`@03
o`000?nMHYgoWF:M00SoWF:M1Ol0000AolhacP03o`000?o_4>ooka3_00?oka3_1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000oo@;m?od2o@02_od2o@00ol0003ok1?/on`Ck002on`Ck0?o00001OoS7><00ol0003o`Ck1
ol4n`@04ol4n`@04o`000?nMHYgoWF:MoieRW@Oo00001?o><Lh00ol0003ocS7>olhacP0>olhacP03
o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om0_d
oo@;m00;oo@;m003o`000?o/4ncok1?/00Gok1?/0ol00003on<Lh`04o`000?o1?/7o`Ck1ol4n`@Ko
00003?o><Lh00ol0003ocS7>olhacP0=olhacP03o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?od2o@0
3?od2o@00ol0003ok1?/on`Ck008on`Ck0?o000000CohacSo`000?l0003o00000_oX5nP00ol0003o
cS7>olhacP0=olhacP03o`000?o><LkocS7>00cocS7>00?o0000onl@koo_4>l02?o_4>l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00;on`Ck003o`000?oX5nSoj1OX00?o
j1OX00?o0000olhac_o><Lh03?o><Lh00ol0003of2OHo`00000=olhacP03o`000?o_4>ooka3_00So
ka3_00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00:on`Ck003o`00
0?oX5nSoj1OX00Goj1OX00?o0000olhac_o><Lh02_o><Lh01?l0003of2OHomPWf?oH9mP2o`0000[o
cS7>00?o0000onl@koo_4>l02Oo_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo@;m?od2o@0
3?od2o@00ol0003ok1?/on`Ck009on`Ck003o`000?oX5nSoj1OX00Koj1OX00?o0000olhac_o><Lh0
2Oo><Lh00ol0003of2OHomPWf002omPWf003o`000?oZ5N[o000000;o00001oo><Lh00ol0003oka3_
onl@k`09onl@k`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m00;oo@;m003o`000?o/
4ncok1?/00Sok1?/00?o0000onPGj?oX5nP01ooX5nP00ol0003ocS7>olhacP08olhacP03o`000?oH
9mSof2OH00?of2OH00?o0000onXEj_oZ5NX00_oZ5NX2o`0000CocS7>00?o0000onl@koo_4>l02_o_
4>l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo@;m0Ko00001?o/4n`00ol0003oj1OXonPGj008
onPGj003o`000?o><LkocS7>00OocS7>00?o0000omPWf?oH9mP00ooH9mP00ol0003ojQGZonXEjP05
onXEjP?o000000?ocS7>o`000?o_4>l02oo_4>l00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo@;m003o`000?of2OKomPWf00ComPWf1?l0000<onPGj003o`000?o><LkocS7>
00GocS7>00?o0000omPWf?oH9mP01?oH9mP00ol0003ojQGZonXEjP08onXEjP03o`000?o_4>ooka3_
00_oka3_00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om0_d00?o0000ooH9m_of
2OH02?of2OH00ol0003oj1OXonPGj00:onPGj003o`000?o><LkocS7>00CocS7>00?o0000omPWf?oH
9mP01OoH9mP00ol0003ojQGZonXEjP08onXEjP03o`000?o_4>ooka3_00Woka3_1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooH9mP03o`000?oX5nSoj1OX00Woj1OX
00?o0000olhac_o><Lh00oo><Lh00ol0003of2OHomPWf005omPWf003o`000?oZ5N[ojQGZ00[ojQGZ
00?o0000onl@koo_4>l01?o_4>l4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oX5nSoj1OX00Woj1OX00?o0000olhac_o><Lh00_o>
<Lh00ol0003of2OHomPWf006omPWf003o`000?oZ5N[ojQGZ00[ojQGZ00?o0000onl@koo_4>l01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?of2OKomPWf00[omPWf00?o0000onPGj?oX5nP02OoX5nP01Ol0003ocS7>olha
c_o><Lko000000Wof2OH00?o0000onXEj_oZ5NX02ooZ5NX2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003omPWfooH9mP0;ooH9mP03o`000?oX5nSoj1OX00Woj1OX00?o
0000olhac_l000002OoH9mP00ol0003ojQGZonXEjP0<onXEjP03o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oX5nSo
j1OX00Soj1OX1Ol00008omPWf003o`000?oZ5N[ojQGZ00cojQGZ00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooH9m_of2OH02_of2OH00ol0003oj1OXonPGj007onPG
j003o`000?o]4^gokA;]00?okA;]0ol00005omPWf003o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
mPWf00?o0000onPGj?oX5nP01OoX5nP00ol0003okA;]ondBk@07ondBk@?o000000?of2OHo`000?oZ
5NX03OoZ5NX00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_of2OH00ol0003oj1OXonPGj003onPGj0;o0000
3Oo]4^d2o`0000gojQGZ0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?of2OKomPWf00OomPWf00Co0000onPGj?oX5nSoj1OX
0_l00002ooP7n003o`000?o]4^gokA;]00cokA;]3Ol00003ooT6n@03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooH9mP03o`000?oX5nSo000000Gon0Oh
00?o0000ondBkOo]4^d02oo]4^d00ol0003ol@kaoo4>l@09oo4>l@03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?omPWf0ol0
0007ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oo4>lOoa3_402Ooa3_400ol0003on@KiooT6
n@04ooT6n@;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003okA;]ondB
k@08ondBk@03o`000?oa3_7ol@ka00[ol@ka00?o0000ooT6nOoi1_T01_oi1_T00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o]4^gokA;]00OokA;]00?o
0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@07ooT6n@;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o]4^gokA;]00KokA;]00?o0000oo4>lOoa3_402_oa3_40
0ol0003on@KiooT6n@09ooT6n@05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ondBkOo]4^d01Oo]4^d00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@04ondBk@03o`000?oa3_7ol@ka00Wol@ka00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]
00;okA;]00?o0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000ondBkOo]
4^gokA;]o`00000<oo4>l@03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003okA;]o`000004o`0000Wol@ka00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003oo0?loo`3o003oo`3o0Oo00000_oa3_400ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003oo@;m
o`000002o`0000Son0Oh00?o0000oo`3o?ol0o`02_ol0o`5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003oo@;mood2o@03ood2o@?o00001?oh1oP00ol0003oo0?loo`3
o00=oo`3o003o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?om0_goo@;m00Koo@;m0ol000000ooh1oSo0000oo`3o00>oo`3o003o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`03ool0o`00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool03?l00?l4oooo00So003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l3oooo00Wo003o0_ooo`03o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`?oool01_l00?l2oooo00Go003o00?oool0o`00ool00?l00_l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000_o003o0oooo`05o`00o`;oool01Ol00?l2oooo
00?o003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000co003o0_ooo`04o`00o`;oool01_l00?l2oooo00?o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool03Ol00?l2oooo00?o003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00go003o0_ooo`03o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00So003o1Oooo`000ol00?ooool0oooo0002o`00o`;oool01Ol00?l3oooo00;o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Oo003o0_ooo`04o`00o`?oool00_l00?l3oooo00?o003o
0oooo`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l0
0?l00oooo`3o003ooooo0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000Ko003o0oooo`05o`00o`;oool00_l0
0?l2oooo0003o`00ooooo`3oool000?oool01?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol0
0?l1ooooo`00JOl00?l2oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03
o`00o`?oool01?l00?l4oooo0003o`00ooooo`3o003o00;oool01_l00?l2oooo00Ko003o0_ooo`03
o`00o`03oooo0?l00?oo003o00So003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool0
06Wo003o0_ooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo
00Ko003o0_ooo`03o`00o`;oool02Ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00Co003o00?oool0o`00ool00?l01ol00?l2oooo00Ko003o00?oool0o`00ool0
0?l01Ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool01_l00?l2oooo01So003o
0_ooo`06o`00o`;oool01_l00?l00oooo`3o003oo`00o`03o`00o`;oool02Ol00?l2oooo00Co003o
0_ooo`07o`00o`;oool0Iol00?l1ooooo`00J?l00?l2oooo00Ko003o0_ooo`07o`00o`03oooo0?l0
0?oo003o01Ko003o0_ooo`000olb</co003oo`00o`04o`00o`03oooo0?l00?oo003o00?o003o0_oo
o`06o`00o`;oool02?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?ooo`3oool006Oo003o0Ooo
ool006Oo003o0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`Goool01?l00?l2
oooo00?o003o0_ooo`09o`00o`;oool01ol00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol00?l1
ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo027o003o1?ooo`0<o`00
o`?oool01Ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(970) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.995 .005 .995 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.99 .01 .99 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.978 .022 .978 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.981 .019 .981 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.956 .044 .956 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.987 .013 .987 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.995 .005 .995 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.908 .092 .908 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.971 .029 .971 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.984 .016 .984 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.992 .008 .992 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.958 .042 .958 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.982 .018 .982 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.93 .07 .93 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.981 .019 .981 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.972 .028 .972 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.976 .024 .976 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.923 .077 .923 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.986 .014 .986 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.961 .039 .961 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.934 .066 .934 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.775 .225 .775 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.812 .188 .812 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.995 .005 .995 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.939 .061 .939 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.798 .202 .798 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.759 .241 .759 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.687 .313 .687 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.93 .07 .93 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.957 .043 .957 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.95 .05 .95 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.911 .089 .911 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.995 .005 .995 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.98 .02 .98 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.812 .188 .812 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.694 .306 .694 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.877 .123 .877 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.444 .556 .444 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.438 .562 .438 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.564 .436 .564 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.8 .2 .8 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.825 .175 .825 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.509 .491 .509 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.459 .541 .459 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.964 .036 .964 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.611 .389 .611 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.752 .248 .752 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.925 .075 .925 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.938 .062 .938 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.671 .329 .671 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.889 .111 .889 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.367 .633 .367 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.872 .128 .872 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.756 .244 .756 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.171 .829 .171 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.983 .017 .983 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.282 .718 .282 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.204 .796 .204 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.912 .088 .912 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.986 .014 .986 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.548 .452 .548 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.157 .843 .157 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.235 .765 .235 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.841 .159 .841 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.34 .66 .34 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.567 .433 .567 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.253 .747 .253 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.062 .938 .062 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.381 .619 .381 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.567 .433 .567 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.97 .03 .97 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.619 .381 .619 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.703 .297 .703 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.07 .93 .07 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.013 .987 .013 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.038 .962 .038 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.115 .885 .115 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.151 .849 .151 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.808 .192 .808 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.927 .073 .927 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.953 .047 .953 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.521 .479 .521 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.106 .894 .106 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.846 .154 .846 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.243 .757 .243 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.457 .543 .457 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.148 .852 .148 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.3 .7 .3 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.885 .115 .885 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.419 .581 .419 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.133 .867 .133 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.985 .015 .985 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.919 .081 .919 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.945 .055 .945 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.325 .675 .325 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.979 .021 .979 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.045 .955 .045 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.005 .995 .005 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.678 .322 .678 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.656 .344 .656 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.15 .85 .15 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.269 .731 .269 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.555 .445 .555 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.81 .19 .81 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.152 .848 .152 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.99 .01 .99 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.077 .923 .077 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.24 .76 .24 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.343 .657 .343 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.523 .477 .523 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.501 .499 .501 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.357 .643 .357 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.285 .715 .285 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.934 .066 .934 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.912 .088 .912 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.907 .093 .907 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.236 .764 .236 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.544 .456 .544 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.694 .306 .694 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.881 .119 .881 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.978 .022 .978 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.534 .466 .534 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.752 .248 .752 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.442 .558 .442 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.971 .029 .971 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.952 .048 .952 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.872 .128 .872 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.982 .018 .982 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.549 .451 .549 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.659 .341 .659 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.608 .392 .608 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.916 .084 .916 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.738 .262 .738 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.845 .155 .845 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.694 .306 .694 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.981 .019 .981 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.965 .035 .965 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.814 .186 .814 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.973 .027 .973 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.776 .224 .776 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.792 .208 .792 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.893 .107 .893 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.887 .113 .887 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.967 .033 .967 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.847 .153 .847 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.968 .032 .968 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.948 .052 .948 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.937 .063 .937 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.898 .102 .898 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.906 .094 .906 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.871 .129 .871 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.951 .049 .951 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.984 .016 .984 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.972 .028 .972 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.979 .021 .979 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.989 .011 .989 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.976 .024 .976 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.919 .081 .919 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.971 .029 .971 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.98 .02 .98 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.988 .012 .988 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.996 .004 .996 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.978 .022 .978 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.982 .018 .982 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.988 .012 .988 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooP7n0;o00003?om0_d2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003ol`cc
oo<<looc3?<5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oh1oSon0Oh00Gon0Oh0_l00008ood2o@;o00000_oi1_T00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003ol`ccoo<<l`07oo<<l`Ko00000_oo0?l4o`0000goo@;m00?o0000ooP7n?oh1oP0
1ooh1oP2o`0000Goo@;m00?o0000ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003ol`ccoo<<l`0<oo<<l`?o00001?oj1OX3o`0000Woo@;m00?o
0000ooP7n?oh1oP02_oh1oP2o`000003ood2oOl0003o000000Oon@Ki00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oh1oSon0Oh00gon0Oh00?o0000ooT6nOoi1_T02?oi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oh1oP03ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo`3o00>oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on0OhooP7n00?ooP7n003o`000?oi1_Won@Ki00[on@Ki2ol0000;ood2o@Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ol0ocoo0?l00coo0?l00?o0000oo<<looc3?<03Ooc3?<00ol0
003onPGjooX5nP0=ooX5nP;o00004?oh1oP00ol0003on@KiooT6n@0:ooT6n@03o`000?og2?Oom`Sg
00Oom`Sg00?o0000ood2oOom0_d00_om0_d7o`0000Con@Ki00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[onPGj
00gonPGj00Co0000onTFjOoY5^Wo00003ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?og2?Oo
m`Sg00Wom`Sg1?l0000;ooT6n@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000oo0?l?l0003o00002Ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oj1O[o
nPGj00gonPGj00Go0000onTFjOoY5^WojAKYo`00000=ooP7n003o`000?oi1_Won@Ki00[on@Ki00?o
0000ooL8moog2?L02Oog2?L00ol0003on@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o`3o3ol0o`00;ol0o`0_l00007oo`3o003o`000?oc3??o
l`cc00col`cc00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@03onTFj@03o`000?oh1oSo
n0Oh00[on0Oh00?o0000ooT6nOoi1_T02_oi1_T00ol0003om`SgooL8m`09ooL8m`03o`000?oi1_Wo
n@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?
l?o`3o001Oo`3o000ol0003oo0?loo`3o003oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@04onTFj@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003om`SgooL8m`0:ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?l?o`3o001_o`3o02o`0000?o
o0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003onPGjooX5nP0<ooX5nP03o`000?oY5^WojAKY00Ko
jAKY00?o0000ooP7n?oh1oP02?oh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?og2?Oom`Sg00[o
m`Sg00?o0000ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o`3o3ol0o`00Wol0o`0_l000000ool0oco0000oo<<l`0<oo<<l`?o00003_oj1OX00ol0003ojAKY
onTFj@07onTFj@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T02Ooi1_T00ol0003om`Sg
ooL8m`0;ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o`3o3ol0o`00_ol0o`00?o0000oo<<looc3?<02_oc3?<2o`0000?ohQgR00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ojAKYonTFj@09onTFj@03o`000?oh1oSon0Oh00Kon0Oh00?o
0000ooT6nOoi1_T02?oi1_T00ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003ol0o`oo0?l00<oo0?l003o`000?oc3??ol`cc00Sol`cc0_l00006on8MhP;o00002_oj1OX0
0ol0003ojAKYonTFj@0:onTFj@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003_o`3o000ol0003ol`ccoo<<l`04
oo<<l`?o00002_oR7N800ol0003onPGjooX5nP07ooX5nP03o`000?oY5^WojAKY00_ojAKY00?o0000
ooP7n?oh1oP00ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?og2?Oom`Sg00com`Sg00?o0000
ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003oo`3o001?l0
003ol`ccoo<<looc3?<2o`0000kohQgR0_l00006ooX5nP03o`000?oY5^WojAKY00gojAKY00?o0000
ooP7n?oh1oP00_oh1oP00ol0003on@KiooT6n@08ooT6n@03o`000?og2?Oom`Sg00com`Sg0ol0000=
ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00@oo0?l0Co00004_oR7N800ol0
003onPGjooX5nP03ooX5nP03o`000?oY5^WojAKY00kojAKY00Go0000ooP7n?oh1oSon0Oho`000005
ooT6n@Oo00003?og2?L01Ol0003ol`ccoo<<looc3??o000000con@Ki00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00=
oo0?l0?o000000Cogb3Oo`000?l0003o00004ooR7N82o`0000;onPGj00?o0000onTFjOoY5^T04?oY
5^T00ol0003on0Oho`000006o`0000Ooi1_T00?o0000ooL8moog2?L02?og2?L00ol0003ol`ccoo<<
l`03oo<<l`;o00002?oi1_T3o`0000Koo@;m1?l00002oo`3o003o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oh1oP3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003ol0o`oo0?
l00;oo0?l0?o00000ooO8=l01Ol0003oebSGo`000?ncC;?o000001CohQgR00?o0000ooX5n_l00000
4ooY5^T00ol0003oi1_Ton@Ki00=on@Ki003o`000?og2?Oom`Sg00Gom`Sg0_l00008oo<<l`03o`00
0?oi1_Won@Ki00Go00000ooh1oP00ol0003oo@;mood2o@03o`0000Ooo0?l00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con0Oh0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000oo0?l?o`3o002Oo`3o03o`0000Gogb3O00Co0000omLXeooG:=Oo00000_ncC;<00ol0003o
hQgRon8MhP0Bon8MhP03o`000?oY5^WojAKY01;ojAKY00?o0000on@Ki?oT6n@03_oT6n@00ol0003o
m`SgooL8m`03ooL8m`03o`000?oc3??ol`cc00Wol`cc0_l00009ooP7n0;o00002_ol0o`00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooP7n0;o00001oom0_d5o`0000;o
nPGj00?o0000oo0?l?o`3o001_o`3o03o`0000Sogb3O00Co0000omLXeooG:=Oo00000oncC;<00ol0
003ohQgRon8MhP0Aon8MhP03o`000?oY5^WojAKY017ojAKY00?o0000on@Ki?oT6n@04?oT6n@01Ol0
003om`SgooL8moog2?Oo000000col`cc00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo0?loo`3o00:
oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooP7n?oh1oP01ooh1oP3o`00
0004ood2oOl0003o0000o`0000Gol`cc0_l00006oo0?l0?o00002_oO8=l01Ol0003oebSGomLXeooG
:=Oo000000Co/dbc00?o0000on8Mh_oR7N804?oR7N800ol0003ojAKYonTFj@0AonTFj@03o`000?oT
6nCoi1_T017oi1_T00?o0000ooL8mol000003Ooc3?<00ol0003on0OhooP7n008ooP7n003o`000?ol
0ocoo0?l00[oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP02_oh1oP00ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00?o00003OoO8=l0
1Ol0003oebSGomLXeooG:=Oo000000Go/dbc00?o0000on8Mh_oR7N803ooR7N800ol0003ojAKYonTF
j@0AonTFj@03o`000?oT6nCoi1_T01;oi1_T00?o0000oo<<looc3?<03?oc3?<00ol0003on0OhooP7
n008ooP7n003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?oc3??ol`cc00Wol`cc0_l0000?omlPg`03o`000?oG:=Oo
ebSG00;oebSG00?o0000ok=</oncC;<01?ncC;<00ol0003ohQgRon8MhP0=on8MhP?o00004OoY5^T0
0ol0003oi1_Ton@Ki00Con@Ki003o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on0OhooP7n00:ooP7n003o`000?oc3??ol`cc00Wol`cc00?o0000omlPgooO8=l03OoO8=l0
0ol0003oebSGomLXe`03omLXe`03o`000?ncC;?o/dbc00Go/dbc00?o0000on8Mh_oR7N802_oR7N82
o`0000?oYeRW00?o0000onTFjOoY5^T03_oY5^T00ol0003oi1_Ton@Ki00Con@Ki003o`000?oc3??o
l`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on0Oh00?o0000oo<<
looc3?<02ooc3?<00ol0003ogb3OomlPg`0<omlPg`03o`000?oG:=OoebSG00?oebSG00?o0000ok=<
/oncC;<01_ncC;<00ol0003ohQgRon8MhP07on8MhP;o00001_nWF:L2o`0000kojAKY00?o0000on@K
i?oT6n@04ooT6n@00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3
o?ol0o`03?ol0o`00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on0Oh00?o0000oo<<looc3?<02ooc3?<00ol0003ogb3OomlPg`0;omlP
g`03o`000?oG:=OoebSG00CoebSG00?o0000ok=</oncC;<01oncC;<00ol0003ohQgRon8MhP05on8M
hP03o`000?nWF:OoYeRW00SoYeRW00?o0000onTFjOoY5^T02_oY5^T00ol0003oi1_Ton@Ki00Don@K
i003o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo0?loo`3o00<oo`3
o003o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on0Oh00?o0000oo<<looc3?<02ooc3?<00ol0003ogb3OomlPg`0;omlPg`03o`000?oG:=OoebSG
00CoebSG00?o0000ok=</oncC;<02?ncC;<00ol0003ohQgRon8MhP02on8MhP;o00003?nWF:L2o`00
00[ojAKY00?o0000on@Ki?oT6n@05?oT6n@00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh
00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oO8=oogb3O00Wogb3O00?o0000omLXeooG:=L01OoG:=L00ol0003o/dbcok=</`09ok=</`04
o`000?oR7N;o0000o`00013oYeRW0_l00008onTFj@03o`000?oT6nCoi1_T01Coi1_T0ol0000;oo<<
l`03o`000?oh1oSon0Oh00Won0Oh00?o0000oo`3o?ol0o`03Ool0o`01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooP7
n?oh1oP02?oh1oP00ol0003ol`ccoo<<l`0;oo<<l`;o00002_oO8=l00ol0003oebSGomLXe`06omLX
e`03o`000?ncC;?o/dbc00[o/dbc00?o0000ojMHYonWF:L04_nWF:L00ol0003ojAKYonTFj@04onTF
j@03o`000?oT6nCoi1_T01Goi1_T00?o0000omhQg_oN8Mh01Ol00005oo<<l`03o`000?oh1oSon0Oh
00[on0Oh00?o0000oo`3o?ol0o`03_ol0o`3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooP7n?oh1oP01ooh1oP00ol0003ol`ccoo<<l`0;oo<<l`04
o`000?o?<<oocc3?o`0000Wogb3O00?o0000omLXeooG:=L01_oG:=L00ol0003o/dbcok=</`0:ok=<
/`03o`000?nWF:OoYeRW01?oYeRW0_l00003onTFj@Co00005?oT6n@00ol0003ogR7NomhQgP06omhQ
gPCo000000?ol`cco`000?oh1oP02ooh1oP00ol0003oo0?loo`3o00>oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP01ooh1oP00ol0003ol`ccoo<<l`09oo<<l`;o00001?o?<<l00ol0003ogb3OomlPg`05omlPg`03
o`000?oG:=OoebSG00OoebSG00?o0000ok=</oncC;<02_ncC;<00ol0003oYeRWojMHY`0EojMHY`03
o`000?oY5^Wo000000Co_4>l0ol0000@on@Ki003o`000?oN8MkogR7N00_ogR7N0_l0000<ooP7n003
o`000?ol0ocoo0?l00coo0?l0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000oo<<looc3?<02?oc3?<00ol0003occ3?
oll`c`05oll`c`03o`000?oO8=oogb3O00Cogb3O00?o0000omLXeooG:=L01ooG:=L00ol0003o/dbc
ok=</`0:ok=</`03o`000?nWF:OoYeRW01KoYeRW00?o0000oka3_?nl@k`01_nl@k`3o`0000coi1_T
00?o0000omhQg_oN8Mh03OoN8Mh00ol0003on0OhooP7n009ooP7n0Go00002Ool0o`2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ol`ccoo<<l`07oo<<l`03o`000?o?<<oocc3?00Oocc3?00?o0000omlPgooO8=l00_oO
8=l00ol0003oebSGomLXe`08omLXe`03o`000?ncC;?o/dbc00Wo/dbc00?o0000ojMHYonWF:L05onW
F:L00ol0003o_4>loka3_009oka3_0?o00002OoT6n@00ol0003ogR7NomhQgP0>omhQgPKo00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_ol0o`2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on0OhooP7n006ooP7n003o`000?oc
3??ol`cc00Gol`cc0_l0000;oll`c`04o`000?oO8=oogb3Oo`0000_oebSG00?o0000ok=</oncC;<0
2OncC;<00ol0003oYeRWojMHY`0FojMHY`03o`000?nl@kco_4>l00go_4>l0ol00005on@Ki003o`00
0?oN8MkogR7N00oogR7N00?o0000on/Djoo[5>/00oo[5>/4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oh1oP00ol0003ol`ccoo<<
l`05oo<<l`03o`000?o?<<oocc3?00cocc3?00?o0000omlPgol000002ooG:=L00ol0003o/dbcok=<
/`07ok=</`?o00006?nWF:L00ol0003o_4>loka3_00@oka3_0?o000000?oi1_To`000?oN8Mh04?oN
8Mh00ol0003ojaC[on/Dj`07on/Dj`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooP7n003o`000?oc3??ol`cc00?ol`cc0_l0000@oll`c`03o`000?oG:=OoebSG00[oebSG00?o0000
ok=</oncC;<00oncC;<4o`0000;oQGZ500?o0000ojMHYonWF:L05OnWF:L00ol0003o_4>loka3_00D
oka3_003o`000?oN8MkogR7N013ogR7N00?o0000on/Djoo[5>/01oo[5>/00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?ol`cc00?o0000oll`coo?<<l04?o?<<l00ol0
003oebSGomLXe`0:omLXe`03o`000?ncC;?o000000?o00001on5NXD00ol0003oYeRWojMHY`0DojMH
Y`03o`000?nl@kco_4>l01Co_4>l00?o0000omhQg_oN8Mh03ooN8Mh00ol0003ojaC[on/Dj`08on/D
j`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00?o
k1?/00?o0000oo<<lol000004oo?<<l4o`0000WoebSG0_l0000<ohEjQ@03o`000?nWF:OoYeRW01?o
YeRW00?o0000oka3_?nl@k`05Onl@k`00ol0003ogR7NomhQgP0>omhQgP03o`000?o[5>_ojaC[00So
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ok1?/on`Ck005on`Ck003o`00
0?o?<<oocc3?01;occ3?00Co0000ohacS?n<LhcoS7><1Ol00003omLXe`03o`000?n5NXGoQGZ500go
QGZ50ol0000@ojMHY`;o00006?nl@k`00ol0003ogR7NomhQgP0=omhQgP03o`000?o[5>_ojaC[00Wo
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`00
0?o?<<oocc3?017occ3?00?o0000ohacS?n<Lh`01on<Lh`3o`00013oQGZ500?o0000oe>/DomC[5<0
1Ol00009ojMHY`;o000000?oP7n0o`000?nl@k`05onl@k`00ol0003ogR7NomhQgP0=omhQgP03o`00
0?o[5>_ojaC[00WojaC[00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000oll`coo?<<l03oo?<<l00ol0003oS7><ohac
S00:ohacS003o`000?n5NXGoQGZ500goQGZ500?o0000oe>/DomC[5<01_mC[5<4o`0000CoYeRW00?o
0000oh1oP?n0Oh000_n0Oh000ol0003o_4>loka3_00Foka3_003o`000?oN8MkogR7N00_ogR7N00?o
0000on/Djoo[5>/02oo[5>/00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ok1?/00?o0000oll`coo?<<l03oo?<<l00ol0003oS7><ohacS00;ohacS003o`000?n5NXGo
QGZ500coQGZ500?o0000oe>/DomC[5<02_mC[5<4o`0000GoP7n000?o0000oka3_?nl@k`05_nl@k`0
0ol0003ogR7NomhQgP0:omhQgP03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000on`C
k?o/4n`02Oo/4n`00ol0003occ3?oll`c`0=oll`c`03o`000?n<LhcoS7><00coS7><00?o0000ohEj
QOn5NXD03?n5NXD00ol0003oDjaCoe>/D`0;oe>/D`03o`000?mGZ5Oo000000KoP7n000?o0000oka3
_?nl@k`05_nl@k`00ol0003ogR7NomhQgP09omhQgP03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000oll`coo?<<l02?o?<<l4o`0000oo
S7><00?o0000ohEjQOn5NXD02on5NXD00ol0003oDjaCoe>/D`0;oe>/D`04o`000?mGZ5OoEjQGo`00
00OoP7n000?o0000oka3_?nl@k`05Onl@k`00ol0003ogR7NomhQgP08omhQgP03o`000?o[5>_ojaC[
00gojaC[00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000oll`coo?
<<l00oo?<<l5o`0000?oT6n@00?o0000ohacS?n<Lh`03_n<Lh`00ol0003oQGZ5ohEjQ@0:ohEjQ@03
o`000?mC[5?oDjaC00[oDjaC00Go0000oeNXEomGZ5OoEjQGo`000007oh1oP003o`000?nl@kco_4>l
01Go_4>l00?o0000omhQg_oN8Mh02?oN8Mh00ol0003ojaC[on/Dj`0=on/Dj`03o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00<on`Ck0Go00002On@Ki000ol0003o
S7><ohacS00<ohacS0;o00003?n5NXD00ol0003oDjaCoe>/D`0:oe>/D`05o`000?mGZ5OoEjQGoeNX
Eol000002?n0Oh000ol0003o_4>loka3_00Doka3_0?o00001ooN8Mh00ol0003ojaC[on/Dj`0>on/D
j`03o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000on`Ck?o/4n`03?o/4n`01?l0003oc3?<ol`cc?l0000;oi1_T003o`000?n<LhcoS7><
00_oS7><00Co0000od2o@?m0_d3o00002_n5NXD00ol0003oDjaCoe>/D`0:oe>/D`03o`000?mGZ5Oo
EjQG00;oEjQG00?o0000oh1oP?n0Oh001_n0Oh000ol0003o_4>loka3_00Aoka3_0?o00000oo6>LH0
0ol0003ogR7NomhQgP04omhQgP03o`000?o[5>_ojaC[00gojaC[1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000ol`cc?o<<l`00_o<<l`0
0ol0003oT6n@oi1_T008oi1_T003o`000?n<LhcoS7><00[oS7><00?o0000od2o@?m0_d000_m0_d00
0ol0003oQGZ5ohEjQ@03ohEjQ@Go00002omC[5<00ol0003oEjQGoeNXE`03oeNXE`03o`000?n0Oh3o
P7n000OoP7n000?o0000oka3_?nl@k`03_nl@k`2o`0000OoaSW600?o0000omhQg_oN8Mh00_oN8Mh0
0ol0003ojaC[on/Dj`0=on/Dj`03o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol`c
c?o<<l`00oo<<l`00ol0003oT6n@oi1_T009oi1_T003o`000?n<LhcoS7><00SoS7><00?o0000od2o
@?m0_d001?m0_d05o`0000Co?/4n00?o0000oe>/DomC[5<02OmC[5<00ol0003oEjQGoeNXE`03oeNX
E`03o`000?n0Oh3oP7n000SoP7n000?o0000oka3_?nl@k`02_nl@k`3o`0000[oaSW600Go0000omhQ
g_oN8MkogR7No`00000>on/Dj`03o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol`c
c?o<<l`01?o<<l`00ol0003oT6n@oi1_T009oi1_T003o`000?n<LhcoS7><00OoS7><00?o0000od2o
@?m0_d001Om0_d000ol0003o?/4nock1?P07ock1?P03o`000?mC[5?oDjaC00OoDjaC00?o0000oeNX
EomGZ5L01?mGZ5L00ol0003oP7n0oh1oP008oh1oP003o`000?nl@kco_4>l00So_4>l0_l0000>olHi
aPCo00003?o[5>/2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003ok1?/on`Ck009on`Ck003o`000?o<<lcoc3?<00Koc3?<00?o0000oi1_T?n@Ki002On@Ki000ol0
003oS7><ohacS005ohacS003o`000?m0_d3o@;m000Ko@;m000?o0000ock1?_ln`Ch02?ln`Ch00ol0
003oDjaCoe>/D`06oe>/D`03o`000?mGZ5OoEjQG00CoEjQG00?o0000oh1oP?n0Oh002On0Oh04o`00
00?o_4>l0ol0000@olHiaP05o`000?oW6>OoiaSWonLHiol000002_o[5>/00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[ok1?/00?o0000ol`cc?o<<l`01oo<<l`0
0ol0003oT6n@oi1_T009oi1_T003o`000?n<LhcoS7><00CoS7><00?o0000od2o@?m0_d001om0_d00
0ol0003o?/4nock1?P08ock1?P;o00001_mC[5<00ol0003oEjQGoeNXE`05oeNXE`03o`000?n0Oh3o
P7n000WoP7n000Co0000oi]TVonKI9_oVfBK0ol0000BolHiaP03o`000?oW6>OoiaSW00?oiaSW0_l0
0006on/Dj`;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o/4n`00ol0003oc3?<ol`cc008ol`cc003o`000?n@Ki3o
T6n@00[oT6n@00?o0000ohacS?n<Lh`00_n<Lh`00ol0003o@;m0od2o@008od2o@003o`000?ln`Cko
?/4n00Ko?/4n0_l00002obGJ9@03o`000?mC[5?oDjaC00;oDjaC00?o0000oeNXEomGZ5L01_mGZ5L0
0ol0003oP7n0oh1oP008oh1oP003o`000?nKI9_oVfBK00CoVfBK00?o0000olHia_o6>LH03oo6>LH0
0ol0003oiaSWonLHi`06onLHi`;o00000oo[5>/00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003oc3?<ol`cc00:ol`cc003o`000?n@Ki3oT6n@
00WoT6n@00Go0000ohacS?n<LhcoS7><o`00000;od2o@003o`000?ln`Cko?/4n00Co?/4n0_l00005
obGJ9@05o`000?mC[5?oDjaCoe>/Dol000002?mGZ5L00ol0003oP7n0oh1oP008oh1oP003o`000?nK
I9_oVfBK00GoVfBK00?o0000olHia_o6>LH03_o6>LH00ol0003oiaSWonLHi`08onLHi`03o`000?o[
5>_o000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oc3?<
ol`cc00;ol`cc003o`000?n@Ki3oT6n@00WoT6n@00Co0000ohacS?n<Lhco00003?m0_d000ol0003o
?/4nock1?P02ock1?P;o00002?lUfRD00ol0003oDjaCo`000009oeNXE`03o`000?n0Oh3oP7n000So
P7n000?o0000oi]TVonKI9/01OnKI9/00ol0003oaSW6olHiaP0=olHiaP03o`000?oW6>OoiaSW00[o
iaSW00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o/4ncok1?/00Cok1?/00?o0000ol`cc?o<<l`03?o<<l`00ol0003oT6n@oi1_T00:oi1_T0?o0000
3?m0_d000ol0003o?/4nock1?P02o`0000_o9MXU00?o0000oeNXEomGZ5L02?mGZ5L00ol0003oP7n0
oh1oP007oh1oP003o`000?nKI9_oVfBK00OoVfBK00?o0000olHia_o6>LH03?o6>LH00ol0003oiaSW
onLHi`0;onLHi`;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo/
4n`00ol0003oc3?<ol`cc00>ol`cc003o`000?n@Ki3oT6n@00SoT6n@00Co0000odRgB?m8]dSoB;M8
0_l0000:od2o@0?o00003OlUfRD00ol0003oEjQGoeNXE`08oeNXE`03o`000?n0Oh3oP7n000OoP7n0
00?o0000oi]TVonKI9/01onKI9/00ol0003oaSW6olHiaP0;olHiaP03o`000?oW6>OoiaSW00coiaSW
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003oo@;m003o`000?o/4nco0000017oc3?<00?o0000oi1_T?n@Ki001on@Ki000ol0003oB;M8odRg
B004odRgB0;o00002?m0_d000ol0003o9MXUobGJ9@0>obGJ9@;o00002?mGZ5L00ol0003oP7n0oh1o
P006oh1oP003o`000?nKI9_oVfBK00WoVfBK00?o0000olHia_o6>LH02Oo6>LH00ol0003oiaSWonLH
i`0=onLHi`03o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006oo@;m003o`000?o<<lcoc3?<013oc3?<00?o0000oi1_T?n@Ki001_n@Ki00
0ol0003oB;M8odRgB007odRgB003o`000?m0_d3o@;m000Co@;m00ol0000>obGJ9@03o`000?lVfBKo
9]TV00?o00001OmGZ5L00ol0003oP7n0oh1oP006oh1oP003o`000?nKI9_oVfBK00[oVfBK00?o0000
olHia_o6>LH02?o6>LH00ol0003oiaSWonLHi`0=onLHi`03o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008oo@;m003o`000?o<<lcoc3?<
017oc3?<00Co0000oi1_T?n@Ki3oT6n@1?l0000;odRgB0;o000000Co@;m0o`000?l0003o00000olA
kQ42o`0000_o9MXU00?o0000obKI9_lVfBH01?lVfBH2o`0000?oEjQG00?o0000oh1oP?n0Oh001_n0
Oh000ol0003oVfBKoi]TV`0:oi]TV`03o`000?o6>LKoaSW600OoaSW600?o0000onLHiooW6>L03_oW
6>L00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<oo@;m003o`000?o<<lco
c3?<013oc3?<1?l00003oh9mPP03o`000?m8]dSoB;M800_oB;M800?o0000oa7^4OlAkQ401_lAkQ40
0ol0003o9MXUobGJ9@07obGJ9@03o`000?lVfBKo9]TV00Oo9]TV3?l0000>oi]TV`03o`000?o6>LKo
aSW600KoaSW600?o0000onLHiooW6>L03_oW6>L00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_od2o@00ol0003oc3?<ol`cc00?ol`cc003o`000?n2OH;oPWf200KoPWf200?o0000
odRgB?m8]dP02_m8]dP00ol0003o4NhAoa7^4@07oa7^4@;o00001_lUfRD00ol0003o9]TVobKI9P08
obKI9P03o`000?mKY5_oFjAK00SoFjAK00?o0000oi]TVonKI9/03?nKI9/00ol0003oaSW6olHiaP05
olHiaP03o`000?oW6>OoiaSW00ooiaSW0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03_od2o@00ol0
003oc3?<ol`cc00>ol`cc003o`000?n2OH;oPWf200OoPWf200?o0000odRgB?m8]dP02_m8]dP00ol0
003o4NhAoa7^4@09oa7^4@;o00000olUfRD00ol0003o9]TVobKI9P09obKI9P03o`000?mKY5_oFjAK
00WoFjAK00?o0000oi]TVonKI9/02_nKI9/4o`0000CoaSW600?o0000onLHiooW6>L04?oW6>L01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03ood2o@@o`0000[oPWf200?o0000odRg
B?m8]dP02Om8]dP00ol0003o3o0?o`00000<oa7^4@05o`000?lUfRGo0000o`_d2ol000002_lVfBH0
0ol0003oFjAKoe^TF`09oe^TF`03o`000?nKI9_oVfBK00OoVfBK0ol00004ok5>/@?o000000?oaSW6
o`000?oW6>L04OoW6>L01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00?
oo@;m003o`000?o2?L;o`Sg200co`Sg200?o0000oh9mP_n2OH802On2OH800ol0003oB;M8odRgB007
odRgB004o`000?l?l0oo3o0?o`0000go4NhA00Go0000o`_d2ol;m0_o2o@;o`000009obKI9P03o`00
0?mKY5_oFjAK00[oFjAK00?o0000oi]TVonKI9/00onKI9/3o`0000[o/Dja00?o0000onLHiooW6>L0
4?oW6>L00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo@;m?od2o@03ood2o@00ol0003o`Sg2ol8m`P0<ol8m`P03o`000?n2
OH;oPWf200WoPWf200?o0000odRgB?m8]dP01_m8]dP00ol0003o3o0?o`o`3`02o`o`3`03o`000?lA
kQ7o4NhA00[o4NhA00?o0000o`_d2ol;m0/00_l;m0/00ol0003o9]TVobKI9P06obKI9P03o`000?mK
Y5_oFjAK00[oFjAK00?o0000oi]TVonKI9/00ol0000=ok5>/@03o`000?oW6>OoiaSW013oiaSW00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00=oo@;m0?o00003oo2?L80
0ol0003oPWf2oh9mPP08oh9mPP03o`000?m8]dSoB;M800GoB;M800?o0000o`o`3ol?l0l00ol?l0l0
0ol0003o4NhAoa7^4@0:oa7^4@03o`000?l;m0_o2o@;00?o2o@;00?o0000obKI9_lVfBH01OlVfBH0
0ol0003oFjAKoe^TF`0;oe^TF`;o00004OnaC[400ol0003oiaSWonLHi`0?onLHi`03o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_doo@;m009oo@;m0Go00000_oX5nP00ol0
003o`Sg2ol8m`P0=ol8m`P03o`000?n2OH;oPWf200WoPWf200?o0000odRgB?m8]dP01?m8]dP00ol0
003o3o0?o`o`3`04o`o`3`03o`000?lAkQ7o4NhA00So4NhA00?o0000o`_d2ol;m0/01Ol;m0/00ol0
003o9]TVobKI9P04obKI9P03o`000?mKY5_oFjAK00_oFjAK00?o0000ok5>/OnaC[404?naC[400ol0
003oiaSWonLHi`0?onLHi`03o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?od2oCom0_d00Com0_d1Ol00007onPGj003
o`000?o2?L;o`Sg200go`Sg200?o0000oh9mP_n2OH802On2OH800ol0003oB;M8odRgB003odRgB003
o`000?l?l0oo3o0?00Go3o0?00?o0000oa7^4OlAkQ402?lAkQ400ol0003o2o@;o`_d2`06o`_d2`03
o`000?lVfBKo9]TV00?o9]TV00?o0000oe^TFomKY5/02omKY5/00ol0003o/Djaok5>/@0@ok5>/@03
o`000?oW6>OoiaSW00ooiaSW00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?l00000
1?l0000<onPGj003o`000?o2?L;o`Sg200ko`Sg200?o0000oh9mP_n2OH802?n2OH800ol0003oB;M8
odRgB002odRgB003o`000?l?l0oo3o0?00Oo3o0?00?o0000oa7^4OlAkQ401olAkQ400ol0003o2o@;
o`_d2`07o`_d2`03o`000?lVfBKo9]TV00;o9]TV00?o0000oe^TFomKY5/02omKY5/00ol0003o/Dja
ok5>/@0Aok5>/@03o`000?oW6>OoiaSW00goiaSW00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oj1OX00?o0000ol8m`_o2?L803_o2
?L800ol0003oPWf2oh9mPP09oh9mPP04o`000?m8]dSoB;M8o`0000[o3o0?00?o0000oa7^4OlAkQ40
1olAkQ400ol0003o2o@;o`_d2`08o`_d2`05o`000?lVfBKo9]TVobKI9_l000003OmKY5/00ol0003o
/Djaok5>/@0Aok5>/@?o00003OoW6>L00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;on`Ck00?o0000onPGj?oX5nP03ooX5nP00ol0003o
`Sg2ol8m`P0>ol8m`P03o`000?n2OH;oPWf200SoPWf21Ol0000;o`o`3`03o`000?lAkQ7o4NhA00Ko
4NhA00?o0000o`_d2ol;m0/02Ol;m0/01?l0003o9]TVobKI9_l0000=oe^TF`03o`000?naC[7o/Dja
017o/Dja00?o0000omPWf?oH9mP00ol0000:onLHi`Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005oo/4n`03o`000?oX5nSoj1OX00koj1OX00?o0000ol8m
`_o2?L803_o2?L800ol0003oPWf2oh9mPP07oh9mPP03o`000?l[e2_o:m@[00?o:m@[00?o0000o`o`
3ol?l0l02?l?l0l00ol0003o4NhAoa7^4@05oa7^4@03o`000?l;m0_o2o@;00[o2o@;1Ol0000<oe^T
F`03o`000?naC[7o/Dja013o/Dja00?o0000omPWf?oH9mP01?oH9mP3o`0000KoiaSW00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000oo/4nook1?/01?ok1?/00ol0003oj1OXonPGj00=onPGj003o`000?o2?L;o`Sg200oo
`Sg200?o0000oh9mP_n2OH801?n2OH82o`0000Oo:m@[00?o0000o`o`3ol?l0l01ol?l0lEo`0000Go
9]TV00?o0000oe^TFomKY5/02?mKY5/3o`00013o/Dja00?o0000omPWf?oH9mP02?oH9mP3o`0000;o
iaSW00?o0000ooX5n_oj1OX02?oj1OX5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oj1OXonPGj00;onPGj0Co0000
3oo2?L800ol0003oPWf2oh9mPP03oh9mPP03o`000?l[e2_o:m@[00So:m@[00?o0000o`o`3ol?l0l0
1?l?l0l2o`0000So0o`300?o0000o`7n0Ol1oP402?l1oP400ol0003o9]TVobKI9P05obKI9P;o0000
1_mKY5/2o`0000?oLHia00?o0000ok5>/OnaC[403?naC[400ol0003of2OHomPWf00<omPWf0;o0000
4?oj1OX3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o
0000onPGj?oX5nP02OoX5nP00ol0003okQ7^o`000002olHiaP?o00003?o2?L801?l0003oPWf2oh9m
P_n2OH82o`0000co:m@[00?o0000o`o`3ol?l0l00_l?l0l00ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l1oP7o0Oh100So0Oh100?o0000obKI9_lVfBH01olVfBH00ol0003oFjAKoe^TF`02oe^TF`03o`00
0?maSW7oLHia00CoLHia0_l0000;ok5>/@03o`000?oH9mSof2OH00cof2OH00?o0000onl@kol00000
4_oj1OX00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o
0000onPGj?oX5nP01_oX5nP2o`0000;okQ7^00?o0000olHia_o6>LH00oo6>LH3o`0000[o`Sg200?o
0000oh9mP_l000003ol[e2/01?l0003o3o0?o`000?l0000;o`?l0`03o`000?l1oP7o0Oh100So0Oh1
00?o0000obKI9_lVfBH02?lVfBH01?l0003oFjAKo`000?l00009og6>L@03o`000?naC[7o/Dja00Oo
/Dja00?o0000omPWf?oH9mP03?oH9mP01?l0003oka3_onl@kol0000CooX5nP03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oX5nSoj1OX00Co
j1OX00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oaSW6olHiaP05olHiaP?o00001_o2?L84o`00013o
:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV00Wo
9]TV00?o0000og6>LOmaSW402_maSW42o`0000Ko/Dja00?o0000omPWf?oH9mP03?oH9mP00ol0003o
ka3_onl@k`02onl@k`03o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00Co0000onPGj?oX5nSo
j1OX0_l00006onhAkP03o`000?o6>LKoaSW600SoaSW60ol000000oo2?L;o0000o`000004ogF:M@03
o`000?l[e2_o:m@[00go:m@[00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03
o`000?lVfBKo9]TV00Wo9]TV00?o0000og6>LOmaSW403?maSW400ol0003o/Djaok5>/@03o`0000ko
f2OH00?o0000onl@koo_4>l00oo_4>l00ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000onPGj?l000002?o^4Nh00ol0003oaSW6olHiaP0;olHiaP03o`000?meRWGoMHYe00Go
MHYe00?o0000ob_D:ol[e2/03?l[e2/00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l1oP7o0Oh100Oo
0Oh100?o0000obKI9_lVfBH02?lVfBH2o`0000ooLHia0_l00002olXebP03o`000?oH9mSof2OH00_o
f2OH00?o0000onl@koo_4>l01?o_4>l00ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003oaSW6olHiaP0;olHiaP03o`000?meRWGoMHYe00KoMHYe00?o0000ob_D:ol[e2/0
2ol[e2/2o`0000go0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9]TVobKI9P07obKI9P04o`00
0?ll`cco?<<lo`0000koLHia00?o0000olXeb_o:=LX00_o:=LX00ol0003of2OHomPWf009omPWf003
o`000?o_4>ooka3_00Koka3_00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000oo/4nook1?/02_ok1?/2o`0000Wo
kQ7^00?o0000olHia_o6>LH02oo6>LH00ol0003oMHYeogF:M@07ogF:M@03o`000?l[e2_o:m@[00Wo
:m@[00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV
00Ko9]TV00Go0000occ3??ll`cco?<<lo`00000>og6>L@03o`000?o:=L[obSG:00?obSG:00?o0000
omPWf?oH9mP01ooH9mP00ol0003oka3_onl@k`07onl@k`03o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00Co0000ooT6nOoi1_Wo00002Oo^4Nh00ol0003oaSW6olHiaP09olHiaP03o`000?meRWGo
MHYe00WoMHYe00?o0000ob_D:ol[e2/01ol[e2/00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9]TVobKI9P05obKI9P03o`000?ll`cco
?<<l00?o?<<l00?o0000og6>LOmaSW402_maSW400ol0003obSG:olXebP05olXebP03o`000?oH9mSo
f2OH00Gof2OH00?o0000onl@koo_4>l02?o_4>l00ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won`Ck00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okQ7^onhAkP06onhAkP03o`000?o6>LKoaSW600WoaSW600?o0000ogF:
MOmeRWD02_meRWD00ol0003o:m@[ob_D:`05ob_D:`03o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lVfBKo9]TV00Co9]TV00?o0000occ3
??ll`c`01?ll`c`00ol0003oLHiaog6>L@0:og6>L@03o`000?o:=L[obSG:00KobSG:00?o0000omPW
f?oH9mP00ooH9mP00ol0003oka3_onl@k`09onl@k`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ook1?/00ol0003o
n@KiooT6n@03ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000olHia_o6>LH02Oo6>LH00ol0003o
MHYeogF:M@0;ogF:M@03o`000?l[e2_o:m@[00?o:m@[00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l1oP7o0Oh100Ko0Oh100?o0000obKI9_lVfBH00_lVfBH2o`0000So
?<<l00?o0000og6>LOmaSW402OmaSW400ol0003obSG:olXebP07olXebP05o`000?oH9mSof2OHomPW
f?l000003Oo_4>l00ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ook1?_o0000ooT6n@06ooT6n@03
o`000?o^4NkokQ7^00GokQ7^00?o0000olHia_o6>LH02Oo6>LH00ol0003oMHYeogF:M@0<ogF:M@05
o`000?l[e2_o:m@[ob_D:ol000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh1
00Ko0Oh100?o0000obKI9_l000000_l000000olCk1?o0000occ3?007occ3?003o`000?maSW7oLHia
00SoLHia00?o0000olXeb_o:=LX02Oo:=LX00ol0003of2OHo`00000=onl@k`Co00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oaSW6olHiaP09olHiaP03
o`000?meRWGoMHYe00goMHYe00?o0000ob_D:ol000003?l9mPT:o`0000Oo0Oh10ol00005oa?/4`03
o`000?ll`cco?<<l00Ko?<<l00?o0000og6>LOmaSW401omaSW400ol0003obSG:olXebP0:olXebP03
o`000?o_4>ooka3_00_oka3_00?o0000oo/4nook1?/00_ok1?/3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olHia_o6>LH01oo6>LH00ol0003oMHYeogF:M@0?ogF:M@;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100;o0Oh10ol00008oa?/4`03o`00
0?ll`cco?<<l00Ko?<<l00?o0000og6>LOmaSW401omaSW400ol0003obSG:olXebP0:olXebP03o`00
0?o_4>ooka3_00[oka3_00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o^4NkokQ7^00CokQ7^00?o0000olHia_o6>LH01oo6>LH00ol0003oMHYeogF:
M@0>ogF:M@04o`000?ldbcCo=</do`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0Oh1
o`000?l0000<oa?/4`03o`000?ll`cco?<<l00Ko?<<l00?o0000og6>LOmaSW401_maSW400ol0003o
bSG:olXebP0;olXebP03o`000?o_4>ooka3_00Ooka3_0_l00009oo/4n`03o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh00oo^4Nh>o`0000goMHYe00?o0000ocC;=?ldbc@0
0_ldbc@00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oa?/4olCk1<0
3?lCk1<00ol0003o?<<locc3?006occ3?003o`000?maSW7oLHia00GoLHia00?o0000olXeb_o:=LX0
3?o:=LX00ol0003oka3_onl@k`06onl@k`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okQ7^onhAk_o^4Nko000000_occ3?00?o0000og6>LOmaSW400ol00009ogF:M@03o`00
0?ldbcCo=</d00Co=</d00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lCk1?o4n`C00go4n`C00?o0000occ3??ll`c`01_ll`c`00ol0003oLHiaog6>L@03og6>L@?o0000
3Oo:=LX00ol0003oka3_onl@k`05onl@k`03o`000?ok1?_on`Ck00con`Ck0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cocc3?00?o0000og6>LOmaSW400omaSW43o`0000GoMHYe00?o0000ocC;=?ldbc@01_ld
bc@01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oa?/4olCk1<03OlCk1<00ol0003o?<<l
occ3?006occ3?003o`000?maSW7oLHia00?o00000on<Lh`00ol0003obSG:olXebP0;olXebP03o`00
0?o_4>ooka3_00?oka3_00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003ooD:m@03o`000?o?<<oocc3?00[occ3?00?o0000og6>LOmaSW401_maSW43o`000003ogF:MOl0
003o=</d00Wo=</d00?o0000o`Wf2Ol000004?l9mPT00ol0003o4n`Coa?/4`0=oa?/4`03o`000?ll
`cco?<<l00Oo?<<l0_l00007ohacS003o`000?o:=L[obSG:00[obSG:00Co0000onl@koo_4>ooka3_
0ol0000?oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom@[e00?o0000oll`coo?
<<l02_o?<<l00ol0003oLHiaog6>L@09og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o4n`Coa?/4`0>oa?/4`03o`000?ll`cco?<<l00Ko?<<l00?o0000ohacS?n<
Lh`01on<Lh`4o`0000SobSG:00Co0000onl@koo_4>oo00000oof2OH2o`0000gon`Ck00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000oll`coo?<<l02Oo?<<l00ol0003o
LHiaog6>L@0:og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
4n`Coa?/4`0>oa?/4`03o`000?ll`cco?<<l00Go?<<l00?o0000ohacS?n<Lh`02?n<Lh`01?l0003o
d2o@om0_d?o@;m07o`0000;obSG:0_l00006ooH9mP;o00003?ok1?/00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003occ3?oll`c`08oll`c`03o`000?maSW7oLHia00[o
LHia00?o0000ocC;=?ldbc@02oldbc@00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lCk1?o4n`C00ko
4n`C1Ol00002occ3?003o`000?n<LhcoS7><00WoS7><00?o0000om0_d?o@;m002?o@;m03o`0000Wo
mPWf0_l0000:oo/4n`03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@07ooD:m@03o`00
0?o?<<oocc3?00Socc3?00?o0000og6>LOmaSW402_maSW400ol0003o=</docC;=00:ocC;=0;o0000
3_l9mPT3o`0000go4n`C0ol00005odRgB0;o00002on<Lh`00ol0003od2o@om0_d00;om0_d0;o0000
2_of2OH2o`0000Oon`Ck0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?oe2_Gom@[e00Oom@[e00?o0000oll`coo?<<l02?o?<<l>o`0000Wo=</d0ol000000olXebSo0000
o`Wf2@0:o`Wf2@?o00000_lKi1/00ol0003o4n`Coa?/4`09oa?/4`;o00002Om8]dP00ol0003oS7><
ohacS009ohacS003o`000?o@;m3od2o@00_od2o@00?o0000onDJiOl000002oof2OH2o`0000Con`Ck
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oe2_Gom@[e00Kom@[e00?o0000oll`coo?<<l02?o?<<l00ol0003oL8m`
og2?L00:og2?L003o`000?ldbcCo=</d00Co=</d0ol00005obSG:003o`000?l9mPWo2OH900Co2OH9
1?l00006oa_T6`03o`000?lCk1?o4n`C00Ko4n`C0_l0000;odRgB003o`000?n<LhcoS7><00WoS7><
00?o0000om0_d?o@;m002_o@;m001Ol0003oiA[UonDJiOoU6^Go000000comPWf0_l000000ook1?_o
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003occ3?oll`c`07oll`c`03o`00
0?m`Sg3oL8m`00_oL8m`00?o0000ocC;=?ldbc@00_ldbc@2o`0000Wo:=LX00?o0000o`Wf2Ol9mPT0
0ol0000;oa_T6`03o`000?lCk1?o4n`C00;o4n`C0ol0000>odRgB003o`000?n<LhcoS7><00OoS7><
00?o0000om0_d?o@;m002oo@;m000ol0003oiA[UonDJi@02onDJi@03o`000?of2OKomPWf00_omPWf
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000ooD:mOoe2_D01ooe2_D00ol0003occ3?oll`c`05oll`c`?o00003Om`
Sg04o`0000_o:=LX0ol0000?oa_T6`04o`000?lCk1?o0000o`00017oB;M800?o0000ohacS?n<Lh`0
1on<Lh`00ol0003od2o@om0_d00:om0_d003o`000?oU6^GoiA[U00CoiA[U00?o0000ooH9m_of2OH0
1oof2OH3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om@[eooD:
m@06ooD:m@03o`000?o?<<oocc3?00;occ3?0ol00003ojm@[`03o`000?m`Sg3oL8m`00[oL8m`00?o
0000obSG:?lXebP02olXebP00ol0003o8m`So`00000Aoa_T6`03o`000?m8]dSoB;M8017oB;M800?o
0000ohacS?n<Lh`01on<Lh`00ol0003od2o@om0_d00:om0_d003o`000?oU6^GoiA[U00GoiA[U00Co
0000ooH9m_of2OKomPWf1Ol00002ooP7n003o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@05ooD:m@?o0000
00?occ3?o`000?l000001on_D:l00ol0003oL8m`og2?L008og2?L0?o00002_lXebP2o`0000;o8m`S
00?o0000oa_T6olKi1/03olKi1/00ol0003oB;M8odRgB00AodRgB003o`000?n<LhcoS7><00OoS7><
00?o0000om0_d?o@;m002Oo@;m000ol0003oiA[UonDJi@07onDJi@?o00001ooh1oP00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om@[e0_l00003onl@k`03o`000?n_D:oo[e2_00So[e2_0_l00006og2?L0;o00000omM
XUd00ol0003o:=LXobSG:006obSG:003o`000?lSg2?o8m`S00?o8m`S00?o0000oa_T6olKi1/03_lK
i1/00ol0003oB;M8odRgB00BodRgB003o`000?n<LhcoS7><00GoS7><00?o0000om0_d?o@;m002Oo@
;m000ol0003oiA[UonDJi@08onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo_4>l00ol0003o[e2_ojm@[`0:ojm@[`03o`000?m`Sg3oL8m`00;oL8m`00?o0000
oefRGOmMXUd01?mMXUd00ol0003o:=LXobSG:004obSG:003o`000?lSg2?o8m`S00Co8m`S00?o0000
oa_T6olKi1/03_lKi1/00ol0003oB;M8odRgB00BodRgB0[o00002_o@;m000ol0003oiA[UonDJi@08
onDJi@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onl@koo_4>l01?o_4>l0
0ol0003o[e2_ojm@[`0:ojm@[`04o`000?m`Sg3o0000o`0000SoGJ9M00Co0000obSG:?lXebSo:=LX
0_l00007ob?L8`03o`000?lKi1_o6n@K00ko6n@K00?o0000odRgB?m8]dP04_m8]dP00ol0003oZ5NX
ojQGZ007ojQGZ003o`000?o@;m3od2o@00Kod2o@00?o0000onDJiOoU6^D02_oU6^D00ol0003on0Oh
ooP7n006ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onl@koo_4>l01?o_4>l00ol0003o[e2_ojm@[`0;ojm@[`03o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obSG:?l000002OlSg2<00ol0003o6n@Koa_T6`0>oa_T6`;o0000
4_m8]dP00ol0003oZ5NXojQGZ009ojQGZ0;o00001_o@;m000ol0003oiA[UonDJi@0:onDJi@03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?n_D:oo[e2_00[o[e2_00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa_T6olKi1/03_lKi1/00ol0003o?L8mo`00
0002o`0000ooB;M800?o0000ojQGZ?nXEjP02onXEjP00ol0003od2o@om0_d003o`0000goiA[U00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o_4>ooka3_00Goka3_00?o0000ojm@[on_D:l02On_D:l2
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lKi1_o6n@K00co6n@K00?o0000ocg2?Olm`Sd00olm`Sd3
o`0000coB;M800?o0000ojQGZ?nXEjP03?nXEjP2o`0000;ohacS00?o0000onDJiOoU6^D03?oU6^D0
0ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o[e2_ojm@[`07ojm@
[`03o`000?naC[7o000000[oGJ9M00Co0000oe:]D_mB[E;o00002_lSg2<00ol0003o6n@Koa_T6`0<
oa_T6`03o`000?lm`Sgo?L8m00Ko?L8m0_l00008odRgB0;o00003onXEjP00ol0003ohacSon<Lh`02
on<Lh`03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o_4>ooka3_
00Koka3_00?o0000ojm@[on_D:l01_n_D:l01Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe:]D_mB[E800_mB[E800ol0003o8m`Sob?L8`06ob?L8`Co00003?lKi1/00ol0003o?L8mocg2?@08
ocg2?@?o00000_m8]dP3o`000003ohQgR?l0003oZ5NX00goZ5NX00?o0000on<LhooS7><01?oS7><0
0ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`07onl@
k`03o`000?n_D:oo[e2_00?o[e2_0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe:]
D_mB[E800omB[E800ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa_T
6`;o00003_lm`Sd2o`0000GoR7N800?o0000ojQGZ?nXEjP02_nXEjP00ol0003ohacSon<Lh`05on<L
h`03o`000?oU6^GoiA[U00_oiA[U00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o_4>ooka3_00Oo
ka3_00?o0000ojm@[on_D:l00_n_D:l00ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe:]D_mB[E801OmB[E800ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6n@K0_l000000olRgB;o0000ocg2?@0=ocg2?@03o`000?n8MhSoR7N800GoR7N800?o0000ojQGZ?nX
EjP02?nXEjP00ol0003ohacSon<Lh`07on<Lh`03o`000?oU6^GoiA[U00[oiA[U00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o_4>ooka3_00Soka3_00Co0000ojm@[on_D:oo00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDZeB00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lRgB80
0ol0003o?L8mocg2?@0;ocg2?@03o`000?n8MhSoR7N800KoR7N800?o0000ojQGZ?nXEjP01onXEjP0
0ol0003ohacSon<Lh`08on<Lh`Co00002?oU6^D00ol0003on0OhooP7n004ooP7n003o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onl@
k`03o`000?n_D:oo000000_o/Dja00?o0000oefRGOl000002_mB[E800ol0003o8m`So`00000?oagR
7@03o`000?lRgB;o8]dR00;o8]dR00?o0000ocg2?Olm`Sd02olm`Sd00ol0003oR7N8ohQgR006ohQg
R003o`000?nXEjSoZ5NX00KoZ5NX00?o0000on<LhooS7><02OoS7><01?l0003olPgboo8=l_ob3O87
o`0000;oiA[U00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o_4>ooka3_00Ooka3_00?o0000ok5>
/OnaC[402onaC[400ol0003oDZeBoe:]DP0:oe:]DP03o`000?lMhQgo7N8M00go7N8M00?o0000ob;M
8_lRgB801?lRgB800ol0003o?L8mocg2?@09ocg2?@03o`000?n8MhSoR7N800SoR7N800?o0000ojQG
Z?nXEjP00onXEjP2o`0000cohacS00?o0000oo8=l_ob3O802?ob3O8<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mB[E;oDZeB00WoDZeB0_l0000>oagR7@03o`000?lRgB;o8]dR00Go
8]dR00?o0000ocg2?Olm`Sd02Olm`Sd00ol0003oR7N8ohQgR009ohQgR003o`000?nXEjSo000000;o
00000_oH9mP00ol0003ohacSon<Lh`08on<Lh`03o`000?ob3O;olPgb00colPgb00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?ooP7n0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003oka3_
onl@k`04onl@k`03o`000?naC[7o/Dja00_o/Dja0ol00007oe:]DP?o000000?o?<<lo`000?lMhQd0
3OlMhQd00ol0003o8]dRob;M8P06ob;M8P03o`000?lm`Sgo?L8m00So?L8m00?o0000ohQgR?n8MhP0
2_n8MhP00ol0003of2OHomPWf004omPWf003o`000?oS7>?ohacS00OohacS00?o0000oo8=l_ob3O80
2oob3O800ol0003onPGjooX5nP08ooX5nP03o`000?on0OkooP7n00CooP7n0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onl@koo_4>l00oo_4>l>o`0000?oW6>L0_l00002oe:]DP?o0000
1Oll`c`00ol0003o7N8MoagR7@0:oagR7@03o`000?lRgB;o8]dR00Oo8]dR00?o0000ocg2?Olm`Sd0
2?lm`Sd00ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Gof2OH00?o0000on<LhooS7><0
1_oS7><00ol0003olPgboo8=lP0;oo8=lP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
1oon0Oh2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onl@koo_4>l00_o_4>l00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009occ3?003o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob;M8_lRgB802?lRgB82o`0000So?L8m00?o0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPW
f007omPWf003o`000?oS7>?ohacS00CohacS00?o0000oo8=l_ob3O802oob3O800ol0003onPGjooX5
nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?oka3_
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?ll`cco?<<l00Wo?<<l00?o0000
oagR7OlMhQd01olMhQd00ol0003o8]dRob;M8P09ob;M8P04o`000?m4^dCo0000o`0000Ko?L8m00?o
0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPWf008omPWf003o`000?oS7>?ohacS00?ohacS00?o
0000oo8=l_ob3O802oob3O800ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooi1_T2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o?<<locc3?00:occ3?0Wo00002olRgB800ol0003oA;]4odBkA002odBkA0?o00000_lm`Sd0
0ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Wof2OH00?o0000on<LhooS7><00_oS7><0
0ol0003olPgboo8=lP0:oo8=lP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02_on0Oh0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000Gon@Ki00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?ll`cco?<<l00Wo?<<l00?o0000obKI9_lVfBH01OlVfBH00ol0003o8]dRob;M8P09ob;M
8P03o`000?m4^dCoA;]400GoA;]40ol00009ohQgR0?o00003OoH9mP01Ol0003ohacSon<LhooS7>?o
000000colPgb00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000Oon@Ki00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?ll`cco?<<l00So?<<l00?o0000obKI9_lVfBH01olVfBH00ol0003o8]dRob;M8P07
ob;M8P03o`000?m4^dCoA;]400SoA;]40ol00002ohQgR0Go00000_o0?l000ol0003of2OHomPWf00<
omPWf003o`000?oS7>?o000000colPgb00?o0000ooX5n_oj1OX02_oj1OX00ol0003ooP7nooh1oP0:
ooh1oP03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000Son@Ki00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o?<<locc3?008occ3?003o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob;M8_lRgB801olRgB800ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;
00;o00002?o0?l000ol0003of2OHomPWf00<omPWf0Co00002_ob3O800ol0003onPGjooX5nP0:ooX5
nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooT6n@03o`000?o^4NkokQ7^
00;okQ7^00?o0000olPgb?o8=lP00_o8=lP4o`0000WoW6>L00?o0000occ3??ll`c`02?ll`c`00ol0
003o9]TVobKI9P08obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000odBkA?m4^d@02?m4^d@01Ol0
003oRgB;oh]dRon;M8_o000000[o`3o00ol0000;omPWf004o`000?og2?Oom`SgooL8m`Co00001Oob
3O800ol0003onPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003on@KiooT6n@0:
ooT6n@03o`000?o^4NkokQ7^00?okQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oW6>LoiaSW007
oiaSW003o`000?ll`cco?<<l00Ko?<<l0_l0000;obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000
odBkA?m4^d@02?m4^d@00ol0003oRgB;oh]dR`02oh]dR`03o`000?o0?l3o`3o000Oo`3o000?o0000
onXEj_oZ5NX01?l00006omPWf003o`000?og2?Oom`Sg00Kom`Sg0ol00002oo8=lP03o`000?oj1O[o
nPGj00_onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi1_Won@Ki00Won@Ki00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ob3O8olPgb005olPgb003o`000?nLHicoW6>L00OoW6>L00?o0000occ3
??ll`c`00_ll`c`3o`000003oeNXEol0003o9]TV00[o9]TV00?o0000ob;M8_lRgB801OlRgB800ol0
003oA;]4odBkA007odBkA003o`000?n;M8_oRgB;00?oRgB;00?o0000ol0o`?o0?l001oo0?l000ol0
003ojQGZonXEjP04onXEjP?o00000_oH9mP00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooT6nOoi1_T02Ooi1_T00ol0003okQ7^onhAkP04onhAkP03
o`000?o8=lSob3O800Kob3O80_l00007oiaSW003o`000?ll`cco000000;o00001OmGZ5L00ol0003o
9]TVobKI9P08obKI9P?o00001?lRgB800ol0003oA;]4odBkA008odBkA003o`000?n;M8_oRgB;00Co
RgB;00?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP07onXEjP;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?on0OkooP7n00cooP7n00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@KiooT6n@08ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oc3?<ol`cc003o`0000CoW6>L
0_l00008oeNXE`03o`000?lVfBKo9]TV00Oo9]TV00Co0000odbcC?m</dcoC;=<0ol000000olRgB;o
0000odBkA009odBkA003o`000?n;M8_oRgB;00CoRgB;00?o0000ol0o`?o0?l001Oo0?l000ol0003o
jQGZonXEjP09onXEjP03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0<ooh1oP03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooT6nOoi1_T01ooi1_T00ol0003okQ7^onhAkP06onhAkP03o`00
0?o8=lSob3O800?ob3O800?o0000ol`cc?o<<l`01?o<<l`2o`000003oiaSW?l0003oEjQG00[oEjQG
00?o0000obKI9_lVfBH01OlVfBH00ol0003oC;=<odbcC005odbcC003o`000?m4^dCoA;]400OoA;]4
0ol00007oh]dR`03o`000?o0?l3o`3o000Co`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oi
1_Won@Ki00Gon@Ki0ol00009onhAkP05o`000?o8=lSob3O8olPgb?l000002Oo<<l`00ol0003oEjQG
oeNXE`0;oeNXE`03o`000?lVfBKo9]TV00?o9]TV00?o0000odbcC?m</d`01_m</d`00ol0003oA;]4
odBkA006odBkA005o`000?n5NXGoQGZ5ohEjQOl000001on;M8/00ol0003o`3o0ol0o`003ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?on0OkooP7n00[ooP7n00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003on@Kio`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003ob3O8olPgb?l00009ol`cc0;o00003OmGZ5L00ol0003o9]TVobKI9P02obKI9P03
o`000?m</dcoC;=<00SoC;=<00?o0000odBkA?m4^d@00om4^d@2o`0000GoQGZ500?o0000oh]dRon;
M8/01?n;M8/00ol0003o`3o0ol0o`003ol0o`003o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ob3O8o`000009ol`cc004o`000?n[E:_oZeB[o`0000go
EjQG00Co0000obKI9_lVfBKo00003?m</d`01Ol0003oA;]4odBkA?m4^dCo000000SoQGZ50_l00005
oh]dR`03o`000?o0?l3o`3o000;o`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oc3?<ol`cc007ol`cc003o`000?n[E:_oZeB[
00;oZeB[00?o0000oeNXEomGZ5L02_mGZ5L00ol0003o9]TVo`00000>odbcC003o`000?m4^dCo0000
00_oQGZ500?o0000oh]dRon;M8/00_n;M8/01Ol0003o`3o0ol0o`?o0?l3o000000cojQGZ00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[
00?oZeB[00?o0000oeNXEomGZ5L02omGZ5L00ol0003oC;=<odbcC00>odbcC003o`000?n5NXGoQGZ5
00_oQGZ50_l00003oh]dR`04o`000?o0?l3o`3o0o`0000[ojQGZ0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n[E:_oZeB[00GoZeB[00?o0000oeNX
EomGZ5L01omGZ5L3o`00017oC;=<00?o0000ohEjQOn5NXD03On5NXD01Ol0003oRgB;oh]dRol0003o
`3o000Co00000ooZ5NX5o`0000;on`Ck00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oZeB[oj]DZ`06oj]DZ`03o`000?mGZ5OoEjQG
00CoEjQG0ol00002of6NH@03o`000?m</dcoC;=<00ooC;=<0_l0000?ohEjQ@04o`000?n;M8_o0000
o`0000Cogb3O0ol00008oo/4n`03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003ooP7nooh1oP07ooh1oP03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000Ooc3?<00?o0000oj]D
Zon[E:/02?n[E:/00ol0003oEjQGoeNXE`03o`0000KoHIiQ00?o0000odbcC?m</d`03Om</d`01?l0
003oSW6>ohiaS_l0000?ohEjQ@03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/02?ok1?/0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ooh1oP03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o<<lcoc3?<00?oc3?<00?o0000oj]DZon[E:/02_n[E:/2o`0000[oHIiQ00?o0000odbc
C?m</d`02om</d`00ol0003oSW6>ohiaSP02ohiaSP03o`000?n5NXGoQGZ500_oQGZ50_l00007omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ooh1
o_on0Oh00oon0Oh3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o<<lcoc3?<ol`c
c?l000003On[E:/00ol0003oHIiQof6NH@0:of6NH@03o`000?m</dcoC;=<00WoC;=<00?o0000ohia
S_n>LHh01?n>LHh00ol0003oQGZ5ohEjQ@08ohEjQ@;o000000?o/Djao`000?oO8=l01ooO8=l00ol0
003on`Ckoo/4n`09oo/4n`04o`000?og2?Oo0000o`0001CooP7n00?o0000ooh1o_on0Oh00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003oc3?<o`00000=oj]DZ`03o`000?mQWV7oHIiQ
00_oHIiQ00?o0000odbcC?m</d`02?m</d`00ol0003oSW6>ohiaSP06ohiaSP03o`000?n5NXGoQGZ5
00GoQGZ50_l00003ok5>/@03o`000?oO8=oogb3O00Kogb3O00?o0000oo/4nook1?/02_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000oj]DZon[
E:/03?n[E:/00ol0003oHIiQof6NH@0<of6NH@03o`000?m</dcoC;=<00KoC;=<00?o0000ohiaS_n>
LHh02?n>LHh00ol0003oQGZ5ohEjQ@02ohEjQ@;o00001_naC[400ol0003ogb3OomlPg`05omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000coZeB[00?o0000of6NHOmQWV403OmQWV400ol0003oC;=<
odbcC004odbcC003o`000?n>LHkoSW6>00[oSW6>00Co0000ohEjQOl0003o00002?naC[400ol0003o
gb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oC;=?o000000;o00002?n[E:/00ol0003oHIiQ
of6NH@0?of6NH@Ko00003_n>LHh00ol0003o/Djaok5>/@08ok5>/@03o`000?oO8=oogb3O00Kogb3O
00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oC;=?odbcC00?odbcC0ol00005oj]DZ`;o00004?mQWV401_l0003oM8]d
ogB;M?l0003oJiA[o`0000koSW6>00?o0000ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`05omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oC;=?odbcC00KodbcC0ol000001?n[E:_o0000oi5^TOnAKY43o`00
00coHIiQ00Go0000ogB;M?mdRgCoM8]do`000002of^DJ`03o`000?n>LHkoSW6>00_oSW6>00?o0000
ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Son`Ck0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oC;=<00ol0003oTFjAoi5^T@04oi5^
T@?o00002?mQWV400ol0003oM8]dogB;M002ogB;M005o`000?m[U6_oJiA[of^DJol000003?n>LHh0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oO8=oogb3O00Gogb3O3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om</
dooC;=<02_oC;=<00ol0003oTFjAoi5^T@07oi5^T@;o00001OmQWV400ol0003oM8]dogB;M003ogB;
M003o`000?m[U6_oJiA[00;oJiA[00?o0000ohiaS_n>LHh02On>LHh00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om</dooC;=<02ooC;=<00ol0003oTFjAoi5^T@09oi5^T@?o000000?oHIiQo`000?md
Rg@01OmdRg@00ol0003oJiA[of^DJ`03of^DJ`03o`000?n>LHkoSW6>00SoSW6>3_l00003omlPg`;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003omPWfo`00000;oo0?l003o`000?oC;=?odbcC00[odbcC
0_l0000>oi5^T@03o`000?mdRgCoM8]d00GoM8]d00?o0000of^DJom[U6/00om[U6/00ol0003oSW6>
ohiaSP08ohiaSP03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omlPgol000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooH9m_of2OKo00002_o`3o000ol0003odbcCom</d`09om</d`03o`000?o0?l3o000000koTFjA
00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJiA[of^DJ`04of^DJ`03o`000?n>LHkoSW6>00KoSW6>
00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH00_of
2OH00ol0003ol0o`oo0?l006oo0?l003o`000?oC;=?odbcC00SodbcC0_l00003ol0o`003o`000?nA
KY7oTFjA00_oTFjA00?o0000ogB;M?mdRg@01OmdRg@00ol0003oJiA[of^DJ`05of^DJ`03o`000?n>
LHkoSW6>00GoSW6>00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooH9m_of2OH00oof2OH00ol0003ol0o`oo0?l005oo0?l003o`000?oC;=?odbcC00OodbcC00?o0000
ol0o`?o0?l000oo0?l000ol0003oTFjAoi5^T@0:oi5^T@03o`000?mdRgCoM8]d00KoM8]d00?o0000
of^DJom[U6/01_m[U6/00ol0003oSW6>ohiaSP04ohiaSP03o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01Oof2OH00ol0
003ol0o`oo0?l004oo0?l003o`000?oC;=?odbcC00GodbcC0_l00006ol0o`003o`000?nAKY7oTFjA
00WoTFjA0_l00008ogB;M003o`000?m[U6_oJiA[00KoJiA[1Ol000000on>LHko0000on4Nh@0?on4N
h@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01_of2OH00ol0003o
l0o`oo0?l004o`0000KodbcC00?o0000ol0o`?o0?l001oo0?l000ol0003oTFjAoi5^T@05oi5^T@?o
000000?oTFjAo`000?mdRg@01omdRg@00ol0003oJiA[of^DJ`05of^DJ`03o`000?n]DZgo[E:]00?o
[E:]0_l0000?on4Nh@;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo0?l00?o0000ooH9m_of2OH01oof2OH2o`0000CojAKY00Co0000om</dooC;=?o
dbcC0_l0000:ol0o`003o`000?nAKY7oTFjA00;oTFjA0ol00005oi5^T@03o`000?mdRgCoM8]d00Go
M8]d00?o0000of^DJom[U6/01?m[U6/00ol0003o[E:]ojeB[@06ojeB[@03o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003omPWfooH9mP08ooH9mP03o`00
0?oY5^WojAKY00CojAKY00?o0000om</dol000003?o0?l000ol0003oTFjAo`000002o`0000WoTFjA
00?o0000ogB;M?mdRg@01?mdRg@00ol0003oJiA[of^DJ`03of^DJ`03o`000?n]DZgo[E:]00So[E:]
1_l00004on4Nh@;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH01oof
2OH00ol0003ojAKYonTFj@06onTFj@03o`000?o0?l3o`3o000co`3o000?o0000oi5^TOnAKY402_nA
KY400ol0003oM8]dogB;M004ogB;M004o`000?m[U6_oJiA[of^DJ`;o00002on]DZd00ol0003oj1OX
onPGj003onPGj0Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003omPWfooH9mP07ooH9mP03o`000?oY
5^WojAKY00OojAKY00?o0000ol0o`?o0?l003?o0?l000ol0003oTFjAoi5^T@0;oi5^T@03o`000?md
RgCoM8]d00?oM8]d00Co0000of^DJom[U6_o00003On]DZd00ol0003oj1OXonPGj006onPGj003o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000ooH9m_of2OH0
1_of2OH00ol0003ojAKYonTFj@09onTFj@03o`000?o0?l3o`3o000Wo`3o00_l0000>oi5^T@?o0000
0omdRg@00ol0003oJiA[o`00000=ojeB[@03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000OomPWf00?o
0000onTFjOoY5^T02_oY5^T00ol0003o`3o0ol0o`006ol0o`0;o000000?o`Ck1o`000?nAKY402onA
KY42o`0000?oWV6N1Ol0000>ojeB[@03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`03oo/4n`Co00000_of2OH00ol0003ojAKYonTFj@0;
onTFj@03o`000?o0?l3o`3o000?o`3o00ol00004ol4n`@03o`000?nAKY7oTFjA00OoTFjA0_l00008
oiiQWP03o`000?n]DZgo[E:]00go[E:]00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onTFj@03o`000?o0?l3o`3o000;o00002?o1?/400ol0
003oTFjAoi5^T@05oi5^T@03o`000?nNHIkoWV6N00SoWV6N00?o0000ojeB[On]DZd03On]DZd00ol0
003oj1OXonPGj008onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oY5^WojAKY00kojAKY0_l0000;ol4n`@03o`000?nAKY7oTFjA00;oTFjA0_l0000;oiiQ
WP03o`000?n]DZgo[E:]00go[E:]00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00gojAKY0_l0000<ol4n`@04o`000?nAKY7o0000
o`0000goWV6N00?o0000ojeB[On]DZd03?n]DZd00ol0003oj1OXonPGj009onPGj003o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00cojAKY00Co0000on<L
hooS7>?o00003?o1?/400ol0003oWV6NoiiQWP0>oiiQWP03o`000?n]DZgo[E:]00So[E:]1?l0000;
onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oY5^WojAKY
00_ojAKY00?o0000on<LhooS7><00_oS7><00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nNHIkoWV6N
00koWV6N00Co0000ojeB[On]DZgo[E:]1ol00003oll`c`03o`000?oX5nSoj1OX00Woj1OX00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000onTFjOoY5^T02_oY5^T00ol0
003ohacSon<Lh`03on<Lh`03o`000?o1?/7o`Ck100So`Ck100?o0000oiiQW_nNHIh03_nNHIh4o`00
00_occ3?00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook
1?/03?ok1?/7o`0000GojAKY00?o0000on<LhooS7><01OoS7><00ol0003o`Ck1ol4n`@07ol4n`@03
o`000?nNHIkoWV6N00koWV6N00?o0000oll`coo?<<l03Oo?<<l00ol0003oj1OXonPGj008onPGj003
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?od2oCom0_d00Com0_d
1Ol00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oiiQW_nNHIh03_nNHIh00ol0003occ3?
oll`c`0=oll`c`03o`000?oX5nSoj1OX00Soj1OX00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=oo/4n`03o`000?od2oCom0_d00Wom0_d
0_l00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oiiQW_nNHIh03?nNHIh00ol0003occ3?
oll`c`0?oll`c`Ko00001?oX5nP4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m0_doo@;m009oo@;m003o`000?o/4nco000000;o00001ooS7><00ol0003o`Ck1ol4n`@05ol4n`@03
o`000?nNHIkoWV6N00SoWV6N1Ol0000Aoll`c`03o`000?o_4>ooka3_00?oka3_1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000oo@;m?od2o@02_od2o@00ol0003ok1?/on`Ck002on`Ck0?o00001OoS7><00ol0003o`Ck1
ol4n`@04ol4n`@04o`000?nNHIkoWV6NoiiQWPOo00001?o><Lh00ol0003occ3?oll`c`0>oll`c`03
o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om0_d
oo@;m00;oo@;m003o`000?o/4ncok1?/00Gok1?/0ol00003on<Lh`04o`000?o1?/7o`Ck1ol4n`@Ko
00003?o><Lh00ol0003occ3?oll`c`0=oll`c`03o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?od2o@0
3?od2o@00ol0003ok1?/on`Ck008on`Ck0?o000000CohacSo`000?l0003o00000_oY5^T00ol0003o
cS7>olhacP0=olhacP03o`000?o?<<oocc3?00cocc3?00?o0000onl@koo_4>l02?o_4>l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00;on`Ck003o`000?oY5^WojAKY00?o
jAKY00?o0000olhac_o><Lh03?o><Lh00ol0003of2OHo`00000=oll`c`03o`000?o_4>ooka3_00So
ka3_00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000oo@;m?od2o@03?od2o@00ol0003ok1?/on`Ck00:on`Ck003o`00
0?oY5^WojAKY00GojAKY00?o0000olhac_o><Lh02_o><Lh01?l0003of2OHomPWf?oH9mP2o`0000[o
cc3?00?o0000onl@koo_4>l02Oo_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo@;m?od2o@0
3?od2o@00ol0003ok1?/on`Ck009on`Ck003o`000?oY5^WojAKY00KojAKY00?o0000olhac_o><Lh0
2Oo><Lh00ol0003of2OHomPWf002omPWf003o`000?o[5>_o000000;o00001oo?<<l00ol0003oka3_
onl@k`09onl@k`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om0_doo@;m00;oo@;m003o`000?o/
4ncok1?/00Sok1?/00?o0000onTFjOoY5^T01ooY5^T00ol0003ocS7>olhacP08olhacP03o`000?oH
9mSof2OH00?of2OH00?o0000on/Djoo[5>/00_o[5>/2o`0000Cocc3?00?o0000onl@koo_4>l02_o_
4>l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;oo@;m0Ko00001?o/4n`00ol0003ojAKYonTFj@08
onTFj@03o`000?o><LkocS7>00OocS7>00?o0000omPWf?oH9mP00ooH9mP00ol0003ojaC[on/Dj`05
on/Dj`?o000000?occ3?o`000?o_4>l02oo_4>l00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006oo@;m003o`000?of2OKomPWf00ComPWf1?l0000<onTFj@03o`000?o><LkocS7>
00GocS7>00?o0000omPWf?oH9mP01?oH9mP00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_
00_oka3_00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om0_d00?o0000ooH9m_of
2OH02?of2OH00ol0003ojAKYonTFj@0:onTFj@03o`000?o><LkocS7>00CocS7>00?o0000omPWf?oH
9mP01OoH9mP00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_00Woka3_1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooH9mP03o`000?oY5^WojAKY00WojAKY
00?o0000olhac_o><Lh00oo><Lh00ol0003of2OHomPWf005omPWf003o`000?o[5>_ojaC[00[ojaC[
00?o0000onl@koo_4>l01?o_4>l4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oY5^WojAKY00WojAKY00?o0000olhac_o><Lh00_o>
<Lh00ol0003of2OHomPWf006omPWf003o`000?o[5>_ojaC[00[ojaC[00?o0000onl@koo_4>l01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?of2OKomPWf00[omPWf00?o0000onTFjOoY5^T02OoY5^T01Ol0003ocS7>olha
c_o><Lko000000Wof2OH00?o0000on/Djoo[5>/02oo[5>/2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003omPWfooH9mP0;ooH9mP03o`000?oY5^WojAKY00WojAKY00?o
0000olhac_l000002OoH9mP00ol0003ojaC[on/Dj`0<on/Dj`03o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003omPWfooH9mP0:ooH9mP03o`000?oY5^Wo
jAKY00SojAKY1Ol00008omPWf003o`000?o[5>_ojaC[00cojaC[00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooH9m_of2OH02_of2OH00ol0003ojAKYonTFj@07onTF
j@03o`000?o]4^gokA;]00?okA;]0ol00005omPWf003o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
mPWf00?o0000onTFjOoY5^T01OoY5^T00ol0003okA;]ondBk@07ondBk@?o000000?of2OHo`000?o[
5>/03Oo[5>/00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_of2OH00ol0003ojAKYonTFj@03onTFj@;o0000
3Oo]4^d2o`0000gojaC[0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?of2OKomPWf00OomPWf00Co0000onTFjOoY5^WojAKY
0_l00002ooP7n003o`000?o]4^gokA;]00cokA;]3Ol00003ooT6n@03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooH9mP03o`000?oY5^Wo000000Gon0Oh
00?o0000ondBkOo]4^d02oo]4^d00ol0003ol@kaoo4>l@09oo4>l@03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?omPWf0ol0
0007ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oo4>lOoa3_402Ooa3_400ol0003on@KiooT6
n@04ooT6n@;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003okA;]ondB
k@08ondBk@03o`000?oa3_7ol@ka00[ol@ka00?o0000ooT6nOoi1_T01_oi1_T00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o]4^gokA;]00OokA;]00?o
0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@07ooT6n@;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o]4^gokA;]00KokA;]00?o0000oo4>lOoa3_402_oa3_40
0ol0003on@KiooT6n@09ooT6n@05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ondBkOo]4^d01Oo]4^d00ol0003ol@kaoo4>l@0:
oo4>l@03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@04ondBk@03o`000?oa3_7ol@ka00Wol@ka00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]
00;okA;]00?o0000oo4>lOoa3_402_oa3_400ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000ondBkOo]
4^gokA;]o`00000<oo4>l@03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003okA;]o`000004o`0000Wol@ka00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003oo0?loo`3o003oo`3o0Oo00000_oa3_400ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003oo@;m
o`000002o`0000Son0Oh00?o0000oo`3o?ol0o`02_ol0o`5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003oo@;mood2o@03ood2o@?o00001?oh1oP00ol0003oo0?loo`3
o00=oo`3o003o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?om0_goo@;m00Koo@;m0ol000000ooh1oSo0000oo`3o00>oo`3o003o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`03ool0o`00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool03Ol00?l00oooo`3o003oo`00o`08o`00o`Coool0
2Ol00?l2oooo06Oo003o0Oooool006co003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000So003o0oooo`0;o`00o`03oooo0?l0
0?oo003o00Oo003o0_ooo`03o`00o`03oooo0?l00?oo003o00Ko003o0_ooo`1Wo`00o`7ooooo001/
o`00o`;oool01_l00?l2oooo00Wo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02
o`00o`;oool000?o003ooooo0?ooo`002_l00?l3oooo00Wo003o00?oool0o`00ool00?l01_l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000_o003o0oooo`09o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`05o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;o
ool000?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;o
ool01_l00?l4oooo0003o`00ooooo`3oool000co003o0_ooo`09o`00o`03oooo0?l00?oo003o00Go
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool0
1?l00?l2oooo00Go003o1?ooo`02o`00o`;oool03Ol00?l2oooo00So003o00?oool0o`00ool00?l0
1?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00go003o0_ooo`09o`00o`03oooo0?l00?oo003o00?o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l00?oo003o00;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`04o`00o`04oooo0?l0
0?ooool0oooo00So003o1Oooo`000ol00?ooool0oooo0008o`00o`03oooo0?l00?oo003o00?o003o
0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006[o003o0_ooo`03o`00o`03oooo0?l0
0?oo003o00;oool00ol00?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_oo
o`04o`00o`04oooo0?l00?ooool0oooo00Oo003o0_ooo`04o`00o`?oool02?l00?l00oooo`3o003o
o`00o`03o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l0
0?l00oooo`3o003ooooo0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_oo
o`03o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000Ko003o0oooo`05o`00o`;oool02Ol0
0?l00oooo`3o003oo`00o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Y
o`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04
o`00o`Coool000?o003ooooo0?l00?l00_ooo`06o`00o`;oool01_l00?l2oooo00Wo003o00?oool0
o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo
00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;oool01_l00?l2oooo
00Wo003o00?oool0o`00ool00?l00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1oooo
o`00J?l00?l3oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o01Oo003o0_ooo`06o`00o`;o
ool01_l00?l2oooo00[o003o00Coool0o`00ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o
00Go003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;o
ool01_l00?l2oooo00Ko003o00Coool0o`00ool00?ooool02?l00?l00oooo`3o003oo`00o`02o`00
o`;oool01?l00?l2oooo00Oo003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Oo
003o00?oool0o`00ool00?l05_l00?l2oooo0003oc8bc?l00?oo003o00Co003o00?oool0o`00ool0
0?l00ol00?l2oooo00?o003o00?oool0o`00ool00?l01Ol00?l00oooo`3o003oo`00o`02o`00o`;o
ool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol00?l3oooo00Go003o
0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`04o`00o`;oool00ol00?l2oooo00Co003o
2_ooo`04o`00o`;oool00_l00?l2oooo00Go003o1Oooo`1Wo`00o`7ooooo001Vo`00o`Koool000?o
003ooooo0?ooo`001Oooo`03o`00o`Goool08Ol00?l4oooo00Go003o2_ooo`05o`00o`Coool0L_l0
0?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(980) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.996 .004 .996 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.99 .01 .99 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.978 .022 .978 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.981 .019 .981 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.957 .043 .957 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.987 .013 .987 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.995 .005 .995 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.909 .091 .909 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.971 .029 .971 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.984 .016 .984 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.992 .008 .992 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.958 .042 .958 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.982 .018 .982 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.93 .07 .93 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.982 .018 .982 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.973 .027 .973 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.977 .023 .977 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.924 .076 .924 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.987 .013 .987 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.961 .039 .961 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.935 .065 .935 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.776 .224 .776 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.813 .187 .813 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.996 .004 .996 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.939 .061 .939 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.8 .2 .8 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.761 .239 .761 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.688 .312 .688 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.93 .07 .93 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.958 .042 .958 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.951 .049 .951 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.912 .088 .912 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.995 .005 .995 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.98 .02 .98 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.815 .185 .815 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.694 .306 .694 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.877 .123 .877 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.444 .556 .444 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.438 .562 .438 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.567 .433 .567 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.8 .2 .8 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.826 .174 .826 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.512 .488 .512 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.461 .539 .461 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.965 .035 .965 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.611 .389 .611 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.753 .247 .753 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.925 .075 .925 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.939 .061 .939 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.672 .328 .672 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.889 .111 .889 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.367 .633 .367 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.874 .126 .874 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.757 .243 .757 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.173 .827 .173 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.321 .679 .321 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.983 .017 .983 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.284 .716 .284 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.205 .795 .205 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.913 .087 .913 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.986 .014 .986 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.551 .449 .551 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.157 .843 .157 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.235 .765 .235 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.843 .157 .843 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.341 .659 .341 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.568 .432 .568 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.255 .745 .255 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.062 .938 .062 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.138 .862 .138 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.382 .618 .382 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.569 .431 .569 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.97 .03 .97 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.622 .378 .622 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.706 .294 .706 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.071 .929 .071 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.014 .986 .014 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.038 .962 .038 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.115 .885 .115 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.151 .849 .151 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.809 .191 .809 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.928 .072 .928 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.954 .046 .954 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.525 .475 .525 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.106 .894 .106 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.847 .153 .847 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.244 .756 .244 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.459 .541 .459 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.15 .85 .15 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.301 .699 .301 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.886 .114 .886 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.419 .581 .419 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.133 .867 .133 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.985 .015 .985 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.92 .08 .92 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.946 .054 .946 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.329 .671 .329 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.979 .021 .979 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.046 .954 .046 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.006 .994 .006 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.68 .32 .68 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.659 .341 .659 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.152 .848 .152 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.27 .73 .27 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.556 .444 .556 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.812 .188 .812 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.154 .846 .154 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.99 .01 .99 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.078 .922 .078 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.241 .759 .241 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.347 .653 .347 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.976 .024 .976 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.525 .475 .525 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.505 .495 .505 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.361 .639 .361 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.287 .713 .287 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.935 .065 .935 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.914 .086 .914 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.907 .093 .907 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.237 .763 .237 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.545 .455 .545 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.694 .306 .694 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.882 .118 .882 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.978 .022 .978 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.535 .465 .535 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.753 .247 .753 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.446 .554 .446 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.972 .028 .972 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.952 .048 .952 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.873 .127 .873 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.982 .018 .982 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.551 .449 .551 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.661 .339 .661 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.992 .008 .992 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.612 .388 .612 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.917 .083 .917 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.741 .259 .741 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.846 .154 .846 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.697 .303 .697 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.981 .019 .981 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.966 .034 .966 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.815 .185 .815 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.974 .026 .974 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.779 .221 .779 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.794 .206 .794 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.895 .105 .895 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.888 .112 .888 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.968 .032 .968 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.849 .151 .849 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.969 .031 .969 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.949 .051 .949 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.938 .062 .938 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.899 .101 .899 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.907 .093 .907 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.874 .126 .874 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.952 .048 .952 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.985 .015 .985 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.972 .028 .972 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.98 .02 .98 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.99 .01 .99 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.976 .024 .976 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.921 .079 .921 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.971 .029 .971 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.98 .02 .98 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.985 .015 .985 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.988 .012 .988 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.997 .003 .997 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.978 .022 .978 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.982 .018 .982 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.989 .011 .989 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ood2o@03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo@;mood2o@0;ood2o@05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?om0_goo@;m00coo@;m00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d03_om0_d00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oom0_d00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooP7n0;o00003?om0_d2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003om0_d
oo@;m?od2o@5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oh1oSon0Oh00Gon0Oh0_l00008ood2o@;o00000_oi1_T00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003om0_doo@;m007oo@;m0Ko00000_oo0?l4o`0000goo@;m00?o0000ooP7n?oh1oP0
1ooh1oP2o`0000Goo@;m00?o0000ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003om0_doo@;m00<oo@;m0?o00001?oj1OX3o`0000Woo@;m00?o
0000ooP7n?oh1oP02_oh1oP2o`000003ood2oOl0003o000000Oon@Ki00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oh1oSon0Oh00gon0Oh00?o0000ooT6nOoi1_T02?oi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oh1oP03ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000Soo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo`3o00>oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on0OhooP7n00?ooP7n003o`000?oi1_Won@Ki00[on@Ki2ol0000;ood2o@Go00003?om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ol0ocoo0?l00coo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0
003onPGjooX5nP0=ooX5nP;o00004?oh1oP00ol0003on@KiooT6n@0:ooT6n@03o`000?oh1oSon0Oh
00Oon0Oh00?o0000ood2oOom0_d00_om0_d7o`0000Con@Ki00?o0000ood2oOom0_d02_om0_d00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj
00gonPGj00Co0000onTFjOoY5^Wo00003ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSo
n0Oh00Won0Oh1?l0000;ooT6n@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000oo0?l?l0003o00002Ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[o
nPGj00gonPGj00Go0000onTFjOoY5^WojAKYo`00000=ooP7n003o`000?oi1_Won@Ki00[on@Ki00?o
0000ooP7n?oh1oP02Ooh1oP00ol0003on@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00[oo@;m00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o`3o3ol0o`00;ol0o`0_l00007oo`3o003o`000?od2oCo
m0_d00com0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@03onTFj@03o`000?oh1oSo
n0Oh00[on0Oh00?o0000ooT6nOoi1_T02_oi1_T00ol0003on0OhooP7n009ooP7n003o`000?oi1_Wo
n@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?
l?o`3o001Oo`3o000ol0003oo0?loo`3o003oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@04onTFj@03o`000?oh1oSon0Oh00Won0Oh00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003on0OhooP7n00:ooP7n003o`000?oi1_Won@Ki00con@Ki00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?l?o`3o001_o`3o02o`0000?o
o0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0<ooX5nP03o`000?oY5^WojAKY00Ko
jAKY00?o0000ooP7n?oh1oP02?oh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00[o
n0Oh00?o0000ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o`3o3ol0o`00Wol0o`0_l000000ool0oco0000oo@;m00<oo@;m0?o00003_oj1OX00ol0003ojAKY
onTFj@07onTFj@03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooT6nOoi1_T02Ooi1_T00ol0003on0Oh
ooP7n00;ooP7n003o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o`3o3ol0o`00_ol0o`00?o0000oo@;m?od2o@02_od2o@2o`0000?ohQgR00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ojAKYonTFj@09onTFj@03o`000?oh1oSon0Oh00Kon0Oh00?o
0000ooT6nOoi1_T02?oi1_T00ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00con@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003ol0o`oo0?l00<oo0?l003o`000?od2oCom0_d00Som0_d0_l00006on8MhP;o00002_oj1OX0
0ol0003ojAKYonTFj@0:onTFj@03o`000?oh1oSon0Oh00Gon0Oh00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00con@Ki00?o0000ood2oOom0_d02oom0_d0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003_o`3o000ol0003om0_doo@;m004
oo@;m0?o00002_oR7N800ol0003onPGjooX5nP07ooX5nP03o`000?oY5^WojAKY00_ojAKY00?o0000
ooP7n?oh1oP00ooh1oP00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00con0Oh00?o0000
ooT6nOoi1_T03?oi1_T00ol0003oo@;mood2o@0;ood2o@;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003oo`3o001?l0
003om0_doo@;m?od2o@2o`0000kohQgR0_l00006ooX5nP03o`000?oY5^WojAKY00gojAKY00?o0000
ooP7n?oh1oP00_oh1oP00ol0003on@KiooT6n@08ooT6n@03o`000?oh1oSon0Oh00con0Oh0ol0000=
ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00@oo0?l0Co00004_oR7N800ol0
003onPGjooX5nP03ooX5nP03o`000?oY5^WojAKY00kojAKY00Go0000ooP7n?oh1oSon0Oho`000005
ooT6n@Oo00003?oh1oP01Ol0003ol`ccoo<<looc3??o000000con@Ki00?o0000ood2oOom0_d02?om
0_d3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00=
oo0?l0?o000000Cogb3Oo`000?l0003o00004ooR7N82o`0000;onPGj00?o0000onTFjOoY5^T04?oY
5^T00ol0003on0Oho`000006o`0000OoiA[U00?o0000ooP7n?oh1oP02?oh1oP00ol0003ol`ccoo<<
l`03oo<<l`;o00002?oi1_T3o`0000Koo@;m1?l00002ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oi1_T3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003ol0o`oo0?
l00;oo0?l0?o00000ooO8=l01Ol0003oebSGo`000?ndBkCo000001CohQgR00?o0000ooX5n_l00000
4ooY5^T00ol0003oiA[UonDJi@0=onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l00008oo<<l`03o`00
0?oi1_Won@Ki00Go00000ooh1oP00ol0003oo@;mood2o@03o`0000Ooo@;m00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con@Ki0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000oo0?l?o`3o002Oo`3o03o`0000Gogb3O00Co0000omLXeooG:=Oo00000_ndBk@00ol0003o
hQgRon8MhP0Bon8MhP03o`000?oY5^WojAKY01;ojAKY00?o0000onDJiOoU6^D03_oU6^D00ol0003o
n0OhooP7n003ooP7n003o`000?oc3??ol`cc00Wol`cc0_l00009ooP7n0;o00002_om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooT6n@;o00001oom0_d5o`0000;o
nPGj00?o0000oo0?l?o`3o001_o`3o03o`0000Sogb3O00Co0000omLXeooG:=Oo00000ondBk@00ol0
003ohQgRon8MhP0Aon8MhP03o`000?oY5^WojAKY017ojAKY00?o0000onDJiOoU6^D04?oU6^D01Ol0
003on0OhooP7n?oh1oSo000000col`cc00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo@;mood2o@0:
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooT6nOoi1_T01ooi1_T3o`00
0004ood2oOl0003o0000o`0000Gol`cc0_l00006oo0?l0?o00002_oO8=l01Ol0003oebSGomLXeooG
:=Oo000000Co]4^d00?o0000on8Mh_oR7N804?oR7N800ol0003ojAKYonTFj@0AonTFj@03o`000?oU
6^GoiA[U017oiA[U00?o0000ooP7n?l000003Ooc3?<00ol0003on0OhooP7n008ooP7n003o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooT6nOoi1_T02_oi1_T00ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00?o00003OoO8=l0
1Ol0003oebSGomLXeooG:=Oo000000Go]4^d00?o0000on8Mh_oR7N803ooR7N800ol0003ojAKYonTF
j@0AonTFj@03o`000?oU6^GoiA[U01;oiA[U00?o0000oo<<looc3?<03?oc3?<00ol0003on0OhooP7
n008ooP7n003o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc0_l0000?omlPg`03o`000?oG:=Oo
ebSG00;oebSG00?o0000okA;]?ndBk@01?ndBk@00ol0003ohQgRon8MhP0=on8MhP?o00004OoY5^T0
0ol0003oiA[UonDJi@0ConDJi@03o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc00?o0000omlPgooO8=l03OoO8=l0
0ol0003oebSGomLXe`03omLXe`03o`000?ndBkCo]4^d00Go]4^d00?o0000on8Mh_oR7N802_oR7N82
o`0000?oZ5NX00?o0000onTFjOoY5^T03_oY5^T00ol0003oiA[UonDJi@0ConDJi@03o`000?oc3??o
l`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on@Ki00?o0000oo<<
looc3?<02ooc3?<00ol0003ogb3OomlPg`0<omlPg`03o`000?oG:=OoebSG00?oebSG00?o0000okA;
]?ndBk@01_ndBk@00ol0003ohQgRon8MhP07on8MhP;o00001_nXEjP2o`0000kojAKY00?o0000onDJ
iOoU6^D04ooU6^D00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh00Won0Oh00?o0000ood2
oOom0_d03?om0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003ogb3OomlPg`0;omlP
g`03o`000?oG:=OoebSG00CoebSG00?o0000okA;]?ndBk@01ondBk@00ol0003ohQgRon8MhP05on8M
hP03o`000?nXEjSoZ5NX00SoZ5NX00?o0000onTFjOoY5^T02_oY5^T00ol0003oiA[UonDJi@0DonDJ
i@03o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0<ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003ogb3OomlPg`0;omlPg`03o`000?oG:=OoebSG
00CoebSG00?o0000okA;]?ndBk@02?ndBk@00ol0003ohQgRon8MhP02on8MhP;o00003?nXEjP2o`00
00[ojAKY00?o0000onDJiOoU6^D05?oU6^D00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh
00Won0Oh00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oO8=oogb3O00Wogb3O00?o0000omLXeooG:=L01OoG:=L00ol0003o]4^dokA;]009okA;]004
o`000?oR7N;o0000o`00013oZ5NX0_l00008onTFj@03o`000?oU6^GoiA[U01CoiA[U0ol0000;oo<<
l`03o`000?oh1oSon0Oh00Won0Oh00?o0000ood2oOom0_d03Oom0_d01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooT6
nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0;oo<<l`;o00002_oO8=l00ol0003oebSGomLXe`06omLX
e`03o`000?ndBkCo]4^d00[o]4^d00?o0000ojQGZ?nXEjP04_nXEjP00ol0003ojAKYonTFj@04onTF
j@03o`000?oU6^GoiA[U01GoiA[U00?o0000omlPgooO8=l01Ol00005oo<<l`03o`000?oh1oSon0Oh
00[on0Oh00?o0000ood2oOom0_d03_om0_d3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003ol`ccoo<<l`0;oo<<l`04
o`000?o@;m3od2o@o`0000Wogb3O00?o0000omLXeooG:=L01_oG:=L00ol0003o]4^dokA;]00:okA;
]003o`000?nXEjSoZ5NX01?oZ5NX0_l00003onTFj@Co00005?oU6^D00ol0003ogb3OomlPg`06omlP
g`Co000000?ol`cco`000?oh1oP02ooh1oP00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ol`ccoo<<l`09oo<<l`;o00001?o@;m000ol0003ogb3OomlPg`05omlPg`03
o`000?oG:=OoebSG00OoebSG00?o0000okA;]?ndBk@02_ndBk@00ol0003oZ5NXojQGZ00EojQGZ003
o`000?oY5^Wo000000Co_D:m0ol0000@onDJi@03o`000?oO8=oogb3O00_ogb3O0_l0000<ooP7n003
o`000?om0_goo@;m00coo@;m0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oi1_Won@Ki00Oon@Ki00?o0000oo<<looc3?<02?oc3?<00ol0003od2o@
om0_d005om0_d003o`000?oO8=oogb3O00Cogb3O00?o0000omLXeooG:=L01ooG:=L00ol0003o]4^d
okA;]00:okA;]003o`000?nXEjSoZ5NX01KoZ5NX00?o0000oke2_Onm@[d01_nm@[d3o`0000coiA[U
00?o0000omlPgooO8=l03OoO8=l00ol0003on0OhooP7n009ooP7n0Go00002Oom0_d2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooT6nOoi1_T01_oi
1_T00ol0003ol`ccoo<<l`07oo<<l`03o`000?o@;m3od2o@00Ood2o@00?o0000omlPgooO8=l00_oO
8=l00ol0003oebSGomLXe`08omLXe`03o`000?ndBkCo]4^d00Wo]4^d00?o0000ojQGZ?nXEjP05onX
EjP00ol0003o_D:moke2_@09oke2_@?o00002OoU6^D00ol0003ogb3OomlPg`0>omlPg`Ko00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_om0_d2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?oc
3??ol`cc00Gol`cc0_l0000;om0_d004o`000?oO8=oogb3Oo`0000_oebSG00?o0000okA;]?ndBk@0
2OndBk@00ol0003oZ5NXojQGZ00FojQGZ003o`000?nm@[go_D:m00go_D:m0ol00005onDJi@03o`00
0?oO8=oogb3O00oogb3O00?o0000on/Djoo[5>/00oo[5>/4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oi1_T00ol0003ol`ccoo<<
l`05oo<<l`03o`000?o@;m3od2o@00cod2o@00?o0000omlPgol000002ooG:=L00ol0003o]4^dokA;
]007okA;]0?o00006?nXEjP00ol0003o_D:moke2_@0@oke2_@?o000000?oiA[Uo`000?oO8=l04?oO
8=l00ol0003ojaC[on/Dj`07on/Dj`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooT6n@03o`000?oc3??ol`cc00?ol`cc0_l0000@om0_d003o`000?oG:=OoebSG00[oebSG00?o0000
okA;]?ndBk@00ondBk@4o`0000;oQWV600?o0000ojQGZ?nXEjP05OnXEjP00ol0003o_D:moke2_@0D
oke2_@03o`000?oO8=oogb3O013ogb3O00?o0000on/Djoo[5>/01oo[5>/00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?ol`cc00?o0000om0_d?o@;m004?o@;m000ol0
003oebSGomLXe`0:omLXe`03o`000?ndBkCo000000?o00001on6NHH00ol0003oZ5NXojQGZ00DojQG
Z003o`000?nm@[go_D:m01Co_D:m00?o0000omlPgooO8=l03ooO8=l00ol0003ojaC[on/Dj`08on/D
j`03o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00?o
k1?/00?o0000oo<<lol000004oo@;m04o`0000WoebSG0_l0000<ohIiQP03o`000?nXEjSoZ5NX01?o
Z5NX00?o0000oke2_Onm@[d05Onm@[d00ol0003ogb3OomlPg`0>omlPg`03o`000?o[5>_ojaC[00So
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ok1?/on`Ck005on`Ck003o`00
0?o@;m3od2o@01;od2o@00Co0000ohebSOn=LXgoSG:=1Ol00003omLXe`03o`000?n6NHKoQWV600go
QWV60ol0000@ojQGZ0;o00006?nm@[d00ol0003ogb3OomlPg`0=omlPg`03o`000?o[5>_ojaC[00Wo
jaC[00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`00
0?o@;m3od2o@017od2o@00?o0000ohebSOn=LXd01on=LXd3o`00013oQWV600?o0000oeB[E?mDZe@0
1Ol00009ojQGZ0;o000000?oPGj1o`000?nm@[d05onm@[d00ol0003ogb3OomlPg`0=omlPg`03o`00
0?o[5>_ojaC[00WojaC[00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000om0_d?o@;m003oo@;m000ol0003oSG:=oheb
S@0:ohebS@03o`000?n6NHKoQWV600goQWV600?o0000oeB[E?mDZe@01_mDZe@4o`0000CoZ5NX00?o
0000oh5nPOn1OX400_n1OX400ol0003o_D:moke2_@0Foke2_@03o`000?oO8=oogb3O00_ogb3O00?o
0000on/Djoo[5>/02oo[5>/00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ok1?/00?o0000om0_d?o@;m003oo@;m000ol0003oSG:=ohebS@0;ohebS@03o`000?n6NHKo
QWV600coQWV600?o0000oeB[E?mDZe@02_mDZe@4o`0000GoPGj100?o0000oke2_Onm@[d05_nm@[d0
0ol0003ogb3OomlPg`0:omlPg`03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000on`C
k?o/4n`02Oo/4n`00ol0003od2o@om0_d00=om0_d003o`000?n=LXgoSG:=00coSG:=00?o0000ohIi
Q_n6NHH03?n6NHH00ol0003oE:]DoeB[E00;oeB[E003o`000?mHYeSo000000KoPGj100?o0000oke2
_Onm@[d05_nm@[d00ol0003ogb3OomlPg`09omlPg`03o`000?o[5>_ojaC[00cojaC[00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000om0_d?o@;m002?o@;m04o`0000oo
SG:=00?o0000ohIiQ_n6NHH02on6NHH00ol0003oE:]DoeB[E00;oeB[E004o`000?mHYeSoF:MHo`00
00OoPGj100?o0000oke2_Onm@[d05Onm@[d00ol0003ogb3OomlPg`08omlPg`03o`000?o[5>_ojaC[
00gojaC[00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000om0_d?o@
;m000oo@;m05o`0000?oTFjA00?o0000ohebSOn=LXd03_n=LXd00ol0003oQWV6ohIiQP0:ohIiQP03
o`000?mDZeCoE:]D00[oE:]D00Go0000oeRWF?mHYeSoF:MHo`000007oh5nP@03o`000?nm@[go_D:m
01Go_D:m00?o0000omlPgooO8=l02?oO8=l00ol0003ojaC[on/Dj`0=on/Dj`03o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00<on`Ck0Go00002OnAKY400ol0003o
SG:=ohebS@0<ohebS@;o00003?n6NHH00ol0003oE:]DoeB[E00:oeB[E005o`000?mHYeSoF:MHoeRW
F?l000002?n1OX400ol0003o_D:moke2_@0Doke2_@?o00001ooO8=l00ol0003ojaC[on/Dj`0>on/D
j`03o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000on`Ck?o/4n`03?o/4n`01?l0003oc3?<ol`cc?l0000;oi5^T@03o`000?n=LXgoSG:=
00_oSG:=00Co0000od6n@Om1_T7o00002_n6NHH00ol0003oE:]DoeB[E00:oeB[E003o`000?mHYeSo
F:MH00;oF:MH00?o0000oh5nPOn1OX401_n1OX400ol0003o_D:moke2_@0Aoke2_@?o00000oo7><L0
0ol0003ogb3OomlPg`04omlPg`03o`000?o[5>_ojaC[00gojaC[1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000ol`cc?o<<l`00_o<<l`0
0ol0003oTFjAoi5^T@08oi5^T@03o`000?n=LXgoSG:=00[oSG:=00?o0000od6n@Om1_T400_m1_T40
0ol0003oQWV6ohIiQP03ohIiQPGo00002omDZe@00ol0003oF:MHoeRWF003oeRWF003o`000?n1OX7o
PGj100OoPGj100?o0000oke2_Onm@[d03_nm@[d2o`0000OoacS700?o0000omlPgooO8=l00_oO8=l0
0ol0003ojaC[on/Dj`0=on/Dj`03o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol`c
c?o<<l`00oo<<l`00ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00SoSG:=00?o0000od6n
@Om1_T401?m1_T45o`0000Co?/4n00?o0000oeB[E?mDZe@02OmDZe@00ol0003oF:MHoeRWF003oeRW
F003o`000?n1OX7oPGj100SoPGj100?o0000oke2_Onm@[d02_nm@[d3o`0000[oacS700Go0000omlP
gooO8=oogb3Oo`00000>on/Dj`03o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000ol`c
c?o<<l`01?o<<l`00ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00OoSG:=00?o0000od6n
@Om1_T401Om1_T400ol0003o?/4nock1?P07ock1?P03o`000?mDZeCoE:]D00OoE:]D00?o0000oeRW
F?mHYeP01?mHYeP00ol0003oPGj1oh5nP@08oh5nP@03o`000?nm@[go_D:m00So_D:m0_l0000>olLh
a`Co00003?o[5>/2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003ok1?/on`Ck009on`Ck003o`000?o<<lcoc3?<00Koc3?<00?o0000oi5^TOnAKY402OnAKY400ol0
003oSG:=ohebS@05ohebS@03o`000?m1_T7o@Ki100Ko@Ki100?o0000ock1?_ln`Ch02?ln`Ch00ol0
003oE:]DoeB[E006oeB[E003o`000?mHYeSoF:MH00CoF:MH00?o0000oh5nPOn1OX402On1OX44o`00
00?o_D:m0ol0000@olLha`05o`000?oX5nSoj1OXonPGj?l000002_o[5>/00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[ok1?/00?o0000ol`cc?o<<l`01oo<<l`0
0ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00CoSG:=00?o0000od6n@Om1_T401om1_T40
0ol0003o?/4nock1?P08ock1?P;o00001_mDZe@00ol0003oF:MHoeRWF005oeRWF003o`000?n1OX7o
PGj100WoPGj100Co0000oiaSW?nLHicoW6>L0ol0000BolLha`03o`000?oX5nSoj1OX00?oj1OX0_l0
0006on/Dj`;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o/4n`00ol0003oc3?<ol`cc008ol`cc003o`000?nAKY7o
TFjA00[oTFjA00?o0000ohebSOn=LXd00_n=LXd00ol0003o@Ki1od6n@@08od6n@@03o`000?ln`Cko
?/4n00Ko?/4n0_l00002obKI9P03o`000?mDZeCoE:]D00;oE:]D00?o0000oeRWF?mHYeP01_mHYeP0
0ol0003oPGj1oh5nP@08oh5nP@03o`000?nLHicoW6>L00CoW6>L00?o0000olLhaoo7><L03oo7><L0
0ol0003oj1OXonPGj006onPGj0;o00000oo[5>/00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003oc3?<ol`cc00:ol`cc003o`000?nAKY7oTFjA
00WoTFjA00Go0000ohebSOn=LXgoSG:=o`00000;od6n@@03o`000?ln`Cko?/4n00Co?/4n0_l00005
obKI9P05o`000?mDZeCoE:]DoeB[E?l000002?mHYeP00ol0003oPGj1oh5nP@08oh5nP@03o`000?nL
HicoW6>L00GoW6>L00?o0000olLhaoo7><L03_o7><L00ol0003oj1OXonPGj008onPGj003o`000?o[
5>_o000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003oc3?<
ol`cc00;ol`cc003o`000?nAKY7oTFjA00WoTFjA00Co0000ohebSOn=LXgo00003?m1_T400ol0003o
?/4nock1?P02ock1?P;o00002?lVfBH00ol0003oE:]Do`000009oeRWF003o`000?n1OX7oPGj100So
PGj100?o0000oiaSW?nLHi`01OnLHi`00ol0003oacS7olLha`0=olLha`03o`000?oX5nSoj1OX00[o
j1OX00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o/4ncok1?/00Cok1?/00?o0000ol`cc?o<<l`03?o<<l`00ol0003oTFjAoi5^T@0:oi5^T@?o0000
3?m1_T400ol0003o?/4nock1?P02o`0000_o9]TV00?o0000oeRWF?mHYeP02?mHYeP00ol0003oPGj1
oh5nP@07oh5nP@03o`000?nLHicoW6>L00OoW6>L00?o0000olLhaoo7><L03?o7><L00ol0003oj1OX
onPGj00;onPGj0;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo/
4n`00ol0003oc3?<ol`cc00>ol`cc003o`000?nAKY7oTFjA00SoTFjA00Co0000odRgB?m8]dSoB;M8
0_l0000:od6n@@?o00003OlVfBH00ol0003oF:MHoeRWF008oeRWF003o`000?n1OX7oPGj100OoPGj1
00?o0000oiaSW?nLHi`01onLHi`00ol0003oacS7olLha`0;olLha`03o`000?oX5nSoj1OX00coj1OX
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003oo@;m003o`000?o/4nco0000017oc3?<00?o0000oi5^TOnAKY401onAKY400ol0003oB;M8odRg
B004odRgB0;o00002?m1_T400ol0003o9]TVobKI9P0>obKI9P;o00002?mHYeP00ol0003oPGj1oh5n
P@06oh5nP@03o`000?nLHicoW6>L00WoW6>L00?o0000olLhaoo7><L02Oo7><L00ol0003oj1OXonPG
j00=onPGj003o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006oo@;m003o`000?o<<lcoc3?<013oc3?<00?o0000oi5^TOnAKY401_nAKY40
0ol0003oB;M8odRgB007odRgB003o`000?m1_T7o@Ki100Co@Ki10ol0000>obKI9P03o`000?lVfBKo
9]TV00?o00001OmHYeP00ol0003oPGj1oh5nP@06oh5nP@03o`000?nLHicoW6>L00[oW6>L00?o0000
olLhaoo7><L02?o7><L00ol0003oj1OXonPGj00=onPGj003o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008oo@;m003o`000?o<<lcoc3?<
017oc3?<00Co0000oi5^TOnAKY7oTFjA1?l0000;odRgB0;o000000Co@Ki1o`000?l0003o00000olB
kA82o`0000_o9]TV00?o0000obKI9_lVfBH01?lVfBH2o`0000?oF:MH00?o0000oh5nPOn1OX401_n1
OX400ol0003oW6>LoiaSW00:oiaSW003o`000?o7><OoacS700OoacS700?o0000onPGj?oX5nP03_oX
5nP00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<oo@;m003o`000?o<<lco
c3?<013oc3?<1?l00003oh=lP`03o`000?m8]dSoB;M800_oB;M800?o0000oa;]4_lBkA801_lBkA80
0ol0003o9]TVobKI9P07obKI9P03o`000?lVfBKo9]TV00Oo9]TV3?l0000>oiaSW003o`000?o7><Oo
acS700KoacS700?o0000onPGj?oX5nP03_oX5nP00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_od2o@00ol0003oc3?<ol`cc00?ol`cc003o`000?n3O8?oPgb300KoPgb300?o0000
odRgB?m8]dP02_m8]dP00ol0003o4^dBoa;]4P07oa;]4P;o00001_lVfBH00ol0003o9]TVobKI9P08
obKI9P03o`000?mLXecoG:=L00SoG:=L00?o0000oiaSW?nLHi`03?nLHi`00ol0003oacS7olLha`05
olLha`03o`000?oX5nSoj1OX00ooj1OX0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03_od2o@00ol0
003oc3?<ol`cc00>ol`cc003o`000?n3O8?oPgb300OoPgb300?o0000odRgB?m8]dP02_m8]dP00ol0
003o4^dBoa;]4P09oa;]4P;o00000olVfBH00ol0003o9]TVobKI9P09obKI9P03o`000?mLXecoG:=L
00WoG:=L00?o0000oiaSW?nLHi`02_nLHi`4o`0000CoacS700?o0000onPGj?oX5nP04?oX5nP01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03ood2o@@o`0000[oPgb300?o0000odRg
B?m8]dP02Om8]dP00ol0003o3o0?o`00000<oa;]4P05o`000?lVfBKo0000o`_d2ol000002_lVfBH0
0ol0003oG:=LoebSG009oebSG003o`000?nLHicoW6>L00OoW6>L0ol00004ok9=/P?o000000?oacS7
o`000?oX5nP04OoX5nP01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00?
oo@;m003o`000?o2?L;o`Sg200co`Sg200?o0000oh=lPon3O8<02On3O8<00ol0003oB;M8odRgB007
odRgB004o`000?l?l0oo3o0?o`0000go4^dB00Go0000o`_d2ol;m0_o2o@;o`000009obKI9P03o`00
0?mLXecoG:=L00[oG:=L00?o0000oiaSW?nLHi`00onLHi`3o`0000[o/Tfb00?o0000onPGj?oX5nP0
4?oX5nP00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo@;m?od2o@03ood2o@00ol0003o`Sg2ol8m`P0<ol8m`P03o`000?n3
O8?oPgb300WoPgb300?o0000odRgB?m8]dP01_m8]dP00ol0003o3o0?o`o`3`02o`o`3`03o`000?lB
kA;o4^dB00[o4^dB00?o0000o`_d2ol;m0/00_l;m0/00ol0003o9]TVobKI9P06obKI9P03o`000?mL
XecoG:=L00[oG:=L00?o0000oiaSW?nLHi`00ol0000=ok9=/P03o`000?oX5nSoj1OX013oj1OX00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00=oo@;m0?o00003oo2?L80
0ol0003oPgb3oh=lP`08oh=lP`03o`000?m8]dSoB;M800GoB;M800?o0000o`o`3ol?l0l00ol?l0l0
0ol0003o4^dBoa;]4P0:oa;]4P03o`000?l;m0_o2o@;00?o2o@;00?o0000obKI9_lVfBH01OlVfBH0
0ol0003oG:=LoebSG00;oebSG0;o00004OnbCK800ol0003oj1OXonPGj00?onPGj003o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_doo@;m009oo@;m0Go00000_oX5nP00ol0
003o`Sg2ol8m`P0=ol8m`P03o`000?n3O8?oPgb300WoPgb300?o0000odRgB?m8]dP01?m8]dP00ol0
003o3o0?o`o`3`04o`o`3`03o`000?lBkA;o4^dB00So4^dB00?o0000o`_d2ol;m0/01Ol;m0/00ol0
003o9]TVobKI9P04obKI9P03o`000?mLXecoG:=L00_oG:=L00?o0000ok9=/_nbCK804?nbCK800ol0
003oj1OXonPGj00?onPGj003o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?od2oCom0_d00Com0_d1Ol00007onPGj003
o`000?o2?L;o`Sg200go`Sg200?o0000oh=lPon3O8<02On3O8<00ol0003oB;M8odRgB003odRgB003
o`000?l?l0oo3o0?00Go3o0?00?o0000oa;]4_lBkA802?lBkA800ol0003o2o@;o`_d2`06o`_d2`03
o`000?lVfBKo9]TV00?o9]TV00?o0000oebSG?mLXe`02omLXe`00ol0003o/Tfbok9=/P0@ok9=/P03
o`000?oX5nSoj1OX00ooj1OX00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?l00000
1?l0000<onPGj003o`000?o2?L;o`Sg200ko`Sg200?o0000oh=lPon3O8<02?n3O8<00ol0003oB;M8
odRgB002odRgB003o`000?l?l0oo3o0?00Oo3o0?00?o0000oa;]4_lBkA801olBkA800ol0003o2o@;
o`_d2`07o`_d2`03o`000?lVfBKo9]TV00;o9]TV00?o0000oebSG?mLXe`02omLXe`00ol0003o/Tfb
ok9=/P0Aok9=/P03o`000?oX5nSoj1OX00goj1OX00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oj1OX00?o0000ol8m`_o2?L803_o2
?L800ol0003oPgb3oh=lP`09oh=lP`04o`000?m8]dSoB;M8o`0000[o3o0?00?o0000oa;]4_lBkA80
1olBkA800ol0003o2o@;o`_d2`08o`_d2`05o`000?lVfBKo9]TVobKI9_l000003OmLXe`00ol0003o
/Tfbok9=/P0Aok9=/P?o00003OoX5nP00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;on`Ck00?o0000onPGj?oX5nP03ooX5nP00ol0003o
`Sg2ol8m`P0>ol8m`P03o`000?n3O8?oPgb300SoPgb31Ol0000;o`o`3`03o`000?lBkA;o4^dB00Ko
4^dB00?o0000o`_d2ol;m0/02Ol;m0/01?l0003o9]TVobKI9_l0000=oebSG003o`000?nbCK;o/Tfb
017o/Tfb00?o0000omTVfOoI9]T00ol0000:onPGj0Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005oo/4n`03o`000?oX5nSoj1OX00koj1OX00?o0000ol8m
`_o2?L803_o2?L800ol0003oPgb3oh=lP`07oh=lP`03o`000?l/dbco;=</00?o;=</00?o0000o`o`
3ol?l0l02?l?l0l00ol0003o4^dBoa;]4P05oa;]4P03o`000?l;m0_o2o@;00[o2o@;1Ol0000<oebS
G003o`000?nbCK;o/Tfb013o/Tfb00?o0000omTVfOoI9]T01?oI9]T3o`0000Koj1OX00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000oo/4nook1?/01?ok1?/00ol0003oj1OXonPGj00=onPGj003o`000?o2?L;o`Sg200oo
`Sg200?o0000oh=lPon3O8<01?n3O8<2o`0000Oo;=</00?o0000o`o`3ol?l0l01ol?l0lEo`0000Go
9mPW00?o0000oebSG?mLXe`02?mLXe`3o`00013o/Tfb00?o0000omTVfOoI9]T02?oI9]T3o`0000;o
j1OX00?o0000ooX5n_oj1OX02?oj1OX5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oj1OXonPGj00;onPGj0Co0000
3oo2?L800ol0003oPgb3oh=lP`03oh=lP`03o`000?l/dbco;=</00So;=</00?o0000o`o`3ol?l0l0
1?l?l0l2o`0000So0o`300?o0000o`7n0Ol1oP402?l1oP400ol0003o9mPWobOH9`05obOH9`;o0000
1_mLXe`2o`0000?oLXeb00?o0000ok9=/_nbCK803?nbCK800ol0003ofBKIomTVf@0<omTVf@;o0000
4?oj1OX3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o
0000onPGj?oX5nP02OoX5nP00ol0003okQ7^o`000002olHiaP?o00003?o2?L801?l0003oPgb3oh=l
Pon3O8<2o`0000co;=</00?o0000o`o`3ol?l0l00_l?l0l00ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l1oP7o0Oh100So0Oh100?o0000obOH9olWf2L01olWf2L00ol0003oG:=LoebSG002oebSG003o`00
0?mbSG;oLXeb00CoLXeb0_l0000;ok9=/P03o`000?oI9]WofBKI00cofBKI00?o0000oo0?l?l00000
4_oj1OX00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o
0000onPGj?oX5nP01_oX5nP2o`0000;okQ7^00?o0000olHia_o6>LH00oo6>LH3o`0000[o`Sg200?o
0000oh=lPol000003ol/db`01?l0003o3o0?o`000?l0000;o`?l0`03o`000?l1oP7o0Oh100So0Oh1
00?o0000obOH9olWf2L02?lWf2L01?l0003oG:=Lo`000?l00009og:=LP03o`000?nbCK;o/Tfb00Oo
/Tfb00?o0000omTVfOoI9]T03?oI9]T01?l0003ol0o`oo0?l?l0000CooX5nP03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oX5nSoj1OX00Co
j1OX00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oaSW6olHiaP05olHiaP?o00001_o2?L84o`00013o
;=</00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW00Wo
9mPW00?o0000og:=L_mbSG802_mbSG82o`0000Ko/Tfb00?o0000omTVfOoI9]T03?oI9]T00ol0003o
l0o`oo0?l002oo0?l003o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00Co0000onPGj?oX5nSo
j1OX0_l00006onhAkP03o`000?o6>LKoaSW600SoaSW60ol000000oo2?L;o0000o`000004ogJ9MP03
o`000?l/dbco;=</00go;=</00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03
o`000?lWf2Oo9mPW00Wo9mPW00?o0000og:=L_mbSG803?mbSG800ol0003o/Tfbok9=/P03o`0000ko
fBKI00?o0000oo0?l?o`3o000oo`3o000ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000onPGj?l000002?o^4Nh00ol0003oaSW6olHiaP0;olHiaP03o`000?mfRGKoMXUf00Go
MXUf00?o0000obcC;?l/db`03?l/db`00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l1oP7o0Oh100Oo
0Oh100?o0000obOH9olWf2L02?lWf2L2o`0000ooLXeb0_l00002ol/db`03o`000?oI9]WofBKI00_o
fBKI00?o0000oo0?l?o`3o001?o`3o000ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003oaSW6olHiaP0;olHiaP03o`000?mfRGKoMXUf00KoMXUf00?o0000obcC;?l/db`0
2ol/db`2o`0000go0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9mPWobOH9`07obOH9`04o`00
0?ll`cco?<<lo`0000koLXeb00?o0000ol/dboo;=</00_o;=</00ol0003ofBKIomTVf@09omTVf@03
o`000?o`3o3ol0o`00Kol0o`00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000oo/4nook1?/02_ok1?/2o`0000Wo
kQ7^00?o0000olHia_o6>LH02oo6>LH00ol0003oMXUfogJ9MP07ogJ9MP03o`000?l/dbco;=</00Wo
;=</00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW
00Ko9mPW00Go0000occ3??ll`cco?<<lo`00000>og:=LP03o`000?o;=<_obcC;00?obcC;00?o0000
omTVfOoI9]T01ooI9]T00ol0003ol0o`oo0?l007oo0?l003o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00Co0000ooT6nOoi1_Wo00002Oo^4Nh00ol0003oaSW6olHiaP09olHiaP03o`000?mfRGKo
MXUf00WoMXUf00?o0000obcC;?l/db`01ol/db`00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9mPWobOH9`05obOH9`03o`000?ll`cco
?<<l00?o?<<l00?o0000og:=L_mbSG802_mbSG800ol0003obcC;ol/db`05ol/db`03o`000?oI9]Wo
fBKI00GofBKI00?o0000oo0?l?o`3o002?o`3o000ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won`Ck00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okQ7^onhAkP06onhAkP03o`000?o6>LKoaSW600WoaSW600?o0000ogJ9
M_mfRGH02_mfRGH00ol0003o;=</obcC;005obcC;003o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW00Co9mPW00?o0000occ3
??ll`c`01?ll`c`00ol0003oLXebog:=LP0:og:=LP03o`000?o;=<_obcC;00KobcC;00?o0000omTV
fOoI9]T00ooI9]T00ol0003ol0o`oo0?l009oo0?l003o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ook1?/00ol0003o
n@KiooT6n@03ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000olHia_o6>LH02Oo6>LH00ol0003o
MXUfogJ9MP0;ogJ9MP03o`000?l/dbco;=</00?o;=</00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l1oP7o0Oh100Ko0Oh100?o0000obOH9olWf2L00_lWf2L2o`0000So
?<<l00?o0000og:=L_mbSG802OmbSG800ol0003obcC;ol/db`07ol/db`05o`000?oI9]WofBKIomTV
fOl000003Oo`3o000ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ook1?_o0000ooT6n@06ooT6n@03
o`000?o^4NkokQ7^00GokQ7^00?o0000olHia_o6>LH02Oo6>LH00ol0003oMXUfogJ9MP0<ogJ9MP05
o`000?l/dbco;=</obcC;?l000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh1
00Ko0Oh100?o0000obOH9ol000000_l000000olCk1?o0000occ3?007occ3?003o`000?mbSG;oLXeb
00SoLXeb00?o0000ol/dboo;=</02Oo;=</00ol0003ofBKIo`00000=oo0?l0Co00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oaSW6olHiaP09olHiaP03
o`000?mfRGKoMXUf00goMXUf00?o0000obcC;?l000003?l9mPT:o`0000Oo0Oh10ol00005oa?/4`03
o`000?ll`cco?<<l00Ko?<<l00?o0000og:=L_mbSG801ombSG800ol0003obcC;ol/db`0:ol/db`03
o`000?o`3o3ol0o`00_ol0o`00?o0000oo`3o?ol0o`00_ol0o`3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olHia_o6>LH01oo6>LH00ol0003oMXUfogJ9MP0?ogJ9MP;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100;o0Oh10ol00008oa?/4`03o`00
0?ll`cco?<<l00Ko?<<l00?o0000og:=L_mbSG801ombSG800ol0003obcC;ol/db`0:ol/db`03o`00
0?o`3o3ol0o`00[ol0o`00?o0000oo`3o?ol0o`01_ol0o`00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o^4NkokQ7^00CokQ7^00?o0000olHia_o6>LH01oo6>LH00ol0003oMXUfogJ9
MP0>ogJ9MP04o`000?ldbcCo=</do`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0Oh1
o`000?l0000<oa?/4`03o`000?ll`cco?<<l00Ko?<<l00?o0000og:=L_mbSG801_mbSG800ol0003o
bcC;ol/db`0;ol/db`03o`000?o`3o3ol0o`00Ool0o`0_l00009oo`3o003o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh00oo^4Nh>o`0000goMXUf00?o0000ocC;=?ldbc@0
0_ldbc@00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oa?/4olCk1<0
3?lCk1<00ol0003o?<<locc3?006occ3?003o`000?mbSG;oLXeb00GoLXeb00?o0000ol/dboo;=</0
3?o;=</00ol0003ol0o`oo0?l006oo0?l003o`000?ol0ocoo0?l00[oo0?l00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okQ7^onhAk_o^4Nko000000_od2o@00?o0000og6>LOmaSW400ol00009ogJ9MP03o`00
0?ldbcCo=</d00Co=</d00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lCk1?o4n`C00go4n`C00?o0000occ3??ll`c`01_ll`c`00ol0003oLXebog:=LP03og:=LP?o0000
3Oo;=</00ol0003ol0o`oo0?l005oo0?l003o`000?ol0ocoo0?l00coo0?l0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cod2o@00?o0000og6>LOmaSW400omaSW43o`0000GoMXUf00?o0000ocC;=?ldbc@01_ld
bc@01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oa?/4olCk1<03OlCk1<00ol0003o?<<l
occ3?006occ3?003o`000?mbSG;oLXeb00?o00000on=LXd00ol0003obcC;ol/db`0;ol/db`03o`00
0?o`3o3ol0o`00?ol0o`00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003ooD:m@03o`000?o@;m3od2o@00[od2o@00?o0000og6>LOmaSW401_maSW43o`000003ogJ9M_l0
003o=</d00Wo=</d00?o0000o`Wf2Ol000004?l9mPT00ol0003o4n`Coa?/4`0=oa?/4`03o`000?ll
`cco?<<l00Oo?<<l0_l00007ohebS@03o`000?o;=<_obcC;00[obcC;00Co0000oo0?l?o`3o3ol0o`
0ol0000?oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom@[e00?o0000om0_d?o@
;m002_o@;m000ol0003oLHiaog6>L@09og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o4n`Coa?/4`0>oa?/4`03o`000?ll`cco?<<l00Ko?<<l00?o0000ohebSOn=
LXd01on=LXd4o`0000SobcC;00Co0000oo0?l?o`3o3o00000oof2OH2o`0000goo0?l00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002Oo@;m000ol0003o
LHiaog6>L@0:og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
4n`Coa?/4`0>oa?/4`03o`000?ll`cco?<<l00Go?<<l00?o0000ohebSOn=LXd02?n=LXd01?l0003o
d2o@om0_d?o@;m07o`0000;obcC;0_l00006ooH9mP;o00003?ol0o`00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003od2o@om0_d008om0_d003o`000?maSW7oLHia00[o
LHia00?o0000ocC;=?ldbc@02oldbc@00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lCk1?o4n`C00ko
4n`C1Ol00002occ3?003o`000?n=LXgoSG:=00WoSG:=00?o0000om0_d?o@;m002?o@;m03o`0000Wo
mPWf0_l0000:oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@07ooD:m@03o`00
0?o@;m3od2o@00Sod2o@00?o0000og6>LOmaSW402_maSW400ol0003o=</docC;=00:ocC;=0;o0000
3_l9mPT3o`0000go4n`C0ol00005odVfB@;o00002on=LXd00ol0003od2o@om0_d00;om0_d0;o0000
2_of2OH2o`0000Ooo0?l0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002?o@;m0>o`0000Wo=</d0ol000000olXebSo0000
o`Wf2@0:o`Wf2@?o00000_lKi1/00ol0003o4n`Coa?/4`09oa?/4`;o00002Om9]TT00ol0003oSG:=
ohebS@09ohebS@03o`000?o@;m3od2o@00_od2o@00?o0000onHIi_l000002oof2OH2o`0000Coo0?l
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oe2_Gom@[e00Kom@[e00?o0000om0_d?o@;m002?o@;m000ol0003oL8m`
og2?L00:og2?L003o`000?ldbcCo=</d00Co=</d0ol00005obSG:003o`000?l9mPWo2OH900Co2OH9
1?l00006oa_T6`03o`000?lCk1?o4n`C00Ko4n`C0_l0000;odVfB@03o`000?n=LXgoSG:=00WoSG:=
00?o0000om0_d?o@;m002_o@;m001Ol0003oiQWVonHIi_oV6NKo000000comPWf0_l000000ool0oco
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003od2o@om0_d007om0_d003o`00
0?m`Sg3oL8m`00_oL8m`00?o0000ocC;=?ldbc@00_ldbc@2o`0000Wo:=LX00?o0000o`Wf2Ol9mPT0
0ol0000;oa_T6`03o`000?lCk1?o4n`C00;o4n`C0ol0000>odVfB@03o`000?n=LXgoSG:=00OoSG:=
00?o0000om0_d?o@;m002oo@;m000ol0003oiQWVonHIiP02onHIiP03o`000?of2OKomPWf00_omPWf
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000ooD:mOoe2_D01ooe2_D00ol0003od2o@om0_d005om0_d0?o00003Om`
Sg04o`0000_o:=LX0ol0000?oa_T6`04o`000?lCk1?o0000o`00017oBKI900?o0000ohebSOn=LXd0
1on=LXd00ol0003od2o@om0_d00:om0_d003o`000?oV6NKoiQWV00CoiQWV00?o0000ooH9m_of2OH0
1oof2OH3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om@[eooD:
m@06ooD:m@03o`000?o@;m3od2o@00;od2o@0ol00003ok1?/003o`000?m`Sg3oL8m`00[oL8m`00?o
0000obSG:?lXebP02olXebP00ol0003o8m`So`00000Aoa_T6`03o`000?m9]TWoBKI9017oBKI900?o
0000ohebSOn=LXd01on=LXd00ol0003od2o@om0_d00:om0_d003o`000?oV6NKoiQWV00GoiQWV00Co
0000ooH9m_of2OKomPWf1Ol00002ooP7n003o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@05ooD:m@?o0000
00?od2o@o`000?l000001on`Ck000ol0003oL8m`og2?L008og2?L0?o00002_lXebP2o`0000;o8m`S
00?o0000oa_T6olKi1/03olKi1/00ol0003oBKI9odVfB@0AodVfB@03o`000?n=LXgoSG:=00OoSG:=
00?o0000om0_d?o@;m002Oo@;m000ol0003oiQWVonHIiP07onHIiP?o00001ooh1oP00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om@[e0_l00003onl@k`03o`000?n`Ck3o/4n`00So/4n`0_l00006og2?L0;o00000omM
XUd00ol0003o:=LXobSG:006obSG:003o`000?lSg2?o8m`S00?o8m`S00?o0000oa_T6olKi1/03_lK
i1/00ol0003oBKI9odVfB@0BodVfB@03o`000?n=LXgoSG:=00GoSG:=00?o0000om0_d?o@;m002Oo@
;m000ol0003oiQWVonHIiP08onHIiP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo_4>l00ol0003o/4n`ok1?/00:ok1?/003o`000?m`Sg3oL8m`00;oL8m`00?o0000
oefRGOmMXUd01?mMXUd00ol0003o:=LXobSG:004obSG:003o`000?lSg2?o8m`S00Co8m`S00?o0000
oa_T6olKi1/03_lKi1/00ol0003oBKI9odVfB@0BodVfB@[o00002_o@;m000ol0003oiQWVonHIiP08
onHIiP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onl@koo_4>l01?o_4>l0
0ol0003o/4n`ok1?/00:ok1?/004o`000?m`Sg3o0000o`0000SoGJ9M00Co0000obSG:?lXebSo:=LX
0_l00007ob?L8`03o`000?lKi1_o6n@K00ko6n@K00?o0000odVfBOm9]TT04_m9]TT00ol0003oZEJY
ojUFZ@07ojUFZ@03o`000?o@;m3od2o@00Kod2o@00?o0000onHIi_oV6NH02_oV6NH00ol0003on0Oh
ooP7n006ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onl@koo_4>l01?o_4>l00ol0003o/4n`ok1?/00;ok1?/003o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obSG:?l000002OlSg2<00ol0003o6n@Koa_T6`0>oa_T6`;o0000
4_m9]TT00ol0003oZEJYojUFZ@09ojUFZ@;o00001_o@;m000ol0003oiQWVonHIiP0:onHIiP03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?n`Ck3o/4n`00[o/4n`00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa_T6olKi1/03_lKi1/00ol0003o?L8mo`00
0002o`0000ooBKI900?o0000ojUFZOnYEZT02onYEZT00ol0003od2o@om0_d003o`0000goiQWV00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o_4>ooka3_00Goka3_00?o0000ok1?/?n`Ck002On`Ck02
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lKi1_o6n@K00co6n@K00?o0000ocg2?Olm`Sd00olm`Sd3
o`0000coBKI900?o0000ojUFZOnYEZT03?nYEZT2o`0000;ohacS00?o0000onHIi_oV6NH03?oV6NH0
0ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o/4n`ok1?/007ok1?
/003o`000?naC[7o000000[oGJ9M00Co0000oe:]D_mB[E;o00002_lSg2<00ol0003o6n@Koa_T6`0<
oa_T6`03o`000?lm`Sgo?L8m00Ko?L8m0_l00008odVfB@;o00003onYEZT00ol0003ohacSon<Lh`02
on<Lh`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o_4>ooka3_
00Koka3_00?o0000ok1?/?n`Ck001_n`Ck001Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe:]D_mB[E800_mB[E800ol0003o8m`Sob?L8`06ob?L8`Co00003?lKi1/00ol0003o?L8mocg2?@08
ocg2?@?o00000_m9]TT3o`000003ohQgR?l0003oZEJY00goZEJY00?o0000on<LhooS7><01?oS7><0
0ol0003oiQWVonHIiP0:onHIiP03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`07onl@
k`03o`000?n`Ck3o/4n`00?o/4n`0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe:]
D_mB[E800omB[E800ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa_T
6`;o00003_lm`Sd2o`0000GoR7N800?o0000ojUFZOnYEZT02_nYEZT00ol0003ohacSon<Lh`05on<L
h`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o_4>ooka3_00Oo
ka3_00?o0000ok1?/?n`Ck000_n`Ck000ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe:]D_mB[E801OmB[E800ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6n@K0_l000000olRgB;o0000ocg2?@0=ocg2?@03o`000?n8MhSoR7N800GoR7N800?o0000ojUFZOnY
EZT02?nYEZT00ol0003ohacSon<Lh`07on<Lh`03o`000?oV6NKoiQWV00[oiQWV00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o_4>ooka3_00Soka3_00Co0000ok1?/?n`Ck3o00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDZeB00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lRgB80
0ol0003o?L8mocg2?@0;ocg2?@03o`000?n8MhSoR7N800KoR7N800?o0000ojUFZOnYEZT01onYEZT0
0ol0003ohacSon<Lh`08on<Lh`Co00002?oV6NH00ol0003on0OhooP7n004ooP7n003o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onl@
k`03o`000?n`Ck3o000000_o/Dja00?o0000oefRGOl000002_mB[E800ol0003o8m`So`00000?oagR
7@03o`000?lRgB;o8]dR00;o8]dR00?o0000ocg2?Olm`Sd02olm`Sd00ol0003oR7N8ohQgR006ohQg
R003o`000?nYEZWoZEJY00KoZEJY00?o0000on<LhooS7><02OoS7><01?l0003olPgboo8=l_ob3O87
o`0000;oiQWV00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o_4>ooka3_00Ooka3_00?o0000ok5>
/OnaC[402onaC[400ol0003oDZeBoe:]DP0:oe:]DP03o`000?lMhQgo7N8M00go7N8M00?o0000ob;M
8_lRgB801?lRgB800ol0003o?L8mocg2?@09ocg2?@03o`000?n8MhSoR7N800SoR7N800?o0000ojUF
ZOnYEZT00onYEZT2o`0000cohacS00?o0000oo8=l_ob3O802?ob3O8<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mB[E;oDZeB00WoDZeB0_l0000>oagR7@03o`000?lRgB;o8]dR00Go
8]dR00?o0000ocg2?Olm`Sd02Olm`Sd00ol0003oR7N8ohQgR009ohQgR003o`000?nYEZWo000000;o
00000_oH9mP00ol0003ohacSon<Lh`08on<Lh`03o`000?ob3O;olPgb00colPgb00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?oo`3o0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003oka3_
onl@k`04onl@k`03o`000?naC[7o/Dja00_o/Dja0ol00007oe:]DP?o000000?o?<<lo`000?lMhQd0
3OlMhQd00ol0003o8]dRob;M8P06ob;M8P03o`000?lm`Sgo?L8m00So?L8m00?o0000ohQgR?n8MhP0
2_n8MhP00ol0003of2OHomPWf004omPWf003o`000?oS7>?ohacS00OohacS00?o0000oo8=l_ob3O80
2oob3O800ol0003onPGjooX5nP08ooX5nP03o`000?oo0?ooo`3o00Coo`3o0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onl@koo_4>l00oo_4>l>o`0000?oW6>L0_l00002oe:]DP?o0000
1Oll`c`00ol0003o7N8MoagR7@0:oagR7@03o`000?lRgB;o8]dR00Oo8]dR00?o0000ocg2?Olm`Sd0
2?lm`Sd00ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Gof2OH00?o0000on<LhooS7><0
1_oS7><00ol0003olPgboo8=lP0;oo8=lP03o`000?oj1O[onPGj00SonPGj00?o0000ool0oooo0?l0
1ooo0?l2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onl@koo_4>l00_o_4>l00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009occ3?003o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob;M8_lRgB802?lRgB82o`0000So?L8m00?o0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPW
f007omPWf003o`000?oS7>?ohacS00CohacS00?o0000oo8=l_ob3O802oob3O800ol0003onPGjooX5
nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?oka3_
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?ll`cco?<<l00Wo?<<l00?o0000
oagR7OlMhQd01olMhQd00ol0003o8]dRob;M8P09ob;M8P04o`000?m5^TGo0000o`0000Ko?L8m00?o
0000ohQgR?n8MhP02On8MhP00ol0003of2OHomPWf008omPWf003o`000?oS7>?ohacS00?ohacS00?o
0000oo8=l_ob3O802oob3O800ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooj1OX2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o?<<locc3?00:occ3?0Wo00002olRgB800ol0003oAKY5odFjA@02odFjA@?o00000_lm`Sd0
0ol0003oR7N8ohQgR00:ohQgR003o`000?oH9mSof2OH00Wof2OH00?o0000on<LhooS7><00_oS7><0
0ol0003olPgboo8=lP0:oo8=lP03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000GonPGj00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?ll`cco?<<l00Wo?<<l00?o0000obKI9_lVfBH01OlVfBH00ol0003o8]dRob;M8P09ob;M
8P03o`000?m5^TGoAKY500GoAKY50ol00009ohQgR0?o00003OoH9mP01Ol0003ohacSon<LhooS7>?o
000000colPgb00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000OonPGj00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?ll`cco?<<l00So?<<l00?o0000obKI9_lVfBH01olVfBH00ol0003o8]dRob;M8P07
ob;M8P03o`000?m5^TGoAKY500SoAKY50ol00002ohQgR0Go00000_o0?l000ol0003of2OHomPWf00<
omPWf003o`000?oS7>?o000000colPgb00?o0000ooX5n_oj1OX02_oj1OX00ol0003oo`3oool0o`0:
ool0o`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000SonPGj00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o?<<locc3?008occ3?003o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob;M8_lRgB801olRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;
00;o00002?o0?l000ol0003of2OHomPWf00<omPWf0Co00002_ob3O800ol0003onPGjooX5nP0:ooX5
nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooX5nP03o`000?o^4NkokQ7^
00;okQ7^00?o0000olPgb?o8=lP00_o8=lP4o`0000WoW6>L00?o0000occ3??ll`c`02?ll`c`00ol0
003o9]TVobKI9P08obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000odFjAOm5^TD02?m5^TD01Ol0
003oRgB;oh]dRon;M8_o000000[o`3o00ol0000;omPWf004o`000?og2?Oom`SgooL8m`Co00001Oob
3O800ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003onPGjooX5nP0:
ooX5nP03o`000?o^4NkokQ7^00?okQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oW6>LoiaSW007
oiaSW003o`000?ll`cco?<<l00Ko?<<l0_l0000;obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000
odFjAOm5^TD02?m5^TD00ol0003oRgB;oh]dR`02oh]dR`03o`000?o0?l3o`3o000Oo`3o000?o0000
onXEj_oZ5NX01?l00006omPWf003o`000?og2?Oom`Sg00Kom`Sg0ol00002oo8=lP03o`000?oj1O[o
nPGj00_onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj00WonPGj00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ob3O8olPgb005olPgb003o`000?nLHicoW6>L00OoW6>L00?o0000occ3
??ll`c`00_ll`c`3o`000003oeNXEol0003o9]TV00[o9]TV00?o0000ob;M8_lRgB801OlRgB800ol0
003oAKY5odFjA@07odFjA@03o`000?n;M8_oRgB;00?oRgB;00?o0000ol0o`?o0?l001oo0?l000ol0
003ojQGZonXEjP04onXEjP?o00000_oH9mP00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003oo`3oool0o`0;ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003okQ7^onhAkP04onhAkP03
o`000?o8=lSob3O800Kob3O80_l00007oiaSW003o`000?ll`cco000000;o00001OmGZ5L00ol0003o
9]TVobKI9P08obKI9P?o00001?lRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;00Co
RgB;00?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP07onXEjP;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oc3?<ol`cc003o`0000CoW6>L
0_l00008oeNXE`03o`000?lVfBKo9]TV00Oo9]TV00Co0000odfbCOm=/TgoCK9=0ol000000olRgB;o
0000odFjA@09odFjA@03o`000?n;M8_oRgB;00CoRgB;00?o0000ol0o`?o0?l001Oo0?l000ol0003o
jQGZonXEjP09onXEjP03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
o`3oool0o`0<ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003okQ7^onhAkP06onhAkP03o`00
0?o8=lSob3O800?ob3O800?o0000ol`cc?o<<l`01?o<<l`2o`000003oiaSW?l0003oEjQG00[oEjQG
00?o0000obKI9_lVfBH01OlVfBH00ol0003oCK9=odfbC@05odfbC@03o`000?m5^TGoAKY500OoAKY5
0ol00007oh]dR`03o`000?o0?l3o`3o000Co`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj
1O[onPGj00GonPGj0ol00009onhAkP05o`000?o8=lSob3O8olPgb?l000002Oo<<l`00ol0003oEjQG
oeNXE`0;oeNXE`03o`000?lVfBKo9]TV00?o9]TV00?o0000odfbCOm=/Td01_m=/Td00ol0003oAKY5
odFjA@06odFjA@05o`000?n6NHKoQWV6ohIiQ_l000001on;M8/00ol0003o`3o0ol0o`003ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjo`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003ob3O8olPgb?l00009ol`cc0;o00003OmGZ5L00ol0003o9]TVobKI9P02obKI9P03
o`000?m=/TgoCK9=00SoCK9=00?o0000odFjAOm5^TD00om5^TD2o`0000GoQWV600?o0000oh]dRon;
M8/01?n;M8/00ol0003o`3o0ol0o`003ol0o`003o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ob3O8o`000009ol`cc004o`000?n/Djco[5>/o`0000go
EjQG00Co0000obKI9_lVfBKo00003?m=/Td01Ol0003oAKY5odFjAOm5^TGo000000SoQWV60_l00005
oh]dR`03o`000?o0?l3o`3o000;o`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003oc3?<ol`cc007ol`cc003o`000?n/Djco[5>/
00;o[5>/00?o0000oeNXEomGZ5L02_mGZ5L00ol0003o9]TVo`00000>odfbC@03o`000?m5^TGo0000
00_oQWV600?o0000oh]dRon;M8/00_n;M8/01Ol0003o`3o0ol0o`?o0?l3o000000cojQGZ00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n/Djco[5>/
00?o[5>/00?o0000oeNXEomGZ5L02omGZ5L00ol0003oCK9=odfbC@0>odfbC@03o`000?n6NHKoQWV6
00_oQWV60_l00003oh]dR`04o`000?o0?l3o`3o0o`0000[ojQGZ0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?n/Djco[5>/00Go[5>/00?o0000oeNX
EomGZ5L01omGZ5L3o`00017oCK9=00?o0000ohIiQ_n6NHH03On6NHH01Ol0003oRgB;oh]dRol0003o
`3o000Co00000ooZ5NX5o`0000;on`Ck00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0003o[5>/ojaC[006ojaC[003o`000?mGZ5OoEjQG
00CoEjQG0ol00002of6NH@03o`000?m=/TgoCK9=00ooCK9=0_l0000?ohIiQP04o`000?n;M8_o0000
o`0000Cogb3O0ol00008oo/4n`03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003oo`3oool0o`07ool0o`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000Ooc3?<00?o0000ojaC
[?n/Dj`02?n/Dj`00ol0003oEjQGoeNXE`03o`0000KoHIiQ00?o0000odfbCOm=/Td03Om=/Td01?l0
003oSW6>ohiaS_l0000?ohIiQP03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/02?ok1?/0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ool0o`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o<<lcoc3?<00?oc3?<00?o0000ojaC[?n/Dj`02_n/Dj`2o`0000[oHIiQ00?o0000odfb
COm=/Td02om=/Td00ol0003oSW6>ohiaSP02ohiaSP03o`000?n6NHKoQWV600_oQWV60_l00007omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ool0
oooo0?l00ooo0?l3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o<<lcoc3?<ol`c
c?l000003On/Dj`00ol0003oHIiQof6NH@0:of6NH@03o`000?m=/TgoCK9=00WoCK9=00?o0000ohia
S_n>LHh01?n>LHh00ol0003oQWV6ohIiQP08ohIiQP;o000000?o/Djao`000?oO8=l01ooO8=l00ol0
003on`Ckoo/4n`09oo/4n`04o`000?og2?Oo0000o`0001CooP7n00?o0000ool0oooo0?l00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003oc3?<o`00000=ojaC[003o`000?mQWV7oHIiQ
00_oHIiQ00?o0000odfbCOm=/Td02?m=/Td00ol0003oSW6>ohiaSP06ohiaSP03o`000?n6NHKoQWV6
00GoQWV60_l00003ok5>/@03o`000?oO8=oogb3O00Kogb3O00?o0000oo/4nook1?/02_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000ojaC[?n/
Dj`03?n/Dj`00ol0003oHIiQof6NH@0<of6NH@03o`000?m=/TgoCK9=00KoCK9=00?o0000ohiaS_n>
LHh02?n>LHh00ol0003oQWV6ohIiQP02ohIiQP;o00001_naC[400ol0003ogb3OomlPg`05omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000co[5>/00?o0000of6NHOmQWV403OmQWV400ol0003oCK9=
odfbC@04odfbC@03o`000?n>LHkoSW6>00[oSW6>00Co0000ohIiQ_l0003o00002?naC[400ol0003o
gb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oC;=?o000000;o00002?n/Dj`00ol0003oHIiQ
of6NH@0?of6NH@Ko00003_n>LHh00ol0003o/Djaok5>/@08ok5>/@03o`000?oO8=oogb3O00Kogb3O
00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oC;=?odbcC00?odbcC0ol00005ojaC[0;o00004?mQWV401_l0003oMHYe
ogF:MOl0003oJiA[o`0000koSW6>00?o0000ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`05omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oC;=?odbcC00KodbcC0ol000001?n/Djco0000oi5^TOnAKY43o`00
00coHIiQ00Go0000ogF:MOmeRWGoMHYeo`000002of^DJ`03o`000?n>LHkoSW6>00_oSW6>00?o0000
ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Son`Ck0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oC;=<00ol0003oTFjAoi5^T@04oi5^
T@?o00002?mQWV400ol0003oMHYeogF:M@02ogF:M@05o`000?m[U6_oJiA[of^DJol000003?n>LHh0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oO8=oogb3O00Gogb3O3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om</
dooC;=<02_oC;=<00ol0003oTFjAoi5^T@07oi5^T@;o00001OmQWV400ol0003oMHYeogF:M@03ogF:
M@03o`000?m[U6_oJiA[00;oJiA[00?o0000ohiaS_n>LHh02On>LHh00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om</dooC;=<02ooC;=<00ol0003oTFjAoi5^T@09oi5^T@?o000000?oHIiQo`000?me
RWD01OmeRWD00ol0003oJiA[of^DJ`03of^DJ`03o`000?n>LHkoSW6>00SoSW6>3_l00003omlPg`;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003omPWfo`00000;oo0?l003o`000?oC;=?odbcC00[odbcC
0_l0000>oi5^T@03o`000?meRWGoMHYe00GoMHYe00?o0000of^DJom[U6/00om[U6/00ol0003oSW6>
ohiaSP08ohiaSP03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omlPgol000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooH9m_of2OKo00002_o`3o000ol0003odbcCom</d`09om</d`03o`000?o0?l3o000000koTFjA
00?o0000ogF:MOmeRWD01OmeRWD00ol0003oJiA[of^DJ`04of^DJ`03o`000?n>LHkoSW6>00KoSW6>
00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH00_of
2OH00ol0003ol0o`oo0?l006oo0?l003o`000?oC;=?odbcC00SodbcC0_l00003ol0o`003o`000?nA
KY7oTFjA00_oTFjA00?o0000ogF:MOmeRWD01OmeRWD00ol0003oJiA[of^DJ`05of^DJ`03o`000?n>
LHkoSW6>00GoSW6>00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooH9m_of2OH00oof2OH00ol0003ol0o`oo0?l005oo0?l003o`000?oC;=?odbcC00OodbcC00?o0000
ol0o`?o0?l000oo0?l000ol0003oTFjAoi5^T@0:oi5^T@03o`000?meRWGoMHYe00KoMHYe00?o0000
of^DJom[U6/01_m[U6/00ol0003oSW6>ohiaSP04ohiaSP03o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01Oof2OH00ol0
003ol0o`oo0?l004oo0?l003o`000?oC;=?odbcC00GodbcC0_l00006ol0o`003o`000?nAKY7oTFjA
00WoTFjA0_l00008ogF:M@03o`000?m[U6_oJiA[00KoJiA[1Ol000000on>LHko0000on4Nh@0?on4N
h@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01_of2OH00ol0003o
l0o`oo0?l004o`0000KodbcC00?o0000ol0o`?o0?l001oo0?l000ol0003oTFjAoi5^T@05oi5^T@?o
000000?oTFjAo`000?meRWD01omeRWD00ol0003oJiA[of^DJ`05of^DJ`03o`000?n^DJko[U6^00?o
[U6^0_l0000?on4Nh@;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo0?l00?o0000ooH9m_of2OH01oof2OH2o`0000CojAKY00Co0000om</dooC;=?o
dbcC0_l0000:ol0o`003o`000?nAKY7oTFjA00;oTFjA0ol00005oi5^T@03o`000?meRWGoMHYe00Go
MHYe00?o0000of^DJom[U6/01?m[U6/00ol0003o[U6^ojiA[P06ojiA[P03o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003omPWfooH9mP08ooH9mP03o`00
0?oY5^WojAKY00CojAKY00?o0000om</dol000003?o0?l000ol0003oTFjAo`000002o`0000WoTFjA
00?o0000ogF:MOmeRWD01?meRWD00ol0003oJiA[of^DJ`03of^DJ`03o`000?n^DJko[U6^00So[U6^
1_l00004on4Nh@;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH01oof
2OH00ol0003ojAKYonTFj@06onTFj@03o`000?o0?l3o`3o000co`3o000?o0000oi5^TOnAKY402_nA
KY400ol0003oMHYeogF:M@04ogF:M@04o`000?m[U6_oJiA[of^DJ`;o00002on^DJh00ol0003oj1OX
onPGj003onPGj0Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003omPWfooH9mP07ooH9mP03o`000?oY
5^WojAKY00OojAKY00?o0000ol0o`?o0?l003?o0?l000ol0003oTFjAoi5^T@0;oi5^T@03o`000?me
RWGoMHYe00?oMHYe00Co0000of^DJom[U6_o00003On^DJh00ol0003oj1OXonPGj006onPGj003o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000ooH9m_of2OH0
1_of2OH00ol0003ojAKYonTFj@09onTFj@03o`000?o0?l3o`3o000Wo`3o00_l0000>oi5^T@?o0000
0omeRWD00ol0003oJiA[o`00000=ojiA[P03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000OomPWf00?o
0000onTFjOoY5^T02_oY5^T00ol0003o`3o0ol0o`006ol0o`0;o000000?o`Ck1o`000?nAKY402onA
KY42o`0000?oWf2O1Ol0000>ojiA[P03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`03oo/4n`Co00000_of2OH00ol0003ojAKYonTFj@0;
onTFj@03o`000?o0?l3o`3o000?o`3o00ol00004ol4n`@03o`000?nAKY7oTFjA00OoTFjA0_l00008
oimPW`03o`000?n^DJko[U6^00go[U6^00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onTFj@03o`000?o0?l3o`3o000;o00002?o1?/400ol0
003oTFjAoi5^T@05oi5^T@03o`000?nOH9ooWf2O00SoWf2O00?o0000ojiA[_n^DJh03On^DJh00ol0
003oj1OXonPGj008onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oY5^WojAKY00kojAKY0_l0000;ol4n`@03o`000?nAKY7oTFjA00;oTFjA0_l0000;oimP
W`03o`000?n^DJko[U6^00go[U6^00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00gojAKY0_l0000<ol4n`@04o`000?nAKY7o0000
o`0000goWf2O00?o0000ojiA[_n^DJh03?n^DJh00ol0003oj1OXonPGj009onPGj003o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00cojAKY00Co0000on<L
hooS7>?o00003?o1?/400ol0003oWf2OoimPW`0>oimPW`03o`000?n^DJko[U6^00So[U6^1?l0000;
onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oY5^WojAKY
00_ojAKY00?o0000on<LhooS7><00_oS7><00ol0003o`Ck1ol4n`@09ol4n`@03o`000?nOH9ooWf2O
00koWf2O00Co0000ojiA[_n^DJko[U6^1ol00003oll`c`03o`000?oX5nSoj1OX00Woj1OX00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000onTFjOoY5^T02_oY5^T00ol0
003ohacSon<Lh`03on<Lh`03o`000?o1?/7o`Ck100So`Ck100?o0000oimPWonOH9l03_nOH9l4o`00
00_occ3?00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook
1?/03?ok1?/7o`0000GojAKY00?o0000on<LhooS7><01OoS7><00ol0003o`Ck1ol4n`@07ol4n`@03
o`000?nOH9ooWf2O00koWf2O00?o0000oll`coo?<<l03Oo?<<l00ol0003oj1OXonPGj008onPGj003
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oe2_Gom@[e00Com@[e
1Ol00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oimPWonOH9l03_nOH9l00ol0003occ3?
oll`c`0=oll`c`03o`000?oX5nSoj1OX00Soj1OX00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=oo/4n`03o`000?oe2_Gom@[e00Wom@[e
0_l00009on<Lh`03o`000?o1?/7o`Ck100Ko`Ck100?o0000oimPWonOH9l03?nOH9l00ol0003occ3?
oll`c`0?oll`c`Ko00001?oX5nP4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m@[eooD:m@09ooD:m@03o`000?o/4nco000000;o00001ooS7><00ol0003o`Ck1ol4n`@05ol4n`@03
o`000?nOH9ooWf2O00SoWf2O1Ol0000Aoll`c`03o`000?o_4>ooka3_00?oka3_1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000ooD:mOoe2_D02_oe2_D00ol0003ok1?/on`Ck002on`Ck0?o00001OoS7><00ol0003o`Ck1
ol4n`@04ol4n`@04o`000?nOH9ooWf2OoimPW`Oo00001?o?<<l00ol0003occ3?oll`c`0>oll`c`03
o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om@[e
ooD:m@0;ooD:m@03o`000?o/4ncok1?/00Gok1?/0ol00003on<Lh`04o`000?o1?/7o`Ck1ol4n`@Ko
00003?o?<<l00ol0003occ3?oll`c`0=oll`c`03o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?oe2_D0
3?oe2_D00ol0003ok1?/on`Ck008on`Ck0?o000000CohacSo`000?l0003o00000_oY5^T00ol0003o
cc3?oll`c`0=oll`c`03o`000?o?<<oocc3?00cocc3?00?o0000onl@koo_4>l02?o_4>l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003ok1?/on`Ck00;on`Ck003o`000?oY5^WojAKY00?o
jAKY00?o0000oll`coo?<<l03?o?<<l00ol0003of2OHo`00000=oll`c`03o`000?o_4>ooka3_00So
ka3_00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003ok1?/on`Ck00:on`Ck003o`00
0?oY5^WojAKY00GojAKY00?o0000oll`coo?<<l02_o?<<l01?l0003of2OHomPWf?oH9mP2o`0000[o
cc3?00?o0000onl@koo_4>l02Oo_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooD:mOoe2_D0
3?oe2_D00ol0003ok1?/on`Ck009on`Ck003o`000?oY5^WojAKY00KojAKY00?o0000oll`coo?<<l0
2Oo?<<l00ol0003of2OHomPWf002omPWf003o`000?o[5>_o000000;o00001oo?<<l00ol0003oka3_
onl@k`09onl@k`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@0;ooD:m@03o`000?o/
4ncok1?/00Sok1?/00?o0000onTFjOoY5^T01ooY5^T00ol0003occ3?oll`c`08oll`c`03o`000?oH
9mSof2OH00?of2OH00?o0000on/Djoo[5>/00_o[5>/2o`0000Cocc3?00?o0000onl@koo_4>l02_o_
4>l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;ooD:m@Ko00001?o/4n`00ol0003ojAKYonTFj@08
onTFj@03o`000?o?<<oocc3?00Oocc3?00?o0000omPWf?oH9mP00ooH9mP00ol0003ojaC[on/Dj`05
on/Dj`?o000000?occ3?o`000?o_4>l02oo_4>l00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006ooD:m@03o`000?og2?Oom`Sg00Com`Sg1?l0000<onTFj@03o`000?o?<<oocc3?
00Gocc3?00?o0000omPWf?oH9mP01?oH9mP00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_
00_oka3_00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om@[e00?o0000ooL8moog
2?L02?og2?L00ol0003ojAKYonTFj@0:onTFj@03o`000?o?<<oocc3?00Cocc3?00?o0000omPWf?oH
9mP01OoH9mP00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_00Woka3_1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooL8m`03o`000?oY5^WojAKY00WojAKY
00?o0000oll`coo?<<l00oo?<<l00ol0003of2OHomPWf005omPWf003o`000?o[5>_ojaC[00[ojaC[
00?o0000onl@koo_4>l01?o_4>l4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oY5^WojAKY00WojAKY00?o0000oll`coo?<<l00_o?
<<l00ol0003of2OHomPWf006omPWf003o`000?o[5>_ojaC[00[ojaC[00?o0000onl@koo_4>l01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?og2?Oom`Sg00[om`Sg00?o0000onTFjOoY5^T02OoY5^T01Ol0003occ3?oll`
coo?<<oo000000Wof2OH00?o0000on/Djoo[5>/02oo[5>/2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003om`SgooL8m`0;ooL8m`03o`000?oY5^WojAKY00WojAKY00?o
0000oll`col000002OoH9mP00ol0003ojaC[on/Dj`0<on/Dj`03o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oY5^Wo
jAKY00SojAKY1Ol00008omPWf003o`000?o[5>_ojaC[00cojaC[00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooL8moog2?L02_og2?L00ol0003ojAKYonTFj@07onTF
j@03o`000?o]4^gokA;]00?okA;]0ol00005omPWf003o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
m`Sg00?o0000onTFjOoY5^T01OoY5^T00ol0003okA;]ondBk@07ondBk@?o000000?of2OHo`000?o[
5>/03Oo[5>/00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_og2?L00ol0003ojAKYonTFj@03onTFj@;o0000
3Oo]4^d2o`0000gojaC[0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?og2?Oom`Sg00Oom`Sg00Co0000onTFjOoY5^WojAKY
0_l00002ooP7n003o`000?o]4^gokA;]00cokA;]3Ol00003ooT6n@03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooL8m`03o`000?oY5^Wo000000Gon0Oh
00?o0000ondBkOo]4^d02oo]4^d00ol0003olPgboo8=lP09oo8=lP03o`000?oi1_Won@Ki00;on@Ki
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om`Sg0ol0
0007ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oo8=l_ob3O802Oob3O800ol0003on@KiooT6
n@04ooT6n@;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003okA;]ondB
k@08ondBk@03o`000?ob3O;olPgb00[olPgb00?o0000ooT6nOoi1_T01_oi1_T00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o]4^gokA;]00OokA;]00?o
0000oo8=l_ob3O802_ob3O800ol0003on@KiooT6n@07ooT6n@;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o]4^gokA;]00KokA;]00?o0000oo8=l_ob3O802_ob3O80
0ol0003on@KiooT6n@09ooT6n@05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ondBkOo]4^d01Oo]4^d00ol0003olPgboo8=lP0:
oo8=lP03o`000?oi1_Won@Ki00Won@Ki1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@04ondBk@03o`000?ob3O;olPgb00WolPgb00?o0000
ooT6nOoi1_T02?oi1_T2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]
00;okA;]00?o0000oo8=l_ob3O802_ob3O800ol0003on@KiooT6n@06ooT6n@;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000ondBkOo]
4^gokA;]o`00000<oo8=lP03o`000?oi1_Won@Ki00Con@Ki0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003okA;]o`000004o`0000WolPgb00?o0000ooT6nOoi1_T00_oi1_T2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003oo0?loo`3o003oo`3o0Oo00000_ob3O800ol0003on@KiooT6n@02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003oo@;m
o`000002o`0000Son0Oh00?o0000oo`3o?ol0o`02_ol0o`5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003oo@;mood2o@03ood2o@?o00001?oh1oP00ol0003oo0?loo`3
o00=oo`3o003o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?om0_goo@;m00Koo@;m0ol000000ooh1oSo0000oo`3o00>oo`3o003o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?om0_goo@;m00[oo@;m00?o0000oo`3
o?ol0o`03ool0o`00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?om0_goo@;m00[o
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l00ooo0?l00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m00_oo@;m5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000koo@;m
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ood2o@03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?om0_goo@;m00Woo@;m1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00;oo@;m1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool02ol00?l6oooo00Oo003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l3oooo00So003o0_ooo`04o`00o`;oool01Ol0
0?l2oooo00?o003o00?oool0o`00ool00?l01_l00?l2oooo06Oo003o0Oooool006co003o0_ooo`06
o`00o`;oool02Ol00?l2oooo00Co003o0_ooo`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`00
0ol00?ooool0oooo000:o`00o`?oool01Ol00?l2oooo00Ko003o0_ooo`03o`00o`;oool01?l00?l2
oooo00Oo003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool000?o003ooooo0?l00?l00ol00?l2oooo
0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`02o`00
o`;oool000?o003ooooo0?ooo`002ol00?l3oooo00Co003o0_ooo`06o`00o`;oool00ol00?l2oooo
00Go003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo003o0Oooool006_o003o0_ooo`000ol00?oo
ool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Co
ool000?o003ooooo0?ooo`003?l00?l2oooo00Co003o0_ooo`06o`00o`;oool00ol00?l00oooo`3o
003oo`00o`04o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Wo`00o`7ooooo001[o`00o`;oool0
00?o003ooooo0?l00?l00ol00?l2oooo0003o`00ooooo`3o003o00Oo003o0_ooo`04o`00o`;oool0
1Ol00?l4oooo00;o003o0_ooo`0=o`00o`;oool00ol00?l2oooo00Go003o0oooo`02o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00_l00?l01?ooo`3o003oo`00
ool00?l2oooo00;o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0oooo`04o`00o`;oool0
3Ol00?l2oooo00Co003o0_ooo`03o`00o`?oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2?l00?l5oooo0003o`00ooooo`3oool000Co003o00?oool0o`00ool00?l00oooo`04o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`07o`00o`;oool01?l00?l3oooo00Go003o1?ooo`05o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01?l00?l00oooo`3o003ooooo
0002oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool00ol0
0?l2oooo0003o`00ooooo`3oool000Ko003o0oooo`05o`00o`;oool01?l00?l4oooo00Ko003o0_oo
o`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00o`?oool01Ol00?l0
0oooo`3o003oo`00o`03o`00o`?oool00ol00?l3oooo00Co003o1?ooo`000ol00?ooool0o`00o`02
oooo00Ko003o0_ooo`06o`00o`;oool00ol00?l3oooo00;o003o0_ooo`04o`00o`;oool01_l00?l2
oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Yo`00o`;oool01Ol00?l3oooo00Go003o00?oool0o`00
ool00?l05ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l3oooo00Co003o0_ooo`03o`00
o`;oool01_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Xo`00o`?oool01Ol00?l3oooo00Go
003o00?oool0o`00ool00?l05ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko
003o0_ooo`02o`00o`;oool01_l00?l00oooo`3o003oo`00o`05o`00o`;oool0Iol00?l1ooooo`00
J?l00?l2oooo00Ko003o0_ooo`06o`00o`;oool06?l00?l2oooo00Ko003o0_ooo`06o`00o`04oooo
0?l00?oo003oo`00o`;oool01_l00?l2oooo00?o003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo
003o0Oooool006So003o0_ooo`06o`00o`;oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool0
00?o<S;<o`00ool00?l01?l00?l00oooo`3o003oo`00o`03o`00o`;oool00ol00?l2oooo00Ko003o
0_ooo`03o`00o`;oool01?l00?l2oooo00Ko003o00?o<S;<oooo0?ooo`00Iol00?l1ooooo`00Iol0
0?l3oooo00Go003o0oooo`07o`00o`03oooo0?l00?oo003o01Ko003o1Oooo`04o`00o`;oool00ol0
0?l2oooo00Go003o0_ooo`04o`00o`;oool01Ol00?l2oooo00;o003o0_ooo`05o`00o`Goool0Iol0
0?l1ooooo`00I_l00?l6oooo0003o`00ooooo`3oool000Goool00ol00?l5oooo027o003o1?ooo`08
o`00o`Goool01ol00?l4oooo07;o003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -49.9063 0 ]
[.5 1.04444 49.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -110.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(990) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
150.875 23.000 moveto
(D) show
158.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.991 .009 .991 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.996 .004 .996 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.99 .01 .99 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.978 .022 .978 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.981 .019 .981 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.957 .043 .957 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.987 .013 .987 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.995 .005 .995 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.996 .004 .996 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.909 .091 .909 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.971 .029 .971 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.984 .016 .984 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.992 .008 .992 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.958 .042 .958 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.982 .018 .982 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.931 .069 .931 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.982 .018 .982 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.973 .027 .973 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.977 .023 .977 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.925 .075 .925 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.987 .013 .987 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.961 .039 .961 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.935 .065 .935 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.778 .222 .778 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.814 .186 .814 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.996 .004 .996 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.983 .017 .983 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.939 .061 .939 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.802 .198 .802 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.763 .237 .763 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.689 .311 .689 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.931 .069 .931 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.958 .042 .958 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.951 .049 .951 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.913 .087 .913 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.995 .005 .995 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.782 .218 .782 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.98 .02 .98 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.817 .183 .817 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.695 .305 .695 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.877 .123 .877 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.444 .556 .444 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.438 .562 .438 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.57 .43 .57 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.801 .199 .801 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.827 .173 .827 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.515 .485 .515 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.463 .537 .463 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.965 .035 .965 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.611 .389 .611 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.754 .246 .754 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.926 .074 .926 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.94 .06 .94 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.673 .327 .673 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.89 .11 .89 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.876 .124 .876 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.759 .241 .759 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.174 .826 .174 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.32 .68 .32 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.983 .017 .983 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.286 .714 .286 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.205 .795 .205 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.914 .086 .914 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.986 .014 .986 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.554 .446 .554 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.157 .843 .157 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.235 .765 .235 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.845 .155 .845 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.342 .658 .342 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.57 .43 .57 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.257 .743 .257 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.063 .937 .063 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.137 .863 .137 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.383 .617 .383 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.57 .43 .57 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.97 .03 .97 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.624 .376 .624 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.709 .291 .709 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.072 .928 .072 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.014 .986 .014 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.039 .961 .039 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.115 .885 .115 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.151 .849 .151 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.811 .189 .811 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.928 .072 .928 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.955 .045 .955 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.528 .472 .528 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.107 .893 .107 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.848 .152 .848 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.246 .754 .246 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.46 .54 .46 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.152 .848 .152 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.303 .697 .303 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.888 .112 .888 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.42 .58 .42 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.134 .866 .134 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.985 .015 .985 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.996 .004 .996 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.921 .079 .921 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.946 .054 .946 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.332 .668 .332 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.98 .02 .98 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.047 .953 .047 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.007 .993 .007 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.682 .318 .682 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.662 .338 .662 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.154 .846 .154 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.27 .73 .27 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.558 .442 .558 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.813 .187 .813 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.999 .001 .999 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.155 .845 .155 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.99 .01 .99 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.078 .922 .078 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.242 .758 .242 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.35 .65 .35 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.977 .023 .977 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.526 .474 .526 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.51 .49 .51 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.364 .636 .364 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.288 .712 .288 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.936 .064 .936 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.915 .085 .915 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.908 .092 .908 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.239 .761 .239 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.545 .455 .545 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.695 .305 .695 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.882 .118 .882 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.978 .022 .978 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.537 .463 .537 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.753 .247 .753 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.449 .551 .449 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.973 .027 .973 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.953 .047 .953 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.873 .127 .873 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.983 .017 .983 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.553 .447 .553 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.663 .337 .663 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.993 .007 .993 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.616 .384 .616 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.917 .083 .917 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.744 .256 .744 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.847 .153 .847 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.7 .3 .7 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.981 .019 .981 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.966 .034 .966 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.817 .183 .817 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.974 .026 .974 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.782 .218 .782 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.796 .204 .796 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.896 .104 .896 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.888 .112 .888 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.968 .032 .968 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.85 .15 .85 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.97 .03 .97 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.949 .051 .949 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.939 .061 .939 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.901 .099 .901 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.909 .091 .909 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.876 .124 .876 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.953 .047 .953 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.985 .015 .985 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.972 .028 .972 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.98 .02 .98 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.99 .01 .99 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.977 .023 .977 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.922 .078 .922 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.972 .028 .972 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.98 .02 .98 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.986 .014 .986 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.988 .012 .988 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.997 .003 .997 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.978 .022 .978 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.983 .017 .983 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.989 .011 .989 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ooh1oP03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0;ooh1oP05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?on0OkooP7n00cooP7n00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooT6n@;o00003?on0Oh2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003om0_d
oo@;m?od2o@5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oi1_Won@Ki00Gon@Ki0_l00008ooh1oP;o00000_oi1_T00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003om0_doo@;m007oo@;m0Ko00000_oo0?l4o`0000goo@;m00?o0000ooT6nOoi1_T0
1ooi1_T2o`0000GooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003om0_doo@;m00<oo@;m0?o00001?oj1OX3o`0000Woo@;m00?o
0000ooT6nOoi1_T02_oi1_T2o`000003ooh1o_l0003o000000Oon@Ki00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oi1_Won@Ki00gon@Ki00?o0000ooT6nOoi1_T02?oi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oi1_T03ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000SooP7n00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ooj
1O[o0000oo`3o00>oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on@KiooT6n@0?ooT6n@03o`000?oi1_Won@Ki00[on@Ki2ol0000;ood2o@Go00003?on0Oh00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005ooX5nP03o`000?ol0ocoo0?l00coo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0
003onPGjooX5nP0=ooX5nP;o00004?oi1_T00ol0003on@KiooT6n@0:ooT6n@03o`000?oh1oSon0Oh
00Oon0Oh00?o0000ood2oOom0_d00_om0_d7o`0000ConPGj00?o0000ooh1o_on0Oh02_on0Oh00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009ooX5nP;o00002ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj
00gonPGj00Co0000onXEj_oZ5N[o00003ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSo
n0Oh00Won0Oh1?l0000;ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00conPGj00Co0000oo0?l?l0003o00002Ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[o
nPGj00gonPGj00Go0000onXEj_oZ5N[ojQGZo`00000=ooT6n@03o`000?oi1_Won@Ki00[on@Ki00?o
0000ooP7n?oh1oP02Ooh1oP00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003onPGjooX5nP0<ooX5nP03o`000?o`3o3ol0o`00;ol0o`0_l00007oo`3o003o`000?od2oCo
m0_d00com0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojQGZonXEjP03onXEjP03o`000?oi1_Wo
n@Ki00[on@Ki00?o0000ooT6nOoi1_T02_oi1_T00ol0003on0OhooP7n009ooP7n003o`000?oj1O[o
nPGj00conPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?
l?o`3o001Oo`3o000ol0003oo0?loo`3o003oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ojQGZonXEjP04onXEjP03o`000?oi1_Won@Ki00Won@Ki00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003on0OhooP7n00:ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?oj1O[onPGj00_onPGj00?o0000oo0?l?o`3o001_o`3o02o`0000?o
o0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0<ooX5nP03o`000?oZ5N[ojQGZ00Ko
jQGZ00?o0000ooT6nOoi1_T02?oi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00[o
n0Oh00?o0000ooX5n_oj1OX03?oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`00
0?o`3o3ol0o`00Wol0o`0_l000000ool0oco0000oo@;m00<oo@;m0?o00003_oj1OX00ol0003ojQGZ
onXEjP07onXEjP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooT6nOoi1_T02Ooi1_T00ol0003on0Oh
ooP7n00;ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003onPGjooX5
nP09ooX5nP03o`000?o`3o3ol0o`00_ol0o`00?o0000oo@;m?od2o@02_od2o@2o`0000?ohacS00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ojQGZonXEjP09onXEjP03o`000?oi1_Won@Ki00Kon@Ki00?o
0000ooT6nOoi1_T02?oi1_T00ol0003on0OhooP7n00<ooP7n003o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003ol0o`oo0?l00<oo0?l003o`000?od2oCom0_d00Som0_d0_l00006on<Lh`;o00002_oj1OX0
0ol0003ojQGZonXEjP0:onXEjP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003on0OhooP7n00<ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003_o`3o000ol0003om0_doo@;m004
oo@;m0?o00002_oS7><00ol0003onPGjooX5nP07ooX5nP03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000
ooT6nOoi1_T00ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00con0Oh00?o0000
ooX5n_oj1OX03?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?oj1O[onPGj00OonPGj00?o0000oo0?l?o`3o003oo`3o001?l0
003om0_doo@;m?od2o@2o`0000kohacS0_l00006ooX5nP03o`000?oZ5N[ojQGZ00gojQGZ00?o0000
ooT6nOoi1_T00_oi1_T00ol0003on@KiooT6n@08ooT6n@03o`000?oh1oSon0Oh00con0Oh0ol0000=
ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00@oo0?l0Co00004_oS7><00ol0
003onPGjooX5nP03ooX5nP03o`000?oZ5N[ojQGZ00kojQGZ00Go0000ooT6nOoi1_Won@Kio`000005
ooT6n@Oo00003?oh1oP01Ol0003ol`ccoo<<looc3??o000000conPGj00?o0000ooh1o_on0Oh02?on
0Oh3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000ooX5n_oj1OX01_oj1OX00ol0003ol0o`oo0?l00=
oo0?l0?o000000Coh1oPo`000?l0003o00004ooS7><2o`0000;onPGj00?o0000onXEj_oZ5NX04?oZ
5NX00ol0003on@Kio`000006o`0000OoiA[U00?o0000ooP7n?oh1oP02?oh1oP00ol0003ol`ccoo<<
l`03oo<<l`;o00002?oj1OX3o`0000KooP7n1?l00002ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oi1_T3o`0000goo@;m00?o0000ooX5n_oj1OX01?oj1OX00ol0003ol0o`oo0?
l00;oo0?l0?o00000ooP7n001Ol0003of2OHo`000?neB[Go000001CohacS00?o0000ooX5n_l00000
4ooZ5NX00ol0003oiA[UonDJi@0=onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l00008oo<<l`03o`00
0?oj1O[onPGj00Go00000ooh1oP00ol0003ooP7nooh1oP03o`0000Ooo@;m00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con@Ki0ol0000:ood2o@03o`000?oj1O[onPGj00?onPGj
00?o0000oo0?l?o`3o002Oo`3o03o`0000Goh1oP00Co0000omPWf?oH9mSo00000_neB[D00ol0003o
hacSon<Lh`0Bon<Lh`03o`000?oZ5N[ojQGZ01;ojQGZ00?o0000onDJiOoU6^D03_oU6^D00ol0003o
n0OhooP7n003ooP7n003o`000?oc3??ol`cc00Wol`cc0_l00009ooP7n0;o00002_om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooT6n@;o00001oom0_d5o`0000;o
nPGj00?o0000oo0?l?o`3o001_o`3o03o`0000Soh1oP00Co0000omPWf?oH9mSo00000oneB[D00ol0
003ohacSon<Lh`0Aon<Lh`03o`000?oZ5N[ojQGZ017ojQGZ00?o0000onDJiOoU6^D04?oU6^D01Ol0
003on0OhooP7n?oh1oSo000000col`cc00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo@;mood2o@0:
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooT6nOoi1_T01ooi1_T3o`00
0004ood2oOl0003o0000o`0000Gol`cc0_l00006oo0?l0?o00002_oP7n001Ol0003of2OHomPWf?oH
9mSo000000Co]DZe00?o0000on<LhooS7><04?oS7><00ol0003ojQGZonXEjP0AonXEjP03o`000?oU
6^GoiA[U017oiA[U00?o0000ooP7n?l000003Ooc3?<00ol0003on0OhooP7n008ooP7n003o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooT6nOoi1_T02_oi1_T00ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00?o00003OoP7n00
1Ol0003of2OHomPWf?oH9mSo000000Go]DZe00?o0000on<LhooS7><03ooS7><00ol0003ojQGZonXE
jP0AonXEjP03o`000?oU6^GoiA[U01;oiA[U00?o0000oo<<looc3?<03?oc3?<00ol0003on0OhooP7
n008ooP7n003o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc0_l0000?on0Oh003o`000?oH9mSo
f2OH00;of2OH00?o0000okE:]OneB[D01?neB[D00ol0003ohacSon<Lh`0=on<Lh`?o00004OoZ5NX0
0ol0003oiA[UonDJi@0ConDJi@03o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc00?o0000on0Oh?oP7n003OoP7n00
0ol0003of2OHomPWf003omPWf003o`000?neB[Go]DZe00Go]DZe00?o0000on<LhooS7><02_oS7><2
o`0000?oZEJY00?o0000onXEj_oZ5NX03_oZ5NX00ol0003oiA[UonDJi@0ConDJi@03o`000?oc3??o
l`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on@Ki00?o0000oo<<
looc3?<02ooc3?<00ol0003oh1oPon0Oh00<on0Oh003o`000?oH9mSof2OH00?of2OH00?o0000okE:
]OneB[D01_neB[D00ol0003ohacSon<Lh`07on<Lh`;o00001_nYEZT2o`0000kojQGZ00?o0000onDJ
iOoU6^D04ooU6^D00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh00Won0Oh00?o0000ood2
oOom0_d03?om0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003oh1oPon0Oh00;on0O
h003o`000?oH9mSof2OH00Cof2OH00?o0000okE:]OneB[D01oneB[D00ol0003ohacSon<Lh`05on<L
h`03o`000?nYEZWoZEJY00SoZEJY00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oiA[UonDJi@0DonDJ
i@03o`000?oc3??ol`cc00_ol`cc00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0<ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003oh1oPon0Oh00;on0Oh003o`000?oH9mSof2OH
00Cof2OH00?o0000okE:]OneB[D02?neB[D00ol0003ohacSon<Lh`02on<Lh`;o00003?nYEZT2o`00
00[ojQGZ00?o0000onDJiOoU6^D05?oU6^D00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oh1oSon0Oh
00Won0Oh00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oP7n3oh1oP00Woh1oP00?o0000omPWf?oH9mP01OoH9mP00ol0003o]DZeokE:]@09okE:]@04
o`000?oS7>?o0000o`00013oZEJY0_l00008onXEjP03o`000?oU6^GoiA[U01CoiA[U0ol0000;oo<<
l`03o`000?oh1oSon0Oh00Won0Oh00?o0000ood2oOom0_d03Oom0_d01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooT6
nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0;oo<<l`;o00002_oP7n000ol0003of2OHomPWf006omPW
f003o`000?neB[Go]DZe00[o]DZe00?o0000ojUFZOnYEZT04_nYEZT00ol0003ojQGZonXEjP04onXE
jP03o`000?oU6^GoiA[U01GoiA[U00?o0000on0Oh?oP7n001Ol00005oo<<l`03o`000?oh1oSon0Oh
00[on0Oh00?o0000ood2oOom0_d03_om0_d3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003ol`ccoo<<l`0;oo<<l`04
o`000?oA;]7odBkAo`0000Woh1oP00?o0000omPWf?oH9mP01_oH9mP00ol0003o]DZeokE:]@0:okE:
]@03o`000?nYEZWoZEJY01?oZEJY0_l00003onXEjPCo00005?oU6^D00ol0003oh1oPon0Oh006on0O
h0Co000000?ol`cco`000?oh1oP02ooh1oP00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ol`ccoo<<l`09oo<<l`;o00001?oA;]400ol0003oh1oPon0Oh005on0Oh003
o`000?oH9mSof2OH00Oof2OH00?o0000okE:]OneB[D02_neB[D00ol0003oZEJYojUFZ@0EojUFZ@03
o`000?oZ5N[o000000Co_T6n0ol0000@onDJi@03o`000?oP7n3oh1oP00_oh1oP0_l0000<ooP7n003
o`000?om0_goo@;m00coo@;m0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oi1_Won@Ki00Oon@Ki00?o0000oo<<looc3?<02?oc3?<00ol0003odBkA
om4^d@05om4^d@03o`000?oP7n3oh1oP00Coh1oP00?o0000omPWf?oH9mP01ooH9mP00ol0003o]DZe
okE:]@0:okE:]@03o`000?nYEZWoZEJY01KoZEJY00?o0000oki1__nn@Kh01_nn@Kh3o`0000coiA[U
00?o0000on0Oh?oP7n003OoP7n000ol0003on0OhooP7n009ooP7n0Go00002Oom0_d2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooT6nOoi1_T01_oi
1_T00ol0003ol`ccoo<<l`07oo<<l`03o`000?oA;]7odBkA00OodBkA00?o0000on0Oh?oP7n000_oP
7n000ol0003of2OHomPWf008omPWf003o`000?neB[Go]DZe00Wo]DZe00?o0000ojUFZOnYEZT05onY
EZT00ol0003o_T6noki1_P09oki1_P?o00002OoU6^D00ol0003oh1oPon0Oh00>on0Oh0Ko00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_om0_d2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?oc
3??ol`cc00Gol`cc0_l0000;om4^d@04o`000?oP7n3oh1oPo`0000_of2OH00?o0000okE:]OneB[D0
2OneB[D00ol0003oZEJYojUFZ@0FojUFZ@03o`000?nn@Kko_T6n00go_T6n0ol00005onDJi@03o`00
0?oP7n3oh1oP00ooh1oP00?o0000on`Ck?o/4n`00oo/4n`4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oi1_T00ol0003ol`ccoo<<
l`05oo<<l`03o`000?oA;]7odBkA00codBkA00?o0000on0Oh?l000002ooH9mP00ol0003o]DZeokE:
]@07okE:]@?o00006?nYEZT00ol0003o_T6noki1_P0@oki1_P?o000000?oiA[Uo`000?oP7n004?oP
7n000ol0003ok1?/on`Ck007on`Ck003o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooT6n@03o`000?oc3??ol`cc00?ol`cc0_l0000@om4^d@03o`000?oH9mSof2OH00[of2OH00?o0000
okE:]OneB[D00oneB[D4o`0000;oQgR700?o0000ojUFZOnYEZT05OnYEZT00ol0003o_T6noki1_P0D
oki1_P03o`000?oP7n3oh1oP013oh1oP00?o0000on`Ck?o/4n`01oo/4n`00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?ol`cc00?o0000om4^dOoA;]404?oA;]400ol0
003of2OHomPWf00:omPWf003o`000?neB[Go000000?o00001on7N8L00ol0003oZEJYojUFZ@0DojUF
Z@03o`000?nn@Kko_T6n01Co_T6n00?o0000on0Oh?oP7n003ooP7n000ol0003ok1?/on`Ck008on`C
k003o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00?o
k1?/00?o0000oo<<lol000004ooA;]44o`0000Wof2OH0_l0000<ohMhQ`03o`000?nYEZWoZEJY01?o
ZEJY00?o0000oki1__nn@Kh05Onn@Kh00ol0003oh1oPon0Oh00>on0Oh003o`000?o/4ncok1?/00So
k1?/00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003ok1?/on`Ck005on`Ck003o`00
0?oA;]7odBkA01;odBkA00Co0000ohebSOn=LXgoSG:=1Ol00003omPWf003o`000?n7N8OoQgR700go
QgR70ol0000@ojUFZ@;o00006?nn@Kh00ol0003oh1oPon0Oh00=on0Oh003o`000?o/4ncok1?/00Wo
k1?/00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003ok1?/on`Ck006on`Ck003o`00
0?oA;]7odBkA017odBkA00?o0000ohebSOn=LXd01on=LXd3o`00013oQgR700?o0000oeB[E?mDZe@0
1Ol00009ojUFZ@;o000000?oPWf2o`000?nn@Kh05onn@Kh00ol0003oh1oPon0Oh00=on0Oh003o`00
0?o/4ncok1?/00Wok1?/00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000om4^dOoA;]403ooA;]400ol0003oSG:=oheb
S@0:ohebS@03o`000?n7N8OoQgR700goQgR700?o0000oeB[E?mDZe@01_mDZe@4o`0000CoZEJY00?o
0000oh9mP_n2OH800_n2OH800ol0003o_T6noki1_P0Foki1_P03o`000?oP7n3oh1oP00_oh1oP00?o
0000on`Ck?o/4n`02oo/4n`00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[ok1?/00?o0000om4^dOoA;]403ooA;]400ol0003oSG:=ohebS@0;ohebS@03o`000?n7N8Oo
QgR700coQgR700?o0000oeB[E?mDZe@02_mDZe@4o`0000GoPWf200?o0000oki1__nn@Kh05_nn@Kh0
0ol0003oh1oPon0Oh00:on0Oh003o`000?o/4ncok1?/00cok1?/00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000on`C
k?o/4n`02Oo/4n`00ol0003odBkAom4^d@0=om4^d@03o`000?n=LXgoSG:=00coSG:=00?o0000ohMh
Qon7N8L03?n7N8L00ol0003oE:]DoeB[E00;oeB[E003o`000?mIYUWo000000KoPWf200?o0000oki1
__nn@Kh05_nn@Kh00ol0003oh1oPon0Oh009on0Oh003o`000?o/4ncok1?/00cok1?/00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000om4^dOoA;]402?oA;]44o`0000oo
SG:=00?o0000ohMhQon7N8L02on7N8L00ol0003oE:]DoeB[E00;oeB[E004o`000?mIYUWoFJIIo`00
00OoPWf200?o0000oki1__nn@Kh05Onn@Kh00ol0003oh1oPon0Oh008on0Oh003o`000?o/4ncok1?/
00gok1?/00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000om4^dOoA
;]400ooA;]45o`0000?oTFjA00?o0000ohebSOn=LXd03_n=LXd00ol0003oQgR7ohMhQ`0:ohMhQ`03
o`000?mDZeCoE:]D00[oE:]D00Go0000oeVVFOmIYUWoFJIIo`000007oh9mPP03o`000?nn@Kko_T6n
01Go_T6n00?o0000on0Oh?oP7n002?oP7n000ol0003ok1?/on`Ck00=on`Ck003o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00<on`Ck0Go00002OnAKY400ol0003o
SG:=ohebS@0<ohebS@;o00003?n7N8L00ol0003oE:]DoeB[E00:oeB[E005o`000?mIYUWoFJIIoeVV
FOl000002?n2OH800ol0003o_T6noki1_P0Doki1_P?o00001ooP7n000ol0003ok1?/on`Ck00>on`C
k003o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000on`Ck?o/4n`03?o/4n`01?l0003ocC;=oldbcOl0000;oi5^T@03o`000?n=LXgoSG:=
00_oSG:=00Co0000od6n@Om1_T7o00002_n7N8L00ol0003oE:]DoeB[E00:oeB[E003o`000?mIYUWo
FJII00;oFJII00?o0000oh9mP_n2OH801_n2OH800ol0003o_T6noki1_P0Aoki1_P?o00000oo8=lP0
0ol0003oh1oPon0Oh004on0Oh003o`000?o/4ncok1?/00gok1?/1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000oldbcOo=</d00_o=</d0
0ol0003oTFjAoi5^T@08oi5^T@03o`000?n=LXgoSG:=00[oSG:=00?o0000od6n@Om1_T400_m1_T40
0ol0003oQgR7ohMhQ`03ohMhQ`Go00002omDZe@00ol0003oFJIIoeVVF@03oeVVF@03o`000?n2OH;o
PWf200OoPWf200?o0000oki1__nn@Kh03_nn@Kh2o`0000Oob3O800?o0000on0Oh?oP7n000_oP7n00
0ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000oldb
cOo=</d00oo=</d00ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00SoSG:=00?o0000od6n
@Om1_T401?m1_T45o`0000Co?/4n00?o0000oeB[E?mDZe@02OmDZe@00ol0003oFJIIoeVVF@03oeVV
F@03o`000?n2OH;oPWf200SoPWf200?o0000oki1__nn@Kh02_nn@Kh3o`0000[ob3O800Go0000on0O
h?oP7n3oh1oPo`00000>on`Ck003o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o/4ncok1?/00[ok1?/00?o0000oldb
cOo=</d01?o=</d00ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00OoSG:=00?o0000od6n
@Om1_T401Om1_T400ol0003o?/4nock1?P07ock1?P03o`000?mDZeCoE:]D00OoE:]D00?o0000oeVV
FOmIYUT01?mIYUT00ol0003oPWf2oh9mPP08oh9mPP03o`000?nn@Kko_T6n00So_T6n0_l0000>olPg
b0Co00003?o/4n`2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003ok1?/on`Ck009on`Ck003o`000?o=</gocC;=00KocC;=00?o0000oi5^TOnAKY402OnAKY400ol0
003oSG:=ohebS@05ohebS@03o`000?m1_T7o@Ki100Ko@Ki100?o0000ock1?_ln`Ch02?ln`Ch00ol0
003oE:]DoeB[E006oeB[E003o`000?mIYUWoFJII00CoFJII00?o0000oh9mP_n2OH802On2OH84o`00
00?o_T6n0ol0000@olPgb005o`000?oX5nSoj1OXonPGj?l000002_o/4n`00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[ok1?/00?o0000oldbcOo=</d01oo=</d0
0ol0003oTFjAoi5^T@09oi5^T@03o`000?n=LXgoSG:=00CoSG:=00?o0000od6n@Om1_T401om1_T40
0ol0003o?/4nock1?P08ock1?P;o00001_mDZe@00ol0003oFJIIoeVVF@05oeVVF@03o`000?n2OH;o
PWf200WoPWf200Co0000oieRWOnMHYgoWF:M0ol0000BolPgb003o`000?oX5nSoj1OX00?oj1OX0_l0
0006on`Ck0;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o/4n`00ol0003ocC;=oldbc@08oldbc@03o`000?nAKY7o
TFjA00[oTFjA00?o0000ohebSOn=LXd00_n=LXd00ol0003o@Ki1od6n@@08od6n@@03o`000?ln`Cko
?/4n00Ko?/4n0_l00002obKI9P03o`000?mDZeCoE:]D00;oE:]D00?o0000oeVVFOmIYUT01_mIYUT0
0ol0003oPWf2oh9mPP08oh9mPP03o`000?nMHYgoWF:M00CoWF:M00?o0000olPgb?o8=lP03oo8=lP0
0ol0003oj1OXonPGj006onPGj0;o00000oo/4n`00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000on`Ck?o/4n`01oo/4n`00ol0003ocC;=oldbc@0:oldbc@03o`000?nAKY7oTFjA
00WoTFjA00Go0000ohebSOn=LXgoSG:=o`00000;od6n@@03o`000?ln`Cko?/4n00Co?/4n0_l00005
obKI9P05o`000?mDZeCoE:]DoeB[E?l000002?mIYUT00ol0003oPWf2oh9mPP08oh9mPP03o`000?nM
HYgoWF:M00GoWF:M00?o0000olPgb?o8=lP03_o8=lP00ol0003oj1OXonPGj008onPGj003o`000?o/
4nco000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000on`Ck?o/4n`01_o/4n`00ol0003ocC;=
oldbc@0;oldbc@03o`000?nAKY7oTFjA00WoTFjA00Co0000ohebSOn=LXgo00003?m1_T400ol0003o
?/4nock1?P02ock1?P;o00002?lVfBH00ol0003oE:]Do`000009oeVVF@03o`000?n2OH;oPWf200So
PWf200?o0000oieRWOnMHYd01OnMHYd00ol0003ob3O8olPgb00=olPgb003o`000?oX5nSoj1OX00[o
j1OX00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o/4ncok1?/00Cok1?/00?o0000oldbcOo=</d03?o=</d00ol0003oTFjAoi5^T@0:oi5^T@?o0000
3?m1_T400ol0003o?/4nock1?P02o`0000_o9]TV00?o0000oeVVFOmIYUT02?mIYUT00ol0003oPWf2
oh9mPP07oh9mPP03o`000?nMHYgoWF:M00OoWF:M00?o0000olPgb?o8=lP03?o8=lP00ol0003oj1OX
onPGj00;onPGj0;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo/
4n`00ol0003ocC;=oldbc@0>oldbc@03o`000?nAKY7oTFjA00SoTFjA00Co0000odVfBOm9]TWoBKI9
0_l0000:od6n@@?o00003OlVfBH00ol0003oFJIIoeVVF@08oeVVF@03o`000?n2OH;oPWf200OoPWf2
00?o0000oieRWOnMHYd01onMHYd00ol0003ob3O8olPgb00;olPgb003o`000?oX5nSoj1OX00coj1OX
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003oo@;m003o`000?o/4nco0000017ocC;=00?o0000oi5^TOnAKY401onAKY400ol0003oBKI9odVf
B@04odVfB@;o00002?m1_T400ol0003o9]TVobKI9P0>obKI9P;o00002?mIYUT00ol0003oPWf2oh9m
PP06oh9mPP03o`000?nMHYgoWF:M00WoWF:M00?o0000olPgb?o8=lP02Oo8=lP00ol0003oj1OXonPG
j00=onPGj003o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006oo@;m003o`000?o=</gocC;=013ocC;=00?o0000oi5^TOnAKY401_nAKY40
0ol0003oBKI9odVfB@07odVfB@03o`000?m1_T7o@Ki100Co@Ki10ol0000>obKI9P03o`000?lWf2Oo
9mPW00?o00001OmIYUT00ol0003oPWf2oh9mPP06oh9mPP03o`000?nMHYgoWF:M00[oWF:M00?o0000
olPgb?o8=lP02?o8=lP00ol0003oj1OXonPGj00=onPGj003o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008oo@;m003o`000?o=</gocC;=
017ocC;=00Co0000oi5^TOnAKY7oTFjA1?l0000;odVfB@;o000000Co@Ki1o`000?l0003o00000olB
kA82o`0000_o9]TV00?o0000obOH9olWf2L01?lWf2L2o`0000?oFJII00?o0000oh9mP_n2OH801_n2
OH800ol0003oWF:MoieRW@0:oieRW@03o`000?o8=lSob3O800Oob3O800?o0000onPGj?oX5nP03_oX
5nP00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<oo@;m003o`000?o=</go
cC;=013ocC;=1?l00003oh=lP`03o`000?m9]TWoBKI900_oBKI900?o0000oa;]4_lBkA801_lBkA80
0ol0003o9]TVobKI9P07obKI9P03o`000?lWf2Oo9mPW00Oo9mPW3?l0000>oieRW@03o`000?o8=lSo
b3O800Kob3O800?o0000onPGj?oX5nP03_oX5nP00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_od2o@00ol0003ocC;=oldbc@0?oldbc@03o`000?n3O8?oPgb300KoPgb300?o0000
odVfBOm9]TT02_m9]TT00ol0003o4^dBoa;]4P07oa;]4P;o00001_lVfBH00ol0003o9mPWobOH9`08
obOH9`03o`000?mMXUgoGJ9M00SoGJ9M00?o0000oieRWOnMHYd03?nMHYd00ol0003ob3O8olPgb005
olPgb003o`000?oX5nSoj1OX00ooj1OX0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03_od2o@00ol0
003ocC;=oldbc@0>oldbc@03o`000?n3O8?oPgb300OoPgb300?o0000odVfBOm9]TT02_m9]TT00ol0
003o4^dBoa;]4P09oa;]4P;o00000olVfBH00ol0003o9mPWobOH9`09obOH9`03o`000?mMXUgoGJ9M
00WoGJ9M00?o0000oieRWOnMHYd02_nMHYd4o`0000Cob3O800?o0000onPGj?oX5nP04?oX5nP01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000oo@;m?od2o@03ood2o@@o`0000[oPgb300?o0000odVf
BOm9]TT02Om9]TT00ol0003o4>l@o`00000<oa;]4P05o`000?lVfBKo0000o`cc3?l000002_lWf2L0
0ol0003oGJ9MoefRG@09oefRG@03o`000?nMHYgoWF:M00OoWF:M0ol00004ok=</`?o000000?ob3O8
o`000?oX5nP04OoX5nP01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00?
oo@;m003o`000?o3?<?o`cc300co`cc300?o0000oh=lPon3O8<02On3O8<00ol0003oBKI9odVfB@07
odVfB@04o`000?l@ka3o4>l@o`0000go4^dB00Go0000o`cc3?l<l`co3?<<o`000009obOH9`03o`00
0?mMXUgoGJ9M00[oGJ9M00?o0000oieRWOnMHYd00onMHYd3o`0000[o/dbc00?o0000onPGj?oX5nP0
4?oX5nP00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000oo@;m?od2o@03ood2o@00ol0003o`cc3ol<l``0<ol<l``03o`000?n3
O8?oPgb300WoPgb300?o0000odVfBOm9]TT01_m9]TT00ol0003o4>l@oa3_4002oa3_4003o`000?lB
kA;o4^dB00[o4^dB00?o0000o`cc3?l<l``00_l<l``00ol0003o9mPWobOH9`06obOH9`03o`000?mM
XUgoGJ9M00[oGJ9M00?o0000oieRWOnMHYd00ol0000=ok=</`03o`000?oX5nSoj1OX013oj1OX00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om0_doo@;m00=oo@;m0?o00003oo3?<<0
0ol0003oPgb3oh=lP`08oh=lP`03o`000?m9]TWoBKI900GoBKI900?o0000oa3_4?l@ka000ol@ka00
0ol0003o4^dBoa;]4P0:oa;]4P03o`000?l<l`co3?<<00?o3?<<00?o0000obOH9olWf2L01OlWf2L0
0ol0003oGJ9MoefRG@0;oefRG@;o00004OncC;<00ol0003oj1OXonPGj00?onPGj003o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om0_doo@;m009oo@;m0Go00000_oX5nP00ol0
003o`cc3ol<l``0=ol<l``03o`000?n3O8?oPgb300WoPgb300?o0000odVfBOm9]TT01?m9]TT00ol0
003o4>l@oa3_4004oa3_4003o`000?lBkA;o4^dB00So4^dB00?o0000o`cc3?l<l``01Ol<l``00ol0
003o9mPWobOH9`04obOH9`03o`000?mMXUgoGJ9M00_oGJ9M00?o0000ok=</oncC;<04?ncC;<00ol0
003oj1OXonPGj00?onPGj003o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?od2oCom0_d00Com0_d1Ol00007onPGj003
o`000?o3?<?o`cc300go`cc300?o0000oh=lPon3O8<02On3O8<00ol0003oBKI9odVfB@03odVfB@03
o`000?l@ka3o4>l@00Go4>l@00?o0000oa;]4_lBkA802?lBkA800ol0003o3?<<o`cc3006o`cc3003
o`000?lWf2Oo9mPW00?o9mPW00?o0000oefRGOmMXUd02omMXUd00ol0003o/dbcok=</`0@ok=</`03
o`000?oX5nSoj1OX00ooj1OX00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo@;m?l00000
1?l0000<onPGj003o`000?o3?<?o`cc300ko`cc300?o0000oh=lPon3O8<02?n3O8<00ol0003oBKI9
odVfB@02odVfB@03o`000?l@ka3o4>l@00Oo4>l@00?o0000oa;]4_lBkA801olBkA800ol0003o3?<<
o`cc3007o`cc3003o`000?lWf2Oo9mPW00;o9mPW00?o0000oefRGOmMXUd02omMXUd00ol0003o/dbc
ok=</`0Aok=</`03o`000?oX5nSoj1OX00goj1OX00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oj1OX00?o0000ol<l`oo3?<<03_o3
?<<00ol0003oPgb3oh=lP`09oh=lP`04o`000?m9]TWoBKI9o`0000[o4>l@00?o0000oa;]4_lBkA80
1olBkA800ol0003o3?<<o`cc3008o`cc3005o`000?lWf2Oo9mPWobOH9ol000003OmMXUd00ol0003o
/dbcok=</`0Aok=</`?o00003OoX5nP00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;on`Ck00?o0000onPGj?oX5nP03ooX5nP00ol0003o
`cc3ol<l``0>ol<l``03o`000?n3O8?oPgb300SoPgb31Ol0000;oa3_4003o`000?lBkA;o4^dB00Ko
4^dB00?o0000o`cc3?l<l``02Ol<l``01?l0003o9mPWobOH9ol0000=oefRG@03o`000?ncC;?o/dbc
017o/dbc00?o0000omTVfOoI9]T00ol0000:onPGj0Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005oo/4n`03o`000?oX5nSoj1OX00koj1OX00?o0000ol<l
`oo3?<<03_o3?<<00ol0003oPgb3oh=lP`07oh=lP`03o`000?l/dbco;=</00?o;=</00?o0000oa3_
4?l@ka002?l@ka000ol0003o4^dBoa;]4P05oa;]4P03o`000?l<l`co3?<<00[o3?<<1Ol0000<oefR
G@03o`000?ncC;?o/dbc013o/dbc00?o0000omTVfOoI9]T01?oI9]T3o`0000Koj1OX00?o0000ooX5
n_oj1OX00_oj1OX5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000oo/4nook1?/01?ok1?/00ol0003oj1OXonPGj00=onPGj003o`000?o3?<?o`cc300oo
`cc300?o0000oh=lPon3O8<01?n3O8<2o`0000Oo;=</00?o0000oa3_4?l@ka001ol@ka0Eo`0000Go
9mPW00?o0000oefRGOmMXUd02?mMXUd3o`00013o/dbc00?o0000omTVfOoI9]T02?oI9]T3o`0000;o
j1OX00?o0000ooX5n_oj1OX02?oj1OX5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oj1OXonPGj00;onPGj0Co0000
3oo3?<<00ol0003oPgb3oh=lP`03oh=lP`03o`000?l/dbco;=</00So;=</00?o0000oa3_4?l@ka00
1?l@ka02o`0000So0o`300?o0000o`7n0Ol1oP402?l1oP400ol0003o9mPWobOH9`05obOH9`;o0000
1_mMXUd2o`0000?oLXeb00?o0000ok=</oncC;<03?ncC;<00ol0003ofBKIomTVf@0<omTVf@;o0000
4?oj1OX3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o
0000onPGj?oX5nP02OoX5nP00ol0003okQ7^o`000002olLha`?o00003?o3?<<01?l0003oPgb3oh=l
Pon3O8<2o`0000co;=</00?o0000oa3_4?l@ka000_l@ka000ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l1oP7o0Oh100So0Oh100?o0000obOH9olWf2L01olWf2L00ol0003oGJ9MoefRG@02oefRG@03o`00
0?mbSG;oLXeb00CoLXeb0_l0000;ok=</`03o`000?oI9]WofBKI00cofBKI00?o0000oo0?l?l00000
4_oj1OX00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o
0000onPGj?oX5nP01_oX5nP2o`0000;okQ7^00?o0000olLhaoo7><L00oo7><L3o`0000[o`cc300?o
0000oh=lPol000003ol/db`01?l0003o4>l@o`000?l0000;o`?l0`03o`000?l1oP7o0Oh100So0Oh1
00?o0000obOH9olWf2L02?lWf2L01?l0003oGJ9Mo`000?l00009og:=LP03o`000?ncC;?o/dbc00Oo
/dbc00?o0000omTVfOoI9]T03?oI9]T01?l0003ol0o`oo0?l?l0000CooX5nP03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oX5nSoj1OX00Co
j1OX00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oacS7olLha`05olLha`?o00001_o3?<<4o`00013o
;=</00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW00Wo
9mPW00?o0000og:=L_mbSG802_mbSG82o`0000Ko/dbc00?o0000omTVfOoI9]T03?oI9]T00ol0003o
l0o`oo0?l002oo0?l003o`000?oj1O[onPGj00oonPGj00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00Co0000onPGj?oX5nSo
j1OX0_l00006onhAkP03o`000?o7><OoacS700SoacS70ol000000oo3?<?o0000o`000004ogJ9MP03
o`000?l/dbco;=</00go;=</00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03
o`000?lWf2Oo9mPW00Wo9mPW00?o0000og:=L_mbSG803?mbSG800ol0003o/dbcok=</`03o`0000ko
fBKI00?o0000oo0?l?o`3o000oo`3o000ol0003onPGjooX5nP0>ooX5nP05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000onPGj?l000002?o^4Nh00ol0003oacS7olLha`0;olLha`03o`000?mfRGKoMXUf00Go
MXUf00?o0000obcC;?l/db`03?l/db`00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l1oP7o0Oh100Oo
0Oh100?o0000obOH9olWf2L02?lWf2L2o`0000ooLXeb0_l00002ol/db`03o`000?oI9]WofBKI00_o
fBKI00?o0000oo0?l?o`3o001?o`3o000ol0003onPGjooX5nP0=ooX5nP03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003oacS7olLha`0;olLha`03o`000?mfRGKoMXUf00KoMXUf00?o0000obcC;?l/db`0
2ol/db`2o`0000go0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9mPWobOH9`07obOH9`04o`00
0?lm`Sgo?L8mo`0000koLXeb00?o0000ol/dboo;=</00_o;=</00ol0003ofBKIomTVf@09omTVf@03
o`000?o`3o3ol0o`00Kol0o`00?o0000ooX5n_oj1OX02ooj1OX00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000oo/4nook1?/02_ok1?/2o`0000Wo
kQ7^00?o0000olLhaoo7><L02oo7><L00ol0003oMXUfogJ9MP07ogJ9MP03o`000?l/dbco;=</00Wo
;=</00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW
00Ko9mPW00Go0000ocg2?Olm`Sgo?L8mo`00000>og:=LP03o`000?o;=<_obcC;00?obcC;00?o0000
omTVfOoI9]T01ooI9]T00ol0003ol0o`oo0?l007oo0?l003o`000?oj1O[onPGj00[onPGj00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00Co0000ooT6nOoi1_Wo00002Oo^4Nh00ol0003oacS7olLha`09olLha`03o`000?mfRGKo
MXUf00WoMXUf00?o0000obcC;?l/db`01ol/db`00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o9mPWobOH9`05obOH9`03o`000?lm`Sgo
?L8m00?o?L8m00?o0000og:=L_mbSG802_mbSG800ol0003obcC;ol/db`05ol/db`03o`000?oI9]Wo
fBKI00GofBKI00?o0000oo0?l?o`3o002?o`3o000ol0003onPGjooX5nP09ooX5nP03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won`Ck00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okQ7^onhAkP06onhAkP03o`000?o7><OoacS700WoacS700?o0000ogJ9
M_mfRGH02_mfRGH00ol0003o;=</obcC;005obcC;003o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lWf2Oo9mPW00Co9mPW00?o0000ocg2
?Olm`Sd01?lm`Sd00ol0003oLXebog:=LP0:og:=LP03o`000?o;=<_obcC;00KobcC;00?o0000omTV
fOoI9]T00ooI9]T00ol0003ol0o`oo0?l009oo0?l003o`000?oj1O[onPGj00SonPGj00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ook1?/00ol0003o
n@KiooT6n@03ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000olLhaoo7><L02Oo7><L00ol0003o
MXUfogJ9MP0;ogJ9MP03o`000?l/dbco;=</00?o;=</00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l1oP7o0Oh100Ko0Oh100?o0000obOH9olWf2L00_lWf2L2o`0000So
?L8m00?o0000og:=L_mbSG802OmbSG800ol0003obcC;ol/db`07ol/db`05o`000?oI9]WofBKIomTV
fOl000003Oo`3o000ol0003onPGjooX5nP06ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ook1?_o0000ooT6n@06ooT6n@03
o`000?o^4NkokQ7^00GokQ7^00?o0000olLhaoo7><L02Oo7><L00ol0003oMXUfogJ9MP0<ogJ9MP05
o`000?l/dbco;=</obcC;?l000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh1
00Ko0Oh100?o0000obOH9ol000000_l000000olCk1?o0000ocg2?@07ocg2?@03o`000?mbSG;oLXeb
00SoLXeb00?o0000ol/dboo;=</02Oo;=</00ol0003ofBKIo`00000=oo0?l0Co00001Ooj1OX00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oacS7olLha`09olLha`03
o`000?mfRGKoMXUf00goMXUf00?o0000obcC;?l000003?l9mPT:o`0000Oo0Oh10ol00005oa?/4`03
o`000?lm`Sgo?L8m00Ko?L8m00?o0000og:=L_mbSG801ombSG800ol0003obcC;ol/db`0:ol/db`03
o`000?o`3o3ol0o`00_ol0o`00?o0000oo`3o?ol0o`00_ol0o`3o`000003ooX5n_l0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olLhaoo7><L01oo7><L00ol0003oMXUfogJ9MP0?ogJ9MP;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100;o0Oh10ol00008oa?/4`03o`00
0?lm`Sgo?L8m00Ko?L8m00?o0000og:=L_mbSG801ombSG800ol0003obcC;ol/db`0:ol/db`03o`00
0?o`3o3ol0o`00[ol0o`00?o0000oo`3o?ol0o`01_ol0o`00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o^4NkokQ7^00CokQ7^00?o0000olLhaoo7><L01oo7><L00ol0003oMXUfogJ9
MP0>ogJ9MP04o`000?ldbcCo=</do`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0Oh1
o`000?l0000<oa?/4`03o`000?lm`Sgo?L8m00Ko?L8m00?o0000og:=L_mbSG801_mbSG800ol0003o
bcC;ol/db`0;ol/db`03o`000?o`3o3ol0o`00Ool0o`0_l00009oo`3o003o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh00oo^4Nh>o`0000goMXUf00?o0000ocC;=?ldbc@0
0_ldbc@00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oa?/4olCk1<0
3?lCk1<00ol0003o?L8mocg2?@06ocg2?@03o`000?mbSG;oLXeb00GoLXeb00?o0000ol/dboo;=</0
3?o;=</00ol0003ol0o`oo0?l006oo0?l003o`000?ol0ocoo0?l00[oo0?l00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okQ7^onhAk_o^4Nko000000_od2o@00?o0000og6>LOmaSW400ol00009ogJ9MP03o`00
0?ldbcCo=</d00Co=</d00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lCk1?o4n`C00go4n`C00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003oLXebog:=LP03og:=LP?o0000
3Oo;=</00ol0003ol0o`oo0?l005oo0?l003o`000?ol0ocoo0?l00coo0?l0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cod2o@00?o0000og6>LOmaSW400omaSW43o`0000GoMXUf00?o0000ocC;=?ldbc@01_ld
bc@01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oa?/4olCk1<03OlCk1<00ol0003o?L8m
ocg2?@06ocg2?@03o`000?mbSG;oLXeb00?o00000on=LXd00ol0003obcC;ol/db`0;ol/db`03o`00
0?o`3o3ol0o`00?ol0o`00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003ooD:m@03o`000?o@;m3od2o@00[od2o@00?o0000og6>LOmaSW401_maSW43o`000003ogJ9M_l0
003o=</d00Wo=</d00?o0000o`Wf2Ol000004?l9mPT00ol0003o4n`Coa?/4`0=oa?/4`03o`000?lm
`Sgo?L8m00Oo?L8m0_l00007ohebS@03o`000?o;=<_obcC;00[obcC;00Co0000oo0?l?o`3o3ol0o`
0ol0000?oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom@[e00?o0000om0_d?o@
;m002_o@;m000ol0003oLHiaog6>L@09og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o4n`Coa?/4`0>oa?/4`03o`000?lm`Sgo?L8m00Ko?L8m00?o0000ohebSOn=
LXd01on=LXd4o`0000SobcC;00Co0000oo0?l?o`3o3o00000oof2OH2o`0000goo0?l00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002Oo@;m000ol0003o
LHiaog6>L@0:og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
4n`Coa?/4`0>oa?/4`03o`000?lm`Sgo?L8m00Go?L8m00?o0000ohebSOn=LXd02?n=LXd01?l0003o
dBkAom4^dOoA;]47o`0000;obcC;0_l00006ooH9mP;o00003?ol0o`00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003od2o@om0_d008om0_d003o`000?maSW7oLHia00[o
LHia00?o0000ocC;=?ldbc@02oldbc@00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lCk1?o4n`C00ko
4n`C1Ol00002ocg2?@03o`000?n=LXgoSG:=00WoSG:=00?o0000om4^dOoA;]402?oA;]43o`0000Wo
mPWf0_l0000:oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@07ooD:m@03o`00
0?o@;m3od2o@00Sod2o@00?o0000og6>LOmaSW402_maSW400ol0003o=</docC;=00:ocC;=0;o0000
3_l9mPT3o`0000go4n`C0ol00005odVfB@;o00002on=LXd00ol0003odBkAom4^d@0;om4^d@;o0000
2_of2OH2o`0000Ooo0?l0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002?o@;m0>o`0000Wo=</d0ol000000olXebSo0000
o`Wf2@0:o`Wf2@?o00000_lKi1/00ol0003o4n`Coa?/4`09oa?/4`;o00002Om9]TT00ol0003oSG:=
ohebS@09ohebS@03o`000?oA;]7odBkA00_odBkA00?o0000onHIi_l000002oof2OH2o`0000Coo0?l
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oe2_Gom@[e00Kom@[e00?o0000om0_d?o@;m002?o@;m000ol0003oL8m`
og2?L00:og2?L003o`000?ldbcCo=</d00Co=</d0ol00005obSG:003o`000?l9mPWo2OH900Co2OH9
1?l00006oa_T6`03o`000?lCk1?o4n`C00Ko4n`C0_l0000;odVfB@03o`000?n=LXgoSG:=00WoSG:=
00?o0000om4^dOoA;]402_oA;]401Ol0003oiQWVonHIi_oV6NKo000000comPWf0_l000000ool0oco
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003od2o@om0_d007om0_d003o`00
0?m`Sg3oL8m`00_oL8m`00?o0000ocC;=?ldbc@00_ldbc@2o`0000Wo:=LX00?o0000o`Wf2Ol9mPT0
0ol0000;oa_T6`03o`000?lCk1?o4n`C00;o4n`C0ol0000>odVfB@03o`000?n=LXgoSG:=00OoSG:=
00?o0000om4^dOoA;]402ooA;]400ol0003oiQWVonHIiP02onHIiP03o`000?of2OKomPWf00_omPWf
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000ooD:mOoe2_D01ooe2_D00ol0003od2o@om0_d005om0_d0?o00003Om`
Sg04o`0000_o:=LX0ol0000?oa_T6`04o`000?lCk1?o0000o`00017oBKI900?o0000ohebSOn=LXd0
1on=LXd00ol0003odBkAom4^d@0:om4^d@03o`000?oV6NKoiQWV00CoiQWV00?o0000ooH9m_of2OH0
1oof2OH3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om@[eooD:
m@06ooD:m@03o`000?o@;m3od2o@00;od2o@0ol00003ok1?/003o`000?m`Sg3oL8m`00[oL8m`00?o
0000obSG:?lXebP02olXebP00ol0003o8m`So`00000Aoa_T6`03o`000?m9]TWoBKI9017oBKI900?o
0000ohebSOn=LXd01on=LXd00ol0003odBkAom4^d@0:om4^d@03o`000?oV6NKoiQWV00GoiQWV00Co
0000ooH9m_of2OKomPWf1Ol00002ooP7n003o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@05ooD:m@?o0000
00?od2o@o`000?l000001on`Ck000ol0003oL8m`og2?L008og2?L0?o00002_lXebP2o`0000;o8m`S
00?o0000oa_T6olKi1/03olKi1/00ol0003oBKI9odVfB@0AodVfB@03o`000?n=LXgoSG:=00OoSG:=
00?o0000om4^dOoA;]402OoA;]400ol0003oiQWVonHIiP07onHIiP?o00001ooh1oP00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om@[e0_l00003onl@k`03o`000?n`Ck3o/4n`00So/4n`0_l00006og2?L0;o00000omM
XUd00ol0003o:=LXobSG:006obSG:003o`000?lSg2?o8m`S00?o8m`S00?o0000oa_T6olKi1/03_lK
i1/00ol0003oBKI9odVfB@0BodVfB@03o`000?n=LXgoSG:=00GoSG:=00?o0000om4^dOoA;]402OoA
;]400ol0003oiQWVonHIiP08onHIiP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo/4n`;o00001Oo_4>l00ol0003o/4n`ok1?/00:ok1?/003o`000?m`Sg3oL8m`00;oL8m`00?o0000
oefRGOmMXUd01?mMXUd00ol0003o:=LXobSG:004obSG:003o`000?lSg2?o8m`S00Co8m`S00?o0000
oa_T6olKi1/03_lKi1/00ol0003oBKI9odVfB@0BodVfB@[o00002_oA;]400ol0003oiQWVonHIiP08
onHIiP03o`000?oh1oSon0Oh00Oon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Oon`Ck00?o0000onl@koo_4>l01?o_4>l0
0ol0003o/4n`ok1?/00:ok1?/004o`000?m`Sg3o0000o`0000SoGJ9M00Co0000obSG:?lXebSo:=LX
0_l00007ob?L8`03o`000?lKi1_o6n@K00ko6n@K00?o0000odVfBOm9]TT04_m9]TT00ol0003oZEJY
ojUFZ@07ojUFZ@03o`000?oA;]7odBkA00KodBkA00?o0000onHIi_oV6NH02_oV6NH00ol0003on0Oh
ooP7n006ooP7n003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Won`Ck00?o0000onl@koo_4>l01?o_4>l00ol0003o/4n`ok1?/00;ok1?/003o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obSG:?l000002OlSg2<00ol0003o6n@Koa_T6`0>oa_T6`;o0000
4_m9]TT00ol0003oZEJYojUFZ@09ojUFZ@;o00001_oA;]400ol0003oiQWVonHIiP0:onHIiP03o`00
0?oh1oSon0Oh00Kon0Oh00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo/4nook1?/02Ook1?/00ol0003oka3_onl@k`05onl@k`03o`000?n`Ck3o/4n`00[o/4n`00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa_T6olKi1/03_lKi1/00ol0003o?L8mo`00
0002o`0000ooBKI900?o0000ojUFZOnYEZT02onYEZT00ol0003odBkAom4^d@03o`0000goiQWV00?o
0000ooP7n?oh1oP01_oh1oP00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o_4>ooka3_00Goka3_00?o0000ok1?/?n`Ck002On`Ck02
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lKi1_o6n@K00co6n@K00?o0000ocg2?Olm`Sd00olm`Sd3
o`0000coBKI900?o0000ojUFZOnYEZT03?nYEZT2o`0000;ohacS00?o0000onHIi_oV6NH03?oV6NH0
0ol0003on0OhooP7n005ooP7n003o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ok1?_on`Ck00[on`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o/4n`ok1?/007ok1?
/003o`000?naC[7o000000[oGJ9M00Co0000oe6^DOmA[U7o00002_lSg2<00ol0003o6n@Koa_T6`0<
oa_T6`03o`000?lm`Sgo?L8m00Ko?L8m0_l00008odVfB@;o00003onYEZT00ol0003ohacSon<Lh`02
on<Lh`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooP7n?oh1oP01Ooh1oP00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?o_4>ooka3_
00Koka3_00?o0000ok1?/?n`Ck001_n`Ck001Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe6^DOmA[U400_mA[U400ol0003o8m`Sob?L8`06ob?L8`Co00003?lKi1/00ol0003o?L8mocg2?@08
ocg2?@?o00000_m9]TT3o`000003ohUfROl0003oZEJY00goZEJY00?o0000on<LhooS7><01?oS7><0
0ol0003oiQWVonHIiP0:onHIiP03o`000?oh1oSon0Oh00Gon0Oh00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oka3_onl@k`07onl@
k`03o`000?n`Ck3o/4n`00?o/4n`0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe6^
DOmA[U400omA[U400ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa_T
6`;o00003_lm`Sd2o`0000GoRGJ900?o0000ojUFZOnYEZT02_nYEZT00ol0003ohacSon<Lh`05on<L
h`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooP7n?oh1oP01?oh1oP00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?o_4>ooka3_00Oo
ka3_00?o0000ok1?/?n`Ck000_n`Ck000ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe6^DOmA[U401OmA[U400ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6n@K0_l000000olRgB;o0000ocg2?@0=ocg2?@03o`000?n9MXWoRGJ900GoRGJ900?o0000ojUFZOnY
EZT02?nYEZT00ol0003ohacSon<Lh`07on<Lh`03o`000?oV6NKoiQWV00[oiQWV00?o0000ooP7n?oh
1oP01?oh1oP00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ck
oo/4n`0<oo/4n`03o`000?o_4>ooka3_00Soka3_00Co0000ok1?/?n`Ck3o00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDJiA00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lRgB80
0ol0003o?L8mocg2?@0;ocg2?@03o`000?n9MXWoRGJ900KoRGJ900?o0000ojUFZOnYEZT01onYEZT0
0ol0003ohacSon<Lh`08on<Lh`Co00002?oV6NH00ol0003on0OhooP7n004ooP7n003o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_on`Ck00_on`Ck0ol00009onl@
k`03o`000?n`Ck3o000000_o/Dja00?o0000oefRGOl000002_mA[U400ol0003o8m`So`00000?oagR
7@03o`000?lRgB;o8]dR00;o8]dR00?o0000ocg2?Olm`Sd02olm`Sd00ol0003oRGJ9ohUfR@06ohUf
R@03o`000?nYEZWoZEJY00KoZEJY00?o0000on<LhooS7><02OoS7><01?l0003olPgboo8=l_ob3O87
o`0000;oiQWV00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ok1?_on`Ck00Son`Ck0ol00003oo/4n`03o`000?o_4>ooka3_00Ooka3_00?o0000ok5>
/OnaC[402onaC[400ol0003oDJiAoe6^D@0:oe6^D@03o`000?lMhQgo7N8M00go7N8M00?o0000ob;M
8_lRgB801?lRgB800ol0003o?L8mocg2?@09ocg2?@03o`000?n9MXWoRGJ900SoRGJ900?o0000ojUF
ZOnYEZT00onYEZT2o`0000cohacS00?o0000oo8=l_ob3O802?ob3O8<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo/4nook1?/01_ok1?/3o`0000Oon`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mA[U7oDJiA00WoDJiA0_l0000>oagR7@03o`000?lRgB;o8]dR00Go
8]dR00?o0000ocg2?Olm`Sd02Olm`Sd00ol0003oRGJ9ohUfR@09ohUfR@03o`000?nYEZWo000000;o
00000_oH9mP00ol0003ohacSon<Lh`08on<Lh`03o`000?ob3O;olPgb00colPgb00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?oo`3o0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`03oo/4n`?o00002ook1?/00ol0003oka3_
onl@k`04onl@k`03o`000?naC[7o/Dja00_o/Dja0ol00007oe6^D@?o000000?o?<<lo`000?lMhQd0
3OlMhQd00ol0003o8]dRob;M8P06ob;M8P03o`000?lm`Sgo?L8m00So?L8m00?o0000ohUfROn9MXT0
2_n9MXT00ol0003of2OHomPWf004omPWf003o`000?oS7>?ohacS00OohacS00?o0000oo8=l_ob3O80
2oob3O800ol0003onPGjooX5nP08ooX5nP03o`000?oo0?ooo`3o00Coo`3o0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo/4nol0
003o0000o`0000oon`Ck00?o0000onl@koo_4>l00oo_4>l>o`0000?oW6>L0_l00002oe6^D@?o0000
1Oll`c`00ol0003o7N8MoagR7@0:oagR7@03o`000?lRgB;o8]dR00Oo8]dR00?o0000ocg2?Olm`Sd0
2?lm`Sd00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?oH9mSof2OH00Gof2OH00?o0000on<LhooS7><0
1_oS7><00ol0003olPgboo8=lP0;oo8=lP03o`000?oj1O[onPGj00SonPGj00?o0000ool0oooo0?l0
1ooo0?l2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onl@koo_4>l00_o_4>l00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009occ3?003o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob;M8_lRgB802?lRgB82o`0000So?L8m00?o0000ohUfROn9MXT02On9MXT00ol0003of2OHomPW
f007omPWf003o`000?oS7>?ohacS00CohacS00?o0000oo8=l_ob3O802oob3O800ol0003onPGjooX5
nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?oka3_
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?ll`cco?<<l00Wo?<<l00?o0000
oagR7OlMhQd01olMhQd00ol0003o8]dRob;M8P09ob;M8P04o`000?m5^TGo0000o`0000Ko?L8m00?o
0000ohUfROn9MXT02On9MXT00ol0003of2OHomPWf008omPWf003o`000?oS7>?ohacS00?ohacS00?o
0000oo8=l_ob3O802oob3O800ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooj1OX2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o?<<locc3?00:occ3?0Wo00002olRgB800ol0003oAKY5odFjA@02odFjA@?o00000_lm`Sd0
0ol0003oRGJ9ohUfR@0:ohUfR@03o`000?oH9mSof2OH00Wof2OH00?o0000on<LhooS7><00_oS7><0
0ol0003olPgboo8=lP0:oo8=lP03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000GonPGj00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?ll`cco?<<l00Wo?<<l00?o0000obKI9_lVfBH01OlVfBH00ol0003o8]dRob;M8P09ob;M
8P03o`000?m5^TGoAKY500GoAKY50ol00009ohUfR@?o00003OoH9mP01Ol0003ohacSon<LhooS7>?o
000000colPgb00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000OonPGj00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?ll`cco?<<l00So?<<l00?o0000obKI9_lVfBH01olVfBH00ol0003o8]dRob;M8P07
ob;M8P03o`000?m5^TGoAKY500SoAKY50ol00002ohUfR@Go00000_o0?l000ol0003of2OHomPWf00<
omPWf003o`000?oS7>?o000000colPgb00?o0000ooX5n_oj1OX02_oj1OX00ol0003oo`3oool0o`0:
ool0o`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000SonPGj00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o?<<locc3?008occ3?003o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob;M8_lRgB801olRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;
00;o00002?o0?l000ol0003of2OHomPWf00<omPWf0Co00002_ob3O800ol0003onPGjooX5nP0:ooX5
nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooX5nP03o`000?o^4NkokQ7^
00;okQ7^00?o0000olPgb?o8=lP00_o8=lP4o`0000WoW6>L00?o0000occ3??ll`c`02?ll`c`00ol0
003o9]TVobKI9P08obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000odFjAOm5^TD02?m5^TD01Ol0
003oRgB;oh]dRon;M8_o000000[o`3o00ol0000;omPWf004o`000?og2?Oom`SgooL8m`Co00001Oob
3O800ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003onPGjooX5nP0:
ooX5nP03o`000?o^4NkokQ7^00?okQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003oW6>LoiaSW007
oiaSW003o`000?ll`cco?<<l00Ko?<<l0_l0000;obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000
odFjAOm5^TD02?m5^TD00ol0003oRgB;oh]dR`02oh]dR`03o`000?o0?l3o`3o000Oo`3o000?o0000
onXEj_oZ5NX01?l00006omPWf003o`000?og2?Oom`Sg00Kom`Sg0ol00002oo8=lP03o`000?oj1O[o
nPGj00_onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj00WonPGj00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ob3O8olPgb005olPgb003o`000?nLHicoW6>L00OoW6>L00?o0000occ3
??ll`c`00_ll`c`3o`000003oeNXEol0003o9]TV00[o9]TV00?o0000ob;M8_lRgB801OlRgB800ol0
003oAKY5odFjA@07odFjA@03o`000?n;M8_oRgB;00?oRgB;00?o0000ol0o`?o0?l001oo0?l000ol0
003ojQGZonXEjP04onXEjP?o00000_oH9mP00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003oo`3oool0o`0;ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003okQ7^onhAkP04onhAkP03
o`000?o8=lSob3O800Kob3O80_l00007oiaSW003o`000?ll`cco000000;o00001OmGZ5L00ol0003o
9]TVobKI9P08obKI9P?o00001?lRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;00Co
RgB;00?o0000ol0o`?o0?l001_o0?l000ol0003ojQGZonXEjP07onXEjP;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olPgb?o8=lP01?o8=lP00ol0003ocC;=oldbc@03o`0000CoW6>L
0_l00008oeNXE`03o`000?lVfBKo9]TV00Oo9]TV00Co0000odfbCOm=/TgoCK9=0ol000000olRgB;o
0000odFjA@09odFjA@03o`000?n;M8_oRgB;00CoRgB;00?o0000ol0o`?o0?l001Oo0?l000ol0003o
jQGZonXEjP09onXEjP03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
o`3oool0o`0<ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003okQ7^onhAkP06onhAkP03o`00
0?o8=lSob3O800?ob3O800?o0000oldbcOo=</d01?o=</d2o`000003oiaSW?l0003oEjQG00[oEjQG
00?o0000obKI9_lVfBH01OlVfBH00ol0003oCK9=odfbC@05odfbC@03o`000?m5^TGoAKY500OoAKY5
0ol00007oh]dR`03o`000?o0?l3o`3o000Co`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj
1O[onPGj00GonPGj0ol00009onhAkP05o`000?o8=lSob3O8olPgb?l000002Oo=</d00ol0003oEjQG
oeNXE`0;oeNXE`03o`000?lVfBKo9]TV00?o9]TV00?o0000odfbCOm=/Td01_m=/Td00ol0003oAKY5
odFjA@06odFjA@05o`000?n6NHKoQWV6ohIiQ_l000001on;M8/00ol0003o`3o0ol0o`003ol0o`003
o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjo`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003ob3O8olPgb?l00009oldbc@;o00003OmGZ5L00ol0003o9]TVobKI9P02obKI9P03
o`000?m=/TgoCK9=00SoCK9=00?o0000odFjAOm5^TD00om5^TD2o`0000GoQWV600?o0000oh]dRon;
M8/01?n;M8/00ol0003o`3o0ol0o`003ol0o`003o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ob3O8o`000009oldbc@04o`000?n/Djco[5>/o`0000go
EjQG00Co0000obKI9_lVfBKo00003?m=/Td01Ol0003oAKY5odFjAOm5^TGo000000SoQWV60_l00005
oh]dR`03o`000?o0?l3o`3o000;o`3o000?o0000onXEj_oZ5NX02OoZ5NX00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ocC;=oldbc@07oldbc@03o`000?n/Djco[5>/
00;o[5>/00?o0000oeNXEomGZ5L02_mGZ5L00ol0003o9]TVo`00000>odfbC@03o`000?m5^TGo0000
00_oQWV600?o0000oh]dRon;M8/00_n;M8/01Ol0003o`3o0ol0o`?o0?l3o000000cojQGZ00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ocC;=oldbc@06oldbc@03o`000?n/Djco[5>/
00?o[5>/00?o0000oeNXEomGZ5L02omGZ5L00ol0003oCK9=odfbC@0>odfbC@03o`000?n6NHKoQWV6
00_oQWV60_l00003oh]dR`04o`000?o0?l3o`3o0o`0000[ojQGZ0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ocC;=oldbc@06oldbc@03o`000?n/Djco[5>/00Go[5>/00?o0000oeNX
EomGZ5L01omGZ5L3o`00017oCK9=00?o0000ohIiQ_n6NHH03On6NHH01Ol0003oRgB;oh]dRol0003o
`3o000Co00000ooZ5NX5o`0000;on`Ck00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000oldbcOo=</d01Oo=</d00ol0003o[5>/ojaC[006ojaC[003o`000?mGZ5OoEjQG
00CoEjQG0ol00002of:MHP03o`000?m=/TgoCK9=00ooCK9=0_l0000?ohIiQP04o`000?n;M8_o0000
o`0000Cogb3O0ol00008oo/4n`03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003oo`3oool0o`07ool0o`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000OocC;=00?o0000ojaC
[?n/Dj`02?n/Dj`00ol0003oEjQGoeNXE`03o`0000KoHYeR00?o0000odfbCOm=/Td03Om=/Td01?l0
003oSW6>ohiaS_l0000?ohIiQP03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/02?ok1?/0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ool0o`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o=</gocC;=00?ocC;=00?o0000ojaC[?n/Dj`02_n/Dj`2o`0000[oHYeR00?o0000odfb
COm=/Td02om=/Td00ol0003oSW6>ohiaSP02ohiaSP03o`000?n6NHKoQWV600_oQWV60_l00007omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ool0
oooo0?l00ooo0?l3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00co
oP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o=</gocC;=oldb
cOl000003On/Dj`00ol0003oHYeRof:MHP0:of:MHP03o`000?m=/TgoCK9=00WoCK9=00?o0000ohia
S_n>LHh01?n>LHh00ol0003oQWV6ohIiQP08ohIiQP;o000000?o/Djao`000?oO8=l01ooO8=l00ol0
003on`Ckoo/4n`09oo/4n`04o`000?og2?Oo0000o`0001CooP7n00?o0000ool0oooo0?l00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003ocC;=o`00000=ojaC[003o`000?mRWF;oHYeR
00_oHYeR00?o0000odfbCOm=/Td02?m=/Td00ol0003oSW6>ohiaSP06ohiaSP03o`000?n6NHKoQWV6
00GoQWV60_l00003ok5>/@03o`000?oO8=oogb3O00Kogb3O00?o0000oo/4nook1?/02_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ooh1o_on
0Oh03oon0Oh00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000ojaC[?n/
Dj`03?n/Dj`00ol0003oHYeRof:MHP0<of:MHP03o`000?m=/TgoCK9=00KoCK9=00?o0000ohiaS_n>
LHh02?n>LHh00ol0003oQWV6ohIiQP02ohIiQP;o00001_naC[400ol0003ogb3OomlPg`05omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000co[5>/00?o0000of:MH_mRWF803OmRWF800ol0003oCK9=
odfbC@04odfbC@03o`000?n>LHkoSW6>00[oSW6>00Co0000ohIiQ_l0003o00002?naC[400ol0003o
gb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0Aooh1oPCo0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oC;=?o000000;o00002?n/Dj`00ol0003oHYeR
of:MHP0?of:MHPKo00003_n>LHh00ol0003o/Djaok5>/@08ok5>/@03o`000?oO8=oogb3O00Kogb3O
00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?on0OkooP7n017ooP7n00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oC;=?odbcC00?odbcC0ol00005ojaC[0;o00004?mRWF801_l0003oMHYe
ogF:MOl0003oJiA[o`0000koSW6>00?o0000ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`05omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?on0OkooP7n00oooP7n00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oC;=?odbcC00KodbcC0ol000001?n/Djco0000oi5^TOnAKY43o`00
00coHYeR00Go0000ogF:MOmeRWGoMHYeo`000002of^DJ`03o`000?n>LHkoSW6>00_oSW6>00?o0000
ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Son`Ck0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03oon0Oh00ol0003oo0?loo`3o004oo`3o0oo00003?oC;=<00ol0003oTFjAoi5^T@04oi5^
T@?o00002?mRWF800ol0003oMHYeogF:M@02ogF:M@05o`000?m[U6_oJiA[of^DJol000003?n>LHh0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oO8=oogb3O00Gogb3O3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om</
dooC;=<02_oC;=<00ol0003oTFjAoi5^T@07oi5^T@;o00001OmRWF800ol0003oMHYeogF:M@03ogF:
M@03o`000?m[U6_oJiA[00;oJiA[00?o0000ohiaS_n>LHh02On>LHh00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om</dooC;=<02ooC;=<00ol0003oTFjAoi5^T@09oi5^T@?o000000?oHYeRo`000?me
RWD01OmeRWD00ol0003oJiA[of^DJ`03of^DJ`03o`000?n>LHkoSW6>00SoSW6>3_l00003omlPg`;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?on0OkooP7n00gooP7n
00?o0000oo`3o?ol0o`01Ool0o`00ol0003omPWfo`00000;oo0?l003o`000?oC;=?odbcC00[odbcC
0_l0000>oi5^T@03o`000?meRWGoMHYe00GoMHYe00?o0000of^DJom[U6/00om[U6/00ol0003oSW6>
ohiaSP08ohiaSP03o`000?oQ7^7ohAkQ00_ohAkQ00?o0000omlPgol000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooH9m_of2OKo00002_o`3o000ol0003odbcCom</d`09om</d`03o`000?o1?/7o000000koTFjA
00?o0000ogF:MOmeRWD01OmeRWD00ol0003oJiA[of^DJ`04of^DJ`03o`000?n>LHkoSW6>00KoSW6>
00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH00_of
2OH00ol0003ol0o`oo0?l006oo0?l003o`000?oC;=?odbcC00SodbcC0_l00003ol4n`@03o`000?nA
KY7oTFjA00_oTFjA00?o0000ogF:MOmeRWD01OmeRWD00ol0003oJiA[of^DJ`05of^DJ`03o`000?n>
LHkoSW6>00GoSW6>00?o0000on4NhOoQ7^403OoQ7^400ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooH9m_of2OH00oof2OH00ol0003ol0o`oo0?l005oo0?l003o`000?oC;=?odbcC00OodbcC00?o0000
ol4n`Oo1?/400oo1?/400ol0003oTFjAoi5^T@0:oi5^T@03o`000?meRWGoMHYe00KoMHYe00?o0000
of^DJom[U6/01_m[U6/00ol0003oSW6>ohiaSP04ohiaSP03o`000?oQ7^7ohAkQ00gohAkQ3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01Oof2OH00ol0
003ol0o`oo0?l004oo0?l003o`000?oC;=?odbcC00GodbcC0_l00006ol4n`@03o`000?nAKY7oTFjA
00WoTFjA0_l00008ogF:M@03o`000?m[U6_oJiA[00KoJiA[1Ol000000on>LHko0000on4Nh@0?on4N
h@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ooh1oP03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01_of2OH00ol0003o
l0o`oo0?l004o`0000KodbcC00?o0000ol4n`Oo1?/401oo1?/400ol0003oTFjAoi5^T@05oi5^T@?o
000000?oTFjAo`000?meRWD01omeRWD00ol0003oJiA[of^DJ`05of^DJ`03o`000?n^DJko[U6^00?o
[U6^0_l0000?on4Nh@;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo0?l00?o0000ooH9m_of2OH01oof2OH2o`0000CojAKY00Co0000om</dooC;=?o
dbcC0_l0000:ol4n`@03o`000?nAKY7oTFjA00;oTFjA0ol00005oi5^T@03o`000?meRWGoMHYe00Go
MHYe00?o0000of^DJom[U6/01?m[U6/00ol0003o[U6^ojiA[P06ojiA[P03o`000?oQ7^7ohAkQ00[o
hAkQ0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003omPWfooH9mP08ooH9mP03o`00
0?oY5^WojAKY00CojAKY00?o0000om</dol000003?o1?/400ol0003oTFjAo`000002o`0000WoTFjA
00?o0000ogF:MOmeRWD01?meRWD00ol0003oJiA[of^DJ`03of^DJ`03o`000?n^DJko[U6^00So[U6^
1_l00004on4Nh@;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH01oof
2OH00ol0003ojAKYonTFj@06onTFj@03o`000?o1?/7o`Ck100co`Ck100?o0000oi5^TOnAKY402_nA
KY400ol0003oMHYeogF:M@04ogF:M@04o`000?m[U6_oJiA[of^DJ`;o00002on^DJh00ol0003oj1OX
onPGj003onPGj0Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003omPWfooH9mP07ooH9mP03o`000?oY
5^WojAKY00OojAKY00?o0000ol4n`Oo1?/403?o1?/400ol0003oTFjAoi5^T@0;oi5^T@03o`000?me
RWGoMHYe00?oMHYe00Co0000of^DJom[U6_o00003On^DJh00ol0003oj1OXonPGj006onPGj003o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000ooH9m_of2OH0
1_of2OH00ol0003ojAKYonTFj@09onTFj@03o`000?o1?/7o`Ck100Wo`Ck10_l0000>oi5^T@?o0000
0omeRWD00ol0003oJiA[o`00000=ojiA[P03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000OomPWf00?o
0000onTFjOoY5^T02_oY5^T00ol0003o`Ck1ol4n`@06ol4n`@;o000000?o`Sg2o`000?nAKY402onA
KY42o`0000?oWf2O1Ol0000>ojiA[P03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`03oo/4n`Co00000_of2OH00ol0003ojAKYonTFj@0;
onTFj@03o`000?o1?/7o`Ck100?o`Ck10ol00004ol8m`P03o`000?nAKY7oTFjA00OoTFjA0_l00008
oimPW`03o`000?n^DJko[U6^00go[U6^00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onTFj@03o`000?o1?/7o`Ck100;o00002?o2?L800ol0
003oTFjAoi5^T@05oi5^T@03o`000?nOH9ooWf2O00SoWf2O00?o0000ojiA[_n^DJh03On^DJh00ol0
003oj1OXonPGj008onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oY5^WojAKY00kojAKY0_l0000;ol8m`P03o`000?nAKY7oTFjA00;oTFjA0_l0000;oimP
W`03o`000?n^DJko[U6^00go[U6^00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00gojAKY0_l0000<ol8m`P04o`000?nAKY7o0000
o`0000goWf2O00?o0000ojiA[_n^DJh03?n^DJh00ol0003oj1OXonPGj009onPGj003o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00cojAKY00Co0000on<L
hooS7>?o00003?o2?L800ol0003oWf2OoimPW`0>oimPW`03o`000?n^DJko[U6^00So[U6^1?l0000;
onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oY5^WojAKY
00_ojAKY00?o0000on<LhooS7><00_oS7><00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nOH9ooWf2O
00koWf2O00Co0000ojiA[_n^DJko[U6^1ol00003om0_d003o`000?oX5nSoj1OX00Woj1OX00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000onTFjOoY5^T02_oY5^T00ol0
003ohacSon<Lh`03on<Lh`03o`000?o2?L;o`Sg200So`Sg200?o0000oimPWonOH9l03_nOH9l4o`00
00_od2o@00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook
1?/03?ok1?/7o`0000GojAKY00?o0000on<LhooS7><01OoS7><00ol0003o`Sg2ol8m`P07ol8m`P03
o`000?nOH9ooWf2O00koWf2O00?o0000om0_d?o@;m003Oo@;m000ol0003oj1OXonPGj008onPGj003
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oe2_Gom@[e00Com@[e
1Ol00009on<Lh`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oimPWonOH9l03_nOH9l00ol0003od2o@
om0_d00=om0_d003o`000?oX5nSoj1OX00Soj1OX00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=oo/4n`03o`000?oe2_Gom@[e00Wom@[e
0_l00009on<Lh`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oimPWonOH9l03?nOH9l00ol0003od2o@
om0_d00?om0_d0Ko00001?oX5nP4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m@[eooD:m@09ooD:m@03o`000?o]4^go000000;o00001ooS7><00ol0003o`Sg2ol8m`P05ol8m`P03
o`000?nOH9ooWf2O00SoWf2O1Ol0000Aom0_d003o`000?o_4>ooka3_00?oka3_1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000ooD:mOoe2_D02_oe2_D00ol0003okA;]ondBk@02ondBk@?o00001OoS7><00ol0003o`Sg2
ol8m`P04ol8m`P04o`000?nOH9ooWf2OoimPW`Oo00001?o?<<l00ol0003od2o@om0_d00>om0_d003
o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om@[e
ooD:m@0;ooD:m@03o`000?o]4^gokA;]00GokA;]0ol00003on<Lh`04o`000?o2?L;o`Sg2ol8m`PKo
00003?o?<<l00ol0003od2o@om0_d00=om0_d003o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?oe2_D0
3?oe2_D00ol0003okA;]ondBk@08ondBk@?o000000CohacSo`000?l0003o00000_oY5^T00ol0003o
cc3?oll`c`0=oll`c`03o`000?o@;m3od2o@00cod2o@00?o0000onl@koo_4>l02?o_4>l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003okA;]ondBk@0;ondBk@03o`000?oY5^WojAKY00?o
jAKY00?o0000oll`coo?<<l03?o?<<l00ol0003ofBKIo`00000=om0_d003o`000?o_4>ooka3_00So
ka3_00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003okA;]ondBk@0:ondBk@03o`00
0?oY5^WojAKY00GojAKY00?o0000oll`coo?<<l02_o?<<l01?l0003ofBKIomTVfOoI9]T2o`0000[o
d2o@00?o0000onl@koo_4>l02Oo_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooD:mOoe2_D0
3?oe2_D00ol0003okA;]ondBk@09ondBk@03o`000?oY5^WojAKY00KojAKY00?o0000oll`coo?<<l0
2Oo?<<l00ol0003ofBKIomTVf@02omTVf@03o`000?o[5>_o000000;o00001oo@;m000ol0003oka3_
onl@k`09onl@k`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@0;ooD:m@03o`000?o]
4^gokA;]00SokA;]00?o0000onTFjOoY5^T01ooY5^T00ol0003occ3?oll`c`08oll`c`03o`000?oI
9]WofBKI00?ofBKI00?o0000on/Djoo[5>/00_o[5>/2o`0000Cod2o@00?o0000onl@koo_4>l02_o_
4>l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;ooD:m@Ko00001?o]4^d00ol0003ojAKYonTFj@08
onTFj@03o`000?o?<<oocc3?00Oocc3?00?o0000omTVfOoI9]T00ooI9]T00ol0003ojaC[on/Dj`05
on/Dj`?o000000?od2o@o`000?o_4>l02oo_4>l00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006ooD:m@03o`000?og2?Oom`Sg00Com`Sg1?l0000<onTFj@03o`000?o?<<oocc3?
00Gocc3?00?o0000omTVfOoI9]T01?oI9]T00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_
00_oka3_00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om@[e00?o0000ooL8moog
2?L02?og2?L00ol0003ojAKYonTFj@0:onTFj@03o`000?o?<<oocc3?00Cocc3?00?o0000omTVfOoI
9]T01OoI9]T00ol0003ojaC[on/Dj`08on/Dj`03o`000?o_4>ooka3_00Woka3_1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooL8m`03o`000?oY5^WojAKY00WojAKY
00?o0000oll`coo?<<l00oo?<<l00ol0003ofBKIomTVf@05omTVf@03o`000?o[5>_ojaC[00[ojaC[
00?o0000onl@koo_4>l01?o_4>l4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oY5^WojAKY00WojAKY00?o0000oll`coo?<<l00_o?
<<l00ol0003ofBKIomTVf@06omTVf@03o`000?o[5>_ojaC[00[ojaC[00?o0000onl@koo_4>l01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?og2?Oom`Sg00[om`Sg00?o0000onTFjOoY5^T02OoY5^T01Ol0003occ3?oll`
coo?<<oo000000WofBKI00?o0000on/Djoo[5>/02oo[5>/2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003om`SgooL8m`0;ooL8m`03o`000?oY5^WojAKY00WojAKY00?o
0000oll`col000002OoI9]T00ol0003ojaC[on/Dj`0<on/Dj`03o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oY5^Wo
jAKY00SojAKY1Ol00008omTVf@03o`000?o[5>_ojaC[00cojaC[00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooL8moog2?L02_og2?L00ol0003ojAKYonTFj@07onTF
j@03o`000?o]4^gokA;]00?okA;]0ol00005omTVf@03o`000?o[5>_ojaC[00_ojaC[00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
m`Sg00?o0000onTFjOoY5^T01OoY5^T00ol0003okA;]ondBk@07ondBk@?o000000?ofBKIo`000?o[
5>/03Oo[5>/00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_og2?L00ol0003ojAKYonTFj@03onTFj@;o0000
3Oo]4^d2o`0000gojaC[0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?og2?Oom`Sg00Oom`Sg00Co0000onTFjOoY5^WojAKY
0_l00002ooP7n003o`000?o]4^gokA;]00cokA;]3Ol00003ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooL8m`03o`000?oY5^Wo000000Gon0Oh
00?o0000ondBkOo]4^d02oo]4^d00ol0003olPgboo8=lP09oo8=lP03o`000?oj1O[onPGj00;onPGj
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om`Sg0ol0
0007ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oo8=l_ob3O802Oob3O800ol0003onPGjooX5
nP04ooX5nP;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003okA;]ondB
k@08ondBk@03o`000?ob3O;olPgb00[olPgb00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o]4^gokA;]00OokA;]00?o
0000oo8=l_ob3O802_ob3O800ol0003onPGjooX5nP07ooX5nP;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o]4^gokA;]00KokA;]00?o0000oo8=l_ob3O802_ob3O80
0ol0003onPGjooX5nP09ooX5nP05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ondBkOo]4^d01Oo]4^d00ol0003olPgboo8=lP0:
oo8=lP03o`000?oj1O[onPGj00WonPGj1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@04ondBk@03o`000?ob3O;olPgb00WolPgb00?o0000
ooX5n_oj1OX02?oj1OX2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]
00;okA;]00?o0000oo8=l_ob3O802_ob3O800ol0003onPGjooX5nP06ooX5nP;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000ondBkOo]
4^gokA;]o`00000<oo8=lP03o`000?oj1O[onPGj00ConPGj0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003okA;]o`000004o`0000WolPgb00?o0000ooX5n_oj1OX00_oj1OX2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003oo0?loo`3o003oo`3o0Oo00000_ob3O800ol0003onPGjooX5nP02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003ooP7n
o`000002o`0000Son0Oh00?o0000oo`3o?ol0o`02_ol0o`5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP?o00001?oh1oP00ol0003oo0?loo`3
o00=oo`3o003o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?on0OkooP7n00KooP7n0ol000000ooh1oSo0000oo`3o00>oo`3o003o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?on0OkooP7n00[ooP7n00?o0000oo`3
o?ol0o`03ool0o`00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?on0OkooP7n00[o
oP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00ooo0?l00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?on0OkooP7n00_ooP7n5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000kooP7n
00?o0000ooh1o_on0Oh04?on0Oh00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ooh1oP03o`00
0?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00WooP7n1Ol0
000Booh1oP;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?on0OkooP7n00;ooP7n1ol00004ool0o`03o`000?on0Oko
oP7n00oooP7n00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?on0OkooP7n00cooP7n0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?on0OkooP7n00_o
oP7n00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on
0Oh02Oon0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?on0OkooP7n00KooP7n0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_on0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000oon0Oh2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ooh1o_l000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00T_l00?l5oooo02So003o1Oooo`1Wo`00o`7ooooo002B
o`00o`;oool000?o<S;<o`00ool00?l0:_l00?l00olb</coool0oooo001Wo`00o`7ooooo002Bo`00
o`;oool0;_l00?l2oooo06Oo003o0Oooool009;o003o0_ooo`0^o`00o`;oool0Iol00?l1ooooo`00
K?l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`06o`00o`?oool02Ol00?l3oooo00co003o1?ooo`09o`00o`;oool0
Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09o`00o`;oool00ol00?l4oooo00;o003o0_oo
o`03o`00o`;oool000?o003ooooo0?ooo`002?l00?l3oooo00Wo003o0oooo`09o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0Iol00?l1ooooo`00K?l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0oooo`09o`00o`?oool01_l00?l2oooo00Co003o0_ooo`07o`00o`;oool0Iol00?l1
ooooo`00Jol00?l2oooo0003o`00ooooo`3o003o00?o003o0_ooo`000ol00?ooool0o`00o`07o`00
o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3oool0
00_o003o0oooo`09o`00o`?oool01Ol00?l2oooo00Go003o00?oool0o`00ool00?l01Ol00?l2oooo
06Oo003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l0
0?l01ol00?l2oooo00Co003o0_ooo`06o`00o`Coool000?o003ooooo0?ooo`003?l00?l2oooo00[o
003o0_ooo`05o`00o`03oooo0?l00?oo003o00Co003o00?oool0o`00ool00?l01Ol00?l2oooo06Oo
003o0Oooool006_o003o0_ooo`000ol00?ooool0o`00o`03o`00o`;oool000?o003ooooo0?l00?l0
1ol00?l2oooo00Co003o0_ooo`05o`00o`Coool00_l00?l2oooo00go003o0_ooo`0:o`00o`;oool0
0ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00J_l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00go003o0_ooo`0:o`00o`;oool00ol00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
Iol00?l1ooooo`00J_l00?l2oooo00?o003o00?oool0o`00ool00?l00_ooo`03o`00o`03oooo0?l0
0?oo003o00Go003o0_ooo`04o`00o`;oool00ol00?l2oooo00Co003o00Coool0o`00ooooo`3oool0
2?l00?l5oooo0003o`00ooooo`3oool000Co003o1Oooo`000ol00?ooool0oooo0002o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`1Wo`00o`7ooooo001Zo`00o`;oool00ol00?l00oooo`3o003oo`00
o`02oooo00?o003o00?oool0o`00ool00?l01Ol00?l2oooo00Co003o0_ooo`03o`00o`;oool01?l0
0?l01?ooo`3o003ooooo0?ooo`07o`00o`;oool01?l00?l3oooo00?o003o0_ooo`04o`00o`?oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2oooo00Co003o00?o
ool0o`00ooooo`000_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00?o003o0_ooo`000ol00?ooool0oooo0006o`00o`?oool01Ol00?l2oooo00;o003o0ooo
o`05o`00o`;oool00_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0Iol00?l1ooooo`00JOl00?l2
oooo00Go003o0oooo`05o`00o`03oooo0?l00?oo003o00?o003o0oooo`03o`00o`?oool01?l00?l4
oooo0003o`00ooooo`3o003o00;oool01_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2
oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006Wo003o0_ooo`05o`00
o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo00Ko003o0_ooo`02o`00
o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo06Oo003o0Oooool006So
003o0oooo`05o`00o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool01_l00?l2oooo00Ko
003o0_ooo`02o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go
003o0_ooo`1Wo`00o`7ooooo001Xo`00o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool0
1_l00?l2oooo00Ko003o00Coool0o`00ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00;o
003o0_ooo`04o`00o`;oool01ol00?l2oooo06Oo003o0Oooool006So003o0_ooo`06o`00o`;oool0
1ol00?l00oooo`3o003oo`00o`0Fo`00o`;oool000?o<S;<o`00ool00?l01?l00?l00oooo`3o003o
o`00o`03o`00o`;oool01?l00?l00oooo`3o003oo`00o`03o`00o`;oool01?l00?l2oooo00Co003o
0_ooo`06o`00o`03oc8bc?ooo`3oool006Oo003o0Oooool006Oo003o0oooo`05o`00o`?oool01ol0
0?l00oooo`3o003oo`00o`0Fo`00o`Goool01?l00?l2oooo00?o003o0_ooo`05o`00o`;oool00ol0
0?l2oooo00Ko003o0_ooo`02o`00o`;oool01Ol00?l5oooo06Oo003o0Oooool006Ko003o1_ooo`00
0ol00?ooool0oooo0005oooo00?o003o1Oooo`0Qo`00o`Coool02?l00?l4oooo00So003o1?ooo`1b
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 300 309.581 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -55.9063 0 ]
[.5 1.04444 55.9063 26 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -116.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(Wus) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
106.938 23.000 moveto
(@) show
114.875 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1000) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
162.875 23.000 moveto
(D) show
170.812 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.995 .005 .995 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.995 .005 .995 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.994 .006 .994 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.992 .008 .992 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.996 .004 .996 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.99 .01 .99 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.979 .021 .979 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.981 .019 .981 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.997 .003 .997 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.958 .042 .958 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.987 .013 .987 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.995 .005 .995 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.997 .003 .997 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.995 .005 .995 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.91 .09 .91 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.983 .017 .983 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.971 .029 .971 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.969 .031 .969 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.974 .026 .974 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.985 .015 .985 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.992 .008 .992 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.958 .042 .958 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.982 .018 .982 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.931 .069 .931 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.988 .012 .988 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.982 .018 .982 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.973 .027 .973 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.977 .023 .977 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.926 .074 .926 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.987 .013 .987 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.961 .039 .961 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.935 .065 .935 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.78 .22 .78 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.815 .185 .815 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.996 .004 .996 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.997 .003 .997 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.984 .016 .984 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.939 .061 .939 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.941 .059 .941 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.804 .196 .804 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.766 .234 .766 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.689 .311 .689 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.931 .069 .931 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.959 .041 .959 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.952 .048 .952 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.913 .087 .913 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.995 .005 .995 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.781 .219 .781 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.988 .012 .988 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.981 .019 .981 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.819 .181 .819 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.695 .305 .695 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.877 .123 .877 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.444 .556 .444 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.438 .562 .438 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.573 .427 .573 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.801 .199 .801 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.827 .173 .827 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.989 .011 .989 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.517 .483 .517 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.465 .535 .465 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.966 .034 .966 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.995 .005 .995 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.611 .389 .611 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.755 .245 .755 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.926 .074 .926 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.941 .059 .941 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.674 .326 .674 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.89 .11 .89 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.877 .123 .877 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.76 .24 .76 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.995 .005 .995 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.176 .824 .176 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.319 .681 .319 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.983 .017 .983 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.287 .713 .287 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.206 .794 .206 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.915 .085 .915 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.986 .014 .986 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.557 .443 .557 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.156 .844 .156 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.235 .765 .235 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.847 .153 .847 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.342 .658 .342 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.571 .429 .571 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.259 .741 .259 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.063 .937 .063 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.137 .863 .137 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.037 .963 .037 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.384 .616 .384 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.57 .43 .57 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.971 .029 .971 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.626 .374 .626 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.712 .288 .712 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.073 .927 .073 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.015 .985 .015 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.039 .961 .039 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.115 .885 .115 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.151 .849 .151 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.812 .188 .812 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.929 .071 .929 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.955 .045 .955 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.531 .469 .531 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.107 .893 .107 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.849 .151 .849 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.993 .007 .993 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.247 .753 .247 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.461 .539 .461 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.153 .847 .153 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.304 .696 .304 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.89 .11 .89 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.42 .58 .42 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.134 .866 .134 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.985 .015 .985 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.997 .003 .997 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.922 .078 .922 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.947 .053 .947 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.335 .665 .335 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.98 .02 .98 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.047 .953 .047 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.007 .993 .007 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.684 .316 .684 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.665 .335 .665 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.155 .845 .155 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.271 .729 .271 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.56 .44 .56 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.815 .185 .815 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.999 .001 .999 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.157 .843 .157 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.99 .01 .99 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.079 .921 .079 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.243 .757 .243 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.353 .647 .353 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.977 .023 .977 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.527 .473 .527 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.995 .005 .995 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.514 .486 .514 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.368 .632 .368 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.29 .71 .29 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.937 .063 .937 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.916 .084 .916 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.909 .091 .909 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.241 .759 .241 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.546 .454 .546 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.695 .305 .695 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.883 .117 .883 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.979 .021 .979 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.994 .006 .994 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.539 .461 .539 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.754 .246 .754 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.452 .548 .452 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.973 .027 .973 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.953 .047 .953 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.873 .127 .873 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.983 .017 .983 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.995 .005 .995 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.555 .445 .555 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.665 .335 .665 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.993 .007 .993 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.62 .38 .62 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.918 .082 .918 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.746 .254 .746 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.848 .152 .848 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.703 .297 .703 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.981 .019 .981 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.966 .034 .966 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.97 .03 .97 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.984 .016 .984 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.818 .182 .818 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.996 .004 .996 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.975 .025 .975 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.786 .214 .786 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.798 .202 .798 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.898 .102 .898 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.889 .111 .889 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.995 .005 .995 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.968 .032 .968 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.993 .007 .993 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.852 .148 .852 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.99 .01 .99 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.97 .03 .97 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.95 .05 .95 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.94 .06 .94 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.902 .098 .902 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.91 .09 .91 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.996 .004 .996 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.878 .122 .878 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.954 .046 .954 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.961 .039 .961 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.985 .015 .985 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.973 .027 .973 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.98 .02 .98 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.99 .01 .99 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.977 .023 .977 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.924 .076 .924 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.972 .028 .972 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.981 .019 .981 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.99 .01 .99 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.986 .014 .986 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.988 .012 .988 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.997 .003 .997 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.978 .022 .978 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.995 .005 .995 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.996 .004 .996 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.993 .007 .993 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.983 .017 .983 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.995 .005 .995 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.989 .011 .989 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.988 .012 .988 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.999 .001 .999 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -69 -30 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 34 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 24.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 309.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001=B000`400?l00000o`00003oool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo002Co`00o`Oo
0000TOl00?l1ooooo`00T_l00?l00ol0003oo`3oool0o`05ool0o`Go0000S?l00?l1ooooo`00QOl0
0?l7o`0000Go003o00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`29o`00o`7ooooo0020
o`00o`Go00001ooo0?l3o`000003o`00ool0003oo`3o00koo`3o00?o0000o`00ool00?l03ol00?l4
o`0004ko003o1?ooo`0So`00o`7ooooo001oo`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03ooo0?l01?l0003o003oo`00ool00?l5o`0000Go003o0ol00004ool0o`?o0000B_l00?l2
oooo00?o003o00?oool0o`00ool00?l08?l00?l1ooooo`00O_l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`03o`000?l00?oo000000;o00002_oo0?l2o`00
04Oo003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00OOl00?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?l00?oo003o04Go003o0_ooo`05o`00o`03oooo0?l00?oo003o01oo003o0Oooool0073o003o
2?l00004o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0A?l00?l00oooo`3o003o
o`00o`04o`00o`03oooo0?l00?oo003o01oo003o0Oooool005go003o0ol00009o`00o`Oo00002?oo
0?l4o`0001?oo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`12o`00o`;oool01_l00?l2oooo023o003o0Oooool005[o003o0ol00003
ool0o`?o00001Ol00?l00ol0003oo`3oool0o`0=ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo
0?l01?l0003ooP7nooh1o_l0000>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l00?l2oooo023o003o0Oooool005Oo003o0ol0
0009ool0o`?o000000?o003oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`11o`00o`;oool01_l0
0?l2oooo023o003o0Oooool005Go003o0_l0000?ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
o`00ool00?l0@?l00?l2oooo00Ko003o0_ooo`0Po`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0oo`00o`;oool01_l00?l2oooo
023o003o0Oooool005Co003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?l00?oo003o03ko003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00E?l00?l00ol0003oo`3o
ool0o`0>ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l04?oo0?l<o`0003Go003o0_ooo`06o`00o`;oool08?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko0000013oo`3o00?o0000ool0oooo0?l02?oo
0?l9o`0000cooP7n00Co0000ool0oooo0?ooo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0bo`00o`;oool01_l00?l00oooo`3o003o
o`00o`0Oo`00o`7ooooo001Co`00o`03o`000?oo0?ooo`3o00coo`3o0_l00003ooh1oP03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on
0OkooP7n00_ooP7n0ol00003ooh1oP03o`000?oo0?ooo`3o00coo`3o0ol0000>ool0o`;o00003Ooo
0?l2o`0003?o003o0_ooo`04o`00o`;oool08Ol00?l1ooooo`00BOl00?l:o`0000koo`3o00?o0000
ooh1o_on0Oh00oon0Oh00ol0003oo`3oool0o`0;ool0o`;o00002ooo0?l00ol0003oo@;mood2o@06
ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3oool0o`0:
ool0o`04o`000?om0_goo@;mood2o@;o00002_oo0?l2o`000003ood2oOl0003oo`3o00koo`3o00?o
0000o`00ool00?l0<?l00?l2oooo00Co003o0_ooo`0Qo`00o`7ooooo0018o`00o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo
o`3o00Woo`3o00?o0000ooh1o_l000002ooo0?l00ol0003oo@;mood2o@06ood2o@03o`000?on0Oko
oP7n00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?om0_go
o@;m00Coo@;m0_l00005ool0o`?o00001?om0_d00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo
003o033o003o0_ooo`02o`00o`;oool08_l00?l1ooooo`00Aol00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l00008ooh1oP03o`000?oo0?ooo`3o00Ooo`3o0_l00003ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l01Ooo0?l2o`0000Woo@;m0_l000000ooo
0?oo0000o`000007ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0<Ol00?l4oooo
02?o003o0Oooool004Ko003o00?o0000ool0oooo0?l02_oo0?l2o`0000Soo`3o00?o0000ooh1o_on
0Oh02?on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo
0?l01ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d01oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o05Oo003o0Oooool004Go003o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7no`000005ool0o`;o00002oon0Oh2o`0000Koo`3o
00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP0;ooh1oP05o`000?oo0?ooo`3oool0ool0
00003_om0_d00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0Eol00?l1ooooo`00A?l00?l00ol0003oo`3oool0o`0;ool0o`05o`000?on0OkooP7nooh1o_l0
00000ooo0?l00ol0003ooP7nooh1oP0:ooh1oP04o`000?ol0ocoo0?lo`0000?oo`3o0_l00008ooh1
oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003ooP7nooh1oP05ooh1
oP03o`000?on0OkooP7n00cooP7n00?o0000ool0ool000003oom0_d00ol0003oo@;mood2o@08ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l09Ol00?lGool0oa[o003o0Oooool004?o
003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo000000_o
oP7n0_l00004oo`3o003o`000?oo0?oo000000_ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@09ood2o@03o`000?on0OkooP7n00CooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003o
o@;mood2o@0>ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0To`00oaOoo`3o6_l00?l1ooooo`00?_l00?l5o`0000koo`3o00?o0000ooh1o_on0Oh0
1?on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh0
2_on0Oh00ol0003oo`3oool0o`05ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Co003o5ooo0?lJo`00o`7ooooo
000mo`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP05ooh1oP03o`000?on0OkooP7n00OooP7n0_l00008oo`3o003o`000?on0OkooP7n00_ooP7n00?o
0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0:ood2o@04o`000?on0OkooP7nooh1oP?o0000
3oon0Oh00ol0003oo@;mood2o@0>ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l0
3ooo0?l3o`0002?o003o5ooo0?lJo`00o`7ooooo000ko`00o`;o00001_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh01?on0Oh2o`0000_oo0?l1?l0
0009ooh1oP03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02oom0_d01?l0003ooP7no`00
0?l00003ooT6n@;o00003?on0Oh2o`00013oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3o
ool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`?o00008?l00?lGooX5nQ[o003o0Oooool003?o003o
1?l00003o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`01?l0003om0_d
oo@;m?od2o@5o`0000GooP7n00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@0<ood2o@03
o`000?oi1_Won@Ki00Gon@Ki0_l00008ooh1oP;o00000_oi1_T00ol0003oo@;mood2o@0=ood2o@03
o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`?o
00007Ol00?lGooX5nQ[o003o0Oooool003;o003o00?o0000ool0oooo0?l00_oo0?l3o`0000[oo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00;o0000
3Ool0o`00ol0003om0_doo@;m007oo@;m0Ko00000_oo0?l4o`0000goo@;m00?o0000ooT6nOoi1_T0
1ooi1_T2o`0000GooP7n00?o0000ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@0<ood2o@03o`00
0?om0_goo@;m00coo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?l00?oo003o01[o003o5ooj1OXJo`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00WooP7n00?o
0000ooh1o_l000003ool0o`00ol0003om0_doo@;m00<oo@;m0?o00001?oj1OX3o`0000Woo@;m00?o
0000ooT6nOoi1_T02_oi1_T2o`000003ooh1o_l0003o000000Oon@Ki00?o0000ood2oOom0_d02oom
0_d00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o1?l0000<ool0o`03o`000?l0
0?oo003o01[o003o5ooj1OXJo`00o`7ooooo000`o`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000
oo`3o?ol0o`03_ol0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj00KonPGj0ol00005
ood2o@03o`000?oi1_Won@Ki00gon@Ki00?o0000ooT6nOoi1_T02?oi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?om0_goo@;m00goo@;m00Co0000ool0oooo0?ooo`3o1Ol00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lGooX5nQ[o003o0Oooool002oo003o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02oon0Oh2o`0000ooo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0:
ooX5nP?o000000?oo@;mo`000?oi1_T03ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?om0_go
o@;m00Soo@;m00?o0000ood2oOom0_d03_om0_d3o`0000SooP7n00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Ho`00oaOom@[e6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ool0o`03o`000?on0OkooP7n00SooP7n0ol000000ook
1?_o0000oo`3o00>oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0
003on@KiooT6n@0?ooT6n@03o`000?oi1_Won@Ki00[on@Ki2ol0000;ood2o@Go00003?on0Oh00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo@;mo`000?oo0?oo0000
00SooP7n0ol00005oo/4n`03o`000?ol0ocoo0?l00coo0?l00?o0000oo@;m?od2o@03Ood2o@00ol0
003onPGjooX5nP0=ooX5nP;o00004?oi1_T00ol0003on@KiooT6n@0:ooT6n@03o`000?oh1oSon0Oh
00Oon0Oh00?o0000ood2oOom0_d00_om0_d7o`0000ConPGj00?o0000ooh1o_on0Oh02_on0Oh00ol0
003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Oo003o5ooe2_DJo`00o`7ooooo000]o`00o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l01?l0003oo@;mood2oOom0_d2o`00
00GooP7n0ol00009oo/4n`;o00002ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[onPGj
00gonPGj00Co0000onXEj_oZ5N[o00003ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSo
n0Oh00Won0Oh1?l0000;ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Go`00oaOom@[e6_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d01?om0_d00ol0003ooP7no`000002o`00
00con`Ck00Co0000oo0?l?l0003o00002Ool0o`00ol0003om0_doo@;m00=oo@;m003o`000?oj1O[o
nPGj00gonPGj00Go0000onXEj_oZ5N[ojQGZo`00000=ooT6n@03o`000?oi1_Won@Ki00[on@Ki00?o
0000ooP7n?oh1oP02Ooh1oP00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o
0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Go`00oaOol0o`6_l00?l1ooooo`00;Ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d0
0ol0003on`Ckoo/4n`0<oo/4n`03o`000?o`3o3ol0o`00;ol0o`0_l00007oo`3o003o`000?od2oCo
m0_d00com0_d00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojQGZonXEjP03onXEjP03o`000?oi1_Wo
n@Ki00[on@Ki00?o0000ooT6nOoi1_T02_oi1_T00ol0003on0OhooP7n009ooP7n003o`000?oj1O[o
nPGj00conPGj00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o01So003o5oo`3o0Jo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00_on`Ck00?o0000oo0?
l?o`3o001Oo`3o000ol0003oo0?loo`3o003oo`3o003o`000?od2oCom0_d00gom0_d00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003ojQGZonXEjP04onXEjP03o`000?oi1_Won@Ki00Won@Ki00?o0000ooT6
nOoi1_T02Ooi1_T00ol0003on0OhooP7n00:ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01So003o5oo`3o0Jo`00
o`7ooooo000]o`00o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o@;mood2o@07ood2o@03o`000?ok1?_on`Ck00_on`Ck00?o0000oo0?l?o`3o001_o`3o02o`0000?o
o0?l00?o0000oo@;m?od2o@03Ood2o@00ol0003onPGjooX5nP0<ooX5nP03o`000?oZ5N[ojQGZ00Ko
jQGZ00?o0000ooT6nOoi1_T02?oi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00[o
n0Oh00?o0000ooX5n_oj1OX03?oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000o`00ool00?l06?l00?lGoo0?l1[o003o0Oooool002go003o0ol0000;ool0o`03o`00
0?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d02?om0_d00ol0003on`Ckoo/4n`0:oo/4n`03o`00
0?o`3o3ol0o`00Wol0o`0_l000000ool0oco0000oo@;m00<oo@;m0?o00003_oj1OX00ol0003ojQGZ
onXEjP07onXEjP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ooT6nOoi1_T02Ooi1_T00ol0003on0Oh
ooP7n00;ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`08ool0o`?o00006_l00?lGoo0?l1[o003o0Oooool002go003o00?o0000ool0oooo0?l00ol0
0008ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003on`Ckoo/4
n`09oo/4n`03o`000?o`3o3ol0o`00_ol0o`00?o0000oo@;m?od2o@02_od2o@2o`0000?ohacS00?o
0000ooX5n_oj1OX02_oj1OX00ol0003ojQGZonXEjP09onXEjP03o`000?oi1_Won@Ki00Kon@Ki00?o
0000ooT6nOoi1_T02?oi1_T00ol0003on0OhooP7n00<ooP7n003o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`Co00000ooo0?l00ol0003o003oo`00
o`0Go`00oaOojaC[6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`04ool0o`?o00001Ooo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000oo/4nook1?/02?ok1?/0
0ol0003ol0o`oo0?l00<oo0?l003o`000?od2oCom0_d00Som0_d0_l00006on<Lh`;o00002_oj1OX0
0ol0003ojQGZonXEjP0:onXEjP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003on0OhooP7n00<ooP7n003o`000?oj1O[onPGj00conPGj00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003oo`3oo`000003o`0000Soo`3o00?o0000o`00ool00?l05_l00?lGon/Dja[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l02?oo0?l3o`0000?oo`3o00Go0000ool0oooo0?ooo`3oo`00000=
ood2o@03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo0?l?o`3o003_o`3o000ol0003om0_doo@;m004
oo@;m0?o00002_oS7><00ol0003onPGjooX5nP07ooX5nP03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000
ooT6nOoi1_T00ooi1_T00ol0003on@KiooT6n@09ooT6n@03o`000?oh1oSon0Oh00con0Oh00?o0000
ooX5n_oj1OX03?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00003Ooo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0<ool0o`Co00000_oo0?l00ol0
003oo@;mood2o@0<ood2o@03o`000?ok1?_on`Ck00Oon`Ck00?o0000oo0?l?o`3o003oo`3o001?l0
003om0_doo@;m?od2o@2o`0000kohacS0_l00006ooX5nP03o`000?oZ5N[ojQGZ00gojQGZ00?o0000
ooT6nOoi1_T00_oi1_T00ol0003on@KiooT6n@08ooT6n@03o`000?oh1oSon0Oh00con0Oh0ol0000=
ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0E
o`00oaOojaC[6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo0000
00ooo@;m00?o0000oo/4nook1?/01_ok1?/00ol0003ol0o`oo0?l00@oo0?l0Co00004_oS7><00ol0
003onPGjooX5nP03ooX5nP03o`000?oZ5N[ojQGZ00kojQGZ00Go0000ooT6nOoi1_Won@Kio`000005
ooT6n@Oo00003?oh1oP01Ol0003om0_doo@;m?od2oCo000000conPGj00?o0000ooh1o_on0Oh02?on
0Oh3o`0000ooo`3o00?o0000o`00ool00?l05Ol00?lGonDJiA[o003o0Oooool002Wo003o00?o0000
ool0oooo0?l04?oo0?l3o`0000ooo@;m00?o0000oo/4nook1?/01_ok1?/00ol0003ol0o`oo0?l00=
oo0?l0?o000000Coh1oPo`000?l0003o00004ooS7><2o`0000;onPGj00?o0000onXEj_oZ5NX04?oZ
5NX00ol0003on@Kio`000006o`0000OoiA[U00?o0000ooP7n?oh1oP02?oh1oP00ol0003om0_doo@;
m003oo@;m0;o00002?oj1OX3o`0000KooP7n1?l00002ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool002Wo003o00?o0000ool0oooo0?l03ooo0?l0
1?l0003ooP7no`000?oi1_T3o`0000goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003ol0o`oo0?
l00;oo0?l0?o00000ooP7n001Ol0003of2OHo`000?nfBKKo000001CohacS00?o0000ooX5n_l00000
4ooZ5NX00ol0003oiA[UonDJi@0=onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l00008oo@;m003o`00
0?oj1O[onPGj00Go00000ooh1oP00ol0003ooP7nooh1oP03o`0000Ooo@;m00?o0000ool0oooo0?l0
3Ooo0?l00ol0003o003oo`00o`0Do`00oaOoiA[U6_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0
o`0>ool0o`04o`000?on0OkooP7no`0000Con@Ki0ol0000:ood2o@03o`000?ok1?_on`Ck00?on`Ck
00?o0000oo0?l?o`3o002Oo`3o03o`0000Goh1oP00Co0000omPWf?oH9mSo00000_nfBKH00ol0003o
hacSon<Lh`0Bon<Lh`03o`000?oZ5N[ojQGZ01;ojQGZ00?o0000onDJiOoU6^D03_oU6^D00ol0003o
n0OhooP7n003ooP7n003o`000?od2oCom0_d00Wom0_d0_l00009ooP7n0;o00002_om0_d00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o01Co003o5ooU6^DJo`00o`7ooooo000Xo`00o`03o`00
0?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7no`000007ooT6n@;o00001oom0_d5o`0000;o
n`Ck00?o0000oo0?l?o`3o001_o`3o03o`0000Soh1oP00Co0000omPWf?oH9mSo00000onfBKH00ol0
003ohacSon<Lh`0Aon<Lh`03o`000?oZ5N[ojQGZ017ojQGZ00?o0000onDJiOoU6^D04?oU6^D01Ol0
003on0OhooP7n?oh1oSo000000com0_d00?o0000ooP7n?oh1oP02?oh1oP00ol0003oo@;mood2o@0:
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l05?l00?lGonDJiA[o003o0Oooool0
02So003o00?o0000ool0oooo0?l03?oo0?l2o`0000CooP7n00?o0000ooT6nOoi1_T01ooi1_T3o`00
0004ood2oOl0003o0000o`0000Gol`cc0_l00006oo0?l0?o00002_oP7n001Ol0003of2OHomPWf?oH
9mSo000000Co]TVf00?o0000on<LhooS7><04?oS7><00ol0003ojQGZonXEjP0AonXEjP03o`000?oU
6^GoiA[U017oiA[U00?o0000ooP7n?l000003Ood2o@00ol0003on0OhooP7n008ooP7n003o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0Do`00oaOoh1oP6_l0
0?l1ooooo`00:?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooT6nOoi1_T02_oi1_T00ol0003ol`ccoo<<l`08oo<<l`03o`000?o`3o3ol0o`00?o00003OoP7n00
1Ol0003of2OHomPWf?oH9mSo000000Go]TVf00?o0000on<LhooS7><03ooS7><00ol0003ojQGZonXE
jP0AonXEjP03o`000?oU6^GoiA[U01;oiA[U00?o0000oo@;m?od2o@03?od2o@00ol0003on0OhooP7
n008ooP7n003o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00
o`0Co`00oaOoh1oP6_l00?l1ooooo`009ol00?l3o`0000_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc0_l0000?on0Oh003o`000?oH9mSo
f2OH00;of2OH00?o0000okI9]_nfBKH01?nfBKH00ol0003ohacSon<Lh`0=on<Lh`?o00004OoZ5NX0
0ol0003oiA[UonDJi@0ConDJi@03o`000?od2oCom0_d00_om0_d00?o0000ooP7n?oh1oP02Ooh1oP0
0ol0003oo@;mood2o@0;ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04ol00?lG
on0Oh1[o003o0Oooool002Ko003o00Go0000ool0oooo0?ooo`3oo`000008ool0o`;o00002?on0Oh0
0ol0003on@KiooT6n@0:ooT6n@03o`000?oc3??ol`cc00Wol`cc00?o0000on0Oh?oP7n003OoP7n00
0ol0003of2OHomPWf003omPWf003o`000?nfBKKo]TVf00Go]TVf00?o0000on<LhooS7><02_oS7><2
o`0000?oZUFZ00?o0000onXEj_oZ5NX03_oZ5NX00ol0003oiA[UonDJi@0ConDJi@03o`000?od2oCo
m0_d00_om0_d00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0;ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l04ol00?lGon0Oh1[o003o0Oooool002Go003o00?o0000ool0
oooo0?l00ooo0?l2o`0000Goo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`0000_on@Ki00?o0000oo<<
looc3?<02ooc3?<00ol0003oh1oPon0Oh00<on0Oh003o`000?oH9mSof2OH00?of2OH00?o0000okI9
]_nfBKH01_nfBKH00ol0003ohacSon<Lh`07on<Lh`;o00001_nZEJX2o`0000kojQGZ00?o0000onDJ
iOoU6^D04ooU6^D00ol0003om0_doo@;m00;oo@;m003o`000?oh1oSon0Oh00Won0Oh00?o0000ood2
oOom0_d03?om0_d00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Co003o5ooK9=/Jo`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Koo`3o00Go0000ool0oooo0?ooo`3oo`000009ooh1
oP03o`000?ok1?_o000000_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003oh1oPon0Oh00;on0O
h003o`000?oH9mSof2OH00Cof2OH00?o0000okI9]_nfBKH01onfBKH00ol0003ohacSon<Lh`05on<L
h`03o`000?nZEJ[oZUFZ00SoZUFZ00?o0000onXEj_oZ5NX02_oZ5NX00ol0003oiA[UonDJi@0DonDJ
i@03o`000?od2oCom0_d00_om0_d00?o0000ooP7n?oh1oP02Ooh1oP00ol0003oo@;mood2o@0<ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002Co
003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oo`000009ooh1oP04o`000?ok1?_on`Cko`00
00_on@Ki00?o0000oo<<looc3?<02ooc3?<00ol0003oh1oPon0Oh00;on0Oh003o`000?oH9mSof2OH
00Cof2OH00?o0000okI9]_nfBKH02?nfBKH00ol0003ohacSon<Lh`02on<Lh`;o00003?nZEJX2o`00
00[ojQGZ00?o0000onDJiOoU6^D05?oU6^D00ol0003om0_doo@;m00;oo@;m003o`000?oh1oSon0Oh
00Won0Oh00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`06ool0o`?o00005ol00?lGom/T
fa[o003o0Oooool002?o003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1oP03
o`000?ok1?_on`Ck00;on`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0<oo<<l`03
o`000?oP7n3oh1oP00Woh1oP00?o0000omPWf?oH9mP01OoH9mP00ol0003o]TVfokI9]P09okI9]P04
o`000?oS7>?o0000o`00013oZUFZ0_l00008onXEjP03o`000?oU6^GoiA[U01CoiA[U0ol0000;oo@;
m003o`000?oh1oSon0Oh00Won0Oh00?o0000ood2oOom0_d03Oom0_d01?l0003oo`3oool0oooo0?l5
o`0000?oo`3o00?o0000o`00ool00?l05?l00?lGom/Tfa[o003o0Oooool002?o003o00?o0000ool0
oooo0?l02Ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00?on`Ck00?o0000ooT6
nOoi1_T02?oi1_T00ol0003ol`ccoo<<l`0;oo<<l`;o00002_oP7n000ol0003of2OHomPWf006omPW
f003o`000?nfBKKo]TVf00[o]TVf00?o0000ojYEZ_nZEJX04_nZEJX00ol0003ojQGZonXEjP04onXE
jP03o`000?oU6^GoiA[U01GoiA[U00?o0000on0Oh?oP7n001Ol00005oo@;m003o`000?oh1oSon0Oh
00[on0Oh00?o0000ood2oOom0_d03_om0_d3o`0000Woo`3o00?o0000o`00ool00?l04ol00?lGom/T
fa[o003o0Oooool002;o003o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP03
o`000?ok1?_on`Ck00Con`Ck00?o0000ooT6nOoi1_T01ooi1_T00ol0003ol`ccoo<<l`0;oo<<l`04
o`000?oA;]7odBkAo`0000Woh1oP00?o0000omPWf?oH9mP01_oH9mP00ol0003o]TVfokI9]P0:okI9
]P03o`000?nZEJ[oZUFZ01?oZUFZ0_l00003onXEjPCo00005?oU6^D00ol0003oh1oPon0Oh006on0O
h0Co000000?om0_do`000?oh1oP02ooh1oP00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o
00[oo`3o00?o0000o`00ool00?l04_l00?lGomHYeQ[o003o0Oooool002;o003o00?o0000ool0oooo
0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi
1_T01ooi1_T00ol0003ol`ccoo<<l`09oo<<l`;o00001?oA;]400ol0003oh1oPon0Oh005on0Oh003
o`000?oH9mSof2OH00Oof2OH00?o0000okI9]_nfBKH02_nfBKH00ol0003oZUFZojYEZP0EojYEZP03
o`000?oZ5N[o000000Co_T6n0ol0000@onDJi@03o`000?oP7n3oh1oP00_oh1oP0_l0000<ooP7n003
o`000?om0_goo@;m00coo@;m0_l0000>ool0o`03o`000?l00?oo003o017o003o5ooF:MHJo`00o`7o
oooo000Qo`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00_on0Oh00ol0003on`Ck
oo/4n`06oo/4n`03o`000?oi1_Won@Ki00Oon@Ki00?o0000oo<<looc3?<02?oc3?<00ol0003odBkA
om4^d@05om4^d@03o`000?oP7n3oh1oP00Coh1oP00?o0000omPWf?oH9mP01ooH9mP00ol0003o]TVf
okI9]P0:okI9]P03o`000?nZEJ[oZUFZ01KoZUFZ00?o0000oki1__nn@Kh01_nn@Kh3o`0000coiA[U
00?o0000on0Oh?oP7n003OoP7n000ol0003on0OhooP7n009ooP7n0Go00002Oom0_d2o`000003ooh1
o_l0003oo`3o00koo`3o00?o0000o`00ool00?l04?l00?lGomHYeQ[o003o0Oooool0027o003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ooh1o_l0003on`Ck00Won`Ck00?o0000ooT6nOoi1_T01_oi
1_T00ol0003ol`ccoo<<l`07oo<<l`03o`000?oA;]7odBkA00OodBkA00?o0000on0Oh?oP7n000_oP
7n000ol0003of2OHomPWf008omPWf003o`000?nfBKKo]TVf00Wo]TVf00?o0000ojYEZ_nZEJX05onZ
EJX00ol0003o_T6noki1_P09oki1_P?o00002OoU6^D00ol0003oh1oPon0Oh00>on0Oh0Ko00001?oh
1oP00ol0003on`Ckoo/4n`03oo/4n`Go00000_om0_d2o`0000CooP7n00?o0000ool0oooo0?l03?oo
0?l00ol0003o003oo`00o`0@o`00oaOoeRWF6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0<
ool0o`05o`000?om0_goo@;mood2oOl000002ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?oc
3??ol`cc00Gol`cc0_l0000;om4^d@04o`000?oP7n3oh1oPo`0000_of2OH00?o0000okI9]_nfBKH0
2OnfBKH00ol0003oZUFZojYEZP0FojYEZP03o`000?nn@Kko_T6n00go_T6n0ol00005onDJi@03o`00
0?oP7n3oh1oP00ooh1oP00?o0000on`Ck?o/4n`00oo/4n`4o`0000_on`Ck0_l00006ooh1oP03o`00
0?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l04?l00?lGom0_d1[o003o0Oooool0023o003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@02ood2o@ko00001_oi1_T00ol0003ol`ccoo<<
l`05oo<<l`03o`000?oA;]7odBkA00codBkA00?o0000on0Oh?l000002ooH9mP00ol0003o]TVfokI9
]P07okI9]P?o00006?nZEJX00ol0003o_T6noki1_P0@oki1_P?o000000?oiA[Uo`000?oP7n004?oP
7n000ol0003ok1?/on`Ck007on`Ck003o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o013o003o5oo@;m0Jo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o00Woo`3o0_l00005ood2o@03o`000?oh1oSon0Oh00_on0Oh0_l00004
ooT6n@03o`000?oc3??ol`cc00?ol`cc0_l0000@om4^d@03o`000?oH9mSof2OH00[of2OH00?o0000
okI9]_nfBKH00onfBKH4o`0000;oQgR700?o0000ojYEZ_nZEJX05OnZEJX00ol0003o_T6noki1_P0D
oki1_P03o`000?oP7n3oh1oP013oh1oP00?o0000on`Ck?o/4n`01oo/4n`00ol0003on`Ckoo/4n`0:
oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@
o`00oaOod2o@6_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m
00Goo@;m00?o0000ooP7n?oh1oP03Ooh1oP6o`0000?ol`cc00?o0000om4^dOoA;]404?oA;]400ol0
003of2OHomPWf00:omPWf003o`000?nfBKKo000000?o00001on7N8L00ol0003oZUFZojYEZP0DojYE
ZP03o`000?nn@Kko_T6n01Co_T6n00?o0000on0Oh?oP7n003ooP7n000ol0003ok1?/on`Ck008on`C
k003o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o00oo003o5oo@;m0Jo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ood2oOom0_d01_om0_d00ol0003on0OhooP7n00=ooP7n003o`000?o]4^gokA;]00?o
kA;]00?o0000oo<<lol000004ooA;]44o`0000Wof2OH0_l0000<ohMhQ`03o`000?nZEJ[oZUFZ01?o
ZUFZ00?o0000oki1__nn@Kh05Onn@Kh00ol0003oh1oPon0Oh00>on0Oh003o`000?o/4ncok1?/00So
k1?/00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGom0_d1[o003o0Oooool001oo003o1?l00006ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000ooP7n?oh1oP02ooh1oP00ol0003okA;]ondBk@05ondBk@03o`00
0?oA;]7odBkA01;odBkA00Co0000ohiaS_n>LHkoSW6>1Ol00003omPWf003o`000?n7N8OoQgR700go
QgR70ol0000@ojYEZP;o00006?nn@Kh00ol0003oh1oPon0Oh00=on0Oh003o`000?o/4ncok1?/00Wo
k1?/00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00_o
o`3o00?o0000o`00ool00?l03ol00?lGol/dba[o003o0Oooool001ko003o00?o0000ool0oooo0?l0
0_oo0?l6o`0000_oo@;m00?o0000ooP7n?oh1oP02_oh1oP00ol0003okA;]ondBk@06ondBk@03o`00
0?oA;]7odBkA017odBkA00?o0000ohiaS_n>LHh01on>LHh3o`00013oQgR700?o0000oeFZEOmEZUD0
1Ol00009ojYEZP;o000000?oPgb3o`000?nn@Kh05onn@Kh00ol0003oh1oPon0Oh00=on0Oh003o`00
0?o/4ncok1?/00Wok1?/00?o0000oo/4nook1?/02?ok1?/2o`0000[ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0
o`03ool0o`03o`000?on0OkooP7n00;ooP7n00?o0000ood2oOom0_d02Oom0_d00ol0003on0OhooP7
n00:ooP7n003o`000?o]4^gokA;]00OokA;]00?o0000om4^dOoA;]403ooA;]400ol0003oSW6>ohia
SP0:ohiaSP03o`000?n7N8OoQgR700goQgR700?o0000oeFZEOmEZUD01_mEZUD4o`0000CoZUFZ00?o
0000oh=lPon3O8<00_n3O8<00ol0003o_T6noki1_P0Foki1_P03o`000?oP7n3oh1oP00_oh1oP00?o
0000on`Ck?o/4n`02oo/4n`00ol0003on`Ckoo/4n`06oo/4n`03o`000?ol0oco000000[ooP7n00?o
0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0?o`00oaOobcC;6_l00?l1ooooo`007?l00?l0
0ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00?ooP7n00?o0000ood2oOom0_d02?om0_d=
o`0000[okA;]00?o0000om4^dOoA;]403ooA;]400ol0003oSW6>ohiaSP0;ohiaSP03o`000?n7N8Oo
QgR700coQgR700?o0000oeFZEOmEZUD02_mEZUD4o`0000GoPgb300?o0000oki1__nn@Kh05_nn@Kh0
0ol0003oh1oPon0Oh00:on0Oh003o`000?o/4ncok1?/00cok1?/00?o0000oo/4nook1?/01?ok1?/2
o`0000?oo0?l00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o013o003o5oo;=</Jo`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh00oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?oh1oSon0Oh00Won0Oh00?o0000ondB
kOo]4^d02Oo]4^d00ol0003odBkAom4^d@0=om4^d@03o`000?n>LHkoSW6>00coSW6>00?o0000ohMh
Qon7N8L03?n7N8L00ol0003oEJYEoeFZE@0;oeFZE@03o`000?mJYE[o000000KoPgb300?o0000oki1
__nn@Kh05_nn@Kh00ol0003oh1oPon0Oh009on0Oh003o`000?o/4ncok1?/00cok1?/00?o0000oo/4
nook1?/00ook1?/00ol0003oo0?loo`3o003oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0
oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1ooooo`006ol00?l00ol0003o
o`3oool0o`06ool0o`03o`000?on0OkooP7n00CooP7n00?o0000ood2oOom0_d01_om0_d00ol0003o
n0OhooP7n008ooP7n003o`000?o]4^gokA;]00_okA;]00?o0000om4^dOoA;]402?oA;]44o`0000oo
SW6>00?o0000ohMhQon7N8L02on7N8L00ol0003oEJYEoeFZE@0;oeFZE@04o`000?mJYE[oFZEJo`00
00OoPgb300?o0000oki1__nn@Kh05Onn@Kh00ol0003oh1oPon0Oh008on0Oh003o`000?o/4ncok1?/
00gok1?/00?o0000oo/4nook1?/00_ok1?/00ol0003oo0?loo`3o005oo`3o003o`000?on0OkooP7n
00OooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0Ao`00oaOoaSW66_l00?l1oooo
o`006ol00?l00ol0003oo`3oool0o`06ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ood2oOom
0_d01Oom0_d00ol0003on0OhooP7n008ooP7n003o`000?o]4^gokA;]00_okA;]00?o0000om4^dOoA
;]400ooA;]45o`0000?oTVfB00?o0000ohiaS_n>LHh03_n>LHh00ol0003oQgR7ohMhQ`0:ohMhQ`03
o`000?mEZUGoEJYE00[oEJYE00Go0000oeZUF_mJYE[oFZEJo`000007oh=lP`03o`000?nn@Kko_T6n
01Go_T6n00?o0000on0Oh?oP7n002?oP7n000ol0003ok1?/on`Ck00=on`Ck003o`000?ok1?_on`Ck
00;o00002?ol0o`00ol0003ooP7nooh1oP08ooh1oPWo00005?l00?lGolHiaQ[o003o0Oooool001[o
003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?om0_goo@;m00Go
o@;m00?o0000ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@0<ondBk@Go00002OnBKI800ol0003o
SW6>ohiaSP0<ohiaSP;o00003?n7N8L00ol0003oEJYEoeFZE@0:oeFZE@05o`000?mJYE[oFZEJoeZU
F_l000002?n3O8<00ol0003o_T6noki1_P0Doki1_P?o00001ooP7n000ol0003ok1?/on`Ck00>on`C
k003o`000?ok1?_o000000_oo0?l00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`06ool0
o`03o`000?l00?oo003o01;o003o5oo6>LHJo`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@04ood2o@03o`000?oh1oSon0Oh00Oo
n0Oh00?o0000ondBkOo]4^d03?o]4^d01?l0003ocC;=oldbcOl0000;oi9]TP03o`000?n>LHkoSW6>
00_oSW6>00Co0000od:m@_m2_D;o00002_n7N8L00ol0003oEJYEoeFZE@0:oeFZE@03o`000?mJYE[o
FZEJ00;oFZEJ00?o0000oh=lPon3O8<01_n3O8<00ol0003o_T6noki1_P0Aoki1_P?o00000oo9=/T0
0ol0003oh1oPon0Oh004on0Oh003o`000?o/4ncok1?/00gok1?/1?l0000;oo`3o003o`000?on0Oko
oP7n00GooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0Ao`00oaOo`Ck16_l00?l1
ooooo`006_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?on0OkooP7n00KooP7n00Co0000ood2
oOom0_goo@;m1?l00008ooP7n003o`000?o]4^gokA;]00_okA;]00?o0000oldbcOo=</d00_o=</d0
0ol0003oTVfBoi9]TP08oi9]TP03o`000?n>LHkoSW6>00[oSW6>00?o0000od:m@_m2_D800_m2_D80
0ol0003oQgR7ohMhQ`03ohMhQ`Go00002omEZUD00ol0003oFZEJoeZUFP03oeZUFP03o`000?n3O8?o
Pgb300OoPgb300?o0000oki1__nn@Kh03_nn@Kh2o`0000OobCK900?o0000on0Oh?oP7n000_oP7n00
0ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj00;onPGj00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l04?l00?lG
ol4n`A[o003o0Oooool001Wo003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP07ooh1
oP?o00001?oj1OX00ol0003on0OhooP7n005ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oldb
cOo=</d00oo=</d00ol0003oTVfBoi9]TP09oi9]TP03o`000?n>LHkoSW6>00SoSW6>00?o0000od:m
@_m2_D801?m2_D85o`0000Co?l0o00?o0000oeFZEOmEZUD02OmEZUD00ol0003oFZEJoeZUFP03oeZU
FP03o`000?n3O8?oPgb300SoPgb300?o0000oki1__nn@Kh02_nn@Kh3o`0000[obCK900Go0000on0O
h?oP7n3oh1oPo`00000>on`Ck003o`000?oj1O[onPGj00ConPGj0_l00009oo`3o003o`000?on0Oko
oP7n00;ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0@o`00oaOo`Ck16_l00?l1
ooooo`006Ol00?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooX5
n_oj1OX01Ooj1OX00ol0003on0OhooP7n003ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oldb
cOo=</d01?o=</d00ol0003oTVfBoi9]TP09oi9]TP03o`000?n>LHkoSW6>00OoSW6>00?o0000od:m
@_m2_D801Om2_D800ol0003o?l0ooco0?`07oco0?`03o`000?mEZUGoEJYE00OoEJYE00?o0000oeZU
F_mJYEX01?mJYEX00ol0003oPgb3oh=lP`08oh=lP`03o`000?nn@Kko_T6n00So_T6n0_l0000>olTf
b@Co00003?o/4n`2o`0000WonPGj00?o0000oo`3o?ol0o`01ool0o`01?l0003ooP7nooh1o_l0000?
ool0o`03o`000?l00?oo003o00oo003o5oo1?/4Jo`00o`7ooooo000Io`00o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003onPGjooX5nP07ooX5nP;o00000ooh1oP00ol0
003okA;]ondBk@09ondBk@03o`000?o=</gocC;=00KocC;=00?o0000oi9]T_nBKI802OnBKI800ol0
003oSW6>ohiaSP05ohiaSP03o`000?m2_D;o@[e200Ko@[e200?o0000oco0?olo`3l02?lo`3l00ol0
003oEJYEoeFZE@06oeFZE@03o`000?mJYE[oFZEJ00CoFZEJ00?o0000oh=lPon3O8<02On3O8<4o`00
00?o_T6n0ol0000@olTfb@05o`000?oX5nSoj1OXonPGj?l000002_o/4n`00ol0003onPGjooX5nP0:
ooX5nPKo00000ool0o`00ol0003ooP7no`00000@ool0o`03o`000?l00?oo003o00oo003o5oo1?/4J
o`00o`7ooooo000Jo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh00ol0
003onPGjooX5nP0:ooX5nP04o`000?oh1oSon0Oho`0000[okA;]00?o0000oldbcOo=</d01oo=</d0
0ol0003oTVfBoi9]TP09oi9]TP03o`000?n>LHkoSW6>00CoSW6>00?o0000od:m@_m2_D801om2_D80
0ol0003o?l0ooco0?`08oco0?`;o00001_mEZUD00ol0003oFZEJoeZUFP05oeZUFP03o`000?n3O8?o
Pgb300WoPgb300Co0000oiiQW_nNHIkoWV6N0ol0000BolTfb@03o`000?oX5nSoj1OX00?oj1OX0_l0
0006on`Ck0;o00003Ooj1OX00ol0003ooP7nooh1oP03ooh1oPGo00004Ooo0?l00ol0003o003oo`00
o`0?o`00oaOo_4>l6_l00?l1ooooo`006_l00?l2o`0000[oo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003onPGjooX5nP0<ooX5nP;o00002_o]4^d00ol0003ocC;=oldbc@08oldbc@03o`000?nBKI;o
TVfB00[oTVfB00?o0000ohiaS_n>LHh00_n>LHh00ol0003o@[e2od:m@P08od:m@P03o`000?lo`3oo
?l0o00Ko?l0o0_l00002obOH9`03o`000?mEZUGoEJYE00;oEJYE00?o0000oeZUF_mJYEX01_mJYEX0
0ol0003oPgb3oh=lP`08oh=lP`03o`000?nNHIkoWV6N00CoWV6N00?o0000olTfbOo9=/T03oo9=/T0
0ol0003oj1OXonPGj006onPGj0;o00000oo/4n`00ol0003onPGjooX5nP0=ooX5nP03o`000?on0Oko
oP7n00OooP7n0_l0000@ool0o`03o`000?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Io`00
o`03o`000?oo0?ooo`3o00?o00001ooo0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?oj1O[onPGj
00konPGj00?o0000ondBkOo]4^d01oo]4^d00ol0003ocC;=oldbc@0:oldbc@03o`000?nBKI;oTVfB
00WoTVfB00Go0000ohiaS_n>LHkoSW6>o`00000;od:m@P03o`000?lo`3oo?l0o00Co?l0o0_l00005
obOH9`05o`000?mEZUGoEJYEoeFZEOl000002?mJYEX00ol0003oPgb3oh=lP`08oh=lP`03o`000?nN
HIkoWV6N00GoWV6N00?o0000olTfbOo9=/T03_o9=/T00ol0003oj1OXonPGj008onPGj003o`000?o/
4nco000000oonPGj00?o0000ooh1o_on0Oh02?on0Oh01?l0003oo`3oo`000?l0000>ool0o`03o`00
0?l00?oo003o00oo003o5onl@k`Jo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0005ool0o`04o`000?on0OkooP7no`00017onPGj00?o0000ondBkOo]4^d01_o]4^d00ol0003ocC;=
oldbc@0;oldbc@03o`000?nBKI;oTVfB00WoTVfB00Co0000ohiaS_n>LHko00003?m2_D800ol0003o
?l0ooco0?`02oco0?`;o00002?lWf2L00ol0003oEJYEo`000009oeZUFP03o`000?n3O8?oPgb300So
Pgb300?o0000oiiQW_nNHIh01OnNHIh00ol0003obCK9olTfb@0=olTfb@03o`000?oX5nSoj1OX00[o
j1OX00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00;o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0@o`00oaOo_4>l6_l00?l1ooooo`00
5ol00?l00ol0003oo`3oool0o`08ool0o`?o000000?oo`3oo`000?l000000ol0000BooX5nP03o`00
0?o]4^gokA;]00CokA;]00?o0000oldbcOo=</d03?o=</d00ol0003oTVfBoi9]TP0:oi9]TP?o0000
3?m2_D800ol0003o?l0ooco0?`02o`0000_o9mPW00?o0000oeZUF_mJYEX02?mJYEX00ol0003oPgb3
oh=lP`07oh=lP`03o`000?nNHIkoWV6N00OoWV6N00?o0000olTfbOo9=/T03?o9=/T00ol0003oj1OX
onPGj00;onPGj0;o00003_oj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00?oo`3o
0_l0000:ool0o`03o`000?l00?oo003o013o003o5onfBKHJo`00o`7ooooo000Fo`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh00ol0003onPGjooX5nP0?ooX5nP?o00000oo]
4^d00ol0003ocC;=oldbc@0>oldbc@03o`000?nBKI;oTVfB00SoTVfB00Co0000odVfBOm9]TWoBKI9
0_l0000:od:m@P?o00003OlWf2L00ol0003oFZEJoeZUFP08oeZUFP03o`000?n3O8?oPgb300OoPgb3
00?o0000oiiQW_nNHIh01onNHIh00ol0003obCK9olTfb@0;olTfb@03o`000?oX5nSoj1OX00coj1OX
00?o0000oo`3o?l000000_l0000:ooX5nP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l0
1Ooo0?l2o`0000Soo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Oooool001Go003o00?o
0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?oj1O[onPGj00conPGj0_l0
0003ooD:m@03o`000?o]4^go0000017ocC;=00?o0000oi9]T_nBKI801onBKI800ol0003oBKI9odVf
B@04odVfB@;o00002?m2_D800ol0003o9mPWobOH9`0>obOH9`;o00002?mJYEX00ol0003oPgb3oh=l
P`06oh=lP`03o`000?nNHIkoWV6N00WoWV6N00?o0000olTfbOo9=/T02Oo9=/T00ol0003oj1OXonPG
j00=onPGj003o`000?ol0ocoo0?l00;oo0?l0ol00007ooX5nP03o`000?on0OkooP7n00OooP7n00?o
0000ool0oooo0?l02?oo0?l2o`0000Koo`3o00?o0000o`00ool00?l04?l00?lGokI9]Q[o003o0Ooo
ool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[o
nPGj00WonPGj0_l00006ooD:m@03o`000?o=</gocC;=013ocC;=00?o0000oi9]T_nBKI801_nBKI80
0ol0003oBKI9odVfB@07odVfB@03o`000?m2_D;o@[e200Co@[e20ol0000>obOH9`03o`000?lWf2Oo
9mPW00?o00001OmJYEX00ol0003oPgb3oh=lP`06oh=lP`03o`000?nNHIkoWV6N00[oWV6N00?o0000
olTfbOo9=/T02?o9=/T00ol0003oj1OXonPGj00=onPGj003o`000?ol0ocoo0?l00Goo0?l0ol00004
ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02
ool0o`;o00004_l00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00GonPGj0ol00008ooD:m@03o`000?o=</gocC;=
017ocC;=00Co0000oi9]T_nBKI;oTVfB1?l0000;odVfB@;o000000Co@[e2o`000?l0003o00000olB
kA82o`0000_o9mPW00?o0000obOH9olWf2L01?lWf2L2o`0000?oFZEJ00?o0000oh=lPon3O8<01_n3
O8<00ol0003oWV6NoiiQWP0:oiiQWP03o`000?o9=/WobCK900OobCK900?o0000onPGj?oX5nP03_oX
5nP00ol0003oo0?loo`3o008oo`3o0Co00002_on0Oh00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l00?l04ol00?lGokI9]Q[o003o0Oooool001Go003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP07ooh1oP03o`000?oj1O[onPGj00;onPGj0_l0000<ooD:m@03o`000?o=</go
cC;=013ocC;=1?l00003ohAkQ003o`000?m9]TWoBKI900_oBKI900?o0000oa;]4_lBkA801_lBkA80
0ol0003o9mPWobOH9`07obOH9`03o`000?lWf2Oo9mPW00Oo9mPW3?l0000>oiiQWP03o`000?o9=/Wo
bCK900KobCK900?o0000onPGj?oX5nP03_oX5nP00ol0003oo0?loo`3o00;oo`3o003o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1
ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00WooP7n00Co0000ooX5
n_l0003o00003_oe2_D00ol0003ocC;=oldbc@0?oldbc@03o`000?n4NhCoQ7^400KoQ7^400?o0000
odVfBOm9]TT02_m9]TT00ol0003o4^dBoa;]4P07oa;]4P;o00001_lWf2L00ol0003o9mPWobOH9`08
obOH9`03o`000?mNXEkoGZ5N00SoGZ5N00?o0000oiiQW_nNHIh03?nNHIh00ol0003obCK9olTfb@05
olTfb@03o`000?oX5nSoj1OX00ooj1OX0_l0000=oo`3o003o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003o003oo`00o`0Co`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D03_oe2_D00ol0
003ocC;=oldbc@0>oldbc@03o`000?n4NhCoQ7^400OoQ7^400?o0000odVfBOm9]TT02_m9]TT00ol0
003o4^dBoa;]4P09oa;]4P;o00000olWf2L00ol0003o9mPWobOH9`09obOH9`03o`000?mNXEkoGZ5N
00WoGZ5N00?o0000oiiQW_nNHIh02_nNHIh4o`0000CobCK900?o0000onPGj?oX5nP04?oX5nP01?l0
003oo0?lo`000?l0000<oo`3o003o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`0Do`00oaOo/Dja6_l00?l1ooooo`005Ol00?l00ol0003oo`3oool0o`0<ool0
o`03o`000?on0OkooP7n00[ooP7n00?o0000ooD:mOoe2_D03ooe2_D@o`0000[oQ7^400?o0000odVf
BOm9]TT02Om9]TT00ol0003o4>l@o`00000<oa;]4P05o`000?lWf2Oo0000o`cc3?l000002_lWf2L0
0ol0003oGZ5NoejQGP09oejQGP03o`000?nNHIkoWV6N00OoWV6N0ol00004ok=</`?o000000?obCK9
o`000?oX5nP04OoX5nP01?l0003oo0?loo`3o?ol0o`2o`0000_oo0?l00?o0000ooh1o_on0Oh00oon
0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01Co003o5onaC[4Jo`00o`7ooooo000E
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om@[eooD:m@0?
ooD:m@03o`000?o4>lCoa3_400coa3_400?o0000ohAkQ?n4Nh@02On4Nh@00ol0003oBKI9odVfB@07
odVfB@04o`000?l@ka3o4>l@o`0000go4^dB00Go0000o`cc3?l<l`co3?<<o`000009obOH9`03o`00
0?mNXEkoGZ5N00[oGZ5N00?o0000oiiQW_nNHIh00onNHIh3o`0000[o/dbc00?o0000onPGj?oX5nP0
4?oX5nP00ol0003oo0?loo`3o004oo`3o0;o00002_ol0o`00ol0003ooP7nooh1oP04o`0000ooo`3o
00?o0000o`00ool00?l05?l00?lGojaC[1[o003o0Oooool001Go003o00?o0000ool0oooo0?l02_oo
0?l3o`0000cooP7n00?o0000ooD:mOoe2_D03ooe2_D00ol0003oa3_4ol@ka00<ol@ka003o`000?n4
NhCoQ7^400WoQ7^400?o0000odVfBOm9]TT01_m9]TT00ol0003o4>l@oa3_4002oa3_4003o`000?lB
kA;o4^dB00[o4^dB00?o0000o`cc3?l<l``00_l<l``00ol0003o9mPWobOH9`06obOH9`03o`000?mN
XEkoGZ5N00[oGZ5N00?o0000oiiQW_nNHIh00ol0000=ok=</`03o`000?oX5nSoj1OX013oj1OX00?o
0000oo`3o?ol0o`01_ol0o`2o`0000Woo0?l0_l00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o
0000o`00ool00?l05Ol00?lGojaC[1[o003o0Oooool001Ko003o00?o0000ool0oooo0?l01Ooo0?l4
o`0000;oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003om@[eooD:m@0=ooD:m@?o00003oo4>l@0
0ol0003oQ7^4ohAkQ008ohAkQ003o`000?m9]TWoBKI900GoBKI900?o0000oa3_4?l@ka000ol@ka00
0ol0003o4^dBoa;]4P0:oa;]4P03o`000?l<l`co3?<<00?o3?<<00?o0000obOH9olWf2L01OlWf2L0
0ol0003oGZ5NoejQGP0;oejQGP;o00004OncC;<00ol0003oj1OXonPGj00?onPGj003o`000?ol0oco
o0?l00Soo0?l0_l00007oo`3o003o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Eo`00oaOo[5>/6_l00?l1ooooo`005ol00?l00ol0003oo`3oool0o`04o`00
00Ooo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003om@[eooD:m@09ooD:m@Go00000_oX5nP00ol0
003oa3_4ol@ka00=ol@ka003o`000?n4NhCoQ7^400WoQ7^400?o0000odVfBOm9]TT01?m9]TT00ol0
003o4>l@oa3_4004oa3_4003o`000?lBkA;o4^dB00So4^dB00?o0000o`cc3?l<l``01Ol<l``00ol0
003o9mPWobOH9`04obOH9`03o`000?mNXEkoGZ5N00_oGZ5N00?o0000ok=</oncC;<04?ncC;<00ol0
003oj1OXonPGj00?onPGj003o`000?ol0ocoo0?l00[oo0?l0_l00004oo`3o003o`000?oo0?ooo`3o
00Koo`3o0_l0000:ool0o`03o`000?l00?oo003o01Go003o5on/Dj`Jo`00o`7ooooo000Ho`00o`;o
00003?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oe2_Gom@[e00Com@[e1Ol00007onPGj003
o`000?o4>lCoa3_400goa3_400?o0000ohAkQ?n4Nh@02On4Nh@00ol0003oBKI9odVfB@03odVfB@03
o`000?l@ka3o4>l@00Go4>l@00?o0000oa;]4_lBkA802?lBkA800ol0003o3?<<o`cc3006o`cc3003
o`000?lWf2Oo9mPW00?o9mPW00?o0000oejQG_mNXEh02omNXEh00ol0003o/dbcok=</`0@ok=</`03
o`000?oX5nSoj1OX00ooj1OX00?o0000oo`3o?ol0o`03?ol0o`2o`000003oo`3o?l0003oo`3o00[o
o`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o003oo`00o`0Fo`00oaOo[5>/6_l00?l1ooooo`00
6?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooD:mOl00000
1?l0000<onPGj003o`000?o4>lCoa3_400koa3_400?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oBKI9
odVfB@02odVfB@03o`000?l@ka3o4>l@00Oo4>l@00?o0000oa;]4_lBkA801olBkA800ol0003o3?<<
o`cc3007o`cc3003o`000?lWf2Oo9mPW00;o9mPW00?o0000oejQG_mNXEh02omNXEh00ol0003o/dbc
ok=</`0Aok=</`03o`000?oX5nSoj1OX00goj1OX00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3o
ool0o`0;ool0o`;o00001Ooo0?l2o`0001So003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh01Oon0Oh3o`00017oj1OX00?o0000ol@ka?o4>l@03_o4
>l@00ol0003oQ7^4ohAkQ009ohAkQ004o`000?m9]TWoBKI9o`0000[o4>l@00?o0000oa;]4_lBkA80
1olBkA800ol0003o3?<<o`cc3008o`cc3005o`000?lWf2Oo9mPWobOH9ol000003OmNXEh00ol0003o
/dbcok=</`0Aok=</`?o00003OoX5nP00ol0003oo0?loo`3o00?oo`3o003o`000?oo0?ooo`3o00go
o`3o00Go0000ool0oooo0?ooo`3oo`00000Jo`00oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003o
o`3oool0o`0=ool0o`?o00000_on0Oh2o`0000;on`Ck00?o0000onPGj?oX5nP03ooX5nP00ol0003o
a3_4ol@ka00>ol@ka003o`000?n4NhCoQ7^400SoQ7^41Ol0000;oa3_4003o`000?lBkA;o4^dB00Ko
4^dB00?o0000o`cc3?l<l``02Ol<l``01?l0003o9mPWobOH9ol0000=oejQGP03o`000?ncC;?o/dbc
017o/dbc00?o0000omXUf_oJ9MX00ol0000:onPGj0Co00003Ool0o`00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?oo000001_o003o5onWF:LJo`00o`7ooooo000Ho`00o`03o`000?oo0?ooo`3o00co
o`3o00Co0000ooh1o_on0OkooP7n0_l00005oo/4n`03o`000?oX5nSoj1OX00koj1OX00?o0000ol@k
a?o4>l@03_o4>l@00ol0003oQ7^4ohAkQ007ohAkQ003o`000?l]dRgo;M8]00?o;M8]00?o0000oa3_
4?l@ka002?l@ka000ol0003o4^dBoa;]4P05oa;]4P03o`000?l<l`co3?<<00[o3?<<1Ol0000<oejQ
GP03o`000?ncC;?o/dbc013o/dbc00?o0000omXUf_oJ9MX01?oJ9MX3o`0000Koj1OX00?o0000oo/4
nook1?/00_ok1?/5o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Jo`00
oaOoYeRW6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0OkooP7n00?o
oP7n00?o0000oo/4nook1?/01?ok1?/00ol0003oj1OXonPGj00=onPGj003o`000?o4>lCoa3_400oo
a3_400?o0000ohAkQ?n4Nh@01?n4Nh@2o`0000Oo;M8]00?o0000oa3_4?l@ka001ol@ka0Eo`0000Go
:=LX00?o0000oejQG_mNXEh02?mNXEh3o`00013o/dbc00?o0000omXUf_oJ9MX02?oJ9MX3o`0000;o
j1OX00?o0000oo/4nook1?/02?ok1?/5o`0000?oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Jo`00oaOoXUfR6_l00?l1ooooo`006?l00?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?on0OkooP7n00CooP7n00?o0000oo/4nook1?/01Ook1?/00ol0003oj1OXonPGj00;onPGj0Co0000
3oo4>l@00ol0003oQ7^4ohAkQ003ohAkQ003o`000?l]dRgo;M8]00So;M8]00?o0000oa3_4?l@ka00
1?l@ka02o`0000So0o`300?o0000o`7n0Ol1oP402?l1oP400ol0003o:=LXobSG:005obSG:0;o0000
1_mNXEh2o`0000?oLhac00?o0000ok=</oncC;<03?ncC;<00ol0003ofRGJomXUfP0<omXUfP;o0000
4?ok1?/3o`0001?oo`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00Kon`Ck00?o
0000onPGj?oX5nP02OoX5nP00ol0003okQ7^o`000002olLha`?o00003?o4>l@01?l0003oQ7^4ohAk
Q?n4Nh@2o`0000co;M8]00?o0000oa3_4?l@ka000_l@ka000ol0003o0o`3o`?l0`08o`?l0`03o`00
0?l1oP7o0Oh100So0Oh100?o0000obSG:?lXebP01olXebP00ol0003oGZ5NoejQGP02oejQGP03o`00
0?mcS7?oLhac00CoLhac0_l0000;ok=</`03o`000?oJ9M[ofRGJ00cofRGJ00?o0000oo0?l?l00000
4_ok1?/00ol0003oo`3oool0o`0@ool0o`;o00007?l00?lGoj9MXQ[o003o0Oooool001So003o00?o
0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00Oon`Ck00?o
0000onPGj?oX5nP01_oX5nP2o`0000;okQ7^00?o0000olLhaoo7><L00oo7><L3o`0000[oa3_400?o
0000ohAkQ?l000003ol]dRd01?l0003o4>l@o`000?l0000;o`?l0`03o`000?l1oP7o0Oh100So0Oh1
00?o0000obSG:?lXebP02?lXebP01?l0003oGZ5No`000?l00009og><L`03o`000?ncC;?o/dbc00Oo
/dbc00?o0000omXUf_oJ9MX03?oJ9MX01?l0003ol0o`oo0?l?l0000Coo/4n`03o`000?oo0?ooo`3o
00coo`3o0ol000000ooo0?oo0000o`00o`0Ko`00oaOoXUfR6_l00?l1ooooo`006?l00?l2o`0000So
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oX5nSoj1OX00Co
j1OX00?o0000onhAk_o^4Nh00oo^4Nh00ol0003oacS7olLha`05olLha`?o00001_o4>l@4o`00013o
;M8]00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lXebSo:=LX00Wo
:=LX00?o0000og><LomcS7<02_mcS7<2o`0000Ko/dbc00?o0000omXUf_oJ9MX03?oJ9MX00ol0003o
l0o`oo0?l002oo0?l003o`000?ok1?_on`Ck00oon`Ck00?o0000ooh1o_l000002ooo0?l2o`0000Co
o`3o00?o0000o`00ool00?l06_l00?lGoj9MXQ[o003o0Oooool001[o003o00?o0000ool0oooo0?l0
1?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ok1?_on`Ck00Won`Ck00Co0000onPGj?oX5nSo
j1OX0_l00006onhAkP03o`000?o7><OoacS700SoacS70ol000000oo4>lCo0000o`000004ogN8M`03
o`000?l]dRgo;M8]00go;M8]00?o0000o`?l0ol3o0<03?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03
o`000?lXebSo:=LX00Wo:=LX00?o0000og><LomcS7<03?mcS7<00ol0003o/dbcok=</`03o`0000ko
fRGJ00?o0000oo0?l?o`3o000oo`3o000ol0003on`Ckoo/4n`0>oo/4n`05o`000?on0OkooP7nooh1
o_l000002?oo0?l2o`0000Ooo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001_o
003o00?o0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00[o
n`Ck00?o0000onPGj?l000002?o^4Nh00ol0003oacS7olLha`0;olLha`03o`000?mgR7OoMhQg00Go
MhQg00?o0000obgB;Ol]dRd03?l]dRd00ol0003o0o`3o`?l0`0<o`?l0`03o`000?l1oP7o0Oh100Oo
0Oh100?o0000obSG:?lXebP02?lXebP2o`0000ooLhac0_l00002ol`cc003o`000?oJ9M[ofRGJ00_o
fRGJ00?o0000oo0?l?o`3o001?o`3o000ol0003on`Ckoo/4n`0=oo/4n`03o`000?on0OkooP7n00?o
oP7n00?o0000ool0oooo0?l00_oo0?l3o`0000Woo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o
003o0Oooool001co003o1Ol0000;ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003oacS7olLha`0;olLha`03o`000?mgR7OoMhQg00KoMhQg00?o0000obgB;Ol]dRd0
2ol]dRd2o`0000go0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o:=LXobSG:007obSG:004o`00
0?lm`Sgo?L8mo`0000koLhac00?o0000ol`cc?o<<l`00_o<<l`00ol0003ofRGJomXUfP09omXUfP03
o`000?o`3o3ol0o`00Kol0o`00?o0000oo/4nook1?/02ook1?/00ol0003ooP7nooh1oP05ooh1oP04
o`000?oo0?oo0000o`0000coo`3o00?o0000o`00ool00?l06Ol00?lGoiaSW1[o003o0Oooool001co
003o00?o0000ool0oooo0?l00_oo0?l3o`0000SooP7n00?o0000oo/4nook1?/02_ok1?/2o`0000Wo
kQ7^00?o0000olLhaoo7><L02oo7><L00ol0003oMhQgogN8M`07ogN8M`03o`000?l]dRgo;M8]00Wo
;M8]00Co0000o`Wf2Ol9mPWo00003?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lXebSo:=LX
00Ko:=LX00Go0000ocg2?Olm`Sgo?L8mo`00000>og><L`03o`000?o<<lcoc3?<00?oc3?<00?o0000
omXUf_oJ9MX01ooJ9MX00ol0003ol0o`oo0?l007oo0?l003o`000?ok1?_on`Ck00[on`Ck00?o0000
ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onLHi`J
o`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00Goo`3o0_l00006ooh1oP03o`000?ok1?_on`Ck
00Won`Ck00Co0000ooT6nOoi1_Wo00002Oo^4Nh00ol0003oacS7olLha`09olLha`03o`000?mgR7Oo
MhQg00WoMhQg00?o0000obgB;Ol]dRd01ol]dRd00ol0003o2OH9o`Wf2@02o`Wf2@03o`000?l3o0?o
0o`300Wo0o`300?o0000o`7n0Ol1oP401ol1oP400ol0003o:=LXobSG:005obSG:003o`000?lm`Sgo
?L8m00?o?L8m00?o0000og><LomcS7<02_mcS7<00ol0003oc3?<ol`cc005ol`cc003o`000?oJ9M[o
fRGJ00GofRGJ00?o0000oo0?l?o`3o002?o`3o000ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1
ooooo`007?l00?l00ol0003oo`3oool0o`07ool0o`?o00000_on0Oh3o`0000Won`Ck00?o0000ooT6
nOoi1_T00_oi1_T00ol0003okQ7^onhAkP06onhAkP03o`000?o7><OoacS700WoacS700?o0000ogN8
MomgR7L02_mgR7L00ol0003o;M8]obgB;@05obgB;@03o`000?l9mPWo2OH900Co2OH900?o0000o`?l
0ol3o0<02?l3o0<00ol0003o0Oh1o`7n0@07o`7n0@03o`000?lXebSo:=LX00Co:=LX00?o0000ocg2
?Olm`Sd01?lm`Sd00ol0003oLhacog><L`0:og><L`03o`000?o<<lcoc3?<00Koc3?<00?o0000omXU
f_oJ9MX00ooJ9MX00ol0003ol0o`oo0?l009oo0?l003o`000?ok1?_on`Ck00Son`Ck00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o01So003o5onGJ9LJo`00
o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o00[oo`3o0_l00003ood2o@?o00001Ook1?/00ol0003o
n@KiooT6n@03ooT6n@03o`000?o^4NkokQ7^00KokQ7^00?o0000olLhaoo7><L02Oo7><L00ol0003o
MhQgogN8M`0;ogN8M`03o`000?l]dRgo;M8]00?o;M8]00?o0000o`Wf2Ol9mPT01_l9mPT00ol0003o
0o`3o`?l0`08o`?l0`03o`000?l1oP7o0Oh100Ko0Oh100?o0000obSG:?lXebP00_lXebP2o`0000So
?L8m00?o0000og><LomcS7<02OmcS7<00ol0003oc3?<ol`cc007ol`cc005o`000?oJ9M[ofRGJomXU
f_l000003Oo`3o000ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`0Ho`00oaOoUfRG6_l00?l1ooooo`007?l00?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Goo@;m0ol000000ook1?_o0000ooT6n@06ooT6n@03
o`000?o^4NkokQ7^00GokQ7^00?o0000olLhaoo7><L02Oo7><L00ol0003oMhQgogN8M`0<ogN8M`05
o`000?l]dRgo;M8]obgB;Ol000002_l9mPT00ol0003o0o`3o`?l0`07o`?l0`03o`000?l1oP7o0Oh1
00Ko0Oh100?o0000obSG:?l000000_l000000olDjaCo0000ocg2?@07ocg2?@03o`000?mcS7?oLhac
00SoLhac00?o0000ol`cc?o<<l`02Oo<<l`00ol0003ofRGJo`00000=oo0?l0Co00001Ook1?/00ol0
003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l06Ol00?lGoiMX
Ua[o003o0Oooool001_o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@08ood2o@03
o`000?oi1_Won@Ki00Oon@Ki00?o0000onhAk_o^4Nh01?o^4Nh00ol0003oacS7olLha`09olLha`03
o`000?mgR7OoMhQg00goMhQg00?o0000obgB;Ol000003?l9mPT:o`0000Oo0Oh10ol00005oaC[5003
o`000?lm`Sgo?L8m00Ko?L8m00?o0000og><LomcS7<01omcS7<00ol0003oc3?<ol`cc00:ol`cc003
o`000?o`3o3ol0o`00_ol0o`00?o0000oo`3o?ol0o`00_ol0o`3o`000003oo/4nol0003ooP7n00_o
oP7n0ol0000>ool0o`03o`000?l00?oo003o01Wo003o5onGJ9LJo`00o`7ooooo000Ko`00o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6n@07ooT6n@03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olLhaoo7><L01oo7><L00ol0003oMhQgogN8M`0?ogN8M`;o0000
2ol9mPT00ol0003o2OH9o`Wf2@07o`Wf2@03o`000?l1oP7o0Oh100;o0Oh10ol00008oaC[5003o`00
0?lm`Sgo?L8m00Ko?L8m00?o0000og><LomcS7<01omcS7<00ol0003oc3?<ol`cc00:ol`cc003o`00
0?o`3o3ol0o`00[ol0o`00?o0000oo`3o?ol0o`01_ol0o`00ol0003ooP7nooh1oP08ooh1oP?o0000
0_on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o01Wo003o5onBKI8Jo`00o`7ooooo
000Ko`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003on@KiooT6
n@08ooT6n@03o`000?o^4NkokQ7^00CokQ7^00?o0000olLhaoo7><L01oo7><L00ol0003oMhQgogN8
M`0>ogN8M`04o`000?ldbcCo=</do`0000Wo2OH900?o0000o`Wf2Ol9mPT02Ol9mPT01?l0003o0Oh1
o`000?l0000<oaC[5003o`000?lm`Sgo?L8m00Ko?L8m00?o0000og><LomcS7<01_mcS7<00ol0003o
c3?<ol`cc00;ol`cc003o`000?o`3o3ol0o`00Ool0o`0_l00009oo`3o003o`000?on0OkooP7n00Co
oP7n1?l00006ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l06_l00?lGoi9]TQ[o
003o0Oooool001_o003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@09ood2o@03o`00
0?oi1_Won@Ki00Son@Ki00?o0000onhAk_o^4Nh00oo^4Nh>o`0000goMhQg00?o0000ocC;=?ldbc@0
0_ldbc@00ol0003o2OH9o`Wf2@05o`Wf2@03o`000?l9mPWo2OH900_o2OH900?o0000oaC[5?lDja@0
3?lDja@00ol0003o?L8mocg2?@06ocg2?@03o`000?mcS7?oLhac00GoLhac00?o0000ol`cc?o<<l`0
3?o<<l`00ol0003ol0o`oo0?l006oo0?l003o`000?ol0ocoo0?l00[oo0?l00?o0000ooh1o_on0Oh0
0ol0000:ooh1oP?o00002_oo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T01Ol0003okQ7^onhAk_o^4Nko000000_od2o@00?o0000og6>LOmaSW400ol00009ogN8M`03o`00
0?ldbcCo=</d00Co=</d00?o0000o`Wf2Ol9mPT00ol9mPT00ol0003o2OH9o`Wf2@0<o`Wf2@03o`00
0?lDjaCo5>/D00go5>/D00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003oLhacog><L`03og><L`?o0000
3Oo<<l`00ol0003ol0o`oo0?l005oo0?l003o`000?ol0ocoo0?l00coo0?l0_l0000=ooh1oP03o`00
0?oo0?ooo`3o00?o00001ooo0?l00ol0003o003oo`00o`0Jo`00oaOoTVfB6_l00?l1ooooo`006ol0
0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooT6nOoi1_T02?oi
1_T4o`0000cod2o@00?o0000og6>LOmaSW400omaSW43o`0000GoMhQg00?o0000ocC;=?ldbc@01_ld
bc@01Ol0003o2OH9o`Wf2Ol9mPWo000000oo2OH900?o0000oaC[5?lDja@03OlDja@00ol0003o?L8m
ocg2?@06ocg2?@03o`000?mcS7?oLhac00?o00000on>LHh00ol0003oc3?<ol`cc00;ol`cc003o`00
0?o`3o3ol0o`00?ol0o`00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oo0?ooo`3o00Coo`3o0ol00004ool0o`03o`000?l00?oo003o01[o003o5on=LXdJo`00o`7ooooo
000Lo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d3o`0000Kon@Ki0ol0
0003ooD:m@03o`000?o@;m3od2o@00[od2o@00?o0000og6>LOmaSW401_maSW43o`000003ogN8Mol0
003o=</d00Wo=</d00?o0000o`Wf2Ol000004?l9mPT00ol0003o5>/DoaC[500=oaC[5003o`000?lm
`Sgo?L8m00Oo?L8m0_l00007ohiaSP03o`000?o<<lcoc3?<00[oc3?<00Co0000oo0?l?o`3o3ol0o`
0ol0000?oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l01ooo0?l4o`0001go003o
5on=LXdJo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02_om
0_d01?l0003oo0?loo`3o?ol0o`2o`000004ooT6nOl0003o0000o`0000Kom@[e00?o0000om0_d?o@
;m002_o@;m000ol0003oLHiaog6>L@09og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9
mPT03ol9mPT00ol0003o5>/DoaC[500>oaC[5003o`000?lm`Sgo?L8m00Ko?L8m00?o0000ohiaS_n>
LHh01on>LHh4o`0000Soc3?<00Co0000oo0?l?o`3o3o00000oof2OH2o`0000goo0?l00?o0000ooh1
o_on0Oh02_on0Oh00ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o01_o003o5on=LXdJo`00
o`7ooooo000No`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d02Oom0_d00ol0003o
o0?loo`3o004oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002Oo@;m000ol0003o
LHiaog6>L@0:og6>L@03o`000?ldbcCo=</d00[o=</d00?o0000o`Wf2Ol9mPT03ol9mPT00ol0003o
5>/DoaC[500>oaC[5003o`000?lm`Sgo?L8m00Go?L8m00?o0000ohiaS_n>LHh02?n>LHh01?l0003o
dBkAom4^dOoA;]47o`0000;oc3?<0_l00006ooH9mP;o00003?ol0o`00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l06ol00?lGohebSA[o003o0Oooool001oo
003o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00Go
o0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003od2o@om0_d008om0_d003o`000?maSW7oLHia00[o
LHia00?o0000ocC;=?ldbc@02oldbc@00ol0003o2OH9o`Wf2@0>o`Wf2@03o`000?lDjaCo5>/D00ko
5>/D1Ol00002ocg2?@03o`000?n>LHkoSW6>00WoSW6>00?o0000om4^dOoA;]402?oA;]43o`0000Wo
mPWf0_l0000:oo`3o003o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Lo`00oaOoSG:=6_l00?l1ooooo`007ol00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@07ooD:m@03o`00
0?o@;m3od2o@00Sod2o@00?o0000og6>LOmaSW402_maSW400ol0003o=</docC;=00:ocC;=0;o0000
3_l9mPT3o`0000go5>/D0ol00005odZeBP;o00002on>LHh00ol0003odBkAom4^d@0;om4^d@;o0000
2_of2OH2o`0000Ooo0?l0ol00009ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0
7?l00?lGohMhQa[o003o0Oooool0023o003o00Co0000ool0oooo0?ooo`3o3?l0000:oo`3o003o`00
0?oe2_Gom@[e00Oom@[e00?o0000om0_d?o@;m002?o@;m0>o`0000Wo=</d0ol000000olWf2Oo0000
o`Wf2@0:o`Wf2@?o00000_lKi1/00ol0003o5>/DoaC[5009oaC[50;o00002Om:]DX00ol0003oSW6>
ohiaSP09ohiaSP03o`000?oA;]7odBkA00_odBkA00?o0000onHIi_l000002oof2OH2o`0000Coo0?l
00Co0000ood2oOom0_goo@;m0_l00007ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool0
0?l07?l00?lGohMhQa[o003o0Oooool0027o003o00?o0000ool0ool000002oon0Oh00ol0003oo0?l
oo`3o009oo`3o003o`000?oe2_Gom@[e00Kom@[e00?o0000om0_d?o@;m002?o@;m000ol0003oL8m`
og2?L00:og2?L003o`000?ldbcCo=</d00Co=</d0ol00005obOH9`03o`000?l9mPWo2OH900Co2OH9
1?l00006oa_T6`03o`000?lDjaCo5>/D00Ko5>/D0_l0000;odZeBP03o`000?n>LHkoSW6>00WoSW6>
00?o0000om4^dOoA;]402_oA;]401Ol0003oiQWVonHIi_oV6NKo000000comPWf0_l000000ool0oco
0000ood2o@05ood2o@03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
003oo`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ol0ocoo0?l00Soo0?l00?o0000ooD:mOoe2_D01_oe2_D00ol0003od2o@om0_d007om0_d003o`00
0?m`Sg3oL8m`00_oL8m`00?o0000ocC;=?ldbc@00_ldbc@2o`0000Wo9mPW00?o0000o`Wf2Ol9mPT0
0ol0000;oa_T6`03o`000?lDjaCo5>/D00;o5>/D0ol0000>odZeBP03o`000?n>LHkoSW6>00OoSW6>
00?o0000om4^dOoA;]402ooA;]400ol0003oiQWVonHIiP02onHIiP03o`000?of2OKomPWf00_omPWf
00?o0000ood2oOom0_d01_om0_d2o`0000?ooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Mo`00oaOoQgR76_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol
0ocoo0?l00Ooo0?l00?o0000ooD:mOoe2_D01ooe2_D00ol0003od2o@om0_d005om0_d0?o00003Om`
Sg04o`0000_o9mPW0ol0000?oa_T6`04o`000?lDjaCo0000o`00017oB[E:00?o0000ohiaS_n>LHh0
1on>LHh00ol0003odBkAom4^d@0:om4^d@03o`000?oV6NKoiQWV00CoiQWV00?o0000ooH9m_of2OH0
1oof2OH3o`0000_oo@;m1?l0000=ool0o`03o`000?l00?oo003o01go003o5on2OH8Jo`00o`7ooooo
000Ro`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003om@[eooD:
m@06ooD:m@03o`000?o@;m3od2o@00;od2o@0ol00003ok1?/003o`000?m`Sg3oL8m`00[oL8m`00?o
0000obOH9olWf2L02olWf2L00ol0003o8m`So`00000Aoa_T6`03o`000?m:]D[oB[E:017oB[E:00?o
0000ohiaS_n>LHh01on>LHh00ol0003odBkAom4^d@0:om4^d@03o`000?oV6NKoiQWV00GoiQWV00Co
0000ooH9m_of2OKomPWf1Ol00002ooT6n@03o`000?om0_goo@;m00Woo@;m00Co0000ool0oooo0?oo
o`3o0ol00009ool0o`03o`000?l00?oo003o01ko003o5on2OH8Jo`00o`7ooooo000Qo`00o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003om@[eooD:m@05ooD:m@?o0000
00?od2o@o`000?l000001on`Ck000ol0003oL8m`og2?L008og2?L0?o00002_lWf2L2o`0000;o8m`S
00?o0000oa_T6olKi1/03olKi1/00ol0003oB[E:odZeBP0AodZeBP03o`000?n>LHkoSW6>00OoSW6>
00?o0000om4^dOoA;]402OoA;]400ol0003oiQWVonHIiP07onHIiP?o00001ooi1_T00ol0003oo@;m
ood2o@09ood2o@03o`000?oo0?ooo`3o00Coo`3o0_l00007ool0o`03o`000?l00?oo003o01ko003o
5on2OH8Jo`00o`7ooooo000Qo`00o`03o`000?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`01ool
0o`4o`0000;om@[e0_l00003onl@k`03o`000?n`Ck3o/4n`00So/4n`0_l00006og2?L0;o00000omM
XUd00ol0003o9mPWobOH9`06obOH9`03o`000?lSg2?o8m`S00?o8m`S00?o0000oa_T6olKi1/03_lK
i1/00ol0003oB[E:odZeBP0BodZeBP03o`000?n>LHkoSW6>00GoSW6>00?o0000om4^dOoA;]402OoA
;]400ol0003oiQWVonHIiP08onHIiP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02?om
0_d00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003o003oo`00o`0No`00oaOoPWf26_l0
0?l1ooooo`008Ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00Coo0?l0_l00004
oo`3o0;o00001Oo_4>l00ol0003o/4n`ok1?/00:ok1?/003o`000?m`Sg3oL8m`00;oL8m`00?o0000
oefRGOmMXUd01?mMXUd00ol0003o9mPWobOH9`04obOH9`03o`000?lSg2?o8m`S00Co8m`S00?o0000
oa_T6olKi1/03_lKi1/00ol0003oB[E:odZeBP0BodZeBP[o00002_oA;]400ol0003oiQWVonHIiP08
onHIiP03o`000?oi1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`09
ool0o`?o000000?oo`3oo`000?l00?l08?l00?lGoh9mPQ[o003o0Oooool002;o003o00?o0000ooh1
o_on0Oh03oon0Oh01?l0003oo0?loo`3o?ol0o`2o`0000Ooo0?l00?o0000onl@koo_4>l01?o_4>l0
0ol0003o/4n`ok1?/00:ok1?/004o`000?m`Sg3o0000o`0000SoGJ9M00Co0000obOH9olWf2Oo9mPW
0_l00007ob?L8`03o`000?lKi1_o6n@K00ko6n@K00?o0000odZeB_m:]DX04_m:]DX00ol0003oZUFZ
ojYEZP07ojYEZP03o`000?oA;]7odBkA00KodBkA00?o0000onHIi_oV6NH02_oV6NH00ol0003on@Ki
ooT6n@06ooT6n@03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o003o
o`00o`0Po`00oaOoOH9m6_l00?l1ooooo`008_l00?l00ol0003ooP7nooh1oP0?ooh1oP04o`000?ol
0oco0000o`0000Woo0?l00?o0000onl@koo_4>l01?o_4>l00ol0003o/4n`ok1?/00;ok1?/003o`00
0?mMXUgoGJ9M00WoGJ9M00?o0000obOH9ol000002OlSg2<00ol0003o6n@Koa_T6`0>oa_T6`;o0000
4_m:]DX00ol0003oZUFZojYEZP09ojYEZP;o00001_oA;]400ol0003oiQWVonHIiP0:onHIiP03o`00
0?oi1_Won@Ki00Kon@Ki00?o0000ood2oOom0_d02?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?l00?oo003o023o003o5ommPWdJo`00o`7ooooo000Ro`00o`03o`000?on0OkooP7n013ooP7n00?o
0000oo`3o?ol0o`02Ool0o`00ol0003oka3_onl@k`05onl@k`03o`000?n`Ck3o/4n`00[o/4n`00?o
0000oefRGOmMXUd02_mMXUd2o`0000Wo8m`S00?o0000oa_T6olKi1/03_lKi1/00ol0003o?/4no`00
0002o`0000ooB[E:00?o0000ojYEZ_nZEJX02onZEJX00ol0003odBkAom4^d@03o`0000goiQWV00?o
0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00coo`3o00?o
0000o`00ool00?l08Ol00?lGogf2OA[o003o0Oooool002?o003o00?o0000ooh1o_on0Oh03oon0Oh0
0ol0003oo0?loo`3o009oo`3o003o`000?o_4>ooka3_00Goka3_00?o0000ok1?/?n`Ck002On`Ck02
o`0000_oGJ9M0_l0000;ob?L8`03o`000?lKi1_o6n@K00co6n@K00?o0000ock1?_ln`Ch00oln`Ch3
o`0000coB[E:00?o0000ojYEZ_nZEJX03?nZEJX2o`0000;ohacS00?o0000onHIi_oV6NH03?oV6NH0
0ol0003on@KiooT6n@05ooT6n@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03?oo0?l0
0ol0003o003oo`00o`0Qo`00oaOoOH9m6_l00?l1ooooo`008ol00?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onl@koo_4>l01_o_4>l00ol0003o/4n`ok1?/007ok1?
/003o`000?naC[7o000000[oGJ9M00Co0000oe6^DOmA[U7o00002_lSg2<00ol0003o6n@Koa_T6`0<
oa_T6`03o`000?ln`Cko?/4n00Ko?/4n0_l00008odZeBP;o00003onZEJX00ol0003ohacSon<Lh`02
on<Lh`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oo@;mood2o@07
ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08Ol00?lGogR7N1[o003o0Oooool0
02?o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00:oo`3o003o`000?o_4>ooka3_
00Koka3_00?o0000ok1?/?n`Ck001_n`Ck001Ol0003o/Djaok5>/OnaC[7o000000SoGJ9M00?o0000
oe6^DOmA[U400_mA[U400ol0003o8m`Sob?L8`06ob?L8`Co00003?lKi1/00ol0003o?/4nock1?P08
ock1?P?o00000_m:]DX3o`000003ohUfROl0003oZUFZ00goZUFZ00?o0000on<LhooS7><01?oS7><0
0ol0003oiQWVonHIiP0:onHIiP03o`000?oi1_Won@Ki00Gon@Ki00?o0000ood2oOom0_d01_om0_d0
0ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o02;o003o5omhQgPJo`00o`7ooooo000To`00
o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003oka3_onl@k`07onl@
k`03o`000?n`Ck3o/4n`00?o/4n`0_l00005ok5>/@03o`000?mMXUgoGJ9M00CoGJ9M00?o0000oe6^
DOmA[U400omA[U400ol0003o8m`Sob?L8`05ob?L8`03o`000?lMhQgo7N8M00;o7N8M0ol00007oa_T
6`;o00003_ln`Ch2o`0000GoRGJ900?o0000ojYEZ_nZEJX02_nZEJX00ol0003ohacSon<Lh`05on<L
h`03o`000?oV6NKoiQWV00_oiQWV00?o0000ooT6nOoi1_T01?oi1_T00ol0003oo@;mood2o@06ood2
o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l08_l00?lGogR7N1[o003o0Oooool002Co
003o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o_4>ooka3_00Oo
ka3_00?o0000ok1?/?n`Ck000_n`Ck000ol0003o/Djaok5>/@06ok5>/@03o`000?mMXUgoGJ9M00;o
GJ9M00?o0000oe6^DOmA[U401OmA[U400ol0003o8m`Sob?L8`02ob?L8`;o00002?lMhQd3o`0000;o
6n@K0_l000000olRgB;o0000ock1?P0=ock1?P03o`000?n9MXWoRGJ900GoRGJ900?o0000ojYEZ_nZ
EJX02?nZEJX00ol0003ohacSon<Lh`07on<Lh`03o`000?oV6NKoiQWV00[oiQWV00?o0000ooT6nOoi
1_T01?oi1_T00ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool0
0?l08_l00?lGogR7N1[o003o0Oooool002Co003o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo0?l
oo`3o00<oo`3o003o`000?o_4>ooka3_00Soka3_00Co0000ok1?/?n`Ck3o00002OnaC[401Ol0003o
GJ9MoefRGOmMXUgo000000SoDJiA00Go0000ob?L8olSg2?o8m`So`00000=oagR7@;o00001?lRgB80
0ol0003o?/4nock1?P0;ock1?P03o`000?n9MXWoRGJ900KoRGJ900?o0000ojYEZ_nZEJX01onZEJX0
0ol0003ohacSon<Lh`08on<Lh`Co00002?oV6NH00ol0003on@KiooT6n@04ooT6n@03o`000?om0_go
o@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0So`00oaOoLXeb6_l00?l1
ooooo`009Ol00?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ol0ocoo0?l00_oo0?l0ol00009onl@
k`03o`000?n`Ck3o000000_o/Dja00?o0000oefRGOl000002_mA[U400ol0003o8m`So`00000?oagR
7@03o`000?lRgB;o8]dR00;o8]dR00?o0000ock1?_ln`Ch02oln`Ch00ol0003oRGJ9ohUfR@06ohUf
R@03o`000?nZEJ[oZUFZ00KoZUFZ00?o0000on<LhooS7><02OoS7><01?l0003ol`ccoo<<looc3?<7
o`0000;oiQWV00?o0000ooT6nOoi1_T00ooi1_T00ol0003oo@;mood2o@05ood2o@03o`000?oo0?oo
o`3o00coo`3o00?o0000o`00ool00?l08ol00?lGog:=LQ[o003o0Oooool002Go003o0_l0000;ooh1
oP03o`000?ol0ocoo0?l00Soo0?l0ol00003oo/4n`03o`000?o_4>ooka3_00Ooka3_00?o0000ok5>
/OnaC[402onaC[400ol0003oDJiAoe6^D@0:oe6^D@03o`000?lMhQgo7N8M00go7N8M00?o0000ob;M
8_lRgB801?lRgB800ol0003o?/4nock1?P09ock1?P03o`000?n9MXWoRGJ900SoRGJ900?o0000ojYE
Z_nZEJX00onZEJX2o`0000cohacS00?o0000oo<<looc3?<02?oc3?<<o`0000?oo@;m0ol0000=ool0
o`03o`000?l00?oo003o02?o003o5ombSG8Jo`00o`7ooooo000Wo`00o`03o`000?on0OkooP7n00Oo
oP7n00?o0000oo`3o?ol0o`01_ol0o`3o`0000Oon`Ck00?o0000onl@koo_4>l01_o_4>l00ol0003o
/Djaok5>/@0;ok5>/@03o`000?mA[U7oDJiA00WoDJiA0_l0000>oagR7@03o`000?lRgB;o8]dR00Go
8]dR00?o0000ock1?_ln`Ch02Oln`Ch00ol0003oRGJ9ohUfR@09ohUfR@03o`000?nZEJ[o000000;o
00000_oI9]T00ol0003ohacSon<Lh`08on<Lh`03o`000?oc3??ol`cc00col`cc00?o0000ooX5n_oj
1OX01_oj1OX3o`0000?oo`3o0_l00009ool0o`;o00009_l00?lGog:=LQ[o003o0Oooool002So003o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o003oo`3o0?o00002ook1?/00ol0003oka3_
onl@k`04onl@k`03o`000?naC[7o/Dja00_o/Dja0ol00007oe6^D@?o000000?o?<<lo`000?lMhQd0
3OlMhQd00ol0003o8]dRob;M8P06ob;M8P03o`000?ln`Cko?/4n00So?/4n00?o0000ohUfROn9MXT0
2_n9MXT00ol0003ofBKIomTVf@04omTVf@03o`000?oS7>?ohacS00OohacS00?o0000oo<<looc3?<0
2ooc3?<00ol0003onPGjooX5nP08ooX5nP03o`000?oo0?ooo`3o00Coo`3o0ol00004ool0o`;o0000
:?l00?lGog:=LQ[o003o0Oooool002Wo003o00?o0000ooh1o_on0Oh00oon0Oh4o`000004oo`3o?l0
003o0000o`0000oon`Ck00?o0000onl@koo_4>l00oo_4>l>o`0000?oW6>L0_l00002oe6^D@?o0000
1Oll`c`00ol0003o7N8MoagR7@0:oagR7@03o`000?lRgB;o8]dR00Oo8]dR00?o0000ock1?_ln`Ch0
2?ln`Ch00ol0003oRGJ9ohUfR@0:ohUfR@03o`000?oI9]WofBKI00GofBKI00?o0000on<LhooS7><0
1_oS7><00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oj1O[onPGj00SonPGj00?o0000ool0oooo0?l0
1ooo0?l2o`000003ool0ool0003o003o02Wo003o5om]TVdJo`00o`7ooooo000Zo`00o`03o`000?on
0Oko000000;o00001?on0Oh2o`0001;on`Ck00?o0000onl@koo_4>l00_o_4>l00ol0003oh1oPon0O
h00:on0Oh003o`000?nLHicoW6>L00?oW6>L0_l00009occ3?003o`000?lMhQgo7N8M00Wo7N8M00?o
0000ob;M8_lRgB802?lRgB82o`0000So?/4n00?o0000ohUfROn9MXT02On9MXT00ol0003ofBKIomTV
f@07omTVf@03o`000?oS7>?ohacS00CohacS00?o0000oo<<looc3?<02ooc3?<00ol0003onPGjooX5
nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Ooo
ool002_o003o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0?oo/4n`?o000000?oka3_
o`000?oP7n002ooP7n000ol0003oW6>LoiaSW004oiaSW003o`000?ll`cco?<<l00Wo?<<l00?o0000
oagR7OlMhQd01olMhQd00ol0003o8]dRob;M8P09ob;M8P04o`000?m5^TGo0000o`0000Ko?/4n00?o
0000ohUfROn9MXT02On9MXT00ol0003ofBKIomTVf@08omTVf@03o`000?oS7>?ohacS00?ohacS00?o
0000oo<<looc3?<02ooc3?<00ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o
0000o`00ool00?l0:Ol00?lGoffBKA[o003o0Oooool002_o003o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0<oo/4n`;o00000ooj1OX2o`0000coh1oP00?o0000oiaSW?nLHi`01?nLHi`0
0ol0003o?<<locc3?00:occ3?0Wo00002olRgB800ol0003oAKY5odFjA@02odFjA@?o00000_ln`Ch0
0ol0003oRGJ9ohUfR@0:ohUfR@03o`000?oI9]WofBKI00WofBKI00?o0000on<LhooS7><00_oS7><0
0ol0003ol`ccoo<<l`0:oo<<l`03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Yo`00oaOoKI9]6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP09ooh1
oP;o00002_ok1?/2o`0000GonPGj00?o0000onhAk_l000002_oP7n000ol0003oW6>LoiaSW006oiaS
W003o`000?ll`cco?<<l00Wo?<<l00?o0000obKI9_lVfBH01OlVfBH00ol0003o8]dRob;M8P09ob;M
8P03o`000?m5^TGoAKY500GoAKY50ol00009ohUfR@?o00003OoI9]T01Ol0003ohacSon<LhooS7>?o
000000col`cc00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo
003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000OonPGj00Co0000onhAk_o^4Nko00002OoP7n000ol0003oW6>LoiaSW006
oiaSW003o`000?ll`cco?<<l00So?<<l00?o0000obKI9_lVfBH01olVfBH00ol0003o8]dRob;M8P07
ob;M8P03o`000?m5^TGoAKY500SoAKY50ol00002ohUfR@Go00000_o1?/400ol0003ofBKIomTVf@0<
omTVf@03o`000?oS7>?o000000col`cc00?o0000ooX5n_oj1OX02_oj1OX00ol0003oo`3oool0o`0:
ool0o`03o`000?l00?oo003o02Wo003o5omXUfPJo`00o`7ooooo000Zo`00o`03o`000?on0OkooP7n
00gooP7n00?o0000oo/4nook1?/00_ok1?/2o`0000SonPGj00?o0000onhAk_o^4Nh00_o^4Nh5o`00
00Coh1oP00?o0000oiaSW?nLHi`01_nLHi`00ol0003o?<<locc3?008occ3?003o`000?lVfBKo9]TV
00Oo9]TV00?o0000ob;M8_lRgB801olRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;
00;o00002?o1?/400ol0003ofBKIomTVf@0<omTVf@Co00002_oc3?<00ol0003onPGjooX5nP0:ooX5
nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l00?lGofRGJ1[o003o0Oooool002[o
003o00?o0000ooh1o_on0Oh03_on0Oh01?l0003on`Cko`000?l0000:ooX5nP03o`000?o^4NkokQ7^
00;okQ7^00?o0000olLhaoo7><L00_o7><L4o`0000WoW6>L00?o0000occ3??ll`c`02?ll`c`00ol0
003o9]TVobKI9P08obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000odFjAOm5^TD02?m5^TD01Ol0
003oRgB;oh]dRon;M8_o000000[o`Ck10ol0000;omTVf@04o`000?og2?Oom`SgooL8m`Co00001Ooc
3?<00ol0003onPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0:?l0
0?lGofRGJ1[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh03oon0Oh00ol0003onPGjooX5nP0:
ooX5nP03o`000?o^4NkokQ7^00?okQ7^00?o0000olLhaoo7><L01?o7><L00ol0003oW6>LoiaSW007
oiaSW003o`000?ll`cco?<<l00Ko?<<l0_l0000;obKI9P03o`000?lRgB;o8]dR00Go8]dR00?o0000
odFjAOm5^TD02?m5^TD00ol0003oRgB;oh]dR`02oh]dR`03o`000?o1?/7o`Ck100Oo`Ck100?o0000
on/Djoo[5>/01?l00006omTVf@03o`000?og2?Oom`Sg00Kom`Sg0ol00002oo<<l`03o`000?oj1O[o
nPGj00_onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003oo`00o`0Xo`00oaOoJ9MX6_l00?l1
ooooo`00:Ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj00WonPGj00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003oacS7olLha`05olLha`03o`000?nLHicoW6>L00OoW6>L00?o0000occ3
??ll`c`00_ll`c`3o`000003oeNXEol0003o9]TV00[o9]TV00?o0000ob;M8_lRgB801OlRgB800ol0
003oAKY5odFjA@07odFjA@03o`000?n;M8_oRgB;00?oRgB;00?o0000ol4n`Oo1?/401oo1?/400ol0
003ojaC[on/Dj`04on/Dj`?o00000_oI9]T00ol0003om`SgooL8m`0:ooL8m`;o00003_oj1OX00ol0
003oo`3oool0o`0;ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03
o`000?on0OkooP7n013ooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003okQ7^onhAkP04onhAkP03
o`000?o7><OoacS700KoacS70_l00007oiaSW003o`000?ll`cco000000;o00001OmGZ5L00ol0003o
9]TVobKI9P08obKI9P?o00001?lRgB800ol0003oAKY5odFjA@08odFjA@03o`000?n;M8_oRgB;00Co
RgB;00?o0000ol4n`Oo1?/401_o1?/400ol0003ojaC[on/Dj`07on/Dj`;o00003_og2?L00ol0003o
nPGjooX5nP0;ooX5nP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0:?l00?lGof>LHa[o
003o0Oooool002Wo003o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjooX5nP08ooX5nP03o`00
0?o^4NkokQ7^00GokQ7^00?o0000olLhaoo7><L01?o7><L00ol0003ocC;=oldbc@03o`0000CoW6>L
0_l00008oeNXE`03o`000?lVfBKo9]TV00Oo9]TV00Co0000odfbCOm=/TgoCK9=0ol000000olRgB;o
0000odFjA@09odFjA@03o`000?n;M8_oRgB;00CoRgB;00?o0000ol4n`Oo1?/401Oo1?/400ol0003o
jaC[on/Dj`09on/Dj`03o`000?og2?Oom`Sg00gom`Sg00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
o`3oool0o`0<ool0o`03o`000?l00?oo003o02So003o5omSW6<Jo`00o`7ooooo000Yo`00o`03o`00
0?on0OkooP7n017ooP7n00?o0000ooX5n_oj1OX01ooj1OX00ol0003okQ7^onhAkP06onhAkP03o`00
0?o7><OoacS700?oacS700?o0000oldbcOo=</d01?o=</d2o`000003oiaSW?l0003oEjQG00[oEjQG
00?o0000obKI9_lVfBH01OlVfBH00ol0003oCK9=odfbC@05odfbC@03o`000?m5^TGoAKY500OoAKY5
0ol00007oh]dR`03o`000?o1?/7o`Ck100Co`Ck100?o0000on/Djoo[5>/02Oo[5>/00ol0003om`Sg
ooL8m`0=ooL8m`03o`000?oj1O[onPGj00[onPGj00?o0000ool0oooo0?l02ooo0?l00ol0003o003o
o`00o`0Yo`00oaOoHiaS6_l00?l1ooooo`00:_l00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oj
1O[onPGj00GonPGj0ol00009onhAkP05o`000?o7><OoacS7olLhaol000002Oo=</d00ol0003oEjQG
oeNXE`0;oeNXE`03o`000?lVfBKo9]TV00?o9]TV00?o0000odfbCOm=/Td01_m=/Td00ol0003oAKY5
odFjA@06odFjA@05o`000?n6NHKoQWV6ohIiQ_l000001on;M8/00ol0003o`Ck1ol4n`@03ol4n`@03
o`000?o[5>_ojaC[00WojaC[00?o0000ooL8moog2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03
o`000?oo0?ooo`3o00[oo`3o00?o0000o`00ool00?l0:_l00?lGoefRGA[o003o0Oooool002[o003o
00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjo`000004o`0000;oo0?l00?o0000onhAk_o^4Nh0
1oo^4Nh01?l0003oacS7olLhaol00009oldbc@;o00003OmGZ5L00ol0003o9]TVobKI9P02obKI9P03
o`000?m=/TgoCK9=00SoCK9=00?o0000odFjAOm5^TD00om5^TD2o`0000GoQWV600?o0000oh]dRon;
M8/01?n;M8/00ol0003o`Ck1ol4n`@03ol4n`@03o`000?o[5>_ojaC[00WojaC[00?o0000ooL8moog
2?L03_og2?L00ol0003onPGjooX5nP09ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000o`00ool0
0?l0:ol00?lGoefRGA[o003o0Oooool002[o003o00?o0000ooh1o_on0Oh04Oon0Oh2o`0000Soo0?l
00?o0000onhAk_o^4Nh01_o^4Nh00ol0003oacS7o`000009oldbc@04o`000?n/Djco[5>/o`0000go
EjQG00Co0000obKI9_lVfBKo00003?m=/Td01Ol0003oAKY5odFjAOm5^TGo000000SoQWV60_l00005
oh]dR`03o`000?o1?/7o`Ck100;o`Ck100?o0000on/Djoo[5>/02Oo[5>/00ol0003om`SgooL8m`0>
ooL8m`03o`000?oj1O[onPGj00WonPGj00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`0[
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l
00Ooo0?l00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ocC;=oldbc@07oldbc@03o`000?n/Djco[5>/
00;o[5>/00?o0000oeNXEomGZ5L02_mGZ5L00ol0003o9]TVo`00000>odfbC@03o`000?m5^TGo0000
00_oQWV600?o0000oh]dRon;M8/00_n;M8/01Ol0003o`Ck1ol4n`Oo1?/7o000000cojaC[00?o0000
ooL8moog2?L03_og2?L3o`0000WonPGj00?o0000ool0oooo0?l02?oo0?l00ol0003o003oo`00o`0/
o`00oaOoGJ9M6_l00?l1ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l
00Woo0?l00?o0000onhAk_o^4Nh01_o^4Nh00ol0003ocC;=oldbc@06oldbc@03o`000?n/Djco[5>/
00?o[5>/00?o0000oeNXEomGZ5L02omGZ5L00ol0003oCK9=odfbC@0>odfbC@03o`000?n6NHKoQWV6
00_oQWV60_l00003oh]dR`04o`000?o1?/7o`Ck1o`0000[ojaC[0ol0000>ooL8m`;o00000oon0Oh2
o`0000OonPGj00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`0]o`00oaOoGJ9M6_l00?l1
ooooo`00:ol00?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000onhA
k_o^4Nh01?o^4Nh00ol0003ocC;=oldbc@06oldbc@03o`000?n/Djco[5>/00Go[5>/00?o0000oeNX
EomGZ5L01omGZ5L3o`00017oCK9=00?o0000ohIiQ_n6NHH03On6NHH01Ol0003oRgB;oh]dRol0003o
`Ck100Co00000oo[5>/5o`0000;on`Ck00?o0000ooL8moog2?L02_og2?L2o`0000OooP7n0_l00004
ooX5nP03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0;Ol00?lGoeRWF1[o003o0Oooool0
02_o003o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?o^4NkokQ7^
00CokQ7^00?o0000oldbcOo=</d01Oo=</d00ol0003o[5>/ojaC[006ojaC[003o`000?mGZ5OoEjQG
00CoEjQG0ol00002of:MHP03o`000?m=/TgoCK9=00ooCK9=0_l0000?ohIiQP04o`000?n;M8_o0000
o`0000Cogb3O0ol00008oo/4n`03o`000?og2?Oom`Sg00Oom`Sg0_l0000;ooh1oP;o00000_oj1OX0
0ol0003oo`3oool0o`07ool0o`03o`000?l00?oo003o02ko003o5omHYePJo`00o`7ooooo000/o`00
o`03o`000?on0OkooP7n00gooP7n00?o0000oo`3o?ol0o`03?ol0o`6o`0000OocC;=00?o0000ojaC
[?n/Dj`02?n/Dj`00ol0003oEjQGoeNXE`03o`0000KoHYeR00?o0000odfbCOm=/Td03Om=/Td01?l0
003oSg2?ohm`Sol0000?ohIiQP03o`000?oO8=oogb3O00Gogb3O00?o0000oo/4nook1?/02?ok1?/0
0ol0003om`SgooL8m`05ooL8m`03o`000?on0OkooP7n00gooP7n0ol00008ool0o`03o`000?l00?oo
003o02oo003o5omHYePJo`00o`7ooooo000/o`00oa3o00003_ol0o`00ol0003ol0o`oo0?l004oo0?
l003o`000?o=</gocC;=00?ocC;=00?o0000ojaC[?n/Dj`02_n/Dj`2o`0000[oHYeR00?o0000odfb
COm=/Td02om=/Td00ol0003oSg2?ohm`S`02ohm`S`03o`000?n6NHKoQWV600_oQWV60_l00007omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooL8moog2?L00_og2?L2o`0001;ooP7n00?o0000ool0
oooo0?l00ooo0?l3o`0003;o003o5omHYePJo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00co
o`3o00?o0000oo`3o?ol0o`02ool0o`00ol0003ol0o`oo0?l006oo0?l005o`000?o=</gocC;=oldb
cOl000003On/Dj`00ol0003oHYeRof:MHP0:of:MHP03o`000?m=/TgoCK9=00WoCK9=00?o0000ohm`
Son?L8l01?n?L8l00ol0003oQWV6ohIiQP08ohIiQP;o000000?o/Djao`000?oO8=l01ooO8=l00ol0
003on`Ckoo/4n`09oo/4n`04o`000?og2?Oo0000o`0001CooP7n00?o0000ool0oooo0?l00ol0000e
o`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo0?l?o`3o002?o`3o000ol0003ocC;=o`00000=ojaC[003o`000?mRWF;oHYeR
00_oHYeR00?o0000odfbCOm=/Td02?m=/Td00ol0003oSg2?ohm`S`06ohm`S`03o`000?n6NHKoQWV6
00GoQWV60_l00003ok5>/@03o`000?oO8=oogb3O00Kogb3O00?o0000oo/4nook1?/02_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP;o0000>?l00?lGoe>/Da[o003o0Oooool002_o003o00?o0000ool0oooo
0?l03ooo0?l00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`00[ol0o`00?o0000ojaC[?n/
Dj`03?n/Dj`00ol0003oHYeRof:MHP0<of:MHP03o`000?m=/TgoCK9=00KoCK9=00?o0000ohm`Son?
L8l02?n?L8l00ol0003oQWV6ohIiQP02ohIiQP;o00001_naC[400ol0003ogb3OomlPg`05omlPg`03
o`000?ok1?_on`Ck00[on`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o003oo`00o`0go`00oaOo
DjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?ol0ocoo0?l00Goo0?l
00?o0000oo0?l?o`3o003?o`3o02o`0000co[5>/00?o0000of:MH_mRWF803OmRWF800ol0003oCK9=
odfbC@04odfbC@03o`000?n?L8ooSg2?00[oSg2?00Co0000ohIiQ_l0003o00002?naC[400ol0003o
gb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
003oo`00o`0go`00oaOoDjaC6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0Aool0o`Co0000
0_ol0o`00ol0003ol0o`oo0?l00=oo0?l003o`000?oC;=?o000000;o00002?n/Dj`00ol0003oHYeR
of:MHP0?of:MHPKo00003_n?L8l00ol0003o/Djaok5>/@08ok5>/@03o`000?oO8=oogb3O00Kogb3O
00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP0Dooh1oP03o`000?l00?oo003o03So003o
5omC[5<Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o017oo`3o00Co0000oo`3o?ol0ocoo0?l
0_l0000?oo0?l003o`000?oC;=?odbcC00?odbcC0ol00005ojaC[0;o00004?mRWF801_l0003oMXUf
ogJ9M_l0003oJiA[o`0000koSg2?00?o0000ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`05omlP
g`03o`000?ok1?_on`Ck00Won`Ck00?o0000ooh1o_on0Oh04oon0Oh2o`0003[o003o5om>/DhJo`00
o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003o
l0o`oo0?l00=oo0?l003o`000?oC;=?odbcC00KodbcC0ol000001?n/Djco0000oi9]T_nBKI83o`00
00coHYeR00Go0000ogJ9M_mfRGKoMXUfo`000002of^DJ`03o`000?n?L8ooSg2?00_oSg2?00?o0000
ok5>/OnaC[402OnaC[400ol0003ogb3OomlPg`06omlPg`03o`000?ok1?_on`Ck00Son`Ck0_l0000A
ooh1oP?o000000?oo`3oo`000?l00?l0>Ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo0?loo`3o004oo`3o0oo00003?oC;=<00ol0003oTVfBoi9]TP04oi9]
TP?o00002?mRWF800ol0003oMXUfogJ9MP02ogJ9MP05o`000?m[U6_oJiA[of^DJol000003?n?L8l0
0ol0003o/Djaok5>/@09ok5>/@03o`000?oO8=oogb3O00Gogb3O3?l00002ooh1oP;o00003Oon0Oh2
o`0000Goo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co003o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo0?loo`3o005oo`3o003o`000?o`3o3ol0o`00_ol0o`00?o0000om</
dooC;=<02_oC;=<00ol0003oTVfBoi9]TP07oi9]TP;o00001OmRWF800ol0003oMXUfogJ9MP03ogJ9
MP03o`000?m[U6_oJiA[00;oJiA[00?o0000ohm`Son?L8l02On?L8l00ol0003o/Djaok5>/@0:ok5>
/@03o`000?oO8=oogb3O00?ogb3O00?o0000ooL8moog2?L02Oog2?L00ol0003ooP7nooh1oP02ooh1
oP;o00002Oon0Oh2o`0000Ooo`3o00?o0000o`00ool00?l0=ol00?lGodjaCQ[o003o0Oooool002co
003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?o`3o3ol0o`00[o
l0o`00?o0000om</dooC;=<02ooC;=<00ol0003oTVfBoi9]TP09oi9]TP?o000000?oHYeRo`000?mf
RGH01OmfRGH00ol0003oJiA[of^DJ`03of^DJ`03o`000?n?L8ooSg2?00SoSg2?3_l00003omlPg`;o
00002oog2?L00ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00?ooP7n0ol00009ool0o`03
o`000?l00?oo003o03Oo003o5om9]TTJo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000oo`3o?ol0o`01Ool0o`00ol0003omPWfo`00000;oo0?l003o`000?oC;=?odbcC00[odbcC
0_l0000>oi9]TP03o`000?mfRGKoMXUf00GoMXUf00?o0000of^DJom[U6/00om[U6/00ol0003oSg2?
ohm`S`08ohm`S`03o`000?oR7N;ohQgR00_ohQgR00?o0000omlPgol000003Oog2?L00ol0003ooP7n
ooh1oP06ooh1oP;o000000?ooP7no`000?l000003Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI9
6_l00?l1ooooo`00;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00Koo0?l00Co
0000ooH9m_of2OKo00002_o`3o000ol0003odbcCom</d`09om</d`03o`000?o1?/7o000000koTVfB
00?o0000ogJ9M_mfRGH01OmfRGH00ol0003oJiA[of^DJ`04of^DJ`03o`000?n?L8ooSg2?00KoSg2?
00?o0000on8Mh_oR7N803OoR7N800ol0003om`SgooL8m`0<ooL8m`03o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l00?l1ooooo`00;Ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH00_of
2OH00ol0003ol0o`oo0?l006oo0?l003o`000?oC;=?odbcC00SodbcC0_l00003ol4n`@03o`000?nB
KI;oTVfB00_oTVfB00?o0000ogJ9M_mfRGH01OmfRGH00ol0003oJiA[of^DJ`05of^DJ`03o`000?n?
L8ooSg2?00GoSg2?00?o0000on8Mh_oR7N803OoR7N800ol0003om`SgooL8m`0;ooL8m`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0fo`00oaOoBKI96_l0
0?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Koo0?l00?o0000
ooH9m_of2OH00oof2OH00ol0003ol0o`oo0?l005oo0?l003o`000?oC;=?odbcC00OodbcC00?o0000
ol4n`Oo1?/400oo1?/400ol0003oTVfBoi9]TP0:oi9]TP03o`000?mfRGKoMXUf00KoMXUf00?o0000
of^DJom[U6/01_m[U6/00ol0003oSg2?ohm`S`04ohm`S`03o`000?oR7N;ohQgR00gohQgR3ol0000;
ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0=ol00?lGodVfBA[o003o0Oooool0
02go003o1?l00008ool0o`03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01Oof2OH00ol0
003ol0o`oo0?l004oo0?l003o`000?oC;=?odbcC00GodbcC0_l00006ol4n`@03o`000?nBKI;oTVfB
00WoTVfB0_l00008ogJ9MP03o`000?m[U6_oJiA[00KoJiA[1Ol000000on?L8oo0000on8MhP0?on8M
hP03o`000?oh1oSon0Oh00_on0Oh00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0<ool0
o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o00;o
o`3o1Ol00003ool0o`03o`000?ol0ocoo0?l00Koo0?l00?o0000ooH9m_of2OH01_of2OH00ol0003o
l0o`oo0?l004o`0000KodbcC00?o0000ol4n`Oo1?/401oo1?/400ol0003oTVfBoi9]TP05oi9]TP?o
000000?oTFjAo`000?mfRGH01omfRGH00ol0003oJiA[of^DJ`05of^DJ`03o`000?n_D:oo[e2_00?o
[e2_0_l0000?on8MhP;o00003Ooh1oP00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l0=ol00?lGod>l@a[o003o0Oooool002co003o00?o0000ool0oooo0?l0
1ooo0?l3o`0000Woo0?l00?o0000ooH9m_of2OH01oof2OH2o`0000CojAKY00Co0000om</dooC;=?o
dbcC0_l0000:ol4n`@03o`000?nBKI;oTVfB00;oTVfB0ol00005oi5^T@03o`000?mfRGKoMXUf00Go
MXUf00?o0000of^DJom[U6/01?m[U6/00ol0003o[e2_ojm@[`06ojm@[`03o`000?oR7N;ohQgR00[o
hQgR0_l00002oo<<l`03o`000?oh1oSon0Oh00[on0Oh00?o0000ooh1o_on0Oh02?on0Oh00ol0003o
o`3oool0o`0=ool0o`03o`000?l00?oo003o03Oo003o5om3_4<Jo`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0003omPWfooH9mP08ooH9mP03o`00
0?oY5^WojAKY00CojAKY00?o0000om</dol000003?o1?/400ol0003oTVfBo`000002o`0000WoTFjA
00?o0000ogJ9M_mfRGH01?mfRGH00ol0003oJiA[of^DJ`03of^DJ`03o`000?n_D:oo[e2_00So[e2_
1_l00004on8MhP;o00001Ooc3?<00ol0003on0OhooP7n009ooP7n003o`000?on0OkooP7n00SooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0ho`00oaOo@ka36_l00?l1ooooo`00;?l0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH01oof
2OH00ol0003ojAKYonTFj@06onTFj@03o`000?o1?/7o`Ck100co`Ck100?o0000oi5^TOnAKY402_nA
KY400ol0003oMXUfogJ9MP04ogJ9MP04o`000?m[U6_oJiA[of^DJ`;o00002on_D:l00ol0003oj1OX
onPGj003onPGj0Co00002?oc3?<00ol0003on0OhooP7n008ooP7n003o`000?on0OkooP7n00OooP7n
0ol0000=ool0o`03o`000?l00?oo003o03So003o5oln`ChJo`00o`7ooooo000/o`00o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`00ool0o`00ol0003omPWfooH9mP07ooH9mP03o`000?oY
5^WojAKY00OojAKY00?o0000ol4n`Oo1?/403?o1?/400ol0003oTFjAoi5^T@0;oi5^T@03o`000?mf
RGKoMXUf00?oMXUf00Co0000of^DJom[U6_o00003On_D:l00ol0003oj1OXonPGj006onPGj003o`00
0?oc3??ol`cc00Ool`cc00?o0000ooP7n?oh1oP01ooh1oP00ol0003ooP7nooh1oP06ooh1oP04o`00
0?oo0?ooo`3oool0o`;o00002ooo0?l00ol0003o003oo`00o`0ho`00oaOo?/4n6_l00?l1ooooo`00
;?l00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000ooH9m_of2OH0
1_of2OH00ol0003ojAKYonTFj@09onTFj@03o`000?o1?/7o`Ck100Wo`Ck10_l0000>oi5^T@?o0000
0omfRGH00ol0003oJiA[o`00000=ojm@[`03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<0
2?oc3?<:o`0000KooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000o`00ool00?l0
>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000ool0oooo0?l03Ooo0?l6o`0000OomPWf00?o
0000onTFjOoY5^T02_oY5^T00ol0003o`Ck1ol4n`@06ol4n`@;o000000?o`Sg2o`000?nAKY402onA
KY42o`0000?oX5nP1Ol0000>ojm@[`03o`000?oX5nSoj1OX00Ooj1OX00?o0000oo<<looc3?<02?oc
3?<00ol0003on`Ckoo/4n`06oo/4n`03o`000?on0OkooP7n00?ooP7n00?o0000ool0oooo0?l01ooo
0?l2o`0000Soo`3o00?o0000o`00ool00?l0>?l00?lGock1?Q[o003o0Oooool002co003o00?o0000
ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`03oo/4n`Co00000_of2OH00ol0003ojAKYonTFj@0;
onTFj@03o`000?o1?/7o`Ck100?o`Ck10ol00004ol8m`P03o`000?nAKY7oTFjA00OoTFjA0_l00008
oj1OX003o`000?n_D:oo[e2_00go[e2_00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`07
oo<<l`03o`000?ok1?_on`Ck00Oon`Ck0ol000000oon0Oko0000ool0o`0;ool0o`;o00001Ooo0?l0
0ol0003o003oo`00o`0io`00oaOo?/4n6_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?ok1?_on`Ck00Oon`Ck0_l0000?onTFj@03o`000?o1?/7o`Ck100;o00002?o2?L800ol0
003oTFjAoi5^T@05oi5^T@03o`000?nPGj3oX5nP00SoX5nP00?o0000ojm@[on_D:l03On_D:l00ol0
003oj1OXonPGj008onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/02?ok1?/01?l0
003ooP7nooh1o_l0000?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000o`00ool00?l0>Ol00?lG
ocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`09oo/4
n`03o`000?oY5^WojAKY00kojAKY0_l0000;ol8m`P03o`000?nAKY7oTFjA00;oTFjA0_l0000;oj1O
X003o`000?n_D:oo[e2_00go[e2_00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`06oo<<
l`03o`000?ok1?_on`Ck00Oon`Ck00Go0000ooh1o_on0OkooP7no`00000@ool0o`;o000000?oo`3o
o`000?l00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0oooo0?l03Ooo0?l00ol0
003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00gojAKY0_l0000<ol8m`P04o`000?nAKY7o0000
o`0000goX5nP00?o0000ojm@[on_D:l03?n_D:l00ol0003oj1OXonPGj009onPGj003o`000?oc3??o
l`cc00Kol`cc00?o0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool002_o003o00?o0000ool0
oooo0?l03Ooo0?l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oY5^WojAKY00cojAKY00Co0000on<L
hooS7>?o00003?o2?L800ol0003oX5nPoj1OX00>oj1OX003o`000?n_D:oo[e2_00So[e2_1?l0000;
onPGj003o`000?oc3??ol`cc00Kol`cc00?o0000oo/4nook1?/01Ook1?/00ol0003ooP7nooh1oP04
ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>ol00?lGocW6>A[o003o0Oooool0
02_o003o00?o0000ool0oooo0?l03?oo0?l00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oY5^WojAKY
00_ojAKY00?o0000on<LhooS7><00_oS7><00ol0003o`Sg2ol8m`P09ol8m`P03o`000?nPGj3oX5nP
00koX5nP00Co0000ojm@[on_D:oo[e2_1ol00003om0_d003o`000?oX5nSoj1OX00Woj1OX00?o0000
oo<<looc3?<01_oc3?<00ol0003on`Ckoo/4n`04oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000
ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0lo`00oaOo=</d6_l00?l1ooooo`00:ol00?l00ol0
003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000onTFjOoY5^T02_oY5^T00ol0
003ohacSon<Lh`03on<Lh`03o`000?o2?L;o`Sg200So`Sg200?o0000oj1OX?nPGj003_nPGj04o`00
00_od2o@00?o0000onPGj?oX5nP02?oX5nP00ol0003ol`ccoo<<l`05oo<<l`03o`000?ok1?_on`Ck
00Gon`Ck00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o
03co003o5oldbc@Jo`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook
1?/03?ok1?/7o`0000GojAKY00?o0000on<LhooS7><01OoS7><00ol0003o`Sg2ol8m`P07ol8m`P03
o`000?nPGj3oX5nP00koX5nP00?o0000om0_d?o@;m003Oo@;m000ol0003oj1OXonPGj008onPGj003
o`000?oc3??ol`cc00Col`cc00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7nooh1oP07ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?Ol00?lGocC;=1[o003o0Oooool002co003o
00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`0=oo/4n`03o`000?oe2_Gom@[e00Com@[e
1Ol00009on<Lh`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oj1OX?nPGj003_nPGj000ol0003od2o@
om0_d00=om0_d003o`000?oX5nSoj1OX00Soj1OX00Co0000oo<<looc3??ol`cc1Ol00004oo/4n`03
o`000?on0OkooP7n00WooP7n1?l0000:ool0o`03o`000?l00?oo003o03go003o5oldbc@Jo`00o`7o
oooo000]o`00o`03o`000?oo0?ooo`3o00Soo`3o0ol0000=oo/4n`03o`000?oe2_Gom@[e00Wom@[e
0_l00009on<Lh`03o`000?o2?L;o`Sg200Ko`Sg200?o0000oj1OX?nPGj003?nPGj000ol0003od2o@
om0_d00?om0_d0Ko00001?oX5nP4o`0000Gon`Ck0_l000000ook1?_o0000ooh1oP0;ooh1oP04o`00
0?oo0?ooo`3oool0o`Oo00000ooo0?l00ol0003o003oo`00o`0mo`00oaOo=</d6_l00?l1ooooo`00
;_l00?l00ol0003oo`3oool0o`06ool0o`04o`000?om0_goo@;mood2o@?o00002_ok1?/00ol0003o
m@[eooD:m@09ooD:m@03o`000?o]4^go000000;o00001ooS7><00ol0003o`Sg2ol8m`P05ol8m`P03
o`000?nPGj3oX5nP00SoX5nP1Ol0000Aom0_d003o`000?o_4>ooka3_00?oka3_1?l0000;oo/4n`03
o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l02Ooo0?l3o`00043o003o5ol_d2lJo`00o`7o
oooo000_o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ood2oOom0_d01Oom0_d2o`0000Oon`Ck
00?o0000ooD:mOoe2_D02_oe2_D00ol0003okA;]ondBk@02ondBk@?o00001OoS7><00ol0003o`Sg2
ol8m`P04ol8m`P04o`000?nPGj3oX5nPoj1OX0Oo00001?o?<<l00ol0003od2o@om0_d00>om0_d003
o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook1?/02Ook1?/00ol0003ooP7nooh1oP09ooh1oP03
o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0?_l00?lGobo@;a[o003o0Oooool0033o003o
00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@08ood2o@;o00001?ok1?/00ol0003om@[e
ooD:m@0;ooD:m@03o`000?o]4^gokA;]00GokA;]0ol00003on<Lh`04o`000?o2?L;o`Sg2ol8m`PKo
00003?o?<<l00ol0003od2o@om0_d00=om0_d003o`000?o_4>ooka3_00Ooka3_00?o0000oo/4nook
1?/02_ok1?/00ol0003ooP7nooh1oP08ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool0
0?l0?Ol00?lGobo@;a[o003o0Oooool0037o003o1?l0000=ood2o@?o000000?on`Cko`000?oe2_D0
3?oe2_D00ol0003okA;]ondBk@08ondBk@?o000000CohacSo`000?l0003o00000_oZ5NX00ol0003o
cc3?oll`c`0=oll`c`03o`000?o@;m3od2o@00cod2o@00?o0000onl@koo_4>l02?o_4>l00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00KooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo;m0_6_l00?l1ooooo`00<Ol00?l01Ol0003oo`3oool0oooo0?oo000000oo
o@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003okA;]ondBk@0;ondBk@03o`000?oZ5N[ojQGZ00?o
jQGZ00?o0000oll`coo?<<l03?o?<<l00ol0003ofBKIo`00000=om0_d003o`000?o_4>ooka3_00So
ka3_00?o0000oo/4nook1?/03?ok1?/3o`0000GooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0mo`00oaOo:MHY6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`03ool0o`03o`00
0?om0_goo@;m00coo@;m00?o0000ooD:mOoe2_D03?oe2_D00ol0003okA;]ondBk@0:ondBk@03o`00
0?oZ5N[ojQGZ00GojQGZ00?o0000oll`coo?<<l02_o?<<l01?l0003ofBKIomTVfOoI9]T2o`0000[o
d2o@00?o0000onl@koo_4>l02Oo_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00?o
000000?ooP7no`000?oo0?l03ooo0?l00ol0003o003oo`00o`0no`00oaOo:MHY6_l00?l1ooooo`00
<?l00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00_oo@;m00?o0000ooD:mOoe2_D0
3?oe2_D00ol0003okA;]ondBk@09ondBk@03o`000?oZ5N[ojQGZ00KojQGZ00?o0000oll`coo?<<l0
2Oo?<<l00ol0003ofBKIomTVf@02omTVf@03o`000?o/4nco000000;o00001oo@;m000ol0003oka3_
onl@k`09onl@k`03o`000?ok1?_on`Ck00_on`Ck00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?l00?oo003o03ko003o5olYeRTJo`00o`7ooooo000_o`00o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om@[eooD:m@0;ooD:m@03o`000?o]
4^gokA;]00SokA;]00?o0000onXEj_oZ5NX01ooZ5NX00ol0003occ3?oll`c`08oll`c`03o`000?oI
9]WofBKI00?ofBKI00?o0000on`Ck?o/4n`00_o/4n`2o`0000Cod2o@00?o0000onl@koo_4>l02_o_
4>l00ol0003on`Ckoo/4n`0:oo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ool0oooo0?l03_oo
0?l00ol0003o003oo`00o`0oo`00oaOo:MHY6_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`07
ool0o`03o`000?om0_goo@;m00[oo@;m0ol0000;ooD:m@Ko00001?o]4^d00ol0003ojQGZonXEjP08
onXEjP03o`000?o?<<oocc3?00Oocc3?00?o0000omTVfOoI9]T00ooI9]T00ol0003ok1?/on`Ck005
on`Ck0?o000000?od2o@o`000?o_4>l02oo_4>l00ol0003on`Ckoo/4n`09oo/4n`03o`000?on0Oko
oP7n00OooP7n00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0oo`00oaOo9=/T6_l00?l1
ooooo`00;ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo/4
nook1?/01?l00006ooD:m@03o`000?og2?Oom`Sg00Com`Sg1?l0000<onXEjP03o`000?o?<<oocc3?
00Gocc3?00?o0000omTVfOoI9]T01?oI9]T00ol0003ok1?/on`Ck008on`Ck003o`000?o_4>ooka3_
00_oka3_00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP08ooh1oPGo00002_oo0?l00ol0
003o003oo`00o`10o`00oaOo9=/T6_l00?l1ooooo`00;_l00?l00ol0003oo`3oool0o`0:ool0o`03
o`000?om0_goo@;m00Ooo@;m00?o0000oo/4nook1?/01Ook1?/3o`0000;om@[e00?o0000ooL8moog
2?L02?og2?L00ol0003ojQGZonXEjP0:onXEjP03o`000?o?<<oocc3?00Cocc3?00?o0000omTVfOoI
9]T01OoI9]T00ol0003ok1?/on`Ck008on`Ck003o`000?o_4>ooka3_00Woka3_1?l00008oo/4n`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000o`00ool0
0?l0@?l00?lGobCK91[o003o0Oooool002ko003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;m
ood2o@05ood2o@03o`000?ok1?_on`Ck00Won`Ck0_l0000<ooL8m`03o`000?oZ5N[ojQGZ00WojQGZ
00?o0000oll`coo?<<l00oo?<<l00ol0003ofBKIomTVf@05omTVf@03o`000?o/4ncok1?/00[ok1?/
00?o0000onl@koo_4>l01?o_4>l4o`0000ConPGj00?o0000oo/4nook1?/01?ok1?/00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Woo`3o0ol00013o`00oaOo9=/T6_l00?l1ooooo`00;ol0
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook
1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oZ5N[ojQGZ00WojQGZ00?o0000oll`coo?<<l00_o?
<<l00ol0003ofBKIomTVf@06omTVf@03o`000?o/4ncok1?/00[ok1?/00?o0000onl@koo_4>l01?l0
0009ooX5nPKo00003?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o047o003o5olT
fb@Jo`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00coo`3o00Co0000ood2oOom0_goo@;m0_l0
000=oo/4n`03o`000?og2?Oom`Sg00[om`Sg00?o0000onXEj_oZ5NX02OoZ5NX01Ol0003occ3?oll`
coo?<<oo000000WofBKI00?o0000on`Ck?o/4n`02oo/4n`2o`0000gonPGj00?o0000ooh1o_on0Oh0
0_on0Oh00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o00?o0000o`00ool00?l0
@Ol00?lGoaoP7a[o003o0Oooool002oo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mo`00
0002ooh1oP;o00002ook1?/00ol0003om`SgooL8m`0;ooL8m`03o`000?oZ5N[ojQGZ00WojQGZ00?o
0000oll`col000002OoI9]T00ol0003ok1?/on`Ck00<on`Ck003o`000?oj1O[onPGj00conPGj00?o
0000ooh1o_on0Oh00oon0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o
0000o`00ool00?l0@?l00?lGoaoP7a[o003o0Oooool0033o003o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003ooP7nooh1oP03ooh1oP;o00002_ok1?/00ol0003om`SgooL8m`0:ooL8m`03o`000?oZ5N[o
jQGZ00SojQGZ1Ol00008omTVf@03o`000?o/4ncok1?/00cok1?/00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003ooP7nooh1oP05ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ool0oooo0?l03Ooo0?l0
0ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0o`0<ool0
o`;o00001oon0Oh2o`0000Son`Ck00?o0000ooL8moog2?L02_og2?L00ol0003ojQGZonXEjP07onXE
jP03o`000?o]4^gokA;]00?okA;]0ol00005omTVf@03o`000?o/4ncok1?/00_ok1?/00?o0000ooX5
n_oj1OX03?oj1OX00ol0003ooP7nooh1oP06ooh1oP03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l03Ooo0?l00ol0003o003oo`00o`10o`00oaOo7n0O6_l00?l1ooooo`00<?l00?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?oo000000WooP7n00?o0000oo/4nook1?/01Ook1?/2o`0000co
m`Sg00?o0000onXEj_oZ5NX01OoZ5NX00ol0003okA;]ondBk@07ondBk@?o000000?ofBKIo`000?o/
4n`03Oo/4n`00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00KooP7n00?o0000ooh1o_on
0Oh01_on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?l00?oo003o047o003o5olJiAXJo`00o`7o
oooo000ao`00o`03o`000?oo0?ooo`3o00Soo`3o0_l00003ool0o`03o`000?on0OkooP7n00OooP7n
0_l00004oo/4n`03o`000?ol0ocoo0?l00;o00002_og2?L00ol0003ojQGZonXEjP03onXEjP;o0000
3Oo]4^d2o`0000gok1?/0ol0000=ooX5nP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh0
1Oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o04;o003o5olJiAXJo`00o`7ooooo
000ao`00o`;o00002?oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?on0OkooP7n00SooP7n0_l0
00000ook1?_o0000oo`3o004oo`3o003o`000?og2?Oom`Sg00Oom`Sg00Co0000onXEj_oZ5N[ojQGZ
0_l00002ooP7n003o`000?o]4^gokA;]00cokA;]3Ol00003ooX5nP03o`000?oj1O[onPGj00[onPGj
00?o0000ooh1o_on0Oh02?on0Oh01?l0003ooP7nooh1o_on0Oh4o`0000koo`3o00?o0000o`00ool0
0?l0@_l00?lGoa[U6Q[o003o0Oooool003?o003o0_l00004ool0o`;o00002?oo0?l00ol0003ooP7n
ooh1oP09ooh1oP03o`000?ol0ocoo0?l00Goo0?l0_l00008ooL8m`03o`000?oZ5N[o000000Gon0Oh
00?o0000ondBkOo]4^d02oo]4^d00ol0003olPgboo8=lP09oo8=lP03o`000?oj1O[onPGj00;onPGj
0_l00009ooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000o`00ool00?l0@ol00?lGoa[U6Q[o003o0Oooool003Go003o0_l000000ooo0?oo0000ool0
o`0:ool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo`3o?ol0o`01ool0o`4o`0000?om`Sg0ol0
0007ooP7n003o`000?o]4^gokA;]00[okA;]00?o0000oo8=l_ob3O802Oob3O800ol0003onPGjooX5
nP04ooX5nP;o00001ooj1OX00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00o`13o`00oaOo6^DJ6_l00?l1ooooo`00=ol00?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n00?o0000oo`3o?ol0o`02?ol0o`0
1?l0003oo@;mood2oOom0_d3o`0000;on`Ck00?o0000ooP7n?oh1oP01_oh1oP00ol0003okA;]ondB
k@08ondBk@03o`000?ob3O;olPgb00[olPgb00?o0000ooX5n_oj1OX01_oj1OX00ol0003onPGjooX5
nP04ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?l00?oo003o04Co003o5olDja@Jo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo0?loo`3o008oo`3o003o`000?om0_go
o@;m00Coo@;m00Go0000oo/4nook1?_on`Cko`000008ooP7n003o`000?o]4^gokA;]00OokA;]00?o
0000oo8=l_ob3O802_ob3O800ol0003onPGjooX5nP07ooX5nP;o00001?oj1OX00ol0003ooP7nooh1
oP08ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l2o`0004Oo003o5olD
ja@Jo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooh1o_on0Oh00oon0Oh0
0ol0003oo0?loo`3o008oo`3o003o`000?om0_goo@;m00Coo@;m00?o0000oo/4nook1?/00_ok1?/0
0ol0003on0OhooP7n007ooP7n003o`000?o]4^gokA;]00KokA;]00?o0000oo8=l_ob3O802_ob3O80
0ol0003onPGjooX5nP09ooX5nP05o`000?oj1O[onPGjooX5n_l000002Oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00?o0000BOl00?lGoaC[51[o003o0Oooool003Oo003o00?o0000
ool0oooo0?l03Ooo0?l5o`0000_oo0?l00?o0000ood2oOom0_d01?om0_d00ol0003on`Ckoo/4n`03
oo/4n`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ondBkOo]4^d01Oo]4^d00ol0003olPgboo8=lP0:
oo8=lP03o`000?oj1O[onPGj00WonPGj1?l00009ooh1oP03o`000?oo0?ooo`3o00goo`3o0_l0001<
o`00oaOo5>/D6_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3o
ool0ool000002_ol0o`00ol0003oo@;mood2o@05ood2o@03o`000?ok1?_on`Ck00?on`Ck00?o0000
ooP7n?oh1oP02?oh1oP00ol0003okA;]ondBk@04ondBk@03o`000?ob3O;olPgb00WolPgb00?o0000
ooX5n_oj1OX02?oj1OX2o`0000?ooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?l00?oo003o04_o003o5ol?l0lJo`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o006oo`3o003o`000?om0_goo@;m
00Goo@;m00?o0000oo/4nook1?/01?ok1?/00ol0003on0OhooP7n009ooP7n003o`000?o]4^gokA;]
00;okA;]00?o0000oo8=l_ob3O802_ob3O800ol0003onPGjooX5nP06ooX5nP;o00001_on0Oh8o`00
017oo`3o00?o0000o`00ool00?l0Bol00?lGo`o`3a[o003o0Oooool003So003o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom
0_d01Oom0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oh1oSon0Oh00Won0Oh00Go0000ondBkOo]
4^gokA;]o`00000<oo8=lP03o`000?oj1O[onPGj00ConPGj0_l00008ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1<o`00oaOo3o0?6_l00?l1oooo
o`00>?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol
0o`00ool0o`00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh
1oP02_oh1oP00ol0003okA;]o`000004o`0000WolPgb00?o0000ooX5n_oj1OX00_oj1OX2o`0000[o
oP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o0000C_l00?lGo`o`3a[o
003o0Oooool003Wo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`07oo/4n`;o0000
2ooh1oP00ol0003oo0?loo`3o003oo`3o0Oo00000_ob3O800ol0003onPGjooX5nP02o`0000_ooP7n
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o04ko003o
5ol?l0lJo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02Ooo
0?l01Ol0003oo0?loo`3o?ol0oco000000Soo@;m00?o0000oo/4nook1?/01ook1?/00ol0003ooP7n
o`000002o`0000Son0Oh00?o0000oo`3o?ol0o`02_ol0o`5o`0000gooP7n00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo003o04oo003o5ol:m@XJo`00o`7ooooo
000ko`00o`03o`000?oo0?ooo`3o00?oo`3o0ol0000<ool0o`03o`000?ol0oco000000Woo@;m00?o
0000oo/4nook1?/01_ok1?/00ol0003ooP7nooh1oP03ooh1oP?o00001?oh1oP00ol0003oo0?loo`3
o00=oo`3o003o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?l00?oo003o053o003o5ol:m@XJo`00o`7ooooo000lo`00o`03o`000?oo0?oo
000000;o00000ooo0?l2o`0000_oo`3o00?o0000ood2oOom0_d01oom0_d00ol0003on`Ckoo/4n`07
oo/4n`03o`000?on0OkooP7n00KooP7n0ol000000ooh1oSo0000oo`3o00>oo`3o003o`000?on0Oko
oP7n00cooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo
003o057o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00009ool0
o`03o`000?om0_goo@;m00;oo@;m1_l00008oo/4n`03o`000?on0OkooP7n00[ooP7n00?o0000oo`3
o?ol0o`03ool0o`00ol0003ooP7nooh1oP0:ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?l00?oo003o05;o003o5ol:m@XJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00So
o`3o0_l00007ool0o`Go00001_on0Oh00ol0003on`Ckoo/4n`05oo/4n`03o`000?on0OkooP7n00[o
oP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7nooh1oP07ooh1oP?o000000?oo`3oo`000?oo
0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000005Go003o5ol5nPDJo`00o`7ooooo000mo`00o`03
o`000?oo0?ooo`3o00[oo`3o0_l00005ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook
1?/00ook1?/00ol0003ooP7nooh1oP0;ooh1oP03o`000?ol0ocoo0?l00ooo0?l00?o0000ooh1o_on
0Oh01Oon0Oh2o`0000Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00001Fo`00oaOo
1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`000?l00000
3Oon0Oh00ol0003on`Ckoo/4n`02oo/4n`03o`000?on0OkooP7n00_ooP7n5?l00004ooh1oP;o0000
2?oo0?l00ol0003oo`3oool0o`0;ool0o`;o0000Eol00?lGo`Gj1A[o003o0Oooool003go003o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000>ooh1oP04o`000?ok1?_on`Cko`0000kooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7no`000002o`0000[oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`1Go`00oaOo1OX56_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0
o`0=ool0o`05o`000?oo0?ooo`3oool0ool000003_on0Oh00ol0003on`Cko`00000>ooh1oP03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?l00?oo003o05So003o5ol5nPDJo`00o`7ooooo000mo`00o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00WooP7n1Ol0
000Bool0o`;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?l00?oo003o05Wo003o5ol0
o`0Jo`00o`7ooooo000no`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003ooP7nooh1oP0<ooh1oP03o`000?on0OkooP7n00;ooP7n1ol00004ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0ool000004?oo0?l00ol0003oo`3oool0o`03ool0o`;o0000G?l00?lG
o`3o01[o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?on0OkooP7n00cooP7n1?l0000<ool0o`03o`000?oo0?ooo`3o00coo`3o0_l00003ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1Lo`00
oaOo0?l06_l00?l1ooooo`00?ol00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?ooo`3oo`00
05oo003o5ol0o`0Jo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo
0?l02Ooo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l03Ooo0?l3o`00097o003o0Oooool0047o003o
0_l00004ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo`3o
ool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000o`00ool00000T_l00?l1ooooo`00@ol00?l2o`000003ool0ool0003oo`3o00goo`3o3?l0
000Aool0o`?o00001_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0
002Eo`00o`7ooooo0015o`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0ool000000ooo0?l2o`0000koo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`2Eo`00o`7ooooo0015o`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0ool000004Ooo0?l00ol0003oo`3oool0o`04ool0o`;o0000V?l00?l1
ooooo`00A_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003o003oo`00o`2Ho`00o`7ooooo0016o`00o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04Ooo0?l5o`0009_o003o0Oooool004Oo003o0_l00009ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0KOl00?l4oooo00Go003o0_ooo`03o`00o`Koool0
7?l00?l1ooooo`00BOl00?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`07ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o06go003o0_oo
o`03o`00o`03oooo0?l00?oo003o00;o003o0_ooo`03o`00o`?oool00ol00?l2oooo01[o003o0Ooo
ool004_o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo
003o06go003o0_ooo`04o`00o`;oool03ol00?l2oooo01Wo003o0Oooool004co003o0ol00002ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0KOl00?l2oooo00Go003o00?oool0o`00
ool00?l03_l00?l00oooo`3o003oo`00o`0Go`00o`7ooooo001?o`00o`;o00004Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`00073o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`0>o`00o`;oool06?l00?l1ooooo`00
DOl00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o0000LOl00?l2oooo00Ko003o0_ooo`0?o`00o`;oool0
6?l00?l1ooooo`00D_l00?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o
1Ol00004ool0o`;o0000Lol00?l2oooo00Ko003o0_ooo`0?o`00o`;oool06?l00?l1ooooo`00Dol0
0?l00ol0003oo`3oool0o`0<ool0o`Co00004ooo0?l2o`0000Co003o1?l0001eo`00o`;oool01_l0
0?l2oooo00ko003o0oooo`0Ho`00o`7ooooo001Do`00o`?o00002?oo0?l3o`0000;o003o0_l0000B
ool0o`03o`000?l00?oo003o07go003o0_ooo`06o`00o`;oool03Ol00?l3oooo01Wo003o0Oooool0
05Oo003o0ol00002ool0o`?o00001ol00?l2o`0000koo`3o0_l00020o`00o`;oool01_l00?l2oooo
00_o003o1Oooo`0Io`00o`7ooooo001Jo`00o`;o00003?l00?l2o`0000_oo`3o00?o0000o`00ool0
0?l0P?l00?l2oooo00Ko003o0_ooo`08o`00o`Koool06ol00?l1ooooo`00J_l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?l00?oo003o087o003o0_ooo`06o`00o`;oool02?l00?l4oooo01go003o
0Oooool006_o003o0_l00003ool0o`Co0000Q?l00?l2oooo00Ko003o00?oool0o`00ool00?l02?l0
0?l00oooo`3o003oo`00o`0Mo`00o`7ooooo001]o`00o`?o0000ROl00?l2oooo00Co003o0_ooo`0:
o`00o`03oooo0?l00?oo003o01go003o0Oooool00?Wo003o0_ooo`04o`00o`;oool02_l00?l00ooo
o`3o003oo`00o`0Mo`00o`7ooooo003jo`00o`;oool00_l00?l2oooo00co003o1_ooo`0Io`00o`7o
oooo003ko`00o`Coool03Ol00?l7oooo01So003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/
o`00o`7ooooo003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo
003oo`00obco003o0Oooool00?oo003o;?l00?l1ooooo`00ool00?l/o`00o`7ooooo003oo`00obco
003o0Oooool00?oo003o;?l00?l1ooooo`00S?l00?l5oooo03Co003o1Oooo`1Qo`00o`7ooooo002<
o`00o`;oool000?o<S;<o`00ool00?l0=_l00?l00olb</coool0oooo001Qo`00o`7ooooo002<o`00
o`;oool0>_l00?l2oooo067o003o0Oooool008co003o0_ooo`0jo`00o`;oool0HOl00?l1ooooo`00
I_l00?l2oooo00Ko003o0_ooo`0:o`00o`Coool000?o003ooooo0?l00?l00ol00?l00oooo`3o003o
oooo0003oooo00;o003o0_ooo`08o`00o`Koool01ol00?l4oooo00So003o1?ooo`08o`00o`Coool0
2Ol00?l2oooo067o003o0Oooool006Ko003o0_ooo`06o`00o`;oool02Ol00?l2oooo00?o003o1?oo
o`02o`00o`;oool00ol00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`08o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`04o`00o`;oool00ol00?l00oooo`3o003oo`00o`04o`00o`;oool00ol0
0?l00oooo`3o003oo`00o`06o`00o`;oool0HOl00?l1ooooo`00I_l00?l2oooo00Ko003o0_ooo`09
o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00ool00?l00_l00?l2oooo0003o`00ooooo`3o
ool000[o003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01?l00?l2
oooo00Co003o0_ooo`07o`00o`;oool0HOl00?l1ooooo`00IOl00?l2oooo0003o`00ooooo`3o003o
00?o003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00?o003o00?oool0o`00
ool00?l00_l00?l2oooo0003o`00ooooo`3oool000[o003o0_ooo`07o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`02o`00o`;oool01Ol00?l00oooo`3o003oo`00o`02o`00o`;oool01Ol00?l00ooo
o`3o003oo`00o`05o`00o`;oool0HOl00?l1ooooo`00IOl00?l2oooo0003o`00ooooo`3o003o00?o
003o0_ooo`000ol00?ooool0o`00o`07o`00o`;oool01?l00?l2oooo00Ko003o1?ooo`000ol00?oo
ool0oooo000:o`00o`;oool01ol00?l00oooo`3o003oo`00o`04o`00o`03oooo0?l00?oo003o00;o
003o00?oool0o`00ool00?l01?l00?l00oooo`3o003oo`00o`02o`00o`03oooo0?l00?oo003o00Co
003o00?oool0o`00ool00?l01Ol00?l2oooo067o003o0Oooool006Go003o0_ooo`000ol00?ooool0
o`00o`03o`00o`;oool000?o003ooooo0?l00?l01ol00?l2oooo00Co003o0_ooo`05o`00o`Coool0
0_l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0HOl00?l1ooooo`00I?l00?l2oooo00;o003o00Co
ool0o`00ool00?oo003o0_ooo`02o`00o`;oool01ol00?l2oooo00Co003o0_ooo`04o`00o`?oool0
1?l00?l2oooo00[o003o0_ooo`06o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0HOl00?l1ooooo`00I?l00?l2oooo00?o003o00?o
ool0o`00ool00?l00_ooo`03o`00o`03oooo0?l00?oo003o00Go003o0_ooo`04o`00o`;oool00ol0
0?l2oooo00Co003o00Coool0o`00ooooo`3oool02_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool0
0_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Qo`00o`7ooooo
001To`00o`;oool00ol00?l00oooo`3o003oo`00o`02oooo00?o003o00?oool0o`00ool00?l01Ol0
0?l2oooo00Co003o0_ooo`03o`00o`;oool01?l00?l01?ooo`3o003ooooo0?ooo`0:o`00o`;oool0
1_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool0
1_l00?l2oooo067o003o0Oooool006?o003o0_ooo`04o`00o`03oooo0?l00?ooool000;oool00ol0
0?l00oooo`3o003oo`00o`05o`00o`;oool01?l00?l2oooo00?o003o0_ooo`03o`00o`;oool000?o
003ooooo0?ooo`002_l00?l2oooo00Ko003o0_ooo`06o`00o`;oool00_l00?l2oooo00Ko003o0_oo
o`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Qo`00o`7ooooo001So`00o`;oool01Ol00?l3
oooo00Go003o00?oool0o`00ool00?l00ol00?l3oooo00?o003o0oooo`04o`00o`Coool000?o003o
oooo0?l00?l00_ooo`0:o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2
oooo00;o003o0_ooo`06o`00o`;oool01_l00?l2oooo067o003o0Oooool006?o003o0_ooo`05o`00
o`?oool01Ol00?l00oooo`3o003oo`00o`0Go`00o`;oool02_l00?l2oooo00Ko003o0_ooo`06o`00
o`;oool00_l00?l2oooo00Ko003o0_ooo`02o`00o`;oool01_l00?l2oooo00Ko003o0_ooo`1Qo`00
o`7ooooo001Ro`00o`?oool01Ol00?l3oooo00Go003o00?oool0o`00ool00?l05ol00?l2oooo00[o
003o0_ooo`06o`00o`;oool01_l00?l01?ooo`3o003oo`00ool00?l2oooo00Ko003o00Coool0o`00
ool00?oo003o0_ooo`06o`00o`03oooo0?l00?oo003o00Go003o0_ooo`1Qo`00o`7ooooo001Ro`00
o`;oool01_l00?l2oooo00Ko003o0_ooo`0Ho`00o`;oool02_l00?l2oooo00Oo003o0_ooo`04o`00
o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;oool01?l00?l2oooo00Oo003o0_ooo`1Qo`00
o`7ooooo001Ro`00o`;oool01_l00?l2oooo00Oo003o00?oool0o`00ool00?l05_l00?l2oooo0003
oc8bc?l00?oo003o00Oo003o0_ooo`07o`00o`;oool01?l00?l2oooo00Co003o0_ooo`04o`00o`;o
ool01?l00?l2oooo00Co003o0_ooo`06o`00o`03oc8bc?ooo`3oool0067o003o0Oooool0067o003o
0oooo`05o`00o`?oool01ol00?l00oooo`3o003oo`00o`0Fo`00o`Goool01Ol00?l4oooo00So003o
0_ooo`02o`00o`;oool01_l00?l2oooo00;o003o0_ooo`06o`00o`;oool00_l00?l2oooo00Go003o
1Oooo`1Qo`00o`7ooooo001Po`00o`Koool000?o003ooooo0?ooo`001Oooo`03o`00o`Goool08_l0
0?l2oooo00Wo003o1?ooo`08o`00o`Coool02?l00?l4oooo06co003o0Oooool00?oo003o;?l00?l1
ooooo`00ool00?l/o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {308.562, 0}} -> {24.3751, 21.3242, 0.356227, \
0.356227}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SBMLODES /. m\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]1", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.1`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ A\[UnderBracket]2[t] + 0.1`\ A\[UnderBracket]3[t] + 
                0.1`\ A\[UnderBracket]8[t] + 
                0.10000000000000003`\ A\[UnderBracket]1[t]\^2\ B\
\[UnderBracket]1[t] + 
                A\[UnderBracket]1[
                    t]\ \((\(-0.6`\) - 
                      0.01`\ Y\[UnderBracket]1[
                          t])\)\)\/cell\[UnderBracket]1\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]10", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]10\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]18[t] + 
              0.1`\ A\[UnderBracket]19[t] + 0.1`\ A\[UnderBracket]28[t] + 
              0.1`\ A\[UnderBracket]4[t] + 0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]10[t]\^2\ \
B\[UnderBracket]10[t] + 
              A\[UnderBracket]10[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]10[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]100", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]100\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]114[t] + 
              0.1`\ A\[UnderBracket]123[t] + 0.1`\ A\[UnderBracket]124[t] + 
              0.1`\ A\[UnderBracket]132[t] + 0.1`\ A\[UnderBracket]65[t] + 
              0.1`\ A\[UnderBracket]83[t] + 0.1`\ A\[UnderBracket]87[t] + 
              0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]100[t]\^2\ B\
\[UnderBracket]100[t] + 
              A\[UnderBracket]100[
                  t]\ \((\(-1.0999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]100[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]101", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]101\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]109[t] + 
              0.1`\ A\[UnderBracket]119[t] + 0.1`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]79[t] + 0.1`\ A\[UnderBracket]84[t] + 
              0.1`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]101[t]\^2\ B\
\[UnderBracket]101[t] + 
              A\[UnderBracket]101[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]101[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]102", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]102\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]109[t] + 
              0.1`\ A\[UnderBracket]110[t] + 0.1`\ A\[UnderBracket]129[t] + 
              0.1`\ A\[UnderBracket]72[t] + 0.1`\ A\[UnderBracket]80[t] + 
              0.1`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]102[t]\^2\ B\
\[UnderBracket]102[t] + 
              A\[UnderBracket]102[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]102[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]103", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]103\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]107[t] + 
              0.1`\ A\[UnderBracket]111[t] + 0.1`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]137[t] + 0.1`\ A\[UnderBracket]77[t] + 
              0.1`\ A\[UnderBracket]92[t] + 
              0.10000000000000003`\ A\[UnderBracket]103[t]\^2\ B\
\[UnderBracket]103[t] + 
              A\[UnderBracket]103[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]103[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]104", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]104\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]115[t] + 
              0.1`\ A\[UnderBracket]124[t] + 0.1`\ A\[UnderBracket]128[t] + 
              0.1`\ A\[UnderBracket]130[t] + 0.1`\ A\[UnderBracket]93[t] + 
              0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]104[t]\^2\ B\
\[UnderBracket]104[t] + 
              A\[UnderBracket]104[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]104[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]105", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]105\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]115[t] + 
              0.1`\ A\[UnderBracket]116[t] + 0.1`\ A\[UnderBracket]90[t] + 
              0.1`\ A\[UnderBracket]93[t] + 
              0.10000000000000003`\ A\[UnderBracket]105[t]\^2\ B\
\[UnderBracket]105[t] + 
              A\[UnderBracket]105[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]105[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]106", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]106\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]118[t] + 
              0.1`\ A\[UnderBracket]125[t] + 0.1`\ A\[UnderBracket]86[t] + 
              0.1`\ A\[UnderBracket]91[t] + 0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]106[t]\^2\ B\
\[UnderBracket]106[t] + 
              A\[UnderBracket]106[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]106[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]107", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]107\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]122[t] + 0.1`\ A\[UnderBracket]137[t] + 
              0.1`\ A\[UnderBracket]77[t] + 0.1`\ A\[UnderBracket]78[t] + 
              0.10000000000000003`\ A\[UnderBracket]107[t]\^2\ B\
\[UnderBracket]107[t] + 
              A\[UnderBracket]107[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]107[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]108", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]108\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]116[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]90[t] + 
              0.1`\ A\[UnderBracket]94[t] + 
              0.10000000000000003`\ A\[UnderBracket]108[t]\^2\ B\
\[UnderBracket]108[t] + 
              A\[UnderBracket]108[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]108[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]109", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]109\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]102[t] - 
              0.7999999999999999`\ A\[UnderBracket]109[t] + 
              0.1`\ A\[UnderBracket]129[t] + 0.1`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]109[t]\^2\ B\
\[UnderBracket]109[t] - 
              0.01`\ A\[UnderBracket]109[t]\ Y\[UnderBracket]109[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]11", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]11\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]13[t] + 
              0.1`\ A\[UnderBracket]22[t] + 0.1`\ A\[UnderBracket]24[t] + 
              0.1`\ A\[UnderBracket]25[t] + 0.1`\ A\[UnderBracket]26[t] + 
              0.1`\ A\[UnderBracket]6[t] + 0.1`\ A\[UnderBracket]7[t] + 
              0.10000000000000003`\ A\[UnderBracket]11[t]\^2\ \
B\[UnderBracket]11[t] + 
              A\[UnderBracket]11[
                  t]\ \((\(-0.9999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]11[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]110", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]110\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]102[t] + 
              0.1`\ A\[UnderBracket]112[t] + 0.1`\ A\[UnderBracket]129[t] + 
              0.1`\ A\[UnderBracket]80[t] + 0.1`\ A\[UnderBracket]88[t] + 
              0.10000000000000003`\ A\[UnderBracket]110[t]\^2\ B\
\[UnderBracket]110[t] + 
              A\[UnderBracket]110[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]110[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]111", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]111\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]121[t] + 0.1`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]92[t] + 0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]111[t]\^2\ B\
\[UnderBracket]111[t] + 
              A\[UnderBracket]111[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]111[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]112", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]112\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]110[t] + 
              0.1`\ A\[UnderBracket]120[t] + 0.1`\ A\[UnderBracket]129[t] + 
              0.1`\ A\[UnderBracket]144[t] + 0.1`\ A\[UnderBracket]149[t] + 
              0.1`\ A\[UnderBracket]88[t] + 
              0.10000000000000003`\ A\[UnderBracket]112[t]\^2\ B\
\[UnderBracket]112[t] + 
              A\[UnderBracket]112[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]112[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]113", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]113\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]127[t] + 
              0.1`\ A\[UnderBracket]134[t] + 0.1`\ A\[UnderBracket]82[t] + 
              0.1`\ A\[UnderBracket]89[t] + 0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]113[t]\^2\ B\
\[UnderBracket]113[t] + 
              A\[UnderBracket]113[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]113[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]114", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]114\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]124[t] + 0.1`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]145[t] + 
              0.10000000000000003`\ A\[UnderBracket]114[t]\^2\ B\
\[UnderBracket]114[t] + 
              A\[UnderBracket]114[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]114[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]115", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]115\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]104[t] + 
              0.1`\ A\[UnderBracket]105[t] - 
              0.8999999999999999`\ A\[UnderBracket]115[t] + 
              0.1`\ A\[UnderBracket]116[t] + 0.1`\ A\[UnderBracket]130[t] + 
              0.1`\ A\[UnderBracket]142[t] + 0.1`\ A\[UnderBracket]93[t] + 
              0.10000000000000003`\ A\[UnderBracket]115[t]\^2\ B\
\[UnderBracket]115[t] - 
              0.01`\ A\[UnderBracket]115[t]\ Y\[UnderBracket]115[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]116", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]116\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]105[t] + 
              0.1`\ A\[UnderBracket]108[t] + 0.1`\ A\[UnderBracket]115[t] - 
              0.8999999999999999`\ A\[UnderBracket]116[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]143[t] + 
              0.1`\ A\[UnderBracket]90[t] + 
              0.10000000000000003`\ A\[UnderBracket]116[t]\^2\ B\
\[UnderBracket]116[t] - 
              0.01`\ A\[UnderBracket]116[t]\ Y\[UnderBracket]116[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]117", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]117\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]108[t] + 
              0.1`\ A\[UnderBracket]116[t] - 
              0.9999999999999999`\ A\[UnderBracket]117[t] + 
              0.1`\ A\[UnderBracket]125[t] + 0.1`\ A\[UnderBracket]143[t] + 
              0.1`\ A\[UnderBracket]154[t] + 0.1`\ A\[UnderBracket]94[t] + 
              0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]117[t]\^2\ B\
\[UnderBracket]117[t] - 
              0.01`\ A\[UnderBracket]117[t]\ Y\[UnderBracket]117[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]118", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]118\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]106[t] + 
              0.1`\ A\[UnderBracket]119[t] + 0.1`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]135[t] + 0.1`\ A\[UnderBracket]91[t] + 
              0.1`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]118[t]\^2\ B\
\[UnderBracket]118[t] + 
              A\[UnderBracket]118[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]118[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]119", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]119\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]118[t] - 
              0.7999999999999999`\ A\[UnderBracket]119[t] + 
              0.1`\ A\[UnderBracket]131[t] + 0.1`\ A\[UnderBracket]135[t] + 
              0.1`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]119[t]\^2\ B\
\[UnderBracket]119[t] - 
              0.01`\ A\[UnderBracket]119[t]\ Y\[UnderBracket]119[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]12", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]12\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]16[t] + 
              0.1`\ A\[UnderBracket]22[t] + 0.1`\ A\[UnderBracket]30[t] + 
              0.1`\ A\[UnderBracket]6[t] + 
              0.10000000000000003`\ A\[UnderBracket]12[t]\^2\ \
B\[UnderBracket]12[t] + 
              A\[UnderBracket]12[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]12[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]120", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]120\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]112[t] + 
              0.1`\ A\[UnderBracket]121[t] + 0.1`\ A\[UnderBracket]126[t] + 
              0.1`\ A\[UnderBracket]149[t] + 0.1`\ A\[UnderBracket]88[t] + 
              0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]120[t]\^2\ B\
\[UnderBracket]120[t] + 
              A\[UnderBracket]120[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]120[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]121", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]121\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]111[t] + 
              0.1`\ A\[UnderBracket]120[t] - 
              0.9999999999999999`\ A\[UnderBracket]121[t] + 
              0.1`\ A\[UnderBracket]126[t] + 0.1`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]138[t] + 0.1`\ A\[UnderBracket]139[t] + 
              0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]121[t]\^2\ B\
\[UnderBracket]121[t] - 
              0.01`\ A\[UnderBracket]121[t]\ Y\[UnderBracket]121[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]122", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]122\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]107[t] + 
              0.1`\ A\[UnderBracket]137[t] + 0.1`\ A\[UnderBracket]150[t] + 
              0.10000000000000003`\ A\[UnderBracket]122[t]\^2\ B\
\[UnderBracket]122[t] + 
              A\[UnderBracket]122[
                  t]\ \((\(-0.6`\) - 0.01`\ Y\[UnderBracket]122[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]123", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]123\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]127[t] + 0.1`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]141[t] + 0.1`\ A\[UnderBracket]83[t] + 
              0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]123[t]\^2\ B\
\[UnderBracket]123[t] + 
              A\[UnderBracket]123[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]123[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]124", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]124\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]104[t] + 0.1`\ A\[UnderBracket]114[t] - 
              0.9999999999999999`\ A\[UnderBracket]124[t] + 
              0.1`\ A\[UnderBracket]128[t] + 0.1`\ A\[UnderBracket]140[t] + 
              0.1`\ A\[UnderBracket]145[t] + 0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]124[t]\^2\ B\
\[UnderBracket]124[t] - 
              0.01`\ A\[UnderBracket]124[t]\ Y\[UnderBracket]124[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]125", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]125\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]106[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]118[t] - 
              1.0999999999999999`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]135[t] + 0.1`\ A\[UnderBracket]154[t] + 
              0.1`\ A\[UnderBracket]155[t] + 0.1`\ A\[UnderBracket]162[t] + 
              0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]125[t]\^2\ B\
\[UnderBracket]125[t] - 
              0.01`\ A\[UnderBracket]125[t]\ Y\[UnderBracket]125[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]126", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]126\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]120[t] + 
              0.1`\ A\[UnderBracket]121[t] - 0.7`\ A\[UnderBracket]126[t] + 
              0.1`\ A\[UnderBracket]138[t] + 0.1`\ A\[UnderBracket]149[t] + 
              0.10000000000000003`\ A\[UnderBracket]126[t]\^2\ B\
\[UnderBracket]126[t] - 
              0.01`\ A\[UnderBracket]126[t]\ Y\[UnderBracket]126[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]127", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]127\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]113[t] + 
              0.1`\ A\[UnderBracket]123[t] - 
              0.7999999999999999`\ A\[UnderBracket]127[t] + 
              0.1`\ A\[UnderBracket]134[t] + 0.1`\ A\[UnderBracket]141[t] + 
              0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]127[t]\^2\ B\
\[UnderBracket]127[t] - 
              0.01`\ A\[UnderBracket]127[t]\ Y\[UnderBracket]127[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]128", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]128\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]104[t] + 
              0.1`\ A\[UnderBracket]124[t] - 0.7`\ A\[UnderBracket]128[t] + 
              0.1`\ A\[UnderBracket]130[t] + 0.1`\ A\[UnderBracket]140[t] + 
              0.10000000000000003`\ A\[UnderBracket]128[t]\^2\ B\
\[UnderBracket]128[t] - 
              0.01`\ A\[UnderBracket]128[t]\ Y\[UnderBracket]128[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]129", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]129\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]102[t] + 
              0.1`\ A\[UnderBracket]109[t] + 0.1`\ A\[UnderBracket]110[t] + 
              0.1`\ A\[UnderBracket]112[t] - 
              0.9999999999999999`\ A\[UnderBracket]129[t] + 
              0.1`\ A\[UnderBracket]131[t] + 0.1`\ A\[UnderBracket]133[t] + 
              0.1`\ A\[UnderBracket]144[t] + 
              0.10000000000000003`\ A\[UnderBracket]129[t]\^2\ B\
\[UnderBracket]129[t] - 
              0.01`\ A\[UnderBracket]129[t]\ Y\[UnderBracket]129[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]13", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]13\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]17[t] + 0.1`\ A\[UnderBracket]26[t] + 
              0.1`\ A\[UnderBracket]39[t] + 0.1`\ A\[UnderBracket]7[t] + 
              0.1`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]13[t]\^2\ \
B\[UnderBracket]13[t] + 
              A\[UnderBracket]13[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]13[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]130", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]130\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]104[t] + 
              0.1`\ A\[UnderBracket]115[t] + 0.1`\ A\[UnderBracket]128[t] - 
              0.9999999999999999`\ A\[UnderBracket]130[t] + 
              0.1`\ A\[UnderBracket]140[t] + 0.1`\ A\[UnderBracket]142[t] + 
              0.1`\ A\[UnderBracket]146[t] + 0.1`\ A\[UnderBracket]156[t] + 
              0.10000000000000003`\ A\[UnderBracket]130[t]\^2\ B\
\[UnderBracket]130[t] - 
              0.01`\ A\[UnderBracket]130[t]\ Y\[UnderBracket]130[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]131", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]131\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]109[t] + 0.1`\ A\[UnderBracket]119[t] + 
              0.1`\ A\[UnderBracket]129[t] - 1.2`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]133[t] + 0.1`\ A\[UnderBracket]135[t] + 
              0.1`\ A\[UnderBracket]147[t] + 0.1`\ A\[UnderBracket]148[t] + 
              0.1`\ A\[UnderBracket]158[t] + 
              0.10000000000000003`\ A\[UnderBracket]131[t]\^2\ B\
\[UnderBracket]131[t] - 
              0.01`\ A\[UnderBracket]131[t]\ Y\[UnderBracket]131[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]132", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]132\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]114[t] + 0.1`\ A\[UnderBracket]123[t] - 
              0.8999999999999999`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]141[t] + 0.1`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]164[t] + 
              0.10000000000000003`\ A\[UnderBracket]132[t]\^2\ B\
\[UnderBracket]132[t] - 
              0.01`\ A\[UnderBracket]132[t]\ Y\[UnderBracket]132[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]133", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]133\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]129[t] + 
              0.1`\ A\[UnderBracket]131[t] - 0.7`\ A\[UnderBracket]133[t] + 
              0.1`\ A\[UnderBracket]144[t] + 0.1`\ A\[UnderBracket]148[t] + 
              
              0.10000000000000003`\ A\[UnderBracket]133[t]\^2\ B\
\[UnderBracket]133[t] - 
              0.01`\ A\[UnderBracket]133[t]\ Y\[UnderBracket]133[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]134", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]134\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]113[t] + 
              0.1`\ A\[UnderBracket]127[t] - 
              0.7999999999999999`\ A\[UnderBracket]134[t] + 
              0.1`\ A\[UnderBracket]141[t] + 0.1`\ A\[UnderBracket]152[t] + 
              0.1`\ A\[UnderBracket]153[t] + 
              0.10000000000000003`\ A\[UnderBracket]134[t]\^2\ B\
\[UnderBracket]134[t] - 
              0.01`\ A\[UnderBracket]134[t]\ Y\[UnderBracket]134[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]135", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]135\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]118[t] + 
              0.1`\ A\[UnderBracket]119[t] + 0.1`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]131[t] - 
              0.8999999999999999`\ A\[UnderBracket]135[t] + 
              0.1`\ A\[UnderBracket]147[t] + 0.1`\ A\[UnderBracket]155[t] + 
              0.10000000000000003`\ A\[UnderBracket]135[t]\^2\ B\
\[UnderBracket]135[t] - 
              0.01`\ A\[UnderBracket]135[t]\ Y\[UnderBracket]135[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]136", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]136\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]111[t] + 0.1`\ A\[UnderBracket]121[t] - 
              0.9999999999999999`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]137[t] + 0.1`\ A\[UnderBracket]139[t] + 
              0.1`\ A\[UnderBracket]157[t] + 0.1`\ A\[UnderBracket]159[t] + 
              0.10000000000000003`\ A\[UnderBracket]136[t]\^2\ B\
\[UnderBracket]136[t] - 
              0.01`\ A\[UnderBracket]136[t]\ Y\[UnderBracket]136[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]137", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]137\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]107[t] + 0.1`\ A\[UnderBracket]122[t] + 
              0.1`\ A\[UnderBracket]136[t] - 
              0.9999999999999999`\ A\[UnderBracket]137[t] + 
              0.1`\ A\[UnderBracket]150[t] + 0.1`\ A\[UnderBracket]159[t] + 
              0.1`\ A\[UnderBracket]171[t] + 
              0.10000000000000003`\ A\[UnderBracket]137[t]\^2\ B\
\[UnderBracket]137[t] - 
              0.01`\ A\[UnderBracket]137[t]\ Y\[UnderBracket]137[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]138", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]138\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]121[t] + 
              0.1`\ A\[UnderBracket]126[t] - 
              0.9999999999999999`\ A\[UnderBracket]138[t] + 
              0.1`\ A\[UnderBracket]139[t] + 0.1`\ A\[UnderBracket]149[t] + 
              0.1`\ A\[UnderBracket]157[t] + 0.1`\ A\[UnderBracket]163[t] + 
              0.1`\ A\[UnderBracket]170[t] + 
              0.10000000000000003`\ A\[UnderBracket]138[t]\^2\ B\
\[UnderBracket]138[t] - 
              0.01`\ A\[UnderBracket]138[t]\ Y\[UnderBracket]138[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]139", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]139\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]121[t] + 
              0.1`\ A\[UnderBracket]136[t] + 0.1`\ A\[UnderBracket]138[t] - 
              0.7`\ A\[UnderBracket]139[t] + 0.1`\ A\[UnderBracket]157[t] + 
              0.10000000000000003`\ A\[UnderBracket]139[t]\^2\ B\
\[UnderBracket]139[t] - 
              0.01`\ A\[UnderBracket]139[t]\ Y\[UnderBracket]139[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]14", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]14\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]17[t] + 
              0.1`\ A\[UnderBracket]23[t] + 0.1`\ A\[UnderBracket]27[t] + 
              0.1`\ A\[UnderBracket]33[t] + 0.1`\ A\[UnderBracket]5[t] + 
              0.1`\ A\[UnderBracket]8[t] + 0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]14[t]\^2\ \
B\[UnderBracket]14[t] + 
              A\[UnderBracket]14[
                  t]\ \((\(-0.9999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]14[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]140", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]140\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]124[t] + 
              0.1`\ A\[UnderBracket]128[t] + 0.1`\ A\[UnderBracket]130[t] - 
              0.7999999999999999`\ A\[UnderBracket]140[t] + 
              0.1`\ A\[UnderBracket]145[t] + 0.1`\ A\[UnderBracket]156[t] + 
              0.10000000000000003`\ A\[UnderBracket]140[t]\^2\ B\
\[UnderBracket]140[t] - 
              0.01`\ A\[UnderBracket]140[t]\ Y\[UnderBracket]140[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]141", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]141\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]123[t] + 
              0.1`\ A\[UnderBracket]127[t] + 0.1`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]134[t] - 
              0.8999999999999999`\ A\[UnderBracket]141[t] + 
              0.1`\ A\[UnderBracket]153[t] + 0.1`\ A\[UnderBracket]164[t] + 
              0.10000000000000003`\ A\[UnderBracket]141[t]\^2\ B\
\[UnderBracket]141[t] - 
              0.01`\ A\[UnderBracket]141[t]\ Y\[UnderBracket]141[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]142", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]142\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]115[t] + 
              0.1`\ A\[UnderBracket]130[t] - 
              0.7999999999999999`\ A\[UnderBracket]142[t] + 
              0.1`\ A\[UnderBracket]143[t] + 0.1`\ A\[UnderBracket]146[t] + 
              0.1`\ A\[UnderBracket]151[t] + 
              0.10000000000000003`\ A\[UnderBracket]142[t]\^2\ B\
\[UnderBracket]142[t] - 
              0.01`\ A\[UnderBracket]142[t]\ Y\[UnderBracket]142[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]143", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]143\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]116[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]142[t] - 
              0.7999999999999999`\ A\[UnderBracket]143[t] + 
              0.1`\ A\[UnderBracket]151[t] + 0.1`\ A\[UnderBracket]154[t] + 
              0.10000000000000003`\ A\[UnderBracket]143[t]\^2\ B\
\[UnderBracket]143[t] - 
              0.01`\ A\[UnderBracket]143[t]\ Y\[UnderBracket]143[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]144", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]144\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]112[t] + 
              0.1`\ A\[UnderBracket]129[t] + 0.1`\ A\[UnderBracket]133[t] - 
              0.9999999999999999`\ A\[UnderBracket]144[t] + 
              0.1`\ A\[UnderBracket]148[t] + 0.1`\ A\[UnderBracket]149[t] + 
              0.1`\ A\[UnderBracket]165[t] + 0.1`\ A\[UnderBracket]169[t] + 
              0.10000000000000003`\ A\[UnderBracket]144[t]\^2\ B\
\[UnderBracket]144[t] - 
              0.01`\ A\[UnderBracket]144[t]\ Y\[UnderBracket]144[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]145", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]145\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]114[t] + 
              0.1`\ A\[UnderBracket]124[t] + 0.1`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]140[t] - 
              1.0999999999999999`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]156[t] + 0.1`\ A\[UnderBracket]160[t] + 
              0.1`\ A\[UnderBracket]164[t] + 0.1`\ A\[UnderBracket]188[t] + 
              0.10000000000000003`\ A\[UnderBracket]145[t]\^2\ B\
\[UnderBracket]145[t] - 
              0.01`\ A\[UnderBracket]145[t]\ Y\[UnderBracket]145[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]146", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]146\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]130[t] + 
              0.1`\ A\[UnderBracket]142[t] - 
              0.7999999999999999`\ A\[UnderBracket]146[t] + 
              0.1`\ A\[UnderBracket]151[t] + 0.1`\ A\[UnderBracket]156[t] + 
              0.1`\ A\[UnderBracket]161[t] + 
              0.10000000000000003`\ A\[UnderBracket]146[t]\^2\ B\
\[UnderBracket]146[t] - 
              0.01`\ A\[UnderBracket]146[t]\ Y\[UnderBracket]146[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]147", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]147\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]135[t] - 
              0.7999999999999999`\ A\[UnderBracket]147[t] + 
              0.1`\ A\[UnderBracket]155[t] + 0.1`\ A\[UnderBracket]158[t] + 
              0.1`\ A\[UnderBracket]167[t] + 
              0.10000000000000003`\ A\[UnderBracket]147[t]\^2\ B\
\[UnderBracket]147[t] - 
              0.01`\ A\[UnderBracket]147[t]\ Y\[UnderBracket]147[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]148", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]148\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]133[t] + 0.1`\ A\[UnderBracket]144[t] - 
              0.8999999999999999`\ A\[UnderBracket]148[t] + 
              0.1`\ A\[UnderBracket]158[t] + 0.1`\ A\[UnderBracket]168[t] + 
              0.1`\ A\[UnderBracket]169[t] + 
              0.10000000000000003`\ A\[UnderBracket]148[t]\^2\ B\
\[UnderBracket]148[t] - 
              0.01`\ A\[UnderBracket]148[t]\ Y\[UnderBracket]148[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]149", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]149\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]112[t] + 
              0.1`\ A\[UnderBracket]120[t] + 0.1`\ A\[UnderBracket]126[t] + 
              0.1`\ A\[UnderBracket]138[t] + 0.1`\ A\[UnderBracket]144[t] - 
              0.9999999999999999`\ A\[UnderBracket]149[t] + 
              0.1`\ A\[UnderBracket]163[t] + 0.1`\ A\[UnderBracket]165[t] + 
              0.10000000000000003`\ A\[UnderBracket]149[t]\^2\ B\
\[UnderBracket]149[t] - 
              0.01`\ A\[UnderBracket]149[t]\ Y\[UnderBracket]149[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]15", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]15\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]20[t] + 
              0.1`\ A\[UnderBracket]21[t] + 0.1`\ A\[UnderBracket]29[t] + 
              0.1`\ A\[UnderBracket]34[t] + 0.1`\ A\[UnderBracket]35[t] + 
              0.10000000000000003`\ A\[UnderBracket]15[t]\^2\ \
B\[UnderBracket]15[t] + 
              A\[UnderBracket]15[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]15[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]150", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]150\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]122[t] + 
              0.1`\ A\[UnderBracket]137[t] - 0.6`\ A\[UnderBracket]150[t] + 
              0.1`\ A\[UnderBracket]171[t] + 
              0.10000000000000003`\ A\[UnderBracket]150[t]\^2\ B\
\[UnderBracket]150[t] - 
              0.01`\ A\[UnderBracket]150[t]\ Y\[UnderBracket]150[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]151", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]151\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]142[t] + 
              0.1`\ A\[UnderBracket]143[t] + 0.1`\ A\[UnderBracket]146[t] - 
              0.9999999999999999`\ A\[UnderBracket]151[t] + 
              0.1`\ A\[UnderBracket]154[t] + 0.1`\ A\[UnderBracket]161[t] + 
              0.1`\ A\[UnderBracket]166[t] + 0.1`\ A\[UnderBracket]175[t] + 
              0.10000000000000003`\ A\[UnderBracket]151[t]\^2\ B\
\[UnderBracket]151[t] - 
              0.01`\ A\[UnderBracket]151[t]\ Y\[UnderBracket]151[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]152", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]152\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]134[t] + 
              0.1`\ A\[UnderBracket]153[t] + 0.1`\ A\[UnderBracket]172[t] + 
              0.1`\ A\[UnderBracket]178[t] + 
              0.10000000000000003`\ A\[UnderBracket]152[t]\^2\ B\
\[UnderBracket]152[t] + 
              A\[UnderBracket]152[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]152[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]153", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]153\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]134[t] + 
              0.1`\ A\[UnderBracket]141[t] + 0.1`\ A\[UnderBracket]152[t] - 
              0.8999999999999999`\ A\[UnderBracket]153[t] + 
              0.1`\ A\[UnderBracket]164[t] + 0.1`\ A\[UnderBracket]172[t] + 
              0.1`\ A\[UnderBracket]176[t] + 
              0.10000000000000003`\ A\[UnderBracket]153[t]\^2\ B\
\[UnderBracket]153[t] - 
              0.01`\ A\[UnderBracket]153[t]\ Y\[UnderBracket]153[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]154", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]154\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]117[t] + 
              0.1`\ A\[UnderBracket]125[t] + 0.1`\ A\[UnderBracket]143[t] + 
              0.1`\ A\[UnderBracket]151[t] - 
              0.8999999999999999`\ A\[UnderBracket]154[t] + 
              0.1`\ A\[UnderBracket]162[t] + 0.1`\ A\[UnderBracket]166[t] + 
              0.10000000000000003`\ A\[UnderBracket]154[t]\^2\ B\
\[UnderBracket]154[t] - 
              0.01`\ A\[UnderBracket]154[t]\ Y\[UnderBracket]154[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]155", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]155\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]135[t] + 0.1`\ A\[UnderBracket]147[t] - 
              0.8999999999999999`\ A\[UnderBracket]155[t] + 
              0.1`\ A\[UnderBracket]162[t] + 0.1`\ A\[UnderBracket]167[t] + 
              0.1`\ A\[UnderBracket]173[t] + 
              0.10000000000000003`\ A\[UnderBracket]155[t]\^2\ B\
\[UnderBracket]155[t] - 
              0.01`\ A\[UnderBracket]155[t]\ Y\[UnderBracket]155[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]156", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]156\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]130[t] + 
              0.1`\ A\[UnderBracket]140[t] + 0.1`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]146[t] - 
              0.8999999999999999`\ A\[UnderBracket]156[t] + 
              0.1`\ A\[UnderBracket]160[t] + 0.1`\ A\[UnderBracket]161[t] + 
              
              0.10000000000000003`\ A\[UnderBracket]156[t]\^2\ B\
\[UnderBracket]156[t] - 
              0.01`\ A\[UnderBracket]156[t]\ Y\[UnderBracket]156[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]157", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]157\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]138[t] + 0.1`\ A\[UnderBracket]139[t] - 
              0.7999999999999999`\ A\[UnderBracket]157[t] + 
              0.1`\ A\[UnderBracket]159[t] + 0.1`\ A\[UnderBracket]170[t] + 
              0.10000000000000003`\ A\[UnderBracket]157[t]\^2\ B\
\[UnderBracket]157[t] - 
              0.01`\ A\[UnderBracket]157[t]\ Y\[UnderBracket]157[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]158", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]158\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]131[t] + 
              0.1`\ A\[UnderBracket]147[t] + 0.1`\ A\[UnderBracket]148[t] - 
              0.8999999999999999`\ A\[UnderBracket]158[t] + 
              0.1`\ A\[UnderBracket]167[t] + 0.1`\ A\[UnderBracket]168[t] + 
              0.1`\ A\[UnderBracket]179[t] + 
              0.10000000000000003`\ A\[UnderBracket]158[t]\^2\ B\
\[UnderBracket]158[t] - 
              0.01`\ A\[UnderBracket]158[t]\ Y\[UnderBracket]158[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]159", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]159\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]136[t] + 
              0.1`\ A\[UnderBracket]137[t] + 0.1`\ A\[UnderBracket]157[t] - 
              0.9999999999999999`\ A\[UnderBracket]159[t] + 
              0.1`\ A\[UnderBracket]170[t] + 0.1`\ A\[UnderBracket]171[t] + 
              0.1`\ A\[UnderBracket]181[t] + 0.1`\ A\[UnderBracket]182[t] + 
              0.10000000000000003`\ A\[UnderBracket]159[t]\^2\ B\
\[UnderBracket]159[t] - 
              0.01`\ A\[UnderBracket]159[t]\ Y\[UnderBracket]159[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]16", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.1`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ A\[UnderBracket]12[t] + 0.1`\ A\[UnderBracket]30[t] + 
                0.10000000000000003`\ A\[UnderBracket]16[t]\^2\ B\
\[UnderBracket]16[t] + 
                A\[UnderBracket]16[
                    t]\ \((\(-0.5`\) - 
                      0.01`\ Y\[UnderBracket]16[
                          t])\)\)\/cell\[UnderBracket]16\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]160", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]160\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]156[t] - 
              0.7999999999999999`\ A\[UnderBracket]160[t] + 
              0.1`\ A\[UnderBracket]161[t] + 0.1`\ A\[UnderBracket]186[t] + 
              0.1`\ A\[UnderBracket]188[t] + 
              0.10000000000000003`\ A\[UnderBracket]160[t]\^2\ B\
\[UnderBracket]160[t] - 
              0.01`\ A\[UnderBracket]160[t]\ Y\[UnderBracket]160[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]161", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]161\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]146[t] + 
              0.1`\ A\[UnderBracket]151[t] + 0.1`\ A\[UnderBracket]156[t] + 
              0.1`\ A\[UnderBracket]160[t] - 
              0.9999999999999999`\ A\[UnderBracket]161[t] + 
              0.1`\ A\[UnderBracket]175[t] + 0.1`\ A\[UnderBracket]186[t] + 
              0.1`\ A\[UnderBracket]190[t] + 
              0.10000000000000003`\ A\[UnderBracket]161[t]\^2\ B\
\[UnderBracket]161[t] - 
              0.01`\ A\[UnderBracket]161[t]\ Y\[UnderBracket]161[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]162", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]162\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]154[t] + 0.1`\ A\[UnderBracket]155[t] - 
              0.9999999999999999`\ A\[UnderBracket]162[t] + 
              0.1`\ A\[UnderBracket]166[t] + 0.1`\ A\[UnderBracket]173[t] + 
              0.1`\ A\[UnderBracket]183[t] + 0.1`\ A\[UnderBracket]184[t] + 
              0.10000000000000003`\ A\[UnderBracket]162[t]\^2\ B\
\[UnderBracket]162[t] - 
              0.01`\ A\[UnderBracket]162[t]\ Y\[UnderBracket]162[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]163", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]163\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]138[t] + 
              0.1`\ A\[UnderBracket]149[t] - 
              0.7999999999999999`\ A\[UnderBracket]163[t] + 
              0.1`\ A\[UnderBracket]165[t] + 0.1`\ A\[UnderBracket]170[t] + 
              0.1`\ A\[UnderBracket]180[t] + 
              0.10000000000000003`\ A\[UnderBracket]163[t]\^2\ B\
\[UnderBracket]163[t] - 
              0.01`\ A\[UnderBracket]163[t]\ Y\[UnderBracket]163[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]164", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]164\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]132[t] + 
              0.1`\ A\[UnderBracket]141[t] + 0.1`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]153[t] - 
              0.9999999999999999`\ A\[UnderBracket]164[t] + 
              0.1`\ A\[UnderBracket]176[t] + 0.1`\ A\[UnderBracket]188[t] + 
              0.1`\ A\[UnderBracket]201[t] + 
              0.10000000000000003`\ A\[UnderBracket]164[t]\^2\ B\
\[UnderBracket]164[t] - 
              0.01`\ A\[UnderBracket]164[t]\ Y\[UnderBracket]164[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]165", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]165\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]144[t] + 
              0.1`\ A\[UnderBracket]149[t] + 0.1`\ A\[UnderBracket]163[t] - 
              0.8999999999999999`\ A\[UnderBracket]165[t] + 
              0.1`\ A\[UnderBracket]169[t] + 0.1`\ A\[UnderBracket]177[t] + 
              0.1`\ A\[UnderBracket]180[t] + 
              0.10000000000000003`\ A\[UnderBracket]165[t]\^2\ B\
\[UnderBracket]165[t] - 
              0.01`\ A\[UnderBracket]165[t]\ Y\[UnderBracket]165[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]166", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]166\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]151[t] + 
              0.1`\ A\[UnderBracket]154[t] + 0.1`\ A\[UnderBracket]162[t] - 
              0.7999999999999999`\ A\[UnderBracket]166[t] + 
              0.1`\ A\[UnderBracket]175[t] + 0.1`\ A\[UnderBracket]183[t] + 
              0.10000000000000003`\ A\[UnderBracket]166[t]\^2\ B\
\[UnderBracket]166[t] - 
              0.01`\ A\[UnderBracket]166[t]\ Y\[UnderBracket]166[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]167", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]167\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]147[t] + 
              0.1`\ A\[UnderBracket]155[t] + 0.1`\ A\[UnderBracket]158[t] - 
              0.8999999999999999`\ A\[UnderBracket]167[t] + 
              0.1`\ A\[UnderBracket]173[t] + 0.1`\ A\[UnderBracket]174[t] + 
              0.1`\ A\[UnderBracket]179[t] + 
              0.10000000000000003`\ A\[UnderBracket]167[t]\^2\ B\
\[UnderBracket]167[t] - 
              0.01`\ A\[UnderBracket]167[t]\ Y\[UnderBracket]167[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]168", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]168\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]148[t] + 
              0.1`\ A\[UnderBracket]158[t] - 0.7`\ A\[UnderBracket]168[t] + 
              0.1`\ A\[UnderBracket]169[t] + 0.1`\ A\[UnderBracket]179[t] + 
              0.10000000000000003`\ A\[UnderBracket]168[t]\^2\ B\
\[UnderBracket]168[t] - 
              0.01`\ A\[UnderBracket]168[t]\ Y\[UnderBracket]168[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]169", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]169\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]144[t] + 
              0.1`\ A\[UnderBracket]148[t] + 0.1`\ A\[UnderBracket]165[t] + 
              0.1`\ A\[UnderBracket]168[t] - 
              1.0999999999999999`\ A\[UnderBracket]169[t] + 
              0.1`\ A\[UnderBracket]177[t] + 0.1`\ A\[UnderBracket]179[t] + 
              0.1`\ A\[UnderBracket]192[t] + 0.1`\ A\[UnderBracket]193[t] + 
              0.10000000000000003`\ A\[UnderBracket]169[t]\^2\ B\
\[UnderBracket]169[t] - 
              0.01`\ A\[UnderBracket]169[t]\ Y\[UnderBracket]169[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]17", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]17\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]13[t] + 
              0.1`\ A\[UnderBracket]14[t] - 
              0.9999999999999999`\ A\[UnderBracket]17[t] + 
              0.1`\ A\[UnderBracket]23[t] + 0.1`\ A\[UnderBracket]39[t] + 
              0.1`\ A\[UnderBracket]53[t] + 0.1`\ A\[UnderBracket]54[t] + 
              0.1`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]17[t]\^2\ \
B\[UnderBracket]17[t] - 
              0.01`\ A\[UnderBracket]17[t]\ Y\[UnderBracket]17[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]170", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]170\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]138[t] + 
              0.1`\ A\[UnderBracket]157[t] + 0.1`\ A\[UnderBracket]159[t] + 
              0.1`\ A\[UnderBracket]163[t] - 
              0.8999999999999999`\ A\[UnderBracket]170[t] + 
              0.1`\ A\[UnderBracket]180[t] + 0.1`\ A\[UnderBracket]181[t] + 
              0.10000000000000003`\ A\[UnderBracket]170[t]\^2\ B\
\[UnderBracket]170[t] - 
              0.01`\ A\[UnderBracket]170[t]\ Y\[UnderBracket]170[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]171", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]171\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]137[t] + 
              0.1`\ A\[UnderBracket]150[t] + 0.1`\ A\[UnderBracket]159[t] - 
              0.7`\ A\[UnderBracket]171[t] + 0.1`\ A\[UnderBracket]182[t] + 
              0.10000000000000003`\ A\[UnderBracket]171[t]\^2\ B\
\[UnderBracket]171[t] - 
              0.01`\ A\[UnderBracket]171[t]\ Y\[UnderBracket]171[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]172", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]172\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]152[t] + 
              0.1`\ A\[UnderBracket]153[t] - 
              0.7999999999999999`\ A\[UnderBracket]172[t] + 
              0.1`\ A\[UnderBracket]176[t] + 0.1`\ A\[UnderBracket]178[t] + 
              0.1`\ A\[UnderBracket]185[t] + 
              0.10000000000000003`\ A\[UnderBracket]172[t]\^2\ B\
\[UnderBracket]172[t] - 
              0.01`\ A\[UnderBracket]172[t]\ Y\[UnderBracket]172[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]173", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]173\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]155[t] + 
              0.1`\ A\[UnderBracket]162[t] + 0.1`\ A\[UnderBracket]167[t] - 
              0.8999999999999999`\ A\[UnderBracket]173[t] + 
              0.1`\ A\[UnderBracket]174[t] + 0.1`\ A\[UnderBracket]184[t] + 
              0.1`\ A\[UnderBracket]189[t] + 
              0.10000000000000003`\ A\[UnderBracket]173[t]\^2\ B\
\[UnderBracket]173[t] - 
              0.01`\ A\[UnderBracket]173[t]\ Y\[UnderBracket]173[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]174", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]174\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]167[t] + 
              0.1`\ A\[UnderBracket]173[t] - 
              0.7999999999999999`\ A\[UnderBracket]174[t] + 
              0.1`\ A\[UnderBracket]179[t] + 0.1`\ A\[UnderBracket]187[t] + 
              0.1`\ A\[UnderBracket]189[t] + 
              0.10000000000000003`\ A\[UnderBracket]174[t]\^2\ B\
\[UnderBracket]174[t] - 
              0.01`\ A\[UnderBracket]174[t]\ Y\[UnderBracket]174[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]175", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]175\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]151[t] + 
              0.1`\ A\[UnderBracket]161[t] + 0.1`\ A\[UnderBracket]166[t] - 
              0.8999999999999999`\ A\[UnderBracket]175[t] + 
              0.1`\ A\[UnderBracket]183[t] + 0.1`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]199[t] + 
              0.10000000000000003`\ A\[UnderBracket]175[t]\^2\ B\
\[UnderBracket]175[t] - 
              0.01`\ A\[UnderBracket]175[t]\ Y\[UnderBracket]175[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]176", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]176\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]153[t] + 
              0.1`\ A\[UnderBracket]164[t] + 0.1`\ A\[UnderBracket]172[t] - 
              0.8999999999999999`\ A\[UnderBracket]176[t] + 
              0.1`\ A\[UnderBracket]185[t] + 0.1`\ A\[UnderBracket]197[t] + 
              0.1`\ A\[UnderBracket]201[t] + 
              0.10000000000000003`\ A\[UnderBracket]176[t]\^2\ B\
\[UnderBracket]176[t] - 
              0.01`\ A\[UnderBracket]176[t]\ Y\[UnderBracket]176[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]177", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]177\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]165[t] + 
              0.1`\ A\[UnderBracket]169[t] - 
              0.7999999999999999`\ A\[UnderBracket]177[t] + 
              0.1`\ A\[UnderBracket]180[t] + 0.1`\ A\[UnderBracket]193[t] + 
              0.1`\ A\[UnderBracket]194[t] + 
              0.10000000000000003`\ A\[UnderBracket]177[t]\^2\ B\
\[UnderBracket]177[t] - 
              0.01`\ A\[UnderBracket]177[t]\ Y\[UnderBracket]177[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]178", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]178\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]152[t] + 
              0.1`\ A\[UnderBracket]172[t] - 0.7`\ A\[UnderBracket]178[t] + 
              0.1`\ A\[UnderBracket]185[t] + 0.1`\ A\[UnderBracket]203[t] + 
              0.10000000000000003`\ A\[UnderBracket]178[t]\^2\ B\
\[UnderBracket]178[t] - 
              0.01`\ A\[UnderBracket]178[t]\ Y\[UnderBracket]178[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]179", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]179\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]158[t] + 
              0.1`\ A\[UnderBracket]167[t] + 0.1`\ A\[UnderBracket]168[t] + 
              0.1`\ A\[UnderBracket]169[t] + 0.1`\ A\[UnderBracket]174[t] - 
              1.0999999999999999`\ A\[UnderBracket]179[t] + 
              0.1`\ A\[UnderBracket]187[t] + 0.1`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]192[t] + 
              0.10000000000000003`\ A\[UnderBracket]179[t]\^2\ B\
\[UnderBracket]179[t] - 
              0.01`\ A\[UnderBracket]179[t]\ Y\[UnderBracket]179[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]18", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]18\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]10[t] + 
              0.1`\ A\[UnderBracket]27[t] + 0.1`\ A\[UnderBracket]28[t] + 
              0.1`\ A\[UnderBracket]31[t] + 0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]18[t]\^2\ \
B\[UnderBracket]18[t] + 
              A\[UnderBracket]18[
                  t]\ \((\(-0.7999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]18[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]180", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]180\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]163[t] + 
              0.1`\ A\[UnderBracket]165[t] + 0.1`\ A\[UnderBracket]170[t] + 
              0.1`\ A\[UnderBracket]177[t] - 
              1.0999999999999999`\ A\[UnderBracket]180[t] + 
              0.1`\ A\[UnderBracket]181[t] + 0.1`\ A\[UnderBracket]194[t] + 
              0.1`\ A\[UnderBracket]196[t] + 0.1`\ A\[UnderBracket]204[t] + 
              0.10000000000000003`\ A\[UnderBracket]180[t]\^2\ B\
\[UnderBracket]180[t] - 
              0.01`\ A\[UnderBracket]180[t]\ Y\[UnderBracket]180[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]181", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]181\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]159[t] + 
              0.1`\ A\[UnderBracket]170[t] + 0.1`\ A\[UnderBracket]180[t] - 
              0.8999999999999999`\ A\[UnderBracket]181[t] + 
              0.1`\ A\[UnderBracket]182[t] + 0.1`\ A\[UnderBracket]196[t] + 
              0.1`\ A\[UnderBracket]200[t] + 
              0.10000000000000003`\ A\[UnderBracket]181[t]\^2\ B\
\[UnderBracket]181[t] - 
              0.01`\ A\[UnderBracket]181[t]\ Y\[UnderBracket]181[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]182", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]182\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]159[t] + 
              0.1`\ A\[UnderBracket]171[t] + 0.1`\ A\[UnderBracket]181[t] - 
              0.7`\ A\[UnderBracket]182[t] + 0.1`\ A\[UnderBracket]200[t] + 
              0.10000000000000003`\ A\[UnderBracket]182[t]\^2\ B\
\[UnderBracket]182[t] - 
              0.01`\ A\[UnderBracket]182[t]\ Y\[UnderBracket]182[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]183", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]183\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]162[t] + 
              0.1`\ A\[UnderBracket]166[t] + 0.1`\ A\[UnderBracket]175[t] - 
              0.8999999999999999`\ A\[UnderBracket]183[t] + 
              0.1`\ A\[UnderBracket]184[t] + 0.1`\ A\[UnderBracket]195[t] + 
              0.1`\ A\[UnderBracket]199[t] + 
              0.10000000000000003`\ A\[UnderBracket]183[t]\^2\ B\
\[UnderBracket]183[t] - 
              0.01`\ A\[UnderBracket]183[t]\ Y\[UnderBracket]183[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]184", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]184\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]162[t] + 
              0.1`\ A\[UnderBracket]173[t] + 0.1`\ A\[UnderBracket]183[t] - 
              0.8999999999999999`\ A\[UnderBracket]184[t] + 
              0.1`\ A\[UnderBracket]189[t] + 0.1`\ A\[UnderBracket]195[t] + 
              0.1`\ A\[UnderBracket]202[t] + 
              0.10000000000000003`\ A\[UnderBracket]184[t]\^2\ B\
\[UnderBracket]184[t] - 
              0.01`\ A\[UnderBracket]184[t]\ Y\[UnderBracket]184[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]185", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]185\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]172[t] + 
              0.1`\ A\[UnderBracket]176[t] + 0.1`\ A\[UnderBracket]178[t] - 
              0.8999999999999999`\ A\[UnderBracket]185[t] + 
              0.1`\ A\[UnderBracket]197[t] + 0.1`\ A\[UnderBracket]203[t] + 
              0.1`\ A\[UnderBracket]208[t] + 
              0.10000000000000003`\ A\[UnderBracket]185[t]\^2\ B\
\[UnderBracket]185[t] - 
              0.01`\ A\[UnderBracket]185[t]\ Y\[UnderBracket]185[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]186", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]186\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]160[t] + 
              0.1`\ A\[UnderBracket]161[t] - 
              0.7999999999999999`\ A\[UnderBracket]186[t] + 
              0.1`\ A\[UnderBracket]188[t] + 0.1`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]198[t] + 
              0.10000000000000003`\ A\[UnderBracket]186[t]\^2\ B\
\[UnderBracket]186[t] - 
              0.01`\ A\[UnderBracket]186[t]\ Y\[UnderBracket]186[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]187", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]187\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]174[t] + 
              0.1`\ A\[UnderBracket]179[t] - 
              0.7999999999999999`\ A\[UnderBracket]187[t] + 
              0.1`\ A\[UnderBracket]189[t] + 0.1`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]205[t] + 
              0.10000000000000003`\ A\[UnderBracket]187[t]\^2\ B\
\[UnderBracket]187[t] - 
              0.01`\ A\[UnderBracket]187[t]\ Y\[UnderBracket]187[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]188", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]188\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]145[t] + 
              0.1`\ A\[UnderBracket]160[t] + 0.1`\ A\[UnderBracket]164[t] + 
              0.1`\ A\[UnderBracket]186[t] - 
              0.9999999999999999`\ A\[UnderBracket]188[t] + 
              0.1`\ A\[UnderBracket]198[t] + 0.1`\ A\[UnderBracket]201[t] + 
              0.1`\ A\[UnderBracket]218[t] + 
              0.10000000000000003`\ A\[UnderBracket]188[t]\^2\ B\
\[UnderBracket]188[t] - 
              0.01`\ A\[UnderBracket]188[t]\ Y\[UnderBracket]188[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]189", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]189\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]173[t] + 
              0.1`\ A\[UnderBracket]174[t] + 0.1`\ A\[UnderBracket]184[t] + 
              0.1`\ A\[UnderBracket]187[t] - 
              0.8999999999999999`\ A\[UnderBracket]189[t] + 
              0.1`\ A\[UnderBracket]202[t] + 0.1`\ A\[UnderBracket]205[t] + 
              0.10000000000000003`\ A\[UnderBracket]189[t]\^2\ B\
\[UnderBracket]189[t] - 
              0.01`\ A\[UnderBracket]189[t]\ Y\[UnderBracket]189[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]19", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]19\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]10[t] + 
              0.1`\ A\[UnderBracket]20[t] + 0.1`\ A\[UnderBracket]28[t] + 
              0.1`\ A\[UnderBracket]32[t] + 0.1`\ A\[UnderBracket]38[t] + 
              0.1`\ A\[UnderBracket]40[t] + 
              0.10000000000000003`\ A\[UnderBracket]19[t]\^2\ \
B\[UnderBracket]19[t] + 
              A\[UnderBracket]19[
                  t]\ \((\(-0.8999999999999999`\) - 
                    0.01`\ Y\[UnderBracket]19[t])\))\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]190", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]190\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]161[t] + 
              0.1`\ A\[UnderBracket]175[t] + 0.1`\ A\[UnderBracket]186[t] - 
              0.9999999999999999`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]198[t] + 0.1`\ A\[UnderBracket]199[t] + 
              0.1`\ A\[UnderBracket]207[t] + 0.1`\ A\[UnderBracket]215[t] + 
              0.10000000000000003`\ A\[UnderBracket]190[t]\^2\ B\
\[UnderBracket]190[t] - 
              0.01`\ A\[UnderBracket]190[t]\ Y\[UnderBracket]190[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]191", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]191\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]179[t] + 
              0.1`\ A\[UnderBracket]187[t] - 
              0.8999999999999999`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]192[t] + 0.1`\ A\[UnderBracket]205[t] + 
              0.1`\ A\[UnderBracket]206[t] + 0.1`\ A\[UnderBracket]216[t] + 
              0.10000000000000003`\ A\[UnderBracket]191[t]\^2\ B\
\[UnderBracket]191[t] - 
              0.01`\ A\[UnderBracket]191[t]\ Y\[UnderBracket]191[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]192", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]192\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]169[t] + 
              0.1`\ A\[UnderBracket]179[t] + 0.1`\ A\[UnderBracket]191[t] - 
              0.7999999999999999`\ A\[UnderBracket]192[t] + 
              0.1`\ A\[UnderBracket]193[t] + 0.1`\ A\[UnderBracket]206[t] + 
              0.10000000000000003`\ A\[UnderBracket]192[t]\^2\ B\
\[UnderBracket]192[t] - 
              0.01`\ A\[UnderBracket]192[t]\ Y\[UnderBracket]192[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]193", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]193\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]169[t] + 
              0.1`\ A\[UnderBracket]177[t] + 0.1`\ A\[UnderBracket]192[t] - 
              0.7999999999999999`\ A\[UnderBracket]193[t] + 
              0.1`\ A\[UnderBracket]194[t] + 0.1`\ A\[UnderBracket]206[t] + 
              0.10000000000000003`\ A\[UnderBracket]193[t]\^2\ B\
\[UnderBracket]193[t] - 
              0.01`\ A\[UnderBracket]193[t]\ Y\[UnderBracket]193[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]194", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]194\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]177[t] + 
              0.1`\ A\[UnderBracket]180[t] + 0.1`\ A\[UnderBracket]193[t] - 
              0.7999999999999999`\ A\[UnderBracket]194[t] + 
              0.1`\ A\[UnderBracket]204[t] + 0.1`\ A\[UnderBracket]206[t] + 
              0.10000000000000003`\ A\[UnderBracket]194[t]\^2\ B\
\[UnderBracket]194[t] - 
              0.01`\ A\[UnderBracket]194[t]\ Y\[UnderBracket]194[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]195", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]195\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]183[t] + 
              0.1`\ A\[UnderBracket]184[t] - 
              0.8999999999999999`\ A\[UnderBracket]195[t] + 
              0.1`\ A\[UnderBracket]199[t] + 0.1`\ A\[UnderBracket]202[t] + 
              0.1`\ A\[UnderBracket]213[t] + 0.1`\ A\[UnderBracket]222[t] + 
              0.10000000000000003`\ A\[UnderBracket]195[t]\^2\ B\
\[UnderBracket]195[t] - 
              0.01`\ A\[UnderBracket]195[t]\ Y\[UnderBracket]195[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]196", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]196\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]180[t] + 
              0.1`\ A\[UnderBracket]181[t] - 
              0.8999999999999999`\ A\[UnderBracket]196[t] + 
              0.1`\ A\[UnderBracket]200[t] + 0.1`\ A\[UnderBracket]204[t] + 
              0.1`\ A\[UnderBracket]211[t] + 0.1`\ A\[UnderBracket]214[t] + 
              
              0.10000000000000003`\ A\[UnderBracket]196[t]\^2\ B\
\[UnderBracket]196[t] - 
              0.01`\ A\[UnderBracket]196[t]\ Y\[UnderBracket]196[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]197", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]197\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]176[t] + 
              0.1`\ A\[UnderBracket]185[t] - 
              0.7999999999999999`\ A\[UnderBracket]197[t] + 
              0.1`\ A\[UnderBracket]201[t] + 0.1`\ A\[UnderBracket]208[t] + 
              0.1`\ A\[UnderBracket]209[t] + 
              0.10000000000000003`\ A\[UnderBracket]197[t]\^2\ B\
\[UnderBracket]197[t] - 
              0.01`\ A\[UnderBracket]197[t]\ Y\[UnderBracket]197[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]198", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]198\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]186[t] + 
              0.1`\ A\[UnderBracket]188[t] + 0.1`\ A\[UnderBracket]190[t] - 
              0.7999999999999999`\ A\[UnderBracket]198[t] + 
              0.1`\ A\[UnderBracket]215[t] + 0.1`\ A\[UnderBracket]218[t] + 
              0.10000000000000003`\ A\[UnderBracket]198[t]\^2\ B\
\[UnderBracket]198[t] - 
              0.01`\ A\[UnderBracket]198[t]\ Y\[UnderBracket]198[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]199", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]199\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]175[t] + 
              0.1`\ A\[UnderBracket]183[t] + 0.1`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]195[t] - 
              0.9999999999999999`\ A\[UnderBracket]199[t] + 
              0.1`\ A\[UnderBracket]207[t] + 0.1`\ A\[UnderBracket]212[t] + 
              0.1`\ A\[UnderBracket]222[t] + 
              0.10000000000000003`\ A\[UnderBracket]199[t]\^2\ B\
\[UnderBracket]199[t] - 
              0.01`\ A\[UnderBracket]199[t]\ Y\[UnderBracket]199[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]2", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]2\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]1[t] + 
              0.1`\ A\[UnderBracket]4[t] + 0.1`\ A\[UnderBracket]5[t] + 
              0.1`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]2[t]\^2\ \
B\[UnderBracket]2[t] + 
              A\[UnderBracket]2[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]2[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]20", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]20\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]15[t] + 
              0.1`\ A\[UnderBracket]19[t] - 0.7`\ A\[UnderBracket]20[t] + 
              0.1`\ A\[UnderBracket]34[t] + 0.1`\ A\[UnderBracket]40[t] + 
              0.10000000000000003`\ A\[UnderBracket]20[t]\^2\ \
B\[UnderBracket]20[t] - 
              0.01`\ A\[UnderBracket]20[t]\ Y\[UnderBracket]20[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]200", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]200\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]181[t] + 
              0.1`\ A\[UnderBracket]182[t] + 0.1`\ A\[UnderBracket]196[t] - 
              0.7`\ A\[UnderBracket]200[t] + 0.1`\ A\[UnderBracket]211[t] + 
              0.10000000000000003`\ A\[UnderBracket]200[t]\^2\ B\
\[UnderBracket]200[t] - 
              0.01`\ A\[UnderBracket]200[t]\ Y\[UnderBracket]200[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]201", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]201\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]164[t] + 
              0.1`\ A\[UnderBracket]176[t] + 0.1`\ A\[UnderBracket]188[t] + 
              0.1`\ A\[UnderBracket]197[t] - 
              0.9999999999999999`\ A\[UnderBracket]201[t] + 
              0.1`\ A\[UnderBracket]209[t] + 0.1`\ A\[UnderBracket]218[t] + 
              0.1`\ A\[UnderBracket]220[t] + 
              0.10000000000000003`\ A\[UnderBracket]201[t]\^2\ B\
\[UnderBracket]201[t] - 
              0.01`\ A\[UnderBracket]201[t]\ Y\[UnderBracket]201[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]202", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]202\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]184[t] + 
              0.1`\ A\[UnderBracket]189[t] + 0.1`\ A\[UnderBracket]195[t] - 
              0.8999999999999999`\ A\[UnderBracket]202[t] + 
              0.1`\ A\[UnderBracket]205[t] + 0.1`\ A\[UnderBracket]210[t] + 
              0.1`\ A\[UnderBracket]213[t] + 
              0.10000000000000003`\ A\[UnderBracket]202[t]\^2\ B\
\[UnderBracket]202[t] - 
              0.01`\ A\[UnderBracket]202[t]\ Y\[UnderBracket]202[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]203", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]203\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]178[t] + 
              0.1`\ A\[UnderBracket]185[t] - 0.7`\ A\[UnderBracket]203[t] + 
              0.1`\ A\[UnderBracket]208[t] + 0.1`\ A\[UnderBracket]219[t] + 
              0.10000000000000003`\ A\[UnderBracket]203[t]\^2\ B\
\[UnderBracket]203[t] - 
              0.01`\ A\[UnderBracket]203[t]\ Y\[UnderBracket]203[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]204", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]204\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]180[t] + 
              0.1`\ A\[UnderBracket]194[t] + 0.1`\ A\[UnderBracket]196[t] - 
              0.8999999999999999`\ A\[UnderBracket]204[t] + 
              0.1`\ A\[UnderBracket]206[t] + 0.1`\ A\[UnderBracket]214[t] + 
              0.1`\ A\[UnderBracket]217[t] + 
              0.10000000000000003`\ A\[UnderBracket]204[t]\^2\ B\
\[UnderBracket]204[t] - 
              0.01`\ A\[UnderBracket]204[t]\ Y\[UnderBracket]204[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]205", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]205\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]187[t] + 
              0.1`\ A\[UnderBracket]189[t] + 0.1`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]202[t] - 
              0.9999999999999999`\ A\[UnderBracket]205[t] + 
              0.1`\ A\[UnderBracket]210[t] + 0.1`\ A\[UnderBracket]216[t] + 
              0.1`\ A\[UnderBracket]225[t] + 
              0.10000000000000003`\ A\[UnderBracket]205[t]\^2\ B\
\[UnderBracket]205[t] - 
              0.01`\ A\[UnderBracket]205[t]\ Y\[UnderBracket]205[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]206", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]206\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]192[t] + 0.1`\ A\[UnderBracket]193[t] + 
              0.1`\ A\[UnderBracket]194[t] + 0.1`\ A\[UnderBracket]204[t] - 
              1.0999999999999999`\ A\[UnderBracket]206[t] + 
              0.1`\ A\[UnderBracket]216[t] + 0.1`\ A\[UnderBracket]217[t] + 
              0.1`\ A\[UnderBracket]221[t] + 
              0.10000000000000003`\ A\[UnderBracket]206[t]\^2\ B\
\[UnderBracket]206[t] - 
              0.01`\ A\[UnderBracket]206[t]\ Y\[UnderBracket]206[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]207", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]207\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]199[t] - 0.7`\ A\[UnderBracket]207[t] + 
              0.1`\ A\[UnderBracket]212[t] + 0.1`\ A\[UnderBracket]215[t] + 
              0.10000000000000003`\ A\[UnderBracket]207[t]\^2\ B\
\[UnderBracket]207[t] - 
              0.01`\ A\[UnderBracket]207[t]\ Y\[UnderBracket]207[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]208", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]208\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]185[t] + 
              0.1`\ A\[UnderBracket]197[t] + 0.1`\ A\[UnderBracket]203[t] - 
              0.8999999999999999`\ A\[UnderBracket]208[t] + 
              0.1`\ A\[UnderBracket]209[t] + 0.1`\ A\[UnderBracket]219[t] + 
              0.1`\ A\[UnderBracket]226[t] + 
              0.10000000000000003`\ A\[UnderBracket]208[t]\^2\ B\
\[UnderBracket]208[t] - 
              0.01`\ A\[UnderBracket]208[t]\ Y\[UnderBracket]208[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]209", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]209\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]197[t] + 
              0.1`\ A\[UnderBracket]201[t] + 0.1`\ A\[UnderBracket]208[t] - 
              0.8999999999999999`\ A\[UnderBracket]209[t] + 
              0.1`\ A\[UnderBracket]220[t] + 0.1`\ A\[UnderBracket]226[t] + 
              0.1`\ A\[UnderBracket]227[t] + 
              0.10000000000000003`\ A\[UnderBracket]209[t]\^2\ B\
\[UnderBracket]209[t] - 
              0.01`\ A\[UnderBracket]209[t]\ Y\[UnderBracket]209[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]21", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]21\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]15[t] + 
              0.1`\ A\[UnderBracket]29[t] + 0.1`\ A\[UnderBracket]36[t] + 
              0.1`\ A\[UnderBracket]47[t] + 
              0.10000000000000003`\ A\[UnderBracket]21[t]\^2\ \
B\[UnderBracket]21[t] + 
              A\[UnderBracket]21[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]21[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]210", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]210\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]202[t] + 
              0.1`\ A\[UnderBracket]205[t] - 
              0.7999999999999999`\ A\[UnderBracket]210[t] + 
              0.1`\ A\[UnderBracket]213[t] + 0.1`\ A\[UnderBracket]224[t] + 
              0.1`\ A\[UnderBracket]225[t] + 
              0.10000000000000003`\ A\[UnderBracket]210[t]\^2\ B\
\[UnderBracket]210[t] - 
              0.01`\ A\[UnderBracket]210[t]\ Y\[UnderBracket]210[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]211", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]211\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]196[t] + 
              0.1`\ A\[UnderBracket]200[t] - 0.6`\ A\[UnderBracket]211[t] + 
              0.1`\ A\[UnderBracket]214[t] + 
              0.10000000000000003`\ A\[UnderBracket]211[t]\^2\ B\
\[UnderBracket]211[t] - 
              0.01`\ A\[UnderBracket]211[t]\ Y\[UnderBracket]211[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]212", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]212\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]199[t] + 
              0.1`\ A\[UnderBracket]207[t] - 
              0.8999999999999999`\ A\[UnderBracket]212[t] + 
              0.1`\ A\[UnderBracket]215[t] + 0.1`\ A\[UnderBracket]222[t] + 
              0.1`\ A\[UnderBracket]223[t] + 0.1`\ A\[UnderBracket]230[t] + 
              0.10000000000000003`\ A\[UnderBracket]212[t]\^2\ B\
\[UnderBracket]212[t] - 
              0.01`\ A\[UnderBracket]212[t]\ Y\[UnderBracket]212[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]213", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]213\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]195[t] + 
              0.1`\ A\[UnderBracket]202[t] + 0.1`\ A\[UnderBracket]210[t] - 
              0.7999999999999999`\ A\[UnderBracket]213[t] + 
              0.1`\ A\[UnderBracket]222[t] + 0.1`\ A\[UnderBracket]224[t] + 
              0.10000000000000003`\ A\[UnderBracket]213[t]\^2\ B\
\[UnderBracket]213[t] - 
              0.01`\ A\[UnderBracket]213[t]\ Y\[UnderBracket]213[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]214", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]214\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]196[t] + 
              0.1`\ A\[UnderBracket]204[t] + 0.1`\ A\[UnderBracket]211[t] - 
              0.7`\ A\[UnderBracket]214[t] + 0.1`\ A\[UnderBracket]217[t] + 
              0.10000000000000003`\ A\[UnderBracket]214[t]\^2\ B\
\[UnderBracket]214[t] - 
              0.01`\ A\[UnderBracket]214[t]\ Y\[UnderBracket]214[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]215", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]215\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]190[t] + 
              0.1`\ A\[UnderBracket]198[t] + 0.1`\ A\[UnderBracket]207[t] + 
              0.1`\ A\[UnderBracket]212[t] - 1.3`\ A\[UnderBracket]215[t] + 
              0.1`\ A\[UnderBracket]218[t] + 0.1`\ A\[UnderBracket]228[t] + 
              0.1`\ A\[UnderBracket]230[t] + 0.1`\ A\[UnderBracket]232[t] + 
              0.1`\ A\[UnderBracket]233[t] + 0.1`\ A\[UnderBracket]235[t] + 
              0.10000000000000003`\ A\[UnderBracket]215[t]\^2\ B\
\[UnderBracket]215[t] - 
              0.01`\ A\[UnderBracket]215[t]\ Y\[UnderBracket]215[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]216", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]216\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]191[t] + 
              0.1`\ A\[UnderBracket]205[t] + 0.1`\ A\[UnderBracket]206[t] - 
              0.8999999999999999`\ A\[UnderBracket]216[t] + 
              0.1`\ A\[UnderBracket]221[t] + 0.1`\ A\[UnderBracket]225[t] + 
              0.1`\ A\[UnderBracket]234[t] + 
              0.10000000000000003`\ A\[UnderBracket]216[t]\^2\ B\
\[UnderBracket]216[t] - 
              0.01`\ A\[UnderBracket]216[t]\ Y\[UnderBracket]216[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]217", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]217\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]204[t] + 
              0.1`\ A\[UnderBracket]206[t] + 0.1`\ A\[UnderBracket]214[t] - 
              0.7`\ A\[UnderBracket]217[t] + 0.1`\ A\[UnderBracket]221[t] + 
              0.10000000000000003`\ A\[UnderBracket]217[t]\^2\ B\
\[UnderBracket]217[t] - 
              0.01`\ A\[UnderBracket]217[t]\ Y\[UnderBracket]217[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]218", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]218\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]188[t] + 
              0.1`\ A\[UnderBracket]198[t] + 0.1`\ A\[UnderBracket]201[t] + 
              0.1`\ A\[UnderBracket]215[t] - 
              0.9999999999999999`\ A\[UnderBracket]218[t] + 
              0.1`\ A\[UnderBracket]220[t] + 0.1`\ A\[UnderBracket]228[t] + 
              0.1`\ A\[UnderBracket]229[t] + 
              0.10000000000000003`\ A\[UnderBracket]218[t]\^2\ B\
\[UnderBracket]218[t] - 
              0.01`\ A\[UnderBracket]218[t]\ Y\[UnderBracket]218[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]219", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]219\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]203[t] + 
              0.1`\ A\[UnderBracket]208[t] - 0.7`\ A\[UnderBracket]219[t] + 
              0.1`\ A\[UnderBracket]226[t] + 0.1`\ A\[UnderBracket]237[t] + 
              0.10000000000000003`\ A\[UnderBracket]219[t]\^2\ B\
\[UnderBracket]219[t] - 
              0.01`\ A\[UnderBracket]219[t]\ Y\[UnderBracket]219[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]22", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]22\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]12[t] - 
              0.8999999999999999`\ A\[UnderBracket]22[t] + 
              0.1`\ A\[UnderBracket]24[t] + 0.1`\ A\[UnderBracket]37[t] + 
              0.1`\ A\[UnderBracket]43[t] + 0.1`\ A\[UnderBracket]6[t] + 
              0.10000000000000003`\ A\[UnderBracket]22[t]\^2\ \
B\[UnderBracket]22[t] - 
              0.01`\ A\[UnderBracket]22[t]\ Y\[UnderBracket]22[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]220", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]220\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]201[t] + 
              0.1`\ A\[UnderBracket]209[t] + 0.1`\ A\[UnderBracket]218[t] - 
              0.7999999999999999`\ A\[UnderBracket]220[t] + 
              0.1`\ A\[UnderBracket]227[t] + 0.1`\ A\[UnderBracket]229[t] + 
              0.10000000000000003`\ A\[UnderBracket]220[t]\^2\ B\
\[UnderBracket]220[t] - 
              0.01`\ A\[UnderBracket]220[t]\ Y\[UnderBracket]220[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]221", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]221\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]206[t] + 
              0.1`\ A\[UnderBracket]216[t] + 0.1`\ A\[UnderBracket]217[t] - 
              0.6`\ A\[UnderBracket]221[t] + 
              0.10000000000000003`\ A\[UnderBracket]221[t]\^2\ B\
\[UnderBracket]221[t] - 
              0.01`\ A\[UnderBracket]221[t]\ Y\[UnderBracket]221[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]222", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]222\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]195[t] + 
              0.1`\ A\[UnderBracket]199[t] + 0.1`\ A\[UnderBracket]212[t] + 
              0.1`\ A\[UnderBracket]213[t] - 
              0.9999999999999999`\ A\[UnderBracket]222[t] + 
              0.1`\ A\[UnderBracket]223[t] + 0.1`\ A\[UnderBracket]224[t] + 
              0.1`\ A\[UnderBracket]231[t] + 
              0.10000000000000003`\ A\[UnderBracket]222[t]\^2\ B\
\[UnderBracket]222[t] - 
              0.01`\ A\[UnderBracket]222[t]\ Y\[UnderBracket]222[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]223", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]223\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]212[t] + 
              0.1`\ A\[UnderBracket]222[t] - 
              0.8999999999999999`\ A\[UnderBracket]223[t] + 
              0.1`\ A\[UnderBracket]230[t] + 0.1`\ A\[UnderBracket]231[t] + 
              0.1`\ A\[UnderBracket]236[t] + 0.1`\ A\[UnderBracket]238[t] + 
              0.10000000000000003`\ A\[UnderBracket]223[t]\^2\ B\
\[UnderBracket]223[t] - 
              0.01`\ A\[UnderBracket]223[t]\ Y\[UnderBracket]223[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]224", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]224\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]210[t] + 
              0.1`\ A\[UnderBracket]213[t] + 0.1`\ A\[UnderBracket]222[t] - 
              0.7999999999999999`\ A\[UnderBracket]224[t] + 
              0.1`\ A\[UnderBracket]225[t] + 0.1`\ A\[UnderBracket]231[t] + 
              0.10000000000000003`\ A\[UnderBracket]224[t]\^2\ B\
\[UnderBracket]224[t] - 
              0.01`\ A\[UnderBracket]224[t]\ Y\[UnderBracket]224[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]225", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]225\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]205[t] + 
              0.1`\ A\[UnderBracket]210[t] + 0.1`\ A\[UnderBracket]216[t] + 
              0.1`\ A\[UnderBracket]224[t] - 
              0.8999999999999999`\ A\[UnderBracket]225[t] + 
              0.1`\ A\[UnderBracket]231[t] + 0.1`\ A\[UnderBracket]234[t] + 
              0.10000000000000003`\ A\[UnderBracket]225[t]\^2\ B\
\[UnderBracket]225[t] - 
              0.01`\ A\[UnderBracket]225[t]\ Y\[UnderBracket]225[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]226", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]226\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]208[t] + 
              0.1`\ A\[UnderBracket]209[t] + 0.1`\ A\[UnderBracket]219[t] - 
              0.8999999999999999`\ A\[UnderBracket]226[t] + 
              0.1`\ A\[UnderBracket]227[t] + 0.1`\ A\[UnderBracket]237[t] + 
              0.1`\ A\[UnderBracket]239[t] + 
              0.10000000000000003`\ A\[UnderBracket]226[t]\^2\ B\
\[UnderBracket]226[t] - 
              0.01`\ A\[UnderBracket]226[t]\ Y\[UnderBracket]226[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]227", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]227\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]209[t] + 
              0.1`\ A\[UnderBracket]220[t] + 0.1`\ A\[UnderBracket]226[t] - 
              0.7999999999999999`\ A\[UnderBracket]227[t] + 
              0.1`\ A\[UnderBracket]229[t] + 0.1`\ A\[UnderBracket]239[t] + 
              0.10000000000000003`\ A\[UnderBracket]227[t]\^2\ B\
\[UnderBracket]227[t] - 
              0.01`\ A\[UnderBracket]227[t]\ Y\[UnderBracket]227[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]228", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]228\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]215[t] + 
              0.1`\ A\[UnderBracket]218[t] - 
              0.7999999999999999`\ A\[UnderBracket]228[t] + 
              0.1`\ A\[UnderBracket]229[t] + 0.1`\ A\[UnderBracket]235[t] + 
              0.1`\ A\[UnderBracket]240[t] + 
              0.10000000000000003`\ A\[UnderBracket]228[t]\^2\ B\
\[UnderBracket]228[t] - 
              0.01`\ A\[UnderBracket]228[t]\ Y\[UnderBracket]228[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]229", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]229\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]218[t] + 
              0.1`\ A\[UnderBracket]220[t] + 0.1`\ A\[UnderBracket]227[t] + 
              0.1`\ A\[UnderBracket]228[t] - 
              0.9999999999999999`\ A\[UnderBracket]229[t] + 
              0.1`\ A\[UnderBracket]239[t] + 0.1`\ A\[UnderBracket]240[t] + 
              0.1`\ A\[UnderBracket]242[t] + 
              0.10000000000000003`\ A\[UnderBracket]229[t]\^2\ B\
\[UnderBracket]229[t] - 
              0.01`\ A\[UnderBracket]229[t]\ Y\[UnderBracket]229[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]23", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]23\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]14[t] + 
              0.1`\ A\[UnderBracket]17[t] - 
              0.7999999999999999`\ A\[UnderBracket]23[t] + 
              0.1`\ A\[UnderBracket]33[t] + 0.1`\ A\[UnderBracket]45[t] + 
              0.1`\ A\[UnderBracket]54[t] + 
              0.10000000000000003`\ A\[UnderBracket]23[t]\^2\ \
B\[UnderBracket]23[t] - 
              0.01`\ A\[UnderBracket]23[t]\ Y\[UnderBracket]23[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]230", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]230\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]212[t] + 
              0.1`\ A\[UnderBracket]215[t] + 0.1`\ A\[UnderBracket]223[t] - 
              0.8999999999999999`\ A\[UnderBracket]230[t] + 
              0.1`\ A\[UnderBracket]232[t] + 0.1`\ A\[UnderBracket]236[t] + 
              0.1`\ A\[UnderBracket]245[t] + 
              0.10000000000000003`\ A\[UnderBracket]230[t]\^2\ B\
\[UnderBracket]230[t] - 
              0.01`\ A\[UnderBracket]230[t]\ Y\[UnderBracket]230[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]231", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]231\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]222[t] + 
              0.1`\ A\[UnderBracket]223[t] + 0.1`\ A\[UnderBracket]224[t] + 
              0.1`\ A\[UnderBracket]225[t] - 
              0.9999999999999999`\ A\[UnderBracket]231[t] + 
              0.1`\ A\[UnderBracket]234[t] + 0.1`\ A\[UnderBracket]238[t] + 
              0.1`\ A\[UnderBracket]244[t] + 
              0.10000000000000003`\ A\[UnderBracket]231[t]\^2\ B\
\[UnderBracket]231[t] - 
              0.01`\ A\[UnderBracket]231[t]\ Y\[UnderBracket]231[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]232", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]232\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]215[t] + 
              0.1`\ A\[UnderBracket]230[t] - 0.7`\ A\[UnderBracket]232[t] + 
              0.1`\ A\[UnderBracket]233[t] + 0.1`\ A\[UnderBracket]245[t] + 
              0.10000000000000003`\ A\[UnderBracket]232[t]\^2\ B\
\[UnderBracket]232[t] - 
              0.01`\ A\[UnderBracket]232[t]\ Y\[UnderBracket]232[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]233", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]233\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]215[t] + 
              0.1`\ A\[UnderBracket]232[t] - 
              0.7999999999999999`\ A\[UnderBracket]233[t] + 
              0.1`\ A\[UnderBracket]235[t] + 0.1`\ A\[UnderBracket]241[t] + 
              0.1`\ A\[UnderBracket]245[t] + 
              0.10000000000000003`\ A\[UnderBracket]233[t]\^2\ B\
\[UnderBracket]233[t] - 
              0.01`\ A\[UnderBracket]233[t]\ Y\[UnderBracket]233[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]234", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]234\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]216[t] + 
              0.1`\ A\[UnderBracket]225[t] + 0.1`\ A\[UnderBracket]231[t] - 
              0.7`\ A\[UnderBracket]234[t] + 0.1`\ A\[UnderBracket]244[t] + 
              0.10000000000000003`\ A\[UnderBracket]234[t]\^2\ B\
\[UnderBracket]234[t] - 
              0.01`\ A\[UnderBracket]234[t]\ Y\[UnderBracket]234[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]235", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]235\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]215[t] + 
              0.1`\ A\[UnderBracket]228[t] + 0.1`\ A\[UnderBracket]233[t] - 
              0.8999999999999999`\ A\[UnderBracket]235[t] + 
              0.1`\ A\[UnderBracket]240[t] + 0.1`\ A\[UnderBracket]241[t] + 
              0.1`\ A\[UnderBracket]243[t] + 
              0.10000000000000003`\ A\[UnderBracket]235[t]\^2\ B\
\[UnderBracket]235[t] - 
              0.01`\ A\[UnderBracket]235[t]\ Y\[UnderBracket]235[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]236", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]236\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]223[t] + 
              0.1`\ A\[UnderBracket]230[t] - 
              0.7999999999999999`\ A\[UnderBracket]236[t] + 
              0.1`\ A\[UnderBracket]238[t] + 0.1`\ A\[UnderBracket]245[t] + 
              0.1`\ A\[UnderBracket]248[t] + 
              0.10000000000000003`\ A\[UnderBracket]236[t]\^2\ B\
\[UnderBracket]236[t] - 
              0.01`\ A\[UnderBracket]236[t]\ Y\[UnderBracket]236[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]237", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]237\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]219[t] + 
              0.1`\ A\[UnderBracket]226[t] - 0.7`\ A\[UnderBracket]237[t] + 
              0.1`\ A\[UnderBracket]239[t] + 0.1`\ A\[UnderBracket]249[t] + 
              0.10000000000000003`\ A\[UnderBracket]237[t]\^2\ B\
\[UnderBracket]237[t] - 
              0.01`\ A\[UnderBracket]237[t]\ Y\[UnderBracket]237[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]238", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]238\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]223[t] + 
              0.1`\ A\[UnderBracket]231[t] + 0.1`\ A\[UnderBracket]236[t] - 
              0.8999999999999999`\ A\[UnderBracket]238[t] + 
              0.1`\ A\[UnderBracket]244[t] + 0.1`\ A\[UnderBracket]246[t] + 
              0.1`\ A\[UnderBracket]248[t] + 
              0.10000000000000003`\ A\[UnderBracket]238[t]\^2\ B\
\[UnderBracket]238[t] - 
              0.01`\ A\[UnderBracket]238[t]\ Y\[UnderBracket]238[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]239", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]239\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]226[t] + 
              0.1`\ A\[UnderBracket]227[t] + 0.1`\ A\[UnderBracket]229[t] + 
              0.1`\ A\[UnderBracket]237[t] - 
              0.9999999999999999`\ A\[UnderBracket]239[t] + 
              0.1`\ A\[UnderBracket]242[t] + 0.1`\ A\[UnderBracket]249[t] + 
              0.1`\ A\[UnderBracket]250[t] + 
              0.10000000000000003`\ A\[UnderBracket]239[t]\^2\ B\
\[UnderBracket]239[t] - 
              0.01`\ A\[UnderBracket]239[t]\ Y\[UnderBracket]239[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]24", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]24\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]22[t] - 0.7`\ A\[UnderBracket]24[t] + 
              0.1`\ A\[UnderBracket]25[t] + 0.1`\ A\[UnderBracket]37[t] + 
              0.10000000000000003`\ A\[UnderBracket]24[t]\^2\ \
B\[UnderBracket]24[t] - 
              0.01`\ A\[UnderBracket]24[t]\ Y\[UnderBracket]24[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]240", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]240\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]228[t] + 
              0.1`\ A\[UnderBracket]229[t] + 0.1`\ A\[UnderBracket]235[t] - 
              0.8999999999999999`\ A\[UnderBracket]240[t] + 
              0.1`\ A\[UnderBracket]242[t] + 0.1`\ A\[UnderBracket]243[t] + 
              0.1`\ A\[UnderBracket]247[t] + 
              0.10000000000000003`\ A\[UnderBracket]240[t]\^2\ B\
\[UnderBracket]240[t] - 
              0.01`\ A\[UnderBracket]240[t]\ Y\[UnderBracket]240[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]241", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]241\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]233[t] + 
              0.1`\ A\[UnderBracket]235[t] - 
              0.9999999999999999`\ A\[UnderBracket]241[t] + 
              0.1`\ A\[UnderBracket]243[t] + 0.1`\ A\[UnderBracket]245[t] + 
              0.1`\ A\[UnderBracket]247[t] + 0.1`\ A\[UnderBracket]251[t] + 
              0.1`\ A\[UnderBracket]253[t] + 
              0.10000000000000003`\ A\[UnderBracket]241[t]\^2\ B\
\[UnderBracket]241[t] - 
              0.01`\ A\[UnderBracket]241[t]\ Y\[UnderBracket]241[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]242", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]242\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]229[t] + 
              0.1`\ A\[UnderBracket]239[t] + 0.1`\ A\[UnderBracket]240[t] - 
              0.8999999999999999`\ A\[UnderBracket]242[t] + 
              0.1`\ A\[UnderBracket]247[t] + 0.1`\ A\[UnderBracket]250[t] + 
              0.1`\ A\[UnderBracket]252[t] + 
              0.10000000000000003`\ A\[UnderBracket]242[t]\^2\ B\
\[UnderBracket]242[t] - 
              0.01`\ A\[UnderBracket]242[t]\ Y\[UnderBracket]242[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]243", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]243\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]235[t] + 
              0.1`\ A\[UnderBracket]240[t] + 0.1`\ A\[UnderBracket]241[t] - 
              0.7`\ A\[UnderBracket]243[t] + 0.1`\ A\[UnderBracket]247[t] + 
              0.10000000000000003`\ A\[UnderBracket]243[t]\^2\ B\
\[UnderBracket]243[t] - 
              0.01`\ A\[UnderBracket]243[t]\ Y\[UnderBracket]243[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]244", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]244\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]231[t] + 
              0.1`\ A\[UnderBracket]234[t] + 0.1`\ A\[UnderBracket]238[t] - 
              0.7`\ A\[UnderBracket]244[t] + 0.1`\ A\[UnderBracket]246[t] + 
              0.10000000000000003`\ A\[UnderBracket]244[t]\^2\ B\
\[UnderBracket]244[t] - 
              0.01`\ A\[UnderBracket]244[t]\ Y\[UnderBracket]244[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]245", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]245\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]230[t] + 
              0.1`\ A\[UnderBracket]232[t] + 0.1`\ A\[UnderBracket]233[t] + 
              0.1`\ A\[UnderBracket]236[t] + 0.1`\ A\[UnderBracket]241[t] - 
              0.9999999999999999`\ A\[UnderBracket]245[t] + 
              0.1`\ A\[UnderBracket]248[t] + 0.1`\ A\[UnderBracket]251[t] + 
              0.10000000000000003`\ A\[UnderBracket]245[t]\^2\ B\
\[UnderBracket]245[t] - 
              0.01`\ A\[UnderBracket]245[t]\ Y\[UnderBracket]245[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]246", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]246\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]238[t] + 
              0.1`\ A\[UnderBracket]244[t] - 0.6`\ A\[UnderBracket]246[t] + 
              0.1`\ A\[UnderBracket]248[t] + 
              0.10000000000000003`\ A\[UnderBracket]246[t]\^2\ B\
\[UnderBracket]246[t] - 
              0.01`\ A\[UnderBracket]246[t]\ Y\[UnderBracket]246[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]247", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]247\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]240[t] + 
              0.1`\ A\[UnderBracket]241[t] + 0.1`\ A\[UnderBracket]242[t] + 
              0.1`\ A\[UnderBracket]243[t] - 
              0.8999999999999999`\ A\[UnderBracket]247[t] + 
              0.1`\ A\[UnderBracket]252[t] + 0.1`\ A\[UnderBracket]253[t] + 
              0.10000000000000003`\ A\[UnderBracket]247[t]\^2\ B\
\[UnderBracket]247[t] - 
              0.01`\ A\[UnderBracket]247[t]\ Y\[UnderBracket]247[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]248", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]248\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]236[t] + 
              0.1`\ A\[UnderBracket]238[t] + 0.1`\ A\[UnderBracket]245[t] + 
              0.1`\ A\[UnderBracket]246[t] - 0.7`\ A\[UnderBracket]248[t] + 
              0.10000000000000003`\ A\[UnderBracket]248[t]\^2\ B\
\[UnderBracket]248[t] - 
              0.01`\ A\[UnderBracket]248[t]\ Y\[UnderBracket]248[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]249", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]249\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]237[t] + 
              0.1`\ A\[UnderBracket]239[t] - 0.6`\ A\[UnderBracket]249[t] + 
              0.1`\ A\[UnderBracket]250[t] + 
              0.10000000000000003`\ A\[UnderBracket]249[t]\^2\ B\
\[UnderBracket]249[t] - 
              0.01`\ A\[UnderBracket]249[t]\ Y\[UnderBracket]249[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]25", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]25\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]24[t] - 
              0.7999999999999999`\ A\[UnderBracket]25[t] + 
              0.1`\ A\[UnderBracket]26[t] + 0.1`\ A\[UnderBracket]37[t] + 
              0.1`\ A\[UnderBracket]39[t] + 
              0.10000000000000003`\ A\[UnderBracket]25[t]\^2\ \
B\[UnderBracket]25[t] - 
              0.01`\ A\[UnderBracket]25[t]\ Y\[UnderBracket]25[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]250", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]250\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]239[t] + 
              0.1`\ A\[UnderBracket]242[t] + 0.1`\ A\[UnderBracket]249[t] - 
              0.7`\ A\[UnderBracket]250[t] + 0.1`\ A\[UnderBracket]252[t] + 
              0.10000000000000003`\ A\[UnderBracket]250[t]\^2\ B\
\[UnderBracket]250[t] - 
              0.01`\ A\[UnderBracket]250[t]\ Y\[UnderBracket]250[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]251", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]251\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]241[t] + 
              0.1`\ A\[UnderBracket]245[t] - 0.6`\ A\[UnderBracket]251[t] + 
              0.1`\ A\[UnderBracket]253[t] + 
              0.10000000000000003`\ A\[UnderBracket]251[t]\^2\ B\
\[UnderBracket]251[t] - 
              0.01`\ A\[UnderBracket]251[t]\ Y\[UnderBracket]251[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]252", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]252\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]242[t] + 
              0.1`\ A\[UnderBracket]247[t] + 0.1`\ A\[UnderBracket]250[t] - 
              0.7`\ A\[UnderBracket]252[t] + 0.1`\ A\[UnderBracket]253[t] + 
              0.10000000000000003`\ A\[UnderBracket]252[t]\^2\ B\
\[UnderBracket]252[t] - 
              0.01`\ A\[UnderBracket]252[t]\ Y\[UnderBracket]252[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]253", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]253\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]241[t] + 
              0.1`\ A\[UnderBracket]247[t] + 0.1`\ A\[UnderBracket]251[t] + 
              0.1`\ A\[UnderBracket]252[t] - 0.7`\ A\[UnderBracket]253[t] + 
              0.10000000000000003`\ A\[UnderBracket]253[t]\^2\ B\
\[UnderBracket]253[t] - 
              0.01`\ A\[UnderBracket]253[t]\ Y\[UnderBracket]253[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]26", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]26\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]13[t] + 0.1`\ A\[UnderBracket]25[t] - 
              0.7`\ A\[UnderBracket]26[t] + 0.1`\ A\[UnderBracket]39[t] + 
              
              0.10000000000000003`\ A\[UnderBracket]26[t]\^2\ \
B\[UnderBracket]26[t] - 
              0.01`\ A\[UnderBracket]26[t]\ Y\[UnderBracket]26[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]27", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]27\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]14[t] + 
              0.1`\ A\[UnderBracket]18[t] - 
              0.7999999999999999`\ A\[UnderBracket]27[t] + 
              0.1`\ A\[UnderBracket]31[t] + 0.1`\ A\[UnderBracket]33[t] + 
              0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]27[t]\^2\ \
B\[UnderBracket]27[t] - 
              0.01`\ A\[UnderBracket]27[t]\ Y\[UnderBracket]27[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]28", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]28\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]10[t] + 
              0.1`\ A\[UnderBracket]18[t] + 0.1`\ A\[UnderBracket]19[t] - 
              0.8999999999999999`\ A\[UnderBracket]28[t] + 
              0.1`\ A\[UnderBracket]31[t] + 0.1`\ A\[UnderBracket]32[t] + 
              0.1`\ A\[UnderBracket]44[t] + 
              0.10000000000000003`\ A\[UnderBracket]28[t]\^2\ \
B\[UnderBracket]28[t] - 
              0.01`\ A\[UnderBracket]28[t]\ Y\[UnderBracket]28[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]29", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]29\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]15[t] + 
              0.1`\ A\[UnderBracket]21[t] - 
              0.8999999999999999`\ A\[UnderBracket]29[t] + 
              0.1`\ A\[UnderBracket]35[t] + 0.1`\ A\[UnderBracket]47[t] + 
              0.1`\ A\[UnderBracket]49[t] + 0.1`\ A\[UnderBracket]57[t] + 
              0.10000000000000003`\ A\[UnderBracket]29[t]\^2\ \
B\[UnderBracket]29[t] - 
              0.01`\ A\[UnderBracket]29[t]\ Y\[UnderBracket]29[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]3", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]3\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]1[t] + 
              0.1`\ A\[UnderBracket]6[t] + 0.1`\ A\[UnderBracket]7[t] + 
              0.1`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]3[t]\^2\ \
B\[UnderBracket]3[t] + 
              A\[UnderBracket]3[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]3[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]30", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]30\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]12[t] + 
              0.1`\ A\[UnderBracket]16[t] - 0.7`\ A\[UnderBracket]30[t] + 
              0.1`\ A\[UnderBracket]43[t] + 0.1`\ A\[UnderBracket]50[t] + 
              0.10000000000000003`\ A\[UnderBracket]30[t]\^2\ \
B\[UnderBracket]30[t] - 
              0.01`\ A\[UnderBracket]30[t]\ Y\[UnderBracket]30[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]31", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]31\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]18[t] + 
              0.1`\ A\[UnderBracket]27[t] + 0.1`\ A\[UnderBracket]28[t] - 
              0.8999999999999999`\ A\[UnderBracket]31[t] + 
              0.1`\ A\[UnderBracket]33[t] + 0.1`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]46[t] + 
              0.10000000000000003`\ A\[UnderBracket]31[t]\^2\ \
B\[UnderBracket]31[t] - 
              0.01`\ A\[UnderBracket]31[t]\ Y\[UnderBracket]31[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]32", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]32\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]19[t] + 
              0.1`\ A\[UnderBracket]28[t] - 0.7`\ A\[UnderBracket]32[t] + 
              0.1`\ A\[UnderBracket]38[t] + 0.1`\ A\[UnderBracket]44[t] + 
              0.10000000000000003`\ A\[UnderBracket]32[t]\^2\ \
B\[UnderBracket]32[t] - 
              0.01`\ A\[UnderBracket]32[t]\ Y\[UnderBracket]32[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]33", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]33\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]14[t] + 
              0.1`\ A\[UnderBracket]23[t] + 0.1`\ A\[UnderBracket]27[t] + 
              0.1`\ A\[UnderBracket]31[t] - 
              0.8999999999999999`\ A\[UnderBracket]33[t] + 
              0.1`\ A\[UnderBracket]45[t] + 0.1`\ A\[UnderBracket]46[t] + 
              0.10000000000000003`\ A\[UnderBracket]33[t]\^2\ \
B\[UnderBracket]33[t] - 
              0.01`\ A\[UnderBracket]33[t]\ Y\[UnderBracket]33[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]34", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]34\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]15[t] + 
              0.1`\ A\[UnderBracket]20[t] - 
              0.9999999999999999`\ A\[UnderBracket]34[t] + 
              0.1`\ A\[UnderBracket]35[t] + 0.1`\ A\[UnderBracket]40[t] + 
              0.1`\ A\[UnderBracket]41[t] + 0.1`\ A\[UnderBracket]51[t] + 
              0.1`\ A\[UnderBracket]52[t] + 
              0.10000000000000003`\ A\[UnderBracket]34[t]\^2\ \
B\[UnderBracket]34[t] - 
              0.01`\ A\[UnderBracket]34[t]\ Y\[UnderBracket]34[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]35", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]35\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]15[t] + 
              0.1`\ A\[UnderBracket]29[t] + 0.1`\ A\[UnderBracket]34[t] - 
              0.8999999999999999`\ A\[UnderBracket]35[t] + 
              0.1`\ A\[UnderBracket]41[t] + 0.1`\ A\[UnderBracket]57[t] + 
              0.1`\ A\[UnderBracket]60[t] + 
              0.10000000000000003`\ A\[UnderBracket]35[t]\^2\ \
B\[UnderBracket]35[t] - 
              0.01`\ A\[UnderBracket]35[t]\ Y\[UnderBracket]35[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]36", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]36\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]21[t] + 
              0.1`\ A\[UnderBracket]42[t] + 0.1`\ A\[UnderBracket]47[t] + 
              0.1`\ A\[UnderBracket]48[t] + 
              0.10000000000000003`\ A\[UnderBracket]36[t]\^2\ \
B\[UnderBracket]36[t] + 
              A\[UnderBracket]36[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]36[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]37", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]37\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]22[t] + 
              0.1`\ A\[UnderBracket]24[t] + 0.1`\ A\[UnderBracket]25[t] - 
              0.8999999999999999`\ A\[UnderBracket]37[t] + 
              0.1`\ A\[UnderBracket]39[t] + 0.1`\ A\[UnderBracket]43[t] + 
              0.1`\ A\[UnderBracket]59[t] + 
              0.10000000000000003`\ A\[UnderBracket]37[t]\^2\ \
B\[UnderBracket]37[t] - 
              0.01`\ A\[UnderBracket]37[t]\ Y\[UnderBracket]37[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]38", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]38\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]19[t] + 
              0.1`\ A\[UnderBracket]32[t] - 
              0.8999999999999999`\ A\[UnderBracket]38[t] + 
              0.1`\ A\[UnderBracket]40[t] + 0.1`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]56[t] + 0.1`\ A\[UnderBracket]67[t] + 
              0.10000000000000003`\ A\[UnderBracket]38[t]\^2\ \
B\[UnderBracket]38[t] - 
              0.01`\ A\[UnderBracket]38[t]\ Y\[UnderBracket]38[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]39", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]39\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]13[t] + 
              0.1`\ A\[UnderBracket]17[t] + 0.1`\ A\[UnderBracket]25[t] + 
              0.1`\ A\[UnderBracket]26[t] + 0.1`\ A\[UnderBracket]37[t] - 
              1.0999999999999999`\ A\[UnderBracket]39[t] + 
              0.1`\ A\[UnderBracket]53[t] + 0.1`\ A\[UnderBracket]59[t] + 
              0.1`\ A\[UnderBracket]65[t] + 
              0.10000000000000003`\ A\[UnderBracket]39[t]\^2\ \
B\[UnderBracket]39[t] - 
              0.01`\ A\[UnderBracket]39[t]\ Y\[UnderBracket]39[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]4", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]4\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]10[t] + 
              0.1`\ A\[UnderBracket]2[t] - 0.7`\ A\[UnderBracket]4[t] + 
              0.1`\ A\[UnderBracket]5[t] + 0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]4[t]\^2\ \
B\[UnderBracket]4[t] - 
              0.01`\ A\[UnderBracket]4[t]\ Y\[UnderBracket]4[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]40", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]40\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]19[t] + 
              0.1`\ A\[UnderBracket]20[t] + 0.1`\ A\[UnderBracket]34[t] + 
              0.1`\ A\[UnderBracket]38[t] - 
              0.8999999999999999`\ A\[UnderBracket]40[t] + 
              0.1`\ A\[UnderBracket]51[t] + 0.1`\ A\[UnderBracket]56[t] + 
              0.10000000000000003`\ A\[UnderBracket]40[t]\^2\ \
B\[UnderBracket]40[t] - 
              0.01`\ A\[UnderBracket]40[t]\ Y\[UnderBracket]40[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]41", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]41\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]34[t] + 
              0.1`\ A\[UnderBracket]35[t] - 0.7`\ A\[UnderBracket]41[t] + 
              0.1`\ A\[UnderBracket]52[t] + 0.1`\ A\[UnderBracket]60[t] + 
              0.10000000000000003`\ A\[UnderBracket]41[t]\^2\ \
B\[UnderBracket]41[t] - 
              0.01`\ A\[UnderBracket]41[t]\ Y\[UnderBracket]41[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]42", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]42\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]36[t] + 
              0.1`\ A\[UnderBracket]48[t] + 0.1`\ A\[UnderBracket]58[t] + 
              0.10000000000000003`\ A\[UnderBracket]42[t]\^2\ \
B\[UnderBracket]42[t] + 
              A\[UnderBracket]42[
                  t]\ \((\(-0.6`\) - 0.01`\ Y\[UnderBracket]42[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]43", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]43\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]22[t] + 
              0.1`\ A\[UnderBracket]30[t] + 0.1`\ A\[UnderBracket]37[t] - 
              0.9999999999999999`\ A\[UnderBracket]43[t] + 
              0.1`\ A\[UnderBracket]50[t] + 0.1`\ A\[UnderBracket]59[t] + 
              0.1`\ A\[UnderBracket]61[t] + 0.1`\ A\[UnderBracket]64[t] + 
              0.10000000000000003`\ A\[UnderBracket]43[t]\^2\ \
B\[UnderBracket]43[t] - 
              0.01`\ A\[UnderBracket]43[t]\ Y\[UnderBracket]43[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]44", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]44\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]28[t] + 
              0.1`\ A\[UnderBracket]31[t] + 0.1`\ A\[UnderBracket]32[t] + 
              0.1`\ A\[UnderBracket]38[t] - 
              1.0999999999999999`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]46[t] + 0.1`\ A\[UnderBracket]55[t] + 
              0.1`\ A\[UnderBracket]66[t] + 0.1`\ A\[UnderBracket]67[t] + 
              0.10000000000000003`\ A\[UnderBracket]44[t]\^2\ \
B\[UnderBracket]44[t] - 
              0.01`\ A\[UnderBracket]44[t]\ Y\[UnderBracket]44[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]45", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]45\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]23[t] + 
              0.1`\ A\[UnderBracket]33[t] - 
              0.7999999999999999`\ A\[UnderBracket]45[t] + 
              0.1`\ A\[UnderBracket]46[t] + 0.1`\ A\[UnderBracket]54[t] + 
              0.1`\ A\[UnderBracket]75[t] + 
              0.10000000000000003`\ A\[UnderBracket]45[t]\^2\ \
B\[UnderBracket]45[t] - 
              0.01`\ A\[UnderBracket]45[t]\ Y\[UnderBracket]45[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]46", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]46\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]31[t] + 
              0.1`\ A\[UnderBracket]33[t] + 0.1`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]45[t] - 
              0.9999999999999999`\ A\[UnderBracket]46[t] + 
              0.1`\ A\[UnderBracket]55[t] + 0.1`\ A\[UnderBracket]68[t] + 
              0.1`\ A\[UnderBracket]69[t] + 
              0.10000000000000003`\ A\[UnderBracket]46[t]\^2\ \
B\[UnderBracket]46[t] - 
              0.01`\ A\[UnderBracket]46[t]\ Y\[UnderBracket]46[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]47", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]47\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]21[t] + 
              0.1`\ A\[UnderBracket]29[t] + 0.1`\ A\[UnderBracket]36[t] - 
              0.8999999999999999`\ A\[UnderBracket]47[t] + 
              0.1`\ A\[UnderBracket]48[t] + 0.1`\ A\[UnderBracket]49[t] + 
              0.1`\ A\[UnderBracket]63[t] + 
              0.10000000000000003`\ A\[UnderBracket]47[t]\^2\ \
B\[UnderBracket]47[t] - 
              0.01`\ A\[UnderBracket]47[t]\ Y\[UnderBracket]47[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]48", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]48\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]36[t] + 
              0.1`\ A\[UnderBracket]42[t] + 0.1`\ A\[UnderBracket]47[t] - 
              0.9999999999999999`\ A\[UnderBracket]48[t] + 
              0.1`\ A\[UnderBracket]58[t] + 0.1`\ A\[UnderBracket]63[t] + 
              0.1`\ A\[UnderBracket]73[t] + 0.1`\ A\[UnderBracket]77[t] + 
              0.10000000000000003`\ A\[UnderBracket]48[t]\^2\ \
B\[UnderBracket]48[t] - 
              0.01`\ A\[UnderBracket]48[t]\ Y\[UnderBracket]48[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]49", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]49\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]29[t] + 
              0.1`\ A\[UnderBracket]47[t] - 
              0.7999999999999999`\ A\[UnderBracket]49[t] + 
              0.1`\ A\[UnderBracket]57[t] + 0.1`\ A\[UnderBracket]63[t] + 
              0.1`\ A\[UnderBracket]76[t] + 
              0.10000000000000003`\ A\[UnderBracket]49[t]\^2\ \
B\[UnderBracket]49[t] - 
              0.01`\ A\[UnderBracket]49[t]\ Y\[UnderBracket]49[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]5", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]5\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]14[t] + 
              0.1`\ A\[UnderBracket]2[t] + 0.1`\ A\[UnderBracket]4[t] - 
              0.7999999999999999`\ A\[UnderBracket]5[t] + 
              0.1`\ A\[UnderBracket]8[t] + 0.1`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]5[t]\^2\ \
B\[UnderBracket]5[t] - 
              0.01`\ A\[UnderBracket]5[t]\ Y\[UnderBracket]5[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]50", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]50\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]30[t] + 
              0.1`\ A\[UnderBracket]43[t] - 0.7`\ A\[UnderBracket]50[t] + 
              0.1`\ A\[UnderBracket]61[t] + 0.1`\ A\[UnderBracket]82[t] + 
              0.10000000000000003`\ A\[UnderBracket]50[t]\^2\ \
B\[UnderBracket]50[t] - 
              0.01`\ A\[UnderBracket]50[t]\ Y\[UnderBracket]50[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]51", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]51\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]34[t] + 
              0.1`\ A\[UnderBracket]40[t] - 
              0.9999999999999999`\ A\[UnderBracket]51[t] + 
              0.1`\ A\[UnderBracket]52[t] + 0.1`\ A\[UnderBracket]56[t] + 
              0.1`\ A\[UnderBracket]71[t] + 0.1`\ A\[UnderBracket]72[t] + 
              0.1`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]51[t]\^2\ \
B\[UnderBracket]51[t] - 
              0.01`\ A\[UnderBracket]51[t]\ Y\[UnderBracket]51[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]52", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]52\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]34[t] + 
              0.1`\ A\[UnderBracket]41[t] + 0.1`\ A\[UnderBracket]51[t] - 
              0.7999999999999999`\ A\[UnderBracket]52[t] + 
              0.1`\ A\[UnderBracket]60[t] + 0.1`\ A\[UnderBracket]72[t] + 
              0.10000000000000003`\ A\[UnderBracket]52[t]\^2\ \
B\[UnderBracket]52[t] - 
              0.01`\ A\[UnderBracket]52[t]\ Y\[UnderBracket]52[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]53", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]53\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]17[t] + 
              0.1`\ A\[UnderBracket]39[t] - 
              0.8999999999999999`\ A\[UnderBracket]53[t] + 
              0.1`\ A\[UnderBracket]54[t] + 0.1`\ A\[UnderBracket]65[t] + 
              0.1`\ A\[UnderBracket]70[t] + 0.1`\ A\[UnderBracket]74[t] + 
              0.10000000000000003`\ A\[UnderBracket]53[t]\^2\ \
B\[UnderBracket]53[t] - 
              0.01`\ A\[UnderBracket]53[t]\ Y\[UnderBracket]53[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]54", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]54\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]17[t] + 
              0.1`\ A\[UnderBracket]23[t] + 0.1`\ A\[UnderBracket]45[t] + 
              0.1`\ A\[UnderBracket]53[t] - 
              0.8999999999999999`\ A\[UnderBracket]54[t] + 
              0.1`\ A\[UnderBracket]74[t] + 0.1`\ A\[UnderBracket]75[t] + 
              0.10000000000000003`\ A\[UnderBracket]54[t]\^2\ \
B\[UnderBracket]54[t] - 
              0.01`\ A\[UnderBracket]54[t]\ Y\[UnderBracket]54[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]55", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]55\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]46[t] - 
              0.7999999999999999`\ A\[UnderBracket]55[t] + 
              0.1`\ A\[UnderBracket]66[t] + 0.1`\ A\[UnderBracket]69[t] + 
              0.1`\ A\[UnderBracket]86[t] + 
              0.10000000000000003`\ A\[UnderBracket]55[t]\^2\ \
B\[UnderBracket]55[t] - 
              0.01`\ A\[UnderBracket]55[t]\ Y\[UnderBracket]55[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]56", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]56\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]38[t] + 
              0.1`\ A\[UnderBracket]40[t] + 0.1`\ A\[UnderBracket]51[t] - 
              0.8999999999999999`\ A\[UnderBracket]56[t] + 
              0.1`\ A\[UnderBracket]62[t] + 0.1`\ A\[UnderBracket]67[t] + 
              0.1`\ A\[UnderBracket]71[t] + 
              0.10000000000000003`\ A\[UnderBracket]56[t]\^2\ \
B\[UnderBracket]56[t] - 
              0.01`\ A\[UnderBracket]56[t]\ Y\[UnderBracket]56[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]57", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]57\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]29[t] + 
              0.1`\ A\[UnderBracket]35[t] + 0.1`\ A\[UnderBracket]49[t] - 
              0.9999999999999999`\ A\[UnderBracket]57[t] + 
              0.1`\ A\[UnderBracket]60[t] + 0.1`\ A\[UnderBracket]76[t] + 
              0.1`\ A\[UnderBracket]81[t] + 0.1`\ A\[UnderBracket]85[t] + 
              0.10000000000000003`\ A\[UnderBracket]57[t]\^2\ \
B\[UnderBracket]57[t] - 
              0.01`\ A\[UnderBracket]57[t]\ Y\[UnderBracket]57[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]58", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]58\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]42[t] + 
              0.1`\ A\[UnderBracket]48[t] - 0.7`\ A\[UnderBracket]58[t] + 
              0.1`\ A\[UnderBracket]77[t] + 0.1`\ A\[UnderBracket]78[t] + 
              0.10000000000000003`\ A\[UnderBracket]58[t]\^2\ \
B\[UnderBracket]58[t] - 
              0.01`\ A\[UnderBracket]58[t]\ Y\[UnderBracket]58[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]59", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]59\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]37[t] + 
              0.1`\ A\[UnderBracket]39[t] + 0.1`\ A\[UnderBracket]43[t] - 
              0.9999999999999999`\ A\[UnderBracket]59[t] + 
              0.1`\ A\[UnderBracket]64[t] + 0.1`\ A\[UnderBracket]65[t] + 
              0.1`\ A\[UnderBracket]83[t] + 0.1`\ A\[UnderBracket]87[t] + 
              0.10000000000000003`\ A\[UnderBracket]59[t]\^2\ \
B\[UnderBracket]59[t] - 
              0.01`\ A\[UnderBracket]59[t]\ Y\[UnderBracket]59[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]6", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]6\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]12[t] + 0.1`\ A\[UnderBracket]22[t] + 
              0.1`\ A\[UnderBracket]3[t] - 
              0.7999999999999999`\ A\[UnderBracket]6[t] + 
              0.1`\ A\[UnderBracket]7[t] + 
              0.10000000000000003`\ A\[UnderBracket]6[t]\^2\ \
B\[UnderBracket]6[t] - 
              0.01`\ A\[UnderBracket]6[t]\ Y\[UnderBracket]6[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]60", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]60\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]35[t] + 
              0.1`\ A\[UnderBracket]41[t] + 0.1`\ A\[UnderBracket]52[t] + 
              0.1`\ A\[UnderBracket]57[t] - 
              0.9999999999999999`\ A\[UnderBracket]60[t] + 
              0.1`\ A\[UnderBracket]72[t] + 0.1`\ A\[UnderBracket]80[t] + 
              0.1`\ A\[UnderBracket]85[t] + 
              0.10000000000000003`\ A\[UnderBracket]60[t]\^2\ \
B\[UnderBracket]60[t] - 
              0.01`\ A\[UnderBracket]60[t]\ Y\[UnderBracket]60[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]61", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]61\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]43[t] + 
              0.1`\ A\[UnderBracket]50[t] - 
              0.8999999999999999`\ A\[UnderBracket]61[t] + 
              0.1`\ A\[UnderBracket]64[t] + 0.1`\ A\[UnderBracket]82[t] + 
              0.1`\ A\[UnderBracket]89[t] + 0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]61[t]\^2\ \
B\[UnderBracket]61[t] - 
              0.01`\ A\[UnderBracket]61[t]\ Y\[UnderBracket]61[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]62", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]62\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]56[t] + 
              0.1`\ A\[UnderBracket]67[t] + 0.1`\ A\[UnderBracket]71[t] + 
              0.1`\ A\[UnderBracket]79[t] + 
              0.10000000000000003`\ A\[UnderBracket]62[t]\^2\ \
B\[UnderBracket]62[t] + 
              A\[UnderBracket]62[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]62[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]63", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]63\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]47[t] + 
              0.1`\ A\[UnderBracket]48[t] + 0.1`\ A\[UnderBracket]49[t] - 
              0.7999999999999999`\ A\[UnderBracket]63[t] + 
              0.1`\ A\[UnderBracket]73[t] + 0.1`\ A\[UnderBracket]76[t] + 
              0.10000000000000003`\ A\[UnderBracket]63[t]\^2\ \
B\[UnderBracket]63[t] - 
              0.01`\ A\[UnderBracket]63[t]\ Y\[UnderBracket]63[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]64", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]64\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]43[t] + 
              0.1`\ A\[UnderBracket]59[t] + 0.1`\ A\[UnderBracket]61[t] - 
              0.7999999999999999`\ A\[UnderBracket]64[t] + 
              0.1`\ A\[UnderBracket]83[t] + 0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]64[t]\^2\ \
B\[UnderBracket]64[t] - 
              0.01`\ A\[UnderBracket]64[t]\ Y\[UnderBracket]64[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]65", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]65\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]39[t] + 0.1`\ A\[UnderBracket]53[t] + 
              0.1`\ A\[UnderBracket]59[t] - 
              0.9999999999999999`\ A\[UnderBracket]65[t] + 
              0.1`\ A\[UnderBracket]70[t] + 0.1`\ A\[UnderBracket]87[t] + 
              0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]65[t]\^2\ \
B\[UnderBracket]65[t] - 
              0.01`\ A\[UnderBracket]65[t]\ Y\[UnderBracket]65[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]66", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]66\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]44[t] + 
              0.1`\ A\[UnderBracket]55[t] - 
              0.8999999999999999`\ A\[UnderBracket]66[t] + 
              0.1`\ A\[UnderBracket]67[t] + 0.1`\ A\[UnderBracket]79[t] + 
              0.1`\ A\[UnderBracket]86[t] + 0.1`\ A\[UnderBracket]91[t] + 
              0.10000000000000003`\ A\[UnderBracket]66[t]\^2\ \
B\[UnderBracket]66[t] - 
              0.01`\ A\[UnderBracket]66[t]\ Y\[UnderBracket]66[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]67", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]67\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]38[t] + 
              0.1`\ A\[UnderBracket]44[t] + 0.1`\ A\[UnderBracket]56[t] + 
              0.1`\ A\[UnderBracket]62[t] + 0.1`\ A\[UnderBracket]66[t] - 
              0.8999999999999999`\ A\[UnderBracket]67[t] + 
              0.1`\ A\[UnderBracket]79[t] + 
              0.10000000000000003`\ A\[UnderBracket]67[t]\^2\ \
B\[UnderBracket]67[t] - 
              0.01`\ A\[UnderBracket]67[t]\ Y\[UnderBracket]67[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]68", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]68\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]46[t] + 
              0.1`\ A\[UnderBracket]69[t] + 0.1`\ A\[UnderBracket]75[t] + 
              0.1`\ A\[UnderBracket]94[t] + 
              0.10000000000000003`\ A\[UnderBracket]68[t]\^2\ \
B\[UnderBracket]68[t] + 
              A\[UnderBracket]68[
                  t]\ \((\(-0.7`\) - 0.01`\ Y\[UnderBracket]68[t])\))\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]69", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]69\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]46[t] + 
              0.1`\ A\[UnderBracket]55[t] + 0.1`\ A\[UnderBracket]68[t] - 
              0.8999999999999999`\ A\[UnderBracket]69[t] + 
              0.1`\ A\[UnderBracket]86[t] + 0.1`\ A\[UnderBracket]94[t] + 
              0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]69[t]\^2\ \
B\[UnderBracket]69[t] - 
              0.01`\ A\[UnderBracket]69[t]\ Y\[UnderBracket]69[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]7", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]7\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]11[t] + 
              0.1`\ A\[UnderBracket]13[t] + 0.1`\ A\[UnderBracket]3[t] + 
              0.1`\ A\[UnderBracket]6[t] - 
              0.7999999999999999`\ A\[UnderBracket]7[t] + 
              0.1`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]7[t]\^2\ \
B\[UnderBracket]7[t] - 
              0.01`\ A\[UnderBracket]7[t]\ Y\[UnderBracket]7[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]70", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]70\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]53[t] + 
              0.1`\ A\[UnderBracket]65[t] - 
              0.7999999999999999`\ A\[UnderBracket]70[t] + 
              0.1`\ A\[UnderBracket]74[t] + 0.1`\ A\[UnderBracket]93[t] + 
              0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]70[t]\^2\ \
B\[UnderBracket]70[t] - 
              0.01`\ A\[UnderBracket]70[t]\ Y\[UnderBracket]70[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]71", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]71\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]51[t] + 
              0.1`\ A\[UnderBracket]56[t] + 0.1`\ A\[UnderBracket]62[t] - 
              0.7999999999999999`\ A\[UnderBracket]71[t] + 
              0.1`\ A\[UnderBracket]79[t] + 0.1`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]71[t]\^2\ \
B\[UnderBracket]71[t] - 
              0.01`\ A\[UnderBracket]71[t]\ Y\[UnderBracket]71[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]72", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]72\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]102[t] + 
              0.1`\ A\[UnderBracket]51[t] + 0.1`\ A\[UnderBracket]52[t] + 
              0.1`\ A\[UnderBracket]60[t] - 
              0.8999999999999999`\ A\[UnderBracket]72[t] + 
              0.1`\ A\[UnderBracket]80[t] + 0.1`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]72[t]\^2\ \
B\[UnderBracket]72[t] - 
              0.01`\ A\[UnderBracket]72[t]\ Y\[UnderBracket]72[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]73", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]73\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]48[t] + 
              0.1`\ A\[UnderBracket]63[t] - 
              0.7999999999999999`\ A\[UnderBracket]73[t] + 
              0.1`\ A\[UnderBracket]76[t] + 0.1`\ A\[UnderBracket]77[t] + 
              0.1`\ A\[UnderBracket]92[t] + 
              0.10000000000000003`\ A\[UnderBracket]73[t]\^2\ \
B\[UnderBracket]73[t] - 
              0.01`\ A\[UnderBracket]73[t]\ Y\[UnderBracket]73[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]74", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]74\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]53[t] + 
              0.1`\ A\[UnderBracket]54[t] + 0.1`\ A\[UnderBracket]70[t] - 
              0.8999999999999999`\ A\[UnderBracket]74[t] + 
              0.1`\ A\[UnderBracket]75[t] + 0.1`\ A\[UnderBracket]90[t] + 
              0.1`\ A\[UnderBracket]93[t] + 
              0.10000000000000003`\ A\[UnderBracket]74[t]\^2\ \
B\[UnderBracket]74[t] - 
              0.01`\ A\[UnderBracket]74[t]\ Y\[UnderBracket]74[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]75", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]75\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]45[t] + 
              0.1`\ A\[UnderBracket]54[t] + 0.1`\ A\[UnderBracket]68[t] + 
              0.1`\ A\[UnderBracket]74[t] - 
              0.8999999999999999`\ A\[UnderBracket]75[t] + 
              0.1`\ A\[UnderBracket]90[t] + 0.1`\ A\[UnderBracket]94[t] + 
              0.10000000000000003`\ A\[UnderBracket]75[t]\^2\ \
B\[UnderBracket]75[t] - 
              0.01`\ A\[UnderBracket]75[t]\ Y\[UnderBracket]75[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]76", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]76\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]49[t] + 
              0.1`\ A\[UnderBracket]57[t] + 0.1`\ A\[UnderBracket]63[t] + 
              0.1`\ A\[UnderBracket]73[t] - 
              0.9999999999999999`\ A\[UnderBracket]76[t] + 
              0.1`\ A\[UnderBracket]81[t] + 0.1`\ A\[UnderBracket]92[t] + 
              0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]76[t]\^2\ \
B\[UnderBracket]76[t] - 
              0.01`\ A\[UnderBracket]76[t]\ Y\[UnderBracket]76[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]77", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]77\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]107[t] + 0.1`\ A\[UnderBracket]48[t] + 
              0.1`\ A\[UnderBracket]58[t] + 0.1`\ A\[UnderBracket]73[t] - 
              0.9999999999999999`\ A\[UnderBracket]77[t] + 
              0.1`\ A\[UnderBracket]78[t] + 0.1`\ A\[UnderBracket]92[t] + 
              0.10000000000000003`\ A\[UnderBracket]77[t]\^2\ \
B\[UnderBracket]77[t] - 
              0.01`\ A\[UnderBracket]77[t]\ Y\[UnderBracket]77[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]78", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]78\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]107[t] + 
              0.1`\ A\[UnderBracket]58[t] + 0.1`\ A\[UnderBracket]77[t] - 
              0.6`\ A\[UnderBracket]78[t] + 
              0.10000000000000003`\ A\[UnderBracket]78[t]\^2\ \
B\[UnderBracket]78[t] - 
              0.01`\ A\[UnderBracket]78[t]\ Y\[UnderBracket]78[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]79", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]79\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]62[t] + 0.1`\ A\[UnderBracket]66[t] + 
              0.1`\ A\[UnderBracket]67[t] + 0.1`\ A\[UnderBracket]71[t] - 
              1.0999999999999999`\ A\[UnderBracket]79[t] + 
              0.1`\ A\[UnderBracket]84[t] + 0.1`\ A\[UnderBracket]91[t] + 
              0.1`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]79[t]\^2\ \
B\[UnderBracket]79[t] - 
              0.01`\ A\[UnderBracket]79[t]\ Y\[UnderBracket]79[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]8", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]8\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]1[t] + 
              0.1`\ A\[UnderBracket]13[t] + 0.1`\ A\[UnderBracket]14[t] + 
              0.1`\ A\[UnderBracket]17[t] + 0.1`\ A\[UnderBracket]2[t] + 
              0.1`\ A\[UnderBracket]3[t] + 0.1`\ A\[UnderBracket]5[t] + 
              0.1`\ A\[UnderBracket]7[t] - 
              1.0999999999999999`\ A\[UnderBracket]8[t] + 
              0.10000000000000003`\ A\[UnderBracket]8[t]\^2\ \
B\[UnderBracket]8[t] - 
              0.01`\ A\[UnderBracket]8[t]\ Y\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]80", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]80\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]102[t] + 
              0.1`\ A\[UnderBracket]110[t] + 0.1`\ A\[UnderBracket]60[t] + 
              0.1`\ A\[UnderBracket]72[t] - 
              0.8999999999999999`\ A\[UnderBracket]80[t] + 
              0.1`\ A\[UnderBracket]85[t] + 0.1`\ A\[UnderBracket]88[t] + 
              0.10000000000000003`\ A\[UnderBracket]80[t]\^2\ \
B\[UnderBracket]80[t] - 
              0.01`\ A\[UnderBracket]80[t]\ Y\[UnderBracket]80[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]81", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]81\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]57[t] + 
              0.1`\ A\[UnderBracket]76[t] - 0.7`\ A\[UnderBracket]81[t] + 
              0.1`\ A\[UnderBracket]85[t] + 0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]81[t]\^2\ \
B\[UnderBracket]81[t] - 
              0.01`\ A\[UnderBracket]81[t]\ Y\[UnderBracket]81[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]82", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]82\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]113[t] + 
              0.1`\ A\[UnderBracket]50[t] + 0.1`\ A\[UnderBracket]61[t] - 
              0.7`\ A\[UnderBracket]82[t] + 0.1`\ A\[UnderBracket]89[t] + 
              0.10000000000000003`\ A\[UnderBracket]82[t]\^2\ \
B\[UnderBracket]82[t] - 
              0.01`\ A\[UnderBracket]82[t]\ Y\[UnderBracket]82[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]83", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]83\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]123[t] + 0.1`\ A\[UnderBracket]59[t] + 
              0.1`\ A\[UnderBracket]64[t] - 
              0.8999999999999999`\ A\[UnderBracket]83[t] + 
              0.1`\ A\[UnderBracket]87[t] + 0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]83[t]\^2\ \
B\[UnderBracket]83[t] - 
              0.01`\ A\[UnderBracket]83[t]\ Y\[UnderBracket]83[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]84", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]84\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]102[t] + 0.1`\ A\[UnderBracket]109[t] + 
              0.1`\ A\[UnderBracket]51[t] + 0.1`\ A\[UnderBracket]71[t] + 
              0.1`\ A\[UnderBracket]72[t] + 0.1`\ A\[UnderBracket]79[t] - 
              0.9999999999999999`\ A\[UnderBracket]84[t] + 
              0.10000000000000003`\ A\[UnderBracket]84[t]\^2\ \
B\[UnderBracket]84[t] - 
              0.01`\ A\[UnderBracket]84[t]\ Y\[UnderBracket]84[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]85", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]85\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]57[t] + 
              0.1`\ A\[UnderBracket]60[t] + 0.1`\ A\[UnderBracket]80[t] + 
              0.1`\ A\[UnderBracket]81[t] - 
              0.8999999999999999`\ A\[UnderBracket]85[t] + 
              0.1`\ A\[UnderBracket]88[t] + 0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]85[t]\^2\ \
B\[UnderBracket]85[t] - 
              0.01`\ A\[UnderBracket]85[t]\ Y\[UnderBracket]85[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]86", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]86\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]106[t] + 
              0.1`\ A\[UnderBracket]55[t] + 0.1`\ A\[UnderBracket]66[t] + 
              0.1`\ A\[UnderBracket]69[t] - 
              0.8999999999999999`\ A\[UnderBracket]86[t] + 
              0.1`\ A\[UnderBracket]91[t] + 0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]86[t]\^2\ \
B\[UnderBracket]86[t] - 
              0.01`\ A\[UnderBracket]86[t]\ Y\[UnderBracket]86[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]87", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]87\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]59[t] + 0.1`\ A\[UnderBracket]65[t] + 
              0.1`\ A\[UnderBracket]83[t] - 0.7`\ A\[UnderBracket]87[t] + 
              0.10000000000000003`\ A\[UnderBracket]87[t]\^2\ \
B\[UnderBracket]87[t] - 
              0.01`\ A\[UnderBracket]87[t]\ Y\[UnderBracket]87[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]88", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]88\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]110[t] + 
              0.1`\ A\[UnderBracket]112[t] + 0.1`\ A\[UnderBracket]120[t] + 
              0.1`\ A\[UnderBracket]80[t] + 0.1`\ A\[UnderBracket]85[t] - 
              0.8999999999999999`\ A\[UnderBracket]88[t] + 
              0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]88[t]\^2\ \
B\[UnderBracket]88[t] - 
              0.01`\ A\[UnderBracket]88[t]\ Y\[UnderBracket]88[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]89", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]89\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]113[t] + 
              0.1`\ A\[UnderBracket]61[t] + 0.1`\ A\[UnderBracket]82[t] - 
              0.7`\ A\[UnderBracket]89[t] + 0.1`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]89[t]\^2\ \
B\[UnderBracket]89[t] - 
              0.01`\ A\[UnderBracket]89[t]\ Y\[UnderBracket]89[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]9", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]9\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]10[t] + 
              0.1`\ A\[UnderBracket]14[t] + 0.1`\ A\[UnderBracket]18[t] + 
              0.1`\ A\[UnderBracket]27[t] + 0.1`\ A\[UnderBracket]4[t] + 
              0.1`\ A\[UnderBracket]5[t] - 
              0.8999999999999999`\ A\[UnderBracket]9[t] + 
              0.10000000000000003`\ A\[UnderBracket]9[t]\^2\ \
B\[UnderBracket]9[t] - 
              0.01`\ A\[UnderBracket]9[t]\ Y\[UnderBracket]9[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]90", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]90\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]105[t] + 
              0.1`\ A\[UnderBracket]108[t] + 0.1`\ A\[UnderBracket]116[t] + 
              0.1`\ A\[UnderBracket]74[t] + 0.1`\ A\[UnderBracket]75[t] - 
              0.8999999999999999`\ A\[UnderBracket]90[t] + 
              0.1`\ A\[UnderBracket]93[t] + 
              
              0.10000000000000003`\ A\[UnderBracket]90[t]\^2\ \
B\[UnderBracket]90[t] - 
              0.01`\ A\[UnderBracket]90[t]\ Y\[UnderBracket]90[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]91", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]91\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]106[t] + 
              0.1`\ A\[UnderBracket]118[t] + 0.1`\ A\[UnderBracket]66[t] + 
              0.1`\ A\[UnderBracket]79[t] + 0.1`\ A\[UnderBracket]86[t] - 
              0.8999999999999999`\ A\[UnderBracket]91[t] + 
              0.1`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]91[t]\^2\ \
B\[UnderBracket]91[t] - 
              0.01`\ A\[UnderBracket]91[t]\ Y\[UnderBracket]91[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]92", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]92\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]103[t] + 
              0.1`\ A\[UnderBracket]111[t] + 0.1`\ A\[UnderBracket]73[t] + 
              0.1`\ A\[UnderBracket]76[t] + 0.1`\ A\[UnderBracket]77[t] - 
              0.8999999999999999`\ A\[UnderBracket]92[t] + 
              0.1`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]92[t]\^2\ \
B\[UnderBracket]92[t] - 
              0.01`\ A\[UnderBracket]92[t]\ Y\[UnderBracket]92[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]93", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]93\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]104[t] + 
              0.1`\ A\[UnderBracket]105[t] + 0.1`\ A\[UnderBracket]115[t] + 
              0.1`\ A\[UnderBracket]70[t] + 0.1`\ A\[UnderBracket]74[t] + 
              0.1`\ A\[UnderBracket]90[t] - 
              0.9999999999999999`\ A\[UnderBracket]93[t] + 
              0.1`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]93[t]\^2\ \
B\[UnderBracket]93[t] - 
              0.01`\ A\[UnderBracket]93[t]\ Y\[UnderBracket]93[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]94", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]94\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]108[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]68[t] + 
              0.1`\ A\[UnderBracket]69[t] + 0.1`\ A\[UnderBracket]75[t] - 
              0.8999999999999999`\ A\[UnderBracket]94[t] + 
              0.1`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]94[t]\^2\ \
B\[UnderBracket]94[t] - 
              0.01`\ A\[UnderBracket]94[t]\ Y\[UnderBracket]94[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]95", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]95\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]111[t] + 
              0.1`\ A\[UnderBracket]120[t] + 0.1`\ A\[UnderBracket]121[t] + 
              0.1`\ A\[UnderBracket]76[t] + 0.1`\ A\[UnderBracket]81[t] + 
              0.1`\ A\[UnderBracket]85[t] + 0.1`\ A\[UnderBracket]88[t] + 
              0.1`\ A\[UnderBracket]92[t] - 
              1.0999999999999999`\ A\[UnderBracket]95[t] + 
              0.10000000000000003`\ A\[UnderBracket]95[t]\^2\ \
B\[UnderBracket]95[t] - 
              0.01`\ A\[UnderBracket]95[t]\ Y\[UnderBracket]95[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]96", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]96\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]113[t] + 
              0.1`\ A\[UnderBracket]123[t] + 0.1`\ A\[UnderBracket]127[t] + 
              0.1`\ A\[UnderBracket]61[t] + 0.1`\ A\[UnderBracket]64[t] + 
              0.1`\ A\[UnderBracket]83[t] + 0.1`\ A\[UnderBracket]89[t] - 
              0.9999999999999999`\ A\[UnderBracket]96[t] + 
              0.10000000000000003`\ A\[UnderBracket]96[t]\^2\ \
B\[UnderBracket]96[t] - 
              0.01`\ A\[UnderBracket]96[t]\ Y\[UnderBracket]96[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]97", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]97\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]100[t] + 
              0.1`\ A\[UnderBracket]104[t] + 0.1`\ A\[UnderBracket]124[t] + 
              0.1`\ A\[UnderBracket]65[t] + 0.1`\ A\[UnderBracket]70[t] + 
              0.1`\ A\[UnderBracket]93[t] - 
              0.8999999999999999`\ A\[UnderBracket]97[t] + 
              0.10000000000000003`\ A\[UnderBracket]97[t]\^2\ \
B\[UnderBracket]97[t] - 
              0.01`\ A\[UnderBracket]97[t]\ Y\[UnderBracket]97[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]98", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]98\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]106[t] + 
              0.1`\ A\[UnderBracket]117[t] + 0.1`\ A\[UnderBracket]125[t] + 
              0.1`\ A\[UnderBracket]69[t] + 0.1`\ A\[UnderBracket]86[t] + 
              0.1`\ A\[UnderBracket]94[t] - 
              0.8999999999999999`\ A\[UnderBracket]98[t] + 
              0.10000000000000003`\ A\[UnderBracket]98[t]\^2\ \
B\[UnderBracket]98[t] - 
              0.01`\ A\[UnderBracket]98[t]\ Y\[UnderBracket]98[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["A\[UnderBracket]99", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]99\)\((\(\(0.1`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ A\[UnderBracket]101[t] + 
              0.1`\ A\[UnderBracket]118[t] + 0.1`\ A\[UnderBracket]119[t] + 
              0.1`\ A\[UnderBracket]79[t] + 0.1`\ A\[UnderBracket]91[t] - 
              0.7999999999999999`\ A\[UnderBracket]99[t] + 
              0.10000000000000003`\ A\[UnderBracket]99[t]\^2\ \
B\[UnderBracket]99[t] - 
              0.01`\ A\[UnderBracket]99[t]\ Y\[UnderBracket]99[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]1", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]1[t] - 
                4.5`\ B\[UnderBracket]1[t] - 
                0.1`\ A\[UnderBracket]1[t]\^2\ B\[UnderBracket]1[t] + 
                1.5`\ B\[UnderBracket]2[t] + 1.5`\ B\[UnderBracket]3[t] + 
                1.5`\ B\[UnderBracket]8[t]\)\/cell\[UnderBracket]1\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]10", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]10\)\((0.2`\ \
A\[UnderBracket]10[t] - 7.5`\ B\[UnderBracket]10[t] - 
              0.1`\ A\[UnderBracket]10[t]\^2\ B\[UnderBracket]10[t] + 
              1.5`\ B\[UnderBracket]18[t] + 1.5`\ B\[UnderBracket]19[t] + 
              1.5`\ B\[UnderBracket]28[t] + 1.5`\ B\[UnderBracket]4[t] + 
              1.5`\ B\[UnderBracket]9[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]100", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]100\)\((0.2`\ \
A\[UnderBracket]100[t] - 12.`\ B\[UnderBracket]100[t] - 
              0.1`\ A\[UnderBracket]100[t]\^2\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]114[t] + 1.5`\ B\[UnderBracket]123[t] + 
              1.5`\ B\[UnderBracket]124[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]65[t] + 1.5`\ B\[UnderBracket]83[t] + 
              1.5`\ B\[UnderBracket]87[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]101", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]101\)\((0.2`\ \
A\[UnderBracket]101[t] - 9.`\ B\[UnderBracket]101[t] - 
              0.1`\ A\[UnderBracket]101[t]\^2\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]109[t] + 1.5`\ B\[UnderBracket]119[t] + 
              1.5`\ B\[UnderBracket]131[t] + 1.5`\ B\[UnderBracket]79[t] + 
              1.5`\ B\[UnderBracket]84[t] + 
              1.5`\ B\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]102", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]102\)\((0.2`\ \
A\[UnderBracket]102[t] - 9.`\ B\[UnderBracket]102[t] - 
              0.1`\ A\[UnderBracket]102[t]\^2\ B\[UnderBracket]102[t] + 
              1.5`\ B\[UnderBracket]109[t] + 1.5`\ B\[UnderBracket]110[t] + 
              1.5`\ B\[UnderBracket]129[t] + 1.5`\ B\[UnderBracket]72[t] + 
              1.5`\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]103", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]103\)\((0.2`\ \
A\[UnderBracket]103[t] - 9.`\ B\[UnderBracket]103[t] - 
              0.1`\ A\[UnderBracket]103[t]\^2\ B\[UnderBracket]103[t] + 
              1.5`\ B\[UnderBracket]107[t] + 1.5`\ B\[UnderBracket]111[t] + 
              1.5`\ B\[UnderBracket]136[t] + 1.5`\ B\[UnderBracket]137[t] + 
              1.5`\ B\[UnderBracket]77[t] + 
              1.5`\ B\[UnderBracket]92[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]104", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]104\)\((0.2`\ \
A\[UnderBracket]104[t] - 9.`\ B\[UnderBracket]104[t] - 
              0.1`\ A\[UnderBracket]104[t]\^2\ B\[UnderBracket]104[t] + 
              1.5`\ B\[UnderBracket]115[t] + 1.5`\ B\[UnderBracket]124[t] + 
              1.5`\ B\[UnderBracket]128[t] + 1.5`\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]93[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]105", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]105\)\((0.2`\ \
A\[UnderBracket]105[t] - 6.`\ B\[UnderBracket]105[t] - 
              0.1`\ A\[UnderBracket]105[t]\^2\ B\[UnderBracket]105[t] + 
              1.5`\ B\[UnderBracket]115[t] + 1.5`\ B\[UnderBracket]116[t] + 
              1.5`\ B\[UnderBracket]90[t] + 
              1.5`\ B\[UnderBracket]93[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]106", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]106\)\((0.2`\ \
A\[UnderBracket]106[t] - 7.5`\ B\[UnderBracket]106[t] - 
              0.1`\ A\[UnderBracket]106[t]\^2\ B\[UnderBracket]106[t] + 
              1.5`\ B\[UnderBracket]118[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]86[t] + 1.5`\ B\[UnderBracket]91[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]107", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]107\)\((0.2`\ \
A\[UnderBracket]107[t] + 1.5`\ B\[UnderBracket]103[t] - 
              7.5`\ B\[UnderBracket]107[t] - 
              0.1`\ A\[UnderBracket]107[t]\^2\ B\[UnderBracket]107[t] + 
              1.5`\ B\[UnderBracket]122[t] + 1.5`\ B\[UnderBracket]137[t] + 
              1.5`\ B\[UnderBracket]77[t] + 
              1.5`\ B\[UnderBracket]78[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]108", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]108\)\((0.2`\ \
A\[UnderBracket]108[t] - 6.`\ B\[UnderBracket]108[t] - 
              0.1`\ A\[UnderBracket]108[t]\^2\ B\[UnderBracket]108[t] + 
              1.5`\ B\[UnderBracket]116[t] + 1.5`\ B\[UnderBracket]117[t] + 
              1.5`\ B\[UnderBracket]90[t] + 
              1.5`\ B\[UnderBracket]94[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]109", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]109\)\((0.2`\ \
A\[UnderBracket]109[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]102[t] - 7.5`\ B\[UnderBracket]109[t] - 
              0.1`\ A\[UnderBracket]109[t]\^2\ B\[UnderBracket]109[t] + 
              1.5`\ B\[UnderBracket]129[t] + 1.5`\ B\[UnderBracket]131[t] + 
              1.5`\ B\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]11", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]11\)\((0.2`\ \
A\[UnderBracket]11[t] - 10.5`\ B\[UnderBracket]11[t] - 
              0.1`\ A\[UnderBracket]11[t]\^2\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]13[t] + 1.5`\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]24[t] + 1.5`\ B\[UnderBracket]25[t] + 
              1.5`\ B\[UnderBracket]26[t] + 1.5`\ B\[UnderBracket]6[t] + 
              1.5`\ B\[UnderBracket]7[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]110", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]110\)\((0.2`\ \
A\[UnderBracket]110[t] + 1.5`\ B\[UnderBracket]102[t] - 
              7.5`\ B\[UnderBracket]110[t] - 
              0.1`\ A\[UnderBracket]110[t]\^2\ B\[UnderBracket]110[t] + 
              1.5`\ B\[UnderBracket]112[t] + 1.5`\ B\[UnderBracket]129[t] + 
              1.5`\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]88[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]111", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]111\)\((0.2`\ \
A\[UnderBracket]111[t] + 1.5`\ B\[UnderBracket]103[t] - 
              7.5`\ B\[UnderBracket]111[t] - 
              0.1`\ A\[UnderBracket]111[t]\^2\ B\[UnderBracket]111[t] + 
              1.5`\ B\[UnderBracket]121[t] + 1.5`\ B\[UnderBracket]136[t] + 
              1.5`\ B\[UnderBracket]92[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]112", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]112\)\((0.2`\ \
A\[UnderBracket]112[t] + 1.5`\ B\[UnderBracket]110[t] - 
              9.`\ B\[UnderBracket]112[t] - 
              0.1`\ A\[UnderBracket]112[t]\^2\ B\[UnderBracket]112[t] + 
              1.5`\ B\[UnderBracket]120[t] + 1.5`\ B\[UnderBracket]129[t] + 
              1.5`\ B\[UnderBracket]144[t] + 1.5`\ B\[UnderBracket]149[t] + 
              1.5`\ B\[UnderBracket]88[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]113", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]113\)\((0.2`\ \
A\[UnderBracket]113[t] - 7.5`\ B\[UnderBracket]113[t] - 
              0.1`\ A\[UnderBracket]113[t]\^2\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]127[t] + 1.5`\ B\[UnderBracket]134[t] + 
              1.5`\ B\[UnderBracket]82[t] + 1.5`\ B\[UnderBracket]89[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]114", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]114\)\((0.2`\ \
A\[UnderBracket]114[t] + 1.5`\ B\[UnderBracket]100[t] - 
              6.`\ B\[UnderBracket]114[t] - 
              0.1`\ A\[UnderBracket]114[t]\^2\ B\[UnderBracket]114[t] + 
              1.5`\ B\[UnderBracket]124[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]145[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]115", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]115\)\((0.2`\ \
A\[UnderBracket]115[t] + 1.5`\ B\[UnderBracket]104[t] + 
              1.5`\ B\[UnderBracket]105[t] - 9.`\ B\[UnderBracket]115[t] - 
              0.1`\ A\[UnderBracket]115[t]\^2\ B\[UnderBracket]115[t] + 
              1.5`\ B\[UnderBracket]116[t] + 1.5`\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]142[t] + 
              1.5`\ B\[UnderBracket]93[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]116", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]116\)\((0.2`\ \
A\[UnderBracket]116[t] + 1.5`\ B\[UnderBracket]105[t] + 
              1.5`\ B\[UnderBracket]108[t] + 1.5`\ B\[UnderBracket]115[t] - 
              9.`\ B\[UnderBracket]116[t] - 
              0.1`\ A\[UnderBracket]116[t]\^2\ B\[UnderBracket]116[t] + 
              1.5`\ B\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]143[t] + 
              1.5`\ B\[UnderBracket]90[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]117", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]117\)\((0.2`\ \
A\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]108[t] + 
              1.5`\ B\[UnderBracket]116[t] - 10.5`\ B\[UnderBracket]117[t] - 
              0.1`\ A\[UnderBracket]117[t]\^2\ B\[UnderBracket]117[t] + 
              1.5`\ B\[UnderBracket]125[t] + 1.5`\ B\[UnderBracket]143[t] + 
              1.5`\ B\[UnderBracket]154[t] + 1.5`\ B\[UnderBracket]94[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]118", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]118\)\((0.2`\ \
A\[UnderBracket]118[t] + 1.5`\ B\[UnderBracket]106[t] - 
              9.`\ B\[UnderBracket]118[t] - 
              0.1`\ A\[UnderBracket]118[t]\^2\ B\[UnderBracket]118[t] + 
              1.5`\ B\[UnderBracket]119[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]135[t] + 1.5`\ B\[UnderBracket]91[t] + 
              1.5`\ B\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]119", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]119\)\((0.2`\ \
A\[UnderBracket]119[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]118[t] - 7.5`\ B\[UnderBracket]119[t] - 
              0.1`\ A\[UnderBracket]119[t]\^2\ B\[UnderBracket]119[t] + 
              1.5`\ B\[UnderBracket]131[t] + 1.5`\ B\[UnderBracket]135[t] + 
              1.5`\ B\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]12", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]12\)\((0.2`\ \
A\[UnderBracket]12[t] - 6.`\ B\[UnderBracket]12[t] - 
              0.1`\ A\[UnderBracket]12[t]\^2\ B\[UnderBracket]12[t] + 
              1.5`\ B\[UnderBracket]16[t] + 1.5`\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]30[t] + 1.5`\ B\[UnderBracket]6[t])\)\)}],
         ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]120", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]120\)\((0.2`\ \
A\[UnderBracket]120[t] + 1.5`\ B\[UnderBracket]112[t] - 
              9.`\ B\[UnderBracket]120[t] - 
              0.1`\ A\[UnderBracket]120[t]\^2\ B\[UnderBracket]120[t] + 
              1.5`\ B\[UnderBracket]121[t] + 1.5`\ B\[UnderBracket]126[t] + 
              1.5`\ B\[UnderBracket]149[t] + 1.5`\ B\[UnderBracket]88[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]121", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]121\)\((0.2`\ \
A\[UnderBracket]121[t] + 1.5`\ B\[UnderBracket]111[t] + 
              1.5`\ B\[UnderBracket]120[t] - 10.5`\ B\[UnderBracket]121[t] - 
              0.1`\ A\[UnderBracket]121[t]\^2\ B\[UnderBracket]121[t] + 
              1.5`\ B\[UnderBracket]126[t] + 1.5`\ B\[UnderBracket]136[t] + 
              1.5`\ B\[UnderBracket]138[t] + 1.5`\ B\[UnderBracket]139[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]122", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]122[t] + 
                1.5`\ B\[UnderBracket]107[t] - 4.5`\ B\[UnderBracket]122[t] - 
                0.1`\ A\[UnderBracket]122[t]\^2\ B\[UnderBracket]122[t] + 
                1.5`\ B\[UnderBracket]137[t] + 
                1.5`\ B\[UnderBracket]150[t]\)\/cell\[UnderBracket]122\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]123", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]123\)\((0.2`\ \
A\[UnderBracket]123[t] + 1.5`\ B\[UnderBracket]100[t] - 
              9.`\ B\[UnderBracket]123[t] - 
              0.1`\ A\[UnderBracket]123[t]\^2\ B\[UnderBracket]123[t] + 
              1.5`\ B\[UnderBracket]127[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]83[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]124", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]124\)\((0.2`\ \
A\[UnderBracket]124[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]104[t] + 1.5`\ B\[UnderBracket]114[t] - 
              10.5`\ B\[UnderBracket]124[t] - 
              0.1`\ A\[UnderBracket]124[t]\^2\ B\[UnderBracket]124[t] + 
              1.5`\ B\[UnderBracket]128[t] + 1.5`\ B\[UnderBracket]140[t] + 
              1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]125", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]125\)\((0.2`\ \
A\[UnderBracket]125[t] + 1.5`\ B\[UnderBracket]106[t] + 
              1.5`\ B\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]118[t] - 
              12.`\ B\[UnderBracket]125[t] - 
              0.1`\ A\[UnderBracket]125[t]\^2\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]135[t] + 1.5`\ B\[UnderBracket]154[t] + 
              1.5`\ B\[UnderBracket]155[t] + 1.5`\ B\[UnderBracket]162[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]126", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]126\)\((0.2`\ \
A\[UnderBracket]126[t] + 1.5`\ B\[UnderBracket]120[t] + 
              1.5`\ B\[UnderBracket]121[t] - 6.`\ B\[UnderBracket]126[t] - 
              0.1`\ A\[UnderBracket]126[t]\^2\ B\[UnderBracket]126[t] + 
              1.5`\ B\[UnderBracket]138[t] + 
              1.5`\ B\[UnderBracket]149[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]127", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]127\)\((0.2`\ \
A\[UnderBracket]127[t] + 1.5`\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]123[t] - 7.5`\ B\[UnderBracket]127[t] - 
              0.1`\ A\[UnderBracket]127[t]\^2\ B\[UnderBracket]127[t] + 
              1.5`\ B\[UnderBracket]134[t] + 1.5`\ B\[UnderBracket]141[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]128", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]128\)\((0.2`\ \
A\[UnderBracket]128[t] + 1.5`\ B\[UnderBracket]104[t] + 
              1.5`\ B\[UnderBracket]124[t] - 6.`\ B\[UnderBracket]128[t] - 
              0.1`\ A\[UnderBracket]128[t]\^2\ B\[UnderBracket]128[t] + 
              1.5`\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]140[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]129", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]129\)\((0.2`\ \
A\[UnderBracket]129[t] + 1.5`\ B\[UnderBracket]102[t] + 
              1.5`\ B\[UnderBracket]109[t] + 1.5`\ B\[UnderBracket]110[t] + 
              1.5`\ B\[UnderBracket]112[t] - 10.5`\ B\[UnderBracket]129[t] - 
              0.1`\ A\[UnderBracket]129[t]\^2\ B\[UnderBracket]129[t] + 
              1.5`\ B\[UnderBracket]131[t] + 1.5`\ B\[UnderBracket]133[t] + 
              1.5`\ B\[UnderBracket]144[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]13", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]13\)\((0.2`\ \
A\[UnderBracket]13[t] + 1.5`\ B\[UnderBracket]11[t] - 
              9.`\ B\[UnderBracket]13[t] - 
              0.1`\ A\[UnderBracket]13[t]\^2\ B\[UnderBracket]13[t] + 
              1.5`\ B\[UnderBracket]17[t] + 1.5`\ B\[UnderBracket]26[t] + 
              1.5`\ B\[UnderBracket]39[t] + 1.5`\ B\[UnderBracket]7[t] + 
              1.5`\ B\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]130", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]130\)\((0.2`\ \
A\[UnderBracket]130[t] + 1.5`\ B\[UnderBracket]104[t] + 
              1.5`\ B\[UnderBracket]115[t] + 1.5`\ B\[UnderBracket]128[t] - 
              10.5`\ B\[UnderBracket]130[t] - 
              0.1`\ A\[UnderBracket]130[t]\^2\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]140[t] + 1.5`\ B\[UnderBracket]142[t] + 
              1.5`\ B\[UnderBracket]146[t] + 
              1.5`\ B\[UnderBracket]156[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]131", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]131\)\((0.2`\ \
A\[UnderBracket]131[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]109[t] + 1.5`\ B\[UnderBracket]119[t] + 
              1.5`\ B\[UnderBracket]129[t] - 13.5`\ B\[UnderBracket]131[t] - 
              0.1`\ A\[UnderBracket]131[t]\^2\ B\[UnderBracket]131[t] + 
              1.5`\ B\[UnderBracket]133[t] + 1.5`\ B\[UnderBracket]135[t] + 
              1.5`\ B\[UnderBracket]147[t] + 1.5`\ B\[UnderBracket]148[t] + 
              1.5`\ B\[UnderBracket]158[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]132", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]132\)\((0.2`\ \
A\[UnderBracket]132[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]114[t] + 1.5`\ B\[UnderBracket]123[t] - 
              9.`\ B\[UnderBracket]132[t] - 
              0.1`\ A\[UnderBracket]132[t]\^2\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]164[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]133", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]133\)\((0.2`\ \
A\[UnderBracket]133[t] + 1.5`\ B\[UnderBracket]129[t] + 
              1.5`\ B\[UnderBracket]131[t] - 6.`\ B\[UnderBracket]133[t] - 
              0.1`\ A\[UnderBracket]133[t]\^2\ B\[UnderBracket]133[t] + 
              1.5`\ B\[UnderBracket]144[t] + 
              1.5`\ B\[UnderBracket]148[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]134", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]134\)\((0.2`\ \
A\[UnderBracket]134[t] + 1.5`\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]127[t] - 7.5`\ B\[UnderBracket]134[t] - 
              0.1`\ A\[UnderBracket]134[t]\^2\ B\[UnderBracket]134[t] + 
              1.5`\ B\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]152[t] + 
              1.5`\ B\[UnderBracket]153[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]135", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]135\)\((0.2`\ \
A\[UnderBracket]135[t] + 1.5`\ B\[UnderBracket]118[t] + 
              1.5`\ B\[UnderBracket]119[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]131[t] - 9.`\ B\[UnderBracket]135[t] - 
              0.1`\ A\[UnderBracket]135[t]\^2\ B\[UnderBracket]135[t] + 
              1.5`\ B\[UnderBracket]147[t] + 
              1.5`\ B\[UnderBracket]155[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]136", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]136\)\((0.2`\ \
A\[UnderBracket]136[t] + 1.5`\ B\[UnderBracket]103[t] + 
              1.5`\ B\[UnderBracket]111[t] + 1.5`\ B\[UnderBracket]121[t] - 
              10.5`\ B\[UnderBracket]136[t] - 
              0.1`\ A\[UnderBracket]136[t]\^2\ B\[UnderBracket]136[t] + 
              1.5`\ B\[UnderBracket]137[t] + 1.5`\ B\[UnderBracket]139[t] + 
              1.5`\ B\[UnderBracket]157[t] + 
              1.5`\ B\[UnderBracket]159[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]137", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]137\)\((0.2`\ \
A\[UnderBracket]137[t] + 1.5`\ B\[UnderBracket]103[t] + 
              1.5`\ B\[UnderBracket]107[t] + 1.5`\ B\[UnderBracket]122[t] + 
              1.5`\ B\[UnderBracket]136[t] - 10.5`\ B\[UnderBracket]137[t] - 
              0.1`\ A\[UnderBracket]137[t]\^2\ B\[UnderBracket]137[t] + 
              1.5`\ B\[UnderBracket]150[t] + 1.5`\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]171[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]138", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]138\)\((0.2`\ \
A\[UnderBracket]138[t] + 1.5`\ B\[UnderBracket]121[t] + 
              1.5`\ B\[UnderBracket]126[t] - 10.5`\ B\[UnderBracket]138[t] - 
              0.1`\ A\[UnderBracket]138[t]\^2\ B\[UnderBracket]138[t] + 
              1.5`\ B\[UnderBracket]139[t] + 1.5`\ B\[UnderBracket]149[t] + 
              1.5`\ B\[UnderBracket]157[t] + 1.5`\ B\[UnderBracket]163[t] + 
              1.5`\ B\[UnderBracket]170[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]139", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]139\)\((0.2`\ \
A\[UnderBracket]139[t] + 1.5`\ B\[UnderBracket]121[t] + 
              1.5`\ B\[UnderBracket]136[t] + 1.5`\ B\[UnderBracket]138[t] - 
              6.`\ B\[UnderBracket]139[t] - 
              0.1`\ A\[UnderBracket]139[t]\^2\ B\[UnderBracket]139[t] + 
              1.5`\ B\[UnderBracket]157[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]14", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]14\)\((0.2`\ \
A\[UnderBracket]14[t] - 10.5`\ B\[UnderBracket]14[t] - 
              0.1`\ A\[UnderBracket]14[t]\^2\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]17[t] + 1.5`\ B\[UnderBracket]23[t] + 
              1.5`\ B\[UnderBracket]27[t] + 1.5`\ B\[UnderBracket]33[t] + 
              1.5`\ B\[UnderBracket]5[t] + 1.5`\ B\[UnderBracket]8[t] + 
              1.5`\ B\[UnderBracket]9[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]140", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]140\)\((0.2`\ \
A\[UnderBracket]140[t] + 1.5`\ B\[UnderBracket]124[t] + 
              1.5`\ B\[UnderBracket]128[t] + 1.5`\ B\[UnderBracket]130[t] - 
              7.5`\ B\[UnderBracket]140[t] - 
              0.1`\ A\[UnderBracket]140[t]\^2\ B\[UnderBracket]140[t] + 
              1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]156[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]141", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]141\)\((0.2`\ \
A\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]123[t] + 
              1.5`\ B\[UnderBracket]127[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]134[t] - 9.`\ B\[UnderBracket]141[t] - 
              0.1`\ A\[UnderBracket]141[t]\^2\ B\[UnderBracket]141[t] + 
              1.5`\ B\[UnderBracket]153[t] + 
              1.5`\ B\[UnderBracket]164[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]142", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]142\)\((0.2`\ \
A\[UnderBracket]142[t] + 1.5`\ B\[UnderBracket]115[t] + 
              1.5`\ B\[UnderBracket]130[t] - 7.5`\ B\[UnderBracket]142[t] - 
              0.1`\ A\[UnderBracket]142[t]\^2\ B\[UnderBracket]142[t] + 
              1.5`\ B\[UnderBracket]143[t] + 1.5`\ B\[UnderBracket]146[t] + 
              1.5`\ B\[UnderBracket]151[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]143", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]143\)\((0.2`\ \
A\[UnderBracket]143[t] + 1.5`\ B\[UnderBracket]116[t] + 
              1.5`\ B\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]142[t] - 
              7.5`\ B\[UnderBracket]143[t] - 
              0.1`\ A\[UnderBracket]143[t]\^2\ B\[UnderBracket]143[t] + 
              1.5`\ B\[UnderBracket]151[t] + 
              1.5`\ B\[UnderBracket]154[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]144", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]144\)\((0.2`\ \
A\[UnderBracket]144[t] + 1.5`\ B\[UnderBracket]112[t] + 
              1.5`\ B\[UnderBracket]129[t] + 1.5`\ B\[UnderBracket]133[t] - 
              10.5`\ B\[UnderBracket]144[t] - 
              0.1`\ A\[UnderBracket]144[t]\^2\ B\[UnderBracket]144[t] + 
              1.5`\ B\[UnderBracket]148[t] + 1.5`\ B\[UnderBracket]149[t] + 
              1.5`\ B\[UnderBracket]165[t] + 
              1.5`\ B\[UnderBracket]169[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]145", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]145\)\((0.2`\ \
A\[UnderBracket]145[t] + 1.5`\ B\[UnderBracket]114[t] + 
              1.5`\ B\[UnderBracket]124[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]140[t] - 12.`\ B\[UnderBracket]145[t] - 
              0.1`\ A\[UnderBracket]145[t]\^2\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]156[t] + 1.5`\ B\[UnderBracket]160[t] + 
              1.5`\ B\[UnderBracket]164[t] + 
              1.5`\ B\[UnderBracket]188[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]146", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]146\)\((0.2`\ \
A\[UnderBracket]146[t] + 1.5`\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]142[t] - 7.5`\ B\[UnderBracket]146[t] - 
              0.1`\ A\[UnderBracket]146[t]\^2\ B\[UnderBracket]146[t] + 
              1.5`\ B\[UnderBracket]151[t] + 1.5`\ B\[UnderBracket]156[t] + 
              1.5`\ B\[UnderBracket]161[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]147", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]147\)\((0.2`\ \
A\[UnderBracket]147[t] + 1.5`\ B\[UnderBracket]131[t] + 
              1.5`\ B\[UnderBracket]135[t] - 7.5`\ B\[UnderBracket]147[t] - 
              0.1`\ A\[UnderBracket]147[t]\^2\ B\[UnderBracket]147[t] + 
              1.5`\ B\[UnderBracket]155[t] + 1.5`\ B\[UnderBracket]158[t] + 
              1.5`\ B\[UnderBracket]167[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]148", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]148\)\((0.2`\ \
A\[UnderBracket]148[t] + 1.5`\ B\[UnderBracket]131[t] + 
              1.5`\ B\[UnderBracket]133[t] + 1.5`\ B\[UnderBracket]144[t] - 
              9.`\ B\[UnderBracket]148[t] - 
              0.1`\ A\[UnderBracket]148[t]\^2\ B\[UnderBracket]148[t] + 
              1.5`\ B\[UnderBracket]158[t] + 1.5`\ B\[UnderBracket]168[t] + 
              1.5`\ B\[UnderBracket]169[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]149", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]149\)\((0.2`\ \
A\[UnderBracket]149[t] + 1.5`\ B\[UnderBracket]112[t] + 
              1.5`\ B\[UnderBracket]120[t] + 1.5`\ B\[UnderBracket]126[t] + 
              1.5`\ B\[UnderBracket]138[t] + 1.5`\ B\[UnderBracket]144[t] - 
              10.5`\ B\[UnderBracket]149[t] - 
              0.1`\ A\[UnderBracket]149[t]\^2\ B\[UnderBracket]149[t] + 
              1.5`\ B\[UnderBracket]163[t] + 
              1.5`\ B\[UnderBracket]165[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]15", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]15\)\((0.2`\ \
A\[UnderBracket]15[t] - 7.5`\ B\[UnderBracket]15[t] - 
              0.1`\ A\[UnderBracket]15[t]\^2\ B\[UnderBracket]15[t] + 
              1.5`\ B\[UnderBracket]20[t] + 1.5`\ B\[UnderBracket]21[t] + 
              1.5`\ B\[UnderBracket]29[t] + 1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]35[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]150", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]150[t] + 
                1.5`\ B\[UnderBracket]122[t] + 1.5`\ B\[UnderBracket]137[t] - 
                4.5`\ B\[UnderBracket]150[t] - 
                0.1`\ A\[UnderBracket]150[t]\^2\ B\[UnderBracket]150[t] + 
                1.5`\ B\[UnderBracket]171[t]\)\/cell\[UnderBracket]150\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]151", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]151\)\((0.2`\ \
A\[UnderBracket]151[t] + 1.5`\ B\[UnderBracket]142[t] + 
              1.5`\ B\[UnderBracket]143[t] + 1.5`\ B\[UnderBracket]146[t] - 
              10.5`\ B\[UnderBracket]151[t] - 
              0.1`\ A\[UnderBracket]151[t]\^2\ B\[UnderBracket]151[t] + 
              1.5`\ B\[UnderBracket]154[t] + 1.5`\ B\[UnderBracket]161[t] + 
              1.5`\ B\[UnderBracket]166[t] + 
              1.5`\ B\[UnderBracket]175[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]152", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]152\)\((0.2`\ \
A\[UnderBracket]152[t] + 1.5`\ B\[UnderBracket]134[t] - 
              6.`\ B\[UnderBracket]152[t] - 
              0.1`\ A\[UnderBracket]152[t]\^2\ B\[UnderBracket]152[t] + 
              1.5`\ B\[UnderBracket]153[t] + 1.5`\ B\[UnderBracket]172[t] + 
              1.5`\ B\[UnderBracket]178[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]153", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]153\)\((0.2`\ \
A\[UnderBracket]153[t] + 1.5`\ B\[UnderBracket]134[t] + 
              1.5`\ B\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]152[t] - 
              9.`\ B\[UnderBracket]153[t] - 
              0.1`\ A\[UnderBracket]153[t]\^2\ B\[UnderBracket]153[t] + 
              1.5`\ B\[UnderBracket]164[t] + 1.5`\ B\[UnderBracket]172[t] + 
              1.5`\ B\[UnderBracket]176[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]154", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]154\)\((0.2`\ \
A\[UnderBracket]154[t] + 1.5`\ B\[UnderBracket]117[t] + 
              1.5`\ B\[UnderBracket]125[t] + 1.5`\ B\[UnderBracket]143[t] + 
              1.5`\ B\[UnderBracket]151[t] - 9.`\ B\[UnderBracket]154[t] - 
              0.1`\ A\[UnderBracket]154[t]\^2\ B\[UnderBracket]154[t] + 
              1.5`\ B\[UnderBracket]162[t] + 
              1.5`\ B\[UnderBracket]166[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]155", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]155\)\((0.2`\ \
A\[UnderBracket]155[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]135[t] + 1.5`\ B\[UnderBracket]147[t] - 
              9.`\ B\[UnderBracket]155[t] - 
              0.1`\ A\[UnderBracket]155[t]\^2\ B\[UnderBracket]155[t] + 
              1.5`\ B\[UnderBracket]162[t] + 1.5`\ B\[UnderBracket]167[t] + 
              1.5`\ B\[UnderBracket]173[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]156", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]156\)\((0.2`\ \
A\[UnderBracket]156[t] + 1.5`\ B\[UnderBracket]130[t] + 
              1.5`\ B\[UnderBracket]140[t] + 1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]146[t] - 9.`\ B\[UnderBracket]156[t] - 
              0.1`\ A\[UnderBracket]156[t]\^2\ B\[UnderBracket]156[t] + 
              1.5`\ B\[UnderBracket]160[t] + 
              1.5`\ B\[UnderBracket]161[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]157", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]157\)\((0.2`\ \
A\[UnderBracket]157[t] + 1.5`\ B\[UnderBracket]136[t] + 
              1.5`\ B\[UnderBracket]138[t] + 1.5`\ B\[UnderBracket]139[t] - 
              7.5`\ B\[UnderBracket]157[t] - 
              0.1`\ A\[UnderBracket]157[t]\^2\ B\[UnderBracket]157[t] + 
              1.5`\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]170[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]158", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]158\)\((0.2`\ \
A\[UnderBracket]158[t] + 1.5`\ B\[UnderBracket]131[t] + 
              1.5`\ B\[UnderBracket]147[t] + 1.5`\ B\[UnderBracket]148[t] - 
              9.`\ B\[UnderBracket]158[t] - 
              0.1`\ A\[UnderBracket]158[t]\^2\ B\[UnderBracket]158[t] + 
              1.5`\ B\[UnderBracket]167[t] + 1.5`\ B\[UnderBracket]168[t] + 
              1.5`\ B\[UnderBracket]179[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]159", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]159\)\((0.2`\ \
A\[UnderBracket]159[t] + 1.5`\ B\[UnderBracket]136[t] + 
              1.5`\ B\[UnderBracket]137[t] + 1.5`\ B\[UnderBracket]157[t] - 
              10.5`\ B\[UnderBracket]159[t] - 
              0.1`\ A\[UnderBracket]159[t]\^2\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]170[t] + 1.5`\ B\[UnderBracket]171[t] + 
              1.5`\ B\[UnderBracket]181[t] + 
              1.5`\ B\[UnderBracket]182[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]16", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]16[t] + 
                1.5`\ B\[UnderBracket]12[t] - 3.`\ B\[UnderBracket]16[t] - 
                0.1`\ A\[UnderBracket]16[t]\^2\ B\[UnderBracket]16[t] + 
                1.5`\ B\[UnderBracket]30[t]\)\/cell\[UnderBracket]16\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]160", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]160\)\((0.2`\ \
A\[UnderBracket]160[t] + 1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]156[t] - 7.5`\ B\[UnderBracket]160[t] - 
              0.1`\ A\[UnderBracket]160[t]\^2\ B\[UnderBracket]160[t] + 
              1.5`\ B\[UnderBracket]161[t] + 1.5`\ B\[UnderBracket]186[t] + 
              1.5`\ B\[UnderBracket]188[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]161", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]161\)\((0.2`\ \
A\[UnderBracket]161[t] + 1.5`\ B\[UnderBracket]146[t] + 
              1.5`\ B\[UnderBracket]151[t] + 1.5`\ B\[UnderBracket]156[t] + 
              1.5`\ B\[UnderBracket]160[t] - 10.5`\ B\[UnderBracket]161[t] - 
              0.1`\ A\[UnderBracket]161[t]\^2\ B\[UnderBracket]161[t] + 
              1.5`\ B\[UnderBracket]175[t] + 1.5`\ B\[UnderBracket]186[t] + 
              1.5`\ B\[UnderBracket]190[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]162", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]162\)\((0.2`\ \
A\[UnderBracket]162[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]154[t] + 1.5`\ B\[UnderBracket]155[t] - 
              10.5`\ B\[UnderBracket]162[t] - 
              0.1`\ A\[UnderBracket]162[t]\^2\ B\[UnderBracket]162[t] + 
              1.5`\ B\[UnderBracket]166[t] + 1.5`\ B\[UnderBracket]173[t] + 
              1.5`\ B\[UnderBracket]183[t] + 
              1.5`\ B\[UnderBracket]184[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]163", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]163\)\((0.2`\ \
A\[UnderBracket]163[t] + 1.5`\ B\[UnderBracket]138[t] + 
              1.5`\ B\[UnderBracket]149[t] - 7.5`\ B\[UnderBracket]163[t] - 
              0.1`\ A\[UnderBracket]163[t]\^2\ B\[UnderBracket]163[t] + 
              1.5`\ B\[UnderBracket]165[t] + 1.5`\ B\[UnderBracket]170[t] + 
              1.5`\ B\[UnderBracket]180[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]164", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]164\)\((0.2`\ \
A\[UnderBracket]164[t] + 1.5`\ B\[UnderBracket]132[t] + 
              1.5`\ B\[UnderBracket]141[t] + 1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]153[t] - 10.5`\ B\[UnderBracket]164[t] - 
              0.1`\ A\[UnderBracket]164[t]\^2\ B\[UnderBracket]164[t] + 
              1.5`\ B\[UnderBracket]176[t] + 1.5`\ B\[UnderBracket]188[t] + 
              1.5`\ B\[UnderBracket]201[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]165", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]165\)\((0.2`\ \
A\[UnderBracket]165[t] + 1.5`\ B\[UnderBracket]144[t] + 
              1.5`\ B\[UnderBracket]149[t] + 1.5`\ B\[UnderBracket]163[t] - 
              9.`\ B\[UnderBracket]165[t] - 
              0.1`\ A\[UnderBracket]165[t]\^2\ B\[UnderBracket]165[t] + 
              1.5`\ B\[UnderBracket]169[t] + 1.5`\ B\[UnderBracket]177[t] + 
              1.5`\ B\[UnderBracket]180[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]166", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]166\)\((0.2`\ \
A\[UnderBracket]166[t] + 1.5`\ B\[UnderBracket]151[t] + 
              1.5`\ B\[UnderBracket]154[t] + 1.5`\ B\[UnderBracket]162[t] - 
              7.5`\ B\[UnderBracket]166[t] - 
              0.1`\ A\[UnderBracket]166[t]\^2\ B\[UnderBracket]166[t] + 
              1.5`\ B\[UnderBracket]175[t] + 
              1.5`\ B\[UnderBracket]183[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]167", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]167\)\((0.2`\ \
A\[UnderBracket]167[t] + 1.5`\ B\[UnderBracket]147[t] + 
              1.5`\ B\[UnderBracket]155[t] + 1.5`\ B\[UnderBracket]158[t] - 
              9.`\ B\[UnderBracket]167[t] - 
              0.1`\ A\[UnderBracket]167[t]\^2\ B\[UnderBracket]167[t] + 
              1.5`\ B\[UnderBracket]173[t] + 1.5`\ B\[UnderBracket]174[t] + 
              1.5`\ B\[UnderBracket]179[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]168", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]168\)\((0.2`\ \
A\[UnderBracket]168[t] + 1.5`\ B\[UnderBracket]148[t] + 
              1.5`\ B\[UnderBracket]158[t] - 6.`\ B\[UnderBracket]168[t] - 
              0.1`\ A\[UnderBracket]168[t]\^2\ B\[UnderBracket]168[t] + 
              1.5`\ B\[UnderBracket]169[t] + 
              1.5`\ B\[UnderBracket]179[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]169", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]169\)\((0.2`\ \
A\[UnderBracket]169[t] + 1.5`\ B\[UnderBracket]144[t] + 
              1.5`\ B\[UnderBracket]148[t] + 1.5`\ B\[UnderBracket]165[t] + 
              1.5`\ B\[UnderBracket]168[t] - 12.`\ B\[UnderBracket]169[t] - 
              0.1`\ A\[UnderBracket]169[t]\^2\ B\[UnderBracket]169[t] + 
              1.5`\ B\[UnderBracket]177[t] + 1.5`\ B\[UnderBracket]179[t] + 
              1.5`\ B\[UnderBracket]192[t] + 
              1.5`\ B\[UnderBracket]193[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]17", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]17\)\((0.2`\ \
A\[UnderBracket]17[t] + 1.5`\ B\[UnderBracket]13[t] + 
              1.5`\ B\[UnderBracket]14[t] - 10.5`\ B\[UnderBracket]17[t] - 
              0.1`\ A\[UnderBracket]17[t]\^2\ B\[UnderBracket]17[t] + 
              1.5`\ B\[UnderBracket]23[t] + 1.5`\ B\[UnderBracket]39[t] + 
              1.5`\ B\[UnderBracket]53[t] + 1.5`\ B\[UnderBracket]54[t] + 
              1.5`\ B\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]170", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]170\)\((0.2`\ \
A\[UnderBracket]170[t] + 1.5`\ B\[UnderBracket]138[t] + 
              1.5`\ B\[UnderBracket]157[t] + 1.5`\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]163[t] - 9.`\ B\[UnderBracket]170[t] - 
              0.1`\ A\[UnderBracket]170[t]\^2\ B\[UnderBracket]170[t] + 
              1.5`\ B\[UnderBracket]180[t] + 
              1.5`\ B\[UnderBracket]181[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]171", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]171\)\((0.2`\ \
A\[UnderBracket]171[t] + 1.5`\ B\[UnderBracket]137[t] + 
              1.5`\ B\[UnderBracket]150[t] + 1.5`\ B\[UnderBracket]159[t] - 
              6.`\ B\[UnderBracket]171[t] - 
              0.1`\ A\[UnderBracket]171[t]\^2\ B\[UnderBracket]171[t] + 
              1.5`\ B\[UnderBracket]182[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]172", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]172\)\((0.2`\ \
A\[UnderBracket]172[t] + 1.5`\ B\[UnderBracket]152[t] + 
              1.5`\ B\[UnderBracket]153[t] - 7.5`\ B\[UnderBracket]172[t] - 
              0.1`\ A\[UnderBracket]172[t]\^2\ B\[UnderBracket]172[t] + 
              1.5`\ B\[UnderBracket]176[t] + 1.5`\ B\[UnderBracket]178[t] + 
              1.5`\ B\[UnderBracket]185[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]173", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]173\)\((0.2`\ \
A\[UnderBracket]173[t] + 1.5`\ B\[UnderBracket]155[t] + 
              1.5`\ B\[UnderBracket]162[t] + 1.5`\ B\[UnderBracket]167[t] - 
              9.`\ B\[UnderBracket]173[t] - 
              0.1`\ A\[UnderBracket]173[t]\^2\ B\[UnderBracket]173[t] + 
              1.5`\ B\[UnderBracket]174[t] + 1.5`\ B\[UnderBracket]184[t] + 
              1.5`\ B\[UnderBracket]189[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]174", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]174\)\((0.2`\ \
A\[UnderBracket]174[t] + 1.5`\ B\[UnderBracket]167[t] + 
              1.5`\ B\[UnderBracket]173[t] - 7.5`\ B\[UnderBracket]174[t] - 
              0.1`\ A\[UnderBracket]174[t]\^2\ B\[UnderBracket]174[t] + 
              1.5`\ B\[UnderBracket]179[t] + 1.5`\ B\[UnderBracket]187[t] + 
              1.5`\ B\[UnderBracket]189[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]175", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]175\)\((0.2`\ \
A\[UnderBracket]175[t] + 1.5`\ B\[UnderBracket]151[t] + 
              1.5`\ B\[UnderBracket]161[t] + 1.5`\ B\[UnderBracket]166[t] - 
              9.`\ B\[UnderBracket]175[t] - 
              0.1`\ A\[UnderBracket]175[t]\^2\ B\[UnderBracket]175[t] + 
              1.5`\ B\[UnderBracket]183[t] + 1.5`\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]199[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]176", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]176\)\((0.2`\ \
A\[UnderBracket]176[t] + 1.5`\ B\[UnderBracket]153[t] + 
              1.5`\ B\[UnderBracket]164[t] + 1.5`\ B\[UnderBracket]172[t] - 
              9.`\ B\[UnderBracket]176[t] - 
              0.1`\ A\[UnderBracket]176[t]\^2\ B\[UnderBracket]176[t] + 
              1.5`\ B\[UnderBracket]185[t] + 1.5`\ B\[UnderBracket]197[t] + 
              1.5`\ B\[UnderBracket]201[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]177", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]177\)\((0.2`\ \
A\[UnderBracket]177[t] + 1.5`\ B\[UnderBracket]165[t] + 
              1.5`\ B\[UnderBracket]169[t] - 7.5`\ B\[UnderBracket]177[t] - 
              0.1`\ A\[UnderBracket]177[t]\^2\ B\[UnderBracket]177[t] + 
              1.5`\ B\[UnderBracket]180[t] + 1.5`\ B\[UnderBracket]193[t] + 
              1.5`\ B\[UnderBracket]194[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]178", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]178\)\((0.2`\ \
A\[UnderBracket]178[t] + 1.5`\ B\[UnderBracket]152[t] + 
              1.5`\ B\[UnderBracket]172[t] - 6.`\ B\[UnderBracket]178[t] - 
              0.1`\ A\[UnderBracket]178[t]\^2\ B\[UnderBracket]178[t] + 
              1.5`\ B\[UnderBracket]185[t] + 
              1.5`\ B\[UnderBracket]203[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]179", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]179\)\((0.2`\ \
A\[UnderBracket]179[t] + 1.5`\ B\[UnderBracket]158[t] + 
              1.5`\ B\[UnderBracket]167[t] + 1.5`\ B\[UnderBracket]168[t] + 
              1.5`\ B\[UnderBracket]169[t] + 1.5`\ B\[UnderBracket]174[t] - 
              12.`\ B\[UnderBracket]179[t] - 
              0.1`\ A\[UnderBracket]179[t]\^2\ B\[UnderBracket]179[t] + 
              1.5`\ B\[UnderBracket]187[t] + 1.5`\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]192[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]18", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]18\)\((0.2`\ \
A\[UnderBracket]18[t] + 1.5`\ B\[UnderBracket]10[t] - 
              7.5`\ B\[UnderBracket]18[t] - 
              0.1`\ A\[UnderBracket]18[t]\^2\ B\[UnderBracket]18[t] + 
              1.5`\ B\[UnderBracket]27[t] + 1.5`\ B\[UnderBracket]28[t] + 
              1.5`\ B\[UnderBracket]31[t] + 1.5`\ B\[UnderBracket]9[t])\)\)}],
         ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]180", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]180\)\((0.2`\ \
A\[UnderBracket]180[t] + 1.5`\ B\[UnderBracket]163[t] + 
              1.5`\ B\[UnderBracket]165[t] + 1.5`\ B\[UnderBracket]170[t] + 
              1.5`\ B\[UnderBracket]177[t] - 12.`\ B\[UnderBracket]180[t] - 
              0.1`\ A\[UnderBracket]180[t]\^2\ B\[UnderBracket]180[t] + 
              1.5`\ B\[UnderBracket]181[t] + 1.5`\ B\[UnderBracket]194[t] + 
              1.5`\ B\[UnderBracket]196[t] + 
              1.5`\ B\[UnderBracket]204[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]181", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]181\)\((0.2`\ \
A\[UnderBracket]181[t] + 1.5`\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]170[t] + 1.5`\ B\[UnderBracket]180[t] - 
              9.`\ B\[UnderBracket]181[t] - 
              0.1`\ A\[UnderBracket]181[t]\^2\ B\[UnderBracket]181[t] + 
              1.5`\ B\[UnderBracket]182[t] + 1.5`\ B\[UnderBracket]196[t] + 
              1.5`\ B\[UnderBracket]200[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]182", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]182\)\((0.2`\ \
A\[UnderBracket]182[t] + 1.5`\ B\[UnderBracket]159[t] + 
              1.5`\ B\[UnderBracket]171[t] + 1.5`\ B\[UnderBracket]181[t] - 
              6.`\ B\[UnderBracket]182[t] - 
              0.1`\ A\[UnderBracket]182[t]\^2\ B\[UnderBracket]182[t] + 
              1.5`\ B\[UnderBracket]200[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]183", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]183\)\((0.2`\ \
A\[UnderBracket]183[t] + 1.5`\ B\[UnderBracket]162[t] + 
              1.5`\ B\[UnderBracket]166[t] + 1.5`\ B\[UnderBracket]175[t] - 
              9.`\ B\[UnderBracket]183[t] - 
              0.1`\ A\[UnderBracket]183[t]\^2\ B\[UnderBracket]183[t] + 
              1.5`\ B\[UnderBracket]184[t] + 1.5`\ B\[UnderBracket]195[t] + 
              1.5`\ B\[UnderBracket]199[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]184", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]184\)\((0.2`\ \
A\[UnderBracket]184[t] + 1.5`\ B\[UnderBracket]162[t] + 
              1.5`\ B\[UnderBracket]173[t] + 1.5`\ B\[UnderBracket]183[t] - 
              9.`\ B\[UnderBracket]184[t] - 
              0.1`\ A\[UnderBracket]184[t]\^2\ B\[UnderBracket]184[t] + 
              1.5`\ B\[UnderBracket]189[t] + 1.5`\ B\[UnderBracket]195[t] + 
              1.5`\ B\[UnderBracket]202[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]185", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]185\)\((0.2`\ \
A\[UnderBracket]185[t] + 1.5`\ B\[UnderBracket]172[t] + 
              1.5`\ B\[UnderBracket]176[t] + 1.5`\ B\[UnderBracket]178[t] - 
              9.`\ B\[UnderBracket]185[t] - 
              0.1`\ A\[UnderBracket]185[t]\^2\ B\[UnderBracket]185[t] + 
              1.5`\ B\[UnderBracket]197[t] + 1.5`\ B\[UnderBracket]203[t] + 
              1.5`\ B\[UnderBracket]208[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]186", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]186\)\((0.2`\ \
A\[UnderBracket]186[t] + 1.5`\ B\[UnderBracket]160[t] + 
              1.5`\ B\[UnderBracket]161[t] - 7.5`\ B\[UnderBracket]186[t] - 
              0.1`\ A\[UnderBracket]186[t]\^2\ B\[UnderBracket]186[t] + 
              1.5`\ B\[UnderBracket]188[t] + 1.5`\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]198[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]187", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]187\)\((0.2`\ \
A\[UnderBracket]187[t] + 1.5`\ B\[UnderBracket]174[t] + 
              1.5`\ B\[UnderBracket]179[t] - 7.5`\ B\[UnderBracket]187[t] - 
              0.1`\ A\[UnderBracket]187[t]\^2\ B\[UnderBracket]187[t] + 
              1.5`\ B\[UnderBracket]189[t] + 1.5`\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]205[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]188", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]188\)\((0.2`\ \
A\[UnderBracket]188[t] + 1.5`\ B\[UnderBracket]145[t] + 
              1.5`\ B\[UnderBracket]160[t] + 1.5`\ B\[UnderBracket]164[t] + 
              1.5`\ B\[UnderBracket]186[t] - 10.5`\ B\[UnderBracket]188[t] - 
              0.1`\ A\[UnderBracket]188[t]\^2\ B\[UnderBracket]188[t] + 
              1.5`\ B\[UnderBracket]198[t] + 1.5`\ B\[UnderBracket]201[t] + 
              1.5`\ B\[UnderBracket]218[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]189", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]189\)\((0.2`\ \
A\[UnderBracket]189[t] + 1.5`\ B\[UnderBracket]173[t] + 
              1.5`\ B\[UnderBracket]174[t] + 1.5`\ B\[UnderBracket]184[t] + 
              1.5`\ B\[UnderBracket]187[t] - 9.`\ B\[UnderBracket]189[t] - 
              0.1`\ A\[UnderBracket]189[t]\^2\ B\[UnderBracket]189[t] + 
              1.5`\ B\[UnderBracket]202[t] + 
              1.5`\ B\[UnderBracket]205[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]19", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]19\)\((0.2`\ \
A\[UnderBracket]19[t] + 1.5`\ B\[UnderBracket]10[t] - 
              9.`\ B\[UnderBracket]19[t] - 
              0.1`\ A\[UnderBracket]19[t]\^2\ B\[UnderBracket]19[t] + 
              1.5`\ B\[UnderBracket]20[t] + 1.5`\ B\[UnderBracket]28[t] + 
              1.5`\ B\[UnderBracket]32[t] + 1.5`\ B\[UnderBracket]38[t] + 
              1.5`\ B\[UnderBracket]40[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]190", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]190\)\((0.2`\ \
A\[UnderBracket]190[t] + 1.5`\ B\[UnderBracket]161[t] + 
              1.5`\ B\[UnderBracket]175[t] + 1.5`\ B\[UnderBracket]186[t] - 
              10.5`\ B\[UnderBracket]190[t] - 
              0.1`\ A\[UnderBracket]190[t]\^2\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]198[t] + 1.5`\ B\[UnderBracket]199[t] + 
              1.5`\ B\[UnderBracket]207[t] + 
              1.5`\ B\[UnderBracket]215[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]191", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]191\)\((0.2`\ \
A\[UnderBracket]191[t] + 1.5`\ B\[UnderBracket]179[t] + 
              1.5`\ B\[UnderBracket]187[t] - 9.`\ B\[UnderBracket]191[t] - 
              0.1`\ A\[UnderBracket]191[t]\^2\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]192[t] + 1.5`\ B\[UnderBracket]205[t] + 
              1.5`\ B\[UnderBracket]206[t] + 
              1.5`\ B\[UnderBracket]216[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]192", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]192\)\((0.2`\ \
A\[UnderBracket]192[t] + 1.5`\ B\[UnderBracket]169[t] + 
              1.5`\ B\[UnderBracket]179[t] + 1.5`\ B\[UnderBracket]191[t] - 
              7.5`\ B\[UnderBracket]192[t] - 
              0.1`\ A\[UnderBracket]192[t]\^2\ B\[UnderBracket]192[t] + 
              1.5`\ B\[UnderBracket]193[t] + 
              1.5`\ B\[UnderBracket]206[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]193", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]193\)\((0.2`\ \
A\[UnderBracket]193[t] + 1.5`\ B\[UnderBracket]169[t] + 
              1.5`\ B\[UnderBracket]177[t] + 1.5`\ B\[UnderBracket]192[t] - 
              7.5`\ B\[UnderBracket]193[t] - 
              0.1`\ A\[UnderBracket]193[t]\^2\ B\[UnderBracket]193[t] + 
              1.5`\ B\[UnderBracket]194[t] + 
              1.5`\ B\[UnderBracket]206[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]194", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]194\)\((0.2`\ \
A\[UnderBracket]194[t] + 1.5`\ B\[UnderBracket]177[t] + 
              1.5`\ B\[UnderBracket]180[t] + 1.5`\ B\[UnderBracket]193[t] - 
              7.5`\ B\[UnderBracket]194[t] - 
              0.1`\ A\[UnderBracket]194[t]\^2\ B\[UnderBracket]194[t] + 
              1.5`\ B\[UnderBracket]204[t] + 
              1.5`\ B\[UnderBracket]206[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]195", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]195\)\((0.2`\ \
A\[UnderBracket]195[t] + 1.5`\ B\[UnderBracket]183[t] + 
              1.5`\ B\[UnderBracket]184[t] - 9.`\ B\[UnderBracket]195[t] - 
              0.1`\ A\[UnderBracket]195[t]\^2\ B\[UnderBracket]195[t] + 
              1.5`\ B\[UnderBracket]199[t] + 1.5`\ B\[UnderBracket]202[t] + 
              1.5`\ B\[UnderBracket]213[t] + 
              1.5`\ B\[UnderBracket]222[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]196", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]196\)\((0.2`\ \
A\[UnderBracket]196[t] + 1.5`\ B\[UnderBracket]180[t] + 
              1.5`\ B\[UnderBracket]181[t] - 9.`\ B\[UnderBracket]196[t] - 
              0.1`\ A\[UnderBracket]196[t]\^2\ B\[UnderBracket]196[t] + 
              1.5`\ B\[UnderBracket]200[t] + 1.5`\ B\[UnderBracket]204[t] + 
              1.5`\ B\[UnderBracket]211[t] + 
              1.5`\ B\[UnderBracket]214[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]197", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]197\)\((0.2`\ \
A\[UnderBracket]197[t] + 1.5`\ B\[UnderBracket]176[t] + 
              1.5`\ B\[UnderBracket]185[t] - 7.5`\ B\[UnderBracket]197[t] - 
              0.1`\ A\[UnderBracket]197[t]\^2\ B\[UnderBracket]197[t] + 
              1.5`\ B\[UnderBracket]201[t] + 1.5`\ B\[UnderBracket]208[t] + 
              1.5`\ B\[UnderBracket]209[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]198", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]198\)\((0.2`\ \
A\[UnderBracket]198[t] + 1.5`\ B\[UnderBracket]186[t] + 
              1.5`\ B\[UnderBracket]188[t] + 1.5`\ B\[UnderBracket]190[t] - 
              7.5`\ B\[UnderBracket]198[t] - 
              0.1`\ A\[UnderBracket]198[t]\^2\ B\[UnderBracket]198[t] + 
              1.5`\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]218[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]199", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]199\)\((0.2`\ \
A\[UnderBracket]199[t] + 1.5`\ B\[UnderBracket]175[t] + 
              1.5`\ B\[UnderBracket]183[t] + 1.5`\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]195[t] - 10.5`\ B\[UnderBracket]199[t] - 
              0.1`\ A\[UnderBracket]199[t]\^2\ B\[UnderBracket]199[t] + 
              1.5`\ B\[UnderBracket]207[t] + 1.5`\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]222[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]2", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]2[t] + 
                1.5`\ B\[UnderBracket]1[t] - 6.`\ B\[UnderBracket]2[t] - 
                0.1`\ A\[UnderBracket]2[t]\^2\ B\[UnderBracket]2[t] + 
                1.5`\ B\[UnderBracket]4[t] + 1.5`\ B\[UnderBracket]5[t] + 
                1.5`\ B\[UnderBracket]8[t]\)\/cell\[UnderBracket]2\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]20", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]20\)\((0.2`\ \
A\[UnderBracket]20[t] + 1.5`\ B\[UnderBracket]15[t] + 
              1.5`\ B\[UnderBracket]19[t] - 6.`\ B\[UnderBracket]20[t] - 
              0.1`\ A\[UnderBracket]20[t]\^2\ B\[UnderBracket]20[t] + 
              1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]40[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]200", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]200\)\((0.2`\ \
A\[UnderBracket]200[t] + 1.5`\ B\[UnderBracket]181[t] + 
              1.5`\ B\[UnderBracket]182[t] + 1.5`\ B\[UnderBracket]196[t] - 
              6.`\ B\[UnderBracket]200[t] - 
              0.1`\ A\[UnderBracket]200[t]\^2\ B\[UnderBracket]200[t] + 
              1.5`\ B\[UnderBracket]211[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]201", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]201\)\((0.2`\ \
A\[UnderBracket]201[t] + 1.5`\ B\[UnderBracket]164[t] + 
              1.5`\ B\[UnderBracket]176[t] + 1.5`\ B\[UnderBracket]188[t] + 
              1.5`\ B\[UnderBracket]197[t] - 10.5`\ B\[UnderBracket]201[t] - 
              0.1`\ A\[UnderBracket]201[t]\^2\ B\[UnderBracket]201[t] + 
              1.5`\ B\[UnderBracket]209[t] + 1.5`\ B\[UnderBracket]218[t] + 
              1.5`\ B\[UnderBracket]220[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]202", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]202\)\((0.2`\ \
A\[UnderBracket]202[t] + 1.5`\ B\[UnderBracket]184[t] + 
              1.5`\ B\[UnderBracket]189[t] + 1.5`\ B\[UnderBracket]195[t] - 
              9.`\ B\[UnderBracket]202[t] - 
              0.1`\ A\[UnderBracket]202[t]\^2\ B\[UnderBracket]202[t] + 
              1.5`\ B\[UnderBracket]205[t] + 1.5`\ B\[UnderBracket]210[t] + 
              1.5`\ B\[UnderBracket]213[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]203", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]203\)\((0.2`\ \
A\[UnderBracket]203[t] + 1.5`\ B\[UnderBracket]178[t] + 
              1.5`\ B\[UnderBracket]185[t] - 6.`\ B\[UnderBracket]203[t] - 
              0.1`\ A\[UnderBracket]203[t]\^2\ B\[UnderBracket]203[t] + 
              1.5`\ B\[UnderBracket]208[t] + 
              1.5`\ B\[UnderBracket]219[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]204", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]204\)\((0.2`\ \
A\[UnderBracket]204[t] + 1.5`\ B\[UnderBracket]180[t] + 
              1.5`\ B\[UnderBracket]194[t] + 1.5`\ B\[UnderBracket]196[t] - 
              9.`\ B\[UnderBracket]204[t] - 
              0.1`\ A\[UnderBracket]204[t]\^2\ B\[UnderBracket]204[t] + 
              1.5`\ B\[UnderBracket]206[t] + 1.5`\ B\[UnderBracket]214[t] + 
              1.5`\ B\[UnderBracket]217[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]205", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]205\)\((0.2`\ \
A\[UnderBracket]205[t] + 1.5`\ B\[UnderBracket]187[t] + 
              1.5`\ B\[UnderBracket]189[t] + 1.5`\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]202[t] - 10.5`\ B\[UnderBracket]205[t] - 
              0.1`\ A\[UnderBracket]205[t]\^2\ B\[UnderBracket]205[t] + 
              1.5`\ B\[UnderBracket]210[t] + 1.5`\ B\[UnderBracket]216[t] + 
              1.5`\ B\[UnderBracket]225[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]206", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]206\)\((0.2`\ \
A\[UnderBracket]206[t] + 1.5`\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]192[t] + 1.5`\ B\[UnderBracket]193[t] + 
              1.5`\ B\[UnderBracket]194[t] + 1.5`\ B\[UnderBracket]204[t] - 
              12.`\ B\[UnderBracket]206[t] - 
              0.1`\ A\[UnderBracket]206[t]\^2\ B\[UnderBracket]206[t] + 
              1.5`\ B\[UnderBracket]216[t] + 1.5`\ B\[UnderBracket]217[t] + 
              1.5`\ B\[UnderBracket]221[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]207", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]207\)\((0.2`\ \
A\[UnderBracket]207[t] + 1.5`\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]199[t] - 6.`\ B\[UnderBracket]207[t] - 
              0.1`\ A\[UnderBracket]207[t]\^2\ B\[UnderBracket]207[t] + 
              1.5`\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]215[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]208", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]208\)\((0.2`\ \
A\[UnderBracket]208[t] + 1.5`\ B\[UnderBracket]185[t] + 
              1.5`\ B\[UnderBracket]197[t] + 1.5`\ B\[UnderBracket]203[t] - 
              9.`\ B\[UnderBracket]208[t] - 
              0.1`\ A\[UnderBracket]208[t]\^2\ B\[UnderBracket]208[t] + 
              1.5`\ B\[UnderBracket]209[t] + 1.5`\ B\[UnderBracket]219[t] + 
              1.5`\ B\[UnderBracket]226[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]209", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]209\)\((0.2`\ \
A\[UnderBracket]209[t] + 1.5`\ B\[UnderBracket]197[t] + 
              1.5`\ B\[UnderBracket]201[t] + 1.5`\ B\[UnderBracket]208[t] - 
              9.`\ B\[UnderBracket]209[t] - 
              0.1`\ A\[UnderBracket]209[t]\^2\ B\[UnderBracket]209[t] + 
              1.5`\ B\[UnderBracket]220[t] + 1.5`\ B\[UnderBracket]226[t] + 
              1.5`\ B\[UnderBracket]227[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]21", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]21\)\((0.2`\ \
A\[UnderBracket]21[t] + 1.5`\ B\[UnderBracket]15[t] - 
              6.`\ B\[UnderBracket]21[t] - 
              0.1`\ A\[UnderBracket]21[t]\^2\ B\[UnderBracket]21[t] + 
              1.5`\ B\[UnderBracket]29[t] + 1.5`\ B\[UnderBracket]36[t] + 
              1.5`\ B\[UnderBracket]47[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]210", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]210\)\((0.2`\ \
A\[UnderBracket]210[t] + 1.5`\ B\[UnderBracket]202[t] + 
              1.5`\ B\[UnderBracket]205[t] - 7.5`\ B\[UnderBracket]210[t] - 
              0.1`\ A\[UnderBracket]210[t]\^2\ B\[UnderBracket]210[t] + 
              1.5`\ B\[UnderBracket]213[t] + 1.5`\ B\[UnderBracket]224[t] + 
              1.5`\ B\[UnderBracket]225[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]211", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]211[t] + 
                1.5`\ B\[UnderBracket]196[t] + 1.5`\ B\[UnderBracket]200[t] - 
                4.5`\ B\[UnderBracket]211[t] - 
                0.1`\ A\[UnderBracket]211[t]\^2\ B\[UnderBracket]211[t] + 
                1.5`\ B\[UnderBracket]214[t]\)\/cell\[UnderBracket]211\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]212", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]212\)\((0.2`\ \
A\[UnderBracket]212[t] + 1.5`\ B\[UnderBracket]199[t] + 
              1.5`\ B\[UnderBracket]207[t] - 9.`\ B\[UnderBracket]212[t] - 
              0.1`\ A\[UnderBracket]212[t]\^2\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]215[t] + 1.5`\ B\[UnderBracket]222[t] + 
              1.5`\ B\[UnderBracket]223[t] + 
              1.5`\ B\[UnderBracket]230[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]213", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]213\)\((0.2`\ \
A\[UnderBracket]213[t] + 1.5`\ B\[UnderBracket]195[t] + 
              1.5`\ B\[UnderBracket]202[t] + 1.5`\ B\[UnderBracket]210[t] - 
              7.5`\ B\[UnderBracket]213[t] - 
              0.1`\ A\[UnderBracket]213[t]\^2\ B\[UnderBracket]213[t] + 
              1.5`\ B\[UnderBracket]222[t] + 
              1.5`\ B\[UnderBracket]224[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]214", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]214\)\((0.2`\ \
A\[UnderBracket]214[t] + 1.5`\ B\[UnderBracket]196[t] + 
              1.5`\ B\[UnderBracket]204[t] + 1.5`\ B\[UnderBracket]211[t] - 
              6.`\ B\[UnderBracket]214[t] - 
              0.1`\ A\[UnderBracket]214[t]\^2\ B\[UnderBracket]214[t] + 
              1.5`\ B\[UnderBracket]217[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]215", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]215\)\((0.2`\ \
A\[UnderBracket]215[t] + 1.5`\ B\[UnderBracket]190[t] + 
              1.5`\ B\[UnderBracket]198[t] + 1.5`\ B\[UnderBracket]207[t] + 
              1.5`\ B\[UnderBracket]212[t] - 15.`\ B\[UnderBracket]215[t] - 
              0.1`\ A\[UnderBracket]215[t]\^2\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]218[t] + 1.5`\ B\[UnderBracket]228[t] + 
              1.5`\ B\[UnderBracket]230[t] + 1.5`\ B\[UnderBracket]232[t] + 
              1.5`\ B\[UnderBracket]233[t] + 
              1.5`\ B\[UnderBracket]235[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]216", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]216\)\((0.2`\ \
A\[UnderBracket]216[t] + 1.5`\ B\[UnderBracket]191[t] + 
              1.5`\ B\[UnderBracket]205[t] + 1.5`\ B\[UnderBracket]206[t] - 
              9.`\ B\[UnderBracket]216[t] - 
              0.1`\ A\[UnderBracket]216[t]\^2\ B\[UnderBracket]216[t] + 
              1.5`\ B\[UnderBracket]221[t] + 1.5`\ B\[UnderBracket]225[t] + 
              1.5`\ B\[UnderBracket]234[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]217", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]217\)\((0.2`\ \
A\[UnderBracket]217[t] + 1.5`\ B\[UnderBracket]204[t] + 
              1.5`\ B\[UnderBracket]206[t] + 1.5`\ B\[UnderBracket]214[t] - 
              6.`\ B\[UnderBracket]217[t] - 
              0.1`\ A\[UnderBracket]217[t]\^2\ B\[UnderBracket]217[t] + 
              1.5`\ B\[UnderBracket]221[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]218", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]218\)\((0.2`\ \
A\[UnderBracket]218[t] + 1.5`\ B\[UnderBracket]188[t] + 
              1.5`\ B\[UnderBracket]198[t] + 1.5`\ B\[UnderBracket]201[t] + 
              1.5`\ B\[UnderBracket]215[t] - 10.5`\ B\[UnderBracket]218[t] - 
              0.1`\ A\[UnderBracket]218[t]\^2\ B\[UnderBracket]218[t] + 
              1.5`\ B\[UnderBracket]220[t] + 1.5`\ B\[UnderBracket]228[t] + 
              1.5`\ B\[UnderBracket]229[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]219", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]219\)\((0.2`\ \
A\[UnderBracket]219[t] + 1.5`\ B\[UnderBracket]203[t] + 
              1.5`\ B\[UnderBracket]208[t] - 6.`\ B\[UnderBracket]219[t] - 
              0.1`\ A\[UnderBracket]219[t]\^2\ B\[UnderBracket]219[t] + 
              1.5`\ B\[UnderBracket]226[t] + 
              1.5`\ B\[UnderBracket]237[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]22", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]22\)\((0.2`\ \
A\[UnderBracket]22[t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]12[t] - 9.`\ B\[UnderBracket]22[t] - 
              0.1`\ A\[UnderBracket]22[t]\^2\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]24[t] + 1.5`\ B\[UnderBracket]37[t] + 
              1.5`\ B\[UnderBracket]43[t] + 1.5`\ B\[UnderBracket]6[t])\)\)}],
         ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]220", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]220\)\((0.2`\ \
A\[UnderBracket]220[t] + 1.5`\ B\[UnderBracket]201[t] + 
              1.5`\ B\[UnderBracket]209[t] + 1.5`\ B\[UnderBracket]218[t] - 
              7.5`\ B\[UnderBracket]220[t] - 
              0.1`\ A\[UnderBracket]220[t]\^2\ B\[UnderBracket]220[t] + 
              1.5`\ B\[UnderBracket]227[t] + 
              1.5`\ B\[UnderBracket]229[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]221", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]221[t] + 
                1.5`\ B\[UnderBracket]206[t] + 1.5`\ B\[UnderBracket]216[t] + 
                1.5`\ B\[UnderBracket]217[t] - 4.5`\ B\[UnderBracket]221[t] - 
                0.1`\ A\[UnderBracket]221[t]\^2\ B\[UnderBracket]221[
                    t]\)\/cell\[UnderBracket]221\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]222", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]222\)\((0.2`\ \
A\[UnderBracket]222[t] + 1.5`\ B\[UnderBracket]195[t] + 
              1.5`\ B\[UnderBracket]199[t] + 1.5`\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]213[t] - 10.5`\ B\[UnderBracket]222[t] - 
              0.1`\ A\[UnderBracket]222[t]\^2\ B\[UnderBracket]222[t] + 
              1.5`\ B\[UnderBracket]223[t] + 1.5`\ B\[UnderBracket]224[t] + 
              1.5`\ B\[UnderBracket]231[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]223", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]223\)\((0.2`\ \
A\[UnderBracket]223[t] + 1.5`\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]222[t] - 9.`\ B\[UnderBracket]223[t] - 
              0.1`\ A\[UnderBracket]223[t]\^2\ B\[UnderBracket]223[t] + 
              1.5`\ B\[UnderBracket]230[t] + 1.5`\ B\[UnderBracket]231[t] + 
              1.5`\ B\[UnderBracket]236[t] + 
              1.5`\ B\[UnderBracket]238[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]224", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]224\)\((0.2`\ \
A\[UnderBracket]224[t] + 1.5`\ B\[UnderBracket]210[t] + 
              1.5`\ B\[UnderBracket]213[t] + 1.5`\ B\[UnderBracket]222[t] - 
              7.5`\ B\[UnderBracket]224[t] - 
              0.1`\ A\[UnderBracket]224[t]\^2\ B\[UnderBracket]224[t] + 
              1.5`\ B\[UnderBracket]225[t] + 
              1.5`\ B\[UnderBracket]231[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]225", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]225\)\((0.2`\ \
A\[UnderBracket]225[t] + 1.5`\ B\[UnderBracket]205[t] + 
              1.5`\ B\[UnderBracket]210[t] + 1.5`\ B\[UnderBracket]216[t] + 
              1.5`\ B\[UnderBracket]224[t] - 9.`\ B\[UnderBracket]225[t] - 
              0.1`\ A\[UnderBracket]225[t]\^2\ B\[UnderBracket]225[t] + 
              1.5`\ B\[UnderBracket]231[t] + 
              1.5`\ B\[UnderBracket]234[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]226", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]226\)\((0.2`\ \
A\[UnderBracket]226[t] + 1.5`\ B\[UnderBracket]208[t] + 
              1.5`\ B\[UnderBracket]209[t] + 1.5`\ B\[UnderBracket]219[t] - 
              9.`\ B\[UnderBracket]226[t] - 
              0.1`\ A\[UnderBracket]226[t]\^2\ B\[UnderBracket]226[t] + 
              1.5`\ B\[UnderBracket]227[t] + 1.5`\ B\[UnderBracket]237[t] + 
              1.5`\ B\[UnderBracket]239[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]227", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]227\)\((0.2`\ \
A\[UnderBracket]227[t] + 1.5`\ B\[UnderBracket]209[t] + 
              1.5`\ B\[UnderBracket]220[t] + 1.5`\ B\[UnderBracket]226[t] - 
              7.5`\ B\[UnderBracket]227[t] - 
              0.1`\ A\[UnderBracket]227[t]\^2\ B\[UnderBracket]227[t] + 
              1.5`\ B\[UnderBracket]229[t] + 
              1.5`\ B\[UnderBracket]239[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]228", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]228\)\((0.2`\ \
A\[UnderBracket]228[t] + 1.5`\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]218[t] - 7.5`\ B\[UnderBracket]228[t] - 
              0.1`\ A\[UnderBracket]228[t]\^2\ B\[UnderBracket]228[t] + 
              1.5`\ B\[UnderBracket]229[t] + 1.5`\ B\[UnderBracket]235[t] + 
              1.5`\ B\[UnderBracket]240[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]229", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]229\)\((0.2`\ \
A\[UnderBracket]229[t] + 1.5`\ B\[UnderBracket]218[t] + 
              1.5`\ B\[UnderBracket]220[t] + 1.5`\ B\[UnderBracket]227[t] + 
              1.5`\ B\[UnderBracket]228[t] - 10.5`\ B\[UnderBracket]229[t] - 
              0.1`\ A\[UnderBracket]229[t]\^2\ B\[UnderBracket]229[t] + 
              1.5`\ B\[UnderBracket]239[t] + 1.5`\ B\[UnderBracket]240[t] + 
              1.5`\ B\[UnderBracket]242[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]23", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]23\)\((0.2`\ \
A\[UnderBracket]23[t] + 1.5`\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]17[t] - 7.5`\ B\[UnderBracket]23[t] - 
              0.1`\ A\[UnderBracket]23[t]\^2\ B\[UnderBracket]23[t] + 
              1.5`\ B\[UnderBracket]33[t] + 1.5`\ B\[UnderBracket]45[t] + 
              1.5`\ B\[UnderBracket]54[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]230", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]230\)\((0.2`\ \
A\[UnderBracket]230[t] + 1.5`\ B\[UnderBracket]212[t] + 
              1.5`\ B\[UnderBracket]215[t] + 1.5`\ B\[UnderBracket]223[t] - 
              9.`\ B\[UnderBracket]230[t] - 
              0.1`\ A\[UnderBracket]230[t]\^2\ B\[UnderBracket]230[t] + 
              1.5`\ B\[UnderBracket]232[t] + 1.5`\ B\[UnderBracket]236[t] + 
              1.5`\ B\[UnderBracket]245[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]231", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]231\)\((0.2`\ \
A\[UnderBracket]231[t] + 1.5`\ B\[UnderBracket]222[t] + 
              1.5`\ B\[UnderBracket]223[t] + 1.5`\ B\[UnderBracket]224[t] + 
              1.5`\ B\[UnderBracket]225[t] - 10.5`\ B\[UnderBracket]231[t] - 
              0.1`\ A\[UnderBracket]231[t]\^2\ B\[UnderBracket]231[t] + 
              1.5`\ B\[UnderBracket]234[t] + 1.5`\ B\[UnderBracket]238[t] + 
              1.5`\ B\[UnderBracket]244[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]232", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]232\)\((0.2`\ \
A\[UnderBracket]232[t] + 1.5`\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]230[t] - 6.`\ B\[UnderBracket]232[t] - 
              0.1`\ A\[UnderBracket]232[t]\^2\ B\[UnderBracket]232[t] + 
              1.5`\ B\[UnderBracket]233[t] + 
              1.5`\ B\[UnderBracket]245[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]233", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]233\)\((0.2`\ \
A\[UnderBracket]233[t] + 1.5`\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]232[t] - 7.5`\ B\[UnderBracket]233[t] - 
              0.1`\ A\[UnderBracket]233[t]\^2\ B\[UnderBracket]233[t] + 
              1.5`\ B\[UnderBracket]235[t] + 1.5`\ B\[UnderBracket]241[t] + 
              1.5`\ B\[UnderBracket]245[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]234", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]234\)\((0.2`\ \
A\[UnderBracket]234[t] + 1.5`\ B\[UnderBracket]216[t] + 
              1.5`\ B\[UnderBracket]225[t] + 1.5`\ B\[UnderBracket]231[t] - 
              6.`\ B\[UnderBracket]234[t] - 
              0.1`\ A\[UnderBracket]234[t]\^2\ B\[UnderBracket]234[t] + 
              1.5`\ B\[UnderBracket]244[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]235", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]235\)\((0.2`\ \
A\[UnderBracket]235[t] + 1.5`\ B\[UnderBracket]215[t] + 
              1.5`\ B\[UnderBracket]228[t] + 1.5`\ B\[UnderBracket]233[t] - 
              9.`\ B\[UnderBracket]235[t] - 
              0.1`\ A\[UnderBracket]235[t]\^2\ B\[UnderBracket]235[t] + 
              1.5`\ B\[UnderBracket]240[t] + 1.5`\ B\[UnderBracket]241[t] + 
              1.5`\ B\[UnderBracket]243[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]236", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]236\)\((0.2`\ \
A\[UnderBracket]236[t] + 1.5`\ B\[UnderBracket]223[t] + 
              1.5`\ B\[UnderBracket]230[t] - 7.5`\ B\[UnderBracket]236[t] - 
              0.1`\ A\[UnderBracket]236[t]\^2\ B\[UnderBracket]236[t] + 
              1.5`\ B\[UnderBracket]238[t] + 1.5`\ B\[UnderBracket]245[t] + 
              1.5`\ B\[UnderBracket]248[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]237", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]237\)\((0.2`\ \
A\[UnderBracket]237[t] + 1.5`\ B\[UnderBracket]219[t] + 
              1.5`\ B\[UnderBracket]226[t] - 6.`\ B\[UnderBracket]237[t] - 
              0.1`\ A\[UnderBracket]237[t]\^2\ B\[UnderBracket]237[t] + 
              1.5`\ B\[UnderBracket]239[t] + 
              1.5`\ B\[UnderBracket]249[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]238", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]238\)\((0.2`\ \
A\[UnderBracket]238[t] + 1.5`\ B\[UnderBracket]223[t] + 
              1.5`\ B\[UnderBracket]231[t] + 1.5`\ B\[UnderBracket]236[t] - 
              9.`\ B\[UnderBracket]238[t] - 
              0.1`\ A\[UnderBracket]238[t]\^2\ B\[UnderBracket]238[t] + 
              1.5`\ B\[UnderBracket]244[t] + 1.5`\ B\[UnderBracket]246[t] + 
              1.5`\ B\[UnderBracket]248[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]239", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]239\)\((0.2`\ \
A\[UnderBracket]239[t] + 1.5`\ B\[UnderBracket]226[t] + 
              1.5`\ B\[UnderBracket]227[t] + 1.5`\ B\[UnderBracket]229[t] + 
              1.5`\ B\[UnderBracket]237[t] - 10.5`\ B\[UnderBracket]239[t] - 
              0.1`\ A\[UnderBracket]239[t]\^2\ B\[UnderBracket]239[t] + 
              1.5`\ B\[UnderBracket]242[t] + 1.5`\ B\[UnderBracket]249[t] + 
              1.5`\ B\[UnderBracket]250[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]24", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]24\)\((0.2`\ \
A\[UnderBracket]24[t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]22[t] - 6.`\ B\[UnderBracket]24[t] - 
              0.1`\ A\[UnderBracket]24[t]\^2\ B\[UnderBracket]24[t] + 
              1.5`\ B\[UnderBracket]25[t] + 
              1.5`\ B\[UnderBracket]37[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]240", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]240\)\((0.2`\ \
A\[UnderBracket]240[t] + 1.5`\ B\[UnderBracket]228[t] + 
              1.5`\ B\[UnderBracket]229[t] + 1.5`\ B\[UnderBracket]235[t] - 
              9.`\ B\[UnderBracket]240[t] - 
              0.1`\ A\[UnderBracket]240[t]\^2\ B\[UnderBracket]240[t] + 
              1.5`\ B\[UnderBracket]242[t] + 1.5`\ B\[UnderBracket]243[t] + 
              1.5`\ B\[UnderBracket]247[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]241", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]241\)\((0.2`\ \
A\[UnderBracket]241[t] + 1.5`\ B\[UnderBracket]233[t] + 
              1.5`\ B\[UnderBracket]235[t] - 10.5`\ B\[UnderBracket]241[t] - 
              0.1`\ A\[UnderBracket]241[t]\^2\ B\[UnderBracket]241[t] + 
              1.5`\ B\[UnderBracket]243[t] + 1.5`\ B\[UnderBracket]245[t] + 
              1.5`\ B\[UnderBracket]247[t] + 1.5`\ B\[UnderBracket]251[t] + 
              1.5`\ B\[UnderBracket]253[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]242", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]242\)\((0.2`\ \
A\[UnderBracket]242[t] + 1.5`\ B\[UnderBracket]229[t] + 
              1.5`\ B\[UnderBracket]239[t] + 1.5`\ B\[UnderBracket]240[t] - 
              9.`\ B\[UnderBracket]242[t] - 
              0.1`\ A\[UnderBracket]242[t]\^2\ B\[UnderBracket]242[t] + 
              1.5`\ B\[UnderBracket]247[t] + 1.5`\ B\[UnderBracket]250[t] + 
              1.5`\ B\[UnderBracket]252[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]243", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]243\)\((0.2`\ \
A\[UnderBracket]243[t] + 1.5`\ B\[UnderBracket]235[t] + 
              1.5`\ B\[UnderBracket]240[t] + 1.5`\ B\[UnderBracket]241[t] - 
              6.`\ B\[UnderBracket]243[t] - 
              0.1`\ A\[UnderBracket]243[t]\^2\ B\[UnderBracket]243[t] + 
              1.5`\ B\[UnderBracket]247[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]244", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]244\)\((0.2`\ \
A\[UnderBracket]244[t] + 1.5`\ B\[UnderBracket]231[t] + 
              1.5`\ B\[UnderBracket]234[t] + 1.5`\ B\[UnderBracket]238[t] - 
              6.`\ B\[UnderBracket]244[t] - 
              0.1`\ A\[UnderBracket]244[t]\^2\ B\[UnderBracket]244[t] + 
              1.5`\ B\[UnderBracket]246[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]245", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]245\)\((0.2`\ \
A\[UnderBracket]245[t] + 1.5`\ B\[UnderBracket]230[t] + 
              1.5`\ B\[UnderBracket]232[t] + 1.5`\ B\[UnderBracket]233[t] + 
              1.5`\ B\[UnderBracket]236[t] + 1.5`\ B\[UnderBracket]241[t] - 
              10.5`\ B\[UnderBracket]245[t] - 
              0.1`\ A\[UnderBracket]245[t]\^2\ B\[UnderBracket]245[t] + 
              1.5`\ B\[UnderBracket]248[t] + 
              1.5`\ B\[UnderBracket]251[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]246", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]246[t] + 
                1.5`\ B\[UnderBracket]238[t] + 1.5`\ B\[UnderBracket]244[t] - 
                4.5`\ B\[UnderBracket]246[t] - 
                0.1`\ A\[UnderBracket]246[t]\^2\ B\[UnderBracket]246[t] + 
                1.5`\ B\[UnderBracket]248[t]\)\/cell\[UnderBracket]246\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]247", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]247\)\((0.2`\ \
A\[UnderBracket]247[t] + 1.5`\ B\[UnderBracket]240[t] + 
              1.5`\ B\[UnderBracket]241[t] + 1.5`\ B\[UnderBracket]242[t] + 
              1.5`\ B\[UnderBracket]243[t] - 9.`\ B\[UnderBracket]247[t] - 
              0.1`\ A\[UnderBracket]247[t]\^2\ B\[UnderBracket]247[t] + 
              1.5`\ B\[UnderBracket]252[t] + 
              1.5`\ B\[UnderBracket]253[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]248", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]248\)\((0.2`\ \
A\[UnderBracket]248[t] + 1.5`\ B\[UnderBracket]236[t] + 
              1.5`\ B\[UnderBracket]238[t] + 1.5`\ B\[UnderBracket]245[t] + 
              1.5`\ B\[UnderBracket]246[t] - 6.`\ B\[UnderBracket]248[t] - 
              0.1`\ A\[UnderBracket]248[t]\^2\ B\[UnderBracket]248[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]249", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]249[t] + 
                1.5`\ B\[UnderBracket]237[t] + 1.5`\ B\[UnderBracket]239[t] - 
                4.5`\ B\[UnderBracket]249[t] - 
                0.1`\ A\[UnderBracket]249[t]\^2\ B\[UnderBracket]249[t] + 
                1.5`\ B\[UnderBracket]250[t]\)\/cell\[UnderBracket]249\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]25", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]25\)\((0.2`\ \
A\[UnderBracket]25[t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]24[t] - 7.5`\ B\[UnderBracket]25[t] - 
              0.1`\ A\[UnderBracket]25[t]\^2\ B\[UnderBracket]25[t] + 
              1.5`\ B\[UnderBracket]26[t] + 1.5`\ B\[UnderBracket]37[t] + 
              1.5`\ B\[UnderBracket]39[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]250", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]250\)\((0.2`\ \
A\[UnderBracket]250[t] + 1.5`\ B\[UnderBracket]239[t] + 
              1.5`\ B\[UnderBracket]242[t] + 1.5`\ B\[UnderBracket]249[t] - 
              6.`\ B\[UnderBracket]250[t] - 
              0.1`\ A\[UnderBracket]250[t]\^2\ B\[UnderBracket]250[t] + 
              1.5`\ B\[UnderBracket]252[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]251", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]251[t] + 
                1.5`\ B\[UnderBracket]241[t] + 1.5`\ B\[UnderBracket]245[t] - 
                4.5`\ B\[UnderBracket]251[t] - 
                0.1`\ A\[UnderBracket]251[t]\^2\ B\[UnderBracket]251[t] + 
                1.5`\ B\[UnderBracket]253[t]\)\/cell\[UnderBracket]251\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]252", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]252\)\((0.2`\ \
A\[UnderBracket]252[t] + 1.5`\ B\[UnderBracket]242[t] + 
              1.5`\ B\[UnderBracket]247[t] + 1.5`\ B\[UnderBracket]250[t] - 
              6.`\ B\[UnderBracket]252[t] - 
              0.1`\ A\[UnderBracket]252[t]\^2\ B\[UnderBracket]252[t] + 
              1.5`\ B\[UnderBracket]253[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]253", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]253\)\((0.2`\ \
A\[UnderBracket]253[t] + 1.5`\ B\[UnderBracket]241[t] + 
              1.5`\ B\[UnderBracket]247[t] + 1.5`\ B\[UnderBracket]251[t] + 
              1.5`\ B\[UnderBracket]252[t] - 6.`\ B\[UnderBracket]253[t] - 
              0.1`\ A\[UnderBracket]253[t]\^2\ B\[UnderBracket]253[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]26", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]26\)\((0.2`\ \
A\[UnderBracket]26[t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]13[t] + 1.5`\ B\[UnderBracket]25[t] - 
              6.`\ B\[UnderBracket]26[t] - 
              0.1`\ A\[UnderBracket]26[t]\^2\ B\[UnderBracket]26[t] + 
              1.5`\ B\[UnderBracket]39[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]27", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]27\)\((0.2`\ \
A\[UnderBracket]27[t] + 1.5`\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]18[t] - 7.5`\ B\[UnderBracket]27[t] - 
              0.1`\ A\[UnderBracket]27[t]\^2\ B\[UnderBracket]27[t] + 
              1.5`\ B\[UnderBracket]31[t] + 1.5`\ B\[UnderBracket]33[t] + 
              1.5`\ B\[UnderBracket]9[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]28", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]28\)\((0.2`\ \
A\[UnderBracket]28[t] + 1.5`\ B\[UnderBracket]10[t] + 
              1.5`\ B\[UnderBracket]18[t] + 1.5`\ B\[UnderBracket]19[t] - 
              9.`\ B\[UnderBracket]28[t] - 
              0.1`\ A\[UnderBracket]28[t]\^2\ B\[UnderBracket]28[t] + 
              1.5`\ B\[UnderBracket]31[t] + 1.5`\ B\[UnderBracket]32[t] + 
              1.5`\ B\[UnderBracket]44[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]29", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]29\)\((0.2`\ \
A\[UnderBracket]29[t] + 1.5`\ B\[UnderBracket]15[t] + 
              1.5`\ B\[UnderBracket]21[t] - 9.`\ B\[UnderBracket]29[t] - 
              0.1`\ A\[UnderBracket]29[t]\^2\ B\[UnderBracket]29[t] + 
              1.5`\ B\[UnderBracket]35[t] + 1.5`\ B\[UnderBracket]47[t] + 
              1.5`\ B\[UnderBracket]49[t] + 
              1.5`\ B\[UnderBracket]57[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]3", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]3[t] + 
                1.5`\ B\[UnderBracket]1[t] - 6.`\ B\[UnderBracket]3[t] - 
                0.1`\ A\[UnderBracket]3[t]\^2\ B\[UnderBracket]3[t] + 
                1.5`\ B\[UnderBracket]6[t] + 1.5`\ B\[UnderBracket]7[t] + 
                1.5`\ B\[UnderBracket]8[t]\)\/cell\[UnderBracket]3\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]30", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]30\)\((0.2`\ \
A\[UnderBracket]30[t] + 1.5`\ B\[UnderBracket]12[t] + 
              1.5`\ B\[UnderBracket]16[t] - 6.`\ B\[UnderBracket]30[t] - 
              0.1`\ A\[UnderBracket]30[t]\^2\ B\[UnderBracket]30[t] + 
              1.5`\ B\[UnderBracket]43[t] + 
              1.5`\ B\[UnderBracket]50[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]31", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]31\)\((0.2`\ \
A\[UnderBracket]31[t] + 1.5`\ B\[UnderBracket]18[t] + 
              1.5`\ B\[UnderBracket]27[t] + 1.5`\ B\[UnderBracket]28[t] - 
              9.`\ B\[UnderBracket]31[t] - 
              0.1`\ A\[UnderBracket]31[t]\^2\ B\[UnderBracket]31[t] + 
              1.5`\ B\[UnderBracket]33[t] + 1.5`\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]46[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]32", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]32\)\((0.2`\ \
A\[UnderBracket]32[t] + 1.5`\ B\[UnderBracket]19[t] + 
              1.5`\ B\[UnderBracket]28[t] - 6.`\ B\[UnderBracket]32[t] - 
              0.1`\ A\[UnderBracket]32[t]\^2\ B\[UnderBracket]32[t] + 
              1.5`\ B\[UnderBracket]38[t] + 
              1.5`\ B\[UnderBracket]44[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]33", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]33\)\((0.2`\ \
A\[UnderBracket]33[t] + 1.5`\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]23[t] + 1.5`\ B\[UnderBracket]27[t] + 
              1.5`\ B\[UnderBracket]31[t] - 9.`\ B\[UnderBracket]33[t] - 
              0.1`\ A\[UnderBracket]33[t]\^2\ B\[UnderBracket]33[t] + 
              1.5`\ B\[UnderBracket]45[t] + 
              1.5`\ B\[UnderBracket]46[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]34", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]34\)\((0.2`\ \
A\[UnderBracket]34[t] + 1.5`\ B\[UnderBracket]15[t] + 
              1.5`\ B\[UnderBracket]20[t] - 10.5`\ B\[UnderBracket]34[t] - 
              0.1`\ A\[UnderBracket]34[t]\^2\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]35[t] + 1.5`\ B\[UnderBracket]40[t] + 
              1.5`\ B\[UnderBracket]41[t] + 1.5`\ B\[UnderBracket]51[t] + 
              1.5`\ B\[UnderBracket]52[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]35", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]35\)\((0.2`\ \
A\[UnderBracket]35[t] + 1.5`\ B\[UnderBracket]15[t] + 
              1.5`\ B\[UnderBracket]29[t] + 1.5`\ B\[UnderBracket]34[t] - 
              9.`\ B\[UnderBracket]35[t] - 
              0.1`\ A\[UnderBracket]35[t]\^2\ B\[UnderBracket]35[t] + 
              1.5`\ B\[UnderBracket]41[t] + 1.5`\ B\[UnderBracket]57[t] + 
              1.5`\ B\[UnderBracket]60[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]36", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]36\)\((0.2`\ \
A\[UnderBracket]36[t] + 1.5`\ B\[UnderBracket]21[t] - 
              6.`\ B\[UnderBracket]36[t] - 
              0.1`\ A\[UnderBracket]36[t]\^2\ B\[UnderBracket]36[t] + 
              1.5`\ B\[UnderBracket]42[t] + 1.5`\ B\[UnderBracket]47[t] + 
              1.5`\ B\[UnderBracket]48[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]37", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]37\)\((0.2`\ \
A\[UnderBracket]37[t] + 1.5`\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]24[t] + 1.5`\ B\[UnderBracket]25[t] - 
              9.`\ B\[UnderBracket]37[t] - 
              0.1`\ A\[UnderBracket]37[t]\^2\ B\[UnderBracket]37[t] + 
              1.5`\ B\[UnderBracket]39[t] + 1.5`\ B\[UnderBracket]43[t] + 
              1.5`\ B\[UnderBracket]59[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]38", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]38\)\((0.2`\ \
A\[UnderBracket]38[t] + 1.5`\ B\[UnderBracket]19[t] + 
              1.5`\ B\[UnderBracket]32[t] - 9.`\ B\[UnderBracket]38[t] - 
              0.1`\ A\[UnderBracket]38[t]\^2\ B\[UnderBracket]38[t] + 
              1.5`\ B\[UnderBracket]40[t] + 1.5`\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]56[t] + 
              1.5`\ B\[UnderBracket]67[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]39", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]39\)\((0.2`\ \
A\[UnderBracket]39[t] + 1.5`\ B\[UnderBracket]13[t] + 
              1.5`\ B\[UnderBracket]17[t] + 1.5`\ B\[UnderBracket]25[t] + 
              1.5`\ B\[UnderBracket]26[t] + 1.5`\ B\[UnderBracket]37[t] - 
              12.`\ B\[UnderBracket]39[t] - 
              0.1`\ A\[UnderBracket]39[t]\^2\ B\[UnderBracket]39[t] + 
              1.5`\ B\[UnderBracket]53[t] + 1.5`\ B\[UnderBracket]59[t] + 
              1.5`\ B\[UnderBracket]65[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]4", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]4[t] + 
                1.5`\ B\[UnderBracket]10[t] + 1.5`\ B\[UnderBracket]2[t] - 
                6.`\ B\[UnderBracket]4[t] - 
                0.1`\ A\[UnderBracket]4[t]\^2\ B\[UnderBracket]4[t] + 
                1.5`\ B\[UnderBracket]5[t] + 
                1.5`\ B\[UnderBracket]9[t]\)\/cell\[UnderBracket]4\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]40", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]40\)\((0.2`\ \
A\[UnderBracket]40[t] + 1.5`\ B\[UnderBracket]19[t] + 
              1.5`\ B\[UnderBracket]20[t] + 1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]38[t] - 9.`\ B\[UnderBracket]40[t] - 
              0.1`\ A\[UnderBracket]40[t]\^2\ B\[UnderBracket]40[t] + 
              1.5`\ B\[UnderBracket]51[t] + 
              1.5`\ B\[UnderBracket]56[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]41", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]41\)\((0.2`\ \
A\[UnderBracket]41[t] + 1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]35[t] - 6.`\ B\[UnderBracket]41[t] - 
              0.1`\ A\[UnderBracket]41[t]\^2\ B\[UnderBracket]41[t] + 
              1.5`\ B\[UnderBracket]52[t] + 
              1.5`\ B\[UnderBracket]60[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]42", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]42[t] + 
                1.5`\ B\[UnderBracket]36[t] - 4.5`\ B\[UnderBracket]42[t] - 
                0.1`\ A\[UnderBracket]42[t]\^2\ B\[UnderBracket]42[t] + 
                1.5`\ B\[UnderBracket]48[t] + 
                1.5`\ B\[UnderBracket]58[t]\)\/cell\[UnderBracket]42\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]43", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]43\)\((0.2`\ \
A\[UnderBracket]43[t] + 1.5`\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]30[t] + 1.5`\ B\[UnderBracket]37[t] - 
              10.5`\ B\[UnderBracket]43[t] - 
              0.1`\ A\[UnderBracket]43[t]\^2\ B\[UnderBracket]43[t] + 
              1.5`\ B\[UnderBracket]50[t] + 1.5`\ B\[UnderBracket]59[t] + 
              1.5`\ B\[UnderBracket]61[t] + 
              1.5`\ B\[UnderBracket]64[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]44", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]44\)\((0.2`\ \
A\[UnderBracket]44[t] + 1.5`\ B\[UnderBracket]28[t] + 
              1.5`\ B\[UnderBracket]31[t] + 1.5`\ B\[UnderBracket]32[t] + 
              1.5`\ B\[UnderBracket]38[t] - 12.`\ B\[UnderBracket]44[t] - 
              0.1`\ A\[UnderBracket]44[t]\^2\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]46[t] + 1.5`\ B\[UnderBracket]55[t] + 
              1.5`\ B\[UnderBracket]66[t] + 
              1.5`\ B\[UnderBracket]67[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]45", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]45\)\((0.2`\ \
A\[UnderBracket]45[t] + 1.5`\ B\[UnderBracket]23[t] + 
              1.5`\ B\[UnderBracket]33[t] - 7.5`\ B\[UnderBracket]45[t] - 
              0.1`\ A\[UnderBracket]45[t]\^2\ B\[UnderBracket]45[t] + 
              1.5`\ B\[UnderBracket]46[t] + 1.5`\ B\[UnderBracket]54[t] + 
              1.5`\ B\[UnderBracket]75[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]46", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]46\)\((0.2`\ \
A\[UnderBracket]46[t] + 1.5`\ B\[UnderBracket]31[t] + 
              1.5`\ B\[UnderBracket]33[t] + 1.5`\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]45[t] - 10.5`\ B\[UnderBracket]46[t] - 
              0.1`\ A\[UnderBracket]46[t]\^2\ B\[UnderBracket]46[t] + 
              1.5`\ B\[UnderBracket]55[t] + 1.5`\ B\[UnderBracket]68[t] + 
              1.5`\ B\[UnderBracket]69[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]47", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]47\)\((0.2`\ \
A\[UnderBracket]47[t] + 1.5`\ B\[UnderBracket]21[t] + 
              1.5`\ B\[UnderBracket]29[t] + 1.5`\ B\[UnderBracket]36[t] - 
              9.`\ B\[UnderBracket]47[t] - 
              0.1`\ A\[UnderBracket]47[t]\^2\ B\[UnderBracket]47[t] + 
              1.5`\ B\[UnderBracket]48[t] + 1.5`\ B\[UnderBracket]49[t] + 
              1.5`\ B\[UnderBracket]63[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]48", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]48\)\((0.2`\ \
A\[UnderBracket]48[t] + 1.5`\ B\[UnderBracket]36[t] + 
              1.5`\ B\[UnderBracket]42[t] + 1.5`\ B\[UnderBracket]47[t] - 
              10.5`\ B\[UnderBracket]48[t] - 
              0.1`\ A\[UnderBracket]48[t]\^2\ B\[UnderBracket]48[t] + 
              1.5`\ B\[UnderBracket]58[t] + 1.5`\ B\[UnderBracket]63[t] + 
              1.5`\ B\[UnderBracket]73[t] + 
              1.5`\ B\[UnderBracket]77[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]49", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]49\)\((0.2`\ \
A\[UnderBracket]49[t] + 1.5`\ B\[UnderBracket]29[t] + 
              1.5`\ B\[UnderBracket]47[t] - 7.5`\ B\[UnderBracket]49[t] - 
              0.1`\ A\[UnderBracket]49[t]\^2\ B\[UnderBracket]49[t] + 
              1.5`\ B\[UnderBracket]57[t] + 1.5`\ B\[UnderBracket]63[t] + 
              1.5`\ B\[UnderBracket]76[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]5", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]5\)\((0.2`\ A\[UnderBracket]5[
                  t] + 1.5`\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]2[t] + 1.5`\ B\[UnderBracket]4[t] - 
              7.5`\ B\[UnderBracket]5[t] - 
              0.1`\ A\[UnderBracket]5[t]\^2\ B\[UnderBracket]5[t] + 
              1.5`\ B\[UnderBracket]8[t] + 1.5`\ B\[UnderBracket]9[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]50", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]50\)\((0.2`\ \
A\[UnderBracket]50[t] + 1.5`\ B\[UnderBracket]30[t] + 
              1.5`\ B\[UnderBracket]43[t] - 6.`\ B\[UnderBracket]50[t] - 
              0.1`\ A\[UnderBracket]50[t]\^2\ B\[UnderBracket]50[t] + 
              1.5`\ B\[UnderBracket]61[t] + 
              1.5`\ B\[UnderBracket]82[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]51", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]51\)\((0.2`\ \
A\[UnderBracket]51[t] + 1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]40[t] - 10.5`\ B\[UnderBracket]51[t] - 
              0.1`\ A\[UnderBracket]51[t]\^2\ B\[UnderBracket]51[t] + 
              1.5`\ B\[UnderBracket]52[t] + 1.5`\ B\[UnderBracket]56[t] + 
              1.5`\ B\[UnderBracket]71[t] + 1.5`\ B\[UnderBracket]72[t] + 
              1.5`\ B\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]52", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]52\)\((0.2`\ \
A\[UnderBracket]52[t] + 1.5`\ B\[UnderBracket]34[t] + 
              1.5`\ B\[UnderBracket]41[t] + 1.5`\ B\[UnderBracket]51[t] - 
              7.5`\ B\[UnderBracket]52[t] - 
              0.1`\ A\[UnderBracket]52[t]\^2\ B\[UnderBracket]52[t] + 
              1.5`\ B\[UnderBracket]60[t] + 
              1.5`\ B\[UnderBracket]72[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]53", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]53\)\((0.2`\ \
A\[UnderBracket]53[t] + 1.5`\ B\[UnderBracket]17[t] + 
              1.5`\ B\[UnderBracket]39[t] - 9.`\ B\[UnderBracket]53[t] - 
              0.1`\ A\[UnderBracket]53[t]\^2\ B\[UnderBracket]53[t] + 
              1.5`\ B\[UnderBracket]54[t] + 1.5`\ B\[UnderBracket]65[t] + 
              1.5`\ B\[UnderBracket]70[t] + 
              1.5`\ B\[UnderBracket]74[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]54", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]54\)\((0.2`\ \
A\[UnderBracket]54[t] + 1.5`\ B\[UnderBracket]17[t] + 
              1.5`\ B\[UnderBracket]23[t] + 1.5`\ B\[UnderBracket]45[t] + 
              1.5`\ B\[UnderBracket]53[t] - 9.`\ B\[UnderBracket]54[t] - 
              0.1`\ A\[UnderBracket]54[t]\^2\ B\[UnderBracket]54[t] + 
              1.5`\ B\[UnderBracket]74[t] + 
              1.5`\ B\[UnderBracket]75[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]55", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]55\)\((0.2`\ \
A\[UnderBracket]55[t] + 1.5`\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]46[t] - 7.5`\ B\[UnderBracket]55[t] - 
              0.1`\ A\[UnderBracket]55[t]\^2\ B\[UnderBracket]55[t] + 
              1.5`\ B\[UnderBracket]66[t] + 1.5`\ B\[UnderBracket]69[t] + 
              1.5`\ B\[UnderBracket]86[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]56", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]56\)\((0.2`\ \
A\[UnderBracket]56[t] + 1.5`\ B\[UnderBracket]38[t] + 
              1.5`\ B\[UnderBracket]40[t] + 1.5`\ B\[UnderBracket]51[t] - 
              9.`\ B\[UnderBracket]56[t] - 
              0.1`\ A\[UnderBracket]56[t]\^2\ B\[UnderBracket]56[t] + 
              1.5`\ B\[UnderBracket]62[t] + 1.5`\ B\[UnderBracket]67[t] + 
              1.5`\ B\[UnderBracket]71[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]57", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]57\)\((0.2`\ \
A\[UnderBracket]57[t] + 1.5`\ B\[UnderBracket]29[t] + 
              1.5`\ B\[UnderBracket]35[t] + 1.5`\ B\[UnderBracket]49[t] - 
              10.5`\ B\[UnderBracket]57[t] - 
              0.1`\ A\[UnderBracket]57[t]\^2\ B\[UnderBracket]57[t] + 
              1.5`\ B\[UnderBracket]60[t] + 1.5`\ B\[UnderBracket]76[t] + 
              1.5`\ B\[UnderBracket]81[t] + 
              1.5`\ B\[UnderBracket]85[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]58", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]58\)\((0.2`\ \
A\[UnderBracket]58[t] + 1.5`\ B\[UnderBracket]42[t] + 
              1.5`\ B\[UnderBracket]48[t] - 6.`\ B\[UnderBracket]58[t] - 
              0.1`\ A\[UnderBracket]58[t]\^2\ B\[UnderBracket]58[t] + 
              1.5`\ B\[UnderBracket]77[t] + 
              1.5`\ B\[UnderBracket]78[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]59", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]59\)\((0.2`\ \
A\[UnderBracket]59[t] + 1.5`\ B\[UnderBracket]37[t] + 
              1.5`\ B\[UnderBracket]39[t] + 1.5`\ B\[UnderBracket]43[t] - 
              10.5`\ B\[UnderBracket]59[t] - 
              0.1`\ A\[UnderBracket]59[t]\^2\ B\[UnderBracket]59[t] + 
              1.5`\ B\[UnderBracket]64[t] + 1.5`\ B\[UnderBracket]65[t] + 
              1.5`\ B\[UnderBracket]83[t] + 
              1.5`\ B\[UnderBracket]87[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]6", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]6\)\((0.2`\ A\[UnderBracket]6[
                  t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]12[t] + 1.5`\ B\[UnderBracket]22[t] + 
              1.5`\ B\[UnderBracket]3[t] - 7.5`\ B\[UnderBracket]6[t] - 
              0.1`\ A\[UnderBracket]6[t]\^2\ B\[UnderBracket]6[t] + 
              1.5`\ B\[UnderBracket]7[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]60", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]60\)\((0.2`\ \
A\[UnderBracket]60[t] + 1.5`\ B\[UnderBracket]35[t] + 
              1.5`\ B\[UnderBracket]41[t] + 1.5`\ B\[UnderBracket]52[t] + 
              1.5`\ B\[UnderBracket]57[t] - 10.5`\ B\[UnderBracket]60[t] - 
              0.1`\ A\[UnderBracket]60[t]\^2\ B\[UnderBracket]60[t] + 
              1.5`\ B\[UnderBracket]72[t] + 1.5`\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]85[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]61", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]61\)\((0.2`\ \
A\[UnderBracket]61[t] + 1.5`\ B\[UnderBracket]43[t] + 
              1.5`\ B\[UnderBracket]50[t] - 9.`\ B\[UnderBracket]61[t] - 
              0.1`\ A\[UnderBracket]61[t]\^2\ B\[UnderBracket]61[t] + 
              1.5`\ B\[UnderBracket]64[t] + 1.5`\ B\[UnderBracket]82[t] + 
              1.5`\ B\[UnderBracket]89[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]62", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]62\)\((0.2`\ \
A\[UnderBracket]62[t] + 1.5`\ B\[UnderBracket]56[t] - 
              6.`\ B\[UnderBracket]62[t] - 
              0.1`\ A\[UnderBracket]62[t]\^2\ B\[UnderBracket]62[t] + 
              1.5`\ B\[UnderBracket]67[t] + 1.5`\ B\[UnderBracket]71[t] + 
              1.5`\ B\[UnderBracket]79[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]63", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]63\)\((0.2`\ \
A\[UnderBracket]63[t] + 1.5`\ B\[UnderBracket]47[t] + 
              1.5`\ B\[UnderBracket]48[t] + 1.5`\ B\[UnderBracket]49[t] - 
              7.5`\ B\[UnderBracket]63[t] - 
              0.1`\ A\[UnderBracket]63[t]\^2\ B\[UnderBracket]63[t] + 
              1.5`\ B\[UnderBracket]73[t] + 
              1.5`\ B\[UnderBracket]76[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]64", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]64\)\((0.2`\ \
A\[UnderBracket]64[t] + 1.5`\ B\[UnderBracket]43[t] + 
              1.5`\ B\[UnderBracket]59[t] + 1.5`\ B\[UnderBracket]61[t] - 
              7.5`\ B\[UnderBracket]64[t] - 
              0.1`\ A\[UnderBracket]64[t]\^2\ B\[UnderBracket]64[t] + 
              1.5`\ B\[UnderBracket]83[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]65", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]65\)\((0.2`\ \
A\[UnderBracket]65[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]39[t] + 1.5`\ B\[UnderBracket]53[t] + 
              1.5`\ B\[UnderBracket]59[t] - 10.5`\ B\[UnderBracket]65[t] - 
              0.1`\ A\[UnderBracket]65[t]\^2\ B\[UnderBracket]65[t] + 
              1.5`\ B\[UnderBracket]70[t] + 1.5`\ B\[UnderBracket]87[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]66", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]66\)\((0.2`\ \
A\[UnderBracket]66[t] + 1.5`\ B\[UnderBracket]44[t] + 
              1.5`\ B\[UnderBracket]55[t] - 9.`\ B\[UnderBracket]66[t] - 
              0.1`\ A\[UnderBracket]66[t]\^2\ B\[UnderBracket]66[t] + 
              1.5`\ B\[UnderBracket]67[t] + 1.5`\ B\[UnderBracket]79[t] + 
              1.5`\ B\[UnderBracket]86[t] + 
              1.5`\ B\[UnderBracket]91[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]67", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]67\)\((0.2`\ \
A\[UnderBracket]67[t] + 1.5`\ B\[UnderBracket]38[t] + 
              1.5`\ B\[UnderBracket]44[t] + 1.5`\ B\[UnderBracket]56[t] + 
              1.5`\ B\[UnderBracket]62[t] + 1.5`\ B\[UnderBracket]66[t] - 
              9.`\ B\[UnderBracket]67[t] - 
              0.1`\ A\[UnderBracket]67[t]\^2\ B\[UnderBracket]67[t] + 
              1.5`\ B\[UnderBracket]79[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]68", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]68\)\((0.2`\ \
A\[UnderBracket]68[t] + 1.5`\ B\[UnderBracket]46[t] - 
              6.`\ B\[UnderBracket]68[t] - 
              0.1`\ A\[UnderBracket]68[t]\^2\ B\[UnderBracket]68[t] + 
              1.5`\ B\[UnderBracket]69[t] + 1.5`\ B\[UnderBracket]75[t] + 
              1.5`\ B\[UnderBracket]94[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]69", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]69\)\((0.2`\ \
A\[UnderBracket]69[t] + 1.5`\ B\[UnderBracket]46[t] + 
              1.5`\ B\[UnderBracket]55[t] + 1.5`\ B\[UnderBracket]68[t] - 
              9.`\ B\[UnderBracket]69[t] - 
              0.1`\ A\[UnderBracket]69[t]\^2\ B\[UnderBracket]69[t] + 
              1.5`\ B\[UnderBracket]86[t] + 1.5`\ B\[UnderBracket]94[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]7", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]7\)\((0.2`\ A\[UnderBracket]7[
                  t] + 1.5`\ B\[UnderBracket]11[t] + 
              1.5`\ B\[UnderBracket]13[t] + 1.5`\ B\[UnderBracket]3[t] + 
              1.5`\ B\[UnderBracket]6[t] - 7.5`\ B\[UnderBracket]7[t] - 
              0.1`\ A\[UnderBracket]7[t]\^2\ B\[UnderBracket]7[t] + 
              1.5`\ B\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]70", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]70\)\((0.2`\ \
A\[UnderBracket]70[t] + 1.5`\ B\[UnderBracket]53[t] + 
              1.5`\ B\[UnderBracket]65[t] - 7.5`\ B\[UnderBracket]70[t] - 
              0.1`\ A\[UnderBracket]70[t]\^2\ B\[UnderBracket]70[t] + 
              1.5`\ B\[UnderBracket]74[t] + 1.5`\ B\[UnderBracket]93[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]71", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]71\)\((0.2`\ \
A\[UnderBracket]71[t] + 1.5`\ B\[UnderBracket]51[t] + 
              1.5`\ B\[UnderBracket]56[t] + 1.5`\ B\[UnderBracket]62[t] - 
              7.5`\ B\[UnderBracket]71[t] - 
              0.1`\ A\[UnderBracket]71[t]\^2\ B\[UnderBracket]71[t] + 
              1.5`\ B\[UnderBracket]79[t] + 
              1.5`\ B\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]72", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]72\)\((0.2`\ \
A\[UnderBracket]72[t] + 1.5`\ B\[UnderBracket]102[t] + 
              1.5`\ B\[UnderBracket]51[t] + 1.5`\ B\[UnderBracket]52[t] + 
              1.5`\ B\[UnderBracket]60[t] - 9.`\ B\[UnderBracket]72[t] - 
              0.1`\ A\[UnderBracket]72[t]\^2\ B\[UnderBracket]72[t] + 
              1.5`\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]73", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]73\)\((0.2`\ \
A\[UnderBracket]73[t] + 1.5`\ B\[UnderBracket]48[t] + 
              1.5`\ B\[UnderBracket]63[t] - 7.5`\ B\[UnderBracket]73[t] - 
              0.1`\ A\[UnderBracket]73[t]\^2\ B\[UnderBracket]73[t] + 
              1.5`\ B\[UnderBracket]76[t] + 1.5`\ B\[UnderBracket]77[t] + 
              1.5`\ B\[UnderBracket]92[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]74", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]74\)\((0.2`\ \
A\[UnderBracket]74[t] + 1.5`\ B\[UnderBracket]53[t] + 
              1.5`\ B\[UnderBracket]54[t] + 1.5`\ B\[UnderBracket]70[t] - 
              9.`\ B\[UnderBracket]74[t] - 
              0.1`\ A\[UnderBracket]74[t]\^2\ B\[UnderBracket]74[t] + 
              1.5`\ B\[UnderBracket]75[t] + 1.5`\ B\[UnderBracket]90[t] + 
              1.5`\ B\[UnderBracket]93[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]75", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]75\)\((0.2`\ \
A\[UnderBracket]75[t] + 1.5`\ B\[UnderBracket]45[t] + 
              1.5`\ B\[UnderBracket]54[t] + 1.5`\ B\[UnderBracket]68[t] + 
              1.5`\ B\[UnderBracket]74[t] - 9.`\ B\[UnderBracket]75[t] - 
              0.1`\ A\[UnderBracket]75[t]\^2\ B\[UnderBracket]75[t] + 
              1.5`\ B\[UnderBracket]90[t] + 
              1.5`\ B\[UnderBracket]94[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]76", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]76\)\((0.2`\ \
A\[UnderBracket]76[t] + 1.5`\ B\[UnderBracket]49[t] + 
              1.5`\ B\[UnderBracket]57[t] + 1.5`\ B\[UnderBracket]63[t] + 
              1.5`\ B\[UnderBracket]73[t] - 10.5`\ B\[UnderBracket]76[t] - 
              0.1`\ A\[UnderBracket]76[t]\^2\ B\[UnderBracket]76[t] + 
              1.5`\ B\[UnderBracket]81[t] + 1.5`\ B\[UnderBracket]92[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]77", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]77\)\((0.2`\ \
A\[UnderBracket]77[t] + 1.5`\ B\[UnderBracket]103[t] + 
              1.5`\ B\[UnderBracket]107[t] + 1.5`\ B\[UnderBracket]48[t] + 
              1.5`\ B\[UnderBracket]58[t] + 1.5`\ B\[UnderBracket]73[t] - 
              10.5`\ B\[UnderBracket]77[t] - 
              0.1`\ A\[UnderBracket]77[t]\^2\ B\[UnderBracket]77[t] + 
              1.5`\ B\[UnderBracket]78[t] + 
              1.5`\ B\[UnderBracket]92[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]78", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.2`\ A\[UnderBracket]78[t] + 
                1.5`\ B\[UnderBracket]107[t] + 1.5`\ B\[UnderBracket]58[t] + 
                1.5`\ B\[UnderBracket]77[t] - 4.5`\ B\[UnderBracket]78[t] - 
                0.1`\ A\[UnderBracket]78[t]\^2\ B\[UnderBracket]78[
                    t]\)\/cell\[UnderBracket]78\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]79", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]79\)\((0.2`\ \
A\[UnderBracket]79[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]62[t] + 1.5`\ B\[UnderBracket]66[t] + 
              1.5`\ B\[UnderBracket]67[t] + 1.5`\ B\[UnderBracket]71[t] - 
              12.`\ B\[UnderBracket]79[t] - 
              0.1`\ A\[UnderBracket]79[t]\^2\ B\[UnderBracket]79[t] + 
              1.5`\ B\[UnderBracket]84[t] + 1.5`\ B\[UnderBracket]91[t] + 
              1.5`\ B\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]8", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]8\)\((0.2`\ A\[UnderBracket]8[
                  t] + 1.5`\ B\[UnderBracket]1[t] + 
              1.5`\ B\[UnderBracket]13[t] + 1.5`\ B\[UnderBracket]14[t] + 
              1.5`\ B\[UnderBracket]17[t] + 1.5`\ B\[UnderBracket]2[t] + 
              1.5`\ B\[UnderBracket]3[t] + 1.5`\ B\[UnderBracket]5[t] + 
              1.5`\ B\[UnderBracket]7[t] - 12.`\ B\[UnderBracket]8[t] - 
              0.1`\ A\[UnderBracket]8[t]\^2\ B\[UnderBracket]8[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]80", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]80\)\((0.2`\ \
A\[UnderBracket]80[t] + 1.5`\ B\[UnderBracket]102[t] + 
              1.5`\ B\[UnderBracket]110[t] + 1.5`\ B\[UnderBracket]60[t] + 
              1.5`\ B\[UnderBracket]72[t] - 9.`\ B\[UnderBracket]80[t] - 
              0.1`\ A\[UnderBracket]80[t]\^2\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]85[t] + 
              1.5`\ B\[UnderBracket]88[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]81", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]81\)\((0.2`\ \
A\[UnderBracket]81[t] + 1.5`\ B\[UnderBracket]57[t] + 
              1.5`\ B\[UnderBracket]76[t] - 6.`\ B\[UnderBracket]81[t] - 
              0.1`\ A\[UnderBracket]81[t]\^2\ B\[UnderBracket]81[t] + 
              1.5`\ B\[UnderBracket]85[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]82", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]82\)\((0.2`\ \
A\[UnderBracket]82[t] + 1.5`\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]50[t] + 1.5`\ B\[UnderBracket]61[t] - 
              6.`\ B\[UnderBracket]82[t] - 
              0.1`\ A\[UnderBracket]82[t]\^2\ B\[UnderBracket]82[t] + 
              1.5`\ B\[UnderBracket]89[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]83", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]83\)\((0.2`\ \
A\[UnderBracket]83[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]123[t] + 1.5`\ B\[UnderBracket]59[t] + 
              1.5`\ B\[UnderBracket]64[t] - 9.`\ B\[UnderBracket]83[t] - 
              0.1`\ A\[UnderBracket]83[t]\^2\ B\[UnderBracket]83[t] + 
              1.5`\ B\[UnderBracket]87[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]84", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]84\)\((0.2`\ \
A\[UnderBracket]84[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]102[t] + 1.5`\ B\[UnderBracket]109[t] + 
              1.5`\ B\[UnderBracket]51[t] + 1.5`\ B\[UnderBracket]71[t] + 
              1.5`\ B\[UnderBracket]72[t] + 1.5`\ B\[UnderBracket]79[t] - 
              10.5`\ B\[UnderBracket]84[t] - 
              0.1`\ A\[UnderBracket]84[t]\^2\ B\[UnderBracket]84[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]85", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]85\)\((0.2`\ \
A\[UnderBracket]85[t] + 1.5`\ B\[UnderBracket]57[t] + 
              1.5`\ B\[UnderBracket]60[t] + 1.5`\ B\[UnderBracket]80[t] + 
              1.5`\ B\[UnderBracket]81[t] - 9.`\ B\[UnderBracket]85[t] - 
              0.1`\ A\[UnderBracket]85[t]\^2\ B\[UnderBracket]85[t] + 
              1.5`\ B\[UnderBracket]88[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]86", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]86\)\((0.2`\ \
A\[UnderBracket]86[t] + 1.5`\ B\[UnderBracket]106[t] + 
              1.5`\ B\[UnderBracket]55[t] + 1.5`\ B\[UnderBracket]66[t] + 
              1.5`\ B\[UnderBracket]69[t] - 9.`\ B\[UnderBracket]86[t] - 
              0.1`\ A\[UnderBracket]86[t]\^2\ B\[UnderBracket]86[t] + 
              1.5`\ B\[UnderBracket]91[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]87", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]87\)\((0.2`\ \
A\[UnderBracket]87[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]59[t] + 1.5`\ B\[UnderBracket]65[t] + 
              1.5`\ B\[UnderBracket]83[t] - 6.`\ B\[UnderBracket]87[t] - 
              0.1`\ A\[UnderBracket]87[t]\^2\ B\[UnderBracket]87[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]88", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]88\)\((0.2`\ \
A\[UnderBracket]88[t] + 1.5`\ B\[UnderBracket]110[t] + 
              1.5`\ B\[UnderBracket]112[t] + 1.5`\ B\[UnderBracket]120[t] + 
              1.5`\ B\[UnderBracket]80[t] + 1.5`\ B\[UnderBracket]85[t] - 
              9.`\ B\[UnderBracket]88[t] - 
              0.1`\ A\[UnderBracket]88[t]\^2\ B\[UnderBracket]88[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]89", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]89\)\((0.2`\ \
A\[UnderBracket]89[t] + 1.5`\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]61[t] + 1.5`\ B\[UnderBracket]82[t] - 
              6.`\ B\[UnderBracket]89[t] - 
              0.1`\ A\[UnderBracket]89[t]\^2\ B\[UnderBracket]89[t] + 
              1.5`\ B\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]9", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]9\)\((0.2`\ A\[UnderBracket]9[
                  t] + 1.5`\ B\[UnderBracket]10[t] + 
              1.5`\ B\[UnderBracket]14[t] + 1.5`\ B\[UnderBracket]18[t] + 
              1.5`\ B\[UnderBracket]27[t] + 1.5`\ B\[UnderBracket]4[t] + 
              1.5`\ B\[UnderBracket]5[t] - 9.`\ B\[UnderBracket]9[t] - 
              0.1`\ A\[UnderBracket]9[t]\^2\ B\[UnderBracket]9[t])\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]90", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]90\)\((0.2`\ \
A\[UnderBracket]90[t] + 1.5`\ B\[UnderBracket]105[t] + 
              1.5`\ B\[UnderBracket]108[t] + 1.5`\ B\[UnderBracket]116[t] + 
              1.5`\ B\[UnderBracket]74[t] + 1.5`\ B\[UnderBracket]75[t] - 
              9.`\ B\[UnderBracket]90[t] - 
              0.1`\ A\[UnderBracket]90[t]\^2\ B\[UnderBracket]90[t] + 
              1.5`\ B\[UnderBracket]93[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]91", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]91\)\((0.2`\ \
A\[UnderBracket]91[t] + 1.5`\ B\[UnderBracket]106[t] + 
              1.5`\ B\[UnderBracket]118[t] + 1.5`\ B\[UnderBracket]66[t] + 
              1.5`\ B\[UnderBracket]79[t] + 1.5`\ B\[UnderBracket]86[t] - 
              9.`\ B\[UnderBracket]91[t] - 
              0.1`\ A\[UnderBracket]91[t]\^2\ B\[UnderBracket]91[t] + 
              1.5`\ B\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]92", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]92\)\((0.2`\ \
A\[UnderBracket]92[t] + 1.5`\ B\[UnderBracket]103[t] + 
              1.5`\ B\[UnderBracket]111[t] + 1.5`\ B\[UnderBracket]73[t] + 
              1.5`\ B\[UnderBracket]76[t] + 1.5`\ B\[UnderBracket]77[t] - 
              9.`\ B\[UnderBracket]92[t] - 
              0.1`\ A\[UnderBracket]92[t]\^2\ B\[UnderBracket]92[t] + 
              1.5`\ B\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]93", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]93\)\((0.2`\ \
A\[UnderBracket]93[t] + 1.5`\ B\[UnderBracket]104[t] + 
              1.5`\ B\[UnderBracket]105[t] + 1.5`\ B\[UnderBracket]115[t] + 
              1.5`\ B\[UnderBracket]70[t] + 1.5`\ B\[UnderBracket]74[t] + 
              1.5`\ B\[UnderBracket]90[t] - 10.5`\ B\[UnderBracket]93[t] - 
              0.1`\ A\[UnderBracket]93[t]\^2\ B\[UnderBracket]93[t] + 
              1.5`\ B\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]94", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]94\)\((0.2`\ \
A\[UnderBracket]94[t] + 1.5`\ B\[UnderBracket]108[t] + 
              1.5`\ B\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]68[t] + 
              1.5`\ B\[UnderBracket]69[t] + 1.5`\ B\[UnderBracket]75[t] - 
              9.`\ B\[UnderBracket]94[t] - 
              0.1`\ A\[UnderBracket]94[t]\^2\ B\[UnderBracket]94[t] + 
              1.5`\ B\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]95", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]95\)\((0.2`\ \
A\[UnderBracket]95[t] + 1.5`\ B\[UnderBracket]111[t] + 
              1.5`\ B\[UnderBracket]120[t] + 1.5`\ B\[UnderBracket]121[t] + 
              1.5`\ B\[UnderBracket]76[t] + 1.5`\ B\[UnderBracket]81[t] + 
              1.5`\ B\[UnderBracket]85[t] + 1.5`\ B\[UnderBracket]88[t] + 
              1.5`\ B\[UnderBracket]92[t] - 12.`\ B\[UnderBracket]95[t] - 
              0.1`\ A\[UnderBracket]95[t]\^2\ B\[UnderBracket]95[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]96", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]96\)\((0.2`\ \
A\[UnderBracket]96[t] + 1.5`\ B\[UnderBracket]113[t] + 
              1.5`\ B\[UnderBracket]123[t] + 1.5`\ B\[UnderBracket]127[t] + 
              1.5`\ B\[UnderBracket]61[t] + 1.5`\ B\[UnderBracket]64[t] + 
              1.5`\ B\[UnderBracket]83[t] + 1.5`\ B\[UnderBracket]89[t] - 
              10.5`\ B\[UnderBracket]96[t] - 
              0.1`\ A\[UnderBracket]96[t]\^2\ B\[UnderBracket]96[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]97", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]97\)\((0.2`\ \
A\[UnderBracket]97[t] + 1.5`\ B\[UnderBracket]100[t] + 
              1.5`\ B\[UnderBracket]104[t] + 1.5`\ B\[UnderBracket]124[t] + 
              1.5`\ B\[UnderBracket]65[t] + 1.5`\ B\[UnderBracket]70[t] + 
              1.5`\ B\[UnderBracket]93[t] - 9.`\ B\[UnderBracket]97[t] - 
              0.1`\ A\[UnderBracket]97[t]\^2\ B\[UnderBracket]97[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]98", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]98\)\((0.2`\ \
A\[UnderBracket]98[t] + 1.5`\ B\[UnderBracket]106[t] + 
              1.5`\ B\[UnderBracket]117[t] + 1.5`\ B\[UnderBracket]125[t] + 
              1.5`\ B\[UnderBracket]69[t] + 1.5`\ B\[UnderBracket]86[t] + 
              1.5`\ B\[UnderBracket]94[t] - 9.`\ B\[UnderBracket]98[t] - 
              0.1`\ A\[UnderBracket]98[t]\^2\ B\[UnderBracket]98[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["B\[UnderBracket]99", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]99\)\((0.2`\ \
A\[UnderBracket]99[t] + 1.5`\ B\[UnderBracket]101[t] + 
              1.5`\ B\[UnderBracket]118[t] + 1.5`\ B\[UnderBracket]119[t] + 
              1.5`\ B\[UnderBracket]79[t] + 1.5`\ B\[UnderBracket]91[t] - 
              7.5`\ B\[UnderBracket]99[t] - 
              0.1`\ A\[UnderBracket]99[t]\^2\ B\[UnderBracket]99[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]1", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]1[t] - 20\ Y\[UnderBracket]1[t]] - 
                0.1`\ Wus\[UnderBracket]1[t]\)\/cell\[UnderBracket]1\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]10", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]10[t] - 
                      20\ Y\[UnderBracket]10[t]] - 
                0.1`\ Wus\[UnderBracket]10[t]\)\/cell\[UnderBracket]10\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]100", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]100[t] - 
                      20\ Y\[UnderBracket]100[t]] - 
                0.1`\ Wus\[UnderBracket]100[t]\)\/cell\[UnderBracket]100\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]101", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]101[t] - 
                      20\ Y\[UnderBracket]101[t]] - 
                0.1`\ Wus\[UnderBracket]101[t]\)\/cell\[UnderBracket]101\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]102", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]102[t] - 
                      20\ Y\[UnderBracket]102[t]] - 
                0.1`\ Wus\[UnderBracket]102[t]\)\/cell\[UnderBracket]102\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]103", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]103[t] - 
                      20\ Y\[UnderBracket]103[t]] - 
                0.1`\ Wus\[UnderBracket]103[t]\)\/cell\[UnderBracket]103\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]104", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]104[t] - 
                      20\ Y\[UnderBracket]104[t]] - 
                0.1`\ Wus\[UnderBracket]104[t]\)\/cell\[UnderBracket]104\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]105", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]105[t] - 
                      20\ Y\[UnderBracket]105[t]] - 
                0.1`\ Wus\[UnderBracket]105[t]\)\/cell\[UnderBracket]105\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]106", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]106[t] - 
                      20\ Y\[UnderBracket]106[t]] - 
                0.1`\ Wus\[UnderBracket]106[t]\)\/cell\[UnderBracket]106\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]107", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]107[t] - 
                      20\ Y\[UnderBracket]107[t]] - 
                0.1`\ Wus\[UnderBracket]107[t]\)\/cell\[UnderBracket]107\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]108", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]108[t] - 
                      20\ Y\[UnderBracket]108[t]] - 
                0.1`\ Wus\[UnderBracket]108[t]\)\/cell\[UnderBracket]108\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]109", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]109[t] - 
                      20\ Y\[UnderBracket]109[t]] - 
                0.1`\ Wus\[UnderBracket]109[t]\)\/cell\[UnderBracket]109\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]11", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]11[t] - 
                      20\ Y\[UnderBracket]11[t]] - 
                0.1`\ Wus\[UnderBracket]11[t]\)\/cell\[UnderBracket]11\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]110", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]110[t] - 
                      20\ Y\[UnderBracket]110[t]] - 
                0.1`\ Wus\[UnderBracket]110[t]\)\/cell\[UnderBracket]110\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]111", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]111[t] - 
                      20\ Y\[UnderBracket]111[t]] - 
                0.1`\ Wus\[UnderBracket]111[t]\)\/cell\[UnderBracket]111\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]112", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]112[t] - 
                      20\ Y\[UnderBracket]112[t]] - 
                0.1`\ Wus\[UnderBracket]112[t]\)\/cell\[UnderBracket]112\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]113", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]113[t] - 
                      20\ Y\[UnderBracket]113[t]] - 
                0.1`\ Wus\[UnderBracket]113[t]\)\/cell\[UnderBracket]113\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]114", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]114[t] - 
                      20\ Y\[UnderBracket]114[t]] - 
                0.1`\ Wus\[UnderBracket]114[t]\)\/cell\[UnderBracket]114\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]115", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]115[t] - 
                      20\ Y\[UnderBracket]115[t]] - 
                0.1`\ Wus\[UnderBracket]115[t]\)\/cell\[UnderBracket]115\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]116", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]116[t] - 
                      20\ Y\[UnderBracket]116[t]] - 
                0.1`\ Wus\[UnderBracket]116[t]\)\/cell\[UnderBracket]116\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]117", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]117[t] - 
                      20\ Y\[UnderBracket]117[t]] - 
                0.1`\ Wus\[UnderBracket]117[t]\)\/cell\[UnderBracket]117\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]118", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]118[t] - 
                      20\ Y\[UnderBracket]118[t]] - 
                0.1`\ Wus\[UnderBracket]118[t]\)\/cell\[UnderBracket]118\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]119", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]119[t] - 
                      20\ Y\[UnderBracket]119[t]] - 
                0.1`\ Wus\[UnderBracket]119[t]\)\/cell\[UnderBracket]119\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]12", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]12[t] - 
                      20\ Y\[UnderBracket]12[t]] - 
                0.1`\ Wus\[UnderBracket]12[t]\)\/cell\[UnderBracket]12\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]120", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]120[t] - 
                      20\ Y\[UnderBracket]120[t]] - 
                0.1`\ Wus\[UnderBracket]120[t]\)\/cell\[UnderBracket]120\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]121", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]121[t] - 
                      20\ Y\[UnderBracket]121[t]] - 
                0.1`\ Wus\[UnderBracket]121[t]\)\/cell\[UnderBracket]121\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]122", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]122[t] - 
                      20\ Y\[UnderBracket]122[t]] - 
                0.1`\ Wus\[UnderBracket]122[t]\)\/cell\[UnderBracket]122\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]123", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]123[t] - 
                      20\ Y\[UnderBracket]123[t]] - 
                0.1`\ Wus\[UnderBracket]123[t]\)\/cell\[UnderBracket]123\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]124", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]124[t] - 
                      20\ Y\[UnderBracket]124[t]] - 
                0.1`\ Wus\[UnderBracket]124[t]\)\/cell\[UnderBracket]124\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]125", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]125[t] - 
                      20\ Y\[UnderBracket]125[t]] - 
                0.1`\ Wus\[UnderBracket]125[t]\)\/cell\[UnderBracket]125\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]126", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]126[t] - 
                      20\ Y\[UnderBracket]126[t]] - 
                0.1`\ Wus\[UnderBracket]126[t]\)\/cell\[UnderBracket]126\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]127", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]127[t] - 
                      20\ Y\[UnderBracket]127[t]] - 
                0.1`\ Wus\[UnderBracket]127[t]\)\/cell\[UnderBracket]127\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]128", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]128[t] - 
                      20\ Y\[UnderBracket]128[t]] - 
                0.1`\ Wus\[UnderBracket]128[t]\)\/cell\[UnderBracket]128\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]129", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]129[t] - 
                      20\ Y\[UnderBracket]129[t]] - 
                0.1`\ Wus\[UnderBracket]129[t]\)\/cell\[UnderBracket]129\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]13", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]13[t] - 
                      20\ Y\[UnderBracket]13[t]] - 
                0.1`\ Wus\[UnderBracket]13[t]\)\/cell\[UnderBracket]13\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]130", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]130[t] - 
                      20\ Y\[UnderBracket]130[t]] - 
                0.1`\ Wus\[UnderBracket]130[t]\)\/cell\[UnderBracket]130\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]131", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]131[t] - 
                      20\ Y\[UnderBracket]131[t]] - 
                0.1`\ Wus\[UnderBracket]131[t]\)\/cell\[UnderBracket]131\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]132", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]132[t] - 
                      20\ Y\[UnderBracket]132[t]] - 
                0.1`\ Wus\[UnderBracket]132[t]\)\/cell\[UnderBracket]132\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]133", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]133[t] - 
                      20\ Y\[UnderBracket]133[t]] - 
                0.1`\ Wus\[UnderBracket]133[t]\)\/cell\[UnderBracket]133\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]134", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]134[t] - 
                      20\ Y\[UnderBracket]134[t]] - 
                0.1`\ Wus\[UnderBracket]134[t]\)\/cell\[UnderBracket]134\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]135", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]135[t] - 
                      20\ Y\[UnderBracket]135[t]] - 
                0.1`\ Wus\[UnderBracket]135[t]\)\/cell\[UnderBracket]135\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]136", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]136[t] - 
                      20\ Y\[UnderBracket]136[t]] - 
                0.1`\ Wus\[UnderBracket]136[t]\)\/cell\[UnderBracket]136\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]137", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]137[t] - 
                      20\ Y\[UnderBracket]137[t]] - 
                0.1`\ Wus\[UnderBracket]137[t]\)\/cell\[UnderBracket]137\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]138", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]138[t] - 
                      20\ Y\[UnderBracket]138[t]] - 
                0.1`\ Wus\[UnderBracket]138[t]\)\/cell\[UnderBracket]138\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]139", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]139[t] - 
                      20\ Y\[UnderBracket]139[t]] - 
                0.1`\ Wus\[UnderBracket]139[t]\)\/cell\[UnderBracket]139\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]14", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]14[t] - 
                      20\ Y\[UnderBracket]14[t]] - 
                0.1`\ Wus\[UnderBracket]14[t]\)\/cell\[UnderBracket]14\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]140", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]140[t] - 
                      20\ Y\[UnderBracket]140[t]] - 
                0.1`\ Wus\[UnderBracket]140[t]\)\/cell\[UnderBracket]140\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]141", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]141[t] - 
                      20\ Y\[UnderBracket]141[t]] - 
                0.1`\ Wus\[UnderBracket]141[t]\)\/cell\[UnderBracket]141\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]142", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]142[t] - 
                      20\ Y\[UnderBracket]142[t]] - 
                0.1`\ Wus\[UnderBracket]142[t]\)\/cell\[UnderBracket]142\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]143", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]143[t] - 
                      20\ Y\[UnderBracket]143[t]] - 
                0.1`\ Wus\[UnderBracket]143[t]\)\/cell\[UnderBracket]143\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]144", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]144[t] - 
                      20\ Y\[UnderBracket]144[t]] - 
                0.1`\ Wus\[UnderBracket]144[t]\)\/cell\[UnderBracket]144\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]145", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]145[t] - 
                      20\ Y\[UnderBracket]145[t]] - 
                0.1`\ Wus\[UnderBracket]145[t]\)\/cell\[UnderBracket]145\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]146", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]146[t] - 
                      20\ Y\[UnderBracket]146[t]] - 
                0.1`\ Wus\[UnderBracket]146[t]\)\/cell\[UnderBracket]146\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]147", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]147[t] - 
                      20\ Y\[UnderBracket]147[t]] - 
                0.1`\ Wus\[UnderBracket]147[t]\)\/cell\[UnderBracket]147\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]148", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]148[t] - 
                      20\ Y\[UnderBracket]148[t]] - 
                0.1`\ Wus\[UnderBracket]148[t]\)\/cell\[UnderBracket]148\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]149", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]149[t] - 
                      20\ Y\[UnderBracket]149[t]] - 
                0.1`\ Wus\[UnderBracket]149[t]\)\/cell\[UnderBracket]149\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]15", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]15[t] - 
                      20\ Y\[UnderBracket]15[t]] - 
                0.1`\ Wus\[UnderBracket]15[t]\)\/cell\[UnderBracket]15\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]150", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]150[t] - 
                      20\ Y\[UnderBracket]150[t]] - 
                0.1`\ Wus\[UnderBracket]150[t]\)\/cell\[UnderBracket]150\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]151", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]151[t] - 
                      20\ Y\[UnderBracket]151[t]] - 
                0.1`\ Wus\[UnderBracket]151[t]\)\/cell\[UnderBracket]151\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]152", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]152[t] - 
                      20\ Y\[UnderBracket]152[t]] - 
                0.1`\ Wus\[UnderBracket]152[t]\)\/cell\[UnderBracket]152\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]153", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]153[t] - 
                      20\ Y\[UnderBracket]153[t]] - 
                0.1`\ Wus\[UnderBracket]153[t]\)\/cell\[UnderBracket]153\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]154", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]154[t] - 
                      20\ Y\[UnderBracket]154[t]] - 
                0.1`\ Wus\[UnderBracket]154[t]\)\/cell\[UnderBracket]154\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]155", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]155[t] - 
                      20\ Y\[UnderBracket]155[t]] - 
                0.1`\ Wus\[UnderBracket]155[t]\)\/cell\[UnderBracket]155\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]156", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]156[t] - 
                      20\ Y\[UnderBracket]156[t]] - 
                0.1`\ Wus\[UnderBracket]156[t]\)\/cell\[UnderBracket]156\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]157", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]157[t] - 
                      20\ Y\[UnderBracket]157[t]] - 
                0.1`\ Wus\[UnderBracket]157[t]\)\/cell\[UnderBracket]157\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]158", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]158[t] - 
                      20\ Y\[UnderBracket]158[t]] - 
                0.1`\ Wus\[UnderBracket]158[t]\)\/cell\[UnderBracket]158\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]159", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]159[t] - 
                      20\ Y\[UnderBracket]159[t]] - 
                0.1`\ Wus\[UnderBracket]159[t]\)\/cell\[UnderBracket]159\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]16", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]16[t] - 
                      20\ Y\[UnderBracket]16[t]] - 
                0.1`\ Wus\[UnderBracket]16[t]\)\/cell\[UnderBracket]16\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]160", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]160[t] - 
                      20\ Y\[UnderBracket]160[t]] - 
                0.1`\ Wus\[UnderBracket]160[t]\)\/cell\[UnderBracket]160\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]161", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]161[t] - 
                      20\ Y\[UnderBracket]161[t]] - 
                0.1`\ Wus\[UnderBracket]161[t]\)\/cell\[UnderBracket]161\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]162", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]162[t] - 
                      20\ Y\[UnderBracket]162[t]] - 
                0.1`\ Wus\[UnderBracket]162[t]\)\/cell\[UnderBracket]162\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]163", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]163[t] - 
                      20\ Y\[UnderBracket]163[t]] - 
                0.1`\ Wus\[UnderBracket]163[t]\)\/cell\[UnderBracket]163\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]164", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]164[t] - 
                      20\ Y\[UnderBracket]164[t]] - 
                0.1`\ Wus\[UnderBracket]164[t]\)\/cell\[UnderBracket]164\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]165", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]165[t] - 
                      20\ Y\[UnderBracket]165[t]] - 
                0.1`\ Wus\[UnderBracket]165[t]\)\/cell\[UnderBracket]165\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]166", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]166[t] - 
                      20\ Y\[UnderBracket]166[t]] - 
                0.1`\ Wus\[UnderBracket]166[t]\)\/cell\[UnderBracket]166\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]167", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]167[t] - 
                      20\ Y\[UnderBracket]167[t]] - 
                0.1`\ Wus\[UnderBracket]167[t]\)\/cell\[UnderBracket]167\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]168", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]168[t] - 
                      20\ Y\[UnderBracket]168[t]] - 
                0.1`\ Wus\[UnderBracket]168[t]\)\/cell\[UnderBracket]168\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]169", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]169[t] - 
                      20\ Y\[UnderBracket]169[t]] - 
                0.1`\ Wus\[UnderBracket]169[t]\)\/cell\[UnderBracket]169\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]17", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]17[t] - 
                      20\ Y\[UnderBracket]17[t]] - 
                0.1`\ Wus\[UnderBracket]17[t]\)\/cell\[UnderBracket]17\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]170", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]170[t] - 
                      20\ Y\[UnderBracket]170[t]] - 
                0.1`\ Wus\[UnderBracket]170[t]\)\/cell\[UnderBracket]170\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]171", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]171[t] - 
                      20\ Y\[UnderBracket]171[t]] - 
                0.1`\ Wus\[UnderBracket]171[t]\)\/cell\[UnderBracket]171\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]172", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]172[t] - 
                      20\ Y\[UnderBracket]172[t]] - 
                0.1`\ Wus\[UnderBracket]172[t]\)\/cell\[UnderBracket]172\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]173", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]173[t] - 
                      20\ Y\[UnderBracket]173[t]] - 
                0.1`\ Wus\[UnderBracket]173[t]\)\/cell\[UnderBracket]173\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]174", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]174[t] - 
                      20\ Y\[UnderBracket]174[t]] - 
                0.1`\ Wus\[UnderBracket]174[t]\)\/cell\[UnderBracket]174\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]175", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]175[t] - 
                      20\ Y\[UnderBracket]175[t]] - 
                0.1`\ Wus\[UnderBracket]175[t]\)\/cell\[UnderBracket]175\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]176", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]176[t] - 
                      20\ Y\[UnderBracket]176[t]] - 
                0.1`\ Wus\[UnderBracket]176[t]\)\/cell\[UnderBracket]176\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]177", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]177[t] - 
                      20\ Y\[UnderBracket]177[t]] - 
                0.1`\ Wus\[UnderBracket]177[t]\)\/cell\[UnderBracket]177\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]178", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]178[t] - 
                      20\ Y\[UnderBracket]178[t]] - 
                0.1`\ Wus\[UnderBracket]178[t]\)\/cell\[UnderBracket]178\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]179", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]179[t] - 
                      20\ Y\[UnderBracket]179[t]] - 
                0.1`\ Wus\[UnderBracket]179[t]\)\/cell\[UnderBracket]179\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]18", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]18[t] - 
                      20\ Y\[UnderBracket]18[t]] - 
                0.1`\ Wus\[UnderBracket]18[t]\)\/cell\[UnderBracket]18\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]180", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]180[t] - 
                      20\ Y\[UnderBracket]180[t]] - 
                0.1`\ Wus\[UnderBracket]180[t]\)\/cell\[UnderBracket]180\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]181", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]181[t] - 
                      20\ Y\[UnderBracket]181[t]] - 
                0.1`\ Wus\[UnderBracket]181[t]\)\/cell\[UnderBracket]181\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]182", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]182[t] - 
                      20\ Y\[UnderBracket]182[t]] - 
                0.1`\ Wus\[UnderBracket]182[t]\)\/cell\[UnderBracket]182\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]183", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]183[t] - 
                      20\ Y\[UnderBracket]183[t]] - 
                0.1`\ Wus\[UnderBracket]183[t]\)\/cell\[UnderBracket]183\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]184", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]184[t] - 
                      20\ Y\[UnderBracket]184[t]] - 
                0.1`\ Wus\[UnderBracket]184[t]\)\/cell\[UnderBracket]184\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]185", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]185[t] - 
                      20\ Y\[UnderBracket]185[t]] - 
                0.1`\ Wus\[UnderBracket]185[t]\)\/cell\[UnderBracket]185\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]186", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]186[t] - 
                      20\ Y\[UnderBracket]186[t]] - 
                0.1`\ Wus\[UnderBracket]186[t]\)\/cell\[UnderBracket]186\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]187", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]187[t] - 
                      20\ Y\[UnderBracket]187[t]] - 
                0.1`\ Wus\[UnderBracket]187[t]\)\/cell\[UnderBracket]187\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]188", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]188[t] - 
                      20\ Y\[UnderBracket]188[t]] - 
                0.1`\ Wus\[UnderBracket]188[t]\)\/cell\[UnderBracket]188\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]189", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]189[t] - 
                      20\ Y\[UnderBracket]189[t]] - 
                0.1`\ Wus\[UnderBracket]189[t]\)\/cell\[UnderBracket]189\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]19", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]19[t] - 
                      20\ Y\[UnderBracket]19[t]] - 
                0.1`\ Wus\[UnderBracket]19[t]\)\/cell\[UnderBracket]19\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]190", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]190[t] - 
                      20\ Y\[UnderBracket]190[t]] - 
                0.1`\ Wus\[UnderBracket]190[t]\)\/cell\[UnderBracket]190\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]191", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]191[t] - 
                      20\ Y\[UnderBracket]191[t]] - 
                0.1`\ Wus\[UnderBracket]191[t]\)\/cell\[UnderBracket]191\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]192", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]192[t] - 
                      20\ Y\[UnderBracket]192[t]] - 
                0.1`\ Wus\[UnderBracket]192[t]\)\/cell\[UnderBracket]192\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]193", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]193[t] - 
                      20\ Y\[UnderBracket]193[t]] - 
                0.1`\ Wus\[UnderBracket]193[t]\)\/cell\[UnderBracket]193\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]194", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]194[t] - 
                      20\ Y\[UnderBracket]194[t]] - 
                0.1`\ Wus\[UnderBracket]194[t]\)\/cell\[UnderBracket]194\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]195", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]195[t] - 
                      20\ Y\[UnderBracket]195[t]] - 
                0.1`\ Wus\[UnderBracket]195[t]\)\/cell\[UnderBracket]195\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]196", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]196[t] - 
                      20\ Y\[UnderBracket]196[t]] - 
                0.1`\ Wus\[UnderBracket]196[t]\)\/cell\[UnderBracket]196\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]197", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]197[t] - 
                      20\ Y\[UnderBracket]197[t]] - 
                0.1`\ Wus\[UnderBracket]197[t]\)\/cell\[UnderBracket]197\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]198", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]198[t] - 
                      20\ Y\[UnderBracket]198[t]] - 
                0.1`\ Wus\[UnderBracket]198[t]\)\/cell\[UnderBracket]198\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]199", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]199[t] - 
                      20\ Y\[UnderBracket]199[t]] - 
                0.1`\ Wus\[UnderBracket]199[t]\)\/cell\[UnderBracket]199\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]2", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]2[t] - 20\ Y\[UnderBracket]2[t]] - 
                0.1`\ Wus\[UnderBracket]2[t]\)\/cell\[UnderBracket]2\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]20", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]20[t] - 
                      20\ Y\[UnderBracket]20[t]] - 
                0.1`\ Wus\[UnderBracket]20[t]\)\/cell\[UnderBracket]20\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]200", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]200[t] - 
                      20\ Y\[UnderBracket]200[t]] - 
                0.1`\ Wus\[UnderBracket]200[t]\)\/cell\[UnderBracket]200\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]201", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]201[t] - 
                      20\ Y\[UnderBracket]201[t]] - 
                0.1`\ Wus\[UnderBracket]201[t]\)\/cell\[UnderBracket]201\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]202", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]202[t] - 
                      20\ Y\[UnderBracket]202[t]] - 
                0.1`\ Wus\[UnderBracket]202[t]\)\/cell\[UnderBracket]202\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]203", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]203[t] - 
                      20\ Y\[UnderBracket]203[t]] - 
                0.1`\ Wus\[UnderBracket]203[t]\)\/cell\[UnderBracket]203\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]204", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]204[t] - 
                      20\ Y\[UnderBracket]204[t]] - 
                0.1`\ Wus\[UnderBracket]204[t]\)\/cell\[UnderBracket]204\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]205", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]205[t] - 
                      20\ Y\[UnderBracket]205[t]] - 
                0.1`\ Wus\[UnderBracket]205[t]\)\/cell\[UnderBracket]205\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]206", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]206[t] - 
                      20\ Y\[UnderBracket]206[t]] - 
                0.1`\ Wus\[UnderBracket]206[t]\)\/cell\[UnderBracket]206\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]207", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]207[t] - 
                      20\ Y\[UnderBracket]207[t]] - 
                0.1`\ Wus\[UnderBracket]207[t]\)\/cell\[UnderBracket]207\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]208", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]208[t] - 
                      20\ Y\[UnderBracket]208[t]] - 
                0.1`\ Wus\[UnderBracket]208[t]\)\/cell\[UnderBracket]208\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]209", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]209[t] - 
                      20\ Y\[UnderBracket]209[t]] - 
                0.1`\ Wus\[UnderBracket]209[t]\)\/cell\[UnderBracket]209\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]21", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]21[t] - 
                      20\ Y\[UnderBracket]21[t]] - 
                0.1`\ Wus\[UnderBracket]21[t]\)\/cell\[UnderBracket]21\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]210", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]210[t] - 
                      20\ Y\[UnderBracket]210[t]] - 
                0.1`\ Wus\[UnderBracket]210[t]\)\/cell\[UnderBracket]210\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]211", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]211[t] - 
                      20\ Y\[UnderBracket]211[t]] - 
                0.1`\ Wus\[UnderBracket]211[t]\)\/cell\[UnderBracket]211\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]212", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]212[t] - 
                      20\ Y\[UnderBracket]212[t]] - 
                0.1`\ Wus\[UnderBracket]212[t]\)\/cell\[UnderBracket]212\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]213", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]213[t] - 
                      20\ Y\[UnderBracket]213[t]] - 
                0.1`\ Wus\[UnderBracket]213[t]\)\/cell\[UnderBracket]213\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]214", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]214[t] - 
                      20\ Y\[UnderBracket]214[t]] - 
                0.1`\ Wus\[UnderBracket]214[t]\)\/cell\[UnderBracket]214\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]215", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]215[t] - 
                      20\ Y\[UnderBracket]215[t]] - 
                0.1`\ Wus\[UnderBracket]215[t]\)\/cell\[UnderBracket]215\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]216", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]216[t] - 
                      20\ Y\[UnderBracket]216[t]] - 
                0.1`\ Wus\[UnderBracket]216[t]\)\/cell\[UnderBracket]216\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]217", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]217[t] - 
                      20\ Y\[UnderBracket]217[t]] - 
                0.1`\ Wus\[UnderBracket]217[t]\)\/cell\[UnderBracket]217\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]218", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]218[t] - 
                      20\ Y\[UnderBracket]218[t]] - 
                0.1`\ Wus\[UnderBracket]218[t]\)\/cell\[UnderBracket]218\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]219", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]219[t] - 
                      20\ Y\[UnderBracket]219[t]] - 
                0.1`\ Wus\[UnderBracket]219[t]\)\/cell\[UnderBracket]219\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]22", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]22[t] - 
                      20\ Y\[UnderBracket]22[t]] - 
                0.1`\ Wus\[UnderBracket]22[t]\)\/cell\[UnderBracket]22\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]220", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]220[t] - 
                      20\ Y\[UnderBracket]220[t]] - 
                0.1`\ Wus\[UnderBracket]220[t]\)\/cell\[UnderBracket]220\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]221", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]221[t] - 
                      20\ Y\[UnderBracket]221[t]] - 
                0.1`\ Wus\[UnderBracket]221[t]\)\/cell\[UnderBracket]221\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]222", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]222[t] - 
                      20\ Y\[UnderBracket]222[t]] - 
                0.1`\ Wus\[UnderBracket]222[t]\)\/cell\[UnderBracket]222\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]223", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]223[t] - 
                      20\ Y\[UnderBracket]223[t]] - 
                0.1`\ Wus\[UnderBracket]223[t]\)\/cell\[UnderBracket]223\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]224", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]224[t] - 
                      20\ Y\[UnderBracket]224[t]] - 
                0.1`\ Wus\[UnderBracket]224[t]\)\/cell\[UnderBracket]224\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]225", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]225[t] - 
                      20\ Y\[UnderBracket]225[t]] - 
                0.1`\ Wus\[UnderBracket]225[t]\)\/cell\[UnderBracket]225\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]226", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]226[t] - 
                      20\ Y\[UnderBracket]226[t]] - 
                0.1`\ Wus\[UnderBracket]226[t]\)\/cell\[UnderBracket]226\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]227", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]227[t] - 
                      20\ Y\[UnderBracket]227[t]] - 
                0.1`\ Wus\[UnderBracket]227[t]\)\/cell\[UnderBracket]227\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]228", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]228[t] - 
                      20\ Y\[UnderBracket]228[t]] - 
                0.1`\ Wus\[UnderBracket]228[t]\)\/cell\[UnderBracket]228\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]229", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]229[t] - 
                      20\ Y\[UnderBracket]229[t]] - 
                0.1`\ Wus\[UnderBracket]229[t]\)\/cell\[UnderBracket]229\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]23", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]23[t] - 
                      20\ Y\[UnderBracket]23[t]] - 
                0.1`\ Wus\[UnderBracket]23[t]\)\/cell\[UnderBracket]23\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]230", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]230[t] - 
                      20\ Y\[UnderBracket]230[t]] - 
                0.1`\ Wus\[UnderBracket]230[t]\)\/cell\[UnderBracket]230\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]231", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]231[t] - 
                      20\ Y\[UnderBracket]231[t]] - 
                0.1`\ Wus\[UnderBracket]231[t]\)\/cell\[UnderBracket]231\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]232", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]232[t] - 
                      20\ Y\[UnderBracket]232[t]] - 
                0.1`\ Wus\[UnderBracket]232[t]\)\/cell\[UnderBracket]232\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]233", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]233[t] - 
                      20\ Y\[UnderBracket]233[t]] - 
                0.1`\ Wus\[UnderBracket]233[t]\)\/cell\[UnderBracket]233\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]234", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]234[t] - 
                      20\ Y\[UnderBracket]234[t]] - 
                0.1`\ Wus\[UnderBracket]234[t]\)\/cell\[UnderBracket]234\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]235", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]235[t] - 
                      20\ Y\[UnderBracket]235[t]] - 
                0.1`\ Wus\[UnderBracket]235[t]\)\/cell\[UnderBracket]235\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]236", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]236[t] - 
                      20\ Y\[UnderBracket]236[t]] - 
                0.1`\ Wus\[UnderBracket]236[t]\)\/cell\[UnderBracket]236\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]237", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]237[t] - 
                      20\ Y\[UnderBracket]237[t]] - 
                0.1`\ Wus\[UnderBracket]237[t]\)\/cell\[UnderBracket]237\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]238", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]238[t] - 
                      20\ Y\[UnderBracket]238[t]] - 
                0.1`\ Wus\[UnderBracket]238[t]\)\/cell\[UnderBracket]238\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]239", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]239[t] - 
                      20\ Y\[UnderBracket]239[t]] - 
                0.1`\ Wus\[UnderBracket]239[t]\)\/cell\[UnderBracket]239\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]24", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]24[t] - 
                      20\ Y\[UnderBracket]24[t]] - 
                0.1`\ Wus\[UnderBracket]24[t]\)\/cell\[UnderBracket]24\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]240", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]240[t] - 
                      20\ Y\[UnderBracket]240[t]] - 
                0.1`\ Wus\[UnderBracket]240[t]\)\/cell\[UnderBracket]240\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]241", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]241[t] - 
                      20\ Y\[UnderBracket]241[t]] - 
                0.1`\ Wus\[UnderBracket]241[t]\)\/cell\[UnderBracket]241\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]242", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]242[t] - 
                      20\ Y\[UnderBracket]242[t]] - 
                0.1`\ Wus\[UnderBracket]242[t]\)\/cell\[UnderBracket]242\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]243", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]243[t] - 
                      20\ Y\[UnderBracket]243[t]] - 
                0.1`\ Wus\[UnderBracket]243[t]\)\/cell\[UnderBracket]243\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]244", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]244[t] - 
                      20\ Y\[UnderBracket]244[t]] - 
                0.1`\ Wus\[UnderBracket]244[t]\)\/cell\[UnderBracket]244\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]245", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]245[t] - 
                      20\ Y\[UnderBracket]245[t]] - 
                0.1`\ Wus\[UnderBracket]245[t]\)\/cell\[UnderBracket]245\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]246", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]246[t] - 
                      20\ Y\[UnderBracket]246[t]] - 
                0.1`\ Wus\[UnderBracket]246[t]\)\/cell\[UnderBracket]246\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]247", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]247[t] - 
                      20\ Y\[UnderBracket]247[t]] - 
                0.1`\ Wus\[UnderBracket]247[t]\)\/cell\[UnderBracket]247\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]248", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]248[t] - 
                      20\ Y\[UnderBracket]248[t]] - 
                0.1`\ Wus\[UnderBracket]248[t]\)\/cell\[UnderBracket]248\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]249", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]249[t] - 
                      20\ Y\[UnderBracket]249[t]] - 
                0.1`\ Wus\[UnderBracket]249[t]\)\/cell\[UnderBracket]249\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]25", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]25[t] - 
                      20\ Y\[UnderBracket]25[t]] - 
                0.1`\ Wus\[UnderBracket]25[t]\)\/cell\[UnderBracket]25\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]250", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]250[t] - 
                      20\ Y\[UnderBracket]250[t]] - 
                0.1`\ Wus\[UnderBracket]250[t]\)\/cell\[UnderBracket]250\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]251", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]251[t] - 
                      20\ Y\[UnderBracket]251[t]] - 
                0.1`\ Wus\[UnderBracket]251[t]\)\/cell\[UnderBracket]251\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]252", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]252[t] - 
                      20\ Y\[UnderBracket]252[t]] - 
                0.1`\ Wus\[UnderBracket]252[t]\)\/cell\[UnderBracket]252\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]253", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]253[t] - 
                      20\ Y\[UnderBracket]253[t]] - 
                0.1`\ Wus\[UnderBracket]253[t]\)\/cell\[UnderBracket]253\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]26", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]26[t] - 
                      20\ Y\[UnderBracket]26[t]] - 
                0.1`\ Wus\[UnderBracket]26[t]\)\/cell\[UnderBracket]26\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]27", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]27[t] - 
                      20\ Y\[UnderBracket]27[t]] - 
                0.1`\ Wus\[UnderBracket]27[t]\)\/cell\[UnderBracket]27\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]28", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]28[t] - 
                      20\ Y\[UnderBracket]28[t]] - 
                0.1`\ Wus\[UnderBracket]28[t]\)\/cell\[UnderBracket]28\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]29", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]29[t] - 
                      20\ Y\[UnderBracket]29[t]] - 
                0.1`\ Wus\[UnderBracket]29[t]\)\/cell\[UnderBracket]29\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]3", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]3[t] - 20\ Y\[UnderBracket]3[t]] - 
                0.1`\ Wus\[UnderBracket]3[t]\)\/cell\[UnderBracket]3\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]30", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]30[t] - 
                      20\ Y\[UnderBracket]30[t]] - 
                0.1`\ Wus\[UnderBracket]30[t]\)\/cell\[UnderBracket]30\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]31", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]31[t] - 
                      20\ Y\[UnderBracket]31[t]] - 
                0.1`\ Wus\[UnderBracket]31[t]\)\/cell\[UnderBracket]31\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]32", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]32[t] - 
                      20\ Y\[UnderBracket]32[t]] - 
                0.1`\ Wus\[UnderBracket]32[t]\)\/cell\[UnderBracket]32\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]33", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]33[t] - 
                      20\ Y\[UnderBracket]33[t]] - 
                0.1`\ Wus\[UnderBracket]33[t]\)\/cell\[UnderBracket]33\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]34", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]34[t] - 
                      20\ Y\[UnderBracket]34[t]] - 
                0.1`\ Wus\[UnderBracket]34[t]\)\/cell\[UnderBracket]34\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]35", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]35[t] - 
                      20\ Y\[UnderBracket]35[t]] - 
                0.1`\ Wus\[UnderBracket]35[t]\)\/cell\[UnderBracket]35\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]36", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]36[t] - 
                      20\ Y\[UnderBracket]36[t]] - 
                0.1`\ Wus\[UnderBracket]36[t]\)\/cell\[UnderBracket]36\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]37", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]37[t] - 
                      20\ Y\[UnderBracket]37[t]] - 
                0.1`\ Wus\[UnderBracket]37[t]\)\/cell\[UnderBracket]37\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]38", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]38[t] - 
                      20\ Y\[UnderBracket]38[t]] - 
                0.1`\ Wus\[UnderBracket]38[t]\)\/cell\[UnderBracket]38\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]39", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]39[t] - 
                      20\ Y\[UnderBracket]39[t]] - 
                0.1`\ Wus\[UnderBracket]39[t]\)\/cell\[UnderBracket]39\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]4", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]4[t] - 20\ Y\[UnderBracket]4[t]] - 
                0.1`\ Wus\[UnderBracket]4[t]\)\/cell\[UnderBracket]4\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]40", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]40[t] - 
                      20\ Y\[UnderBracket]40[t]] - 
                0.1`\ Wus\[UnderBracket]40[t]\)\/cell\[UnderBracket]40\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]41", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]41[t] - 
                      20\ Y\[UnderBracket]41[t]] - 
                0.1`\ Wus\[UnderBracket]41[t]\)\/cell\[UnderBracket]41\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]42", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]42[t] - 
                      20\ Y\[UnderBracket]42[t]] - 
                0.1`\ Wus\[UnderBracket]42[t]\)\/cell\[UnderBracket]42\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]43", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]43[t] - 
                      20\ Y\[UnderBracket]43[t]] - 
                0.1`\ Wus\[UnderBracket]43[t]\)\/cell\[UnderBracket]43\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]44", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]44[t] - 
                      20\ Y\[UnderBracket]44[t]] - 
                0.1`\ Wus\[UnderBracket]44[t]\)\/cell\[UnderBracket]44\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]45", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]45[t] - 
                      20\ Y\[UnderBracket]45[t]] - 
                0.1`\ Wus\[UnderBracket]45[t]\)\/cell\[UnderBracket]45\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]46", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]46[t] - 
                      20\ Y\[UnderBracket]46[t]] - 
                0.1`\ Wus\[UnderBracket]46[t]\)\/cell\[UnderBracket]46\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]47", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]47[t] - 
                      20\ Y\[UnderBracket]47[t]] - 
                0.1`\ Wus\[UnderBracket]47[t]\)\/cell\[UnderBracket]47\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]48", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]48[t] - 
                      20\ Y\[UnderBracket]48[t]] - 
                0.1`\ Wus\[UnderBracket]48[t]\)\/cell\[UnderBracket]48\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]49", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]49[t] - 
                      20\ Y\[UnderBracket]49[t]] - 
                0.1`\ Wus\[UnderBracket]49[t]\)\/cell\[UnderBracket]49\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]5", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]5[t] - 20\ Y\[UnderBracket]5[t]] - 
                0.1`\ Wus\[UnderBracket]5[t]\)\/cell\[UnderBracket]5\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]50", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]50[t] - 
                      20\ Y\[UnderBracket]50[t]] - 
                0.1`\ Wus\[UnderBracket]50[t]\)\/cell\[UnderBracket]50\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]51", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]51[t] - 
                      20\ Y\[UnderBracket]51[t]] - 
                0.1`\ Wus\[UnderBracket]51[t]\)\/cell\[UnderBracket]51\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]52", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]52[t] - 
                      20\ Y\[UnderBracket]52[t]] - 
                0.1`\ Wus\[UnderBracket]52[t]\)\/cell\[UnderBracket]52\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]53", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]53[t] - 
                      20\ Y\[UnderBracket]53[t]] - 
                0.1`\ Wus\[UnderBracket]53[t]\)\/cell\[UnderBracket]53\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]54", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]54[t] - 
                      20\ Y\[UnderBracket]54[t]] - 
                0.1`\ Wus\[UnderBracket]54[t]\)\/cell\[UnderBracket]54\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]55", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]55[t] - 
                      20\ Y\[UnderBracket]55[t]] - 
                0.1`\ Wus\[UnderBracket]55[t]\)\/cell\[UnderBracket]55\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]56", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]56[t] - 
                      20\ Y\[UnderBracket]56[t]] - 
                0.1`\ Wus\[UnderBracket]56[t]\)\/cell\[UnderBracket]56\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]57", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]57[t] - 
                      20\ Y\[UnderBracket]57[t]] - 
                0.1`\ Wus\[UnderBracket]57[t]\)\/cell\[UnderBracket]57\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]58", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]58[t] - 
                      20\ Y\[UnderBracket]58[t]] - 
                0.1`\ Wus\[UnderBracket]58[t]\)\/cell\[UnderBracket]58\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]59", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]59[t] - 
                      20\ Y\[UnderBracket]59[t]] - 
                0.1`\ Wus\[UnderBracket]59[t]\)\/cell\[UnderBracket]59\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]6", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]6[t] - 20\ Y\[UnderBracket]6[t]] - 
                0.1`\ Wus\[UnderBracket]6[t]\)\/cell\[UnderBracket]6\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]60", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]60[t] - 
                      20\ Y\[UnderBracket]60[t]] - 
                0.1`\ Wus\[UnderBracket]60[t]\)\/cell\[UnderBracket]60\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]61", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]61[t] - 
                      20\ Y\[UnderBracket]61[t]] - 
                0.1`\ Wus\[UnderBracket]61[t]\)\/cell\[UnderBracket]61\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]62", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]62[t] - 
                      20\ Y\[UnderBracket]62[t]] - 
                0.1`\ Wus\[UnderBracket]62[t]\)\/cell\[UnderBracket]62\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]63", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]63[t] - 
                      20\ Y\[UnderBracket]63[t]] - 
                0.1`\ Wus\[UnderBracket]63[t]\)\/cell\[UnderBracket]63\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]64", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]64[t] - 
                      20\ Y\[UnderBracket]64[t]] - 
                0.1`\ Wus\[UnderBracket]64[t]\)\/cell\[UnderBracket]64\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]65", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]65[t] - 
                      20\ Y\[UnderBracket]65[t]] - 
                0.1`\ Wus\[UnderBracket]65[t]\)\/cell\[UnderBracket]65\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]66", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]66[t] - 
                      20\ Y\[UnderBracket]66[t]] - 
                0.1`\ Wus\[UnderBracket]66[t]\)\/cell\[UnderBracket]66\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]67", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]67[t] - 
                      20\ Y\[UnderBracket]67[t]] - 
                0.1`\ Wus\[UnderBracket]67[t]\)\/cell\[UnderBracket]67\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]68", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]68[t] - 
                      20\ Y\[UnderBracket]68[t]] - 
                0.1`\ Wus\[UnderBracket]68[t]\)\/cell\[UnderBracket]68\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]69", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]69[t] - 
                      20\ Y\[UnderBracket]69[t]] - 
                0.1`\ Wus\[UnderBracket]69[t]\)\/cell\[UnderBracket]69\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]7", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]7[t] - 20\ Y\[UnderBracket]7[t]] - 
                0.1`\ Wus\[UnderBracket]7[t]\)\/cell\[UnderBracket]7\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]70", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]70[t] - 
                      20\ Y\[UnderBracket]70[t]] - 
                0.1`\ Wus\[UnderBracket]70[t]\)\/cell\[UnderBracket]70\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]71", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]71[t] - 
                      20\ Y\[UnderBracket]71[t]] - 
                0.1`\ Wus\[UnderBracket]71[t]\)\/cell\[UnderBracket]71\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]72", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]72[t] - 
                      20\ Y\[UnderBracket]72[t]] - 
                0.1`\ Wus\[UnderBracket]72[t]\)\/cell\[UnderBracket]72\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]73", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]73[t] - 
                      20\ Y\[UnderBracket]73[t]] - 
                0.1`\ Wus\[UnderBracket]73[t]\)\/cell\[UnderBracket]73\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]74", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]74[t] - 
                      20\ Y\[UnderBracket]74[t]] - 
                0.1`\ Wus\[UnderBracket]74[t]\)\/cell\[UnderBracket]74\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]75", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]75[t] - 
                      20\ Y\[UnderBracket]75[t]] - 
                0.1`\ Wus\[UnderBracket]75[t]\)\/cell\[UnderBracket]75\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]76", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]76[t] - 
                      20\ Y\[UnderBracket]76[t]] - 
                0.1`\ Wus\[UnderBracket]76[t]\)\/cell\[UnderBracket]76\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]77", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]77[t] - 
                      20\ Y\[UnderBracket]77[t]] - 
                0.1`\ Wus\[UnderBracket]77[t]\)\/cell\[UnderBracket]77\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]78", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]78[t] - 
                      20\ Y\[UnderBracket]78[t]] - 
                0.1`\ Wus\[UnderBracket]78[t]\)\/cell\[UnderBracket]78\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]79", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]79[t] - 
                      20\ Y\[UnderBracket]79[t]] - 
                0.1`\ Wus\[UnderBracket]79[t]\)\/cell\[UnderBracket]79\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]8", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]8[t] - 20\ Y\[UnderBracket]8[t]] - 
                0.1`\ Wus\[UnderBracket]8[t]\)\/cell\[UnderBracket]8\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]80", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]80[t] - 
                      20\ Y\[UnderBracket]80[t]] - 
                0.1`\ Wus\[UnderBracket]80[t]\)\/cell\[UnderBracket]80\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]81", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]81[t] - 
                      20\ Y\[UnderBracket]81[t]] - 
                0.1`\ Wus\[UnderBracket]81[t]\)\/cell\[UnderBracket]81\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]82", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]82[t] - 
                      20\ Y\[UnderBracket]82[t]] - 
                0.1`\ Wus\[UnderBracket]82[t]\)\/cell\[UnderBracket]82\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]83", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]83[t] - 
                      20\ Y\[UnderBracket]83[t]] - 
                0.1`\ Wus\[UnderBracket]83[t]\)\/cell\[UnderBracket]83\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]84", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]84[t] - 
                      20\ Y\[UnderBracket]84[t]] - 
                0.1`\ Wus\[UnderBracket]84[t]\)\/cell\[UnderBracket]84\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]85", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]85[t] - 
                      20\ Y\[UnderBracket]85[t]] - 
                0.1`\ Wus\[UnderBracket]85[t]\)\/cell\[UnderBracket]85\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]86", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]86[t] - 
                      20\ Y\[UnderBracket]86[t]] - 
                0.1`\ Wus\[UnderBracket]86[t]\)\/cell\[UnderBracket]86\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]87", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]87[t] - 
                      20\ Y\[UnderBracket]87[t]] - 
                0.1`\ Wus\[UnderBracket]87[t]\)\/cell\[UnderBracket]87\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]88", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]88[t] - 
                      20\ Y\[UnderBracket]88[t]] - 
                0.1`\ Wus\[UnderBracket]88[t]\)\/cell\[UnderBracket]88\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]89", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]89[t] - 
                      20\ Y\[UnderBracket]89[t]] - 
                0.1`\ Wus\[UnderBracket]89[t]\)\/cell\[UnderBracket]89\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]9", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]9[t] - 20\ Y\[UnderBracket]9[t]] - 
                0.1`\ Wus\[UnderBracket]9[t]\)\/cell\[UnderBracket]9\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]90", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]90[t] - 
                      20\ Y\[UnderBracket]90[t]] - 
                0.1`\ Wus\[UnderBracket]90[t]\)\/cell\[UnderBracket]90\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]91", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]91[t] - 
                      20\ Y\[UnderBracket]91[t]] - 
                0.1`\ Wus\[UnderBracket]91[t]\)\/cell\[UnderBracket]91\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]92", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]92[t] - 
                      20\ Y\[UnderBracket]92[t]] - 
                0.1`\ Wus\[UnderBracket]92[t]\)\/cell\[UnderBracket]92\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]93", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]93[t] - 
                      20\ Y\[UnderBracket]93[t]] - 
                0.1`\ Wus\[UnderBracket]93[t]\)\/cell\[UnderBracket]93\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]94", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]94[t] - 
                      20\ Y\[UnderBracket]94[t]] - 
                0.1`\ Wus\[UnderBracket]94[t]\)\/cell\[UnderBracket]94\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]95", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]95[t] - 
                      20\ Y\[UnderBracket]95[t]] - 
                0.1`\ Wus\[UnderBracket]95[t]\)\/cell\[UnderBracket]95\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]96", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]96[t] - 
                      20\ Y\[UnderBracket]96[t]] - 
                0.1`\ Wus\[UnderBracket]96[t]\)\/cell\[UnderBracket]96\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]97", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]97[t] - 
                      20\ Y\[UnderBracket]97[t]] - 
                0.1`\ Wus\[UnderBracket]97[t]\)\/cell\[UnderBracket]97\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]98", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]98[t] - 
                      20\ Y\[UnderBracket]98[t]] - 
                0.1`\ Wus\[UnderBracket]98[t]\)\/cell\[UnderBracket]98\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Wus\[UnderBracket]99", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Sigma[
                    0.5`\ A\[UnderBracket]99[t] - 
                      20\ Y\[UnderBracket]99[t]] - 
                0.1`\ Wus\[UnderBracket]99[t]\)\/cell\[UnderBracket]99\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]1", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) - 
                0.4`\ Y\[UnderBracket]1[t] + 0.1`\ Y\[UnderBracket]2[t] + 
                0.1`\ Y\[UnderBracket]3[t] + 
                0.1`\ Y\[UnderBracket]8[t]\)\/cell\[UnderBracket]1\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]10", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) - 
                0.6`\ Y\[UnderBracket]10[t] + 0.1`\ Y\[UnderBracket]18[t] + 
                0.1`\ Y\[UnderBracket]19[t] + 0.1`\ Y\[UnderBracket]28[t] + 
                0.1`\ Y\[UnderBracket]4[t] + 
                0.1`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]10\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]100", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \
\(\(1\/cell\[UnderBracket]100\)\((\(-0.8999999999999999`\)\ \
Y\[UnderBracket]100[t] + 0.1`\ Y\[UnderBracket]114[t] + 
              0.1`\ Y\[UnderBracket]123[t] + 0.1`\ Y\[UnderBracket]124[t] + 
              0.1`\ Y\[UnderBracket]132[t] + 0.1`\ Y\[UnderBracket]65[t] + 
              0.1`\ Y\[UnderBracket]83[t] + 0.1`\ Y\[UnderBracket]87[t] + 
              0.1`\ Y\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]101", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]101\)\((\(-0.7`\)\ Y\
\[UnderBracket]101[t] + 0.1`\ Y\[UnderBracket]109[t] + 
              0.1`\ Y\[UnderBracket]119[t] + 0.1`\ Y\[UnderBracket]131[t] + 
              0.1`\ Y\[UnderBracket]79[t] + 0.1`\ Y\[UnderBracket]84[t] + 
              0.1`\ Y\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]102", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]102\)\((\(-0.7`\)\ Y\
\[UnderBracket]102[t] + 0.1`\ Y\[UnderBracket]109[t] + 
              0.1`\ Y\[UnderBracket]110[t] + 0.1`\ Y\[UnderBracket]129[t] + 
              0.1`\ Y\[UnderBracket]72[t] + 0.1`\ Y\[UnderBracket]80[t] + 
              0.1`\ Y\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]103", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]103\)\((\(-0.7`\)\ Y\
\[UnderBracket]103[t] + 0.1`\ Y\[UnderBracket]107[t] + 
              0.1`\ Y\[UnderBracket]111[t] + 0.1`\ Y\[UnderBracket]136[t] + 
              0.1`\ Y\[UnderBracket]137[t] + 0.1`\ Y\[UnderBracket]77[t] + 
              0.1`\ Y\[UnderBracket]92[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]104", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]104\)\((\(-0.7`\)\ Y\
\[UnderBracket]104[t] + 0.1`\ Y\[UnderBracket]115[t] + 
              0.1`\ Y\[UnderBracket]124[t] + 0.1`\ Y\[UnderBracket]128[t] + 
              0.1`\ Y\[UnderBracket]130[t] + 0.1`\ Y\[UnderBracket]93[t] + 
              0.1`\ Y\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]105", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(-0.5`\)\ Y\[UnderBracket]105[t] + 
                0.1`\ Y\[UnderBracket]115[t] + 0.1`\ Y\[UnderBracket]116[t] + 
                0.1`\ Y\[UnderBracket]90[t] + 
                0.1`\ Y\[UnderBracket]93[t]\)\/cell\[UnderBracket]105\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]106", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(-0.6`\)\ Y\[UnderBracket]106[t] + 
                0.1`\ Y\[UnderBracket]118[t] + 0.1`\ Y\[UnderBracket]125[t] + 
                0.1`\ Y\[UnderBracket]86[t] + 0.1`\ Y\[UnderBracket]91[t] + 
                0.1`\ Y\[UnderBracket]98[t]\)\/cell\[UnderBracket]106\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]107", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]103[t] - 0.6`\ Y\[UnderBracket]107[t] + 
                0.1`\ Y\[UnderBracket]122[t] + 0.1`\ Y\[UnderBracket]137[t] + 
                0.1`\ Y\[UnderBracket]77[t] + 
                0.1`\ Y\[UnderBracket]78[t]\)\/cell\[UnderBracket]107\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]108", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(-0.5`\)\ Y\[UnderBracket]108[t] + 
                0.1`\ Y\[UnderBracket]116[t] + 0.1`\ Y\[UnderBracket]117[t] + 
                0.1`\ Y\[UnderBracket]90[t] + 
                0.1`\ Y\[UnderBracket]94[t]\)\/cell\[UnderBracket]108\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]109", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]101[t] + 
                0.1`\ Y\[UnderBracket]102[t] - 0.6`\ Y\[UnderBracket]109[t] + 
                0.1`\ Y\[UnderBracket]129[t] + 0.1`\ Y\[UnderBracket]131[t] + 
                0.1`\ Y\[UnderBracket]84[t]\)\/cell\[UnderBracket]109\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]11", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]11\)\((\(-0.7999999999999999`\
\)\ Y\[UnderBracket]11[t] + 0.1`\ Y\[UnderBracket]13[t] + 
              0.1`\ Y\[UnderBracket]22[t] + 0.1`\ Y\[UnderBracket]24[t] + 
              0.1`\ Y\[UnderBracket]25[t] + 0.1`\ Y\[UnderBracket]26[t] + 
              0.1`\ Y\[UnderBracket]6[t] + 0.1`\ Y\[UnderBracket]7[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]110", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]102[t] - 
                0.6`\ Y\[UnderBracket]110[t] + 0.1`\ Y\[UnderBracket]112[t] + 
                0.1`\ Y\[UnderBracket]129[t] + 0.1`\ Y\[UnderBracket]80[t] + 
                0.1`\ Y\[UnderBracket]88[t]\)\/cell\[UnderBracket]110\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]111", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]103[t] - 
                0.6`\ Y\[UnderBracket]111[t] + 0.1`\ Y\[UnderBracket]121[t] + 
                0.1`\ Y\[UnderBracket]136[t] + 0.1`\ Y\[UnderBracket]92[t] + 
                0.1`\ Y\[UnderBracket]95[t]\)\/cell\[UnderBracket]111\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]112", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]112\)\((0.1`\ \
Y\[UnderBracket]110[t] - 0.7`\ Y\[UnderBracket]112[t] + 
              0.1`\ Y\[UnderBracket]120[t] + 0.1`\ Y\[UnderBracket]129[t] + 
              0.1`\ Y\[UnderBracket]144[t] + 0.1`\ Y\[UnderBracket]149[t] + 
              0.1`\ Y\[UnderBracket]88[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]113", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) - 
                0.6`\ Y\[UnderBracket]113[t] + 0.1`\ Y\[UnderBracket]127[t] + 
                0.1`\ Y\[UnderBracket]134[t] + 0.1`\ Y\[UnderBracket]82[t] + 
                0.1`\ Y\[UnderBracket]89[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]113\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]114", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]100[t] - 
                0.5`\ Y\[UnderBracket]114[t] + 0.1`\ Y\[UnderBracket]124[t] + 
                0.1`\ Y\[UnderBracket]132[t] + 
                0.1`\ Y\[UnderBracket]145[t]\)\/cell\[UnderBracket]114\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]115", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]115\)\((0.1`\ \
Y\[UnderBracket]104[t] + 0.1`\ Y\[UnderBracket]105[t] - 
              0.7`\ Y\[UnderBracket]115[t] + 0.1`\ Y\[UnderBracket]116[t] + 
              0.1`\ Y\[UnderBracket]130[t] + 0.1`\ Y\[UnderBracket]142[t] + 
              0.1`\ Y\[UnderBracket]93[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]116", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]116\)\((0.1`\ \
Y\[UnderBracket]105[t] + 0.1`\ Y\[UnderBracket]108[t] + 
              0.1`\ Y\[UnderBracket]115[t] - 0.7`\ Y\[UnderBracket]116[t] + 
              0.1`\ Y\[UnderBracket]117[t] + 0.1`\ Y\[UnderBracket]143[t] + 
              0.1`\ Y\[UnderBracket]90[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]117", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]117\)\((0.1`\ \
Y\[UnderBracket]108[t] + 0.1`\ Y\[UnderBracket]116[t] - 
              0.7999999999999999`\ Y\[UnderBracket]117[t] + 
              0.1`\ Y\[UnderBracket]125[t] + 0.1`\ Y\[UnderBracket]143[t] + 
              0.1`\ Y\[UnderBracket]154[t] + 0.1`\ Y\[UnderBracket]94[t] + 
              0.1`\ Y\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]118", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]118\)\((0.1`\ \
Y\[UnderBracket]106[t] - 0.7`\ Y\[UnderBracket]118[t] + 
              0.1`\ Y\[UnderBracket]119[t] + 0.1`\ Y\[UnderBracket]125[t] + 
              0.1`\ Y\[UnderBracket]135[t] + 0.1`\ Y\[UnderBracket]91[t] + 
              0.1`\ Y\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]119", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]101[t] + 
                0.1`\ Y\[UnderBracket]118[t] - 0.6`\ Y\[UnderBracket]119[t] + 
                0.1`\ Y\[UnderBracket]131[t] + 0.1`\ Y\[UnderBracket]135[t] + 
                0.1`\ Y\[UnderBracket]99[t]\)\/cell\[UnderBracket]119\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]12", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) - 
                0.5`\ Y\[UnderBracket]12[t] + 0.1`\ Y\[UnderBracket]16[t] + 
                0.1`\ Y\[UnderBracket]22[t] + 0.1`\ Y\[UnderBracket]30[t] + 
                0.1`\ Y\[UnderBracket]6[t]\)\/cell\[UnderBracket]12\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]120", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]120\)\((0.1`\ \
Y\[UnderBracket]112[t] - 0.7`\ Y\[UnderBracket]120[t] + 
              0.1`\ Y\[UnderBracket]121[t] + 0.1`\ Y\[UnderBracket]126[t] + 
              0.1`\ Y\[UnderBracket]149[t] + 0.1`\ Y\[UnderBracket]88[t] + 
              0.1`\ Y\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]121", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]121\)\((0.1`\ \
Y\[UnderBracket]111[t] + 0.1`\ Y\[UnderBracket]120[t] - 
              0.7999999999999999`\ Y\[UnderBracket]121[t] + 
              0.1`\ Y\[UnderBracket]126[t] + 0.1`\ Y\[UnderBracket]136[t] + 
              0.1`\ Y\[UnderBracket]138[t] + 0.1`\ Y\[UnderBracket]139[t] + 
              0.1`\ Y\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]122", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]107[t] - 0.4`\ Y\[UnderBracket]122[t] + 
                0.1`\ Y\[UnderBracket]137[t] + 
                0.1`\ Y\[UnderBracket]150[t]\)\/cell\[UnderBracket]122\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]123", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]123\)\((0.1`\ \
Y\[UnderBracket]100[t] - 0.7`\ Y\[UnderBracket]123[t] + 
              0.1`\ Y\[UnderBracket]127[t] + 0.1`\ Y\[UnderBracket]132[t] + 
              0.1`\ Y\[UnderBracket]141[t] + 0.1`\ Y\[UnderBracket]83[t] + 
              0.1`\ Y\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]124", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]124\)\((0.1`\ \
Y\[UnderBracket]100[t] + 0.1`\ Y\[UnderBracket]104[t] + 
              0.1`\ Y\[UnderBracket]114[t] - 
              0.7999999999999999`\ Y\[UnderBracket]124[t] + 
              0.1`\ Y\[UnderBracket]128[t] + 0.1`\ Y\[UnderBracket]140[t] + 
              0.1`\ Y\[UnderBracket]145[t] + 
              0.1`\ Y\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]125", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]125\)\((0.1`\ \
Y\[UnderBracket]106[t] + 0.1`\ Y\[UnderBracket]117[t] + 
              0.1`\ Y\[UnderBracket]118[t] - 
              0.8999999999999999`\ Y\[UnderBracket]125[t] + 
              0.1`\ Y\[UnderBracket]135[t] + 0.1`\ Y\[UnderBracket]154[t] + 
              0.1`\ Y\[UnderBracket]155[t] + 0.1`\ Y\[UnderBracket]162[t] + 
              0.1`\ Y\[UnderBracket]98[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]126", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]120[t] + 
                0.1`\ Y\[UnderBracket]121[t] - 0.5`\ Y\[UnderBracket]126[t] + 
                0.1`\ Y\[UnderBracket]138[t] + 
                0.1`\ Y\[UnderBracket]149[t]\)\/cell\[UnderBracket]126\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]127", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]113[t] + 
                0.1`\ Y\[UnderBracket]123[t] - 0.6`\ Y\[UnderBracket]127[t] + 
                0.1`\ Y\[UnderBracket]134[t] + 0.1`\ Y\[UnderBracket]141[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]127\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]128", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]104[t] + 
                0.1`\ Y\[UnderBracket]124[t] - 0.5`\ Y\[UnderBracket]128[t] + 
                0.1`\ Y\[UnderBracket]130[t] + 
                0.1`\ Y\[UnderBracket]140[t]\)\/cell\[UnderBracket]128\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]129", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]129\)\((0.1`\ \
Y\[UnderBracket]102[t] + 0.1`\ Y\[UnderBracket]109[t] + 
              0.1`\ Y\[UnderBracket]110[t] + 0.1`\ Y\[UnderBracket]112[t] - 
              0.7999999999999999`\ Y\[UnderBracket]129[t] + 
              0.1`\ Y\[UnderBracket]131[t] + 0.1`\ Y\[UnderBracket]133[t] + 
              0.1`\ Y\[UnderBracket]144[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]13", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] - 
                0.7`\ Y\[UnderBracket]13[t] + 0.1`\ Y\[UnderBracket]17[t] + 
                0.1`\ Y\[UnderBracket]26[t] + 0.1`\ Y\[UnderBracket]39[t] + 
                0.1`\ Y\[UnderBracket]7[t] + 
                0.1`\ Y\[UnderBracket]8[t]\)\/cell\[UnderBracket]13\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]130", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]130\)\((0.1`\ \
Y\[UnderBracket]104[t] + 0.1`\ Y\[UnderBracket]115[t] + 
              0.1`\ Y\[UnderBracket]128[t] - 
              0.7999999999999999`\ Y\[UnderBracket]130[t] + 
              0.1`\ Y\[UnderBracket]140[t] + 0.1`\ Y\[UnderBracket]142[t] + 
              0.1`\ Y\[UnderBracket]146[t] + 
              0.1`\ Y\[UnderBracket]156[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]131", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]131\)\((0.1`\ \
Y\[UnderBracket]101[t] + 0.1`\ Y\[UnderBracket]109[t] + 
              0.1`\ Y\[UnderBracket]119[t] + 0.1`\ Y\[UnderBracket]129[t] - 
              0.9999999999999999`\ Y\[UnderBracket]131[t] + 
              0.1`\ Y\[UnderBracket]133[t] + 0.1`\ Y\[UnderBracket]135[t] + 
              0.1`\ Y\[UnderBracket]147[t] + 0.1`\ Y\[UnderBracket]148[t] + 
              0.1`\ Y\[UnderBracket]158[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]132", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]132\)\((0.1`\ \
Y\[UnderBracket]100[t] + 0.1`\ Y\[UnderBracket]114[t] + 
              0.1`\ Y\[UnderBracket]123[t] - 0.7`\ Y\[UnderBracket]132[t] + 
              0.1`\ Y\[UnderBracket]141[t] + 0.1`\ Y\[UnderBracket]145[t] + 
              0.1`\ Y\[UnderBracket]164[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]133", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]129[t] + 
                0.1`\ Y\[UnderBracket]131[t] - 0.5`\ Y\[UnderBracket]133[t] + 
                0.1`\ Y\[UnderBracket]144[t] + 
                0.1`\ Y\[UnderBracket]148[t]\)\/cell\[UnderBracket]133\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]134", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]113[t] + 0.1`\ Y\[UnderBracket]127[t] - 
                0.6`\ Y\[UnderBracket]134[t] + 0.1`\ Y\[UnderBracket]141[t] + 
                0.1`\ Y\[UnderBracket]152[t] + 
                0.1`\ Y\[UnderBracket]153[t]\)\/cell\[UnderBracket]134\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]135", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]135\)\((0.1`\ \
Y\[UnderBracket]118[t] + 0.1`\ Y\[UnderBracket]119[t] + 
              0.1`\ Y\[UnderBracket]125[t] + 0.1`\ Y\[UnderBracket]131[t] - 
              0.7`\ Y\[UnderBracket]135[t] + 0.1`\ Y\[UnderBracket]147[t] + 
              0.1`\ Y\[UnderBracket]155[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]136", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]136\)\((0.1`\ \
Y\[UnderBracket]103[t] + 0.1`\ Y\[UnderBracket]111[t] + 
              0.1`\ Y\[UnderBracket]121[t] - 
              0.7999999999999999`\ Y\[UnderBracket]136[t] + 
              0.1`\ Y\[UnderBracket]137[t] + 0.1`\ Y\[UnderBracket]139[t] + 
              0.1`\ Y\[UnderBracket]157[t] + 
              0.1`\ Y\[UnderBracket]159[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]137", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]137\)\((0.1`\ \
Y\[UnderBracket]103[t] + 0.1`\ Y\[UnderBracket]107[t] + 
              0.1`\ Y\[UnderBracket]122[t] + 0.1`\ Y\[UnderBracket]136[t] - 
              0.7999999999999999`\ Y\[UnderBracket]137[t] + 
              0.1`\ Y\[UnderBracket]150[t] + 0.1`\ Y\[UnderBracket]159[t] + 
              0.1`\ Y\[UnderBracket]171[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]138", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]138\)\((0.1`\ \
Y\[UnderBracket]121[t] + 0.1`\ Y\[UnderBracket]126[t] - 
              0.7999999999999999`\ Y\[UnderBracket]138[t] + 
              0.1`\ Y\[UnderBracket]139[t] + 0.1`\ Y\[UnderBracket]149[t] + 
              0.1`\ Y\[UnderBracket]157[t] + 0.1`\ Y\[UnderBracket]163[t] + 
              0.1`\ Y\[UnderBracket]170[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]139", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]121[t] + 
                0.1`\ Y\[UnderBracket]136[t] + 0.1`\ Y\[UnderBracket]138[t] - 
                0.5`\ Y\[UnderBracket]139[t] + 
                0.1`\ Y\[UnderBracket]157[t]\)\/cell\[UnderBracket]139\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]14", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]14\)\((\(-0.7999999999999999`\
\)\ Y\[UnderBracket]14[t] + 0.1`\ Y\[UnderBracket]17[t] + 
              0.1`\ Y\[UnderBracket]23[t] + 0.1`\ Y\[UnderBracket]27[t] + 
              0.1`\ Y\[UnderBracket]33[t] + 0.1`\ Y\[UnderBracket]5[t] + 
              0.1`\ Y\[UnderBracket]8[t] + 0.1`\ Y\[UnderBracket]9[t])\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]140", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]124[t] + 
                0.1`\ Y\[UnderBracket]128[t] + 0.1`\ Y\[UnderBracket]130[t] - 
                0.6`\ Y\[UnderBracket]140[t] + 0.1`\ Y\[UnderBracket]145[t] + 
                0.1`\ Y\[UnderBracket]156[t]\)\/cell\[UnderBracket]140\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]141", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]141\)\((0.1`\ \
Y\[UnderBracket]123[t] + 0.1`\ Y\[UnderBracket]127[t] + 
              0.1`\ Y\[UnderBracket]132[t] + 0.1`\ Y\[UnderBracket]134[t] - 
              0.7`\ Y\[UnderBracket]141[t] + 0.1`\ Y\[UnderBracket]153[t] + 
              0.1`\ Y\[UnderBracket]164[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]142", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]115[t] + 
                0.1`\ Y\[UnderBracket]130[t] - 0.6`\ Y\[UnderBracket]142[t] + 
                0.1`\ Y\[UnderBracket]143[t] + 0.1`\ Y\[UnderBracket]146[t] + 
                0.1`\ Y\[UnderBracket]151[t]\)\/cell\[UnderBracket]142\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]143", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]116[t] + 
                0.1`\ Y\[UnderBracket]117[t] + 0.1`\ Y\[UnderBracket]142[t] - 
                0.6`\ Y\[UnderBracket]143[t] + 0.1`\ Y\[UnderBracket]151[t] + 
                0.1`\ Y\[UnderBracket]154[t]\)\/cell\[UnderBracket]143\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]144", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]144\)\((0.1`\ \
Y\[UnderBracket]112[t] + 0.1`\ Y\[UnderBracket]129[t] + 
              0.1`\ Y\[UnderBracket]133[t] - 
              0.7999999999999999`\ Y\[UnderBracket]144[t] + 
              0.1`\ Y\[UnderBracket]148[t] + 0.1`\ Y\[UnderBracket]149[t] + 
              0.1`\ Y\[UnderBracket]165[t] + 
              0.1`\ Y\[UnderBracket]169[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]145", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]145\)\((0.1`\ \
Y\[UnderBracket]114[t] + 0.1`\ Y\[UnderBracket]124[t] + 
              0.1`\ Y\[UnderBracket]132[t] + 0.1`\ Y\[UnderBracket]140[t] - 
              0.8999999999999999`\ Y\[UnderBracket]145[t] + 
              0.1`\ Y\[UnderBracket]156[t] + 0.1`\ Y\[UnderBracket]160[t] + 
              0.1`\ Y\[UnderBracket]164[t] + 
              0.1`\ Y\[UnderBracket]188[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]146", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]130[t] + 
                0.1`\ Y\[UnderBracket]142[t] - 0.6`\ Y\[UnderBracket]146[t] + 
                0.1`\ Y\[UnderBracket]151[t] + 0.1`\ Y\[UnderBracket]156[t] + 
                0.1`\ Y\[UnderBracket]161[t]\)\/cell\[UnderBracket]146\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]147", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]131[t] + 
                0.1`\ Y\[UnderBracket]135[t] - 0.6`\ Y\[UnderBracket]147[t] + 
                0.1`\ Y\[UnderBracket]155[t] + 0.1`\ Y\[UnderBracket]158[t] + 
                0.1`\ Y\[UnderBracket]167[t]\)\/cell\[UnderBracket]147\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]148", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]148\)\((0.1`\ \
Y\[UnderBracket]131[t] + 0.1`\ Y\[UnderBracket]133[t] + 
              0.1`\ Y\[UnderBracket]144[t] - 0.7`\ Y\[UnderBracket]148[t] + 
              0.1`\ Y\[UnderBracket]158[t] + 0.1`\ Y\[UnderBracket]168[t] + 
              0.1`\ Y\[UnderBracket]169[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]149", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]149\)\((0.1`\ \
Y\[UnderBracket]112[t] + 0.1`\ Y\[UnderBracket]120[t] + 
              0.1`\ Y\[UnderBracket]126[t] + 0.1`\ Y\[UnderBracket]138[t] + 
              0.1`\ Y\[UnderBracket]144[t] - 
              0.7999999999999999`\ Y\[UnderBracket]149[t] + 
              0.1`\ Y\[UnderBracket]163[t] + 
              0.1`\ Y\[UnderBracket]165[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]15", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) - 
                0.6`\ Y\[UnderBracket]15[t] + 0.1`\ Y\[UnderBracket]20[t] + 
                0.1`\ Y\[UnderBracket]21[t] + 0.1`\ Y\[UnderBracket]29[t] + 
                0.1`\ Y\[UnderBracket]34[t] + 
                0.1`\ Y\[UnderBracket]35[t]\)\/cell\[UnderBracket]15\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]150", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]122[t] + 0.1`\ Y\[UnderBracket]137[t] - 
                0.4`\ Y\[UnderBracket]150[t] + 
                0.1`\ Y\[UnderBracket]171[t]\)\/cell\[UnderBracket]150\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]151", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]151\)\((0.1`\ \
Y\[UnderBracket]142[t] + 0.1`\ Y\[UnderBracket]143[t] + 
              0.1`\ Y\[UnderBracket]146[t] - 
              0.7999999999999999`\ Y\[UnderBracket]151[t] + 
              0.1`\ Y\[UnderBracket]154[t] + 0.1`\ Y\[UnderBracket]161[t] + 
              0.1`\ Y\[UnderBracket]166[t] + 
              0.1`\ Y\[UnderBracket]175[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]152", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]134[t] - 0.5`\ Y\[UnderBracket]152[t] + 
                0.1`\ Y\[UnderBracket]153[t] + 0.1`\ Y\[UnderBracket]172[t] + 
                0.1`\ Y\[UnderBracket]178[t]\)\/cell\[UnderBracket]152\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]153", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]153\)\((0.1`\ \
Y\[UnderBracket]134[t] + 0.1`\ Y\[UnderBracket]141[t] + 
              0.1`\ Y\[UnderBracket]152[t] - 0.7`\ Y\[UnderBracket]153[t] + 
              0.1`\ Y\[UnderBracket]164[t] + 0.1`\ Y\[UnderBracket]172[t] + 
              0.1`\ Y\[UnderBracket]176[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]154", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]154\)\((0.1`\ \
Y\[UnderBracket]117[t] + 0.1`\ Y\[UnderBracket]125[t] + 
              0.1`\ Y\[UnderBracket]143[t] + 0.1`\ Y\[UnderBracket]151[t] - 
              0.7`\ Y\[UnderBracket]154[t] + 0.1`\ Y\[UnderBracket]162[t] + 
              0.1`\ Y\[UnderBracket]166[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]155", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]155\)\((0.1`\ \
Y\[UnderBracket]125[t] + 0.1`\ Y\[UnderBracket]135[t] + 
              0.1`\ Y\[UnderBracket]147[t] - 0.7`\ Y\[UnderBracket]155[t] + 
              0.1`\ Y\[UnderBracket]162[t] + 0.1`\ Y\[UnderBracket]167[t] + 
              0.1`\ Y\[UnderBracket]173[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]156", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]156\)\((0.1`\ \
Y\[UnderBracket]130[t] + 0.1`\ Y\[UnderBracket]140[t] + 
              0.1`\ Y\[UnderBracket]145[t] + 0.1`\ Y\[UnderBracket]146[t] - 
              0.7`\ Y\[UnderBracket]156[t] + 0.1`\ Y\[UnderBracket]160[t] + 
              0.1`\ Y\[UnderBracket]161[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]157", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]136[t] + 
                0.1`\ Y\[UnderBracket]138[t] + 0.1`\ Y\[UnderBracket]139[t] - 
                0.6`\ Y\[UnderBracket]157[t] + 0.1`\ Y\[UnderBracket]159[t] + 
                0.1`\ Y\[UnderBracket]170[t]\)\/cell\[UnderBracket]157\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]158", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]158\)\((0.1`\ \
Y\[UnderBracket]131[t] + 0.1`\ Y\[UnderBracket]147[t] + 
              0.1`\ Y\[UnderBracket]148[t] - 0.7`\ Y\[UnderBracket]158[t] + 
              0.1`\ Y\[UnderBracket]167[t] + 0.1`\ Y\[UnderBracket]168[t] + 
              0.1`\ Y\[UnderBracket]179[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]159", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]159\)\((0.1`\ \
Y\[UnderBracket]136[t] + 0.1`\ Y\[UnderBracket]137[t] + 
              0.1`\ Y\[UnderBracket]157[t] - 
              0.7999999999999999`\ Y\[UnderBracket]159[t] + 
              0.1`\ Y\[UnderBracket]170[t] + 0.1`\ Y\[UnderBracket]171[t] + 
              0.1`\ Y\[UnderBracket]181[t] + 
              0.1`\ Y\[UnderBracket]182[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]16", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]12[t] - 
                0.30000000000000004`\ Y\[UnderBracket]16[t] + 
                0.1`\ Y\[UnderBracket]30[t]\)\/cell\[UnderBracket]16\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]160", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]145[t] + 
                0.1`\ Y\[UnderBracket]156[t] - 0.6`\ Y\[UnderBracket]160[t] + 
                0.1`\ Y\[UnderBracket]161[t] + 0.1`\ Y\[UnderBracket]186[t] + 
                0.1`\ Y\[UnderBracket]188[t]\)\/cell\[UnderBracket]160\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]161", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]161\)\((0.1`\ \
Y\[UnderBracket]146[t] + 0.1`\ Y\[UnderBracket]151[t] + 
              0.1`\ Y\[UnderBracket]156[t] + 0.1`\ Y\[UnderBracket]160[t] - 
              0.7999999999999999`\ Y\[UnderBracket]161[t] + 
              0.1`\ Y\[UnderBracket]175[t] + 0.1`\ Y\[UnderBracket]186[t] + 
              0.1`\ Y\[UnderBracket]190[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]162", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]162\)\((0.1`\ \
Y\[UnderBracket]125[t] + 0.1`\ Y\[UnderBracket]154[t] + 
              0.1`\ Y\[UnderBracket]155[t] - 
              0.7999999999999999`\ Y\[UnderBracket]162[t] + 
              0.1`\ Y\[UnderBracket]166[t] + 0.1`\ Y\[UnderBracket]173[t] + 
              0.1`\ Y\[UnderBracket]183[t] + 
              0.1`\ Y\[UnderBracket]184[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]163", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]138[t] + 
                0.1`\ Y\[UnderBracket]149[t] - 0.6`\ Y\[UnderBracket]163[t] + 
                0.1`\ Y\[UnderBracket]165[t] + 0.1`\ Y\[UnderBracket]170[t] + 
                0.1`\ Y\[UnderBracket]180[t]\)\/cell\[UnderBracket]163\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]164", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]164\)\((0.1`\ \
Y\[UnderBracket]132[t] + 0.1`\ Y\[UnderBracket]141[t] + 
              0.1`\ Y\[UnderBracket]145[t] + 0.1`\ Y\[UnderBracket]153[t] - 
              0.7999999999999999`\ Y\[UnderBracket]164[t] + 
              0.1`\ Y\[UnderBracket]176[t] + 0.1`\ Y\[UnderBracket]188[t] + 
              0.1`\ Y\[UnderBracket]201[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]165", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]165\)\((0.1`\ \
Y\[UnderBracket]144[t] + 0.1`\ Y\[UnderBracket]149[t] + 
              0.1`\ Y\[UnderBracket]163[t] - 0.7`\ Y\[UnderBracket]165[t] + 
              0.1`\ Y\[UnderBracket]169[t] + 0.1`\ Y\[UnderBracket]177[t] + 
              0.1`\ Y\[UnderBracket]180[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]166", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]151[t] + 
                0.1`\ Y\[UnderBracket]154[t] + 0.1`\ Y\[UnderBracket]162[t] - 
                0.6`\ Y\[UnderBracket]166[t] + 0.1`\ Y\[UnderBracket]175[t] + 
                0.1`\ Y\[UnderBracket]183[t]\)\/cell\[UnderBracket]166\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]167", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]167\)\((0.1`\ \
Y\[UnderBracket]147[t] + 0.1`\ Y\[UnderBracket]155[t] + 
              0.1`\ Y\[UnderBracket]158[t] - 0.7`\ Y\[UnderBracket]167[t] + 
              0.1`\ Y\[UnderBracket]173[t] + 0.1`\ Y\[UnderBracket]174[t] + 
              0.1`\ Y\[UnderBracket]179[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]168", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]148[t] + 
                0.1`\ Y\[UnderBracket]158[t] - 0.5`\ Y\[UnderBracket]168[t] + 
                0.1`\ Y\[UnderBracket]169[t] + 
                0.1`\ Y\[UnderBracket]179[t]\)\/cell\[UnderBracket]168\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]169", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]169\)\((0.1`\ \
Y\[UnderBracket]144[t] + 0.1`\ Y\[UnderBracket]148[t] + 
              0.1`\ Y\[UnderBracket]165[t] + 0.1`\ Y\[UnderBracket]168[t] - 
              0.8999999999999999`\ Y\[UnderBracket]169[t] + 
              0.1`\ Y\[UnderBracket]177[t] + 0.1`\ Y\[UnderBracket]179[t] + 
              0.1`\ Y\[UnderBracket]192[t] + 
              0.1`\ Y\[UnderBracket]193[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]17", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]17\)\((0.1`\ \
Y\[UnderBracket]13[t] + 0.1`\ Y\[UnderBracket]14[t] - 
              0.7999999999999999`\ Y\[UnderBracket]17[t] + 
              0.1`\ Y\[UnderBracket]23[t] + 0.1`\ Y\[UnderBracket]39[t] + 
              0.1`\ Y\[UnderBracket]53[t] + 0.1`\ Y\[UnderBracket]54[t] + 
              0.1`\ Y\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]170", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]170\)\((0.1`\ \
Y\[UnderBracket]138[t] + 0.1`\ Y\[UnderBracket]157[t] + 
              0.1`\ Y\[UnderBracket]159[t] + 0.1`\ Y\[UnderBracket]163[t] - 
              0.7`\ Y\[UnderBracket]170[t] + 0.1`\ Y\[UnderBracket]180[t] + 
              0.1`\ Y\[UnderBracket]181[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]171", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]137[t] + 0.1`\ Y\[UnderBracket]150[t] + 
                0.1`\ Y\[UnderBracket]159[t] - 0.5`\ Y\[UnderBracket]171[t] + 
                0.1`\ Y\[UnderBracket]182[t]\)\/cell\[UnderBracket]171\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]172", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]152[t] + 
                0.1`\ Y\[UnderBracket]153[t] - 0.6`\ Y\[UnderBracket]172[t] + 
                0.1`\ Y\[UnderBracket]176[t] + 0.1`\ Y\[UnderBracket]178[t] + 
                0.1`\ Y\[UnderBracket]185[t]\)\/cell\[UnderBracket]172\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]173", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]173\)\((0.1`\ \
Y\[UnderBracket]155[t] + 0.1`\ Y\[UnderBracket]162[t] + 
              0.1`\ Y\[UnderBracket]167[t] - 0.7`\ Y\[UnderBracket]173[t] + 
              0.1`\ Y\[UnderBracket]174[t] + 0.1`\ Y\[UnderBracket]184[t] + 
              0.1`\ Y\[UnderBracket]189[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]174", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]167[t] + 
                0.1`\ Y\[UnderBracket]173[t] - 0.6`\ Y\[UnderBracket]174[t] + 
                0.1`\ Y\[UnderBracket]179[t] + 0.1`\ Y\[UnderBracket]187[t] + 
                0.1`\ Y\[UnderBracket]189[t]\)\/cell\[UnderBracket]174\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]175", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]175\)\((0.1`\ \
Y\[UnderBracket]151[t] + 0.1`\ Y\[UnderBracket]161[t] + 
              0.1`\ Y\[UnderBracket]166[t] - 0.7`\ Y\[UnderBracket]175[t] + 
              0.1`\ Y\[UnderBracket]183[t] + 0.1`\ Y\[UnderBracket]190[t] + 
              0.1`\ Y\[UnderBracket]199[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]176", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]176\)\((0.1`\ \
Y\[UnderBracket]153[t] + 0.1`\ Y\[UnderBracket]164[t] + 
              0.1`\ Y\[UnderBracket]172[t] - 0.7`\ Y\[UnderBracket]176[t] + 
              0.1`\ Y\[UnderBracket]185[t] + 0.1`\ Y\[UnderBracket]197[t] + 
              0.1`\ Y\[UnderBracket]201[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]177", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]165[t] + 
                0.1`\ Y\[UnderBracket]169[t] - 0.6`\ Y\[UnderBracket]177[t] + 
                0.1`\ Y\[UnderBracket]180[t] + 0.1`\ Y\[UnderBracket]193[t] + 
                0.1`\ Y\[UnderBracket]194[t]\)\/cell\[UnderBracket]177\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]178", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]152[t] + 0.1`\ Y\[UnderBracket]172[t] - 
                0.5`\ Y\[UnderBracket]178[t] + 0.1`\ Y\[UnderBracket]185[t] + 
                0.1`\ Y\[UnderBracket]203[t]\)\/cell\[UnderBracket]178\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]179", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]179\)\((0.1`\ \
Y\[UnderBracket]158[t] + 0.1`\ Y\[UnderBracket]167[t] + 
              0.1`\ Y\[UnderBracket]168[t] + 0.1`\ Y\[UnderBracket]169[t] + 
              0.1`\ Y\[UnderBracket]174[t] - 
              0.8999999999999999`\ Y\[UnderBracket]179[t] + 
              0.1`\ Y\[UnderBracket]187[t] + 0.1`\ Y\[UnderBracket]191[t] + 
              0.1`\ Y\[UnderBracket]192[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]18", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]10[t] - 
                0.6`\ Y\[UnderBracket]18[t] + 0.1`\ Y\[UnderBracket]27[t] + 
                0.1`\ Y\[UnderBracket]28[t] + 0.1`\ Y\[UnderBracket]31[t] + 
                0.1`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]18\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]180", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]180\)\((0.1`\ \
Y\[UnderBracket]163[t] + 0.1`\ Y\[UnderBracket]165[t] + 
              0.1`\ Y\[UnderBracket]170[t] + 0.1`\ Y\[UnderBracket]177[t] - 
              0.8999999999999999`\ Y\[UnderBracket]180[t] + 
              0.1`\ Y\[UnderBracket]181[t] + 0.1`\ Y\[UnderBracket]194[t] + 
              0.1`\ Y\[UnderBracket]196[t] + 
              0.1`\ Y\[UnderBracket]204[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]181", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]181\)\((0.1`\ \
Y\[UnderBracket]159[t] + 0.1`\ Y\[UnderBracket]170[t] + 
              0.1`\ Y\[UnderBracket]180[t] - 0.7`\ Y\[UnderBracket]181[t] + 
              0.1`\ Y\[UnderBracket]182[t] + 0.1`\ Y\[UnderBracket]196[t] + 
              0.1`\ Y\[UnderBracket]200[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]182", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]159[t] + 0.1`\ Y\[UnderBracket]171[t] + 
                0.1`\ Y\[UnderBracket]181[t] - 0.5`\ Y\[UnderBracket]182[t] + 
                0.1`\ Y\[UnderBracket]200[t]\)\/cell\[UnderBracket]182\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]183", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]183\)\((0.1`\ \
Y\[UnderBracket]162[t] + 0.1`\ Y\[UnderBracket]166[t] + 
              0.1`\ Y\[UnderBracket]175[t] - 0.7`\ Y\[UnderBracket]183[t] + 
              0.1`\ Y\[UnderBracket]184[t] + 0.1`\ Y\[UnderBracket]195[t] + 
              0.1`\ Y\[UnderBracket]199[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]184", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]184\)\((0.1`\ \
Y\[UnderBracket]162[t] + 0.1`\ Y\[UnderBracket]173[t] + 
              0.1`\ Y\[UnderBracket]183[t] - 0.7`\ Y\[UnderBracket]184[t] + 
              0.1`\ Y\[UnderBracket]189[t] + 0.1`\ Y\[UnderBracket]195[t] + 
              0.1`\ Y\[UnderBracket]202[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]185", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]185\)\((0.1`\ \
Y\[UnderBracket]172[t] + 0.1`\ Y\[UnderBracket]176[t] + 
              0.1`\ Y\[UnderBracket]178[t] - 0.7`\ Y\[UnderBracket]185[t] + 
              0.1`\ Y\[UnderBracket]197[t] + 0.1`\ Y\[UnderBracket]203[t] + 
              0.1`\ Y\[UnderBracket]208[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]186", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]160[t] + 
                0.1`\ Y\[UnderBracket]161[t] - 0.6`\ Y\[UnderBracket]186[t] + 
                0.1`\ Y\[UnderBracket]188[t] + 0.1`\ Y\[UnderBracket]190[t] + 
                0.1`\ Y\[UnderBracket]198[t]\)\/cell\[UnderBracket]186\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]187", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]174[t] + 
                0.1`\ Y\[UnderBracket]179[t] - 0.6`\ Y\[UnderBracket]187[t] + 
                0.1`\ Y\[UnderBracket]189[t] + 0.1`\ Y\[UnderBracket]191[t] + 
                0.1`\ Y\[UnderBracket]205[t]\)\/cell\[UnderBracket]187\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]188", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]188\)\((0.1`\ \
Y\[UnderBracket]145[t] + 0.1`\ Y\[UnderBracket]160[t] + 
              0.1`\ Y\[UnderBracket]164[t] + 0.1`\ Y\[UnderBracket]186[t] - 
              0.7999999999999999`\ Y\[UnderBracket]188[t] + 
              0.1`\ Y\[UnderBracket]198[t] + 0.1`\ Y\[UnderBracket]201[t] + 
              0.1`\ Y\[UnderBracket]218[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]189", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]189\)\((0.1`\ \
Y\[UnderBracket]173[t] + 0.1`\ Y\[UnderBracket]174[t] + 
              0.1`\ Y\[UnderBracket]184[t] + 0.1`\ Y\[UnderBracket]187[t] - 
              0.7`\ Y\[UnderBracket]189[t] + 0.1`\ Y\[UnderBracket]202[t] + 
              0.1`\ Y\[UnderBracket]205[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]19", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]19\)\((\(\(0.2`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ Y\[UnderBracket]10[t] - 
              0.7`\ Y\[UnderBracket]19[t] + 0.1`\ Y\[UnderBracket]20[t] + 
              0.1`\ Y\[UnderBracket]28[t] + 0.1`\ Y\[UnderBracket]32[t] + 
              0.1`\ Y\[UnderBracket]38[t] + 
              0.1`\ Y\[UnderBracket]40[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]190", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]190\)\((0.1`\ \
Y\[UnderBracket]161[t] + 0.1`\ Y\[UnderBracket]175[t] + 
              0.1`\ Y\[UnderBracket]186[t] - 
              0.7999999999999999`\ Y\[UnderBracket]190[t] + 
              0.1`\ Y\[UnderBracket]198[t] + 0.1`\ Y\[UnderBracket]199[t] + 
              0.1`\ Y\[UnderBracket]207[t] + 
              0.1`\ Y\[UnderBracket]215[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]191", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]191\)\((0.1`\ \
Y\[UnderBracket]179[t] + 0.1`\ Y\[UnderBracket]187[t] - 
              0.7`\ Y\[UnderBracket]191[t] + 0.1`\ Y\[UnderBracket]192[t] + 
              0.1`\ Y\[UnderBracket]205[t] + 0.1`\ Y\[UnderBracket]206[t] + 
              0.1`\ Y\[UnderBracket]216[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]192", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]169[t] + 
                0.1`\ Y\[UnderBracket]179[t] + 0.1`\ Y\[UnderBracket]191[t] - 
                0.6`\ Y\[UnderBracket]192[t] + 0.1`\ Y\[UnderBracket]193[t] + 
                0.1`\ Y\[UnderBracket]206[t]\)\/cell\[UnderBracket]192\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]193", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]169[t] + 
                0.1`\ Y\[UnderBracket]177[t] + 0.1`\ Y\[UnderBracket]192[t] - 
                0.6`\ Y\[UnderBracket]193[t] + 0.1`\ Y\[UnderBracket]194[t] + 
                0.1`\ Y\[UnderBracket]206[t]\)\/cell\[UnderBracket]193\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]194", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]177[t] + 
                0.1`\ Y\[UnderBracket]180[t] + 0.1`\ Y\[UnderBracket]193[t] - 
                0.6`\ Y\[UnderBracket]194[t] + 0.1`\ Y\[UnderBracket]204[t] + 
                0.1`\ Y\[UnderBracket]206[t]\)\/cell\[UnderBracket]194\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]195", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]195\)\((0.1`\ \
Y\[UnderBracket]183[t] + 0.1`\ Y\[UnderBracket]184[t] - 
              0.7`\ Y\[UnderBracket]195[t] + 0.1`\ Y\[UnderBracket]199[t] + 
              0.1`\ Y\[UnderBracket]202[t] + 0.1`\ Y\[UnderBracket]213[t] + 
              0.1`\ Y\[UnderBracket]222[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]196", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]196\)\((0.1`\ \
Y\[UnderBracket]180[t] + 0.1`\ Y\[UnderBracket]181[t] - 
              0.7`\ Y\[UnderBracket]196[t] + 0.1`\ Y\[UnderBracket]200[t] + 
              0.1`\ Y\[UnderBracket]204[t] + 0.1`\ Y\[UnderBracket]211[t] + 
              0.1`\ Y\[UnderBracket]214[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]197", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]176[t] + 
                0.1`\ Y\[UnderBracket]185[t] - 0.6`\ Y\[UnderBracket]197[t] + 
                0.1`\ Y\[UnderBracket]201[t] + 0.1`\ Y\[UnderBracket]208[t] + 
                0.1`\ Y\[UnderBracket]209[t]\)\/cell\[UnderBracket]197\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]198", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]186[t] + 
                0.1`\ Y\[UnderBracket]188[t] + 0.1`\ Y\[UnderBracket]190[t] - 
                0.6`\ Y\[UnderBracket]198[t] + 0.1`\ Y\[UnderBracket]215[t] + 
                0.1`\ Y\[UnderBracket]218[t]\)\/cell\[UnderBracket]198\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]199", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]199\)\((0.1`\ \
Y\[UnderBracket]175[t] + 0.1`\ Y\[UnderBracket]183[t] + 
              0.1`\ Y\[UnderBracket]190[t] + 0.1`\ Y\[UnderBracket]195[t] - 
              0.7999999999999999`\ Y\[UnderBracket]199[t] + 
              0.1`\ Y\[UnderBracket]207[t] + 0.1`\ Y\[UnderBracket]212[t] + 
              0.1`\ Y\[UnderBracket]222[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]2", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]1[t] - 0.5`\ Y\[UnderBracket]2[t] + 
                0.1`\ Y\[UnderBracket]4[t] + 0.1`\ Y\[UnderBracket]5[t] + 
                0.1`\ Y\[UnderBracket]8[t]\)\/cell\[UnderBracket]2\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]20", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]15[t] + 0.1`\ Y\[UnderBracket]19[t] - 
                0.5`\ Y\[UnderBracket]20[t] + 0.1`\ Y\[UnderBracket]34[t] + 
                0.1`\ Y\[UnderBracket]40[t]\)\/cell\[UnderBracket]20\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]200", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]181[t] + 0.1`\ Y\[UnderBracket]182[t] + 
                0.1`\ Y\[UnderBracket]196[t] - 0.5`\ Y\[UnderBracket]200[t] + 
                0.1`\ Y\[UnderBracket]211[t]\)\/cell\[UnderBracket]200\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]201", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]201\)\((0.1`\ \
Y\[UnderBracket]164[t] + 0.1`\ Y\[UnderBracket]176[t] + 
              0.1`\ Y\[UnderBracket]188[t] + 0.1`\ Y\[UnderBracket]197[t] - 
              0.7999999999999999`\ Y\[UnderBracket]201[t] + 
              0.1`\ Y\[UnderBracket]209[t] + 0.1`\ Y\[UnderBracket]218[t] + 
              0.1`\ Y\[UnderBracket]220[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]202", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]202\)\((0.1`\ \
Y\[UnderBracket]184[t] + 0.1`\ Y\[UnderBracket]189[t] + 
              0.1`\ Y\[UnderBracket]195[t] - 0.7`\ Y\[UnderBracket]202[t] + 
              0.1`\ Y\[UnderBracket]205[t] + 0.1`\ Y\[UnderBracket]210[t] + 
              0.1`\ Y\[UnderBracket]213[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]203", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]178[t] + 0.1`\ Y\[UnderBracket]185[t] - 
                0.5`\ Y\[UnderBracket]203[t] + 0.1`\ Y\[UnderBracket]208[t] + 
                0.1`\ Y\[UnderBracket]219[t]\)\/cell\[UnderBracket]203\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]204", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]204\)\((0.1`\ \
Y\[UnderBracket]180[t] + 0.1`\ Y\[UnderBracket]194[t] + 
              0.1`\ Y\[UnderBracket]196[t] - 0.7`\ Y\[UnderBracket]204[t] + 
              0.1`\ Y\[UnderBracket]206[t] + 0.1`\ Y\[UnderBracket]214[t] + 
              0.1`\ Y\[UnderBracket]217[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]205", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]205\)\((0.1`\ \
Y\[UnderBracket]187[t] + 0.1`\ Y\[UnderBracket]189[t] + 
              0.1`\ Y\[UnderBracket]191[t] + 0.1`\ Y\[UnderBracket]202[t] - 
              0.7999999999999999`\ Y\[UnderBracket]205[t] + 
              0.1`\ Y\[UnderBracket]210[t] + 0.1`\ Y\[UnderBracket]216[t] + 
              0.1`\ Y\[UnderBracket]225[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]206", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]206\)\((0.1`\ \
Y\[UnderBracket]191[t] + 0.1`\ Y\[UnderBracket]192[t] + 
              0.1`\ Y\[UnderBracket]193[t] + 0.1`\ Y\[UnderBracket]194[t] + 
              0.1`\ Y\[UnderBracket]204[t] - 
              0.8999999999999999`\ Y\[UnderBracket]206[t] + 
              0.1`\ Y\[UnderBracket]216[t] + 0.1`\ Y\[UnderBracket]217[t] + 
              0.1`\ Y\[UnderBracket]221[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]207", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]190[t] + 
                0.1`\ Y\[UnderBracket]199[t] - 0.5`\ Y\[UnderBracket]207[t] + 
                0.1`\ Y\[UnderBracket]212[t] + 
                0.1`\ Y\[UnderBracket]215[t]\)\/cell\[UnderBracket]207\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]208", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]208\)\((0.1`\ \
Y\[UnderBracket]185[t] + 0.1`\ Y\[UnderBracket]197[t] + 
              0.1`\ Y\[UnderBracket]203[t] - 0.7`\ Y\[UnderBracket]208[t] + 
              0.1`\ Y\[UnderBracket]209[t] + 0.1`\ Y\[UnderBracket]219[t] + 
              0.1`\ Y\[UnderBracket]226[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]209", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]209\)\((0.1`\ \
Y\[UnderBracket]197[t] + 0.1`\ Y\[UnderBracket]201[t] + 
              0.1`\ Y\[UnderBracket]208[t] - 0.7`\ Y\[UnderBracket]209[t] + 
              0.1`\ Y\[UnderBracket]220[t] + 0.1`\ Y\[UnderBracket]226[t] + 
              0.1`\ Y\[UnderBracket]227[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]21", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]15[t] - 0.5`\ Y\[UnderBracket]21[t] + 
                0.1`\ Y\[UnderBracket]29[t] + 0.1`\ Y\[UnderBracket]36[t] + 
                0.1`\ Y\[UnderBracket]47[t]\)\/cell\[UnderBracket]21\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]210", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]202[t] + 
                0.1`\ Y\[UnderBracket]205[t] - 0.6`\ Y\[UnderBracket]210[t] + 
                0.1`\ Y\[UnderBracket]213[t] + 0.1`\ Y\[UnderBracket]224[t] + 
                0.1`\ Y\[UnderBracket]225[t]\)\/cell\[UnderBracket]210\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]211", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]196[t] + 0.1`\ Y\[UnderBracket]200[t] - 
                0.4`\ Y\[UnderBracket]211[t] + 
                0.1`\ Y\[UnderBracket]214[t]\)\/cell\[UnderBracket]211\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]212", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]212\)\((0.1`\ \
Y\[UnderBracket]199[t] + 0.1`\ Y\[UnderBracket]207[t] - 
              0.7`\ Y\[UnderBracket]212[t] + 0.1`\ Y\[UnderBracket]215[t] + 
              0.1`\ Y\[UnderBracket]222[t] + 0.1`\ Y\[UnderBracket]223[t] + 
              0.1`\ Y\[UnderBracket]230[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]213", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]195[t] + 
                0.1`\ Y\[UnderBracket]202[t] + 0.1`\ Y\[UnderBracket]210[t] - 
                0.6`\ Y\[UnderBracket]213[t] + 0.1`\ Y\[UnderBracket]222[t] + 
                0.1`\ Y\[UnderBracket]224[t]\)\/cell\[UnderBracket]213\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]214", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]196[t] + 0.1`\ Y\[UnderBracket]204[t] + 
                0.1`\ Y\[UnderBracket]211[t] - 0.5`\ Y\[UnderBracket]214[t] + 
                0.1`\ Y\[UnderBracket]217[t]\)\/cell\[UnderBracket]214\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]215", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]215\)\((0.1`\ \
Y\[UnderBracket]190[t] + 0.1`\ Y\[UnderBracket]198[t] + 
              0.1`\ Y\[UnderBracket]207[t] + 0.1`\ Y\[UnderBracket]212[t] - 
              1.0999999999999999`\ Y\[UnderBracket]215[t] + 
              0.1`\ Y\[UnderBracket]218[t] + 0.1`\ Y\[UnderBracket]228[t] + 
              0.1`\ Y\[UnderBracket]230[t] + 0.1`\ Y\[UnderBracket]232[t] + 
              0.1`\ Y\[UnderBracket]233[t] + 
              0.1`\ Y\[UnderBracket]235[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]216", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]216\)\((\(\(0.2`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ Y\[UnderBracket]191[t] + 
              0.1`\ Y\[UnderBracket]205[t] + 0.1`\ Y\[UnderBracket]206[t] - 
              0.7`\ Y\[UnderBracket]216[t] + 0.1`\ Y\[UnderBracket]221[t] + 
              0.1`\ Y\[UnderBracket]225[t] + 
              0.1`\ Y\[UnderBracket]234[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]217", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]204[t] + 0.1`\ Y\[UnderBracket]206[t] + 
                0.1`\ Y\[UnderBracket]214[t] - 0.5`\ Y\[UnderBracket]217[t] + 
                0.1`\ Y\[UnderBracket]221[t]\)\/cell\[UnderBracket]217\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]218", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]218\)\((0.1`\ \
Y\[UnderBracket]188[t] + 0.1`\ Y\[UnderBracket]198[t] + 
              0.1`\ Y\[UnderBracket]201[t] + 0.1`\ Y\[UnderBracket]215[t] - 
              0.7999999999999999`\ Y\[UnderBracket]218[t] + 
              0.1`\ Y\[UnderBracket]220[t] + 0.1`\ Y\[UnderBracket]228[t] + 
              0.1`\ Y\[UnderBracket]229[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]219", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]203[t] + 0.1`\ Y\[UnderBracket]208[t] - 
                0.5`\ Y\[UnderBracket]219[t] + 0.1`\ Y\[UnderBracket]226[t] + 
                0.1`\ Y\[UnderBracket]237[t]\)\/cell\[UnderBracket]219\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]22", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] + 
                0.1`\ Y\[UnderBracket]12[t] - 0.7`\ Y\[UnderBracket]22[t] + 
                0.1`\ Y\[UnderBracket]24[t] + 0.1`\ Y\[UnderBracket]37[t] + 
                0.1`\ Y\[UnderBracket]43[t] + 
                0.1`\ Y\[UnderBracket]6[t]\)\/cell\[UnderBracket]22\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]220", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]201[t] + 
                0.1`\ Y\[UnderBracket]209[t] + 0.1`\ Y\[UnderBracket]218[t] - 
                0.6`\ Y\[UnderBracket]220[t] + 0.1`\ Y\[UnderBracket]227[t] + 
                0.1`\ Y\[UnderBracket]229[t]\)\/cell\[UnderBracket]220\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]221", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]206[t] + 0.1`\ Y\[UnderBracket]216[t] + 
                0.1`\ Y\[UnderBracket]217[t] - 
                0.4`\ Y\[UnderBracket]221[t]\)\/cell\[UnderBracket]221\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]222", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]222\)\((0.1`\ \
Y\[UnderBracket]195[t] + 0.1`\ Y\[UnderBracket]199[t] + 
              0.1`\ Y\[UnderBracket]212[t] + 0.1`\ Y\[UnderBracket]213[t] - 
              0.7999999999999999`\ Y\[UnderBracket]222[t] + 
              0.1`\ Y\[UnderBracket]223[t] + 0.1`\ Y\[UnderBracket]224[t] + 
              0.1`\ Y\[UnderBracket]231[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]223", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]223\)\((0.1`\ \
Y\[UnderBracket]212[t] + 0.1`\ Y\[UnderBracket]222[t] - 
              0.7`\ Y\[UnderBracket]223[t] + 0.1`\ Y\[UnderBracket]230[t] + 
              0.1`\ Y\[UnderBracket]231[t] + 0.1`\ Y\[UnderBracket]236[t] + 
              0.1`\ Y\[UnderBracket]238[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]224", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]210[t] + 
                0.1`\ Y\[UnderBracket]213[t] + 0.1`\ Y\[UnderBracket]222[t] - 
                0.6`\ Y\[UnderBracket]224[t] + 0.1`\ Y\[UnderBracket]225[t] + 
                0.1`\ Y\[UnderBracket]231[t]\)\/cell\[UnderBracket]224\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]225", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]225\)\((0.1`\ \
Y\[UnderBracket]205[t] + 0.1`\ Y\[UnderBracket]210[t] + 
              0.1`\ Y\[UnderBracket]216[t] + 0.1`\ Y\[UnderBracket]224[t] - 
              0.7`\ Y\[UnderBracket]225[t] + 0.1`\ Y\[UnderBracket]231[t] + 
              0.1`\ Y\[UnderBracket]234[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]226", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]226\)\((0.1`\ \
Y\[UnderBracket]208[t] + 0.1`\ Y\[UnderBracket]209[t] + 
              0.1`\ Y\[UnderBracket]219[t] - 0.7`\ Y\[UnderBracket]226[t] + 
              0.1`\ Y\[UnderBracket]227[t] + 0.1`\ Y\[UnderBracket]237[t] + 
              0.1`\ Y\[UnderBracket]239[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]227", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]209[t] + 
                0.1`\ Y\[UnderBracket]220[t] + 0.1`\ Y\[UnderBracket]226[t] - 
                0.6`\ Y\[UnderBracket]227[t] + 0.1`\ Y\[UnderBracket]229[t] + 
                0.1`\ Y\[UnderBracket]239[t]\)\/cell\[UnderBracket]227\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]228", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]215[t] + 
                0.1`\ Y\[UnderBracket]218[t] - 0.6`\ Y\[UnderBracket]228[t] + 
                0.1`\ Y\[UnderBracket]229[t] + 0.1`\ Y\[UnderBracket]235[t] + 
                0.1`\ Y\[UnderBracket]240[t]\)\/cell\[UnderBracket]228\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]229", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]229\)\((0.1`\ \
Y\[UnderBracket]218[t] + 0.1`\ Y\[UnderBracket]220[t] + 
              0.1`\ Y\[UnderBracket]227[t] + 0.1`\ Y\[UnderBracket]228[t] - 
              0.7999999999999999`\ Y\[UnderBracket]229[t] + 
              0.1`\ Y\[UnderBracket]239[t] + 0.1`\ Y\[UnderBracket]240[t] + 
              0.1`\ Y\[UnderBracket]242[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]23", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]14[t] + 
                0.1`\ Y\[UnderBracket]17[t] - 0.6`\ Y\[UnderBracket]23[t] + 
                0.1`\ Y\[UnderBracket]33[t] + 0.1`\ Y\[UnderBracket]45[t] + 
                0.1`\ Y\[UnderBracket]54[t]\)\/cell\[UnderBracket]23\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]230", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]230\)\((0.1`\ \
Y\[UnderBracket]212[t] + 0.1`\ Y\[UnderBracket]215[t] + 
              0.1`\ Y\[UnderBracket]223[t] - 0.7`\ Y\[UnderBracket]230[t] + 
              0.1`\ Y\[UnderBracket]232[t] + 0.1`\ Y\[UnderBracket]236[t] + 
              0.1`\ Y\[UnderBracket]245[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]231", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]231\)\((0.1`\ \
Y\[UnderBracket]222[t] + 0.1`\ Y\[UnderBracket]223[t] + 
              0.1`\ Y\[UnderBracket]224[t] + 0.1`\ Y\[UnderBracket]225[t] - 
              0.7999999999999999`\ Y\[UnderBracket]231[t] + 
              0.1`\ Y\[UnderBracket]234[t] + 0.1`\ Y\[UnderBracket]238[t] + 
              0.1`\ Y\[UnderBracket]244[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]232", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]215[t] + 
                0.1`\ Y\[UnderBracket]230[t] - 0.5`\ Y\[UnderBracket]232[t] + 
                0.1`\ Y\[UnderBracket]233[t] + 
                0.1`\ Y\[UnderBracket]245[t]\)\/cell\[UnderBracket]232\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]233", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]215[t] + 
                0.1`\ Y\[UnderBracket]232[t] - 0.6`\ Y\[UnderBracket]233[t] + 
                0.1`\ Y\[UnderBracket]235[t] + 0.1`\ Y\[UnderBracket]241[t] + 
                0.1`\ Y\[UnderBracket]245[t]\)\/cell\[UnderBracket]233\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]234", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]216[t] + 0.1`\ Y\[UnderBracket]225[t] + 
                0.1`\ Y\[UnderBracket]231[t] - 0.5`\ Y\[UnderBracket]234[t] + 
                0.1`\ Y\[UnderBracket]244[t]\)\/cell\[UnderBracket]234\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]235", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]235\)\((0.1`\ \
Y\[UnderBracket]215[t] + 0.1`\ Y\[UnderBracket]228[t] + 
              0.1`\ Y\[UnderBracket]233[t] - 0.7`\ Y\[UnderBracket]235[t] + 
              0.1`\ Y\[UnderBracket]240[t] + 0.1`\ Y\[UnderBracket]241[t] + 
              0.1`\ Y\[UnderBracket]243[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]236", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]223[t] + 
                0.1`\ Y\[UnderBracket]230[t] - 0.6`\ Y\[UnderBracket]236[t] + 
                0.1`\ Y\[UnderBracket]238[t] + 0.1`\ Y\[UnderBracket]245[t] + 
                0.1`\ Y\[UnderBracket]248[t]\)\/cell\[UnderBracket]236\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]237", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]219[t] + 0.1`\ Y\[UnderBracket]226[t] - 
                0.5`\ Y\[UnderBracket]237[t] + 0.1`\ Y\[UnderBracket]239[t] + 
                0.1`\ Y\[UnderBracket]249[t]\)\/cell\[UnderBracket]237\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]238", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]238\)\((0.1`\ \
Y\[UnderBracket]223[t] + 0.1`\ Y\[UnderBracket]231[t] + 
              0.1`\ Y\[UnderBracket]236[t] - 0.7`\ Y\[UnderBracket]238[t] + 
              0.1`\ Y\[UnderBracket]244[t] + 0.1`\ Y\[UnderBracket]246[t] + 
              0.1`\ Y\[UnderBracket]248[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]239", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]239\)\((0.1`\ \
Y\[UnderBracket]226[t] + 0.1`\ Y\[UnderBracket]227[t] + 
              0.1`\ Y\[UnderBracket]229[t] + 0.1`\ Y\[UnderBracket]237[t] - 
              0.7999999999999999`\ Y\[UnderBracket]239[t] + 
              0.1`\ Y\[UnderBracket]242[t] + 0.1`\ Y\[UnderBracket]249[t] + 
              0.1`\ Y\[UnderBracket]250[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]24", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] + 
                0.1`\ Y\[UnderBracket]22[t] - 0.5`\ Y\[UnderBracket]24[t] + 
                0.1`\ Y\[UnderBracket]25[t] + 
                0.1`\ Y\[UnderBracket]37[t]\)\/cell\[UnderBracket]24\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]240", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]240\)\((0.1`\ \
Y\[UnderBracket]228[t] + 0.1`\ Y\[UnderBracket]229[t] + 
              0.1`\ Y\[UnderBracket]235[t] - 0.7`\ Y\[UnderBracket]240[t] + 
              0.1`\ Y\[UnderBracket]242[t] + 0.1`\ Y\[UnderBracket]243[t] + 
              0.1`\ Y\[UnderBracket]247[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]241", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]241\)\((0.1`\ \
Y\[UnderBracket]233[t] + 0.1`\ Y\[UnderBracket]235[t] - 
              0.7999999999999999`\ Y\[UnderBracket]241[t] + 
              0.1`\ Y\[UnderBracket]243[t] + 0.1`\ Y\[UnderBracket]245[t] + 
              0.1`\ Y\[UnderBracket]247[t] + 0.1`\ Y\[UnderBracket]251[t] + 
              0.1`\ Y\[UnderBracket]253[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]242", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]242\)\((0.1`\ \
Y\[UnderBracket]229[t] + 0.1`\ Y\[UnderBracket]239[t] + 
              0.1`\ Y\[UnderBracket]240[t] - 0.7`\ Y\[UnderBracket]242[t] + 
              0.1`\ Y\[UnderBracket]247[t] + 0.1`\ Y\[UnderBracket]250[t] + 
              0.1`\ Y\[UnderBracket]252[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]243", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]235[t] + 
                0.1`\ Y\[UnderBracket]240[t] + 0.1`\ Y\[UnderBracket]241[t] - 
                0.5`\ Y\[UnderBracket]243[t] + 
                0.1`\ Y\[UnderBracket]247[t]\)\/cell\[UnderBracket]243\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]244", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]231[t] + 0.1`\ Y\[UnderBracket]234[t] + 
                0.1`\ Y\[UnderBracket]238[t] - 0.5`\ Y\[UnderBracket]244[t] + 
                0.1`\ Y\[UnderBracket]246[t]\)\/cell\[UnderBracket]244\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]245", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]245\)\((\(\(0.2`\)\(\
\[InvisibleSpace]\)\) + 0.1`\ Y\[UnderBracket]230[t] + 
              0.1`\ Y\[UnderBracket]232[t] + 0.1`\ Y\[UnderBracket]233[t] + 
              0.1`\ Y\[UnderBracket]236[t] + 0.1`\ Y\[UnderBracket]241[t] - 
              0.7999999999999999`\ Y\[UnderBracket]245[t] + 
              0.1`\ Y\[UnderBracket]248[t] + 
              0.1`\ Y\[UnderBracket]251[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]246", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]238[t] + 0.1`\ Y\[UnderBracket]244[t] - 
                0.4`\ Y\[UnderBracket]246[t] + 
                0.1`\ Y\[UnderBracket]248[t]\)\/cell\[UnderBracket]246\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]247", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]247\)\((0.1`\ \
Y\[UnderBracket]240[t] + 0.1`\ Y\[UnderBracket]241[t] + 
              0.1`\ Y\[UnderBracket]242[t] + 0.1`\ Y\[UnderBracket]243[t] - 
              0.7`\ Y\[UnderBracket]247[t] + 0.1`\ Y\[UnderBracket]252[t] + 
              0.1`\ Y\[UnderBracket]253[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]248", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]236[t] + 0.1`\ Y\[UnderBracket]238[t] + 
                0.1`\ Y\[UnderBracket]245[t] + 0.1`\ Y\[UnderBracket]246[t] - 
                0.5`\ Y\[UnderBracket]248[t]\)\/cell\[UnderBracket]248\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]249", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]237[t] + 0.1`\ Y\[UnderBracket]239[t] - 
                0.4`\ Y\[UnderBracket]249[t] + 
                0.1`\ Y\[UnderBracket]250[t]\)\/cell\[UnderBracket]249\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]25", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] + 
                0.1`\ Y\[UnderBracket]24[t] - 0.6`\ Y\[UnderBracket]25[t] + 
                0.1`\ Y\[UnderBracket]26[t] + 0.1`\ Y\[UnderBracket]37[t] + 
                0.1`\ Y\[UnderBracket]39[t]\)\/cell\[UnderBracket]25\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]250", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]239[t] + 0.1`\ Y\[UnderBracket]242[t] + 
                0.1`\ Y\[UnderBracket]249[t] - 0.5`\ Y\[UnderBracket]250[t] + 
                0.1`\ Y\[UnderBracket]252[t]\)\/cell\[UnderBracket]250\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]251", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]241[t] + 0.1`\ Y\[UnderBracket]245[t] - 
                0.4`\ Y\[UnderBracket]251[t] + 
                0.1`\ Y\[UnderBracket]253[t]\)\/cell\[UnderBracket]251\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]252", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]242[t] + 0.1`\ Y\[UnderBracket]247[t] + 
                0.1`\ Y\[UnderBracket]250[t] - 0.5`\ Y\[UnderBracket]252[t] + 
                0.1`\ Y\[UnderBracket]253[t]\)\/cell\[UnderBracket]252\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]253", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]241[t] + 0.1`\ Y\[UnderBracket]247[t] + 
                0.1`\ Y\[UnderBracket]251[t] + 0.1`\ Y\[UnderBracket]252[t] - 
                0.5`\ Y\[UnderBracket]253[t]\)\/cell\[UnderBracket]253\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]26", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] + 
                0.1`\ Y\[UnderBracket]13[t] + 0.1`\ Y\[UnderBracket]25[t] - 
                0.5`\ Y\[UnderBracket]26[t] + 
                0.1`\ Y\[UnderBracket]39[t]\)\/cell\[UnderBracket]26\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]27", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]14[t] + 
                0.1`\ Y\[UnderBracket]18[t] - 0.6`\ Y\[UnderBracket]27[t] + 
                0.1`\ Y\[UnderBracket]31[t] + 0.1`\ Y\[UnderBracket]33[t] + 
                0.1`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]27\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]28", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]10[t] + 
                0.1`\ Y\[UnderBracket]18[t] + 0.1`\ Y\[UnderBracket]19[t] - 
                0.7`\ Y\[UnderBracket]28[t] + 0.1`\ Y\[UnderBracket]31[t] + 
                0.1`\ Y\[UnderBracket]32[t] + 
                0.1`\ Y\[UnderBracket]44[t]\)\/cell\[UnderBracket]28\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]29", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]15[t] + 
                0.1`\ Y\[UnderBracket]21[t] - 0.7`\ Y\[UnderBracket]29[t] + 
                0.1`\ Y\[UnderBracket]35[t] + 0.1`\ Y\[UnderBracket]47[t] + 
                0.1`\ Y\[UnderBracket]49[t] + 
                0.1`\ Y\[UnderBracket]57[t]\)\/cell\[UnderBracket]29\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]3", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]1[t] - 0.5`\ Y\[UnderBracket]3[t] + 
                0.1`\ Y\[UnderBracket]6[t] + 0.1`\ Y\[UnderBracket]7[t] + 
                0.1`\ Y\[UnderBracket]8[t]\)\/cell\[UnderBracket]3\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]30", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]12[t] + 0.1`\ Y\[UnderBracket]16[t] - 
                0.5`\ Y\[UnderBracket]30[t] + 0.1`\ Y\[UnderBracket]43[t] + 
                0.1`\ Y\[UnderBracket]50[t]\)\/cell\[UnderBracket]30\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]31", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]18[t] + 
                0.1`\ Y\[UnderBracket]27[t] + 0.1`\ Y\[UnderBracket]28[t] - 
                0.7`\ Y\[UnderBracket]31[t] + 0.1`\ Y\[UnderBracket]33[t] + 
                0.1`\ Y\[UnderBracket]44[t] + 
                0.1`\ Y\[UnderBracket]46[t]\)\/cell\[UnderBracket]31\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]32", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]19[t] + 
                0.1`\ Y\[UnderBracket]28[t] - 0.5`\ Y\[UnderBracket]32[t] + 
                0.1`\ Y\[UnderBracket]38[t] + 
                0.1`\ Y\[UnderBracket]44[t]\)\/cell\[UnderBracket]32\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]33", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]14[t] + 
                0.1`\ Y\[UnderBracket]23[t] + 0.1`\ Y\[UnderBracket]27[t] + 
                0.1`\ Y\[UnderBracket]31[t] - 0.7`\ Y\[UnderBracket]33[t] + 
                0.1`\ Y\[UnderBracket]45[t] + 
                0.1`\ Y\[UnderBracket]46[t]\)\/cell\[UnderBracket]33\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]34", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]34\)\((0.1`\ \
Y\[UnderBracket]15[t] + 0.1`\ Y\[UnderBracket]20[t] - 
              0.7999999999999999`\ Y\[UnderBracket]34[t] + 
              0.1`\ Y\[UnderBracket]35[t] + 0.1`\ Y\[UnderBracket]40[t] + 
              0.1`\ Y\[UnderBracket]41[t] + 0.1`\ Y\[UnderBracket]51[t] + 
              0.1`\ Y\[UnderBracket]52[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]35", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]15[t] + 
                0.1`\ Y\[UnderBracket]29[t] + 0.1`\ Y\[UnderBracket]34[t] - 
                0.7`\ Y\[UnderBracket]35[t] + 0.1`\ Y\[UnderBracket]41[t] + 
                0.1`\ Y\[UnderBracket]57[t] + 
                0.1`\ Y\[UnderBracket]60[t]\)\/cell\[UnderBracket]35\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]36", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]21[t] - 0.5`\ Y\[UnderBracket]36[t] + 
                0.1`\ Y\[UnderBracket]42[t] + 0.1`\ Y\[UnderBracket]47[t] + 
                0.1`\ Y\[UnderBracket]48[t]\)\/cell\[UnderBracket]36\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]37", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]22[t] + 
                0.1`\ Y\[UnderBracket]24[t] + 0.1`\ Y\[UnderBracket]25[t] - 
                0.7`\ Y\[UnderBracket]37[t] + 0.1`\ Y\[UnderBracket]39[t] + 
                0.1`\ Y\[UnderBracket]43[t] + 
                0.1`\ Y\[UnderBracket]59[t]\)\/cell\[UnderBracket]37\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]38", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]19[t] + 
                0.1`\ Y\[UnderBracket]32[t] - 0.7`\ Y\[UnderBracket]38[t] + 
                0.1`\ Y\[UnderBracket]40[t] + 0.1`\ Y\[UnderBracket]44[t] + 
                0.1`\ Y\[UnderBracket]56[t] + 
                0.1`\ Y\[UnderBracket]67[t]\)\/cell\[UnderBracket]38\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]39", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]39\)\((0.1`\ \
Y\[UnderBracket]13[t] + 0.1`\ Y\[UnderBracket]17[t] + 
              0.1`\ Y\[UnderBracket]25[t] + 0.1`\ Y\[UnderBracket]26[t] + 
              0.1`\ Y\[UnderBracket]37[t] - 
              0.8999999999999999`\ Y\[UnderBracket]39[t] + 
              0.1`\ Y\[UnderBracket]53[t] + 0.1`\ Y\[UnderBracket]59[t] + 
              0.1`\ Y\[UnderBracket]65[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]4", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]10[t] + 0.1`\ Y\[UnderBracket]2[t] - 
                0.5`\ Y\[UnderBracket]4[t] + 0.1`\ Y\[UnderBracket]5[t] + 
                0.1`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]4\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]40", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]19[t] + 
                0.1`\ Y\[UnderBracket]20[t] + 0.1`\ Y\[UnderBracket]34[t] + 
                0.1`\ Y\[UnderBracket]38[t] - 0.7`\ Y\[UnderBracket]40[t] + 
                0.1`\ Y\[UnderBracket]51[t] + 
                0.1`\ Y\[UnderBracket]56[t]\)\/cell\[UnderBracket]40\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]41", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]34[t] + 
                0.1`\ Y\[UnderBracket]35[t] - 0.5`\ Y\[UnderBracket]41[t] + 
                0.1`\ Y\[UnderBracket]52[t] + 
                0.1`\ Y\[UnderBracket]60[t]\)\/cell\[UnderBracket]41\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]42", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]36[t] - 0.4`\ Y\[UnderBracket]42[t] + 
                0.1`\ Y\[UnderBracket]48[t] + 
                0.1`\ Y\[UnderBracket]58[t]\)\/cell\[UnderBracket]42\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]43", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]43\)\((0.1`\ \
Y\[UnderBracket]22[t] + 0.1`\ Y\[UnderBracket]30[t] + 
              0.1`\ Y\[UnderBracket]37[t] - 
              0.7999999999999999`\ Y\[UnderBracket]43[t] + 
              0.1`\ Y\[UnderBracket]50[t] + 0.1`\ Y\[UnderBracket]59[t] + 
              0.1`\ Y\[UnderBracket]61[t] + 
              0.1`\ Y\[UnderBracket]64[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]44", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]44\)\((0.1`\ \
Y\[UnderBracket]28[t] + 0.1`\ Y\[UnderBracket]31[t] + 
              0.1`\ Y\[UnderBracket]32[t] + 0.1`\ Y\[UnderBracket]38[t] - 
              0.8999999999999999`\ Y\[UnderBracket]44[t] + 
              0.1`\ Y\[UnderBracket]46[t] + 0.1`\ Y\[UnderBracket]55[t] + 
              0.1`\ Y\[UnderBracket]66[t] + 
              0.1`\ Y\[UnderBracket]67[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]45", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]23[t] + 
                0.1`\ Y\[UnderBracket]33[t] - 0.6`\ Y\[UnderBracket]45[t] + 
                0.1`\ Y\[UnderBracket]46[t] + 0.1`\ Y\[UnderBracket]54[t] + 
                0.1`\ Y\[UnderBracket]75[t]\)\/cell\[UnderBracket]45\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]46", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]46\)\((0.1`\ \
Y\[UnderBracket]31[t] + 0.1`\ Y\[UnderBracket]33[t] + 
              0.1`\ Y\[UnderBracket]44[t] + 0.1`\ Y\[UnderBracket]45[t] - 
              0.7999999999999999`\ Y\[UnderBracket]46[t] + 
              0.1`\ Y\[UnderBracket]55[t] + 0.1`\ Y\[UnderBracket]68[t] + 
              0.1`\ Y\[UnderBracket]69[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]47", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]21[t] + 
                0.1`\ Y\[UnderBracket]29[t] + 0.1`\ Y\[UnderBracket]36[t] - 
                0.7`\ Y\[UnderBracket]47[t] + 0.1`\ Y\[UnderBracket]48[t] + 
                0.1`\ Y\[UnderBracket]49[t] + 
                0.1`\ Y\[UnderBracket]63[t]\)\/cell\[UnderBracket]47\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]48", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]48\)\((0.1`\ \
Y\[UnderBracket]36[t] + 0.1`\ Y\[UnderBracket]42[t] + 
              0.1`\ Y\[UnderBracket]47[t] - 
              0.7999999999999999`\ Y\[UnderBracket]48[t] + 
              0.1`\ Y\[UnderBracket]58[t] + 0.1`\ Y\[UnderBracket]63[t] + 
              0.1`\ Y\[UnderBracket]73[t] + 
              0.1`\ Y\[UnderBracket]77[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]49", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]29[t] + 
                0.1`\ Y\[UnderBracket]47[t] - 0.6`\ Y\[UnderBracket]49[t] + 
                0.1`\ Y\[UnderBracket]57[t] + 0.1`\ Y\[UnderBracket]63[t] + 
                0.1`\ Y\[UnderBracket]76[t]\)\/cell\[UnderBracket]49\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]5", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]14[t] + 
                0.1`\ Y\[UnderBracket]2[t] + 0.1`\ Y\[UnderBracket]4[t] - 
                0.6`\ Y\[UnderBracket]5[t] + 0.1`\ Y\[UnderBracket]8[t] + 
                0.1`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]5\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]50", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]30[t] + 0.1`\ Y\[UnderBracket]43[t] - 
                0.5`\ Y\[UnderBracket]50[t] + 0.1`\ Y\[UnderBracket]61[t] + 
                0.1`\ Y\[UnderBracket]82[t]\)\/cell\[UnderBracket]50\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]51", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]51\)\((0.1`\ \
Y\[UnderBracket]34[t] + 0.1`\ Y\[UnderBracket]40[t] - 
              0.7999999999999999`\ Y\[UnderBracket]51[t] + 
              0.1`\ Y\[UnderBracket]52[t] + 0.1`\ Y\[UnderBracket]56[t] + 
              0.1`\ Y\[UnderBracket]71[t] + 0.1`\ Y\[UnderBracket]72[t] + 
              0.1`\ Y\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]52", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]34[t] + 
                0.1`\ Y\[UnderBracket]41[t] + 0.1`\ Y\[UnderBracket]51[t] - 
                0.6`\ Y\[UnderBracket]52[t] + 0.1`\ Y\[UnderBracket]60[t] + 
                0.1`\ Y\[UnderBracket]72[t]\)\/cell\[UnderBracket]52\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]53", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]17[t] + 
                0.1`\ Y\[UnderBracket]39[t] - 0.7`\ Y\[UnderBracket]53[t] + 
                0.1`\ Y\[UnderBracket]54[t] + 0.1`\ Y\[UnderBracket]65[t] + 
                0.1`\ Y\[UnderBracket]70[t] + 
                0.1`\ Y\[UnderBracket]74[t]\)\/cell\[UnderBracket]53\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]54", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]17[t] + 
                0.1`\ Y\[UnderBracket]23[t] + 0.1`\ Y\[UnderBracket]45[t] + 
                0.1`\ Y\[UnderBracket]53[t] - 0.7`\ Y\[UnderBracket]54[t] + 
                0.1`\ Y\[UnderBracket]74[t] + 
                0.1`\ Y\[UnderBracket]75[t]\)\/cell\[UnderBracket]54\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]55", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]44[t] + 
                0.1`\ Y\[UnderBracket]46[t] - 0.6`\ Y\[UnderBracket]55[t] + 
                0.1`\ Y\[UnderBracket]66[t] + 0.1`\ Y\[UnderBracket]69[t] + 
                0.1`\ Y\[UnderBracket]86[t]\)\/cell\[UnderBracket]55\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]56", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]38[t] + 
                0.1`\ Y\[UnderBracket]40[t] + 0.1`\ Y\[UnderBracket]51[t] - 
                0.7`\ Y\[UnderBracket]56[t] + 0.1`\ Y\[UnderBracket]62[t] + 
                0.1`\ Y\[UnderBracket]67[t] + 
                0.1`\ Y\[UnderBracket]71[t]\)\/cell\[UnderBracket]56\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]57", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          
          "\[Equal]", \(\(1\/cell\[UnderBracket]57\)\((0.1`\ \
Y\[UnderBracket]29[t] + 0.1`\ Y\[UnderBracket]35[t] + 
              0.1`\ Y\[UnderBracket]49[t] - 
              0.7999999999999999`\ Y\[UnderBracket]57[t] + 
              0.1`\ Y\[UnderBracket]60[t] + 0.1`\ Y\[UnderBracket]76[t] + 
              0.1`\ Y\[UnderBracket]81[t] + 
              0.1`\ Y\[UnderBracket]85[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]58", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]42[t] + 0.1`\ Y\[UnderBracket]48[t] - 
                0.5`\ Y\[UnderBracket]58[t] + 0.1`\ Y\[UnderBracket]77[t] + 
                0.1`\ Y\[UnderBracket]78[t]\)\/cell\[UnderBracket]58\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]59", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]59\)\((0.1`\ \
Y\[UnderBracket]37[t] + 0.1`\ Y\[UnderBracket]39[t] + 
              0.1`\ Y\[UnderBracket]43[t] - 
              0.7999999999999999`\ Y\[UnderBracket]59[t] + 
              0.1`\ Y\[UnderBracket]64[t] + 0.1`\ Y\[UnderBracket]65[t] + 
              0.1`\ Y\[UnderBracket]83[t] + 
              0.1`\ Y\[UnderBracket]87[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]6", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]11[t] + 0.1`\ Y\[UnderBracket]12[t] + 
                0.1`\ Y\[UnderBracket]22[t] + 0.1`\ Y\[UnderBracket]3[t] - 
                0.6`\ Y\[UnderBracket]6[t] + 
                0.1`\ Y\[UnderBracket]7[t]\)\/cell\[UnderBracket]6\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]60", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]60\)\((0.1`\ \
Y\[UnderBracket]35[t] + 0.1`\ Y\[UnderBracket]41[t] + 
              0.1`\ Y\[UnderBracket]52[t] + 0.1`\ Y\[UnderBracket]57[t] - 
              0.7999999999999999`\ Y\[UnderBracket]60[t] + 
              0.1`\ Y\[UnderBracket]72[t] + 0.1`\ Y\[UnderBracket]80[t] + 
              0.1`\ Y\[UnderBracket]85[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]61", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]43[t] + 
                0.1`\ Y\[UnderBracket]50[t] - 0.7`\ Y\[UnderBracket]61[t] + 
                0.1`\ Y\[UnderBracket]64[t] + 0.1`\ Y\[UnderBracket]82[t] + 
                0.1`\ Y\[UnderBracket]89[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]61\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]62", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]56[t] - 
                0.5`\ Y\[UnderBracket]62[t] + 0.1`\ Y\[UnderBracket]67[t] + 
                0.1`\ Y\[UnderBracket]71[t] + 
                0.1`\ Y\[UnderBracket]79[t]\)\/cell\[UnderBracket]62\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]63", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]47[t] + 
                0.1`\ Y\[UnderBracket]48[t] + 0.1`\ Y\[UnderBracket]49[t] - 
                0.6`\ Y\[UnderBracket]63[t] + 0.1`\ Y\[UnderBracket]73[t] + 
                0.1`\ Y\[UnderBracket]76[t]\)\/cell\[UnderBracket]63\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]64", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]43[t] + 
                0.1`\ Y\[UnderBracket]59[t] + 0.1`\ Y\[UnderBracket]61[t] - 
                0.6`\ Y\[UnderBracket]64[t] + 0.1`\ Y\[UnderBracket]83[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]64\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]65", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]65\)\((0.1`\ \
Y\[UnderBracket]100[t] + 0.1`\ Y\[UnderBracket]39[t] + 
              0.1`\ Y\[UnderBracket]53[t] + 0.1`\ Y\[UnderBracket]59[t] - 
              0.7999999999999999`\ Y\[UnderBracket]65[t] + 
              0.1`\ Y\[UnderBracket]70[t] + 0.1`\ Y\[UnderBracket]87[t] + 
              0.1`\ Y\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]66", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]44[t] + 
                0.1`\ Y\[UnderBracket]55[t] - 0.7`\ Y\[UnderBracket]66[t] + 
                0.1`\ Y\[UnderBracket]67[t] + 0.1`\ Y\[UnderBracket]79[t] + 
                0.1`\ Y\[UnderBracket]86[t] + 
                0.1`\ Y\[UnderBracket]91[t]\)\/cell\[UnderBracket]66\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]67", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]38[t] + 
                0.1`\ Y\[UnderBracket]44[t] + 0.1`\ Y\[UnderBracket]56[t] + 
                0.1`\ Y\[UnderBracket]62[t] + 0.1`\ Y\[UnderBracket]66[t] - 
                0.7`\ Y\[UnderBracket]67[t] + 
                0.1`\ Y\[UnderBracket]79[t]\)\/cell\[UnderBracket]67\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]68", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]46[t] - 
                0.5`\ Y\[UnderBracket]68[t] + 0.1`\ Y\[UnderBracket]69[t] + 
                0.1`\ Y\[UnderBracket]75[t] + 
                0.1`\ Y\[UnderBracket]94[t]\)\/cell\[UnderBracket]68\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]69", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]46[t] + 
                0.1`\ Y\[UnderBracket]55[t] + 0.1`\ Y\[UnderBracket]68[t] - 
                0.7`\ Y\[UnderBracket]69[t] + 0.1`\ Y\[UnderBracket]86[t] + 
                0.1`\ Y\[UnderBracket]94[t] + 
                0.1`\ Y\[UnderBracket]98[t]\)\/cell\[UnderBracket]69\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]7", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]11[t] + 
                0.1`\ Y\[UnderBracket]13[t] + 0.1`\ Y\[UnderBracket]3[t] + 
                0.1`\ Y\[UnderBracket]6[t] - 0.6`\ Y\[UnderBracket]7[t] + 
                0.1`\ Y\[UnderBracket]8[t]\)\/cell\[UnderBracket]7\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]70", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]53[t] + 
                0.1`\ Y\[UnderBracket]65[t] - 0.6`\ Y\[UnderBracket]70[t] + 
                0.1`\ Y\[UnderBracket]74[t] + 0.1`\ Y\[UnderBracket]93[t] + 
                0.1`\ Y\[UnderBracket]97[t]\)\/cell\[UnderBracket]70\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]71", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]51[t] + 
                0.1`\ Y\[UnderBracket]56[t] + 0.1`\ Y\[UnderBracket]62[t] - 
                0.6`\ Y\[UnderBracket]71[t] + 0.1`\ Y\[UnderBracket]79[t] + 
                0.1`\ Y\[UnderBracket]84[t]\)\/cell\[UnderBracket]71\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]72", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]102[t] + 
                0.1`\ Y\[UnderBracket]51[t] + 0.1`\ Y\[UnderBracket]52[t] + 
                0.1`\ Y\[UnderBracket]60[t] - 0.7`\ Y\[UnderBracket]72[t] + 
                0.1`\ Y\[UnderBracket]80[t] + 
                0.1`\ Y\[UnderBracket]84[t]\)\/cell\[UnderBracket]72\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]73", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]48[t] + 
                0.1`\ Y\[UnderBracket]63[t] - 0.6`\ Y\[UnderBracket]73[t] + 
                0.1`\ Y\[UnderBracket]76[t] + 0.1`\ Y\[UnderBracket]77[t] + 
                0.1`\ Y\[UnderBracket]92[t]\)\/cell\[UnderBracket]73\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]74", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]53[t] + 
                0.1`\ Y\[UnderBracket]54[t] + 0.1`\ Y\[UnderBracket]70[t] - 
                0.7`\ Y\[UnderBracket]74[t] + 0.1`\ Y\[UnderBracket]75[t] + 
                0.1`\ Y\[UnderBracket]90[t] + 
                0.1`\ Y\[UnderBracket]93[t]\)\/cell\[UnderBracket]74\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]75", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]45[t] + 
                0.1`\ Y\[UnderBracket]54[t] + 0.1`\ Y\[UnderBracket]68[t] + 
                0.1`\ Y\[UnderBracket]74[t] - 0.7`\ Y\[UnderBracket]75[t] + 
                0.1`\ Y\[UnderBracket]90[t] + 
                0.1`\ Y\[UnderBracket]94[t]\)\/cell\[UnderBracket]75\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]76", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]76\)\((0.1`\ \
Y\[UnderBracket]49[t] + 0.1`\ Y\[UnderBracket]57[t] + 
              0.1`\ Y\[UnderBracket]63[t] + 0.1`\ Y\[UnderBracket]73[t] - 
              0.7999999999999999`\ Y\[UnderBracket]76[t] + 
              0.1`\ Y\[UnderBracket]81[t] + 0.1`\ Y\[UnderBracket]92[t] + 
              0.1`\ Y\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]77", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]77\)\((0.1`\ \
Y\[UnderBracket]103[t] + 0.1`\ Y\[UnderBracket]107[t] + 
              0.1`\ Y\[UnderBracket]48[t] + 0.1`\ Y\[UnderBracket]58[t] + 
              0.1`\ Y\[UnderBracket]73[t] - 
              0.7999999999999999`\ Y\[UnderBracket]77[t] + 
              0.1`\ Y\[UnderBracket]78[t] + 
              0.1`\ Y\[UnderBracket]92[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]78", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]107[t] + 0.1`\ Y\[UnderBracket]58[t] + 
                0.1`\ Y\[UnderBracket]77[t] - 
                0.4`\ Y\[UnderBracket]78[t]\)\/cell\[UnderBracket]78\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]79", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]79\)\((0.1`\ \
Y\[UnderBracket]101[t] + 0.1`\ Y\[UnderBracket]62[t] + 
              0.1`\ Y\[UnderBracket]66[t] + 0.1`\ Y\[UnderBracket]67[t] + 
              0.1`\ Y\[UnderBracket]71[t] - 
              0.8999999999999999`\ Y\[UnderBracket]79[t] + 
              0.1`\ Y\[UnderBracket]84[t] + 0.1`\ Y\[UnderBracket]91[t] + 
              0.1`\ Y\[UnderBracket]99[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]8", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]8\)\((0.1`\ Y\[UnderBracket]1[
                  t] + 0.1`\ Y\[UnderBracket]13[t] + 
              0.1`\ Y\[UnderBracket]14[t] + 0.1`\ Y\[UnderBracket]17[t] + 
              0.1`\ Y\[UnderBracket]2[t] + 0.1`\ Y\[UnderBracket]3[t] + 
              0.1`\ Y\[UnderBracket]5[t] + 0.1`\ Y\[UnderBracket]7[t] - 
              0.8999999999999999`\ Y\[UnderBracket]8[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]80", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]102[t] + 
                0.1`\ Y\[UnderBracket]110[t] + 0.1`\ Y\[UnderBracket]60[t] + 
                0.1`\ Y\[UnderBracket]72[t] - 0.7`\ Y\[UnderBracket]80[t] + 
                0.1`\ Y\[UnderBracket]85[t] + 
                0.1`\ Y\[UnderBracket]88[t]\)\/cell\[UnderBracket]80\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]81", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]57[t] + 
                0.1`\ Y\[UnderBracket]76[t] - 0.5`\ Y\[UnderBracket]81[t] + 
                0.1`\ Y\[UnderBracket]85[t] + 
                0.1`\ Y\[UnderBracket]95[t]\)\/cell\[UnderBracket]81\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]82", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(\(\(0.2`\)\(\[InvisibleSpace]\)\) + 
                0.1`\ Y\[UnderBracket]113[t] + 0.1`\ Y\[UnderBracket]50[t] + 
                0.1`\ Y\[UnderBracket]61[t] - 0.5`\ Y\[UnderBracket]82[t] + 
                0.1`\ Y\[UnderBracket]89[t]\)\/cell\[UnderBracket]82\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]83", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]100[t] + 
                0.1`\ Y\[UnderBracket]123[t] + 0.1`\ Y\[UnderBracket]59[t] + 
                0.1`\ Y\[UnderBracket]64[t] - 0.7`\ Y\[UnderBracket]83[t] + 
                0.1`\ Y\[UnderBracket]87[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]83\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]84", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]84\)\((0.1`\ \
Y\[UnderBracket]101[t] + 0.1`\ Y\[UnderBracket]102[t] + 
              0.1`\ Y\[UnderBracket]109[t] + 0.1`\ Y\[UnderBracket]51[t] + 
              0.1`\ Y\[UnderBracket]71[t] + 0.1`\ Y\[UnderBracket]72[t] + 
              0.1`\ Y\[UnderBracket]79[t] - 
              0.7999999999999999`\ Y\[UnderBracket]84[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]85", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]57[t] + 
                0.1`\ Y\[UnderBracket]60[t] + 0.1`\ Y\[UnderBracket]80[t] + 
                0.1`\ Y\[UnderBracket]81[t] - 0.7`\ Y\[UnderBracket]85[t] + 
                0.1`\ Y\[UnderBracket]88[t] + 
                0.1`\ Y\[UnderBracket]95[t]\)\/cell\[UnderBracket]85\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]86", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]106[t] + 
                0.1`\ Y\[UnderBracket]55[t] + 0.1`\ Y\[UnderBracket]66[t] + 
                0.1`\ Y\[UnderBracket]69[t] - 0.7`\ Y\[UnderBracket]86[t] + 
                0.1`\ Y\[UnderBracket]91[t] + 
                0.1`\ Y\[UnderBracket]98[t]\)\/cell\[UnderBracket]86\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]87", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]100[t] + 
                0.1`\ Y\[UnderBracket]59[t] + 0.1`\ Y\[UnderBracket]65[t] + 
                0.1`\ Y\[UnderBracket]83[t] - 
                0.5`\ Y\[UnderBracket]87[t]\)\/cell\[UnderBracket]87\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]88", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]110[t] + 
                0.1`\ Y\[UnderBracket]112[t] + 0.1`\ Y\[UnderBracket]120[t] + 
                0.1`\ Y\[UnderBracket]80[t] + 0.1`\ Y\[UnderBracket]85[t] - 
                0.7`\ Y\[UnderBracket]88[t] + 
                0.1`\ Y\[UnderBracket]95[t]\)\/cell\[UnderBracket]88\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]89", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]113[t] + 
                0.1`\ Y\[UnderBracket]61[t] + 0.1`\ Y\[UnderBracket]82[t] - 
                0.5`\ Y\[UnderBracket]89[t] + 
                0.1`\ Y\[UnderBracket]96[t]\)\/cell\[UnderBracket]89\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]9", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]10[t] + 
                0.1`\ Y\[UnderBracket]14[t] + 0.1`\ Y\[UnderBracket]18[t] + 
                0.1`\ Y\[UnderBracket]27[t] + 0.1`\ Y\[UnderBracket]4[t] + 
                0.1`\ Y\[UnderBracket]5[t] - 
                0.7`\ Y\[UnderBracket]9[t]\)\/cell\[UnderBracket]9\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]90", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]105[t] + 
                0.1`\ Y\[UnderBracket]108[t] + 0.1`\ Y\[UnderBracket]116[t] + 
                0.1`\ Y\[UnderBracket]74[t] + 0.1`\ Y\[UnderBracket]75[t] - 
                0.7`\ Y\[UnderBracket]90[t] + 
                0.1`\ Y\[UnderBracket]93[t]\)\/cell\[UnderBracket]90\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]91", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]106[t] + 
                0.1`\ Y\[UnderBracket]118[t] + 0.1`\ Y\[UnderBracket]66[t] + 
                0.1`\ Y\[UnderBracket]79[t] + 0.1`\ Y\[UnderBracket]86[t] - 
                0.7`\ Y\[UnderBracket]91[t] + 
                0.1`\ Y\[UnderBracket]99[t]\)\/cell\[UnderBracket]91\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]92", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]103[t] + 
                0.1`\ Y\[UnderBracket]111[t] + 0.1`\ Y\[UnderBracket]73[t] + 
                0.1`\ Y\[UnderBracket]76[t] + 0.1`\ Y\[UnderBracket]77[t] - 
                0.7`\ Y\[UnderBracket]92[t] + 
                0.1`\ Y\[UnderBracket]95[t]\)\/cell\[UnderBracket]92\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]93", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]93\)\((0.1`\ \
Y\[UnderBracket]104[t] + 0.1`\ Y\[UnderBracket]105[t] + 
              0.1`\ Y\[UnderBracket]115[t] + 0.1`\ Y\[UnderBracket]70[t] + 
              0.1`\ Y\[UnderBracket]74[t] + 0.1`\ Y\[UnderBracket]90[t] - 
              0.7999999999999999`\ Y\[UnderBracket]93[t] + 
              0.1`\ Y\[UnderBracket]97[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]94", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]108[t] + 
                0.1`\ Y\[UnderBracket]117[t] + 0.1`\ Y\[UnderBracket]68[t] + 
                0.1`\ Y\[UnderBracket]69[t] + 0.1`\ Y\[UnderBracket]75[t] - 
                0.7`\ Y\[UnderBracket]94[t] + 
                0.1`\ Y\[UnderBracket]98[t]\)\/cell\[UnderBracket]94\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]95", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]95\)\((0.1`\ \
Y\[UnderBracket]111[t] + 0.1`\ Y\[UnderBracket]120[t] + 
              0.1`\ Y\[UnderBracket]121[t] + 0.1`\ Y\[UnderBracket]76[t] + 
              0.1`\ Y\[UnderBracket]81[t] + 0.1`\ Y\[UnderBracket]85[t] + 
              0.1`\ Y\[UnderBracket]88[t] + 0.1`\ Y\[UnderBracket]92[t] - 
              0.8999999999999999`\ Y\[UnderBracket]95[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]96", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(1\/cell\[UnderBracket]96\)\((0.1`\ \
Y\[UnderBracket]113[t] + 0.1`\ Y\[UnderBracket]123[t] + 
              0.1`\ Y\[UnderBracket]127[t] + 0.1`\ Y\[UnderBracket]61[t] + 
              0.1`\ Y\[UnderBracket]64[t] + 0.1`\ Y\[UnderBracket]83[t] + 
              0.1`\ Y\[UnderBracket]89[t] - 
              0.7999999999999999`\ Y\[UnderBracket]96[t])\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]97", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]100[t] + 
                0.1`\ Y\[UnderBracket]104[t] + 0.1`\ Y\[UnderBracket]124[t] + 
                0.1`\ Y\[UnderBracket]65[t] + 0.1`\ Y\[UnderBracket]70[t] + 
                0.1`\ Y\[UnderBracket]93[t] - 
                0.7`\ Y\[UnderBracket]97[t]\)\/cell\[UnderBracket]97\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]98", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]106[t] + 
                0.1`\ Y\[UnderBracket]117[t] + 0.1`\ Y\[UnderBracket]125[t] + 
                0.1`\ Y\[UnderBracket]69[t] + 0.1`\ Y\[UnderBracket]86[t] + 
                0.1`\ Y\[UnderBracket]94[t] - 
                0.7`\ Y\[UnderBracket]98[t]\)\/cell\[UnderBracket]98\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["Y\[UnderBracket]99", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], 
          "\[Equal]", \(\(0.1`\ Y\[UnderBracket]101[t] + 
                0.1`\ Y\[UnderBracket]118[t] + 0.1`\ Y\[UnderBracket]119[t] + 
                0.1`\ Y\[UnderBracket]79[t] + 0.1`\ Y\[UnderBracket]91[t] - 
                0.6`\ Y\[UnderBracket]99[t]\)\/cell\[UnderBracket]99\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]1", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]2", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]3", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]4", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]5", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]6", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]7", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]8", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]9", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]10", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]11", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]12", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]13", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]14", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]15", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]16", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]17", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]18", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]19", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]20", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]21", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]22", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]23", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]24", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]25", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]26", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]27", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]28", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]29", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]30", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]31", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]32", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]33", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]34", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]35", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]36", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]37", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]38", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]39", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]40", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]41", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]42", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]43", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]44", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]45", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]46", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]47", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]48", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]49", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]50", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]51", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]52", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]53", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]54", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]55", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]56", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]57", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]58", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]59", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]60", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]61", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]62", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]63", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]64", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]65", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]66", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]67", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]68", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]69", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]70", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]71", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]72", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]73", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]74", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]75", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]76", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]77", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]78", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]79", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]80", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]81", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]82", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]83", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]84", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]85", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]86", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]87", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]88", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]89", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]90", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]91", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]92", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]93", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]94", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]95", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]96", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]97", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]98", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]99", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]100", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]101", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]102", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]103", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]104", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]105", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]106", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]107", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]108", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]109", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]110", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]111", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]112", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]113", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]114", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]115", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]116", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]117", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]118", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]119", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]120", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]121", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]122", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]123", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]124", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]125", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]126", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]127", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]128", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]129", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]130", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]131", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]132", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]133", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]134", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]135", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]136", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]137", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]138", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]139", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]140", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]141", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]142", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]143", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]144", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]145", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]146", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]147", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]148", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]149", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]150", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]151", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]152", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]153", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]154", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]155", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]156", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]157", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]158", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]159", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]160", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]161", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]162", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]163", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]164", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]165", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]166", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]167", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]168", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]169", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]170", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]171", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]172", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]173", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]174", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]175", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]176", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]177", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]178", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]179", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]180", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]181", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]182", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]183", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]184", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]185", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]186", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]187", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]188", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]189", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]190", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]191", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]192", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]193", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]194", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]195", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]196", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]197", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]198", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]199", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]200", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]201", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]202", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]203", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]204", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]205", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]206", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]207", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]208", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]209", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]210", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]211", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]212", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]213", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]214", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]215", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]216", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]217", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]218", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]219", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]220", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]221", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]222", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]223", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]224", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]225", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]226", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]227", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]228", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]229", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]230", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]231", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]232", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]233", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]234", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]235", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]236", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]237", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]238", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]239", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]240", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]241", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]242", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]243", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]244", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]245", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]246", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]247", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]248", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]249", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]250", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]251", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]252", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["L1SP\[UnderBracket]253", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Equal]", "0"}]}], 
      "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run a simulation using xCellerator", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rates = {ky \[Rule] \ 0.2, \ dy \[Rule] \ 0.1, \ Dy \[Rule] \ 0.1, \ 
          kD \[Rule] \ 3.0, \ tauw \[Rule] \ 10, \ dw \[Rule] \ 0.1, \ 
          hw \[Rule] \ 0, \ Twy \[Rule] \ \(-20\), \ Twa \[Rule] \ 0.5, \ 
          a \[Rule] \ 0.1, \ b \[Rule] \ 0.2, \ beta \[Rule] \ 0.1, \ 
          c \[Rule] \ 0.1, \ d \[Rule] \ 0.01, \ Da \[Rule] \ 0.1, \ 
          Db \[Rule] \ 1.5};\)\), "\[IndentingNewLine]", 
    \(\(Clear[L1];\)\), "\[IndentingNewLine]", 
    \(\(internal[
          i_] := \ {\[IndentingNewLine]{Y[i] \[RightTeeArrow] W[i], 
            GRN[1/tauw, Twy, 1, hw, 
              sigma]}, \[IndentingNewLine]{A[i] \[RightTeeArrow] W[i], \ 
            GRN[1/tauw, Twa, 1, hw, 
              sigma]}, \[IndentingNewLine]{W[
                i] \[ShortRightArrow] \[EmptySet], \ 
            dw}, \[IndentingNewLine]{\[EmptySet] \[RightArrowLeftArrow] 
              Y[i], \ ky*L1[i], \ 
            dy}, \[IndentingNewLine]\ {\[EmptySet] \[RightArrowLeftArrow] 
              A[i], a, \ 
            beta + d*\(Y[i]\)[t]}, \[IndentingNewLine]{2  A[i] + 
                B[i] \[ShortRightArrow] 3  A[i], 
            c}, \ \[IndentingNewLine]{A[i] \[ShortRightArrow] B[i], \ 
            b}\[IndentingNewLine]};\)\), "\[IndentingNewLine]", 
    \(\(external[i_, 
          j_] := {\ {Y[i] \[ShortRightArrow] Y[j], \ 
            Dy}, {A[i] \[ShortRightArrow] A[j], \ 
            Da}, {B[i] \[ShortRightArrow] B[j], \ 
            Db}};\)\), "\[IndentingNewLine]", 
    \(\({cpu, STN} = 
        Timing[\[IndentingNewLine]createNetwork[xymeristem, \ 
            internalNetwork \[Rule] \ internal, 
            interactionNetwork \[Rule] \ external, 
            connectionList \[Rule] \ \
"\<PrunedDelaunay\>"\[IndentingNewLine]]];\)\), "\[IndentingNewLine]", 
    \(Print[cpu]\)}], "Input"],

Cell[BoxData[
    \("Using Pruned Delaunay Triangulation for Near Neighbors \
Connections."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]" dimensional data"\),
      SequenceForm[ 2, " dimensional data"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(253\[InvisibleSpace]" cells"\),
      SequenceForm[ 253, " cells"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(1771\[InvisibleSpace]" internal reactions"\),
      SequenceForm[ 1771, " internal reactions"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4230\[InvisibleSpace]" intercellular reactions"\),
      SequenceForm[ 4230, " intercellular reactions"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(0\[InvisibleSpace]" global reactions"\),
      SequenceForm[ 0, " global reactions"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6001\[InvisibleSpace]" total reactions"\),
      SequenceForm[ 6001, " total reactions"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(0.9908559999999991`\ Second\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[STN]\)], "Input"],

Cell[BoxData[
    \(6001\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(STN\)], "Input"],

Cell[BoxData[
    \({{Y[1] \[RightTeeArrow] W[1], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[1] \[RightTeeArrow] W[1], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[1] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[1], ky\ L1[1], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[1], a, 
        beta + d\ \(Y[1]\)[t]}, {2\ A[1] + B[1] \[ShortRightArrow] 3\ A[1], 
        c}, {A[1] \[ShortRightArrow] B[1], b}, {Y[2] \[RightTeeArrow] W[2], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[2] \[RightTeeArrow] W[2], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[2] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[2], ky\ L1[2], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[2], a, 
        beta + d\ \(Y[2]\)[t]}, {2\ A[2] + B[2] \[ShortRightArrow] 3\ A[2], 
        c}, {A[2] \[ShortRightArrow] B[2], b}, {Y[3] \[RightTeeArrow] W[3], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[3] \[RightTeeArrow] W[3], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[3] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[3], ky\ L1[3], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[3], a, 
        beta + d\ \(Y[3]\)[t]}, {2\ A[3] + B[3] \[ShortRightArrow] 3\ A[3], 
        c}, {A[3] \[ShortRightArrow] B[3], b}, {Y[4] \[RightTeeArrow] W[4], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[4] \[RightTeeArrow] W[4], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[4] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[4], ky\ L1[4], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[4], a, 
        beta + d\ \(Y[4]\)[t]}, {2\ A[4] + B[4] \[ShortRightArrow] 3\ A[4], 
        c}, {A[4] \[ShortRightArrow] B[4], b}, {Y[5] \[RightTeeArrow] W[5], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[5] \[RightTeeArrow] W[5], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[5] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[5], ky\ L1[5], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[5], a, 
        beta + d\ \(Y[5]\)[t]}, {2\ A[5] + B[5] \[ShortRightArrow] 3\ A[5], 
        c}, {A[5] \[ShortRightArrow] B[5], b}, {Y[6] \[RightTeeArrow] W[6], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[6] \[RightTeeArrow] W[6], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[6] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[6], ky\ L1[6], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[6], a, 
        beta + d\ \(Y[6]\)[t]}, {2\ A[6] + B[6] \[ShortRightArrow] 3\ A[6], 
        c}, {A[6] \[ShortRightArrow] B[6], b}, {Y[7] \[RightTeeArrow] W[7], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[7] \[RightTeeArrow] W[7], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[7] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[7], ky\ L1[7], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[7], a, 
        beta + d\ \(Y[7]\)[t]}, {2\ A[7] + B[7] \[ShortRightArrow] 3\ A[7], 
        c}, {A[7] \[ShortRightArrow] B[7], b}, {Y[8] \[RightTeeArrow] W[8], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[8] \[RightTeeArrow] W[8], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[8] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[8], ky\ L1[8], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[8], a, 
        beta + d\ \(Y[8]\)[t]}, {2\ A[8] + B[8] \[ShortRightArrow] 3\ A[8], 
        c}, {A[8] \[ShortRightArrow] B[8], b}, {Y[9] \[RightTeeArrow] W[9], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[9] \[RightTeeArrow] W[9], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[9] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[9], ky\ L1[9], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[9], a, 
        beta + d\ \(Y[9]\)[t]}, {2\ A[9] + B[9] \[ShortRightArrow] 3\ A[9], 
        c}, {A[9] \[ShortRightArrow] B[9], b}, {Y[10] \[RightTeeArrow] W[10], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[10] \[RightTeeArrow] W[10], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[10] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[10], ky\ L1[10], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[10], a, 
        beta + d\ \(Y[10]\)[t]}, {2\ A[10] + B[10] \[ShortRightArrow] 
          3\ A[10], c}, {A[10] \[ShortRightArrow] B[10], 
        b}, {Y[11] \[RightTeeArrow] W[11], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[11] \[RightTeeArrow] W[11], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[11] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[11], ky\ L1[11], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[11], a, 
        beta + d\ \(Y[11]\)[t]}, {2\ A[11] + B[11] \[ShortRightArrow] 
          3\ A[11], c}, {A[11] \[ShortRightArrow] B[11], 
        b}, {Y[12] \[RightTeeArrow] W[12], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[12] \[RightTeeArrow] W[12], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[12] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[12], ky\ L1[12], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[12], a, 
        beta + d\ \(Y[12]\)[t]}, {2\ A[12] + B[12] \[ShortRightArrow] 
          3\ A[12], c}, {A[12] \[ShortRightArrow] B[12], 
        b}, {Y[13] \[RightTeeArrow] W[13], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[13] \[RightTeeArrow] W[13], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[13] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[13], ky\ L1[13], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[13], a, 
        beta + d\ \(Y[13]\)[t]}, {2\ A[13] + B[13] \[ShortRightArrow] 
          3\ A[13], c}, {A[13] \[ShortRightArrow] B[13], 
        b}, {Y[14] \[RightTeeArrow] W[14], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[14] \[RightTeeArrow] W[14], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[14] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[14], ky\ L1[14], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[14], a, 
        beta + d\ \(Y[14]\)[t]}, {2\ A[14] + B[14] \[ShortRightArrow] 
          3\ A[14], c}, {A[14] \[ShortRightArrow] B[14], 
        b}, {Y[15] \[RightTeeArrow] W[15], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[15] \[RightTeeArrow] W[15], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[15] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[15], ky\ L1[15], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[15], a, 
        beta + d\ \(Y[15]\)[t]}, {2\ A[15] + B[15] \[ShortRightArrow] 
          3\ A[15], c}, {A[15] \[ShortRightArrow] B[15], 
        b}, {Y[16] \[RightTeeArrow] W[16], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[16] \[RightTeeArrow] W[16], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[16] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[16], ky\ L1[16], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[16], a, 
        beta + d\ \(Y[16]\)[t]}, {2\ A[16] + B[16] \[ShortRightArrow] 
          3\ A[16], c}, {A[16] \[ShortRightArrow] B[16], 
        b}, {Y[17] \[RightTeeArrow] W[17], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[17] \[RightTeeArrow] W[17], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[17] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[17], ky\ L1[17], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[17], a, 
        beta + d\ \(Y[17]\)[t]}, {2\ A[17] + B[17] \[ShortRightArrow] 
          3\ A[17], c}, {A[17] \[ShortRightArrow] B[17], 
        b}, {Y[18] \[RightTeeArrow] W[18], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[18] \[RightTeeArrow] W[18], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[18] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[18], ky\ L1[18], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[18], a, 
        beta + d\ \(Y[18]\)[t]}, {2\ A[18] + B[18] \[ShortRightArrow] 
          3\ A[18], c}, {A[18] \[ShortRightArrow] B[18], 
        b}, {Y[19] \[RightTeeArrow] W[19], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[19] \[RightTeeArrow] W[19], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[19] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[19], ky\ L1[19], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[19], a, 
        beta + d\ \(Y[19]\)[t]}, {2\ A[19] + B[19] \[ShortRightArrow] 
          3\ A[19], c}, {A[19] \[ShortRightArrow] B[19], 
        b}, {Y[20] \[RightTeeArrow] W[20], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[20] \[RightTeeArrow] W[20], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[20] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[20], ky\ L1[20], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[20], a, 
        beta + d\ \(Y[20]\)[t]}, {2\ A[20] + B[20] \[ShortRightArrow] 
          3\ A[20], c}, {A[20] \[ShortRightArrow] B[20], 
        b}, {Y[21] \[RightTeeArrow] W[21], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[21] \[RightTeeArrow] W[21], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[21] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[21], ky\ L1[21], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[21], a, 
        beta + d\ \(Y[21]\)[t]}, {2\ A[21] + B[21] \[ShortRightArrow] 
          3\ A[21], c}, {A[21] \[ShortRightArrow] B[21], 
        b}, {Y[22] \[RightTeeArrow] W[22], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[22] \[RightTeeArrow] W[22], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[22] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[22], ky\ L1[22], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[22], a, 
        beta + d\ \(Y[22]\)[t]}, {2\ A[22] + B[22] \[ShortRightArrow] 
          3\ A[22], c}, {A[22] \[ShortRightArrow] B[22], 
        b}, {Y[23] \[RightTeeArrow] W[23], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[23] \[RightTeeArrow] W[23], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[23] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[23], ky\ L1[23], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[23], a, 
        beta + d\ \(Y[23]\)[t]}, {2\ A[23] + B[23] \[ShortRightArrow] 
          3\ A[23], c}, {A[23] \[ShortRightArrow] B[23], 
        b}, {Y[24] \[RightTeeArrow] W[24], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[24] \[RightTeeArrow] W[24], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[24] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[24], ky\ L1[24], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[24], a, 
        beta + d\ \(Y[24]\)[t]}, {2\ A[24] + B[24] \[ShortRightArrow] 
          3\ A[24], c}, {A[24] \[ShortRightArrow] B[24], 
        b}, {Y[25] \[RightTeeArrow] W[25], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[25] \[RightTeeArrow] W[25], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[25] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[25], ky\ L1[25], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[25], a, 
        beta + d\ \(Y[25]\)[t]}, {2\ A[25] + B[25] \[ShortRightArrow] 
          3\ A[25], c}, {A[25] \[ShortRightArrow] B[25], 
        b}, {Y[26] \[RightTeeArrow] W[26], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[26] \[RightTeeArrow] W[26], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[26] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[26], ky\ L1[26], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[26], a, 
        beta + d\ \(Y[26]\)[t]}, {2\ A[26] + B[26] \[ShortRightArrow] 
          3\ A[26], c}, {A[26] \[ShortRightArrow] B[26], 
        b}, {Y[27] \[RightTeeArrow] W[27], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[27] \[RightTeeArrow] W[27], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[27] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[27], ky\ L1[27], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[27], a, 
        beta + d\ \(Y[27]\)[t]}, {2\ A[27] + B[27] \[ShortRightArrow] 
          3\ A[27], c}, {A[27] \[ShortRightArrow] B[27], 
        b}, {Y[28] \[RightTeeArrow] W[28], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[28] \[RightTeeArrow] W[28], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[28] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[28], ky\ L1[28], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[28], a, 
        beta + d\ \(Y[28]\)[t]}, {2\ A[28] + B[28] \[ShortRightArrow] 
          3\ A[28], c}, {A[28] \[ShortRightArrow] B[28], 
        b}, {Y[29] \[RightTeeArrow] W[29], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[29] \[RightTeeArrow] W[29], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[29] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[29], ky\ L1[29], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[29], a, 
        beta + d\ \(Y[29]\)[t]}, {2\ A[29] + B[29] \[ShortRightArrow] 
          3\ A[29], c}, {A[29] \[ShortRightArrow] B[29], 
        b}, {Y[30] \[RightTeeArrow] W[30], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[30] \[RightTeeArrow] W[30], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[30] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[30], ky\ L1[30], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[30], a, 
        beta + d\ \(Y[30]\)[t]}, {2\ A[30] + B[30] \[ShortRightArrow] 
          3\ A[30], c}, {A[30] \[ShortRightArrow] B[30], 
        b}, {Y[31] \[RightTeeArrow] W[31], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[31] \[RightTeeArrow] W[31], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[31] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[31], ky\ L1[31], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[31], a, 
        beta + d\ \(Y[31]\)[t]}, {2\ A[31] + B[31] \[ShortRightArrow] 
          3\ A[31], c}, {A[31] \[ShortRightArrow] B[31], 
        b}, {Y[32] \[RightTeeArrow] W[32], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[32] \[RightTeeArrow] W[32], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[32] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[32], ky\ L1[32], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[32], a, 
        beta + d\ \(Y[32]\)[t]}, {2\ A[32] + B[32] \[ShortRightArrow] 
          3\ A[32], c}, {A[32] \[ShortRightArrow] B[32], 
        b}, {Y[33] \[RightTeeArrow] W[33], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[33] \[RightTeeArrow] W[33], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[33] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[33], ky\ L1[33], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[33], a, 
        beta + d\ \(Y[33]\)[t]}, {2\ A[33] + B[33] \[ShortRightArrow] 
          3\ A[33], c}, {A[33] \[ShortRightArrow] B[33], 
        b}, {Y[34] \[RightTeeArrow] W[34], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[34] \[RightTeeArrow] W[34], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[34] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[34], ky\ L1[34], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[34], a, 
        beta + d\ \(Y[34]\)[t]}, {2\ A[34] + B[34] \[ShortRightArrow] 
          3\ A[34], c}, {A[34] \[ShortRightArrow] B[34], 
        b}, {Y[35] \[RightTeeArrow] W[35], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[35] \[RightTeeArrow] W[35], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[35] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[35], ky\ L1[35], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[35], a, 
        beta + d\ \(Y[35]\)[t]}, {2\ A[35] + B[35] \[ShortRightArrow] 
          3\ A[35], c}, {A[35] \[ShortRightArrow] B[35], 
        b}, {Y[36] \[RightTeeArrow] W[36], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[36] \[RightTeeArrow] W[36], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[36] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[36], ky\ L1[36], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[36], a, 
        beta + d\ \(Y[36]\)[t]}, {2\ A[36] + B[36] \[ShortRightArrow] 
          3\ A[36], c}, {A[36] \[ShortRightArrow] B[36], 
        b}, {Y[37] \[RightTeeArrow] W[37], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[37] \[RightTeeArrow] W[37], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[37] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[37], ky\ L1[37], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[37], a, 
        beta + d\ \(Y[37]\)[t]}, {2\ A[37] + B[37] \[ShortRightArrow] 
          3\ A[37], c}, {A[37] \[ShortRightArrow] B[37], 
        b}, {Y[38] \[RightTeeArrow] W[38], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[38] \[RightTeeArrow] W[38], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[38] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[38], ky\ L1[38], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[38], a, 
        beta + d\ \(Y[38]\)[t]}, {2\ A[38] + B[38] \[ShortRightArrow] 
          3\ A[38], c}, {A[38] \[ShortRightArrow] B[38], 
        b}, {Y[39] \[RightTeeArrow] W[39], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[39] \[RightTeeArrow] W[39], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[39] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[39], ky\ L1[39], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[39], a, 
        beta + d\ \(Y[39]\)[t]}, {2\ A[39] + B[39] \[ShortRightArrow] 
          3\ A[39], c}, {A[39] \[ShortRightArrow] B[39], 
        b}, {Y[40] \[RightTeeArrow] W[40], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[40] \[RightTeeArrow] W[40], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[40] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[40], ky\ L1[40], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[40], a, 
        beta + d\ \(Y[40]\)[t]}, {2\ A[40] + B[40] \[ShortRightArrow] 
          3\ A[40], c}, {A[40] \[ShortRightArrow] B[40], 
        b}, {Y[41] \[RightTeeArrow] W[41], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[41] \[RightTeeArrow] W[41], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[41] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[41], ky\ L1[41], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[41], a, 
        beta + d\ \(Y[41]\)[t]}, {2\ A[41] + B[41] \[ShortRightArrow] 
          3\ A[41], c}, {A[41] \[ShortRightArrow] B[41], 
        b}, {Y[42] \[RightTeeArrow] W[42], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[42] \[RightTeeArrow] W[42], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[42] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[42], ky\ L1[42], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[42], a, 
        beta + d\ \(Y[42]\)[t]}, {2\ A[42] + B[42] \[ShortRightArrow] 
          3\ A[42], c}, {A[42] \[ShortRightArrow] B[42], 
        b}, {Y[43] \[RightTeeArrow] W[43], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[43] \[RightTeeArrow] W[43], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[43] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[43], ky\ L1[43], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[43], a, 
        beta + d\ \(Y[43]\)[t]}, {2\ A[43] + B[43] \[ShortRightArrow] 
          3\ A[43], c}, {A[43] \[ShortRightArrow] B[43], 
        b}, {Y[44] \[RightTeeArrow] W[44], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[44] \[RightTeeArrow] W[44], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[44] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[44], ky\ L1[44], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[44], a, 
        beta + d\ \(Y[44]\)[t]}, {2\ A[44] + B[44] \[ShortRightArrow] 
          3\ A[44], c}, {A[44] \[ShortRightArrow] B[44], 
        b}, {Y[45] \[RightTeeArrow] W[45], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[45] \[RightTeeArrow] W[45], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[45] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[45], ky\ L1[45], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[45], a, 
        beta + d\ \(Y[45]\)[t]}, {2\ A[45] + B[45] \[ShortRightArrow] 
          3\ A[45], c}, {A[45] \[ShortRightArrow] B[45], 
        b}, {Y[46] \[RightTeeArrow] W[46], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[46] \[RightTeeArrow] W[46], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[46] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[46], ky\ L1[46], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[46], a, 
        beta + d\ \(Y[46]\)[t]}, {2\ A[46] + B[46] \[ShortRightArrow] 
          3\ A[46], c}, {A[46] \[ShortRightArrow] B[46], 
        b}, {Y[47] \[RightTeeArrow] W[47], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[47] \[RightTeeArrow] W[47], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[47] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[47], ky\ L1[47], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[47], a, 
        beta + d\ \(Y[47]\)[t]}, {2\ A[47] + B[47] \[ShortRightArrow] 
          3\ A[47], c}, {A[47] \[ShortRightArrow] B[47], 
        b}, {Y[48] \[RightTeeArrow] W[48], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[48] \[RightTeeArrow] W[48], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[48] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[48], ky\ L1[48], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[48], a, 
        beta + d\ \(Y[48]\)[t]}, {2\ A[48] + B[48] \[ShortRightArrow] 
          3\ A[48], c}, {A[48] \[ShortRightArrow] B[48], 
        b}, {Y[49] \[RightTeeArrow] W[49], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[49] \[RightTeeArrow] W[49], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[49] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[49], ky\ L1[49], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[49], a, 
        beta + d\ \(Y[49]\)[t]}, {2\ A[49] + B[49] \[ShortRightArrow] 
          3\ A[49], c}, {A[49] \[ShortRightArrow] B[49], 
        b}, {Y[50] \[RightTeeArrow] W[50], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[50] \[RightTeeArrow] W[50], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[50] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[50], ky\ L1[50], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[50], a, 
        beta + d\ \(Y[50]\)[t]}, {2\ A[50] + B[50] \[ShortRightArrow] 
          3\ A[50], c}, {A[50] \[ShortRightArrow] B[50], 
        b}, {Y[51] \[RightTeeArrow] W[51], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[51] \[RightTeeArrow] W[51], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[51] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[51], ky\ L1[51], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[51], a, 
        beta + d\ \(Y[51]\)[t]}, {2\ A[51] + B[51] \[ShortRightArrow] 
          3\ A[51], c}, {A[51] \[ShortRightArrow] B[51], 
        b}, {Y[52] \[RightTeeArrow] W[52], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[52] \[RightTeeArrow] W[52], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[52] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[52], ky\ L1[52], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[52], a, 
        beta + d\ \(Y[52]\)[t]}, {2\ A[52] + B[52] \[ShortRightArrow] 
          3\ A[52], c}, {A[52] \[ShortRightArrow] B[52], 
        b}, {Y[53] \[RightTeeArrow] W[53], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[53] \[RightTeeArrow] W[53], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[53] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[53], ky\ L1[53], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[53], a, 
        beta + d\ \(Y[53]\)[t]}, {2\ A[53] + B[53] \[ShortRightArrow] 
          3\ A[53], c}, {A[53] \[ShortRightArrow] B[53], 
        b}, {Y[54] \[RightTeeArrow] W[54], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[54] \[RightTeeArrow] W[54], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[54] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[54], ky\ L1[54], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[54], a, 
        beta + d\ \(Y[54]\)[t]}, {2\ A[54] + B[54] \[ShortRightArrow] 
          3\ A[54], c}, {A[54] \[ShortRightArrow] B[54], 
        b}, {Y[55] \[RightTeeArrow] W[55], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[55] \[RightTeeArrow] W[55], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[55] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[55], ky\ L1[55], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[55], a, 
        beta + d\ \(Y[55]\)[t]}, {2\ A[55] + B[55] \[ShortRightArrow] 
          3\ A[55], c}, {A[55] \[ShortRightArrow] B[55], 
        b}, {Y[56] \[RightTeeArrow] W[56], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[56] \[RightTeeArrow] W[56], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[56] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[56], ky\ L1[56], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[56], a, 
        beta + d\ \(Y[56]\)[t]}, {2\ A[56] + B[56] \[ShortRightArrow] 
          3\ A[56], c}, {A[56] \[ShortRightArrow] B[56], 
        b}, {Y[57] \[RightTeeArrow] W[57], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[57] \[RightTeeArrow] W[57], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[57] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[57], ky\ L1[57], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[57], a, 
        beta + d\ \(Y[57]\)[t]}, {2\ A[57] + B[57] \[ShortRightArrow] 
          3\ A[57], c}, {A[57] \[ShortRightArrow] B[57], 
        b}, {Y[58] \[RightTeeArrow] W[58], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[58] \[RightTeeArrow] W[58], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[58] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[58], ky\ L1[58], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[58], a, 
        beta + d\ \(Y[58]\)[t]}, {2\ A[58] + B[58] \[ShortRightArrow] 
          3\ A[58], c}, {A[58] \[ShortRightArrow] B[58], 
        b}, {Y[59] \[RightTeeArrow] W[59], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[59] \[RightTeeArrow] W[59], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[59] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[59], ky\ L1[59], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[59], a, 
        beta + d\ \(Y[59]\)[t]}, {2\ A[59] + B[59] \[ShortRightArrow] 
          3\ A[59], c}, {A[59] \[ShortRightArrow] B[59], 
        b}, {Y[60] \[RightTeeArrow] W[60], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[60] \[RightTeeArrow] W[60], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[60] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[60], ky\ L1[60], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[60], a, 
        beta + d\ \(Y[60]\)[t]}, {2\ A[60] + B[60] \[ShortRightArrow] 
          3\ A[60], c}, {A[60] \[ShortRightArrow] B[60], 
        b}, {Y[61] \[RightTeeArrow] W[61], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[61] \[RightTeeArrow] W[61], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[61] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[61], ky\ L1[61], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[61], a, 
        beta + d\ \(Y[61]\)[t]}, {2\ A[61] + B[61] \[ShortRightArrow] 
          3\ A[61], c}, {A[61] \[ShortRightArrow] B[61], 
        b}, {Y[62] \[RightTeeArrow] W[62], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[62] \[RightTeeArrow] W[62], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[62] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[62], ky\ L1[62], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[62], a, 
        beta + d\ \(Y[62]\)[t]}, {2\ A[62] + B[62] \[ShortRightArrow] 
          3\ A[62], c}, {A[62] \[ShortRightArrow] B[62], 
        b}, {Y[63] \[RightTeeArrow] W[63], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[63] \[RightTeeArrow] W[63], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[63] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[63], ky\ L1[63], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[63], a, 
        beta + d\ \(Y[63]\)[t]}, {2\ A[63] + B[63] \[ShortRightArrow] 
          3\ A[63], c}, {A[63] \[ShortRightArrow] B[63], 
        b}, {Y[64] \[RightTeeArrow] W[64], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[64] \[RightTeeArrow] W[64], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[64] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[64], ky\ L1[64], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[64], a, 
        beta + d\ \(Y[64]\)[t]}, {2\ A[64] + B[64] \[ShortRightArrow] 
          3\ A[64], c}, {A[64] \[ShortRightArrow] B[64], 
        b}, {Y[65] \[RightTeeArrow] W[65], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[65] \[RightTeeArrow] W[65], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[65] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[65], ky\ L1[65], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[65], a, 
        beta + d\ \(Y[65]\)[t]}, {2\ A[65] + B[65] \[ShortRightArrow] 
          3\ A[65], c}, {A[65] \[ShortRightArrow] B[65], 
        b}, {Y[66] \[RightTeeArrow] W[66], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[66] \[RightTeeArrow] W[66], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[66] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[66], ky\ L1[66], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[66], a, 
        beta + d\ \(Y[66]\)[t]}, {2\ A[66] + B[66] \[ShortRightArrow] 
          3\ A[66], c}, {A[66] \[ShortRightArrow] B[66], 
        b}, {Y[67] \[RightTeeArrow] W[67], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[67] \[RightTeeArrow] W[67], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[67] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[67], ky\ L1[67], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[67], a, 
        beta + d\ \(Y[67]\)[t]}, {2\ A[67] + B[67] \[ShortRightArrow] 
          3\ A[67], c}, {A[67] \[ShortRightArrow] B[67], 
        b}, {Y[68] \[RightTeeArrow] W[68], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[68] \[RightTeeArrow] W[68], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[68] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[68], ky\ L1[68], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[68], a, 
        beta + d\ \(Y[68]\)[t]}, {2\ A[68] + B[68] \[ShortRightArrow] 
          3\ A[68], c}, {A[68] \[ShortRightArrow] B[68], 
        b}, {Y[69] \[RightTeeArrow] W[69], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[69] \[RightTeeArrow] W[69], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[69] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[69], ky\ L1[69], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[69], a, 
        beta + d\ \(Y[69]\)[t]}, {2\ A[69] + B[69] \[ShortRightArrow] 
          3\ A[69], c}, {A[69] \[ShortRightArrow] B[69], 
        b}, {Y[70] \[RightTeeArrow] W[70], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[70] \[RightTeeArrow] W[70], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[70] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[70], ky\ L1[70], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[70], a, 
        beta + d\ \(Y[70]\)[t]}, {2\ A[70] + B[70] \[ShortRightArrow] 
          3\ A[70], c}, {A[70] \[ShortRightArrow] B[70], 
        b}, {Y[71] \[RightTeeArrow] W[71], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[71] \[RightTeeArrow] W[71], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[71] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[71], ky\ L1[71], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[71], a, 
        beta + d\ \(Y[71]\)[t]}, {2\ A[71] + B[71] \[ShortRightArrow] 
          3\ A[71], c}, {A[71] \[ShortRightArrow] B[71], 
        b}, {Y[72] \[RightTeeArrow] W[72], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[72] \[RightTeeArrow] W[72], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[72] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[72], ky\ L1[72], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[72], a, 
        beta + d\ \(Y[72]\)[t]}, {2\ A[72] + B[72] \[ShortRightArrow] 
          3\ A[72], c}, {A[72] \[ShortRightArrow] B[72], 
        b}, {Y[73] \[RightTeeArrow] W[73], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[73] \[RightTeeArrow] W[73], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[73] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[73], ky\ L1[73], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[73], a, 
        beta + d\ \(Y[73]\)[t]}, {2\ A[73] + B[73] \[ShortRightArrow] 
          3\ A[73], c}, {A[73] \[ShortRightArrow] B[73], 
        b}, {Y[74] \[RightTeeArrow] W[74], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[74] \[RightTeeArrow] W[74], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[74] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[74], ky\ L1[74], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[74], a, 
        beta + d\ \(Y[74]\)[t]}, {2\ A[74] + B[74] \[ShortRightArrow] 
          3\ A[74], c}, {A[74] \[ShortRightArrow] B[74], 
        b}, {Y[75] \[RightTeeArrow] W[75], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[75] \[RightTeeArrow] W[75], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[75] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[75], ky\ L1[75], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[75], a, 
        beta + d\ \(Y[75]\)[t]}, {2\ A[75] + B[75] \[ShortRightArrow] 
          3\ A[75], c}, {A[75] \[ShortRightArrow] B[75], 
        b}, {Y[76] \[RightTeeArrow] W[76], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[76] \[RightTeeArrow] W[76], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[76] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[76], ky\ L1[76], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[76], a, 
        beta + d\ \(Y[76]\)[t]}, {2\ A[76] + B[76] \[ShortRightArrow] 
          3\ A[76], c}, {A[76] \[ShortRightArrow] B[76], 
        b}, {Y[77] \[RightTeeArrow] W[77], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[77] \[RightTeeArrow] W[77], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[77] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[77], ky\ L1[77], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[77], a, 
        beta + d\ \(Y[77]\)[t]}, {2\ A[77] + B[77] \[ShortRightArrow] 
          3\ A[77], c}, {A[77] \[ShortRightArrow] B[77], 
        b}, {Y[78] \[RightTeeArrow] W[78], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[78] \[RightTeeArrow] W[78], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[78] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[78], ky\ L1[78], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[78], a, 
        beta + d\ \(Y[78]\)[t]}, {2\ A[78] + B[78] \[ShortRightArrow] 
          3\ A[78], c}, {A[78] \[ShortRightArrow] B[78], 
        b}, {Y[79] \[RightTeeArrow] W[79], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[79] \[RightTeeArrow] W[79], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[79] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[79], ky\ L1[79], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[79], a, 
        beta + d\ \(Y[79]\)[t]}, {2\ A[79] + B[79] \[ShortRightArrow] 
          3\ A[79], c}, {A[79] \[ShortRightArrow] B[79], 
        b}, {Y[80] \[RightTeeArrow] W[80], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[80] \[RightTeeArrow] W[80], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[80] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[80], ky\ L1[80], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[80], a, 
        beta + d\ \(Y[80]\)[t]}, {2\ A[80] + B[80] \[ShortRightArrow] 
          3\ A[80], c}, {A[80] \[ShortRightArrow] B[80], 
        b}, {Y[81] \[RightTeeArrow] W[81], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[81] \[RightTeeArrow] W[81], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[81] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[81], ky\ L1[81], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[81], a, 
        beta + d\ \(Y[81]\)[t]}, {2\ A[81] + B[81] \[ShortRightArrow] 
          3\ A[81], c}, {A[81] \[ShortRightArrow] B[81], 
        b}, {Y[82] \[RightTeeArrow] W[82], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[82] \[RightTeeArrow] W[82], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[82] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[82], ky\ L1[82], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[82], a, 
        beta + d\ \(Y[82]\)[t]}, {2\ A[82] + B[82] \[ShortRightArrow] 
          3\ A[82], c}, {A[82] \[ShortRightArrow] B[82], 
        b}, {Y[83] \[RightTeeArrow] W[83], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[83] \[RightTeeArrow] W[83], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[83] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[83], ky\ L1[83], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[83], a, 
        beta + d\ \(Y[83]\)[t]}, {2\ A[83] + B[83] \[ShortRightArrow] 
          3\ A[83], c}, {A[83] \[ShortRightArrow] B[83], 
        b}, {Y[84] \[RightTeeArrow] W[84], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[84] \[RightTeeArrow] W[84], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[84] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[84], ky\ L1[84], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[84], a, 
        beta + d\ \(Y[84]\)[t]}, {2\ A[84] + B[84] \[ShortRightArrow] 
          3\ A[84], c}, {A[84] \[ShortRightArrow] B[84], 
        b}, {Y[85] \[RightTeeArrow] W[85], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[85] \[RightTeeArrow] W[85], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[85] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[85], ky\ L1[85], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[85], a, 
        beta + d\ \(Y[85]\)[t]}, {2\ A[85] + B[85] \[ShortRightArrow] 
          3\ A[85], c}, {A[85] \[ShortRightArrow] B[85], 
        b}, {Y[86] \[RightTeeArrow] W[86], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[86] \[RightTeeArrow] W[86], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[86] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[86], ky\ L1[86], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[86], a, 
        beta + d\ \(Y[86]\)[t]}, {2\ A[86] + B[86] \[ShortRightArrow] 
          3\ A[86], c}, {A[86] \[ShortRightArrow] B[86], 
        b}, {Y[87] \[RightTeeArrow] W[87], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[87] \[RightTeeArrow] W[87], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[87] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[87], ky\ L1[87], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[87], a, 
        beta + d\ \(Y[87]\)[t]}, {2\ A[87] + B[87] \[ShortRightArrow] 
          3\ A[87], c}, {A[87] \[ShortRightArrow] B[87], 
        b}, {Y[88] \[RightTeeArrow] W[88], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[88] \[RightTeeArrow] W[88], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[88] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[88], ky\ L1[88], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[88], a, 
        beta + d\ \(Y[88]\)[t]}, {2\ A[88] + B[88] \[ShortRightArrow] 
          3\ A[88], c}, {A[88] \[ShortRightArrow] B[88], 
        b}, {Y[89] \[RightTeeArrow] W[89], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[89] \[RightTeeArrow] W[89], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[89] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[89], ky\ L1[89], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[89], a, 
        beta + d\ \(Y[89]\)[t]}, {2\ A[89] + B[89] \[ShortRightArrow] 
          3\ A[89], c}, {A[89] \[ShortRightArrow] B[89], 
        b}, {Y[90] \[RightTeeArrow] W[90], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[90] \[RightTeeArrow] W[90], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[90] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[90], ky\ L1[90], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[90], a, 
        beta + d\ \(Y[90]\)[t]}, {2\ A[90] + B[90] \[ShortRightArrow] 
          3\ A[90], c}, {A[90] \[ShortRightArrow] B[90], 
        b}, {Y[91] \[RightTeeArrow] W[91], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[91] \[RightTeeArrow] W[91], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[91] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[91], ky\ L1[91], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[91], a, 
        beta + d\ \(Y[91]\)[t]}, {2\ A[91] + B[91] \[ShortRightArrow] 
          3\ A[91], c}, {A[91] \[ShortRightArrow] B[91], 
        b}, {Y[92] \[RightTeeArrow] W[92], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[92] \[RightTeeArrow] W[92], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[92] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[92], ky\ L1[92], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[92], a, 
        beta + d\ \(Y[92]\)[t]}, {2\ A[92] + B[92] \[ShortRightArrow] 
          3\ A[92], c}, {A[92] \[ShortRightArrow] B[92], 
        b}, {Y[93] \[RightTeeArrow] W[93], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[93] \[RightTeeArrow] W[93], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[93] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[93], ky\ L1[93], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[93], a, 
        beta + d\ \(Y[93]\)[t]}, {2\ A[93] + B[93] \[ShortRightArrow] 
          3\ A[93], c}, {A[93] \[ShortRightArrow] B[93], 
        b}, {Y[94] \[RightTeeArrow] W[94], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[94] \[RightTeeArrow] W[94], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[94] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[94], ky\ L1[94], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[94], a, 
        beta + d\ \(Y[94]\)[t]}, {2\ A[94] + B[94] \[ShortRightArrow] 
          3\ A[94], c}, {A[94] \[ShortRightArrow] B[94], 
        b}, {Y[95] \[RightTeeArrow] W[95], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[95] \[RightTeeArrow] W[95], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[95] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[95], ky\ L1[95], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[95], a, 
        beta + d\ \(Y[95]\)[t]}, {2\ A[95] + B[95] \[ShortRightArrow] 
          3\ A[95], c}, {A[95] \[ShortRightArrow] B[95], 
        b}, {Y[96] \[RightTeeArrow] W[96], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[96] \[RightTeeArrow] W[96], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[96] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[96], ky\ L1[96], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[96], a, 
        beta + d\ \(Y[96]\)[t]}, {2\ A[96] + B[96] \[ShortRightArrow] 
          3\ A[96], c}, {A[96] \[ShortRightArrow] B[96], 
        b}, {Y[97] \[RightTeeArrow] W[97], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[97] \[RightTeeArrow] W[97], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[97] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[97], ky\ L1[97], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[97], a, 
        beta + d\ \(Y[97]\)[t]}, {2\ A[97] + B[97] \[ShortRightArrow] 
          3\ A[97], c}, {A[97] \[ShortRightArrow] B[97], 
        b}, {Y[98] \[RightTeeArrow] W[98], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[98] \[RightTeeArrow] W[98], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[98] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[98], ky\ L1[98], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[98], a, 
        beta + d\ \(Y[98]\)[t]}, {2\ A[98] + B[98] \[ShortRightArrow] 
          3\ A[98], c}, {A[98] \[ShortRightArrow] B[98], 
        b}, {Y[99] \[RightTeeArrow] W[99], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[99] \[RightTeeArrow] W[99], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[99] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[99], ky\ L1[99], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[99], a, 
        beta + d\ \(Y[99]\)[t]}, {2\ A[99] + B[99] \[ShortRightArrow] 
          3\ A[99], c}, {A[99] \[ShortRightArrow] B[99], 
        b}, {Y[100] \[RightTeeArrow] W[100], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[100] \[RightTeeArrow] W[100], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[100] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[100], ky\ L1[100], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[100], a, 
        beta + d\ \(Y[100]\)[t]}, {2\ A[100] + B[100] \[ShortRightArrow] 
          3\ A[100], c}, {A[100] \[ShortRightArrow] B[100], 
        b}, {Y[101] \[RightTeeArrow] W[101], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[101] \[RightTeeArrow] W[101], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[101] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[101], ky\ L1[101], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[101], a, 
        beta + d\ \(Y[101]\)[t]}, {2\ A[101] + B[101] \[ShortRightArrow] 
          3\ A[101], c}, {A[101] \[ShortRightArrow] B[101], 
        b}, {Y[102] \[RightTeeArrow] W[102], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[102] \[RightTeeArrow] W[102], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[102] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[102], ky\ L1[102], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[102], a, 
        beta + d\ \(Y[102]\)[t]}, {2\ A[102] + B[102] \[ShortRightArrow] 
          3\ A[102], c}, {A[102] \[ShortRightArrow] B[102], 
        b}, {Y[103] \[RightTeeArrow] W[103], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[103] \[RightTeeArrow] W[103], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[103] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[103], ky\ L1[103], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[103], a, 
        beta + d\ \(Y[103]\)[t]}, {2\ A[103] + B[103] \[ShortRightArrow] 
          3\ A[103], c}, {A[103] \[ShortRightArrow] B[103], 
        b}, {Y[104] \[RightTeeArrow] W[104], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[104] \[RightTeeArrow] W[104], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[104] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[104], ky\ L1[104], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[104], a, 
        beta + d\ \(Y[104]\)[t]}, {2\ A[104] + B[104] \[ShortRightArrow] 
          3\ A[104], c}, {A[104] \[ShortRightArrow] B[104], 
        b}, {Y[105] \[RightTeeArrow] W[105], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[105] \[RightTeeArrow] W[105], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[105] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[105], ky\ L1[105], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[105], a, 
        beta + d\ \(Y[105]\)[t]}, {2\ A[105] + B[105] \[ShortRightArrow] 
          3\ A[105], c}, {A[105] \[ShortRightArrow] B[105], 
        b}, {Y[106] \[RightTeeArrow] W[106], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[106] \[RightTeeArrow] W[106], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[106] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[106], ky\ L1[106], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[106], a, 
        beta + d\ \(Y[106]\)[t]}, {2\ A[106] + B[106] \[ShortRightArrow] 
          3\ A[106], c}, {A[106] \[ShortRightArrow] B[106], 
        b}, {Y[107] \[RightTeeArrow] W[107], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[107] \[RightTeeArrow] W[107], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[107] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[107], ky\ L1[107], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[107], a, 
        beta + d\ \(Y[107]\)[t]}, {2\ A[107] + B[107] \[ShortRightArrow] 
          3\ A[107], c}, {A[107] \[ShortRightArrow] B[107], 
        b}, {Y[108] \[RightTeeArrow] W[108], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[108] \[RightTeeArrow] W[108], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[108] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[108], ky\ L1[108], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[108], a, 
        beta + d\ \(Y[108]\)[t]}, {2\ A[108] + B[108] \[ShortRightArrow] 
          3\ A[108], c}, {A[108] \[ShortRightArrow] B[108], 
        b}, {Y[109] \[RightTeeArrow] W[109], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[109] \[RightTeeArrow] W[109], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[109] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[109], ky\ L1[109], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[109], a, 
        beta + d\ \(Y[109]\)[t]}, {2\ A[109] + B[109] \[ShortRightArrow] 
          3\ A[109], c}, {A[109] \[ShortRightArrow] B[109], 
        b}, {Y[110] \[RightTeeArrow] W[110], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[110] \[RightTeeArrow] W[110], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[110] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[110], ky\ L1[110], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[110], a, 
        beta + d\ \(Y[110]\)[t]}, {2\ A[110] + B[110] \[ShortRightArrow] 
          3\ A[110], c}, {A[110] \[ShortRightArrow] B[110], 
        b}, {Y[111] \[RightTeeArrow] W[111], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[111] \[RightTeeArrow] W[111], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[111] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[111], ky\ L1[111], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[111], a, 
        beta + d\ \(Y[111]\)[t]}, {2\ A[111] + B[111] \[ShortRightArrow] 
          3\ A[111], c}, {A[111] \[ShortRightArrow] B[111], 
        b}, {Y[112] \[RightTeeArrow] W[112], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[112] \[RightTeeArrow] W[112], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[112] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[112], ky\ L1[112], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[112], a, 
        beta + d\ \(Y[112]\)[t]}, {2\ A[112] + B[112] \[ShortRightArrow] 
          3\ A[112], c}, {A[112] \[ShortRightArrow] B[112], 
        b}, {Y[113] \[RightTeeArrow] W[113], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[113] \[RightTeeArrow] W[113], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[113] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[113], ky\ L1[113], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[113], a, 
        beta + d\ \(Y[113]\)[t]}, {2\ A[113] + B[113] \[ShortRightArrow] 
          3\ A[113], c}, {A[113] \[ShortRightArrow] B[113], 
        b}, {Y[114] \[RightTeeArrow] W[114], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[114] \[RightTeeArrow] W[114], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[114] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[114], ky\ L1[114], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[114], a, 
        beta + d\ \(Y[114]\)[t]}, {2\ A[114] + B[114] \[ShortRightArrow] 
          3\ A[114], c}, {A[114] \[ShortRightArrow] B[114], 
        b}, {Y[115] \[RightTeeArrow] W[115], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[115] \[RightTeeArrow] W[115], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[115] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[115], ky\ L1[115], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[115], a, 
        beta + d\ \(Y[115]\)[t]}, {2\ A[115] + B[115] \[ShortRightArrow] 
          3\ A[115], c}, {A[115] \[ShortRightArrow] B[115], 
        b}, {Y[116] \[RightTeeArrow] W[116], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[116] \[RightTeeArrow] W[116], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[116] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[116], ky\ L1[116], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[116], a, 
        beta + d\ \(Y[116]\)[t]}, {2\ A[116] + B[116] \[ShortRightArrow] 
          3\ A[116], c}, {A[116] \[ShortRightArrow] B[116], 
        b}, {Y[117] \[RightTeeArrow] W[117], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[117] \[RightTeeArrow] W[117], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[117] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[117], ky\ L1[117], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[117], a, 
        beta + d\ \(Y[117]\)[t]}, {2\ A[117] + B[117] \[ShortRightArrow] 
          3\ A[117], c}, {A[117] \[ShortRightArrow] B[117], 
        b}, {Y[118] \[RightTeeArrow] W[118], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[118] \[RightTeeArrow] W[118], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[118] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[118], ky\ L1[118], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[118], a, 
        beta + d\ \(Y[118]\)[t]}, {2\ A[118] + B[118] \[ShortRightArrow] 
          3\ A[118], c}, {A[118] \[ShortRightArrow] B[118], 
        b}, {Y[119] \[RightTeeArrow] W[119], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[119] \[RightTeeArrow] W[119], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[119] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[119], ky\ L1[119], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[119], a, 
        beta + d\ \(Y[119]\)[t]}, {2\ A[119] + B[119] \[ShortRightArrow] 
          3\ A[119], c}, {A[119] \[ShortRightArrow] B[119], 
        b}, {Y[120] \[RightTeeArrow] W[120], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[120] \[RightTeeArrow] W[120], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[120] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[120], ky\ L1[120], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[120], a, 
        beta + d\ \(Y[120]\)[t]}, {2\ A[120] + B[120] \[ShortRightArrow] 
          3\ A[120], c}, {A[120] \[ShortRightArrow] B[120], 
        b}, {Y[121] \[RightTeeArrow] W[121], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[121] \[RightTeeArrow] W[121], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[121] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[121], ky\ L1[121], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[121], a, 
        beta + d\ \(Y[121]\)[t]}, {2\ A[121] + B[121] \[ShortRightArrow] 
          3\ A[121], c}, {A[121] \[ShortRightArrow] B[121], 
        b}, {Y[122] \[RightTeeArrow] W[122], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[122] \[RightTeeArrow] W[122], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[122] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[122], ky\ L1[122], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[122], a, 
        beta + d\ \(Y[122]\)[t]}, {2\ A[122] + B[122] \[ShortRightArrow] 
          3\ A[122], c}, {A[122] \[ShortRightArrow] B[122], 
        b}, {Y[123] \[RightTeeArrow] W[123], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[123] \[RightTeeArrow] W[123], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[123] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[123], ky\ L1[123], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[123], a, 
        beta + d\ \(Y[123]\)[t]}, {2\ A[123] + B[123] \[ShortRightArrow] 
          3\ A[123], c}, {A[123] \[ShortRightArrow] B[123], 
        b}, {Y[124] \[RightTeeArrow] W[124], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[124] \[RightTeeArrow] W[124], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[124] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[124], ky\ L1[124], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[124], a, 
        beta + d\ \(Y[124]\)[t]}, {2\ A[124] + B[124] \[ShortRightArrow] 
          3\ A[124], c}, {A[124] \[ShortRightArrow] B[124], 
        b}, {Y[125] \[RightTeeArrow] W[125], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[125] \[RightTeeArrow] W[125], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[125] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[125], ky\ L1[125], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[125], a, 
        beta + d\ \(Y[125]\)[t]}, {2\ A[125] + B[125] \[ShortRightArrow] 
          3\ A[125], c}, {A[125] \[ShortRightArrow] B[125], 
        b}, {Y[126] \[RightTeeArrow] W[126], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[126] \[RightTeeArrow] W[126], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[126] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[126], ky\ L1[126], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[126], a, 
        beta + d\ \(Y[126]\)[t]}, {2\ A[126] + B[126] \[ShortRightArrow] 
          3\ A[126], c}, {A[126] \[ShortRightArrow] B[126], 
        b}, {Y[127] \[RightTeeArrow] W[127], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[127] \[RightTeeArrow] W[127], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[127] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[127], ky\ L1[127], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[127], a, 
        beta + d\ \(Y[127]\)[t]}, {2\ A[127] + B[127] \[ShortRightArrow] 
          3\ A[127], c}, {A[127] \[ShortRightArrow] B[127], 
        b}, {Y[128] \[RightTeeArrow] W[128], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[128] \[RightTeeArrow] W[128], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[128] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[128], ky\ L1[128], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[128], a, 
        beta + d\ \(Y[128]\)[t]}, {2\ A[128] + B[128] \[ShortRightArrow] 
          3\ A[128], c}, {A[128] \[ShortRightArrow] B[128], 
        b}, {Y[129] \[RightTeeArrow] W[129], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[129] \[RightTeeArrow] W[129], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[129] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[129], ky\ L1[129], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[129], a, 
        beta + d\ \(Y[129]\)[t]}, {2\ A[129] + B[129] \[ShortRightArrow] 
          3\ A[129], c}, {A[129] \[ShortRightArrow] B[129], 
        b}, {Y[130] \[RightTeeArrow] W[130], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[130] \[RightTeeArrow] W[130], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[130] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[130], ky\ L1[130], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[130], a, 
        beta + d\ \(Y[130]\)[t]}, {2\ A[130] + B[130] \[ShortRightArrow] 
          3\ A[130], c}, {A[130] \[ShortRightArrow] B[130], 
        b}, {Y[131] \[RightTeeArrow] W[131], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[131] \[RightTeeArrow] W[131], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[131] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[131], ky\ L1[131], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[131], a, 
        beta + d\ \(Y[131]\)[t]}, {2\ A[131] + B[131] \[ShortRightArrow] 
          3\ A[131], c}, {A[131] \[ShortRightArrow] B[131], 
        b}, {Y[132] \[RightTeeArrow] W[132], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[132] \[RightTeeArrow] W[132], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[132] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[132], ky\ L1[132], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[132], a, 
        beta + d\ \(Y[132]\)[t]}, {2\ A[132] + B[132] \[ShortRightArrow] 
          3\ A[132], c}, {A[132] \[ShortRightArrow] B[132], 
        b}, {Y[133] \[RightTeeArrow] W[133], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[133] \[RightTeeArrow] W[133], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[133] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[133], ky\ L1[133], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[133], a, 
        beta + d\ \(Y[133]\)[t]}, {2\ A[133] + B[133] \[ShortRightArrow] 
          3\ A[133], c}, {A[133] \[ShortRightArrow] B[133], 
        b}, {Y[134] \[RightTeeArrow] W[134], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[134] \[RightTeeArrow] W[134], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[134] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[134], ky\ L1[134], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[134], a, 
        beta + d\ \(Y[134]\)[t]}, {2\ A[134] + B[134] \[ShortRightArrow] 
          3\ A[134], c}, {A[134] \[ShortRightArrow] B[134], 
        b}, {Y[135] \[RightTeeArrow] W[135], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[135] \[RightTeeArrow] W[135], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[135] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[135], ky\ L1[135], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[135], a, 
        beta + d\ \(Y[135]\)[t]}, {2\ A[135] + B[135] \[ShortRightArrow] 
          3\ A[135], c}, {A[135] \[ShortRightArrow] B[135], 
        b}, {Y[136] \[RightTeeArrow] W[136], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[136] \[RightTeeArrow] W[136], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[136] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[136], ky\ L1[136], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[136], a, 
        beta + d\ \(Y[136]\)[t]}, {2\ A[136] + B[136] \[ShortRightArrow] 
          3\ A[136], c}, {A[136] \[ShortRightArrow] B[136], 
        b}, {Y[137] \[RightTeeArrow] W[137], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[137] \[RightTeeArrow] W[137], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[137] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[137], ky\ L1[137], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[137], a, 
        beta + d\ \(Y[137]\)[t]}, {2\ A[137] + B[137] \[ShortRightArrow] 
          3\ A[137], c}, {A[137] \[ShortRightArrow] B[137], 
        b}, {Y[138] \[RightTeeArrow] W[138], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[138] \[RightTeeArrow] W[138], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[138] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[138], ky\ L1[138], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[138], a, 
        beta + d\ \(Y[138]\)[t]}, {2\ A[138] + B[138] \[ShortRightArrow] 
          3\ A[138], c}, {A[138] \[ShortRightArrow] B[138], 
        b}, {Y[139] \[RightTeeArrow] W[139], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[139] \[RightTeeArrow] W[139], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[139] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[139], ky\ L1[139], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[139], a, 
        beta + d\ \(Y[139]\)[t]}, {2\ A[139] + B[139] \[ShortRightArrow] 
          3\ A[139], c}, {A[139] \[ShortRightArrow] B[139], 
        b}, {Y[140] \[RightTeeArrow] W[140], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[140] \[RightTeeArrow] W[140], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[140] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[140], ky\ L1[140], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[140], a, 
        beta + d\ \(Y[140]\)[t]}, {2\ A[140] + B[140] \[ShortRightArrow] 
          3\ A[140], c}, {A[140] \[ShortRightArrow] B[140], 
        b}, {Y[141] \[RightTeeArrow] W[141], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[141] \[RightTeeArrow] W[141], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[141] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[141], ky\ L1[141], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[141], a, 
        beta + d\ \(Y[141]\)[t]}, {2\ A[141] + B[141] \[ShortRightArrow] 
          3\ A[141], c}, {A[141] \[ShortRightArrow] B[141], 
        b}, {Y[142] \[RightTeeArrow] W[142], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[142] \[RightTeeArrow] W[142], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[142] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[142], ky\ L1[142], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[142], a, 
        beta + d\ \(Y[142]\)[t]}, {2\ A[142] + B[142] \[ShortRightArrow] 
          3\ A[142], c}, {A[142] \[ShortRightArrow] B[142], 
        b}, {Y[143] \[RightTeeArrow] W[143], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[143] \[RightTeeArrow] W[143], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[143] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[143], ky\ L1[143], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[143], a, 
        beta + d\ \(Y[143]\)[t]}, {2\ A[143] + B[143] \[ShortRightArrow] 
          3\ A[143], c}, {A[143] \[ShortRightArrow] B[143], 
        b}, {Y[144] \[RightTeeArrow] W[144], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[144] \[RightTeeArrow] W[144], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[144] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[144], ky\ L1[144], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[144], a, 
        beta + d\ \(Y[144]\)[t]}, {2\ A[144] + B[144] \[ShortRightArrow] 
          3\ A[144], c}, {A[144] \[ShortRightArrow] B[144], 
        b}, {Y[145] \[RightTeeArrow] W[145], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[145] \[RightTeeArrow] W[145], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[145] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[145], ky\ L1[145], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[145], a, 
        beta + d\ \(Y[145]\)[t]}, {2\ A[145] + B[145] \[ShortRightArrow] 
          3\ A[145], c}, {A[145] \[ShortRightArrow] B[145], 
        b}, {Y[146] \[RightTeeArrow] W[146], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[146] \[RightTeeArrow] W[146], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[146] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[146], ky\ L1[146], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[146], a, 
        beta + d\ \(Y[146]\)[t]}, {2\ A[146] + B[146] \[ShortRightArrow] 
          3\ A[146], c}, {A[146] \[ShortRightArrow] B[146], 
        b}, {Y[147] \[RightTeeArrow] W[147], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[147] \[RightTeeArrow] W[147], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[147] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[147], ky\ L1[147], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[147], a, 
        beta + d\ \(Y[147]\)[t]}, {2\ A[147] + B[147] \[ShortRightArrow] 
          3\ A[147], c}, {A[147] \[ShortRightArrow] B[147], 
        b}, {Y[148] \[RightTeeArrow] W[148], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[148] \[RightTeeArrow] W[148], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[148] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[148], ky\ L1[148], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[148], a, 
        beta + d\ \(Y[148]\)[t]}, {2\ A[148] + B[148] \[ShortRightArrow] 
          3\ A[148], c}, {A[148] \[ShortRightArrow] B[148], 
        b}, {Y[149] \[RightTeeArrow] W[149], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[149] \[RightTeeArrow] W[149], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[149] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[149], ky\ L1[149], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[149], a, 
        beta + d\ \(Y[149]\)[t]}, {2\ A[149] + B[149] \[ShortRightArrow] 
          3\ A[149], c}, {A[149] \[ShortRightArrow] B[149], 
        b}, {Y[150] \[RightTeeArrow] W[150], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[150] \[RightTeeArrow] W[150], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[150] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[150], ky\ L1[150], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[150], a, 
        beta + d\ \(Y[150]\)[t]}, {2\ A[150] + B[150] \[ShortRightArrow] 
          3\ A[150], c}, {A[150] \[ShortRightArrow] B[150], 
        b}, {Y[151] \[RightTeeArrow] W[151], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[151] \[RightTeeArrow] W[151], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[151] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[151], ky\ L1[151], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[151], a, 
        beta + d\ \(Y[151]\)[t]}, {2\ A[151] + B[151] \[ShortRightArrow] 
          3\ A[151], c}, {A[151] \[ShortRightArrow] B[151], 
        b}, {Y[152] \[RightTeeArrow] W[152], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[152] \[RightTeeArrow] W[152], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[152] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[152], ky\ L1[152], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[152], a, 
        beta + d\ \(Y[152]\)[t]}, {2\ A[152] + B[152] \[ShortRightArrow] 
          3\ A[152], c}, {A[152] \[ShortRightArrow] B[152], 
        b}, {Y[153] \[RightTeeArrow] W[153], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[153] \[RightTeeArrow] W[153], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[153] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[153], ky\ L1[153], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[153], a, 
        beta + d\ \(Y[153]\)[t]}, {2\ A[153] + B[153] \[ShortRightArrow] 
          3\ A[153], c}, {A[153] \[ShortRightArrow] B[153], 
        b}, {Y[154] \[RightTeeArrow] W[154], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[154] \[RightTeeArrow] W[154], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[154] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[154], ky\ L1[154], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[154], a, 
        beta + d\ \(Y[154]\)[t]}, {2\ A[154] + B[154] \[ShortRightArrow] 
          3\ A[154], c}, {A[154] \[ShortRightArrow] B[154], 
        b}, {Y[155] \[RightTeeArrow] W[155], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[155] \[RightTeeArrow] W[155], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[155] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[155], ky\ L1[155], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[155], a, 
        beta + d\ \(Y[155]\)[t]}, {2\ A[155] + B[155] \[ShortRightArrow] 
          3\ A[155], c}, {A[155] \[ShortRightArrow] B[155], 
        b}, {Y[156] \[RightTeeArrow] W[156], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[156] \[RightTeeArrow] W[156], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[156] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[156], ky\ L1[156], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[156], a, 
        beta + d\ \(Y[156]\)[t]}, {2\ A[156] + B[156] \[ShortRightArrow] 
          3\ A[156], c}, {A[156] \[ShortRightArrow] B[156], 
        b}, {Y[157] \[RightTeeArrow] W[157], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[157] \[RightTeeArrow] W[157], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[157] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[157], ky\ L1[157], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[157], a, 
        beta + d\ \(Y[157]\)[t]}, {2\ A[157] + B[157] \[ShortRightArrow] 
          3\ A[157], c}, {A[157] \[ShortRightArrow] B[157], 
        b}, {Y[158] \[RightTeeArrow] W[158], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[158] \[RightTeeArrow] W[158], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[158] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[158], ky\ L1[158], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[158], a, 
        beta + d\ \(Y[158]\)[t]}, {2\ A[158] + B[158] \[ShortRightArrow] 
          3\ A[158], c}, {A[158] \[ShortRightArrow] B[158], 
        b}, {Y[159] \[RightTeeArrow] W[159], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[159] \[RightTeeArrow] W[159], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[159] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[159], ky\ L1[159], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[159], a, 
        beta + d\ \(Y[159]\)[t]}, {2\ A[159] + B[159] \[ShortRightArrow] 
          3\ A[159], c}, {A[159] \[ShortRightArrow] B[159], 
        b}, {Y[160] \[RightTeeArrow] W[160], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[160] \[RightTeeArrow] W[160], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[160] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[160], ky\ L1[160], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[160], a, 
        beta + d\ \(Y[160]\)[t]}, {2\ A[160] + B[160] \[ShortRightArrow] 
          3\ A[160], c}, {A[160] \[ShortRightArrow] B[160], 
        b}, {Y[161] \[RightTeeArrow] W[161], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[161] \[RightTeeArrow] W[161], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[161] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[161], ky\ L1[161], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[161], a, 
        beta + d\ \(Y[161]\)[t]}, {2\ A[161] + B[161] \[ShortRightArrow] 
          3\ A[161], c}, {A[161] \[ShortRightArrow] B[161], 
        b}, {Y[162] \[RightTeeArrow] W[162], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[162] \[RightTeeArrow] W[162], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[162] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[162], ky\ L1[162], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[162], a, 
        beta + d\ \(Y[162]\)[t]}, {2\ A[162] + B[162] \[ShortRightArrow] 
          3\ A[162], c}, {A[162] \[ShortRightArrow] B[162], 
        b}, {Y[163] \[RightTeeArrow] W[163], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[163] \[RightTeeArrow] W[163], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[163] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[163], ky\ L1[163], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[163], a, 
        beta + d\ \(Y[163]\)[t]}, {2\ A[163] + B[163] \[ShortRightArrow] 
          3\ A[163], c}, {A[163] \[ShortRightArrow] B[163], 
        b}, {Y[164] \[RightTeeArrow] W[164], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[164] \[RightTeeArrow] W[164], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[164] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[164], ky\ L1[164], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[164], a, 
        beta + d\ \(Y[164]\)[t]}, {2\ A[164] + B[164] \[ShortRightArrow] 
          3\ A[164], c}, {A[164] \[ShortRightArrow] B[164], 
        b}, {Y[165] \[RightTeeArrow] W[165], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[165] \[RightTeeArrow] W[165], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[165] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[165], ky\ L1[165], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[165], a, 
        beta + d\ \(Y[165]\)[t]}, {2\ A[165] + B[165] \[ShortRightArrow] 
          3\ A[165], c}, {A[165] \[ShortRightArrow] B[165], 
        b}, {Y[166] \[RightTeeArrow] W[166], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[166] \[RightTeeArrow] W[166], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[166] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[166], ky\ L1[166], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[166], a, 
        beta + d\ \(Y[166]\)[t]}, {2\ A[166] + B[166] \[ShortRightArrow] 
          3\ A[166], c}, {A[166] \[ShortRightArrow] B[166], 
        b}, {Y[167] \[RightTeeArrow] W[167], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[167] \[RightTeeArrow] W[167], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[167] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[167], ky\ L1[167], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[167], a, 
        beta + d\ \(Y[167]\)[t]}, {2\ A[167] + B[167] \[ShortRightArrow] 
          3\ A[167], c}, {A[167] \[ShortRightArrow] B[167], 
        b}, {Y[168] \[RightTeeArrow] W[168], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[168] \[RightTeeArrow] W[168], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[168] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[168], ky\ L1[168], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[168], a, 
        beta + d\ \(Y[168]\)[t]}, {2\ A[168] + B[168] \[ShortRightArrow] 
          3\ A[168], c}, {A[168] \[ShortRightArrow] B[168], 
        b}, {Y[169] \[RightTeeArrow] W[169], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[169] \[RightTeeArrow] W[169], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[169] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[169], ky\ L1[169], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[169], a, 
        beta + d\ \(Y[169]\)[t]}, {2\ A[169] + B[169] \[ShortRightArrow] 
          3\ A[169], c}, {A[169] \[ShortRightArrow] B[169], 
        b}, {Y[170] \[RightTeeArrow] W[170], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[170] \[RightTeeArrow] W[170], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[170] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[170], ky\ L1[170], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[170], a, 
        beta + d\ \(Y[170]\)[t]}, {2\ A[170] + B[170] \[ShortRightArrow] 
          3\ A[170], c}, {A[170] \[ShortRightArrow] B[170], 
        b}, {Y[171] \[RightTeeArrow] W[171], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[171] \[RightTeeArrow] W[171], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[171] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[171], ky\ L1[171], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[171], a, 
        beta + d\ \(Y[171]\)[t]}, {2\ A[171] + B[171] \[ShortRightArrow] 
          3\ A[171], c}, {A[171] \[ShortRightArrow] B[171], 
        b}, {Y[172] \[RightTeeArrow] W[172], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[172] \[RightTeeArrow] W[172], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[172] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[172], ky\ L1[172], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[172], a, 
        beta + d\ \(Y[172]\)[t]}, {2\ A[172] + B[172] \[ShortRightArrow] 
          3\ A[172], c}, {A[172] \[ShortRightArrow] B[172], 
        b}, {Y[173] \[RightTeeArrow] W[173], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[173] \[RightTeeArrow] W[173], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[173] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[173], ky\ L1[173], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[173], a, 
        beta + d\ \(Y[173]\)[t]}, {2\ A[173] + B[173] \[ShortRightArrow] 
          3\ A[173], c}, {A[173] \[ShortRightArrow] B[173], 
        b}, {Y[174] \[RightTeeArrow] W[174], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[174] \[RightTeeArrow] W[174], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[174] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[174], ky\ L1[174], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[174], a, 
        beta + d\ \(Y[174]\)[t]}, {2\ A[174] + B[174] \[ShortRightArrow] 
          3\ A[174], c}, {A[174] \[ShortRightArrow] B[174], 
        b}, {Y[175] \[RightTeeArrow] W[175], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[175] \[RightTeeArrow] W[175], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[175] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[175], ky\ L1[175], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[175], a, 
        beta + d\ \(Y[175]\)[t]}, {2\ A[175] + B[175] \[ShortRightArrow] 
          3\ A[175], c}, {A[175] \[ShortRightArrow] B[175], 
        b}, {Y[176] \[RightTeeArrow] W[176], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[176] \[RightTeeArrow] W[176], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[176] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[176], ky\ L1[176], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[176], a, 
        beta + d\ \(Y[176]\)[t]}, {2\ A[176] + B[176] \[ShortRightArrow] 
          3\ A[176], c}, {A[176] \[ShortRightArrow] B[176], 
        b}, {Y[177] \[RightTeeArrow] W[177], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[177] \[RightTeeArrow] W[177], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[177] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[177], ky\ L1[177], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[177], a, 
        beta + d\ \(Y[177]\)[t]}, {2\ A[177] + B[177] \[ShortRightArrow] 
          3\ A[177], c}, {A[177] \[ShortRightArrow] B[177], 
        b}, {Y[178] \[RightTeeArrow] W[178], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[178] \[RightTeeArrow] W[178], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[178] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[178], ky\ L1[178], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[178], a, 
        beta + d\ \(Y[178]\)[t]}, {2\ A[178] + B[178] \[ShortRightArrow] 
          3\ A[178], c}, {A[178] \[ShortRightArrow] B[178], 
        b}, {Y[179] \[RightTeeArrow] W[179], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[179] \[RightTeeArrow] W[179], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[179] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[179], ky\ L1[179], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[179], a, 
        beta + d\ \(Y[179]\)[t]}, {2\ A[179] + B[179] \[ShortRightArrow] 
          3\ A[179], c}, {A[179] \[ShortRightArrow] B[179], 
        b}, {Y[180] \[RightTeeArrow] W[180], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[180] \[RightTeeArrow] W[180], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[180] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[180], ky\ L1[180], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[180], a, 
        beta + d\ \(Y[180]\)[t]}, {2\ A[180] + B[180] \[ShortRightArrow] 
          3\ A[180], c}, {A[180] \[ShortRightArrow] B[180], 
        b}, {Y[181] \[RightTeeArrow] W[181], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[181] \[RightTeeArrow] W[181], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[181] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[181], ky\ L1[181], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[181], a, 
        beta + d\ \(Y[181]\)[t]}, {2\ A[181] + B[181] \[ShortRightArrow] 
          3\ A[181], c}, {A[181] \[ShortRightArrow] B[181], 
        b}, {Y[182] \[RightTeeArrow] W[182], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[182] \[RightTeeArrow] W[182], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[182] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[182], ky\ L1[182], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[182], a, 
        beta + d\ \(Y[182]\)[t]}, {2\ A[182] + B[182] \[ShortRightArrow] 
          3\ A[182], c}, {A[182] \[ShortRightArrow] B[182], 
        b}, {Y[183] \[RightTeeArrow] W[183], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[183] \[RightTeeArrow] W[183], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[183] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[183], ky\ L1[183], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[183], a, 
        beta + d\ \(Y[183]\)[t]}, {2\ A[183] + B[183] \[ShortRightArrow] 
          3\ A[183], c}, {A[183] \[ShortRightArrow] B[183], 
        b}, {Y[184] \[RightTeeArrow] W[184], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[184] \[RightTeeArrow] W[184], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[184] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[184], ky\ L1[184], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[184], a, 
        beta + d\ \(Y[184]\)[t]}, {2\ A[184] + B[184] \[ShortRightArrow] 
          3\ A[184], c}, {A[184] \[ShortRightArrow] B[184], 
        b}, {Y[185] \[RightTeeArrow] W[185], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[185] \[RightTeeArrow] W[185], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[185] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[185], ky\ L1[185], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[185], a, 
        beta + d\ \(Y[185]\)[t]}, {2\ A[185] + B[185] \[ShortRightArrow] 
          3\ A[185], c}, {A[185] \[ShortRightArrow] B[185], 
        b}, {Y[186] \[RightTeeArrow] W[186], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[186] \[RightTeeArrow] W[186], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[186] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[186], ky\ L1[186], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[186], a, 
        beta + d\ \(Y[186]\)[t]}, {2\ A[186] + B[186] \[ShortRightArrow] 
          3\ A[186], c}, {A[186] \[ShortRightArrow] B[186], 
        b}, {Y[187] \[RightTeeArrow] W[187], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[187] \[RightTeeArrow] W[187], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[187] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[187], ky\ L1[187], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[187], a, 
        beta + d\ \(Y[187]\)[t]}, {2\ A[187] + B[187] \[ShortRightArrow] 
          3\ A[187], c}, {A[187] \[ShortRightArrow] B[187], 
        b}, {Y[188] \[RightTeeArrow] W[188], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[188] \[RightTeeArrow] W[188], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[188] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[188], ky\ L1[188], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[188], a, 
        beta + d\ \(Y[188]\)[t]}, {2\ A[188] + B[188] \[ShortRightArrow] 
          3\ A[188], c}, {A[188] \[ShortRightArrow] B[188], 
        b}, {Y[189] \[RightTeeArrow] W[189], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[189] \[RightTeeArrow] W[189], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[189] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[189], ky\ L1[189], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[189], a, 
        beta + d\ \(Y[189]\)[t]}, {2\ A[189] + B[189] \[ShortRightArrow] 
          3\ A[189], c}, {A[189] \[ShortRightArrow] B[189], 
        b}, {Y[190] \[RightTeeArrow] W[190], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[190] \[RightTeeArrow] W[190], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[190] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[190], ky\ L1[190], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[190], a, 
        beta + d\ \(Y[190]\)[t]}, {2\ A[190] + B[190] \[ShortRightArrow] 
          3\ A[190], c}, {A[190] \[ShortRightArrow] B[190], 
        b}, {Y[191] \[RightTeeArrow] W[191], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[191] \[RightTeeArrow] W[191], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[191] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[191], ky\ L1[191], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[191], a, 
        beta + d\ \(Y[191]\)[t]}, {2\ A[191] + B[191] \[ShortRightArrow] 
          3\ A[191], c}, {A[191] \[ShortRightArrow] B[191], 
        b}, {Y[192] \[RightTeeArrow] W[192], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[192] \[RightTeeArrow] W[192], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[192] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[192], ky\ L1[192], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[192], a, 
        beta + d\ \(Y[192]\)[t]}, {2\ A[192] + B[192] \[ShortRightArrow] 
          3\ A[192], c}, {A[192] \[ShortRightArrow] B[192], 
        b}, {Y[193] \[RightTeeArrow] W[193], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[193] \[RightTeeArrow] W[193], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[193] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[193], ky\ L1[193], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[193], a, 
        beta + d\ \(Y[193]\)[t]}, {2\ A[193] + B[193] \[ShortRightArrow] 
          3\ A[193], c}, {A[193] \[ShortRightArrow] B[193], 
        b}, {Y[194] \[RightTeeArrow] W[194], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[194] \[RightTeeArrow] W[194], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[194] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[194], ky\ L1[194], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[194], a, 
        beta + d\ \(Y[194]\)[t]}, {2\ A[194] + B[194] \[ShortRightArrow] 
          3\ A[194], c}, {A[194] \[ShortRightArrow] B[194], 
        b}, {Y[195] \[RightTeeArrow] W[195], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[195] \[RightTeeArrow] W[195], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[195] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[195], ky\ L1[195], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[195], a, 
        beta + d\ \(Y[195]\)[t]}, {2\ A[195] + B[195] \[ShortRightArrow] 
          3\ A[195], c}, {A[195] \[ShortRightArrow] B[195], 
        b}, {Y[196] \[RightTeeArrow] W[196], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[196] \[RightTeeArrow] W[196], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[196] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[196], ky\ L1[196], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[196], a, 
        beta + d\ \(Y[196]\)[t]}, {2\ A[196] + B[196] \[ShortRightArrow] 
          3\ A[196], c}, {A[196] \[ShortRightArrow] B[196], 
        b}, {Y[197] \[RightTeeArrow] W[197], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[197] \[RightTeeArrow] W[197], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[197] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[197], ky\ L1[197], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[197], a, 
        beta + d\ \(Y[197]\)[t]}, {2\ A[197] + B[197] \[ShortRightArrow] 
          3\ A[197], c}, {A[197] \[ShortRightArrow] B[197], 
        b}, {Y[198] \[RightTeeArrow] W[198], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[198] \[RightTeeArrow] W[198], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[198] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[198], ky\ L1[198], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[198], a, 
        beta + d\ \(Y[198]\)[t]}, {2\ A[198] + B[198] \[ShortRightArrow] 
          3\ A[198], c}, {A[198] \[ShortRightArrow] B[198], 
        b}, {Y[199] \[RightTeeArrow] W[199], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[199] \[RightTeeArrow] W[199], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[199] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[199], ky\ L1[199], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[199], a, 
        beta + d\ \(Y[199]\)[t]}, {2\ A[199] + B[199] \[ShortRightArrow] 
          3\ A[199], c}, {A[199] \[ShortRightArrow] B[199], 
        b}, {Y[200] \[RightTeeArrow] W[200], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[200] \[RightTeeArrow] W[200], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[200] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[200], ky\ L1[200], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[200], a, 
        beta + d\ \(Y[200]\)[t]}, {2\ A[200] + B[200] \[ShortRightArrow] 
          3\ A[200], c}, {A[200] \[ShortRightArrow] B[200], 
        b}, {Y[201] \[RightTeeArrow] W[201], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[201] \[RightTeeArrow] W[201], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[201] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[201], ky\ L1[201], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[201], a, 
        beta + d\ \(Y[201]\)[t]}, {2\ A[201] + B[201] \[ShortRightArrow] 
          3\ A[201], c}, {A[201] \[ShortRightArrow] B[201], 
        b}, {Y[202] \[RightTeeArrow] W[202], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[202] \[RightTeeArrow] W[202], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[202] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[202], ky\ L1[202], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[202], a, 
        beta + d\ \(Y[202]\)[t]}, {2\ A[202] + B[202] \[ShortRightArrow] 
          3\ A[202], c}, {A[202] \[ShortRightArrow] B[202], 
        b}, {Y[203] \[RightTeeArrow] W[203], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[203] \[RightTeeArrow] W[203], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[203] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[203], ky\ L1[203], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[203], a, 
        beta + d\ \(Y[203]\)[t]}, {2\ A[203] + B[203] \[ShortRightArrow] 
          3\ A[203], c}, {A[203] \[ShortRightArrow] B[203], 
        b}, {Y[204] \[RightTeeArrow] W[204], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[204] \[RightTeeArrow] W[204], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[204] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[204], ky\ L1[204], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[204], a, 
        beta + d\ \(Y[204]\)[t]}, {2\ A[204] + B[204] \[ShortRightArrow] 
          3\ A[204], c}, {A[204] \[ShortRightArrow] B[204], 
        b}, {Y[205] \[RightTeeArrow] W[205], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[205] \[RightTeeArrow] W[205], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[205] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[205], ky\ L1[205], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[205], a, 
        beta + d\ \(Y[205]\)[t]}, {2\ A[205] + B[205] \[ShortRightArrow] 
          3\ A[205], c}, {A[205] \[ShortRightArrow] B[205], 
        b}, {Y[206] \[RightTeeArrow] W[206], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[206] \[RightTeeArrow] W[206], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[206] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[206], ky\ L1[206], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[206], a, 
        beta + d\ \(Y[206]\)[t]}, {2\ A[206] + B[206] \[ShortRightArrow] 
          3\ A[206], c}, {A[206] \[ShortRightArrow] B[206], 
        b}, {Y[207] \[RightTeeArrow] W[207], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[207] \[RightTeeArrow] W[207], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[207] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[207], ky\ L1[207], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[207], a, 
        beta + d\ \(Y[207]\)[t]}, {2\ A[207] + B[207] \[ShortRightArrow] 
          3\ A[207], c}, {A[207] \[ShortRightArrow] B[207], 
        b}, {Y[208] \[RightTeeArrow] W[208], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[208] \[RightTeeArrow] W[208], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[208] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[208], ky\ L1[208], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[208], a, 
        beta + d\ \(Y[208]\)[t]}, {2\ A[208] + B[208] \[ShortRightArrow] 
          3\ A[208], c}, {A[208] \[ShortRightArrow] B[208], 
        b}, {Y[209] \[RightTeeArrow] W[209], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[209] \[RightTeeArrow] W[209], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[209] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[209], ky\ L1[209], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[209], a, 
        beta + d\ \(Y[209]\)[t]}, {2\ A[209] + B[209] \[ShortRightArrow] 
          3\ A[209], c}, {A[209] \[ShortRightArrow] B[209], 
        b}, {Y[210] \[RightTeeArrow] W[210], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[210] \[RightTeeArrow] W[210], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[210] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[210], ky\ L1[210], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[210], a, 
        beta + d\ \(Y[210]\)[t]}, {2\ A[210] + B[210] \[ShortRightArrow] 
          3\ A[210], c}, {A[210] \[ShortRightArrow] B[210], 
        b}, {Y[211] \[RightTeeArrow] W[211], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[211] \[RightTeeArrow] W[211], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[211] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[211], ky\ L1[211], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[211], a, 
        beta + d\ \(Y[211]\)[t]}, {2\ A[211] + B[211] \[ShortRightArrow] 
          3\ A[211], c}, {A[211] \[ShortRightArrow] B[211], 
        b}, {Y[212] \[RightTeeArrow] W[212], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[212] \[RightTeeArrow] W[212], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[212] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[212], ky\ L1[212], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[212], a, 
        beta + d\ \(Y[212]\)[t]}, {2\ A[212] + B[212] \[ShortRightArrow] 
          3\ A[212], c}, {A[212] \[ShortRightArrow] B[212], 
        b}, {Y[213] \[RightTeeArrow] W[213], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[213] \[RightTeeArrow] W[213], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[213] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[213], ky\ L1[213], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[213], a, 
        beta + d\ \(Y[213]\)[t]}, {2\ A[213] + B[213] \[ShortRightArrow] 
          3\ A[213], c}, {A[213] \[ShortRightArrow] B[213], 
        b}, {Y[214] \[RightTeeArrow] W[214], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[214] \[RightTeeArrow] W[214], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[214] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[214], ky\ L1[214], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[214], a, 
        beta + d\ \(Y[214]\)[t]}, {2\ A[214] + B[214] \[ShortRightArrow] 
          3\ A[214], c}, {A[214] \[ShortRightArrow] B[214], 
        b}, {Y[215] \[RightTeeArrow] W[215], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[215] \[RightTeeArrow] W[215], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[215] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[215], ky\ L1[215], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[215], a, 
        beta + d\ \(Y[215]\)[t]}, {2\ A[215] + B[215] \[ShortRightArrow] 
          3\ A[215], c}, {A[215] \[ShortRightArrow] B[215], 
        b}, {Y[216] \[RightTeeArrow] W[216], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[216] \[RightTeeArrow] W[216], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[216] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[216], ky\ L1[216], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[216], a, 
        beta + d\ \(Y[216]\)[t]}, {2\ A[216] + B[216] \[ShortRightArrow] 
          3\ A[216], c}, {A[216] \[ShortRightArrow] B[216], 
        b}, {Y[217] \[RightTeeArrow] W[217], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[217] \[RightTeeArrow] W[217], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[217] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[217], ky\ L1[217], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[217], a, 
        beta + d\ \(Y[217]\)[t]}, {2\ A[217] + B[217] \[ShortRightArrow] 
          3\ A[217], c}, {A[217] \[ShortRightArrow] B[217], 
        b}, {Y[218] \[RightTeeArrow] W[218], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[218] \[RightTeeArrow] W[218], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[218] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[218], ky\ L1[218], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[218], a, 
        beta + d\ \(Y[218]\)[t]}, {2\ A[218] + B[218] \[ShortRightArrow] 
          3\ A[218], c}, {A[218] \[ShortRightArrow] B[218], 
        b}, {Y[219] \[RightTeeArrow] W[219], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[219] \[RightTeeArrow] W[219], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[219] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[219], ky\ L1[219], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[219], a, 
        beta + d\ \(Y[219]\)[t]}, {2\ A[219] + B[219] \[ShortRightArrow] 
          3\ A[219], c}, {A[219] \[ShortRightArrow] B[219], 
        b}, {Y[220] \[RightTeeArrow] W[220], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[220] \[RightTeeArrow] W[220], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[220] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[220], ky\ L1[220], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[220], a, 
        beta + d\ \(Y[220]\)[t]}, {2\ A[220] + B[220] \[ShortRightArrow] 
          3\ A[220], c}, {A[220] \[ShortRightArrow] B[220], 
        b}, {Y[221] \[RightTeeArrow] W[221], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[221] \[RightTeeArrow] W[221], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[221] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[221], ky\ L1[221], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[221], a, 
        beta + d\ \(Y[221]\)[t]}, {2\ A[221] + B[221] \[ShortRightArrow] 
          3\ A[221], c}, {A[221] \[ShortRightArrow] B[221], 
        b}, {Y[222] \[RightTeeArrow] W[222], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[222] \[RightTeeArrow] W[222], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[222] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[222], ky\ L1[222], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[222], a, 
        beta + d\ \(Y[222]\)[t]}, {2\ A[222] + B[222] \[ShortRightArrow] 
          3\ A[222], c}, {A[222] \[ShortRightArrow] B[222], 
        b}, {Y[223] \[RightTeeArrow] W[223], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[223] \[RightTeeArrow] W[223], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[223] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[223], ky\ L1[223], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[223], a, 
        beta + d\ \(Y[223]\)[t]}, {2\ A[223] + B[223] \[ShortRightArrow] 
          3\ A[223], c}, {A[223] \[ShortRightArrow] B[223], 
        b}, {Y[224] \[RightTeeArrow] W[224], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[224] \[RightTeeArrow] W[224], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[224] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[224], ky\ L1[224], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[224], a, 
        beta + d\ \(Y[224]\)[t]}, {2\ A[224] + B[224] \[ShortRightArrow] 
          3\ A[224], c}, {A[224] \[ShortRightArrow] B[224], 
        b}, {Y[225] \[RightTeeArrow] W[225], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[225] \[RightTeeArrow] W[225], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[225] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[225], ky\ L1[225], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[225], a, 
        beta + d\ \(Y[225]\)[t]}, {2\ A[225] + B[225] \[ShortRightArrow] 
          3\ A[225], c}, {A[225] \[ShortRightArrow] B[225], 
        b}, {Y[226] \[RightTeeArrow] W[226], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[226] \[RightTeeArrow] W[226], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[226] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[226], ky\ L1[226], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[226], a, 
        beta + d\ \(Y[226]\)[t]}, {2\ A[226] + B[226] \[ShortRightArrow] 
          3\ A[226], c}, {A[226] \[ShortRightArrow] B[226], 
        b}, {Y[227] \[RightTeeArrow] W[227], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[227] \[RightTeeArrow] W[227], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[227] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[227], ky\ L1[227], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[227], a, 
        beta + d\ \(Y[227]\)[t]}, {2\ A[227] + B[227] \[ShortRightArrow] 
          3\ A[227], c}, {A[227] \[ShortRightArrow] B[227], 
        b}, {Y[228] \[RightTeeArrow] W[228], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[228] \[RightTeeArrow] W[228], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[228] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[228], ky\ L1[228], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[228], a, 
        beta + d\ \(Y[228]\)[t]}, {2\ A[228] + B[228] \[ShortRightArrow] 
          3\ A[228], c}, {A[228] \[ShortRightArrow] B[228], 
        b}, {Y[229] \[RightTeeArrow] W[229], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[229] \[RightTeeArrow] W[229], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[229] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[229], ky\ L1[229], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[229], a, 
        beta + d\ \(Y[229]\)[t]}, {2\ A[229] + B[229] \[ShortRightArrow] 
          3\ A[229], c}, {A[229] \[ShortRightArrow] B[229], 
        b}, {Y[230] \[RightTeeArrow] W[230], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[230] \[RightTeeArrow] W[230], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[230] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[230], ky\ L1[230], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[230], a, 
        beta + d\ \(Y[230]\)[t]}, {2\ A[230] + B[230] \[ShortRightArrow] 
          3\ A[230], c}, {A[230] \[ShortRightArrow] B[230], 
        b}, {Y[231] \[RightTeeArrow] W[231], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[231] \[RightTeeArrow] W[231], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[231] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[231], ky\ L1[231], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[231], a, 
        beta + d\ \(Y[231]\)[t]}, {2\ A[231] + B[231] \[ShortRightArrow] 
          3\ A[231], c}, {A[231] \[ShortRightArrow] B[231], 
        b}, {Y[232] \[RightTeeArrow] W[232], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[232] \[RightTeeArrow] W[232], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[232] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[232], ky\ L1[232], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[232], a, 
        beta + d\ \(Y[232]\)[t]}, {2\ A[232] + B[232] \[ShortRightArrow] 
          3\ A[232], c}, {A[232] \[ShortRightArrow] B[232], 
        b}, {Y[233] \[RightTeeArrow] W[233], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[233] \[RightTeeArrow] W[233], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[233] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[233], ky\ L1[233], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[233], a, 
        beta + d\ \(Y[233]\)[t]}, {2\ A[233] + B[233] \[ShortRightArrow] 
          3\ A[233], c}, {A[233] \[ShortRightArrow] B[233], 
        b}, {Y[234] \[RightTeeArrow] W[234], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[234] \[RightTeeArrow] W[234], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[234] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[234], ky\ L1[234], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[234], a, 
        beta + d\ \(Y[234]\)[t]}, {2\ A[234] + B[234] \[ShortRightArrow] 
          3\ A[234], c}, {A[234] \[ShortRightArrow] B[234], 
        b}, {Y[235] \[RightTeeArrow] W[235], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[235] \[RightTeeArrow] W[235], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[235] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[235], ky\ L1[235], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[235], a, 
        beta + d\ \(Y[235]\)[t]}, {2\ A[235] + B[235] \[ShortRightArrow] 
          3\ A[235], c}, {A[235] \[ShortRightArrow] B[235], 
        b}, {Y[236] \[RightTeeArrow] W[236], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[236] \[RightTeeArrow] W[236], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[236] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[236], ky\ L1[236], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[236], a, 
        beta + d\ \(Y[236]\)[t]}, {2\ A[236] + B[236] \[ShortRightArrow] 
          3\ A[236], c}, {A[236] \[ShortRightArrow] B[236], 
        b}, {Y[237] \[RightTeeArrow] W[237], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[237] \[RightTeeArrow] W[237], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[237] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[237], ky\ L1[237], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[237], a, 
        beta + d\ \(Y[237]\)[t]}, {2\ A[237] + B[237] \[ShortRightArrow] 
          3\ A[237], c}, {A[237] \[ShortRightArrow] B[237], 
        b}, {Y[238] \[RightTeeArrow] W[238], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[238] \[RightTeeArrow] W[238], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[238] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[238], ky\ L1[238], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[238], a, 
        beta + d\ \(Y[238]\)[t]}, {2\ A[238] + B[238] \[ShortRightArrow] 
          3\ A[238], c}, {A[238] \[ShortRightArrow] B[238], 
        b}, {Y[239] \[RightTeeArrow] W[239], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[239] \[RightTeeArrow] W[239], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[239] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[239], ky\ L1[239], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[239], a, 
        beta + d\ \(Y[239]\)[t]}, {2\ A[239] + B[239] \[ShortRightArrow] 
          3\ A[239], c}, {A[239] \[ShortRightArrow] B[239], 
        b}, {Y[240] \[RightTeeArrow] W[240], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[240] \[RightTeeArrow] W[240], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[240] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[240], ky\ L1[240], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[240], a, 
        beta + d\ \(Y[240]\)[t]}, {2\ A[240] + B[240] \[ShortRightArrow] 
          3\ A[240], c}, {A[240] \[ShortRightArrow] B[240], 
        b}, {Y[241] \[RightTeeArrow] W[241], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[241] \[RightTeeArrow] W[241], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[241] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[241], ky\ L1[241], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[241], a, 
        beta + d\ \(Y[241]\)[t]}, {2\ A[241] + B[241] \[ShortRightArrow] 
          3\ A[241], c}, {A[241] \[ShortRightArrow] B[241], 
        b}, {Y[242] \[RightTeeArrow] W[242], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[242] \[RightTeeArrow] W[242], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[242] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[242], ky\ L1[242], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[242], a, 
        beta + d\ \(Y[242]\)[t]}, {2\ A[242] + B[242] \[ShortRightArrow] 
          3\ A[242], c}, {A[242] \[ShortRightArrow] B[242], 
        b}, {Y[243] \[RightTeeArrow] W[243], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[243] \[RightTeeArrow] W[243], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[243] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[243], ky\ L1[243], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[243], a, 
        beta + d\ \(Y[243]\)[t]}, {2\ A[243] + B[243] \[ShortRightArrow] 
          3\ A[243], c}, {A[243] \[ShortRightArrow] B[243], 
        b}, {Y[244] \[RightTeeArrow] W[244], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[244] \[RightTeeArrow] W[244], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[244] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[244], ky\ L1[244], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[244], a, 
        beta + d\ \(Y[244]\)[t]}, {2\ A[244] + B[244] \[ShortRightArrow] 
          3\ A[244], c}, {A[244] \[ShortRightArrow] B[244], 
        b}, {Y[245] \[RightTeeArrow] W[245], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[245] \[RightTeeArrow] W[245], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[245] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[245], ky\ L1[245], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[245], a, 
        beta + d\ \(Y[245]\)[t]}, {2\ A[245] + B[245] \[ShortRightArrow] 
          3\ A[245], c}, {A[245] \[ShortRightArrow] B[245], 
        b}, {Y[246] \[RightTeeArrow] W[246], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[246] \[RightTeeArrow] W[246], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[246] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[246], ky\ L1[246], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[246], a, 
        beta + d\ \(Y[246]\)[t]}, {2\ A[246] + B[246] \[ShortRightArrow] 
          3\ A[246], c}, {A[246] \[ShortRightArrow] B[246], 
        b}, {Y[247] \[RightTeeArrow] W[247], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[247] \[RightTeeArrow] W[247], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[247] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[247], ky\ L1[247], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[247], a, 
        beta + d\ \(Y[247]\)[t]}, {2\ A[247] + B[247] \[ShortRightArrow] 
          3\ A[247], c}, {A[247] \[ShortRightArrow] B[247], 
        b}, {Y[248] \[RightTeeArrow] W[248], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[248] \[RightTeeArrow] W[248], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[248] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[248], ky\ L1[248], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[248], a, 
        beta + d\ \(Y[248]\)[t]}, {2\ A[248] + B[248] \[ShortRightArrow] 
          3\ A[248], c}, {A[248] \[ShortRightArrow] B[248], 
        b}, {Y[249] \[RightTeeArrow] W[249], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[249] \[RightTeeArrow] W[249], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[249] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[249], ky\ L1[249], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[249], a, 
        beta + d\ \(Y[249]\)[t]}, {2\ A[249] + B[249] \[ShortRightArrow] 
          3\ A[249], c}, {A[249] \[ShortRightArrow] B[249], 
        b}, {Y[250] \[RightTeeArrow] W[250], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[250] \[RightTeeArrow] W[250], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[250] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[250], ky\ L1[250], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[250], a, 
        beta + d\ \(Y[250]\)[t]}, {2\ A[250] + B[250] \[ShortRightArrow] 
          3\ A[250], c}, {A[250] \[ShortRightArrow] B[250], 
        b}, {Y[251] \[RightTeeArrow] W[251], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[251] \[RightTeeArrow] W[251], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[251] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[251], ky\ L1[251], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[251], a, 
        beta + d\ \(Y[251]\)[t]}, {2\ A[251] + B[251] \[ShortRightArrow] 
          3\ A[251], c}, {A[251] \[ShortRightArrow] B[251], 
        b}, {Y[252] \[RightTeeArrow] W[252], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[252] \[RightTeeArrow] W[252], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[252] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[252], ky\ L1[252], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[252], a, 
        beta + d\ \(Y[252]\)[t]}, {2\ A[252] + B[252] \[ShortRightArrow] 
          3\ A[252], c}, {A[252] \[ShortRightArrow] B[252], 
        b}, {Y[253] \[RightTeeArrow] W[253], 
        GRN[1\/tauw, Twy, 1, hw, sigma]}, {A[253] \[RightTeeArrow] W[253], 
        GRN[1\/tauw, Twa, 1, hw, 
          sigma]}, {W[253] \[ShortRightArrow] \[EmptySet], 
        dw}, {\[EmptySet] \[RightArrowLeftArrow] Y[253], ky\ L1[253], 
        dy}, {\[EmptySet] \[RightArrowLeftArrow] A[253], a, 
        beta + d\ \(Y[253]\)[t]}, {2\ A[253] + B[253] \[ShortRightArrow] 
          3\ A[253], c}, {A[253] \[ShortRightArrow] B[253], 
        b}, {A[1] \[ShortRightArrow] A[2], 
        Da}, {A[1] \[ShortRightArrow] A[3], 
        Da}, {A[1] \[ShortRightArrow] A[8], 
        Da}, {A[2] \[ShortRightArrow] A[1], 
        Da}, {A[2] \[ShortRightArrow] A[4], 
        Da}, {A[2] \[ShortRightArrow] A[5], 
        Da}, {A[2] \[ShortRightArrow] A[8], 
        Da}, {A[3] \[ShortRightArrow] A[1], 
        Da}, {A[3] \[ShortRightArrow] A[6], 
        Da}, {A[3] \[ShortRightArrow] A[7], 
        Da}, {A[3] \[ShortRightArrow] A[8], 
        Da}, {A[4] \[ShortRightArrow] A[2], 
        Da}, {A[4] \[ShortRightArrow] A[5], 
        Da}, {A[4] \[ShortRightArrow] A[9], 
        Da}, {A[4] \[ShortRightArrow] A[10], 
        Da}, {A[5] \[ShortRightArrow] A[2], 
        Da}, {A[5] \[ShortRightArrow] A[4], 
        Da}, {A[5] \[ShortRightArrow] A[8], 
        Da}, {A[5] \[ShortRightArrow] A[9], 
        Da}, {A[5] \[ShortRightArrow] A[14], 
        Da}, {A[6] \[ShortRightArrow] A[3], 
        Da}, {A[6] \[ShortRightArrow] A[7], 
        Da}, {A[6] \[ShortRightArrow] A[11], 
        Da}, {A[6] \[ShortRightArrow] A[12], 
        Da}, {A[6] \[ShortRightArrow] A[22], 
        Da}, {A[7] \[ShortRightArrow] A[3], 
        Da}, {A[7] \[ShortRightArrow] A[6], 
        Da}, {A[7] \[ShortRightArrow] A[8], 
        Da}, {A[7] \[ShortRightArrow] A[11], 
        Da}, {A[7] \[ShortRightArrow] A[13], 
        Da}, {A[8] \[ShortRightArrow] A[1], 
        Da}, {A[8] \[ShortRightArrow] A[2], 
        Da}, {A[8] \[ShortRightArrow] A[3], 
        Da}, {A[8] \[ShortRightArrow] A[5], 
        Da}, {A[8] \[ShortRightArrow] A[7], 
        Da}, {A[8] \[ShortRightArrow] A[13], 
        Da}, {A[8] \[ShortRightArrow] A[14], 
        Da}, {A[8] \[ShortRightArrow] A[17], 
        Da}, {A[9] \[ShortRightArrow] A[4], 
        Da}, {A[9] \[ShortRightArrow] A[5], 
        Da}, {A[9] \[ShortRightArrow] A[10], 
        Da}, {A[9] \[ShortRightArrow] A[14], 
        Da}, {A[9] \[ShortRightArrow] A[18], 
        Da}, {A[9] \[ShortRightArrow] A[27], 
        Da}, {A[10] \[ShortRightArrow] A[4], 
        Da}, {A[10] \[ShortRightArrow] A[9], 
        Da}, {A[10] \[ShortRightArrow] A[18], 
        Da}, {A[10] \[ShortRightArrow] A[19], 
        Da}, {A[10] \[ShortRightArrow] A[28], 
        Da}, {A[11] \[ShortRightArrow] A[6], 
        Da}, {A[11] \[ShortRightArrow] A[7], 
        Da}, {A[11] \[ShortRightArrow] A[13], 
        Da}, {A[11] \[ShortRightArrow] A[22], 
        Da}, {A[11] \[ShortRightArrow] A[24], 
        Da}, {A[11] \[ShortRightArrow] A[25], 
        Da}, {A[11] \[ShortRightArrow] A[26], 
        Da}, {A[12] \[ShortRightArrow] A[6], 
        Da}, {A[12] \[ShortRightArrow] A[16], 
        Da}, {A[12] \[ShortRightArrow] A[22], 
        Da}, {A[12] \[ShortRightArrow] A[30], 
        Da}, {A[13] \[ShortRightArrow] A[7], 
        Da}, {A[13] \[ShortRightArrow] A[8], 
        Da}, {A[13] \[ShortRightArrow] A[11], 
        Da}, {A[13] \[ShortRightArrow] A[17], 
        Da}, {A[13] \[ShortRightArrow] A[26], 
        Da}, {A[13] \[ShortRightArrow] A[39], 
        Da}, {A[14] \[ShortRightArrow] A[5], 
        Da}, {A[14] \[ShortRightArrow] A[8], 
        Da}, {A[14] \[ShortRightArrow] A[9], 
        Da}, {A[14] \[ShortRightArrow] A[17], 
        Da}, {A[14] \[ShortRightArrow] A[23], 
        Da}, {A[14] \[ShortRightArrow] A[27], 
        Da}, {A[14] \[ShortRightArrow] A[33], 
        Da}, {A[15] \[ShortRightArrow] A[20], 
        Da}, {A[15] \[ShortRightArrow] A[21], 
        Da}, {A[15] \[ShortRightArrow] A[29], 
        Da}, {A[15] \[ShortRightArrow] A[34], 
        Da}, {A[15] \[ShortRightArrow] A[35], 
        Da}, {A[16] \[ShortRightArrow] A[12], 
        Da}, {A[16] \[ShortRightArrow] A[30], 
        Da}, {A[17] \[ShortRightArrow] A[8], 
        Da}, {A[17] \[ShortRightArrow] A[13], 
        Da}, {A[17] \[ShortRightArrow] A[14], 
        Da}, {A[17] \[ShortRightArrow] A[23], 
        Da}, {A[17] \[ShortRightArrow] A[39], 
        Da}, {A[17] \[ShortRightArrow] A[53], 
        Da}, {A[17] \[ShortRightArrow] A[54], 
        Da}, {A[18] \[ShortRightArrow] A[9], 
        Da}, {A[18] \[ShortRightArrow] A[10], 
        Da}, {A[18] \[ShortRightArrow] A[27], 
        Da}, {A[18] \[ShortRightArrow] A[28], 
        Da}, {A[18] \[ShortRightArrow] A[31], 
        Da}, {A[19] \[ShortRightArrow] A[10], 
        Da}, {A[19] \[ShortRightArrow] A[20], 
        Da}, {A[19] \[ShortRightArrow] A[28], 
        Da}, {A[19] \[ShortRightArrow] A[32], 
        Da}, {A[19] \[ShortRightArrow] A[38], 
        Da}, {A[19] \[ShortRightArrow] A[40], 
        Da}, {A[20] \[ShortRightArrow] A[15], 
        Da}, {A[20] \[ShortRightArrow] A[19], 
        Da}, {A[20] \[ShortRightArrow] A[34], 
        Da}, {A[20] \[ShortRightArrow] A[40], 
        Da}, {A[21] \[ShortRightArrow] A[15], 
        Da}, {A[21] \[ShortRightArrow] A[29], 
        Da}, {A[21] \[ShortRightArrow] A[36], 
        Da}, {A[21] \[ShortRightArrow] A[47], 
        Da}, {A[22] \[ShortRightArrow] A[6], 
        Da}, {A[22] \[ShortRightArrow] A[11], 
        Da}, {A[22] \[ShortRightArrow] A[12], 
        Da}, {A[22] \[ShortRightArrow] A[24], 
        Da}, {A[22] \[ShortRightArrow] A[37], 
        Da}, {A[22] \[ShortRightArrow] A[43], 
        Da}, {A[23] \[ShortRightArrow] A[14], 
        Da}, {A[23] \[ShortRightArrow] A[17], 
        Da}, {A[23] \[ShortRightArrow] A[33], 
        Da}, {A[23] \[ShortRightArrow] A[45], 
        Da}, {A[23] \[ShortRightArrow] A[54], 
        Da}, {A[24] \[ShortRightArrow] A[11], 
        Da}, {A[24] \[ShortRightArrow] A[22], 
        Da}, {A[24] \[ShortRightArrow] A[25], 
        Da}, {A[24] \[ShortRightArrow] A[37], 
        Da}, {A[25] \[ShortRightArrow] A[11], 
        Da}, {A[25] \[ShortRightArrow] A[24], 
        Da}, {A[25] \[ShortRightArrow] A[26], 
        Da}, {A[25] \[ShortRightArrow] A[37], 
        Da}, {A[25] \[ShortRightArrow] A[39], 
        Da}, {A[26] \[ShortRightArrow] A[11], 
        Da}, {A[26] \[ShortRightArrow] A[13], 
        Da}, {A[26] \[ShortRightArrow] A[25], 
        Da}, {A[26] \[ShortRightArrow] A[39], 
        Da}, {A[27] \[ShortRightArrow] A[9], 
        Da}, {A[27] \[ShortRightArrow] A[14], 
        Da}, {A[27] \[ShortRightArrow] A[18], 
        Da}, {A[27] \[ShortRightArrow] A[31], 
        Da}, {A[27] \[ShortRightArrow] A[33], 
        Da}, {A[28] \[ShortRightArrow] A[10], 
        Da}, {A[28] \[ShortRightArrow] A[18], 
        Da}, {A[28] \[ShortRightArrow] A[19], 
        Da}, {A[28] \[ShortRightArrow] A[31], 
        Da}, {A[28] \[ShortRightArrow] A[32], 
        Da}, {A[28] \[ShortRightArrow] A[44], 
        Da}, {A[29] \[ShortRightArrow] A[15], 
        Da}, {A[29] \[ShortRightArrow] A[21], 
        Da}, {A[29] \[ShortRightArrow] A[35], 
        Da}, {A[29] \[ShortRightArrow] A[47], 
        Da}, {A[29] \[ShortRightArrow] A[49], 
        Da}, {A[29] \[ShortRightArrow] A[57], 
        Da}, {A[30] \[ShortRightArrow] A[12], 
        Da}, {A[30] \[ShortRightArrow] A[16], 
        Da}, {A[30] \[ShortRightArrow] A[43], 
        Da}, {A[30] \[ShortRightArrow] A[50], 
        Da}, {A[31] \[ShortRightArrow] A[18], 
        Da}, {A[31] \[ShortRightArrow] A[27], 
        Da}, {A[31] \[ShortRightArrow] A[28], 
        Da}, {A[31] \[ShortRightArrow] A[33], 
        Da}, {A[31] \[ShortRightArrow] A[44], 
        Da}, {A[31] \[ShortRightArrow] A[46], 
        Da}, {A[32] \[ShortRightArrow] A[19], 
        Da}, {A[32] \[ShortRightArrow] A[28], 
        Da}, {A[32] \[ShortRightArrow] A[38], 
        Da}, {A[32] \[ShortRightArrow] A[44], 
        Da}, {A[33] \[ShortRightArrow] A[14], 
        Da}, {A[33] \[ShortRightArrow] A[23], 
        Da}, {A[33] \[ShortRightArrow] A[27], 
        Da}, {A[33] \[ShortRightArrow] A[31], 
        Da}, {A[33] \[ShortRightArrow] A[45], 
        Da}, {A[33] \[ShortRightArrow] A[46], 
        Da}, {A[34] \[ShortRightArrow] A[15], 
        Da}, {A[34] \[ShortRightArrow] A[20], 
        Da}, {A[34] \[ShortRightArrow] A[35], 
        Da}, {A[34] \[ShortRightArrow] A[40], 
        Da}, {A[34] \[ShortRightArrow] A[41], 
        Da}, {A[34] \[ShortRightArrow] A[51], 
        Da}, {A[34] \[ShortRightArrow] A[52], 
        Da}, {A[35] \[ShortRightArrow] A[15], 
        Da}, {A[35] \[ShortRightArrow] A[29], 
        Da}, {A[35] \[ShortRightArrow] A[34], 
        Da}, {A[35] \[ShortRightArrow] A[41], 
        Da}, {A[35] \[ShortRightArrow] A[57], 
        Da}, {A[35] \[ShortRightArrow] A[60], 
        Da}, {A[36] \[ShortRightArrow] A[21], 
        Da}, {A[36] \[ShortRightArrow] A[42], 
        Da}, {A[36] \[ShortRightArrow] A[47], 
        Da}, {A[36] \[ShortRightArrow] A[48], 
        Da}, {A[37] \[ShortRightArrow] A[22], 
        Da}, {A[37] \[ShortRightArrow] A[24], 
        Da}, {A[37] \[ShortRightArrow] A[25], 
        Da}, {A[37] \[ShortRightArrow] A[39], 
        Da}, {A[37] \[ShortRightArrow] A[43], 
        Da}, {A[37] \[ShortRightArrow] A[59], 
        Da}, {A[38] \[ShortRightArrow] A[19], 
        Da}, {A[38] \[ShortRightArrow] A[32], 
        Da}, {A[38] \[ShortRightArrow] A[40], 
        Da}, {A[38] \[ShortRightArrow] A[44], 
        Da}, {A[38] \[ShortRightArrow] A[56], 
        Da}, {A[38] \[ShortRightArrow] A[67], 
        Da}, {A[39] \[ShortRightArrow] A[13], 
        Da}, {A[39] \[ShortRightArrow] A[17], 
        Da}, {A[39] \[ShortRightArrow] A[25], 
        Da}, {A[39] \[ShortRightArrow] A[26], 
        Da}, {A[39] \[ShortRightArrow] A[37], 
        Da}, {A[39] \[ShortRightArrow] A[53], 
        Da}, {A[39] \[ShortRightArrow] A[59], 
        Da}, {A[39] \[ShortRightArrow] A[65], 
        Da}, {A[40] \[ShortRightArrow] A[19], 
        Da}, {A[40] \[ShortRightArrow] A[20], 
        Da}, {A[40] \[ShortRightArrow] A[34], 
        Da}, {A[40] \[ShortRightArrow] A[38], 
        Da}, {A[40] \[ShortRightArrow] A[51], 
        Da}, {A[40] \[ShortRightArrow] A[56], 
        Da}, {A[41] \[ShortRightArrow] A[34], 
        Da}, {A[41] \[ShortRightArrow] A[35], 
        Da}, {A[41] \[ShortRightArrow] A[52], 
        Da}, {A[41] \[ShortRightArrow] A[60], 
        Da}, {A[42] \[ShortRightArrow] A[36], 
        Da}, {A[42] \[ShortRightArrow] A[48], 
        Da}, {A[42] \[ShortRightArrow] A[58], 
        Da}, {A[43] \[ShortRightArrow] A[22], 
        Da}, {A[43] \[ShortRightArrow] A[30], 
        Da}, {A[43] \[ShortRightArrow] A[37], 
        Da}, {A[43] \[ShortRightArrow] A[50], 
        Da}, {A[43] \[ShortRightArrow] A[59], 
        Da}, {A[43] \[ShortRightArrow] A[61], 
        Da}, {A[43] \[ShortRightArrow] A[64], 
        Da}, {A[44] \[ShortRightArrow] A[28], 
        Da}, {A[44] \[ShortRightArrow] A[31], 
        Da}, {A[44] \[ShortRightArrow] A[32], 
        Da}, {A[44] \[ShortRightArrow] A[38], 
        Da}, {A[44] \[ShortRightArrow] A[46], 
        Da}, {A[44] \[ShortRightArrow] A[55], 
        Da}, {A[44] \[ShortRightArrow] A[66], 
        Da}, {A[44] \[ShortRightArrow] A[67], 
        Da}, {A[45] \[ShortRightArrow] A[23], 
        Da}, {A[45] \[ShortRightArrow] A[33], 
        Da}, {A[45] \[ShortRightArrow] A[46], 
        Da}, {A[45] \[ShortRightArrow] A[54], 
        Da}, {A[45] \[ShortRightArrow] A[75], 
        Da}, {A[46] \[ShortRightArrow] A[31], 
        Da}, {A[46] \[ShortRightArrow] A[33], 
        Da}, {A[46] \[ShortRightArrow] A[44], 
        Da}, {A[46] \[ShortRightArrow] A[45], 
        Da}, {A[46] \[ShortRightArrow] A[55], 
        Da}, {A[46] \[ShortRightArrow] A[68], 
        Da}, {A[46] \[ShortRightArrow] A[69], 
        Da}, {A[47] \[ShortRightArrow] A[21], 
        Da}, {A[47] \[ShortRightArrow] A[29], 
        Da}, {A[47] \[ShortRightArrow] A[36], 
        Da}, {A[47] \[ShortRightArrow] A[48], 
        Da}, {A[47] \[ShortRightArrow] A[49], 
        Da}, {A[47] \[ShortRightArrow] A[63], 
        Da}, {A[48] \[ShortRightArrow] A[36], 
        Da}, {A[48] \[ShortRightArrow] A[42], 
        Da}, {A[48] \[ShortRightArrow] A[47], 
        Da}, {A[48] \[ShortRightArrow] A[58], 
        Da}, {A[48] \[ShortRightArrow] A[63], 
        Da}, {A[48] \[ShortRightArrow] A[73], 
        Da}, {A[48] \[ShortRightArrow] A[77], 
        Da}, {A[49] \[ShortRightArrow] A[29], 
        Da}, {A[49] \[ShortRightArrow] A[47], 
        Da}, {A[49] \[ShortRightArrow] A[57], 
        Da}, {A[49] \[ShortRightArrow] A[63], 
        Da}, {A[49] \[ShortRightArrow] A[76], 
        Da}, {A[50] \[ShortRightArrow] A[30], 
        Da}, {A[50] \[ShortRightArrow] A[43], 
        Da}, {A[50] \[ShortRightArrow] A[61], 
        Da}, {A[50] \[ShortRightArrow] A[82], 
        Da}, {A[51] \[ShortRightArrow] A[34], 
        Da}, {A[51] \[ShortRightArrow] A[40], 
        Da}, {A[51] \[ShortRightArrow] A[52], 
        Da}, {A[51] \[ShortRightArrow] A[56], 
        Da}, {A[51] \[ShortRightArrow] A[71], 
        Da}, {A[51] \[ShortRightArrow] A[72], 
        Da}, {A[51] \[ShortRightArrow] A[84], 
        Da}, {A[52] \[ShortRightArrow] A[34], 
        Da}, {A[52] \[ShortRightArrow] A[41], 
        Da}, {A[52] \[ShortRightArrow] A[51], 
        Da}, {A[52] \[ShortRightArrow] A[60], 
        Da}, {A[52] \[ShortRightArrow] A[72], 
        Da}, {A[53] \[ShortRightArrow] A[17], 
        Da}, {A[53] \[ShortRightArrow] A[39], 
        Da}, {A[53] \[ShortRightArrow] A[54], 
        Da}, {A[53] \[ShortRightArrow] A[65], 
        Da}, {A[53] \[ShortRightArrow] A[70], 
        Da}, {A[53] \[ShortRightArrow] A[74], 
        Da}, {A[54] \[ShortRightArrow] A[17], 
        Da}, {A[54] \[ShortRightArrow] A[23], 
        Da}, {A[54] \[ShortRightArrow] A[45], 
        Da}, {A[54] \[ShortRightArrow] A[53], 
        Da}, {A[54] \[ShortRightArrow] A[74], 
        Da}, {A[54] \[ShortRightArrow] A[75], 
        Da}, {A[55] \[ShortRightArrow] A[44], 
        Da}, {A[55] \[ShortRightArrow] A[46], 
        Da}, {A[55] \[ShortRightArrow] A[66], 
        Da}, {A[55] \[ShortRightArrow] A[69], 
        Da}, {A[55] \[ShortRightArrow] A[86], 
        Da}, {A[56] \[ShortRightArrow] A[38], 
        Da}, {A[56] \[ShortRightArrow] A[40], 
        Da}, {A[56] \[ShortRightArrow] A[51], 
        Da}, {A[56] \[ShortRightArrow] A[62], 
        Da}, {A[56] \[ShortRightArrow] A[67], 
        Da}, {A[56] \[ShortRightArrow] A[71], 
        Da}, {A[57] \[ShortRightArrow] A[29], 
        Da}, {A[57] \[ShortRightArrow] A[35], 
        Da}, {A[57] \[ShortRightArrow] A[49], 
        Da}, {A[57] \[ShortRightArrow] A[60], 
        Da}, {A[57] \[ShortRightArrow] A[76], 
        Da}, {A[57] \[ShortRightArrow] A[81], 
        Da}, {A[57] \[ShortRightArrow] A[85], 
        Da}, {A[58] \[ShortRightArrow] A[42], 
        Da}, {A[58] \[ShortRightArrow] A[48], 
        Da}, {A[58] \[ShortRightArrow] A[77], 
        Da}, {A[58] \[ShortRightArrow] A[78], 
        Da}, {A[59] \[ShortRightArrow] A[37], 
        Da}, {A[59] \[ShortRightArrow] A[39], 
        Da}, {A[59] \[ShortRightArrow] A[43], 
        Da}, {A[59] \[ShortRightArrow] A[64], 
        Da}, {A[59] \[ShortRightArrow] A[65], 
        Da}, {A[59] \[ShortRightArrow] A[83], 
        Da}, {A[59] \[ShortRightArrow] A[87], 
        Da}, {A[60] \[ShortRightArrow] A[35], 
        Da}, {A[60] \[ShortRightArrow] A[41], 
        Da}, {A[60] \[ShortRightArrow] A[52], 
        Da}, {A[60] \[ShortRightArrow] A[57], 
        Da}, {A[60] \[ShortRightArrow] A[72], 
        Da}, {A[60] \[ShortRightArrow] A[80], 
        Da}, {A[60] \[ShortRightArrow] A[85], 
        Da}, {A[61] \[ShortRightArrow] A[43], 
        Da}, {A[61] \[ShortRightArrow] A[50], 
        Da}, {A[61] \[ShortRightArrow] A[64], 
        Da}, {A[61] \[ShortRightArrow] A[82], 
        Da}, {A[61] \[ShortRightArrow] A[89], 
        Da}, {A[61] \[ShortRightArrow] A[96], 
        Da}, {A[62] \[ShortRightArrow] A[56], 
        Da}, {A[62] \[ShortRightArrow] A[67], 
        Da}, {A[62] \[ShortRightArrow] A[71], 
        Da}, {A[62] \[ShortRightArrow] A[79], 
        Da}, {A[63] \[ShortRightArrow] A[47], 
        Da}, {A[63] \[ShortRightArrow] A[48], 
        Da}, {A[63] \[ShortRightArrow] A[49], 
        Da}, {A[63] \[ShortRightArrow] A[73], 
        Da}, {A[63] \[ShortRightArrow] A[76], 
        Da}, {A[64] \[ShortRightArrow] A[43], 
        Da}, {A[64] \[ShortRightArrow] A[59], 
        Da}, {A[64] \[ShortRightArrow] A[61], 
        Da}, {A[64] \[ShortRightArrow] A[83], 
        Da}, {A[64] \[ShortRightArrow] A[96], 
        Da}, {A[65] \[ShortRightArrow] A[39], 
        Da}, {A[65] \[ShortRightArrow] A[53], 
        Da}, {A[65] \[ShortRightArrow] A[59], 
        Da}, {A[65] \[ShortRightArrow] A[70], 
        Da}, {A[65] \[ShortRightArrow] A[87], 
        Da}, {A[65] \[ShortRightArrow] A[97], 
        Da}, {A[65] \[ShortRightArrow] A[100], 
        Da}, {A[66] \[ShortRightArrow] A[44], 
        Da}, {A[66] \[ShortRightArrow] A[55], 
        Da}, {A[66] \[ShortRightArrow] A[67], 
        Da}, {A[66] \[ShortRightArrow] A[79], 
        Da}, {A[66] \[ShortRightArrow] A[86], 
        Da}, {A[66] \[ShortRightArrow] A[91], 
        Da}, {A[67] \[ShortRightArrow] A[38], 
        Da}, {A[67] \[ShortRightArrow] A[44], 
        Da}, {A[67] \[ShortRightArrow] A[56], 
        Da}, {A[67] \[ShortRightArrow] A[62], 
        Da}, {A[67] \[ShortRightArrow] A[66], 
        Da}, {A[67] \[ShortRightArrow] A[79], 
        Da}, {A[68] \[ShortRightArrow] A[46], 
        Da}, {A[68] \[ShortRightArrow] A[69], 
        Da}, {A[68] \[ShortRightArrow] A[75], 
        Da}, {A[68] \[ShortRightArrow] A[94], 
        Da}, {A[69] \[ShortRightArrow] A[46], 
        Da}, {A[69] \[ShortRightArrow] A[55], 
        Da}, {A[69] \[ShortRightArrow] A[68], 
        Da}, {A[69] \[ShortRightArrow] A[86], 
        Da}, {A[69] \[ShortRightArrow] A[94], 
        Da}, {A[69] \[ShortRightArrow] A[98], 
        Da}, {A[70] \[ShortRightArrow] A[53], 
        Da}, {A[70] \[ShortRightArrow] A[65], 
        Da}, {A[70] \[ShortRightArrow] A[74], 
        Da}, {A[70] \[ShortRightArrow] A[93], 
        Da}, {A[70] \[ShortRightArrow] A[97], 
        Da}, {A[71] \[ShortRightArrow] A[51], 
        Da}, {A[71] \[ShortRightArrow] A[56], 
        Da}, {A[71] \[ShortRightArrow] A[62], 
        Da}, {A[71] \[ShortRightArrow] A[79], 
        Da}, {A[71] \[ShortRightArrow] A[84], 
        Da}, {A[72] \[ShortRightArrow] A[51], 
        Da}, {A[72] \[ShortRightArrow] A[52], 
        Da}, {A[72] \[ShortRightArrow] A[60], 
        Da}, {A[72] \[ShortRightArrow] A[80], 
        Da}, {A[72] \[ShortRightArrow] A[84], 
        Da}, {A[72] \[ShortRightArrow] A[102], 
        Da}, {A[73] \[ShortRightArrow] A[48], 
        Da}, {A[73] \[ShortRightArrow] A[63], 
        Da}, {A[73] \[ShortRightArrow] A[76], 
        Da}, {A[73] \[ShortRightArrow] A[77], 
        Da}, {A[73] \[ShortRightArrow] A[92], 
        Da}, {A[74] \[ShortRightArrow] A[53], 
        Da}, {A[74] \[ShortRightArrow] A[54], 
        Da}, {A[74] \[ShortRightArrow] A[70], 
        Da}, {A[74] \[ShortRightArrow] A[75], 
        Da}, {A[74] \[ShortRightArrow] A[90], 
        Da}, {A[74] \[ShortRightArrow] A[93], 
        Da}, {A[75] \[ShortRightArrow] A[45], 
        Da}, {A[75] \[ShortRightArrow] A[54], 
        Da}, {A[75] \[ShortRightArrow] A[68], 
        Da}, {A[75] \[ShortRightArrow] A[74], 
        Da}, {A[75] \[ShortRightArrow] A[90], 
        Da}, {A[75] \[ShortRightArrow] A[94], 
        Da}, {A[76] \[ShortRightArrow] A[49], 
        Da}, {A[76] \[ShortRightArrow] A[57], 
        Da}, {A[76] \[ShortRightArrow] A[63], 
        Da}, {A[76] \[ShortRightArrow] A[73], 
        Da}, {A[76] \[ShortRightArrow] A[81], 
        Da}, {A[76] \[ShortRightArrow] A[92], 
        Da}, {A[76] \[ShortRightArrow] A[95], 
        Da}, {A[77] \[ShortRightArrow] A[48], 
        Da}, {A[77] \[ShortRightArrow] A[58], 
        Da}, {A[77] \[ShortRightArrow] A[73], 
        Da}, {A[77] \[ShortRightArrow] A[78], 
        Da}, {A[77] \[ShortRightArrow] A[92], 
        Da}, {A[77] \[ShortRightArrow] A[103], 
        Da}, {A[77] \[ShortRightArrow] A[107], 
        Da}, {A[78] \[ShortRightArrow] A[58], 
        Da}, {A[78] \[ShortRightArrow] A[77], 
        Da}, {A[78] \[ShortRightArrow] A[107], 
        Da}, {A[79] \[ShortRightArrow] A[62], 
        Da}, {A[79] \[ShortRightArrow] A[66], 
        Da}, {A[79] \[ShortRightArrow] A[67], 
        Da}, {A[79] \[ShortRightArrow] A[71], 
        Da}, {A[79] \[ShortRightArrow] A[84], 
        Da}, {A[79] \[ShortRightArrow] A[91], 
        Da}, {A[79] \[ShortRightArrow] A[99], 
        Da}, {A[79] \[ShortRightArrow] A[101], 
        Da}, {A[80] \[ShortRightArrow] A[60], 
        Da}, {A[80] \[ShortRightArrow] A[72], 
        Da}, {A[80] \[ShortRightArrow] A[85], 
        Da}, {A[80] \[ShortRightArrow] A[88], 
        Da}, {A[80] \[ShortRightArrow] A[102], 
        Da}, {A[80] \[ShortRightArrow] A[110], 
        Da}, {A[81] \[ShortRightArrow] A[57], 
        Da}, {A[81] \[ShortRightArrow] A[76], 
        Da}, {A[81] \[ShortRightArrow] A[85], 
        Da}, {A[81] \[ShortRightArrow] A[95], 
        Da}, {A[82] \[ShortRightArrow] A[50], 
        Da}, {A[82] \[ShortRightArrow] A[61], 
        Da}, {A[82] \[ShortRightArrow] A[89], 
        Da}, {A[82] \[ShortRightArrow] A[113], 
        Da}, {A[83] \[ShortRightArrow] A[59], 
        Da}, {A[83] \[ShortRightArrow] A[64], 
        Da}, {A[83] \[ShortRightArrow] A[87], 
        Da}, {A[83] \[ShortRightArrow] A[96], 
        Da}, {A[83] \[ShortRightArrow] A[100], 
        Da}, {A[83] \[ShortRightArrow] A[123], 
        Da}, {A[84] \[ShortRightArrow] A[51], 
        Da}, {A[84] \[ShortRightArrow] A[71], 
        Da}, {A[84] \[ShortRightArrow] A[72], 
        Da}, {A[84] \[ShortRightArrow] A[79], 
        Da}, {A[84] \[ShortRightArrow] A[101], 
        Da}, {A[84] \[ShortRightArrow] A[102], 
        Da}, {A[84] \[ShortRightArrow] A[109], 
        Da}, {A[85] \[ShortRightArrow] A[57], 
        Da}, {A[85] \[ShortRightArrow] A[60], 
        Da}, {A[85] \[ShortRightArrow] A[80], 
        Da}, {A[85] \[ShortRightArrow] A[81], 
        Da}, {A[85] \[ShortRightArrow] A[88], 
        Da}, {A[85] \[ShortRightArrow] A[95], 
        Da}, {A[86] \[ShortRightArrow] A[55], 
        Da}, {A[86] \[ShortRightArrow] A[66], 
        Da}, {A[86] \[ShortRightArrow] A[69], 
        Da}, {A[86] \[ShortRightArrow] A[91], 
        Da}, {A[86] \[ShortRightArrow] A[98], 
        Da}, {A[86] \[ShortRightArrow] A[106], 
        Da}, {A[87] \[ShortRightArrow] A[59], 
        Da}, {A[87] \[ShortRightArrow] A[65], 
        Da}, {A[87] \[ShortRightArrow] A[83], 
        Da}, {A[87] \[ShortRightArrow] A[100], 
        Da}, {A[88] \[ShortRightArrow] A[80], 
        Da}, {A[88] \[ShortRightArrow] A[85], 
        Da}, {A[88] \[ShortRightArrow] A[95], 
        Da}, {A[88] \[ShortRightArrow] A[110], 
        Da}, {A[88] \[ShortRightArrow] A[112], 
        Da}, {A[88] \[ShortRightArrow] A[120], 
        Da}, {A[89] \[ShortRightArrow] A[61], 
        Da}, {A[89] \[ShortRightArrow] A[82], 
        Da}, {A[89] \[ShortRightArrow] A[96], 
        Da}, {A[89] \[ShortRightArrow] A[113], 
        Da}, {A[90] \[ShortRightArrow] A[74], 
        Da}, {A[90] \[ShortRightArrow] A[75], 
        Da}, {A[90] \[ShortRightArrow] A[93], 
        Da}, {A[90] \[ShortRightArrow] A[105], 
        Da}, {A[90] \[ShortRightArrow] A[108], 
        Da}, {A[90] \[ShortRightArrow] A[116], 
        Da}, {A[91] \[ShortRightArrow] A[66], 
        Da}, {A[91] \[ShortRightArrow] A[79], 
        Da}, {A[91] \[ShortRightArrow] A[86], 
        Da}, {A[91] \[ShortRightArrow] A[99], 
        Da}, {A[91] \[ShortRightArrow] A[106], 
        Da}, {A[91] \[ShortRightArrow] A[118], 
        Da}, {A[92] \[ShortRightArrow] A[73], 
        Da}, {A[92] \[ShortRightArrow] A[76], 
        Da}, {A[92] \[ShortRightArrow] A[77], 
        Da}, {A[92] \[ShortRightArrow] A[95], 
        Da}, {A[92] \[ShortRightArrow] A[103], 
        Da}, {A[92] \[ShortRightArrow] A[111], 
        Da}, {A[93] \[ShortRightArrow] A[70], 
        Da}, {A[93] \[ShortRightArrow] A[74], 
        Da}, {A[93] \[ShortRightArrow] A[90], 
        Da}, {A[93] \[ShortRightArrow] A[97], 
        Da}, {A[93] \[ShortRightArrow] A[104], 
        Da}, {A[93] \[ShortRightArrow] A[105], 
        Da}, {A[93] \[ShortRightArrow] A[115], 
        Da}, {A[94] \[ShortRightArrow] A[68], 
        Da}, {A[94] \[ShortRightArrow] A[69], 
        Da}, {A[94] \[ShortRightArrow] A[75], 
        Da}, {A[94] \[ShortRightArrow] A[98], 
        Da}, {A[94] \[ShortRightArrow] A[108], 
        Da}, {A[94] \[ShortRightArrow] A[117], 
        Da}, {A[95] \[ShortRightArrow] A[76], 
        Da}, {A[95] \[ShortRightArrow] A[81], 
        Da}, {A[95] \[ShortRightArrow] A[85], 
        Da}, {A[95] \[ShortRightArrow] A[88], 
        Da}, {A[95] \[ShortRightArrow] A[92], 
        Da}, {A[95] \[ShortRightArrow] A[111], 
        Da}, {A[95] \[ShortRightArrow] A[120], 
        Da}, {A[95] \[ShortRightArrow] A[121], 
        Da}, {A[96] \[ShortRightArrow] A[61], 
        Da}, {A[96] \[ShortRightArrow] A[64], 
        Da}, {A[96] \[ShortRightArrow] A[83], 
        Da}, {A[96] \[ShortRightArrow] A[89], 
        Da}, {A[96] \[ShortRightArrow] A[113], 
        Da}, {A[96] \[ShortRightArrow] A[123], 
        Da}, {A[96] \[ShortRightArrow] A[127], 
        Da}, {A[97] \[ShortRightArrow] A[65], 
        Da}, {A[97] \[ShortRightArrow] A[70], 
        Da}, {A[97] \[ShortRightArrow] A[93], 
        Da}, {A[97] \[ShortRightArrow] A[100], 
        Da}, {A[97] \[ShortRightArrow] A[104], 
        Da}, {A[97] \[ShortRightArrow] A[124], 
        Da}, {A[98] \[ShortRightArrow] A[69], 
        Da}, {A[98] \[ShortRightArrow] A[86], 
        Da}, {A[98] \[ShortRightArrow] A[94], 
        Da}, {A[98] \[ShortRightArrow] A[106], 
        Da}, {A[98] \[ShortRightArrow] A[117], 
        Da}, {A[98] \[ShortRightArrow] A[125], 
        Da}, {A[99] \[ShortRightArrow] A[79], 
        Da}, {A[99] \[ShortRightArrow] A[91], 
        Da}, {A[99] \[ShortRightArrow] A[101], 
        Da}, {A[99] \[ShortRightArrow] A[118], 
        Da}, {A[99] \[ShortRightArrow] A[119], 
        Da}, {A[100] \[ShortRightArrow] A[65], 
        Da}, {A[100] \[ShortRightArrow] A[83], 
        Da}, {A[100] \[ShortRightArrow] A[87], 
        Da}, {A[100] \[ShortRightArrow] A[97], 
        Da}, {A[100] \[ShortRightArrow] A[114], 
        Da}, {A[100] \[ShortRightArrow] A[123], 
        Da}, {A[100] \[ShortRightArrow] A[124], 
        Da}, {A[100] \[ShortRightArrow] A[132], 
        Da}, {A[101] \[ShortRightArrow] A[79], 
        Da}, {A[101] \[ShortRightArrow] A[84], 
        Da}, {A[101] \[ShortRightArrow] A[99], 
        Da}, {A[101] \[ShortRightArrow] A[109], 
        Da}, {A[101] \[ShortRightArrow] A[119], 
        Da}, {A[101] \[ShortRightArrow] A[131], 
        Da}, {A[102] \[ShortRightArrow] A[72], 
        Da}, {A[102] \[ShortRightArrow] A[80], 
        Da}, {A[102] \[ShortRightArrow] A[84], 
        Da}, {A[102] \[ShortRightArrow] A[109], 
        Da}, {A[102] \[ShortRightArrow] A[110], 
        Da}, {A[102] \[ShortRightArrow] A[129], 
        Da}, {A[103] \[ShortRightArrow] A[77], 
        Da}, {A[103] \[ShortRightArrow] A[92], 
        Da}, {A[103] \[ShortRightArrow] A[107], 
        Da}, {A[103] \[ShortRightArrow] A[111], 
        Da}, {A[103] \[ShortRightArrow] A[136], 
        Da}, {A[103] \[ShortRightArrow] A[137], 
        Da}, {A[104] \[ShortRightArrow] A[93], 
        Da}, {A[104] \[ShortRightArrow] A[97], 
        Da}, {A[104] \[ShortRightArrow] A[115], 
        Da}, {A[104] \[ShortRightArrow] A[124], 
        Da}, {A[104] \[ShortRightArrow] A[128], 
        Da}, {A[104] \[ShortRightArrow] A[130], 
        Da}, {A[105] \[ShortRightArrow] A[90], 
        Da}, {A[105] \[ShortRightArrow] A[93], 
        Da}, {A[105] \[ShortRightArrow] A[115], 
        Da}, {A[105] \[ShortRightArrow] A[116], 
        Da}, {A[106] \[ShortRightArrow] A[86], 
        Da}, {A[106] \[ShortRightArrow] A[91], 
        Da}, {A[106] \[ShortRightArrow] A[98], 
        Da}, {A[106] \[ShortRightArrow] A[118], 
        Da}, {A[106] \[ShortRightArrow] A[125], 
        Da}, {A[107] \[ShortRightArrow] A[77], 
        Da}, {A[107] \[ShortRightArrow] A[78], 
        Da}, {A[107] \[ShortRightArrow] A[103], 
        Da}, {A[107] \[ShortRightArrow] A[122], 
        Da}, {A[107] \[ShortRightArrow] A[137], 
        Da}, {A[108] \[ShortRightArrow] A[90], 
        Da}, {A[108] \[ShortRightArrow] A[94], 
        Da}, {A[108] \[ShortRightArrow] A[116], 
        Da}, {A[108] \[ShortRightArrow] A[117], 
        Da}, {A[109] \[ShortRightArrow] A[84], 
        Da}, {A[109] \[ShortRightArrow] A[101], 
        Da}, {A[109] \[ShortRightArrow] A[102], 
        Da}, {A[109] \[ShortRightArrow] A[129], 
        Da}, {A[109] \[ShortRightArrow] A[131], 
        Da}, {A[110] \[ShortRightArrow] A[80], 
        Da}, {A[110] \[ShortRightArrow] A[88], 
        Da}, {A[110] \[ShortRightArrow] A[102], 
        Da}, {A[110] \[ShortRightArrow] A[112], 
        Da}, {A[110] \[ShortRightArrow] A[129], 
        Da}, {A[111] \[ShortRightArrow] A[92], 
        Da}, {A[111] \[ShortRightArrow] A[95], 
        Da}, {A[111] \[ShortRightArrow] A[103], 
        Da}, {A[111] \[ShortRightArrow] A[121], 
        Da}, {A[111] \[ShortRightArrow] A[136], 
        Da}, {A[112] \[ShortRightArrow] A[88], 
        Da}, {A[112] \[ShortRightArrow] A[110], 
        Da}, {A[112] \[ShortRightArrow] A[120], 
        Da}, {A[112] \[ShortRightArrow] A[129], 
        Da}, {A[112] \[ShortRightArrow] A[144], 
        Da}, {A[112] \[ShortRightArrow] A[149], 
        Da}, {A[113] \[ShortRightArrow] A[82], 
        Da}, {A[113] \[ShortRightArrow] A[89], 
        Da}, {A[113] \[ShortRightArrow] A[96], 
        Da}, {A[113] \[ShortRightArrow] A[127], 
        Da}, {A[113] \[ShortRightArrow] A[134], 
        Da}, {A[114] \[ShortRightArrow] A[100], 
        Da}, {A[114] \[ShortRightArrow] A[124], 
        Da}, {A[114] \[ShortRightArrow] A[132], 
        Da}, {A[114] \[ShortRightArrow] A[145], 
        Da}, {A[115] \[ShortRightArrow] A[93], 
        Da}, {A[115] \[ShortRightArrow] A[104], 
        Da}, {A[115] \[ShortRightArrow] A[105], 
        Da}, {A[115] \[ShortRightArrow] A[116], 
        Da}, {A[115] \[ShortRightArrow] A[130], 
        Da}, {A[115] \[ShortRightArrow] A[142], 
        Da}, {A[116] \[ShortRightArrow] A[90], 
        Da}, {A[116] \[ShortRightArrow] A[105], 
        Da}, {A[116] \[ShortRightArrow] A[108], 
        Da}, {A[116] \[ShortRightArrow] A[115], 
        Da}, {A[116] \[ShortRightArrow] A[117], 
        Da}, {A[116] \[ShortRightArrow] A[143], 
        Da}, {A[117] \[ShortRightArrow] A[94], 
        Da}, {A[117] \[ShortRightArrow] A[98], 
        Da}, {A[117] \[ShortRightArrow] A[108], 
        Da}, {A[117] \[ShortRightArrow] A[116], 
        Da}, {A[117] \[ShortRightArrow] A[125], 
        Da}, {A[117] \[ShortRightArrow] A[143], 
        Da}, {A[117] \[ShortRightArrow] A[154], 
        Da}, {A[118] \[ShortRightArrow] A[91], 
        Da}, {A[118] \[ShortRightArrow] A[99], 
        Da}, {A[118] \[ShortRightArrow] A[106], 
        Da}, {A[118] \[ShortRightArrow] A[119], 
        Da}, {A[118] \[ShortRightArrow] A[125], 
        Da}, {A[118] \[ShortRightArrow] A[135], 
        Da}, {A[119] \[ShortRightArrow] A[99], 
        Da}, {A[119] \[ShortRightArrow] A[101], 
        Da}, {A[119] \[ShortRightArrow] A[118], 
        Da}, {A[119] \[ShortRightArrow] A[131], 
        Da}, {A[119] \[ShortRightArrow] A[135], 
        Da}, {A[120] \[ShortRightArrow] A[88], 
        Da}, {A[120] \[ShortRightArrow] A[95], 
        Da}, {A[120] \[ShortRightArrow] A[112], 
        Da}, {A[120] \[ShortRightArrow] A[121], 
        Da}, {A[120] \[ShortRightArrow] A[126], 
        Da}, {A[120] \[ShortRightArrow] A[149], 
        Da}, {A[121] \[ShortRightArrow] A[95], 
        Da}, {A[121] \[ShortRightArrow] A[111], 
        Da}, {A[121] \[ShortRightArrow] A[120], 
        Da}, {A[121] \[ShortRightArrow] A[126], 
        Da}, {A[121] \[ShortRightArrow] A[136], 
        Da}, {A[121] \[ShortRightArrow] A[138], 
        Da}, {A[121] \[ShortRightArrow] A[139], 
        Da}, {A[122] \[ShortRightArrow] A[107], 
        Da}, {A[122] \[ShortRightArrow] A[137], 
        Da}, {A[122] \[ShortRightArrow] A[150], 
        Da}, {A[123] \[ShortRightArrow] A[83], 
        Da}, {A[123] \[ShortRightArrow] A[96], 
        Da}, {A[123] \[ShortRightArrow] A[100], 
        Da}, {A[123] \[ShortRightArrow] A[127], 
        Da}, {A[123] \[ShortRightArrow] A[132], 
        Da}, {A[123] \[ShortRightArrow] A[141], 
        Da}, {A[124] \[ShortRightArrow] A[97], 
        Da}, {A[124] \[ShortRightArrow] A[100], 
        Da}, {A[124] \[ShortRightArrow] A[104], 
        Da}, {A[124] \[ShortRightArrow] A[114], 
        Da}, {A[124] \[ShortRightArrow] A[128], 
        Da}, {A[124] \[ShortRightArrow] A[140], 
        Da}, {A[124] \[ShortRightArrow] A[145], 
        Da}, {A[125] \[ShortRightArrow] A[98], 
        Da}, {A[125] \[ShortRightArrow] A[106], 
        Da}, {A[125] \[ShortRightArrow] A[117], 
        Da}, {A[125] \[ShortRightArrow] A[118], 
        Da}, {A[125] \[ShortRightArrow] A[135], 
        Da}, {A[125] \[ShortRightArrow] A[154], 
        Da}, {A[125] \[ShortRightArrow] A[155], 
        Da}, {A[125] \[ShortRightArrow] A[162], 
        Da}, {A[126] \[ShortRightArrow] A[120], 
        Da}, {A[126] \[ShortRightArrow] A[121], 
        Da}, {A[126] \[ShortRightArrow] A[138], 
        Da}, {A[126] \[ShortRightArrow] A[149], 
        Da}, {A[127] \[ShortRightArrow] A[96], 
        Da}, {A[127] \[ShortRightArrow] A[113], 
        Da}, {A[127] \[ShortRightArrow] A[123], 
        Da}, {A[127] \[ShortRightArrow] A[134], 
        Da}, {A[127] \[ShortRightArrow] A[141], 
        Da}, {A[128] \[ShortRightArrow] A[104], 
        Da}, {A[128] \[ShortRightArrow] A[124], 
        Da}, {A[128] \[ShortRightArrow] A[130], 
        Da}, {A[128] \[ShortRightArrow] A[140], 
        Da}, {A[129] \[ShortRightArrow] A[102], 
        Da}, {A[129] \[ShortRightArrow] A[109], 
        Da}, {A[129] \[ShortRightArrow] A[110], 
        Da}, {A[129] \[ShortRightArrow] A[112], 
        Da}, {A[129] \[ShortRightArrow] A[131], 
        Da}, {A[129] \[ShortRightArrow] A[133], 
        Da}, {A[129] \[ShortRightArrow] A[144], 
        Da}, {A[130] \[ShortRightArrow] A[104], 
        Da}, {A[130] \[ShortRightArrow] A[115], 
        Da}, {A[130] \[ShortRightArrow] A[128], 
        Da}, {A[130] \[ShortRightArrow] A[140], 
        Da}, {A[130] \[ShortRightArrow] A[142], 
        Da}, {A[130] \[ShortRightArrow] A[146], 
        Da}, {A[130] \[ShortRightArrow] A[156], 
        Da}, {A[131] \[ShortRightArrow] A[101], 
        Da}, {A[131] \[ShortRightArrow] A[109], 
        Da}, {A[131] \[ShortRightArrow] A[119], 
        Da}, {A[131] \[ShortRightArrow] A[129], 
        Da}, {A[131] \[ShortRightArrow] A[133], 
        Da}, {A[131] \[ShortRightArrow] A[135], 
        Da}, {A[131] \[ShortRightArrow] A[147], 
        Da}, {A[131] \[ShortRightArrow] A[148], 
        Da}, {A[131] \[ShortRightArrow] A[158], 
        Da}, {A[132] \[ShortRightArrow] A[100], 
        Da}, {A[132] \[ShortRightArrow] A[114], 
        Da}, {A[132] \[ShortRightArrow] A[123], 
        Da}, {A[132] \[ShortRightArrow] A[141], 
        Da}, {A[132] \[ShortRightArrow] A[145], 
        Da}, {A[132] \[ShortRightArrow] A[164], 
        Da}, {A[133] \[ShortRightArrow] A[129], 
        Da}, {A[133] \[ShortRightArrow] A[131], 
        Da}, {A[133] \[ShortRightArrow] A[144], 
        Da}, {A[133] \[ShortRightArrow] A[148], 
        Da}, {A[134] \[ShortRightArrow] A[113], 
        Da}, {A[134] \[ShortRightArrow] A[127], 
        Da}, {A[134] \[ShortRightArrow] A[141], 
        Da}, {A[134] \[ShortRightArrow] A[152], 
        Da}, {A[134] \[ShortRightArrow] A[153], 
        Da}, {A[135] \[ShortRightArrow] A[118], 
        Da}, {A[135] \[ShortRightArrow] A[119], 
        Da}, {A[135] \[ShortRightArrow] A[125], 
        Da}, {A[135] \[ShortRightArrow] A[131], 
        Da}, {A[135] \[ShortRightArrow] A[147], 
        Da}, {A[135] \[ShortRightArrow] A[155], 
        Da}, {A[136] \[ShortRightArrow] A[103], 
        Da}, {A[136] \[ShortRightArrow] A[111], 
        Da}, {A[136] \[ShortRightArrow] A[121], 
        Da}, {A[136] \[ShortRightArrow] A[137], 
        Da}, {A[136] \[ShortRightArrow] A[139], 
        Da}, {A[136] \[ShortRightArrow] A[157], 
        Da}, {A[136] \[ShortRightArrow] A[159], 
        Da}, {A[137] \[ShortRightArrow] A[103], 
        Da}, {A[137] \[ShortRightArrow] A[107], 
        Da}, {A[137] \[ShortRightArrow] A[122], 
        Da}, {A[137] \[ShortRightArrow] A[136], 
        Da}, {A[137] \[ShortRightArrow] A[150], 
        Da}, {A[137] \[ShortRightArrow] A[159], 
        Da}, {A[137] \[ShortRightArrow] A[171], 
        Da}, {A[138] \[ShortRightArrow] A[121], 
        Da}, {A[138] \[ShortRightArrow] A[126], 
        Da}, {A[138] \[ShortRightArrow] A[139], 
        Da}, {A[138] \[ShortRightArrow] A[149], 
        Da}, {A[138] \[ShortRightArrow] A[157], 
        Da}, {A[138] \[ShortRightArrow] A[163], 
        Da}, {A[138] \[ShortRightArrow] A[170], 
        Da}, {A[139] \[ShortRightArrow] A[121], 
        Da}, {A[139] \[ShortRightArrow] A[136], 
        Da}, {A[139] \[ShortRightArrow] A[138], 
        Da}, {A[139] \[ShortRightArrow] A[157], 
        Da}, {A[140] \[ShortRightArrow] A[124], 
        Da}, {A[140] \[ShortRightArrow] A[128], 
        Da}, {A[140] \[ShortRightArrow] A[130], 
        Da}, {A[140] \[ShortRightArrow] A[145], 
        Da}, {A[140] \[ShortRightArrow] A[156], 
        Da}, {A[141] \[ShortRightArrow] A[123], 
        Da}, {A[141] \[ShortRightArrow] A[127], 
        Da}, {A[141] \[ShortRightArrow] A[132], 
        Da}, {A[141] \[ShortRightArrow] A[134], 
        Da}, {A[141] \[ShortRightArrow] A[153], 
        Da}, {A[141] \[ShortRightArrow] A[164], 
        Da}, {A[142] \[ShortRightArrow] A[115], 
        Da}, {A[142] \[ShortRightArrow] A[130], 
        Da}, {A[142] \[ShortRightArrow] A[143], 
        Da}, {A[142] \[ShortRightArrow] A[146], 
        Da}, {A[142] \[ShortRightArrow] A[151], 
        Da}, {A[143] \[ShortRightArrow] A[116], 
        Da}, {A[143] \[ShortRightArrow] A[117], 
        Da}, {A[143] \[ShortRightArrow] A[142], 
        Da}, {A[143] \[ShortRightArrow] A[151], 
        Da}, {A[143] \[ShortRightArrow] A[154], 
        Da}, {A[144] \[ShortRightArrow] A[112], 
        Da}, {A[144] \[ShortRightArrow] A[129], 
        Da}, {A[144] \[ShortRightArrow] A[133], 
        Da}, {A[144] \[ShortRightArrow] A[148], 
        Da}, {A[144] \[ShortRightArrow] A[149], 
        Da}, {A[144] \[ShortRightArrow] A[165], 
        Da}, {A[144] \[ShortRightArrow] A[169], 
        Da}, {A[145] \[ShortRightArrow] A[114], 
        Da}, {A[145] \[ShortRightArrow] A[124], 
        Da}, {A[145] \[ShortRightArrow] A[132], 
        Da}, {A[145] \[ShortRightArrow] A[140], 
        Da}, {A[145] \[ShortRightArrow] A[156], 
        Da}, {A[145] \[ShortRightArrow] A[160], 
        Da}, {A[145] \[ShortRightArrow] A[164], 
        Da}, {A[145] \[ShortRightArrow] A[188], 
        Da}, {A[146] \[ShortRightArrow] A[130], 
        Da}, {A[146] \[ShortRightArrow] A[142], 
        Da}, {A[146] \[ShortRightArrow] A[151], 
        Da}, {A[146] \[ShortRightArrow] A[156], 
        Da}, {A[146] \[ShortRightArrow] A[161], 
        Da}, {A[147] \[ShortRightArrow] A[131], 
        Da}, {A[147] \[ShortRightArrow] A[135], 
        Da}, {A[147] \[ShortRightArrow] A[155], 
        Da}, {A[147] \[ShortRightArrow] A[158], 
        Da}, {A[147] \[ShortRightArrow] A[167], 
        Da}, {A[148] \[ShortRightArrow] A[131], 
        Da}, {A[148] \[ShortRightArrow] A[133], 
        Da}, {A[148] \[ShortRightArrow] A[144], 
        Da}, {A[148] \[ShortRightArrow] A[158], 
        Da}, {A[148] \[ShortRightArrow] A[168], 
        Da}, {A[148] \[ShortRightArrow] A[169], 
        Da}, {A[149] \[ShortRightArrow] A[112], 
        Da}, {A[149] \[ShortRightArrow] A[120], 
        Da}, {A[149] \[ShortRightArrow] A[126], 
        Da}, {A[149] \[ShortRightArrow] A[138], 
        Da}, {A[149] \[ShortRightArrow] A[144], 
        Da}, {A[149] \[ShortRightArrow] A[163], 
        Da}, {A[149] \[ShortRightArrow] A[165], 
        Da}, {A[150] \[ShortRightArrow] A[122], 
        Da}, {A[150] \[ShortRightArrow] A[137], 
        Da}, {A[150] \[ShortRightArrow] A[171], 
        Da}, {A[151] \[ShortRightArrow] A[142], 
        Da}, {A[151] \[ShortRightArrow] A[143], 
        Da}, {A[151] \[ShortRightArrow] A[146], 
        Da}, {A[151] \[ShortRightArrow] A[154], 
        Da}, {A[151] \[ShortRightArrow] A[161], 
        Da}, {A[151] \[ShortRightArrow] A[166], 
        Da}, {A[151] \[ShortRightArrow] A[175], 
        Da}, {A[152] \[ShortRightArrow] A[134], 
        Da}, {A[152] \[ShortRightArrow] A[153], 
        Da}, {A[152] \[ShortRightArrow] A[172], 
        Da}, {A[152] \[ShortRightArrow] A[178], 
        Da}, {A[153] \[ShortRightArrow] A[134], 
        Da}, {A[153] \[ShortRightArrow] A[141], 
        Da}, {A[153] \[ShortRightArrow] A[152], 
        Da}, {A[153] \[ShortRightArrow] A[164], 
        Da}, {A[153] \[ShortRightArrow] A[172], 
        Da}, {A[153] \[ShortRightArrow] A[176], 
        Da}, {A[154] \[ShortRightArrow] A[117], 
        Da}, {A[154] \[ShortRightArrow] A[125], 
        Da}, {A[154] \[ShortRightArrow] A[143], 
        Da}, {A[154] \[ShortRightArrow] A[151], 
        Da}, {A[154] \[ShortRightArrow] A[162], 
        Da}, {A[154] \[ShortRightArrow] A[166], 
        Da}, {A[155] \[ShortRightArrow] A[125], 
        Da}, {A[155] \[ShortRightArrow] A[135], 
        Da}, {A[155] \[ShortRightArrow] A[147], 
        Da}, {A[155] \[ShortRightArrow] A[162], 
        Da}, {A[155] \[ShortRightArrow] A[167], 
        Da}, {A[155] \[ShortRightArrow] A[173], 
        Da}, {A[156] \[ShortRightArrow] A[130], 
        Da}, {A[156] \[ShortRightArrow] A[140], 
        Da}, {A[156] \[ShortRightArrow] A[145], 
        Da}, {A[156] \[ShortRightArrow] A[146], 
        Da}, {A[156] \[ShortRightArrow] A[160], 
        Da}, {A[156] \[ShortRightArrow] A[161], 
        Da}, {A[157] \[ShortRightArrow] A[136], 
        Da}, {A[157] \[ShortRightArrow] A[138], 
        Da}, {A[157] \[ShortRightArrow] A[139], 
        Da}, {A[157] \[ShortRightArrow] A[159], 
        Da}, {A[157] \[ShortRightArrow] A[170], 
        Da}, {A[158] \[ShortRightArrow] A[131], 
        Da}, {A[158] \[ShortRightArrow] A[147], 
        Da}, {A[158] \[ShortRightArrow] A[148], 
        Da}, {A[158] \[ShortRightArrow] A[167], 
        Da}, {A[158] \[ShortRightArrow] A[168], 
        Da}, {A[158] \[ShortRightArrow] A[179], 
        Da}, {A[159] \[ShortRightArrow] A[136], 
        Da}, {A[159] \[ShortRightArrow] A[137], 
        Da}, {A[159] \[ShortRightArrow] A[157], 
        Da}, {A[159] \[ShortRightArrow] A[170], 
        Da}, {A[159] \[ShortRightArrow] A[171], 
        Da}, {A[159] \[ShortRightArrow] A[181], 
        Da}, {A[159] \[ShortRightArrow] A[182], 
        Da}, {A[160] \[ShortRightArrow] A[145], 
        Da}, {A[160] \[ShortRightArrow] A[156], 
        Da}, {A[160] \[ShortRightArrow] A[161], 
        Da}, {A[160] \[ShortRightArrow] A[186], 
        Da}, {A[160] \[ShortRightArrow] A[188], 
        Da}, {A[161] \[ShortRightArrow] A[146], 
        Da}, {A[161] \[ShortRightArrow] A[151], 
        Da}, {A[161] \[ShortRightArrow] A[156], 
        Da}, {A[161] \[ShortRightArrow] A[160], 
        Da}, {A[161] \[ShortRightArrow] A[175], 
        Da}, {A[161] \[ShortRightArrow] A[186], 
        Da}, {A[161] \[ShortRightArrow] A[190], 
        Da}, {A[162] \[ShortRightArrow] A[125], 
        Da}, {A[162] \[ShortRightArrow] A[154], 
        Da}, {A[162] \[ShortRightArrow] A[155], 
        Da}, {A[162] \[ShortRightArrow] A[166], 
        Da}, {A[162] \[ShortRightArrow] A[173], 
        Da}, {A[162] \[ShortRightArrow] A[183], 
        Da}, {A[162] \[ShortRightArrow] A[184], 
        Da}, {A[163] \[ShortRightArrow] A[138], 
        Da}, {A[163] \[ShortRightArrow] A[149], 
        Da}, {A[163] \[ShortRightArrow] A[165], 
        Da}, {A[163] \[ShortRightArrow] A[170], 
        Da}, {A[163] \[ShortRightArrow] A[180], 
        Da}, {A[164] \[ShortRightArrow] A[132], 
        Da}, {A[164] \[ShortRightArrow] A[141], 
        Da}, {A[164] \[ShortRightArrow] A[145], 
        Da}, {A[164] \[ShortRightArrow] A[153], 
        Da}, {A[164] \[ShortRightArrow] A[176], 
        Da}, {A[164] \[ShortRightArrow] A[188], 
        Da}, {A[164] \[ShortRightArrow] A[201], 
        Da}, {A[165] \[ShortRightArrow] A[144], 
        Da}, {A[165] \[ShortRightArrow] A[149], 
        Da}, {A[165] \[ShortRightArrow] A[163], 
        Da}, {A[165] \[ShortRightArrow] A[169], 
        Da}, {A[165] \[ShortRightArrow] A[177], 
        Da}, {A[165] \[ShortRightArrow] A[180], 
        Da}, {A[166] \[ShortRightArrow] A[151], 
        Da}, {A[166] \[ShortRightArrow] A[154], 
        Da}, {A[166] \[ShortRightArrow] A[162], 
        Da}, {A[166] \[ShortRightArrow] A[175], 
        Da}, {A[166] \[ShortRightArrow] A[183], 
        Da}, {A[167] \[ShortRightArrow] A[147], 
        Da}, {A[167] \[ShortRightArrow] A[155], 
        Da}, {A[167] \[ShortRightArrow] A[158], 
        Da}, {A[167] \[ShortRightArrow] A[173], 
        Da}, {A[167] \[ShortRightArrow] A[174], 
        Da}, {A[167] \[ShortRightArrow] A[179], 
        Da}, {A[168] \[ShortRightArrow] A[148], 
        Da}, {A[168] \[ShortRightArrow] A[158], 
        Da}, {A[168] \[ShortRightArrow] A[169], 
        Da}, {A[168] \[ShortRightArrow] A[179], 
        Da}, {A[169] \[ShortRightArrow] A[144], 
        Da}, {A[169] \[ShortRightArrow] A[148], 
        Da}, {A[169] \[ShortRightArrow] A[165], 
        Da}, {A[169] \[ShortRightArrow] A[168], 
        Da}, {A[169] \[ShortRightArrow] A[177], 
        Da}, {A[169] \[ShortRightArrow] A[179], 
        Da}, {A[169] \[ShortRightArrow] A[192], 
        Da}, {A[169] \[ShortRightArrow] A[193], 
        Da}, {A[170] \[ShortRightArrow] A[138], 
        Da}, {A[170] \[ShortRightArrow] A[157], 
        Da}, {A[170] \[ShortRightArrow] A[159], 
        Da}, {A[170] \[ShortRightArrow] A[163], 
        Da}, {A[170] \[ShortRightArrow] A[180], 
        Da}, {A[170] \[ShortRightArrow] A[181], 
        Da}, {A[171] \[ShortRightArrow] A[137], 
        Da}, {A[171] \[ShortRightArrow] A[150], 
        Da}, {A[171] \[ShortRightArrow] A[159], 
        Da}, {A[171] \[ShortRightArrow] A[182], 
        Da}, {A[172] \[ShortRightArrow] A[152], 
        Da}, {A[172] \[ShortRightArrow] A[153], 
        Da}, {A[172] \[ShortRightArrow] A[176], 
        Da}, {A[172] \[ShortRightArrow] A[178], 
        Da}, {A[172] \[ShortRightArrow] A[185], 
        Da}, {A[173] \[ShortRightArrow] A[155], 
        Da}, {A[173] \[ShortRightArrow] A[162], 
        Da}, {A[173] \[ShortRightArrow] A[167], 
        Da}, {A[173] \[ShortRightArrow] A[174], 
        Da}, {A[173] \[ShortRightArrow] A[184], 
        Da}, {A[173] \[ShortRightArrow] A[189], 
        Da}, {A[174] \[ShortRightArrow] A[167], 
        Da}, {A[174] \[ShortRightArrow] A[173], 
        Da}, {A[174] \[ShortRightArrow] A[179], 
        Da}, {A[174] \[ShortRightArrow] A[187], 
        Da}, {A[174] \[ShortRightArrow] A[189], 
        Da}, {A[175] \[ShortRightArrow] A[151], 
        Da}, {A[175] \[ShortRightArrow] A[161], 
        Da}, {A[175] \[ShortRightArrow] A[166], 
        Da}, {A[175] \[ShortRightArrow] A[183], 
        Da}, {A[175] \[ShortRightArrow] A[190], 
        Da}, {A[175] \[ShortRightArrow] A[199], 
        Da}, {A[176] \[ShortRightArrow] A[153], 
        Da}, {A[176] \[ShortRightArrow] A[164], 
        Da}, {A[176] \[ShortRightArrow] A[172], 
        Da}, {A[176] \[ShortRightArrow] A[185], 
        Da}, {A[176] \[ShortRightArrow] A[197], 
        Da}, {A[176] \[ShortRightArrow] A[201], 
        Da}, {A[177] \[ShortRightArrow] A[165], 
        Da}, {A[177] \[ShortRightArrow] A[169], 
        Da}, {A[177] \[ShortRightArrow] A[180], 
        Da}, {A[177] \[ShortRightArrow] A[193], 
        Da}, {A[177] \[ShortRightArrow] A[194], 
        Da}, {A[178] \[ShortRightArrow] A[152], 
        Da}, {A[178] \[ShortRightArrow] A[172], 
        Da}, {A[178] \[ShortRightArrow] A[185], 
        Da}, {A[178] \[ShortRightArrow] A[203], 
        Da}, {A[179] \[ShortRightArrow] A[158], 
        Da}, {A[179] \[ShortRightArrow] A[167], 
        Da}, {A[179] \[ShortRightArrow] A[168], 
        Da}, {A[179] \[ShortRightArrow] A[169], 
        Da}, {A[179] \[ShortRightArrow] A[174], 
        Da}, {A[179] \[ShortRightArrow] A[187], 
        Da}, {A[179] \[ShortRightArrow] A[191], 
        Da}, {A[179] \[ShortRightArrow] A[192], 
        Da}, {A[180] \[ShortRightArrow] A[163], 
        Da}, {A[180] \[ShortRightArrow] A[165], 
        Da}, {A[180] \[ShortRightArrow] A[170], 
        Da}, {A[180] \[ShortRightArrow] A[177], 
        Da}, {A[180] \[ShortRightArrow] A[181], 
        Da}, {A[180] \[ShortRightArrow] A[194], 
        Da}, {A[180] \[ShortRightArrow] A[196], 
        Da}, {A[180] \[ShortRightArrow] A[204], 
        Da}, {A[181] \[ShortRightArrow] A[159], 
        Da}, {A[181] \[ShortRightArrow] A[170], 
        Da}, {A[181] \[ShortRightArrow] A[180], 
        Da}, {A[181] \[ShortRightArrow] A[182], 
        Da}, {A[181] \[ShortRightArrow] A[196], 
        Da}, {A[181] \[ShortRightArrow] A[200], 
        Da}, {A[182] \[ShortRightArrow] A[159], 
        Da}, {A[182] \[ShortRightArrow] A[171], 
        Da}, {A[182] \[ShortRightArrow] A[181], 
        Da}, {A[182] \[ShortRightArrow] A[200], 
        Da}, {A[183] \[ShortRightArrow] A[162], 
        Da}, {A[183] \[ShortRightArrow] A[166], 
        Da}, {A[183] \[ShortRightArrow] A[175], 
        Da}, {A[183] \[ShortRightArrow] A[184], 
        Da}, {A[183] \[ShortRightArrow] A[195], 
        Da}, {A[183] \[ShortRightArrow] A[199], 
        Da}, {A[184] \[ShortRightArrow] A[162], 
        Da}, {A[184] \[ShortRightArrow] A[173], 
        Da}, {A[184] \[ShortRightArrow] A[183], 
        Da}, {A[184] \[ShortRightArrow] A[189], 
        Da}, {A[184] \[ShortRightArrow] A[195], 
        Da}, {A[184] \[ShortRightArrow] A[202], 
        Da}, {A[185] \[ShortRightArrow] A[172], 
        Da}, {A[185] \[ShortRightArrow] A[176], 
        Da}, {A[185] \[ShortRightArrow] A[178], 
        Da}, {A[185] \[ShortRightArrow] A[197], 
        Da}, {A[185] \[ShortRightArrow] A[203], 
        Da}, {A[185] \[ShortRightArrow] A[208], 
        Da}, {A[186] \[ShortRightArrow] A[160], 
        Da}, {A[186] \[ShortRightArrow] A[161], 
        Da}, {A[186] \[ShortRightArrow] A[188], 
        Da}, {A[186] \[ShortRightArrow] A[190], 
        Da}, {A[186] \[ShortRightArrow] A[198], 
        Da}, {A[187] \[ShortRightArrow] A[174], 
        Da}, {A[187] \[ShortRightArrow] A[179], 
        Da}, {A[187] \[ShortRightArrow] A[189], 
        Da}, {A[187] \[ShortRightArrow] A[191], 
        Da}, {A[187] \[ShortRightArrow] A[205], 
        Da}, {A[188] \[ShortRightArrow] A[145], 
        Da}, {A[188] \[ShortRightArrow] A[160], 
        Da}, {A[188] \[ShortRightArrow] A[164], 
        Da}, {A[188] \[ShortRightArrow] A[186], 
        Da}, {A[188] \[ShortRightArrow] A[198], 
        Da}, {A[188] \[ShortRightArrow] A[201], 
        Da}, {A[188] \[ShortRightArrow] A[218], 
        Da}, {A[189] \[ShortRightArrow] A[173], 
        Da}, {A[189] \[ShortRightArrow] A[174], 
        Da}, {A[189] \[ShortRightArrow] A[184], 
        Da}, {A[189] \[ShortRightArrow] A[187], 
        Da}, {A[189] \[ShortRightArrow] A[202], 
        Da}, {A[189] \[ShortRightArrow] A[205], 
        Da}, {A[190] \[ShortRightArrow] A[161], 
        Da}, {A[190] \[ShortRightArrow] A[175], 
        Da}, {A[190] \[ShortRightArrow] A[186], 
        Da}, {A[190] \[ShortRightArrow] A[198], 
        Da}, {A[190] \[ShortRightArrow] A[199], 
        Da}, {A[190] \[ShortRightArrow] A[207], 
        Da}, {A[190] \[ShortRightArrow] A[215], 
        Da}, {A[191] \[ShortRightArrow] A[179], 
        Da}, {A[191] \[ShortRightArrow] A[187], 
        Da}, {A[191] \[ShortRightArrow] A[192], 
        Da}, {A[191] \[ShortRightArrow] A[205], 
        Da}, {A[191] \[ShortRightArrow] A[206], 
        Da}, {A[191] \[ShortRightArrow] A[216], 
        Da}, {A[192] \[ShortRightArrow] A[169], 
        Da}, {A[192] \[ShortRightArrow] A[179], 
        Da}, {A[192] \[ShortRightArrow] A[191], 
        Da}, {A[192] \[ShortRightArrow] A[193], 
        Da}, {A[192] \[ShortRightArrow] A[206], 
        Da}, {A[193] \[ShortRightArrow] A[169], 
        Da}, {A[193] \[ShortRightArrow] A[177], 
        Da}, {A[193] \[ShortRightArrow] A[192], 
        Da}, {A[193] \[ShortRightArrow] A[194], 
        Da}, {A[193] \[ShortRightArrow] A[206], 
        Da}, {A[194] \[ShortRightArrow] A[177], 
        Da}, {A[194] \[ShortRightArrow] A[180], 
        Da}, {A[194] \[ShortRightArrow] A[193], 
        Da}, {A[194] \[ShortRightArrow] A[204], 
        Da}, {A[194] \[ShortRightArrow] A[206], 
        Da}, {A[195] \[ShortRightArrow] A[183], 
        Da}, {A[195] \[ShortRightArrow] A[184], 
        Da}, {A[195] \[ShortRightArrow] A[199], 
        Da}, {A[195] \[ShortRightArrow] A[202], 
        Da}, {A[195] \[ShortRightArrow] A[213], 
        Da}, {A[195] \[ShortRightArrow] A[222], 
        Da}, {A[196] \[ShortRightArrow] A[180], 
        Da}, {A[196] \[ShortRightArrow] A[181], 
        Da}, {A[196] \[ShortRightArrow] A[200], 
        Da}, {A[196] \[ShortRightArrow] A[204], 
        Da}, {A[196] \[ShortRightArrow] A[211], 
        Da}, {A[196] \[ShortRightArrow] A[214], 
        Da}, {A[197] \[ShortRightArrow] A[176], 
        Da}, {A[197] \[ShortRightArrow] A[185], 
        Da}, {A[197] \[ShortRightArrow] A[201], 
        Da}, {A[197] \[ShortRightArrow] A[208], 
        Da}, {A[197] \[ShortRightArrow] A[209], 
        Da}, {A[198] \[ShortRightArrow] A[186], 
        Da}, {A[198] \[ShortRightArrow] A[188], 
        Da}, {A[198] \[ShortRightArrow] A[190], 
        Da}, {A[198] \[ShortRightArrow] A[215], 
        Da}, {A[198] \[ShortRightArrow] A[218], 
        Da}, {A[199] \[ShortRightArrow] A[175], 
        Da}, {A[199] \[ShortRightArrow] A[183], 
        Da}, {A[199] \[ShortRightArrow] A[190], 
        Da}, {A[199] \[ShortRightArrow] A[195], 
        Da}, {A[199] \[ShortRightArrow] A[207], 
        Da}, {A[199] \[ShortRightArrow] A[212], 
        Da}, {A[199] \[ShortRightArrow] A[222], 
        Da}, {A[200] \[ShortRightArrow] A[181], 
        Da}, {A[200] \[ShortRightArrow] A[182], 
        Da}, {A[200] \[ShortRightArrow] A[196], 
        Da}, {A[200] \[ShortRightArrow] A[211], 
        Da}, {A[201] \[ShortRightArrow] A[164], 
        Da}, {A[201] \[ShortRightArrow] A[176], 
        Da}, {A[201] \[ShortRightArrow] A[188], 
        Da}, {A[201] \[ShortRightArrow] A[197], 
        Da}, {A[201] \[ShortRightArrow] A[209], 
        Da}, {A[201] \[ShortRightArrow] A[218], 
        Da}, {A[201] \[ShortRightArrow] A[220], 
        Da}, {A[202] \[ShortRightArrow] A[184], 
        Da}, {A[202] \[ShortRightArrow] A[189], 
        Da}, {A[202] \[ShortRightArrow] A[195], 
        Da}, {A[202] \[ShortRightArrow] A[205], 
        Da}, {A[202] \[ShortRightArrow] A[210], 
        Da}, {A[202] \[ShortRightArrow] A[213], 
        Da}, {A[203] \[ShortRightArrow] A[178], 
        Da}, {A[203] \[ShortRightArrow] A[185], 
        Da}, {A[203] \[ShortRightArrow] A[208], 
        Da}, {A[203] \[ShortRightArrow] A[219], 
        Da}, {A[204] \[ShortRightArrow] A[180], 
        Da}, {A[204] \[ShortRightArrow] A[194], 
        Da}, {A[204] \[ShortRightArrow] A[196], 
        Da}, {A[204] \[ShortRightArrow] A[206], 
        Da}, {A[204] \[ShortRightArrow] A[214], 
        Da}, {A[204] \[ShortRightArrow] A[217], 
        Da}, {A[205] \[ShortRightArrow] A[187], 
        Da}, {A[205] \[ShortRightArrow] A[189], 
        Da}, {A[205] \[ShortRightArrow] A[191], 
        Da}, {A[205] \[ShortRightArrow] A[202], 
        Da}, {A[205] \[ShortRightArrow] A[210], 
        Da}, {A[205] \[ShortRightArrow] A[216], 
        Da}, {A[205] \[ShortRightArrow] A[225], 
        Da}, {A[206] \[ShortRightArrow] A[191], 
        Da}, {A[206] \[ShortRightArrow] A[192], 
        Da}, {A[206] \[ShortRightArrow] A[193], 
        Da}, {A[206] \[ShortRightArrow] A[194], 
        Da}, {A[206] \[ShortRightArrow] A[204], 
        Da}, {A[206] \[ShortRightArrow] A[216], 
        Da}, {A[206] \[ShortRightArrow] A[217], 
        Da}, {A[206] \[ShortRightArrow] A[221], 
        Da}, {A[207] \[ShortRightArrow] A[190], 
        Da}, {A[207] \[ShortRightArrow] A[199], 
        Da}, {A[207] \[ShortRightArrow] A[212], 
        Da}, {A[207] \[ShortRightArrow] A[215], 
        Da}, {A[208] \[ShortRightArrow] A[185], 
        Da}, {A[208] \[ShortRightArrow] A[197], 
        Da}, {A[208] \[ShortRightArrow] A[203], 
        Da}, {A[208] \[ShortRightArrow] A[209], 
        Da}, {A[208] \[ShortRightArrow] A[219], 
        Da}, {A[208] \[ShortRightArrow] A[226], 
        Da}, {A[209] \[ShortRightArrow] A[197], 
        Da}, {A[209] \[ShortRightArrow] A[201], 
        Da}, {A[209] \[ShortRightArrow] A[208], 
        Da}, {A[209] \[ShortRightArrow] A[220], 
        Da}, {A[209] \[ShortRightArrow] A[226], 
        Da}, {A[209] \[ShortRightArrow] A[227], 
        Da}, {A[210] \[ShortRightArrow] A[202], 
        Da}, {A[210] \[ShortRightArrow] A[205], 
        Da}, {A[210] \[ShortRightArrow] A[213], 
        Da}, {A[210] \[ShortRightArrow] A[224], 
        Da}, {A[210] \[ShortRightArrow] A[225], 
        Da}, {A[211] \[ShortRightArrow] A[196], 
        Da}, {A[211] \[ShortRightArrow] A[200], 
        Da}, {A[211] \[ShortRightArrow] A[214], 
        Da}, {A[212] \[ShortRightArrow] A[199], 
        Da}, {A[212] \[ShortRightArrow] A[207], 
        Da}, {A[212] \[ShortRightArrow] A[215], 
        Da}, {A[212] \[ShortRightArrow] A[222], 
        Da}, {A[212] \[ShortRightArrow] A[223], 
        Da}, {A[212] \[ShortRightArrow] A[230], 
        Da}, {A[213] \[ShortRightArrow] A[195], 
        Da}, {A[213] \[ShortRightArrow] A[202], 
        Da}, {A[213] \[ShortRightArrow] A[210], 
        Da}, {A[213] \[ShortRightArrow] A[222], 
        Da}, {A[213] \[ShortRightArrow] A[224], 
        Da}, {A[214] \[ShortRightArrow] A[196], 
        Da}, {A[214] \[ShortRightArrow] A[204], 
        Da}, {A[214] \[ShortRightArrow] A[211], 
        Da}, {A[214] \[ShortRightArrow] A[217], 
        Da}, {A[215] \[ShortRightArrow] A[190], 
        Da}, {A[215] \[ShortRightArrow] A[198], 
        Da}, {A[215] \[ShortRightArrow] A[207], 
        Da}, {A[215] \[ShortRightArrow] A[212], 
        Da}, {A[215] \[ShortRightArrow] A[218], 
        Da}, {A[215] \[ShortRightArrow] A[228], 
        Da}, {A[215] \[ShortRightArrow] A[230], 
        Da}, {A[215] \[ShortRightArrow] A[232], 
        Da}, {A[215] \[ShortRightArrow] A[233], 
        Da}, {A[215] \[ShortRightArrow] A[235], 
        Da}, {A[216] \[ShortRightArrow] A[191], 
        Da}, {A[216] \[ShortRightArrow] A[205], 
        Da}, {A[216] \[ShortRightArrow] A[206], 
        Da}, {A[216] \[ShortRightArrow] A[221], 
        Da}, {A[216] \[ShortRightArrow] A[225], 
        Da}, {A[216] \[ShortRightArrow] A[234], 
        Da}, {A[217] \[ShortRightArrow] A[204], 
        Da}, {A[217] \[ShortRightArrow] A[206], 
        Da}, {A[217] \[ShortRightArrow] A[214], 
        Da}, {A[217] \[ShortRightArrow] A[221], 
        Da}, {A[218] \[ShortRightArrow] A[188], 
        Da}, {A[218] \[ShortRightArrow] A[198], 
        Da}, {A[218] \[ShortRightArrow] A[201], 
        Da}, {A[218] \[ShortRightArrow] A[215], 
        Da}, {A[218] \[ShortRightArrow] A[220], 
        Da}, {A[218] \[ShortRightArrow] A[228], 
        Da}, {A[218] \[ShortRightArrow] A[229], 
        Da}, {A[219] \[ShortRightArrow] A[203], 
        Da}, {A[219] \[ShortRightArrow] A[208], 
        Da}, {A[219] \[ShortRightArrow] A[226], 
        Da}, {A[219] \[ShortRightArrow] A[237], 
        Da}, {A[220] \[ShortRightArrow] A[201], 
        Da}, {A[220] \[ShortRightArrow] A[209], 
        Da}, {A[220] \[ShortRightArrow] A[218], 
        Da}, {A[220] \[ShortRightArrow] A[227], 
        Da}, {A[220] \[ShortRightArrow] A[229], 
        Da}, {A[221] \[ShortRightArrow] A[206], 
        Da}, {A[221] \[ShortRightArrow] A[216], 
        Da}, {A[221] \[ShortRightArrow] A[217], 
        Da}, {A[222] \[ShortRightArrow] A[195], 
        Da}, {A[222] \[ShortRightArrow] A[199], 
        Da}, {A[222] \[ShortRightArrow] A[212], 
        Da}, {A[222] \[ShortRightArrow] A[213], 
        Da}, {A[222] \[ShortRightArrow] A[223], 
        Da}, {A[222] \[ShortRightArrow] A[224], 
        Da}, {A[222] \[ShortRightArrow] A[231], 
        Da}, {A[223] \[ShortRightArrow] A[212], 
        Da}, {A[223] \[ShortRightArrow] A[222], 
        Da}, {A[223] \[ShortRightArrow] A[230], 
        Da}, {A[223] \[ShortRightArrow] A[231], 
        Da}, {A[223] \[ShortRightArrow] A[236], 
        Da}, {A[223] \[ShortRightArrow] A[238], 
        Da}, {A[224] \[ShortRightArrow] A[210], 
        Da}, {A[224] \[ShortRightArrow] A[213], 
        Da}, {A[224] \[ShortRightArrow] A[222], 
        Da}, {A[224] \[ShortRightArrow] A[225], 
        Da}, {A[224] \[ShortRightArrow] A[231], 
        Da}, {A[225] \[ShortRightArrow] A[205], 
        Da}, {A[225] \[ShortRightArrow] A[210], 
        Da}, {A[225] \[ShortRightArrow] A[216], 
        Da}, {A[225] \[ShortRightArrow] A[224], 
        Da}, {A[225] \[ShortRightArrow] A[231], 
        Da}, {A[225] \[ShortRightArrow] A[234], 
        Da}, {A[226] \[ShortRightArrow] A[208], 
        Da}, {A[226] \[ShortRightArrow] A[209], 
        Da}, {A[226] \[ShortRightArrow] A[219], 
        Da}, {A[226] \[ShortRightArrow] A[227], 
        Da}, {A[226] \[ShortRightArrow] A[237], 
        Da}, {A[226] \[ShortRightArrow] A[239], 
        Da}, {A[227] \[ShortRightArrow] A[209], 
        Da}, {A[227] \[ShortRightArrow] A[220], 
        Da}, {A[227] \[ShortRightArrow] A[226], 
        Da}, {A[227] \[ShortRightArrow] A[229], 
        Da}, {A[227] \[ShortRightArrow] A[239], 
        Da}, {A[228] \[ShortRightArrow] A[215], 
        Da}, {A[228] \[ShortRightArrow] A[218], 
        Da}, {A[228] \[ShortRightArrow] A[229], 
        Da}, {A[228] \[ShortRightArrow] A[235], 
        Da}, {A[228] \[ShortRightArrow] A[240], 
        Da}, {A[229] \[ShortRightArrow] A[218], 
        Da}, {A[229] \[ShortRightArrow] A[220], 
        Da}, {A[229] \[ShortRightArrow] A[227], 
        Da}, {A[229] \[ShortRightArrow] A[228], 
        Da}, {A[229] \[ShortRightArrow] A[239], 
        Da}, {A[229] \[ShortRightArrow] A[240], 
        Da}, {A[229] \[ShortRightArrow] A[242], 
        Da}, {A[230] \[ShortRightArrow] A[212], 
        Da}, {A[230] \[ShortRightArrow] A[215], 
        Da}, {A[230] \[ShortRightArrow] A[223], 
        Da}, {A[230] \[ShortRightArrow] A[232], 
        Da}, {A[230] \[ShortRightArrow] A[236], 
        Da}, {A[230] \[ShortRightArrow] A[245], 
        Da}, {A[231] \[ShortRightArrow] A[222], 
        Da}, {A[231] \[ShortRightArrow] A[223], 
        Da}, {A[231] \[ShortRightArrow] A[224], 
        Da}, {A[231] \[ShortRightArrow] A[225], 
        Da}, {A[231] \[ShortRightArrow] A[234], 
        Da}, {A[231] \[ShortRightArrow] A[238], 
        Da}, {A[231] \[ShortRightArrow] A[244], 
        Da}, {A[232] \[ShortRightArrow] A[215], 
        Da}, {A[232] \[ShortRightArrow] A[230], 
        Da}, {A[232] \[ShortRightArrow] A[233], 
        Da}, {A[232] \[ShortRightArrow] A[245], 
        Da}, {A[233] \[ShortRightArrow] A[215], 
        Da}, {A[233] \[ShortRightArrow] A[232], 
        Da}, {A[233] \[ShortRightArrow] A[235], 
        Da}, {A[233] \[ShortRightArrow] A[241], 
        Da}, {A[233] \[ShortRightArrow] A[245], 
        Da}, {A[234] \[ShortRightArrow] A[216], 
        Da}, {A[234] \[ShortRightArrow] A[225], 
        Da}, {A[234] \[ShortRightArrow] A[231], 
        Da}, {A[234] \[ShortRightArrow] A[244], 
        Da}, {A[235] \[ShortRightArrow] A[215], 
        Da}, {A[235] \[ShortRightArrow] A[228], 
        Da}, {A[235] \[ShortRightArrow] A[233], 
        Da}, {A[235] \[ShortRightArrow] A[240], 
        Da}, {A[235] \[ShortRightArrow] A[241], 
        Da}, {A[235] \[ShortRightArrow] A[243], 
        Da}, {A[236] \[ShortRightArrow] A[223], 
        Da}, {A[236] \[ShortRightArrow] A[230], 
        Da}, {A[236] \[ShortRightArrow] A[238], 
        Da}, {A[236] \[ShortRightArrow] A[245], 
        Da}, {A[236] \[ShortRightArrow] A[248], 
        Da}, {A[237] \[ShortRightArrow] A[219], 
        Da}, {A[237] \[ShortRightArrow] A[226], 
        Da}, {A[237] \[ShortRightArrow] A[239], 
        Da}, {A[237] \[ShortRightArrow] A[249], 
        Da}, {A[238] \[ShortRightArrow] A[223], 
        Da}, {A[238] \[ShortRightArrow] A[231], 
        Da}, {A[238] \[ShortRightArrow] A[236], 
        Da}, {A[238] \[ShortRightArrow] A[244], 
        Da}, {A[238] \[ShortRightArrow] A[246], 
        Da}, {A[238] \[ShortRightArrow] A[248], 
        Da}, {A[239] \[ShortRightArrow] A[226], 
        Da}, {A[239] \[ShortRightArrow] A[227], 
        Da}, {A[239] \[ShortRightArrow] A[229], 
        Da}, {A[239] \[ShortRightArrow] A[237], 
        Da}, {A[239] \[ShortRightArrow] A[242], 
        Da}, {A[239] \[ShortRightArrow] A[249], 
        Da}, {A[239] \[ShortRightArrow] A[250], 
        Da}, {A[240] \[ShortRightArrow] A[228], 
        Da}, {A[240] \[ShortRightArrow] A[229], 
        Da}, {A[240] \[ShortRightArrow] A[235], 
        Da}, {A[240] \[ShortRightArrow] A[242], 
        Da}, {A[240] \[ShortRightArrow] A[243], 
        Da}, {A[240] \[ShortRightArrow] A[247], 
        Da}, {A[241] \[ShortRightArrow] A[233], 
        Da}, {A[241] \[ShortRightArrow] A[235], 
        Da}, {A[241] \[ShortRightArrow] A[243], 
        Da}, {A[241] \[ShortRightArrow] A[245], 
        Da}, {A[241] \[ShortRightArrow] A[247], 
        Da}, {A[241] \[ShortRightArrow] A[251], 
        Da}, {A[241] \[ShortRightArrow] A[253], 
        Da}, {A[242] \[ShortRightArrow] A[229], 
        Da}, {A[242] \[ShortRightArrow] A[239], 
        Da}, {A[242] \[ShortRightArrow] A[240], 
        Da}, {A[242] \[ShortRightArrow] A[247], 
        Da}, {A[242] \[ShortRightArrow] A[250], 
        Da}, {A[242] \[ShortRightArrow] A[252], 
        Da}, {A[243] \[ShortRightArrow] A[235], 
        Da}, {A[243] \[ShortRightArrow] A[240], 
        Da}, {A[243] \[ShortRightArrow] A[241], 
        Da}, {A[243] \[ShortRightArrow] A[247], 
        Da}, {A[244] \[ShortRightArrow] A[231], 
        Da}, {A[244] \[ShortRightArrow] A[234], 
        Da}, {A[244] \[ShortRightArrow] A[238], 
        Da}, {A[244] \[ShortRightArrow] A[246], 
        Da}, {A[245] \[ShortRightArrow] A[230], 
        Da}, {A[245] \[ShortRightArrow] A[232], 
        Da}, {A[245] \[ShortRightArrow] A[233], 
        Da}, {A[245] \[ShortRightArrow] A[236], 
        Da}, {A[245] \[ShortRightArrow] A[241], 
        Da}, {A[245] \[ShortRightArrow] A[248], 
        Da}, {A[245] \[ShortRightArrow] A[251], 
        Da}, {A[246] \[ShortRightArrow] A[238], 
        Da}, {A[246] \[ShortRightArrow] A[244], 
        Da}, {A[246] \[ShortRightArrow] A[248], 
        Da}, {A[247] \[ShortRightArrow] A[240], 
        Da}, {A[247] \[ShortRightArrow] A[241], 
        Da}, {A[247] \[ShortRightArrow] A[242], 
        Da}, {A[247] \[ShortRightArrow] A[243], 
        Da}, {A[247] \[ShortRightArrow] A[252], 
        Da}, {A[247] \[ShortRightArrow] A[253], 
        Da}, {A[248] \[ShortRightArrow] A[236], 
        Da}, {A[248] \[ShortRightArrow] A[238], 
        Da}, {A[248] \[ShortRightArrow] A[245], 
        Da}, {A[248] \[ShortRightArrow] A[246], 
        Da}, {A[249] \[ShortRightArrow] A[237], 
        Da}, {A[249] \[ShortRightArrow] A[239], 
        Da}, {A[249] \[ShortRightArrow] A[250], 
        Da}, {A[250] \[ShortRightArrow] A[239], 
        Da}, {A[250] \[ShortRightArrow] A[242], 
        Da}, {A[250] \[ShortRightArrow] A[249], 
        Da}, {A[250] \[ShortRightArrow] A[252], 
        Da}, {A[251] \[ShortRightArrow] A[241], 
        Da}, {A[251] \[ShortRightArrow] A[245], 
        Da}, {A[251] \[ShortRightArrow] A[253], 
        Da}, {A[252] \[ShortRightArrow] A[242], 
        Da}, {A[252] \[ShortRightArrow] A[247], 
        Da}, {A[252] \[ShortRightArrow] A[250], 
        Da}, {A[252] \[ShortRightArrow] A[253], 
        Da}, {A[253] \[ShortRightArrow] A[241], 
        Da}, {A[253] \[ShortRightArrow] A[247], 
        Da}, {A[253] \[ShortRightArrow] A[251], 
        Da}, {A[253] \[ShortRightArrow] A[252], 
        Da}, {B[1] \[ShortRightArrow] B[2], 
        Db}, {B[1] \[ShortRightArrow] B[3], 
        Db}, {B[1] \[ShortRightArrow] B[8], 
        Db}, {B[2] \[ShortRightArrow] B[1], 
        Db}, {B[2] \[ShortRightArrow] B[4], 
        Db}, {B[2] \[ShortRightArrow] B[5], 
        Db}, {B[2] \[ShortRightArrow] B[8], 
        Db}, {B[3] \[ShortRightArrow] B[1], 
        Db}, {B[3] \[ShortRightArrow] B[6], 
        Db}, {B[3] \[ShortRightArrow] B[7], 
        Db}, {B[3] \[ShortRightArrow] B[8], 
        Db}, {B[4] \[ShortRightArrow] B[2], 
        Db}, {B[4] \[ShortRightArrow] B[5], 
        Db}, {B[4] \[ShortRightArrow] B[9], 
        Db}, {B[4] \[ShortRightArrow] B[10], 
        Db}, {B[5] \[ShortRightArrow] B[2], 
        Db}, {B[5] \[ShortRightArrow] B[4], 
        Db}, {B[5] \[ShortRightArrow] B[8], 
        Db}, {B[5] \[ShortRightArrow] B[9], 
        Db}, {B[5] \[ShortRightArrow] B[14], 
        Db}, {B[6] \[ShortRightArrow] B[3], 
        Db}, {B[6] \[ShortRightArrow] B[7], 
        Db}, {B[6] \[ShortRightArrow] B[11], 
        Db}, {B[6] \[ShortRightArrow] B[12], 
        Db}, {B[6] \[ShortRightArrow] B[22], 
        Db}, {B[7] \[ShortRightArrow] B[3], 
        Db}, {B[7] \[ShortRightArrow] B[6], 
        Db}, {B[7] \[ShortRightArrow] B[8], 
        Db}, {B[7] \[ShortRightArrow] B[11], 
        Db}, {B[7] \[ShortRightArrow] B[13], 
        Db}, {B[8] \[ShortRightArrow] B[1], 
        Db}, {B[8] \[ShortRightArrow] B[2], 
        Db}, {B[8] \[ShortRightArrow] B[3], 
        Db}, {B[8] \[ShortRightArrow] B[5], 
        Db}, {B[8] \[ShortRightArrow] B[7], 
        Db}, {B[8] \[ShortRightArrow] B[13], 
        Db}, {B[8] \[ShortRightArrow] B[14], 
        Db}, {B[8] \[ShortRightArrow] B[17], 
        Db}, {B[9] \[ShortRightArrow] B[4], 
        Db}, {B[9] \[ShortRightArrow] B[5], 
        Db}, {B[9] \[ShortRightArrow] B[10], 
        Db}, {B[9] \[ShortRightArrow] B[14], 
        Db}, {B[9] \[ShortRightArrow] B[18], 
        Db}, {B[9] \[ShortRightArrow] B[27], 
        Db}, {B[10] \[ShortRightArrow] B[4], 
        Db}, {B[10] \[ShortRightArrow] B[9], 
        Db}, {B[10] \[ShortRightArrow] B[18], 
        Db}, {B[10] \[ShortRightArrow] B[19], 
        Db}, {B[10] \[ShortRightArrow] B[28], 
        Db}, {B[11] \[ShortRightArrow] B[6], 
        Db}, {B[11] \[ShortRightArrow] B[7], 
        Db}, {B[11] \[ShortRightArrow] B[13], 
        Db}, {B[11] \[ShortRightArrow] B[22], 
        Db}, {B[11] \[ShortRightArrow] B[24], 
        Db}, {B[11] \[ShortRightArrow] B[25], 
        Db}, {B[11] \[ShortRightArrow] B[26], 
        Db}, {B[12] \[ShortRightArrow] B[6], 
        Db}, {B[12] \[ShortRightArrow] B[16], 
        Db}, {B[12] \[ShortRightArrow] B[22], 
        Db}, {B[12] \[ShortRightArrow] B[30], 
        Db}, {B[13] \[ShortRightArrow] B[7], 
        Db}, {B[13] \[ShortRightArrow] B[8], 
        Db}, {B[13] \[ShortRightArrow] B[11], 
        Db}, {B[13] \[ShortRightArrow] B[17], 
        Db}, {B[13] \[ShortRightArrow] B[26], 
        Db}, {B[13] \[ShortRightArrow] B[39], 
        Db}, {B[14] \[ShortRightArrow] B[5], 
        Db}, {B[14] \[ShortRightArrow] B[8], 
        Db}, {B[14] \[ShortRightArrow] B[9], 
        Db}, {B[14] \[ShortRightArrow] B[17], 
        Db}, {B[14] \[ShortRightArrow] B[23], 
        Db}, {B[14] \[ShortRightArrow] B[27], 
        Db}, {B[14] \[ShortRightArrow] B[33], 
        Db}, {B[15] \[ShortRightArrow] B[20], 
        Db}, {B[15] \[ShortRightArrow] B[21], 
        Db}, {B[15] \[ShortRightArrow] B[29], 
        Db}, {B[15] \[ShortRightArrow] B[34], 
        Db}, {B[15] \[ShortRightArrow] B[35], 
        Db}, {B[16] \[ShortRightArrow] B[12], 
        Db}, {B[16] \[ShortRightArrow] B[30], 
        Db}, {B[17] \[ShortRightArrow] B[8], 
        Db}, {B[17] \[ShortRightArrow] B[13], 
        Db}, {B[17] \[ShortRightArrow] B[14], 
        Db}, {B[17] \[ShortRightArrow] B[23], 
        Db}, {B[17] \[ShortRightArrow] B[39], 
        Db}, {B[17] \[ShortRightArrow] B[53], 
        Db}, {B[17] \[ShortRightArrow] B[54], 
        Db}, {B[18] \[ShortRightArrow] B[9], 
        Db}, {B[18] \[ShortRightArrow] B[10], 
        Db}, {B[18] \[ShortRightArrow] B[27], 
        Db}, {B[18] \[ShortRightArrow] B[28], 
        Db}, {B[18] \[ShortRightArrow] B[31], 
        Db}, {B[19] \[ShortRightArrow] B[10], 
        Db}, {B[19] \[ShortRightArrow] B[20], 
        Db}, {B[19] \[ShortRightArrow] B[28], 
        Db}, {B[19] \[ShortRightArrow] B[32], 
        Db}, {B[19] \[ShortRightArrow] B[38], 
        Db}, {B[19] \[ShortRightArrow] B[40], 
        Db}, {B[20] \[ShortRightArrow] B[15], 
        Db}, {B[20] \[ShortRightArrow] B[19], 
        Db}, {B[20] \[ShortRightArrow] B[34], 
        Db}, {B[20] \[ShortRightArrow] B[40], 
        Db}, {B[21] \[ShortRightArrow] B[15], 
        Db}, {B[21] \[ShortRightArrow] B[29], 
        Db}, {B[21] \[ShortRightArrow] B[36], 
        Db}, {B[21] \[ShortRightArrow] B[47], 
        Db}, {B[22] \[ShortRightArrow] B[6], 
        Db}, {B[22] \[ShortRightArrow] B[11], 
        Db}, {B[22] \[ShortRightArrow] B[12], 
        Db}, {B[22] \[ShortRightArrow] B[24], 
        Db}, {B[22] \[ShortRightArrow] B[37], 
        Db}, {B[22] \[ShortRightArrow] B[43], 
        Db}, {B[23] \[ShortRightArrow] B[14], 
        Db}, {B[23] \[ShortRightArrow] B[17], 
        Db}, {B[23] \[ShortRightArrow] B[33], 
        Db}, {B[23] \[ShortRightArrow] B[45], 
        Db}, {B[23] \[ShortRightArrow] B[54], 
        Db}, {B[24] \[ShortRightArrow] B[11], 
        Db}, {B[24] \[ShortRightArrow] B[22], 
        Db}, {B[24] \[ShortRightArrow] B[25], 
        Db}, {B[24] \[ShortRightArrow] B[37], 
        Db}, {B[25] \[ShortRightArrow] B[11], 
        Db}, {B[25] \[ShortRightArrow] B[24], 
        Db}, {B[25] \[ShortRightArrow] B[26], 
        Db}, {B[25] \[ShortRightArrow] B[37], 
        Db}, {B[25] \[ShortRightArrow] B[39], 
        Db}, {B[26] \[ShortRightArrow] B[11], 
        Db}, {B[26] \[ShortRightArrow] B[13], 
        Db}, {B[26] \[ShortRightArrow] B[25], 
        Db}, {B[26] \[ShortRightArrow] B[39], 
        Db}, {B[27] \[ShortRightArrow] B[9], 
        Db}, {B[27] \[ShortRightArrow] B[14], 
        Db}, {B[27] \[ShortRightArrow] B[18], 
        Db}, {B[27] \[ShortRightArrow] B[31], 
        Db}, {B[27] \[ShortRightArrow] B[33], 
        Db}, {B[28] \[ShortRightArrow] B[10], 
        Db}, {B[28] \[ShortRightArrow] B[18], 
        Db}, {B[28] \[ShortRightArrow] B[19], 
        Db}, {B[28] \[ShortRightArrow] B[31], 
        Db}, {B[28] \[ShortRightArrow] B[32], 
        Db}, {B[28] \[ShortRightArrow] B[44], 
        Db}, {B[29] \[ShortRightArrow] B[15], 
        Db}, {B[29] \[ShortRightArrow] B[21], 
        Db}, {B[29] \[ShortRightArrow] B[35], 
        Db}, {B[29] \[ShortRightArrow] B[47], 
        Db}, {B[29] \[ShortRightArrow] B[49], 
        Db}, {B[29] \[ShortRightArrow] B[57], 
        Db}, {B[30] \[ShortRightArrow] B[12], 
        Db}, {B[30] \[ShortRightArrow] B[16], 
        Db}, {B[30] \[ShortRightArrow] B[43], 
        Db}, {B[30] \[ShortRightArrow] B[50], 
        Db}, {B[31] \[ShortRightArrow] B[18], 
        Db}, {B[31] \[ShortRightArrow] B[27], 
        Db}, {B[31] \[ShortRightArrow] B[28], 
        Db}, {B[31] \[ShortRightArrow] B[33], 
        Db}, {B[31] \[ShortRightArrow] B[44], 
        Db}, {B[31] \[ShortRightArrow] B[46], 
        Db}, {B[32] \[ShortRightArrow] B[19], 
        Db}, {B[32] \[ShortRightArrow] B[28], 
        Db}, {B[32] \[ShortRightArrow] B[38], 
        Db}, {B[32] \[ShortRightArrow] B[44], 
        Db}, {B[33] \[ShortRightArrow] B[14], 
        Db}, {B[33] \[ShortRightArrow] B[23], 
        Db}, {B[33] \[ShortRightArrow] B[27], 
        Db}, {B[33] \[ShortRightArrow] B[31], 
        Db}, {B[33] \[ShortRightArrow] B[45], 
        Db}, {B[33] \[ShortRightArrow] B[46], 
        Db}, {B[34] \[ShortRightArrow] B[15], 
        Db}, {B[34] \[ShortRightArrow] B[20], 
        Db}, {B[34] \[ShortRightArrow] B[35], 
        Db}, {B[34] \[ShortRightArrow] B[40], 
        Db}, {B[34] \[ShortRightArrow] B[41], 
        Db}, {B[34] \[ShortRightArrow] B[51], 
        Db}, {B[34] \[ShortRightArrow] B[52], 
        Db}, {B[35] \[ShortRightArrow] B[15], 
        Db}, {B[35] \[ShortRightArrow] B[29], 
        Db}, {B[35] \[ShortRightArrow] B[34], 
        Db}, {B[35] \[ShortRightArrow] B[41], 
        Db}, {B[35] \[ShortRightArrow] B[57], 
        Db}, {B[35] \[ShortRightArrow] B[60], 
        Db}, {B[36] \[ShortRightArrow] B[21], 
        Db}, {B[36] \[ShortRightArrow] B[42], 
        Db}, {B[36] \[ShortRightArrow] B[47], 
        Db}, {B[36] \[ShortRightArrow] B[48], 
        Db}, {B[37] \[ShortRightArrow] B[22], 
        Db}, {B[37] \[ShortRightArrow] B[24], 
        Db}, {B[37] \[ShortRightArrow] B[25], 
        Db}, {B[37] \[ShortRightArrow] B[39], 
        Db}, {B[37] \[ShortRightArrow] B[43], 
        Db}, {B[37] \[ShortRightArrow] B[59], 
        Db}, {B[38] \[ShortRightArrow] B[19], 
        Db}, {B[38] \[ShortRightArrow] B[32], 
        Db}, {B[38] \[ShortRightArrow] B[40], 
        Db}, {B[38] \[ShortRightArrow] B[44], 
        Db}, {B[38] \[ShortRightArrow] B[56], 
        Db}, {B[38] \[ShortRightArrow] B[67], 
        Db}, {B[39] \[ShortRightArrow] B[13], 
        Db}, {B[39] \[ShortRightArrow] B[17], 
        Db}, {B[39] \[ShortRightArrow] B[25], 
        Db}, {B[39] \[ShortRightArrow] B[26], 
        Db}, {B[39] \[ShortRightArrow] B[37], 
        Db}, {B[39] \[ShortRightArrow] B[53], 
        Db}, {B[39] \[ShortRightArrow] B[59], 
        Db}, {B[39] \[ShortRightArrow] B[65], 
        Db}, {B[40] \[ShortRightArrow] B[19], 
        Db}, {B[40] \[ShortRightArrow] B[20], 
        Db}, {B[40] \[ShortRightArrow] B[34], 
        Db}, {B[40] \[ShortRightArrow] B[38], 
        Db}, {B[40] \[ShortRightArrow] B[51], 
        Db}, {B[40] \[ShortRightArrow] B[56], 
        Db}, {B[41] \[ShortRightArrow] B[34], 
        Db}, {B[41] \[ShortRightArrow] B[35], 
        Db}, {B[41] \[ShortRightArrow] B[52], 
        Db}, {B[41] \[ShortRightArrow] B[60], 
        Db}, {B[42] \[ShortRightArrow] B[36], 
        Db}, {B[42] \[ShortRightArrow] B[48], 
        Db}, {B[42] \[ShortRightArrow] B[58], 
        Db}, {B[43] \[ShortRightArrow] B[22], 
        Db}, {B[43] \[ShortRightArrow] B[30], 
        Db}, {B[43] \[ShortRightArrow] B[37], 
        Db}, {B[43] \[ShortRightArrow] B[50], 
        Db}, {B[43] \[ShortRightArrow] B[59], 
        Db}, {B[43] \[ShortRightArrow] B[61], 
        Db}, {B[43] \[ShortRightArrow] B[64], 
        Db}, {B[44] \[ShortRightArrow] B[28], 
        Db}, {B[44] \[ShortRightArrow] B[31], 
        Db}, {B[44] \[ShortRightArrow] B[32], 
        Db}, {B[44] \[ShortRightArrow] B[38], 
        Db}, {B[44] \[ShortRightArrow] B[46], 
        Db}, {B[44] \[ShortRightArrow] B[55], 
        Db}, {B[44] \[ShortRightArrow] B[66], 
        Db}, {B[44] \[ShortRightArrow] B[67], 
        Db}, {B[45] \[ShortRightArrow] B[23], 
        Db}, {B[45] \[ShortRightArrow] B[33], 
        Db}, {B[45] \[ShortRightArrow] B[46], 
        Db}, {B[45] \[ShortRightArrow] B[54], 
        Db}, {B[45] \[ShortRightArrow] B[75], 
        Db}, {B[46] \[ShortRightArrow] B[31], 
        Db}, {B[46] \[ShortRightArrow] B[33], 
        Db}, {B[46] \[ShortRightArrow] B[44], 
        Db}, {B[46] \[ShortRightArrow] B[45], 
        Db}, {B[46] \[ShortRightArrow] B[55], 
        Db}, {B[46] \[ShortRightArrow] B[68], 
        Db}, {B[46] \[ShortRightArrow] B[69], 
        Db}, {B[47] \[ShortRightArrow] B[21], 
        Db}, {B[47] \[ShortRightArrow] B[29], 
        Db}, {B[47] \[ShortRightArrow] B[36], 
        Db}, {B[47] \[ShortRightArrow] B[48], 
        Db}, {B[47] \[ShortRightArrow] B[49], 
        Db}, {B[47] \[ShortRightArrow] B[63], 
        Db}, {B[48] \[ShortRightArrow] B[36], 
        Db}, {B[48] \[ShortRightArrow] B[42], 
        Db}, {B[48] \[ShortRightArrow] B[47], 
        Db}, {B[48] \[ShortRightArrow] B[58], 
        Db}, {B[48] \[ShortRightArrow] B[63], 
        Db}, {B[48] \[ShortRightArrow] B[73], 
        Db}, {B[48] \[ShortRightArrow] B[77], 
        Db}, {B[49] \[ShortRightArrow] B[29], 
        Db}, {B[49] \[ShortRightArrow] B[47], 
        Db}, {B[49] \[ShortRightArrow] B[57], 
        Db}, {B[49] \[ShortRightArrow] B[63], 
        Db}, {B[49] \[ShortRightArrow] B[76], 
        Db}, {B[50] \[ShortRightArrow] B[30], 
        Db}, {B[50] \[ShortRightArrow] B[43], 
        Db}, {B[50] \[ShortRightArrow] B[61], 
        Db}, {B[50] \[ShortRightArrow] B[82], 
        Db}, {B[51] \[ShortRightArrow] B[34], 
        Db}, {B[51] \[ShortRightArrow] B[40], 
        Db}, {B[51] \[ShortRightArrow] B[52], 
        Db}, {B[51] \[ShortRightArrow] B[56], 
        Db}, {B[51] \[ShortRightArrow] B[71], 
        Db}, {B[51] \[ShortRightArrow] B[72], 
        Db}, {B[51] \[ShortRightArrow] B[84], 
        Db}, {B[52] \[ShortRightArrow] B[34], 
        Db}, {B[52] \[ShortRightArrow] B[41], 
        Db}, {B[52] \[ShortRightArrow] B[51], 
        Db}, {B[52] \[ShortRightArrow] B[60], 
        Db}, {B[52] \[ShortRightArrow] B[72], 
        Db}, {B[53] \[ShortRightArrow] B[17], 
        Db}, {B[53] \[ShortRightArrow] B[39], 
        Db}, {B[53] \[ShortRightArrow] B[54], 
        Db}, {B[53] \[ShortRightArrow] B[65], 
        Db}, {B[53] \[ShortRightArrow] B[70], 
        Db}, {B[53] \[ShortRightArrow] B[74], 
        Db}, {B[54] \[ShortRightArrow] B[17], 
        Db}, {B[54] \[ShortRightArrow] B[23], 
        Db}, {B[54] \[ShortRightArrow] B[45], 
        Db}, {B[54] \[ShortRightArrow] B[53], 
        Db}, {B[54] \[ShortRightArrow] B[74], 
        Db}, {B[54] \[ShortRightArrow] B[75], 
        Db}, {B[55] \[ShortRightArrow] B[44], 
        Db}, {B[55] \[ShortRightArrow] B[46], 
        Db}, {B[55] \[ShortRightArrow] B[66], 
        Db}, {B[55] \[ShortRightArrow] B[69], 
        Db}, {B[55] \[ShortRightArrow] B[86], 
        Db}, {B[56] \[ShortRightArrow] B[38], 
        Db}, {B[56] \[ShortRightArrow] B[40], 
        Db}, {B[56] \[ShortRightArrow] B[51], 
        Db}, {B[56] \[ShortRightArrow] B[62], 
        Db}, {B[56] \[ShortRightArrow] B[67], 
        Db}, {B[56] \[ShortRightArrow] B[71], 
        Db}, {B[57] \[ShortRightArrow] B[29], 
        Db}, {B[57] \[ShortRightArrow] B[35], 
        Db}, {B[57] \[ShortRightArrow] B[49], 
        Db}, {B[57] \[ShortRightArrow] B[60], 
        Db}, {B[57] \[ShortRightArrow] B[76], 
        Db}, {B[57] \[ShortRightArrow] B[81], 
        Db}, {B[57] \[ShortRightArrow] B[85], 
        Db}, {B[58] \[ShortRightArrow] B[42], 
        Db}, {B[58] \[ShortRightArrow] B[48], 
        Db}, {B[58] \[ShortRightArrow] B[77], 
        Db}, {B[58] \[ShortRightArrow] B[78], 
        Db}, {B[59] \[ShortRightArrow] B[37], 
        Db}, {B[59] \[ShortRightArrow] B[39], 
        Db}, {B[59] \[ShortRightArrow] B[43], 
        Db}, {B[59] \[ShortRightArrow] B[64], 
        Db}, {B[59] \[ShortRightArrow] B[65], 
        Db}, {B[59] \[ShortRightArrow] B[83], 
        Db}, {B[59] \[ShortRightArrow] B[87], 
        Db}, {B[60] \[ShortRightArrow] B[35], 
        Db}, {B[60] \[ShortRightArrow] B[41], 
        Db}, {B[60] \[ShortRightArrow] B[52], 
        Db}, {B[60] \[ShortRightArrow] B[57], 
        Db}, {B[60] \[ShortRightArrow] B[72], 
        Db}, {B[60] \[ShortRightArrow] B[80], 
        Db}, {B[60] \[ShortRightArrow] B[85], 
        Db}, {B[61] \[ShortRightArrow] B[43], 
        Db}, {B[61] \[ShortRightArrow] B[50], 
        Db}, {B[61] \[ShortRightArrow] B[64], 
        Db}, {B[61] \[ShortRightArrow] B[82], 
        Db}, {B[61] \[ShortRightArrow] B[89], 
        Db}, {B[61] \[ShortRightArrow] B[96], 
        Db}, {B[62] \[ShortRightArrow] B[56], 
        Db}, {B[62] \[ShortRightArrow] B[67], 
        Db}, {B[62] \[ShortRightArrow] B[71], 
        Db}, {B[62] \[ShortRightArrow] B[79], 
        Db}, {B[63] \[ShortRightArrow] B[47], 
        Db}, {B[63] \[ShortRightArrow] B[48], 
        Db}, {B[63] \[ShortRightArrow] B[49], 
        Db}, {B[63] \[ShortRightArrow] B[73], 
        Db}, {B[63] \[ShortRightArrow] B[76], 
        Db}, {B[64] \[ShortRightArrow] B[43], 
        Db}, {B[64] \[ShortRightArrow] B[59], 
        Db}, {B[64] \[ShortRightArrow] B[61], 
        Db}, {B[64] \[ShortRightArrow] B[83], 
        Db}, {B[64] \[ShortRightArrow] B[96], 
        Db}, {B[65] \[ShortRightArrow] B[39], 
        Db}, {B[65] \[ShortRightArrow] B[53], 
        Db}, {B[65] \[ShortRightArrow] B[59], 
        Db}, {B[65] \[ShortRightArrow] B[70], 
        Db}, {B[65] \[ShortRightArrow] B[87], 
        Db}, {B[65] \[ShortRightArrow] B[97], 
        Db}, {B[65] \[ShortRightArrow] B[100], 
        Db}, {B[66] \[ShortRightArrow] B[44], 
        Db}, {B[66] \[ShortRightArrow] B[55], 
        Db}, {B[66] \[ShortRightArrow] B[67], 
        Db}, {B[66] \[ShortRightArrow] B[79], 
        Db}, {B[66] \[ShortRightArrow] B[86], 
        Db}, {B[66] \[ShortRightArrow] B[91], 
        Db}, {B[67] \[ShortRightArrow] B[38], 
        Db}, {B[67] \[ShortRightArrow] B[44], 
        Db}, {B[67] \[ShortRightArrow] B[56], 
        Db}, {B[67] \[ShortRightArrow] B[62], 
        Db}, {B[67] \[ShortRightArrow] B[66], 
        Db}, {B[67] \[ShortRightArrow] B[79], 
        Db}, {B[68] \[ShortRightArrow] B[46], 
        Db}, {B[68] \[ShortRightArrow] B[69], 
        Db}, {B[68] \[ShortRightArrow] B[75], 
        Db}, {B[68] \[ShortRightArrow] B[94], 
        Db}, {B[69] \[ShortRightArrow] B[46], 
        Db}, {B[69] \[ShortRightArrow] B[55], 
        Db}, {B[69] \[ShortRightArrow] B[68], 
        Db}, {B[69] \[ShortRightArrow] B[86], 
        Db}, {B[69] \[ShortRightArrow] B[94], 
        Db}, {B[69] \[ShortRightArrow] B[98], 
        Db}, {B[70] \[ShortRightArrow] B[53], 
        Db}, {B[70] \[ShortRightArrow] B[65], 
        Db}, {B[70] \[ShortRightArrow] B[74], 
        Db}, {B[70] \[ShortRightArrow] B[93], 
        Db}, {B[70] \[ShortRightArrow] B[97], 
        Db}, {B[71] \[ShortRightArrow] B[51], 
        Db}, {B[71] \[ShortRightArrow] B[56], 
        Db}, {B[71] \[ShortRightArrow] B[62], 
        Db}, {B[71] \[ShortRightArrow] B[79], 
        Db}, {B[71] \[ShortRightArrow] B[84], 
        Db}, {B[72] \[ShortRightArrow] B[51], 
        Db}, {B[72] \[ShortRightArrow] B[52], 
        Db}, {B[72] \[ShortRightArrow] B[60], 
        Db}, {B[72] \[ShortRightArrow] B[80], 
        Db}, {B[72] \[ShortRightArrow] B[84], 
        Db}, {B[72] \[ShortRightArrow] B[102], 
        Db}, {B[73] \[ShortRightArrow] B[48], 
        Db}, {B[73] \[ShortRightArrow] B[63], 
        Db}, {B[73] \[ShortRightArrow] B[76], 
        Db}, {B[73] \[ShortRightArrow] B[77], 
        Db}, {B[73] \[ShortRightArrow] B[92], 
        Db}, {B[74] \[ShortRightArrow] B[53], 
        Db}, {B[74] \[ShortRightArrow] B[54], 
        Db}, {B[74] \[ShortRightArrow] B[70], 
        Db}, {B[74] \[ShortRightArrow] B[75], 
        Db}, {B[74] \[ShortRightArrow] B[90], 
        Db}, {B[74] \[ShortRightArrow] B[93], 
        Db}, {B[75] \[ShortRightArrow] B[45], 
        Db}, {B[75] \[ShortRightArrow] B[54], 
        Db}, {B[75] \[ShortRightArrow] B[68], 
        Db}, {B[75] \[ShortRightArrow] B[74], 
        Db}, {B[75] \[ShortRightArrow] B[90], 
        Db}, {B[75] \[ShortRightArrow] B[94], 
        Db}, {B[76] \[ShortRightArrow] B[49], 
        Db}, {B[76] \[ShortRightArrow] B[57], 
        Db}, {B[76] \[ShortRightArrow] B[63], 
        Db}, {B[76] \[ShortRightArrow] B[73], 
        Db}, {B[76] \[ShortRightArrow] B[81], 
        Db}, {B[76] \[ShortRightArrow] B[92], 
        Db}, {B[76] \[ShortRightArrow] B[95], 
        Db}, {B[77] \[ShortRightArrow] B[48], 
        Db}, {B[77] \[ShortRightArrow] B[58], 
        Db}, {B[77] \[ShortRightArrow] B[73], 
        Db}, {B[77] \[ShortRightArrow] B[78], 
        Db}, {B[77] \[ShortRightArrow] B[92], 
        Db}, {B[77] \[ShortRightArrow] B[103], 
        Db}, {B[77] \[ShortRightArrow] B[107], 
        Db}, {B[78] \[ShortRightArrow] B[58], 
        Db}, {B[78] \[ShortRightArrow] B[77], 
        Db}, {B[78] \[ShortRightArrow] B[107], 
        Db}, {B[79] \[ShortRightArrow] B[62], 
        Db}, {B[79] \[ShortRightArrow] B[66], 
        Db}, {B[79] \[ShortRightArrow] B[67], 
        Db}, {B[79] \[ShortRightArrow] B[71], 
        Db}, {B[79] \[ShortRightArrow] B[84], 
        Db}, {B[79] \[ShortRightArrow] B[91], 
        Db}, {B[79] \[ShortRightArrow] B[99], 
        Db}, {B[79] \[ShortRightArrow] B[101], 
        Db}, {B[80] \[ShortRightArrow] B[60], 
        Db}, {B[80] \[ShortRightArrow] B[72], 
        Db}, {B[80] \[ShortRightArrow] B[85], 
        Db}, {B[80] \[ShortRightArrow] B[88], 
        Db}, {B[80] \[ShortRightArrow] B[102], 
        Db}, {B[80] \[ShortRightArrow] B[110], 
        Db}, {B[81] \[ShortRightArrow] B[57], 
        Db}, {B[81] \[ShortRightArrow] B[76], 
        Db}, {B[81] \[ShortRightArrow] B[85], 
        Db}, {B[81] \[ShortRightArrow] B[95], 
        Db}, {B[82] \[ShortRightArrow] B[50], 
        Db}, {B[82] \[ShortRightArrow] B[61], 
        Db}, {B[82] \[ShortRightArrow] B[89], 
        Db}, {B[82] \[ShortRightArrow] B[113], 
        Db}, {B[83] \[ShortRightArrow] B[59], 
        Db}, {B[83] \[ShortRightArrow] B[64], 
        Db}, {B[83] \[ShortRightArrow] B[87], 
        Db}, {B[83] \[ShortRightArrow] B[96], 
        Db}, {B[83] \[ShortRightArrow] B[100], 
        Db}, {B[83] \[ShortRightArrow] B[123], 
        Db}, {B[84] \[ShortRightArrow] B[51], 
        Db}, {B[84] \[ShortRightArrow] B[71], 
        Db}, {B[84] \[ShortRightArrow] B[72], 
        Db}, {B[84] \[ShortRightArrow] B[79], 
        Db}, {B[84] \[ShortRightArrow] B[101], 
        Db}, {B[84] \[ShortRightArrow] B[102], 
        Db}, {B[84] \[ShortRightArrow] B[109], 
        Db}, {B[85] \[ShortRightArrow] B[57], 
        Db}, {B[85] \[ShortRightArrow] B[60], 
        Db}, {B[85] \[ShortRightArrow] B[80], 
        Db}, {B[85] \[ShortRightArrow] B[81], 
        Db}, {B[85] \[ShortRightArrow] B[88], 
        Db}, {B[85] \[ShortRightArrow] B[95], 
        Db}, {B[86] \[ShortRightArrow] B[55], 
        Db}, {B[86] \[ShortRightArrow] B[66], 
        Db}, {B[86] \[ShortRightArrow] B[69], 
        Db}, {B[86] \[ShortRightArrow] B[91], 
        Db}, {B[86] \[ShortRightArrow] B[98], 
        Db}, {B[86] \[ShortRightArrow] B[106], 
        Db}, {B[87] \[ShortRightArrow] B[59], 
        Db}, {B[87] \[ShortRightArrow] B[65], 
        Db}, {B[87] \[ShortRightArrow] B[83], 
        Db}, {B[87] \[ShortRightArrow] B[100], 
        Db}, {B[88] \[ShortRightArrow] B[80], 
        Db}, {B[88] \[ShortRightArrow] B[85], 
        Db}, {B[88] \[ShortRightArrow] B[95], 
        Db}, {B[88] \[ShortRightArrow] B[110], 
        Db}, {B[88] \[ShortRightArrow] B[112], 
        Db}, {B[88] \[ShortRightArrow] B[120], 
        Db}, {B[89] \[ShortRightArrow] B[61], 
        Db}, {B[89] \[ShortRightArrow] B[82], 
        Db}, {B[89] \[ShortRightArrow] B[96], 
        Db}, {B[89] \[ShortRightArrow] B[113], 
        Db}, {B[90] \[ShortRightArrow] B[74], 
        Db}, {B[90] \[ShortRightArrow] B[75], 
        Db}, {B[90] \[ShortRightArrow] B[93], 
        Db}, {B[90] \[ShortRightArrow] B[105], 
        Db}, {B[90] \[ShortRightArrow] B[108], 
        Db}, {B[90] \[ShortRightArrow] B[116], 
        Db}, {B[91] \[ShortRightArrow] B[66], 
        Db}, {B[91] \[ShortRightArrow] B[79], 
        Db}, {B[91] \[ShortRightArrow] B[86], 
        Db}, {B[91] \[ShortRightArrow] B[99], 
        Db}, {B[91] \[ShortRightArrow] B[106], 
        Db}, {B[91] \[ShortRightArrow] B[118], 
        Db}, {B[92] \[ShortRightArrow] B[73], 
        Db}, {B[92] \[ShortRightArrow] B[76], 
        Db}, {B[92] \[ShortRightArrow] B[77], 
        Db}, {B[92] \[ShortRightArrow] B[95], 
        Db}, {B[92] \[ShortRightArrow] B[103], 
        Db}, {B[92] \[ShortRightArrow] B[111], 
        Db}, {B[93] \[ShortRightArrow] B[70], 
        Db}, {B[93] \[ShortRightArrow] B[74], 
        Db}, {B[93] \[ShortRightArrow] B[90], 
        Db}, {B[93] \[ShortRightArrow] B[97], 
        Db}, {B[93] \[ShortRightArrow] B[104], 
        Db}, {B[93] \[ShortRightArrow] B[105], 
        Db}, {B[93] \[ShortRightArrow] B[115], 
        Db}, {B[94] \[ShortRightArrow] B[68], 
        Db}, {B[94] \[ShortRightArrow] B[69], 
        Db}, {B[94] \[ShortRightArrow] B[75], 
        Db}, {B[94] \[ShortRightArrow] B[98], 
        Db}, {B[94] \[ShortRightArrow] B[108], 
        Db}, {B[94] \[ShortRightArrow] B[117], 
        Db}, {B[95] \[ShortRightArrow] B[76], 
        Db}, {B[95] \[ShortRightArrow] B[81], 
        Db}, {B[95] \[ShortRightArrow] B[85], 
        Db}, {B[95] \[ShortRightArrow] B[88], 
        Db}, {B[95] \[ShortRightArrow] B[92], 
        Db}, {B[95] \[ShortRightArrow] B[111], 
        Db}, {B[95] \[ShortRightArrow] B[120], 
        Db}, {B[95] \[ShortRightArrow] B[121], 
        Db}, {B[96] \[ShortRightArrow] B[61], 
        Db}, {B[96] \[ShortRightArrow] B[64], 
        Db}, {B[96] \[ShortRightArrow] B[83], 
        Db}, {B[96] \[ShortRightArrow] B[89], 
        Db}, {B[96] \[ShortRightArrow] B[113], 
        Db}, {B[96] \[ShortRightArrow] B[123], 
        Db}, {B[96] \[ShortRightArrow] B[127], 
        Db}, {B[97] \[ShortRightArrow] B[65], 
        Db}, {B[97] \[ShortRightArrow] B[70], 
        Db}, {B[97] \[ShortRightArrow] B[93], 
        Db}, {B[97] \[ShortRightArrow] B[100], 
        Db}, {B[97] \[ShortRightArrow] B[104], 
        Db}, {B[97] \[ShortRightArrow] B[124], 
        Db}, {B[98] \[ShortRightArrow] B[69], 
        Db}, {B[98] \[ShortRightArrow] B[86], 
        Db}, {B[98] \[ShortRightArrow] B[94], 
        Db}, {B[98] \[ShortRightArrow] B[106], 
        Db}, {B[98] \[ShortRightArrow] B[117], 
        Db}, {B[98] \[ShortRightArrow] B[125], 
        Db}, {B[99] \[ShortRightArrow] B[79], 
        Db}, {B[99] \[ShortRightArrow] B[91], 
        Db}, {B[99] \[ShortRightArrow] B[101], 
        Db}, {B[99] \[ShortRightArrow] B[118], 
        Db}, {B[99] \[ShortRightArrow] B[119], 
        Db}, {B[100] \[ShortRightArrow] B[65], 
        Db}, {B[100] \[ShortRightArrow] B[83], 
        Db}, {B[100] \[ShortRightArrow] B[87], 
        Db}, {B[100] \[ShortRightArrow] B[97], 
        Db}, {B[100] \[ShortRightArrow] B[114], 
        Db}, {B[100] \[ShortRightArrow] B[123], 
        Db}, {B[100] \[ShortRightArrow] B[124], 
        Db}, {B[100] \[ShortRightArrow] B[132], 
        Db}, {B[101] \[ShortRightArrow] B[79], 
        Db}, {B[101] \[ShortRightArrow] B[84], 
        Db}, {B[101] \[ShortRightArrow] B[99], 
        Db}, {B[101] \[ShortRightArrow] B[109], 
        Db}, {B[101] \[ShortRightArrow] B[119], 
        Db}, {B[101] \[ShortRightArrow] B[131], 
        Db}, {B[102] \[ShortRightArrow] B[72], 
        Db}, {B[102] \[ShortRightArrow] B[80], 
        Db}, {B[102] \[ShortRightArrow] B[84], 
        Db}, {B[102] \[ShortRightArrow] B[109], 
        Db}, {B[102] \[ShortRightArrow] B[110], 
        Db}, {B[102] \[ShortRightArrow] B[129], 
        Db}, {B[103] \[ShortRightArrow] B[77], 
        Db}, {B[103] \[ShortRightArrow] B[92], 
        Db}, {B[103] \[ShortRightArrow] B[107], 
        Db}, {B[103] \[ShortRightArrow] B[111], 
        Db}, {B[103] \[ShortRightArrow] B[136], 
        Db}, {B[103] \[ShortRightArrow] B[137], 
        Db}, {B[104] \[ShortRightArrow] B[93], 
        Db}, {B[104] \[ShortRightArrow] B[97], 
        Db}, {B[104] \[ShortRightArrow] B[115], 
        Db}, {B[104] \[ShortRightArrow] B[124], 
        Db}, {B[104] \[ShortRightArrow] B[128], 
        Db}, {B[104] \[ShortRightArrow] B[130], 
        Db}, {B[105] \[ShortRightArrow] B[90], 
        Db}, {B[105] \[ShortRightArrow] B[93], 
        Db}, {B[105] \[ShortRightArrow] B[115], 
        Db}, {B[105] \[ShortRightArrow] B[116], 
        Db}, {B[106] \[ShortRightArrow] B[86], 
        Db}, {B[106] \[ShortRightArrow] B[91], 
        Db}, {B[106] \[ShortRightArrow] B[98], 
        Db}, {B[106] \[ShortRightArrow] B[118], 
        Db}, {B[106] \[ShortRightArrow] B[125], 
        Db}, {B[107] \[ShortRightArrow] B[77], 
        Db}, {B[107] \[ShortRightArrow] B[78], 
        Db}, {B[107] \[ShortRightArrow] B[103], 
        Db}, {B[107] \[ShortRightArrow] B[122], 
        Db}, {B[107] \[ShortRightArrow] B[137], 
        Db}, {B[108] \[ShortRightArrow] B[90], 
        Db}, {B[108] \[ShortRightArrow] B[94], 
        Db}, {B[108] \[ShortRightArrow] B[116], 
        Db}, {B[108] \[ShortRightArrow] B[117], 
        Db}, {B[109] \[ShortRightArrow] B[84], 
        Db}, {B[109] \[ShortRightArrow] B[101], 
        Db}, {B[109] \[ShortRightArrow] B[102], 
        Db}, {B[109] \[ShortRightArrow] B[129], 
        Db}, {B[109] \[ShortRightArrow] B[131], 
        Db}, {B[110] \[ShortRightArrow] B[80], 
        Db}, {B[110] \[ShortRightArrow] B[88], 
        Db}, {B[110] \[ShortRightArrow] B[102], 
        Db}, {B[110] \[ShortRightArrow] B[112], 
        Db}, {B[110] \[ShortRightArrow] B[129], 
        Db}, {B[111] \[ShortRightArrow] B[92], 
        Db}, {B[111] \[ShortRightArrow] B[95], 
        Db}, {B[111] \[ShortRightArrow] B[103], 
        Db}, {B[111] \[ShortRightArrow] B[121], 
        Db}, {B[111] \[ShortRightArrow] B[136], 
        Db}, {B[112] \[ShortRightArrow] B[88], 
        Db}, {B[112] \[ShortRightArrow] B[110], 
        Db}, {B[112] \[ShortRightArrow] B[120], 
        Db}, {B[112] \[ShortRightArrow] B[129], 
        Db}, {B[112] \[ShortRightArrow] B[144], 
        Db}, {B[112] \[ShortRightArrow] B[149], 
        Db}, {B[113] \[ShortRightArrow] B[82], 
        Db}, {B[113] \[ShortRightArrow] B[89], 
        Db}, {B[113] \[ShortRightArrow] B[96], 
        Db}, {B[113] \[ShortRightArrow] B[127], 
        Db}, {B[113] \[ShortRightArrow] B[134], 
        Db}, {B[114] \[ShortRightArrow] B[100], 
        Db}, {B[114] \[ShortRightArrow] B[124], 
        Db}, {B[114] \[ShortRightArrow] B[132], 
        Db}, {B[114] \[ShortRightArrow] B[145], 
        Db}, {B[115] \[ShortRightArrow] B[93], 
        Db}, {B[115] \[ShortRightArrow] B[104], 
        Db}, {B[115] \[ShortRightArrow] B[105], 
        Db}, {B[115] \[ShortRightArrow] B[116], 
        Db}, {B[115] \[ShortRightArrow] B[130], 
        Db}, {B[115] \[ShortRightArrow] B[142], 
        Db}, {B[116] \[ShortRightArrow] B[90], 
        Db}, {B[116] \[ShortRightArrow] B[105], 
        Db}, {B[116] \[ShortRightArrow] B[108], 
        Db}, {B[116] \[ShortRightArrow] B[115], 
        Db}, {B[116] \[ShortRightArrow] B[117], 
        Db}, {B[116] \[ShortRightArrow] B[143], 
        Db}, {B[117] \[ShortRightArrow] B[94], 
        Db}, {B[117] \[ShortRightArrow] B[98], 
        Db}, {B[117] \[ShortRightArrow] B[108], 
        Db}, {B[117] \[ShortRightArrow] B[116], 
        Db}, {B[117] \[ShortRightArrow] B[125], 
        Db}, {B[117] \[ShortRightArrow] B[143], 
        Db}, {B[117] \[ShortRightArrow] B[154], 
        Db}, {B[118] \[ShortRightArrow] B[91], 
        Db}, {B[118] \[ShortRightArrow] B[99], 
        Db}, {B[118] \[ShortRightArrow] B[106], 
        Db}, {B[118] \[ShortRightArrow] B[119], 
        Db}, {B[118] \[ShortRightArrow] B[125], 
        Db}, {B[118] \[ShortRightArrow] B[135], 
        Db}, {B[119] \[ShortRightArrow] B[99], 
        Db}, {B[119] \[ShortRightArrow] B[101], 
        Db}, {B[119] \[ShortRightArrow] B[118], 
        Db}, {B[119] \[ShortRightArrow] B[131], 
        Db}, {B[119] \[ShortRightArrow] B[135], 
        Db}, {B[120] \[ShortRightArrow] B[88], 
        Db}, {B[120] \[ShortRightArrow] B[95], 
        Db}, {B[120] \[ShortRightArrow] B[112], 
        Db}, {B[120] \[ShortRightArrow] B[121], 
        Db}, {B[120] \[ShortRightArrow] B[126], 
        Db}, {B[120] \[ShortRightArrow] B[149], 
        Db}, {B[121] \[ShortRightArrow] B[95], 
        Db}, {B[121] \[ShortRightArrow] B[111], 
        Db}, {B[121] \[ShortRightArrow] B[120], 
        Db}, {B[121] \[ShortRightArrow] B[126], 
        Db}, {B[121] \[ShortRightArrow] B[136], 
        Db}, {B[121] \[ShortRightArrow] B[138], 
        Db}, {B[121] \[ShortRightArrow] B[139], 
        Db}, {B[122] \[ShortRightArrow] B[107], 
        Db}, {B[122] \[ShortRightArrow] B[137], 
        Db}, {B[122] \[ShortRightArrow] B[150], 
        Db}, {B[123] \[ShortRightArrow] B[83], 
        Db}, {B[123] \[ShortRightArrow] B[96], 
        Db}, {B[123] \[ShortRightArrow] B[100], 
        Db}, {B[123] \[ShortRightArrow] B[127], 
        Db}, {B[123] \[ShortRightArrow] B[132], 
        Db}, {B[123] \[ShortRightArrow] B[141], 
        Db}, {B[124] \[ShortRightArrow] B[97], 
        Db}, {B[124] \[ShortRightArrow] B[100], 
        Db}, {B[124] \[ShortRightArrow] B[104], 
        Db}, {B[124] \[ShortRightArrow] B[114], 
        Db}, {B[124] \[ShortRightArrow] B[128], 
        Db}, {B[124] \[ShortRightArrow] B[140], 
        Db}, {B[124] \[ShortRightArrow] B[145], 
        Db}, {B[125] \[ShortRightArrow] B[98], 
        Db}, {B[125] \[ShortRightArrow] B[106], 
        Db}, {B[125] \[ShortRightArrow] B[117], 
        Db}, {B[125] \[ShortRightArrow] B[118], 
        Db}, {B[125] \[ShortRightArrow] B[135], 
        Db}, {B[125] \[ShortRightArrow] B[154], 
        Db}, {B[125] \[ShortRightArrow] B[155], 
        Db}, {B[125] \[ShortRightArrow] B[162], 
        Db}, {B[126] \[ShortRightArrow] B[120], 
        Db}, {B[126] \[ShortRightArrow] B[121], 
        Db}, {B[126] \[ShortRightArrow] B[138], 
        Db}, {B[126] \[ShortRightArrow] B[149], 
        Db}, {B[127] \[ShortRightArrow] B[96], 
        Db}, {B[127] \[ShortRightArrow] B[113], 
        Db}, {B[127] \[ShortRightArrow] B[123], 
        Db}, {B[127] \[ShortRightArrow] B[134], 
        Db}, {B[127] \[ShortRightArrow] B[141], 
        Db}, {B[128] \[ShortRightArrow] B[104], 
        Db}, {B[128] \[ShortRightArrow] B[124], 
        Db}, {B[128] \[ShortRightArrow] B[130], 
        Db}, {B[128] \[ShortRightArrow] B[140], 
        Db}, {B[129] \[ShortRightArrow] B[102], 
        Db}, {B[129] \[ShortRightArrow] B[109], 
        Db}, {B[129] \[ShortRightArrow] B[110], 
        Db}, {B[129] \[ShortRightArrow] B[112], 
        Db}, {B[129] \[ShortRightArrow] B[131], 
        Db}, {B[129] \[ShortRightArrow] B[133], 
        Db}, {B[129] \[ShortRightArrow] B[144], 
        Db}, {B[130] \[ShortRightArrow] B[104], 
        Db}, {B[130] \[ShortRightArrow] B[115], 
        Db}, {B[130] \[ShortRightArrow] B[128], 
        Db}, {B[130] \[ShortRightArrow] B[140], 
        Db}, {B[130] \[ShortRightArrow] B[142], 
        Db}, {B[130] \[ShortRightArrow] B[146], 
        Db}, {B[130] \[ShortRightArrow] B[156], 
        Db}, {B[131] \[ShortRightArrow] B[101], 
        Db}, {B[131] \[ShortRightArrow] B[109], 
        Db}, {B[131] \[ShortRightArrow] B[119], 
        Db}, {B[131] \[ShortRightArrow] B[129], 
        Db}, {B[131] \[ShortRightArrow] B[133], 
        Db}, {B[131] \[ShortRightArrow] B[135], 
        Db}, {B[131] \[ShortRightArrow] B[147], 
        Db}, {B[131] \[ShortRightArrow] B[148], 
        Db}, {B[131] \[ShortRightArrow] B[158], 
        Db}, {B[132] \[ShortRightArrow] B[100], 
        Db}, {B[132] \[ShortRightArrow] B[114], 
        Db}, {B[132] \[ShortRightArrow] B[123], 
        Db}, {B[132] \[ShortRightArrow] B[141], 
        Db}, {B[132] \[ShortRightArrow] B[145], 
        Db}, {B[132] \[ShortRightArrow] B[164], 
        Db}, {B[133] \[ShortRightArrow] B[129], 
        Db}, {B[133] \[ShortRightArrow] B[131], 
        Db}, {B[133] \[ShortRightArrow] B[144], 
        Db}, {B[133] \[ShortRightArrow] B[148], 
        Db}, {B[134] \[ShortRightArrow] B[113], 
        Db}, {B[134] \[ShortRightArrow] B[127], 
        Db}, {B[134] \[ShortRightArrow] B[141], 
        Db}, {B[134] \[ShortRightArrow] B[152], 
        Db}, {B[134] \[ShortRightArrow] B[153], 
        Db}, {B[135] \[ShortRightArrow] B[118], 
        Db}, {B[135] \[ShortRightArrow] B[119], 
        Db}, {B[135] \[ShortRightArrow] B[125], 
        Db}, {B[135] \[ShortRightArrow] B[131], 
        Db}, {B[135] \[ShortRightArrow] B[147], 
        Db}, {B[135] \[ShortRightArrow] B[155], 
        Db}, {B[136] \[ShortRightArrow] B[103], 
        Db}, {B[136] \[ShortRightArrow] B[111], 
        Db}, {B[136] \[ShortRightArrow] B[121], 
        Db}, {B[136] \[ShortRightArrow] B[137], 
        Db}, {B[136] \[ShortRightArrow] B[139], 
        Db}, {B[136] \[ShortRightArrow] B[157], 
        Db}, {B[136] \[ShortRightArrow] B[159], 
        Db}, {B[137] \[ShortRightArrow] B[103], 
        Db}, {B[137] \[ShortRightArrow] B[107], 
        Db}, {B[137] \[ShortRightArrow] B[122], 
        Db}, {B[137] \[ShortRightArrow] B[136], 
        Db}, {B[137] \[ShortRightArrow] B[150], 
        Db}, {B[137] \[ShortRightArrow] B[159], 
        Db}, {B[137] \[ShortRightArrow] B[171], 
        Db}, {B[138] \[ShortRightArrow] B[121], 
        Db}, {B[138] \[ShortRightArrow] B[126], 
        Db}, {B[138] \[ShortRightArrow] B[139], 
        Db}, {B[138] \[ShortRightArrow] B[149], 
        Db}, {B[138] \[ShortRightArrow] B[157], 
        Db}, {B[138] \[ShortRightArrow] B[163], 
        Db}, {B[138] \[ShortRightArrow] B[170], 
        Db}, {B[139] \[ShortRightArrow] B[121], 
        Db}, {B[139] \[ShortRightArrow] B[136], 
        Db}, {B[139] \[ShortRightArrow] B[138], 
        Db}, {B[139] \[ShortRightArrow] B[157], 
        Db}, {B[140] \[ShortRightArrow] B[124], 
        Db}, {B[140] \[ShortRightArrow] B[128], 
        Db}, {B[140] \[ShortRightArrow] B[130], 
        Db}, {B[140] \[ShortRightArrow] B[145], 
        Db}, {B[140] \[ShortRightArrow] B[156], 
        Db}, {B[141] \[ShortRightArrow] B[123], 
        Db}, {B[141] \[ShortRightArrow] B[127], 
        Db}, {B[141] \[ShortRightArrow] B[132], 
        Db}, {B[141] \[ShortRightArrow] B[134], 
        Db}, {B[141] \[ShortRightArrow] B[153], 
        Db}, {B[141] \[ShortRightArrow] B[164], 
        Db}, {B[142] \[ShortRightArrow] B[115], 
        Db}, {B[142] \[ShortRightArrow] B[130], 
        Db}, {B[142] \[ShortRightArrow] B[143], 
        Db}, {B[142] \[ShortRightArrow] B[146], 
        Db}, {B[142] \[ShortRightArrow] B[151], 
        Db}, {B[143] \[ShortRightArrow] B[116], 
        Db}, {B[143] \[ShortRightArrow] B[117], 
        Db}, {B[143] \[ShortRightArrow] B[142], 
        Db}, {B[143] \[ShortRightArrow] B[151], 
        Db}, {B[143] \[ShortRightArrow] B[154], 
        Db}, {B[144] \[ShortRightArrow] B[112], 
        Db}, {B[144] \[ShortRightArrow] B[129], 
        Db}, {B[144] \[ShortRightArrow] B[133], 
        Db}, {B[144] \[ShortRightArrow] B[148], 
        Db}, {B[144] \[ShortRightArrow] B[149], 
        Db}, {B[144] \[ShortRightArrow] B[165], 
        Db}, {B[144] \[ShortRightArrow] B[169], 
        Db}, {B[145] \[ShortRightArrow] B[114], 
        Db}, {B[145] \[ShortRightArrow] B[124], 
        Db}, {B[145] \[ShortRightArrow] B[132], 
        Db}, {B[145] \[ShortRightArrow] B[140], 
        Db}, {B[145] \[ShortRightArrow] B[156], 
        Db}, {B[145] \[ShortRightArrow] B[160], 
        Db}, {B[145] \[ShortRightArrow] B[164], 
        Db}, {B[145] \[ShortRightArrow] B[188], 
        Db}, {B[146] \[ShortRightArrow] B[130], 
        Db}, {B[146] \[ShortRightArrow] B[142], 
        Db}, {B[146] \[ShortRightArrow] B[151], 
        Db}, {B[146] \[ShortRightArrow] B[156], 
        Db}, {B[146] \[ShortRightArrow] B[161], 
        Db}, {B[147] \[ShortRightArrow] B[131], 
        Db}, {B[147] \[ShortRightArrow] B[135], 
        Db}, {B[147] \[ShortRightArrow] B[155], 
        Db}, {B[147] \[ShortRightArrow] B[158], 
        Db}, {B[147] \[ShortRightArrow] B[167], 
        Db}, {B[148] \[ShortRightArrow] B[131], 
        Db}, {B[148] \[ShortRightArrow] B[133], 
        Db}, {B[148] \[ShortRightArrow] B[144], 
        Db}, {B[148] \[ShortRightArrow] B[158], 
        Db}, {B[148] \[ShortRightArrow] B[168], 
        Db}, {B[148] \[ShortRightArrow] B[169], 
        Db}, {B[149] \[ShortRightArrow] B[112], 
        Db}, {B[149] \[ShortRightArrow] B[120], 
        Db}, {B[149] \[ShortRightArrow] B[126], 
        Db}, {B[149] \[ShortRightArrow] B[138], 
        Db}, {B[149] \[ShortRightArrow] B[144], 
        Db}, {B[149] \[ShortRightArrow] B[163], 
        Db}, {B[149] \[ShortRightArrow] B[165], 
        Db}, {B[150] \[ShortRightArrow] B[122], 
        Db}, {B[150] \[ShortRightArrow] B[137], 
        Db}, {B[150] \[ShortRightArrow] B[171], 
        Db}, {B[151] \[ShortRightArrow] B[142], 
        Db}, {B[151] \[ShortRightArrow] B[143], 
        Db}, {B[151] \[ShortRightArrow] B[146], 
        Db}, {B[151] \[ShortRightArrow] B[154], 
        Db}, {B[151] \[ShortRightArrow] B[161], 
        Db}, {B[151] \[ShortRightArrow] B[166], 
        Db}, {B[151] \[ShortRightArrow] B[175], 
        Db}, {B[152] \[ShortRightArrow] B[134], 
        Db}, {B[152] \[ShortRightArrow] B[153], 
        Db}, {B[152] \[ShortRightArrow] B[172], 
        Db}, {B[152] \[ShortRightArrow] B[178], 
        Db}, {B[153] \[ShortRightArrow] B[134], 
        Db}, {B[153] \[ShortRightArrow] B[141], 
        Db}, {B[153] \[ShortRightArrow] B[152], 
        Db}, {B[153] \[ShortRightArrow] B[164], 
        Db}, {B[153] \[ShortRightArrow] B[172], 
        Db}, {B[153] \[ShortRightArrow] B[176], 
        Db}, {B[154] \[ShortRightArrow] B[117], 
        Db}, {B[154] \[ShortRightArrow] B[125], 
        Db}, {B[154] \[ShortRightArrow] B[143], 
        Db}, {B[154] \[ShortRightArrow] B[151], 
        Db}, {B[154] \[ShortRightArrow] B[162], 
        Db}, {B[154] \[ShortRightArrow] B[166], 
        Db}, {B[155] \[ShortRightArrow] B[125], 
        Db}, {B[155] \[ShortRightArrow] B[135], 
        Db}, {B[155] \[ShortRightArrow] B[147], 
        Db}, {B[155] \[ShortRightArrow] B[162], 
        Db}, {B[155] \[ShortRightArrow] B[167], 
        Db}, {B[155] \[ShortRightArrow] B[173], 
        Db}, {B[156] \[ShortRightArrow] B[130], 
        Db}, {B[156] \[ShortRightArrow] B[140], 
        Db}, {B[156] \[ShortRightArrow] B[145], 
        Db}, {B[156] \[ShortRightArrow] B[146], 
        Db}, {B[156] \[ShortRightArrow] B[160], 
        Db}, {B[156] \[ShortRightArrow] B[161], 
        Db}, {B[157] \[ShortRightArrow] B[136], 
        Db}, {B[157] \[ShortRightArrow] B[138], 
        Db}, {B[157] \[ShortRightArrow] B[139], 
        Db}, {B[157] \[ShortRightArrow] B[159], 
        Db}, {B[157] \[ShortRightArrow] B[170], 
        Db}, {B[158] \[ShortRightArrow] B[131], 
        Db}, {B[158] \[ShortRightArrow] B[147], 
        Db}, {B[158] \[ShortRightArrow] B[148], 
        Db}, {B[158] \[ShortRightArrow] B[167], 
        Db}, {B[158] \[ShortRightArrow] B[168], 
        Db}, {B[158] \[ShortRightArrow] B[179], 
        Db}, {B[159] \[ShortRightArrow] B[136], 
        Db}, {B[159] \[ShortRightArrow] B[137], 
        Db}, {B[159] \[ShortRightArrow] B[157], 
        Db}, {B[159] \[ShortRightArrow] B[170], 
        Db}, {B[159] \[ShortRightArrow] B[171], 
        Db}, {B[159] \[ShortRightArrow] B[181], 
        Db}, {B[159] \[ShortRightArrow] B[182], 
        Db}, {B[160] \[ShortRightArrow] B[145], 
        Db}, {B[160] \[ShortRightArrow] B[156], 
        Db}, {B[160] \[ShortRightArrow] B[161], 
        Db}, {B[160] \[ShortRightArrow] B[186], 
        Db}, {B[160] \[ShortRightArrow] B[188], 
        Db}, {B[161] \[ShortRightArrow] B[146], 
        Db}, {B[161] \[ShortRightArrow] B[151], 
        Db}, {B[161] \[ShortRightArrow] B[156], 
        Db}, {B[161] \[ShortRightArrow] B[160], 
        Db}, {B[161] \[ShortRightArrow] B[175], 
        Db}, {B[161] \[ShortRightArrow] B[186], 
        Db}, {B[161] \[ShortRightArrow] B[190], 
        Db}, {B[162] \[ShortRightArrow] B[125], 
        Db}, {B[162] \[ShortRightArrow] B[154], 
        Db}, {B[162] \[ShortRightArrow] B[155], 
        Db}, {B[162] \[ShortRightArrow] B[166], 
        Db}, {B[162] \[ShortRightArrow] B[173], 
        Db}, {B[162] \[ShortRightArrow] B[183], 
        Db}, {B[162] \[ShortRightArrow] B[184], 
        Db}, {B[163] \[ShortRightArrow] B[138], 
        Db}, {B[163] \[ShortRightArrow] B[149], 
        Db}, {B[163] \[ShortRightArrow] B[165], 
        Db}, {B[163] \[ShortRightArrow] B[170], 
        Db}, {B[163] \[ShortRightArrow] B[180], 
        Db}, {B[164] \[ShortRightArrow] B[132], 
        Db}, {B[164] \[ShortRightArrow] B[141], 
        Db}, {B[164] \[ShortRightArrow] B[145], 
        Db}, {B[164] \[ShortRightArrow] B[153], 
        Db}, {B[164] \[ShortRightArrow] B[176], 
        Db}, {B[164] \[ShortRightArrow] B[188], 
        Db}, {B[164] \[ShortRightArrow] B[201], 
        Db}, {B[165] \[ShortRightArrow] B[144], 
        Db}, {B[165] \[ShortRightArrow] B[149], 
        Db}, {B[165] \[ShortRightArrow] B[163], 
        Db}, {B[165] \[ShortRightArrow] B[169], 
        Db}, {B[165] \[ShortRightArrow] B[177], 
        Db}, {B[165] \[ShortRightArrow] B[180], 
        Db}, {B[166] \[ShortRightArrow] B[151], 
        Db}, {B[166] \[ShortRightArrow] B[154], 
        Db}, {B[166] \[ShortRightArrow] B[162], 
        Db}, {B[166] \[ShortRightArrow] B[175], 
        Db}, {B[166] \[ShortRightArrow] B[183], 
        Db}, {B[167] \[ShortRightArrow] B[147], 
        Db}, {B[167] \[ShortRightArrow] B[155], 
        Db}, {B[167] \[ShortRightArrow] B[158], 
        Db}, {B[167] \[ShortRightArrow] B[173], 
        Db}, {B[167] \[ShortRightArrow] B[174], 
        Db}, {B[167] \[ShortRightArrow] B[179], 
        Db}, {B[168] \[ShortRightArrow] B[148], 
        Db}, {B[168] \[ShortRightArrow] B[158], 
        Db}, {B[168] \[ShortRightArrow] B[169], 
        Db}, {B[168] \[ShortRightArrow] B[179], 
        Db}, {B[169] \[ShortRightArrow] B[144], 
        Db}, {B[169] \[ShortRightArrow] B[148], 
        Db}, {B[169] \[ShortRightArrow] B[165], 
        Db}, {B[169] \[ShortRightArrow] B[168], 
        Db}, {B[169] \[ShortRightArrow] B[177], 
        Db}, {B[169] \[ShortRightArrow] B[179], 
        Db}, {B[169] \[ShortRightArrow] B[192], 
        Db}, {B[169] \[ShortRightArrow] B[193], 
        Db}, {B[170] \[ShortRightArrow] B[138], 
        Db}, {B[170] \[ShortRightArrow] B[157], 
        Db}, {B[170] \[ShortRightArrow] B[159], 
        Db}, {B[170] \[ShortRightArrow] B[163], 
        Db}, {B[170] \[ShortRightArrow] B[180], 
        Db}, {B[170] \[ShortRightArrow] B[181], 
        Db}, {B[171] \[ShortRightArrow] B[137], 
        Db}, {B[171] \[ShortRightArrow] B[150], 
        Db}, {B[171] \[ShortRightArrow] B[159], 
        Db}, {B[171] \[ShortRightArrow] B[182], 
        Db}, {B[172] \[ShortRightArrow] B[152], 
        Db}, {B[172] \[ShortRightArrow] B[153], 
        Db}, {B[172] \[ShortRightArrow] B[176], 
        Db}, {B[172] \[ShortRightArrow] B[178], 
        Db}, {B[172] \[ShortRightArrow] B[185], 
        Db}, {B[173] \[ShortRightArrow] B[155], 
        Db}, {B[173] \[ShortRightArrow] B[162], 
        Db}, {B[173] \[ShortRightArrow] B[167], 
        Db}, {B[173] \[ShortRightArrow] B[174], 
        Db}, {B[173] \[ShortRightArrow] B[184], 
        Db}, {B[173] \[ShortRightArrow] B[189], 
        Db}, {B[174] \[ShortRightArrow] B[167], 
        Db}, {B[174] \[ShortRightArrow] B[173], 
        Db}, {B[174] \[ShortRightArrow] B[179], 
        Db}, {B[174] \[ShortRightArrow] B[187], 
        Db}, {B[174] \[ShortRightArrow] B[189], 
        Db}, {B[175] \[ShortRightArrow] B[151], 
        Db}, {B[175] \[ShortRightArrow] B[161], 
        Db}, {B[175] \[ShortRightArrow] B[166], 
        Db}, {B[175] \[ShortRightArrow] B[183], 
        Db}, {B[175] \[ShortRightArrow] B[190], 
        Db}, {B[175] \[ShortRightArrow] B[199], 
        Db}, {B[176] \[ShortRightArrow] B[153], 
        Db}, {B[176] \[ShortRightArrow] B[164], 
        Db}, {B[176] \[ShortRightArrow] B[172], 
        Db}, {B[176] \[ShortRightArrow] B[185], 
        Db}, {B[176] \[ShortRightArrow] B[197], 
        Db}, {B[176] \[ShortRightArrow] B[201], 
        Db}, {B[177] \[ShortRightArrow] B[165], 
        Db}, {B[177] \[ShortRightArrow] B[169], 
        Db}, {B[177] \[ShortRightArrow] B[180], 
        Db}, {B[177] \[ShortRightArrow] B[193], 
        Db}, {B[177] \[ShortRightArrow] B[194], 
        Db}, {B[178] \[ShortRightArrow] B[152], 
        Db}, {B[178] \[ShortRightArrow] B[172], 
        Db}, {B[178] \[ShortRightArrow] B[185], 
        Db}, {B[178] \[ShortRightArrow] B[203], 
        Db}, {B[179] \[ShortRightArrow] B[158], 
        Db}, {B[179] \[ShortRightArrow] B[167], 
        Db}, {B[179] \[ShortRightArrow] B[168], 
        Db}, {B[179] \[ShortRightArrow] B[169], 
        Db}, {B[179] \[ShortRightArrow] B[174], 
        Db}, {B[179] \[ShortRightArrow] B[187], 
        Db}, {B[179] \[ShortRightArrow] B[191], 
        Db}, {B[179] \[ShortRightArrow] B[192], 
        Db}, {B[180] \[ShortRightArrow] B[163], 
        Db}, {B[180] \[ShortRightArrow] B[165], 
        Db}, {B[180] \[ShortRightArrow] B[170], 
        Db}, {B[180] \[ShortRightArrow] B[177], 
        Db}, {B[180] \[ShortRightArrow] B[181], 
        Db}, {B[180] \[ShortRightArrow] B[194], 
        Db}, {B[180] \[ShortRightArrow] B[196], 
        Db}, {B[180] \[ShortRightArrow] B[204], 
        Db}, {B[181] \[ShortRightArrow] B[159], 
        Db}, {B[181] \[ShortRightArrow] B[170], 
        Db}, {B[181] \[ShortRightArrow] B[180], 
        Db}, {B[181] \[ShortRightArrow] B[182], 
        Db}, {B[181] \[ShortRightArrow] B[196], 
        Db}, {B[181] \[ShortRightArrow] B[200], 
        Db}, {B[182] \[ShortRightArrow] B[159], 
        Db}, {B[182] \[ShortRightArrow] B[171], 
        Db}, {B[182] \[ShortRightArrow] B[181], 
        Db}, {B[182] \[ShortRightArrow] B[200], 
        Db}, {B[183] \[ShortRightArrow] B[162], 
        Db}, {B[183] \[ShortRightArrow] B[166], 
        Db}, {B[183] \[ShortRightArrow] B[175], 
        Db}, {B[183] \[ShortRightArrow] B[184], 
        Db}, {B[183] \[ShortRightArrow] B[195], 
        Db}, {B[183] \[ShortRightArrow] B[199], 
        Db}, {B[184] \[ShortRightArrow] B[162], 
        Db}, {B[184] \[ShortRightArrow] B[173], 
        Db}, {B[184] \[ShortRightArrow] B[183], 
        Db}, {B[184] \[ShortRightArrow] B[189], 
        Db}, {B[184] \[ShortRightArrow] B[195], 
        Db}, {B[184] \[ShortRightArrow] B[202], 
        Db}, {B[185] \[ShortRightArrow] B[172], 
        Db}, {B[185] \[ShortRightArrow] B[176], 
        Db}, {B[185] \[ShortRightArrow] B[178], 
        Db}, {B[185] \[ShortRightArrow] B[197], 
        Db}, {B[185] \[ShortRightArrow] B[203], 
        Db}, {B[185] \[ShortRightArrow] B[208], 
        Db}, {B[186] \[ShortRightArrow] B[160], 
        Db}, {B[186] \[ShortRightArrow] B[161], 
        Db}, {B[186] \[ShortRightArrow] B[188], 
        Db}, {B[186] \[ShortRightArrow] B[190], 
        Db}, {B[186] \[ShortRightArrow] B[198], 
        Db}, {B[187] \[ShortRightArrow] B[174], 
        Db}, {B[187] \[ShortRightArrow] B[179], 
        Db}, {B[187] \[ShortRightArrow] B[189], 
        Db}, {B[187] \[ShortRightArrow] B[191], 
        Db}, {B[187] \[ShortRightArrow] B[205], 
        Db}, {B[188] \[ShortRightArrow] B[145], 
        Db}, {B[188] \[ShortRightArrow] B[160], 
        Db}, {B[188] \[ShortRightArrow] B[164], 
        Db}, {B[188] \[ShortRightArrow] B[186], 
        Db}, {B[188] \[ShortRightArrow] B[198], 
        Db}, {B[188] \[ShortRightArrow] B[201], 
        Db}, {B[188] \[ShortRightArrow] B[218], 
        Db}, {B[189] \[ShortRightArrow] B[173], 
        Db}, {B[189] \[ShortRightArrow] B[174], 
        Db}, {B[189] \[ShortRightArrow] B[184], 
        Db}, {B[189] \[ShortRightArrow] B[187], 
        Db}, {B[189] \[ShortRightArrow] B[202], 
        Db}, {B[189] \[ShortRightArrow] B[205], 
        Db}, {B[190] \[ShortRightArrow] B[161], 
        Db}, {B[190] \[ShortRightArrow] B[175], 
        Db}, {B[190] \[ShortRightArrow] B[186], 
        Db}, {B[190] \[ShortRightArrow] B[198], 
        Db}, {B[190] \[ShortRightArrow] B[199], 
        Db}, {B[190] \[ShortRightArrow] B[207], 
        Db}, {B[190] \[ShortRightArrow] B[215], 
        Db}, {B[191] \[ShortRightArrow] B[179], 
        Db}, {B[191] \[ShortRightArrow] B[187], 
        Db}, {B[191] \[ShortRightArrow] B[192], 
        Db}, {B[191] \[ShortRightArrow] B[205], 
        Db}, {B[191] \[ShortRightArrow] B[206], 
        Db}, {B[191] \[ShortRightArrow] B[216], 
        Db}, {B[192] \[ShortRightArrow] B[169], 
        Db}, {B[192] \[ShortRightArrow] B[179], 
        Db}, {B[192] \[ShortRightArrow] B[191], 
        Db}, {B[192] \[ShortRightArrow] B[193], 
        Db}, {B[192] \[ShortRightArrow] B[206], 
        Db}, {B[193] \[ShortRightArrow] B[169], 
        Db}, {B[193] \[ShortRightArrow] B[177], 
        Db}, {B[193] \[ShortRightArrow] B[192], 
        Db}, {B[193] \[ShortRightArrow] B[194], 
        Db}, {B[193] \[ShortRightArrow] B[206], 
        Db}, {B[194] \[ShortRightArrow] B[177], 
        Db}, {B[194] \[ShortRightArrow] B[180], 
        Db}, {B[194] \[ShortRightArrow] B[193], 
        Db}, {B[194] \[ShortRightArrow] B[204], 
        Db}, {B[194] \[ShortRightArrow] B[206], 
        Db}, {B[195] \[ShortRightArrow] B[183], 
        Db}, {B[195] \[ShortRightArrow] B[184], 
        Db}, {B[195] \[ShortRightArrow] B[199], 
        Db}, {B[195] \[ShortRightArrow] B[202], 
        Db}, {B[195] \[ShortRightArrow] B[213], 
        Db}, {B[195] \[ShortRightArrow] B[222], 
        Db}, {B[196] \[ShortRightArrow] B[180], 
        Db}, {B[196] \[ShortRightArrow] B[181], 
        Db}, {B[196] \[ShortRightArrow] B[200], 
        Db}, {B[196] \[ShortRightArrow] B[204], 
        Db}, {B[196] \[ShortRightArrow] B[211], 
        Db}, {B[196] \[ShortRightArrow] B[214], 
        Db}, {B[197] \[ShortRightArrow] B[176], 
        Db}, {B[197] \[ShortRightArrow] B[185], 
        Db}, {B[197] \[ShortRightArrow] B[201], 
        Db}, {B[197] \[ShortRightArrow] B[208], 
        Db}, {B[197] \[ShortRightArrow] B[209], 
        Db}, {B[198] \[ShortRightArrow] B[186], 
        Db}, {B[198] \[ShortRightArrow] B[188], 
        Db}, {B[198] \[ShortRightArrow] B[190], 
        Db}, {B[198] \[ShortRightArrow] B[215], 
        Db}, {B[198] \[ShortRightArrow] B[218], 
        Db}, {B[199] \[ShortRightArrow] B[175], 
        Db}, {B[199] \[ShortRightArrow] B[183], 
        Db}, {B[199] \[ShortRightArrow] B[190], 
        Db}, {B[199] \[ShortRightArrow] B[195], 
        Db}, {B[199] \[ShortRightArrow] B[207], 
        Db}, {B[199] \[ShortRightArrow] B[212], 
        Db}, {B[199] \[ShortRightArrow] B[222], 
        Db}, {B[200] \[ShortRightArrow] B[181], 
        Db}, {B[200] \[ShortRightArrow] B[182], 
        Db}, {B[200] \[ShortRightArrow] B[196], 
        Db}, {B[200] \[ShortRightArrow] B[211], 
        Db}, {B[201] \[ShortRightArrow] B[164], 
        Db}, {B[201] \[ShortRightArrow] B[176], 
        Db}, {B[201] \[ShortRightArrow] B[188], 
        Db}, {B[201] \[ShortRightArrow] B[197], 
        Db}, {B[201] \[ShortRightArrow] B[209], 
        Db}, {B[201] \[ShortRightArrow] B[218], 
        Db}, {B[201] \[ShortRightArrow] B[220], 
        Db}, {B[202] \[ShortRightArrow] B[184], 
        Db}, {B[202] \[ShortRightArrow] B[189], 
        Db}, {B[202] \[ShortRightArrow] B[195], 
        Db}, {B[202] \[ShortRightArrow] B[205], 
        Db}, {B[202] \[ShortRightArrow] B[210], 
        Db}, {B[202] \[ShortRightArrow] B[213], 
        Db}, {B[203] \[ShortRightArrow] B[178], 
        Db}, {B[203] \[ShortRightArrow] B[185], 
        Db}, {B[203] \[ShortRightArrow] B[208], 
        Db}, {B[203] \[ShortRightArrow] B[219], 
        Db}, {B[204] \[ShortRightArrow] B[180], 
        Db}, {B[204] \[ShortRightArrow] B[194], 
        Db}, {B[204] \[ShortRightArrow] B[196], 
        Db}, {B[204] \[ShortRightArrow] B[206], 
        Db}, {B[204] \[ShortRightArrow] B[214], 
        Db}, {B[204] \[ShortRightArrow] B[217], 
        Db}, {B[205] \[ShortRightArrow] B[187], 
        Db}, {B[205] \[ShortRightArrow] B[189], 
        Db}, {B[205] \[ShortRightArrow] B[191], 
        Db}, {B[205] \[ShortRightArrow] B[202], 
        Db}, {B[205] \[ShortRightArrow] B[210], 
        Db}, {B[205] \[ShortRightArrow] B[216], 
        Db}, {B[205] \[ShortRightArrow] B[225], 
        Db}, {B[206] \[ShortRightArrow] B[191], 
        Db}, {B[206] \[ShortRightArrow] B[192], 
        Db}, {B[206] \[ShortRightArrow] B[193], 
        Db}, {B[206] \[ShortRightArrow] B[194], 
        Db}, {B[206] \[ShortRightArrow] B[204], 
        Db}, {B[206] \[ShortRightArrow] B[216], 
        Db}, {B[206] \[ShortRightArrow] B[217], 
        Db}, {B[206] \[ShortRightArrow] B[221], 
        Db}, {B[207] \[ShortRightArrow] B[190], 
        Db}, {B[207] \[ShortRightArrow] B[199], 
        Db}, {B[207] \[ShortRightArrow] B[212], 
        Db}, {B[207] \[ShortRightArrow] B[215], 
        Db}, {B[208] \[ShortRightArrow] B[185], 
        Db}, {B[208] \[ShortRightArrow] B[197], 
        Db}, {B[208] \[ShortRightArrow] B[203], 
        Db}, {B[208] \[ShortRightArrow] B[209], 
        Db}, {B[208] \[ShortRightArrow] B[219], 
        Db}, {B[208] \[ShortRightArrow] B[226], 
        Db}, {B[209] \[ShortRightArrow] B[197], 
        Db}, {B[209] \[ShortRightArrow] B[201], 
        Db}, {B[209] \[ShortRightArrow] B[208], 
        Db}, {B[209] \[ShortRightArrow] B[220], 
        Db}, {B[209] \[ShortRightArrow] B[226], 
        Db}, {B[209] \[ShortRightArrow] B[227], 
        Db}, {B[210] \[ShortRightArrow] B[202], 
        Db}, {B[210] \[ShortRightArrow] B[205], 
        Db}, {B[210] \[ShortRightArrow] B[213], 
        Db}, {B[210] \[ShortRightArrow] B[224], 
        Db}, {B[210] \[ShortRightArrow] B[225], 
        Db}, {B[211] \[ShortRightArrow] B[196], 
        Db}, {B[211] \[ShortRightArrow] B[200], 
        Db}, {B[211] \[ShortRightArrow] B[214], 
        Db}, {B[212] \[ShortRightArrow] B[199], 
        Db}, {B[212] \[ShortRightArrow] B[207], 
        Db}, {B[212] \[ShortRightArrow] B[215], 
        Db}, {B[212] \[ShortRightArrow] B[222], 
        Db}, {B[212] \[ShortRightArrow] B[223], 
        Db}, {B[212] \[ShortRightArrow] B[230], 
        Db}, {B[213] \[ShortRightArrow] B[195], 
        Db}, {B[213] \[ShortRightArrow] B[202], 
        Db}, {B[213] \[ShortRightArrow] B[210], 
        Db}, {B[213] \[ShortRightArrow] B[222], 
        Db}, {B[213] \[ShortRightArrow] B[224], 
        Db}, {B[214] \[ShortRightArrow] B[196], 
        Db}, {B[214] \[ShortRightArrow] B[204], 
        Db}, {B[214] \[ShortRightArrow] B[211], 
        Db}, {B[214] \[ShortRightArrow] B[217], 
        Db}, {B[215] \[ShortRightArrow] B[190], 
        Db}, {B[215] \[ShortRightArrow] B[198], 
        Db}, {B[215] \[ShortRightArrow] B[207], 
        Db}, {B[215] \[ShortRightArrow] B[212], 
        Db}, {B[215] \[ShortRightArrow] B[218], 
        Db}, {B[215] \[ShortRightArrow] B[228], 
        Db}, {B[215] \[ShortRightArrow] B[230], 
        Db}, {B[215] \[ShortRightArrow] B[232], 
        Db}, {B[215] \[ShortRightArrow] B[233], 
        Db}, {B[215] \[ShortRightArrow] B[235], 
        Db}, {B[216] \[ShortRightArrow] B[191], 
        Db}, {B[216] \[ShortRightArrow] B[205], 
        Db}, {B[216] \[ShortRightArrow] B[206], 
        Db}, {B[216] \[ShortRightArrow] B[221], 
        Db}, {B[216] \[ShortRightArrow] B[225], 
        Db}, {B[216] \[ShortRightArrow] B[234], 
        Db}, {B[217] \[ShortRightArrow] B[204], 
        Db}, {B[217] \[ShortRightArrow] B[206], 
        Db}, {B[217] \[ShortRightArrow] B[214], 
        Db}, {B[217] \[ShortRightArrow] B[221], 
        Db}, {B[218] \[ShortRightArrow] B[188], 
        Db}, {B[218] \[ShortRightArrow] B[198], 
        Db}, {B[218] \[ShortRightArrow] B[201], 
        Db}, {B[218] \[ShortRightArrow] B[215], 
        Db}, {B[218] \[ShortRightArrow] B[220], 
        Db}, {B[218] \[ShortRightArrow] B[228], 
        Db}, {B[218] \[ShortRightArrow] B[229], 
        Db}, {B[219] \[ShortRightArrow] B[203], 
        Db}, {B[219] \[ShortRightArrow] B[208], 
        Db}, {B[219] \[ShortRightArrow] B[226], 
        Db}, {B[219] \[ShortRightArrow] B[237], 
        Db}, {B[220] \[ShortRightArrow] B[201], 
        Db}, {B[220] \[ShortRightArrow] B[209], 
        Db}, {B[220] \[ShortRightArrow] B[218], 
        Db}, {B[220] \[ShortRightArrow] B[227], 
        Db}, {B[220] \[ShortRightArrow] B[229], 
        Db}, {B[221] \[ShortRightArrow] B[206], 
        Db}, {B[221] \[ShortRightArrow] B[216], 
        Db}, {B[221] \[ShortRightArrow] B[217], 
        Db}, {B[222] \[ShortRightArrow] B[195], 
        Db}, {B[222] \[ShortRightArrow] B[199], 
        Db}, {B[222] \[ShortRightArrow] B[212], 
        Db}, {B[222] \[ShortRightArrow] B[213], 
        Db}, {B[222] \[ShortRightArrow] B[223], 
        Db}, {B[222] \[ShortRightArrow] B[224], 
        Db}, {B[222] \[ShortRightArrow] B[231], 
        Db}, {B[223] \[ShortRightArrow] B[212], 
        Db}, {B[223] \[ShortRightArrow] B[222], 
        Db}, {B[223] \[ShortRightArrow] B[230], 
        Db}, {B[223] \[ShortRightArrow] B[231], 
        Db}, {B[223] \[ShortRightArrow] B[236], 
        Db}, {B[223] \[ShortRightArrow] B[238], 
        Db}, {B[224] \[ShortRightArrow] B[210], 
        Db}, {B[224] \[ShortRightArrow] B[213], 
        Db}, {B[224] \[ShortRightArrow] B[222], 
        Db}, {B[224] \[ShortRightArrow] B[225], 
        Db}, {B[224] \[ShortRightArrow] B[231], 
        Db}, {B[225] \[ShortRightArrow] B[205], 
        Db}, {B[225] \[ShortRightArrow] B[210], 
        Db}, {B[225] \[ShortRightArrow] B[216], 
        Db}, {B[225] \[ShortRightArrow] B[224], 
        Db}, {B[225] \[ShortRightArrow] B[231], 
        Db}, {B[225] \[ShortRightArrow] B[234], 
        Db}, {B[226] \[ShortRightArrow] B[208], 
        Db}, {B[226] \[ShortRightArrow] B[209], 
        Db}, {B[226] \[ShortRightArrow] B[219], 
        Db}, {B[226] \[ShortRightArrow] B[227], 
        Db}, {B[226] \[ShortRightArrow] B[237], 
        Db}, {B[226] \[ShortRightArrow] B[239], 
        Db}, {B[227] \[ShortRightArrow] B[209], 
        Db}, {B[227] \[ShortRightArrow] B[220], 
        Db}, {B[227] \[ShortRightArrow] B[226], 
        Db}, {B[227] \[ShortRightArrow] B[229], 
        Db}, {B[227] \[ShortRightArrow] B[239], 
        Db}, {B[228] \[ShortRightArrow] B[215], 
        Db}, {B[228] \[ShortRightArrow] B[218], 
        Db}, {B[228] \[ShortRightArrow] B[229], 
        Db}, {B[228] \[ShortRightArrow] B[235], 
        Db}, {B[228] \[ShortRightArrow] B[240], 
        Db}, {B[229] \[ShortRightArrow] B[218], 
        Db}, {B[229] \[ShortRightArrow] B[220], 
        Db}, {B[229] \[ShortRightArrow] B[227], 
        Db}, {B[229] \[ShortRightArrow] B[228], 
        Db}, {B[229] \[ShortRightArrow] B[239], 
        Db}, {B[229] \[ShortRightArrow] B[240], 
        Db}, {B[229] \[ShortRightArrow] B[242], 
        Db}, {B[230] \[ShortRightArrow] B[212], 
        Db}, {B[230] \[ShortRightArrow] B[215], 
        Db}, {B[230] \[ShortRightArrow] B[223], 
        Db}, {B[230] \[ShortRightArrow] B[232], 
        Db}, {B[230] \[ShortRightArrow] B[236], 
        Db}, {B[230] \[ShortRightArrow] B[245], 
        Db}, {B[231] \[ShortRightArrow] B[222], 
        Db}, {B[231] \[ShortRightArrow] B[223], 
        Db}, {B[231] \[ShortRightArrow] B[224], 
        Db}, {B[231] \[ShortRightArrow] B[225], 
        Db}, {B[231] \[ShortRightArrow] B[234], 
        Db}, {B[231] \[ShortRightArrow] B[238], 
        Db}, {B[231] \[ShortRightArrow] B[244], 
        Db}, {B[232] \[ShortRightArrow] B[215], 
        Db}, {B[232] \[ShortRightArrow] B[230], 
        Db}, {B[232] \[ShortRightArrow] B[233], 
        Db}, {B[232] \[ShortRightArrow] B[245], 
        Db}, {B[233] \[ShortRightArrow] B[215], 
        Db}, {B[233] \[ShortRightArrow] B[232], 
        Db}, {B[233] \[ShortRightArrow] B[235], 
        Db}, {B[233] \[ShortRightArrow] B[241], 
        Db}, {B[233] \[ShortRightArrow] B[245], 
        Db}, {B[234] \[ShortRightArrow] B[216], 
        Db}, {B[234] \[ShortRightArrow] B[225], 
        Db}, {B[234] \[ShortRightArrow] B[231], 
        Db}, {B[234] \[ShortRightArrow] B[244], 
        Db}, {B[235] \[ShortRightArrow] B[215], 
        Db}, {B[235] \[ShortRightArrow] B[228], 
        Db}, {B[235] \[ShortRightArrow] B[233], 
        Db}, {B[235] \[ShortRightArrow] B[240], 
        Db}, {B[235] \[ShortRightArrow] B[241], 
        Db}, {B[235] \[ShortRightArrow] B[243], 
        Db}, {B[236] \[ShortRightArrow] B[223], 
        Db}, {B[236] \[ShortRightArrow] B[230], 
        Db}, {B[236] \[ShortRightArrow] B[238], 
        Db}, {B[236] \[ShortRightArrow] B[245], 
        Db}, {B[236] \[ShortRightArrow] B[248], 
        Db}, {B[237] \[ShortRightArrow] B[219], 
        Db}, {B[237] \[ShortRightArrow] B[226], 
        Db}, {B[237] \[ShortRightArrow] B[239], 
        Db}, {B[237] \[ShortRightArrow] B[249], 
        Db}, {B[238] \[ShortRightArrow] B[223], 
        Db}, {B[238] \[ShortRightArrow] B[231], 
        Db}, {B[238] \[ShortRightArrow] B[236], 
        Db}, {B[238] \[ShortRightArrow] B[244], 
        Db}, {B[238] \[ShortRightArrow] B[246], 
        Db}, {B[238] \[ShortRightArrow] B[248], 
        Db}, {B[239] \[ShortRightArrow] B[226], 
        Db}, {B[239] \[ShortRightArrow] B[227], 
        Db}, {B[239] \[ShortRightArrow] B[229], 
        Db}, {B[239] \[ShortRightArrow] B[237], 
        Db}, {B[239] \[ShortRightArrow] B[242], 
        Db}, {B[239] \[ShortRightArrow] B[249], 
        Db}, {B[239] \[ShortRightArrow] B[250], 
        Db}, {B[240] \[ShortRightArrow] B[228], 
        Db}, {B[240] \[ShortRightArrow] B[229], 
        Db}, {B[240] \[ShortRightArrow] B[235], 
        Db}, {B[240] \[ShortRightArrow] B[242], 
        Db}, {B[240] \[ShortRightArrow] B[243], 
        Db}, {B[240] \[ShortRightArrow] B[247], 
        Db}, {B[241] \[ShortRightArrow] B[233], 
        Db}, {B[241] \[ShortRightArrow] B[235], 
        Db}, {B[241] \[ShortRightArrow] B[243], 
        Db}, {B[241] \[ShortRightArrow] B[245], 
        Db}, {B[241] \[ShortRightArrow] B[247], 
        Db}, {B[241] \[ShortRightArrow] B[251], 
        Db}, {B[241] \[ShortRightArrow] B[253], 
        Db}, {B[242] \[ShortRightArrow] B[229], 
        Db}, {B[242] \[ShortRightArrow] B[239], 
        Db}, {B[242] \[ShortRightArrow] B[240], 
        Db}, {B[242] \[ShortRightArrow] B[247], 
        Db}, {B[242] \[ShortRightArrow] B[250], 
        Db}, {B[242] \[ShortRightArrow] B[252], 
        Db}, {B[243] \[ShortRightArrow] B[235], 
        Db}, {B[243] \[ShortRightArrow] B[240], 
        Db}, {B[243] \[ShortRightArrow] B[241], 
        Db}, {B[243] \[ShortRightArrow] B[247], 
        Db}, {B[244] \[ShortRightArrow] B[231], 
        Db}, {B[244] \[ShortRightArrow] B[234], 
        Db}, {B[244] \[ShortRightArrow] B[238], 
        Db}, {B[244] \[ShortRightArrow] B[246], 
        Db}, {B[245] \[ShortRightArrow] B[230], 
        Db}, {B[245] \[ShortRightArrow] B[232], 
        Db}, {B[245] \[ShortRightArrow] B[233], 
        Db}, {B[245] \[ShortRightArrow] B[236], 
        Db}, {B[245] \[ShortRightArrow] B[241], 
        Db}, {B[245] \[ShortRightArrow] B[248], 
        Db}, {B[245] \[ShortRightArrow] B[251], 
        Db}, {B[246] \[ShortRightArrow] B[238], 
        Db}, {B[246] \[ShortRightArrow] B[244], 
        Db}, {B[246] \[ShortRightArrow] B[248], 
        Db}, {B[247] \[ShortRightArrow] B[240], 
        Db}, {B[247] \[ShortRightArrow] B[241], 
        Db}, {B[247] \[ShortRightArrow] B[242], 
        Db}, {B[247] \[ShortRightArrow] B[243], 
        Db}, {B[247] \[ShortRightArrow] B[252], 
        Db}, {B[247] \[ShortRightArrow] B[253], 
        Db}, {B[248] \[ShortRightArrow] B[236], 
        Db}, {B[248] \[ShortRightArrow] B[238], 
        Db}, {B[248] \[ShortRightArrow] B[245], 
        Db}, {B[248] \[ShortRightArrow] B[246], 
        Db}, {B[249] \[ShortRightArrow] B[237], 
        Db}, {B[249] \[ShortRightArrow] B[239], 
        Db}, {B[249] \[ShortRightArrow] B[250], 
        Db}, {B[250] \[ShortRightArrow] B[239], 
        Db}, {B[250] \[ShortRightArrow] B[242], 
        Db}, {B[250] \[ShortRightArrow] B[249], 
        Db}, {B[250] \[ShortRightArrow] B[252], 
        Db}, {B[251] \[ShortRightArrow] B[241], 
        Db}, {B[251] \[ShortRightArrow] B[245], 
        Db}, {B[251] \[ShortRightArrow] B[253], 
        Db}, {B[252] \[ShortRightArrow] B[242], 
        Db}, {B[252] \[ShortRightArrow] B[247], 
        Db}, {B[252] \[ShortRightArrow] B[250], 
        Db}, {B[252] \[ShortRightArrow] B[253], 
        Db}, {B[253] \[ShortRightArrow] B[241], 
        Db}, {B[253] \[ShortRightArrow] B[247], 
        Db}, {B[253] \[ShortRightArrow] B[251], 
        Db}, {B[253] \[ShortRightArrow] B[252], 
        Db}, {Y[1] \[ShortRightArrow] Y[2], 
        Dy}, {Y[1] \[ShortRightArrow] Y[3], 
        Dy}, {Y[1] \[ShortRightArrow] Y[8], 
        Dy}, {Y[2] \[ShortRightArrow] Y[1], 
        Dy}, {Y[2] \[ShortRightArrow] Y[4], 
        Dy}, {Y[2] \[ShortRightArrow] Y[5], 
        Dy}, {Y[2] \[ShortRightArrow] Y[8], 
        Dy}, {Y[3] \[ShortRightArrow] Y[1], 
        Dy}, {Y[3] \[ShortRightArrow] Y[6], 
        Dy}, {Y[3] \[ShortRightArrow] Y[7], 
        Dy}, {Y[3] \[ShortRightArrow] Y[8], 
        Dy}, {Y[4] \[ShortRightArrow] Y[2], 
        Dy}, {Y[4] \[ShortRightArrow] Y[5], 
        Dy}, {Y[4] \[ShortRightArrow] Y[9], 
        Dy}, {Y[4] \[ShortRightArrow] Y[10], 
        Dy}, {Y[5] \[ShortRightArrow] Y[2], 
        Dy}, {Y[5] \[ShortRightArrow] Y[4], 
        Dy}, {Y[5] \[ShortRightArrow] Y[8], 
        Dy}, {Y[5] \[ShortRightArrow] Y[9], 
        Dy}, {Y[5] \[ShortRightArrow] Y[14], 
        Dy}, {Y[6] \[ShortRightArrow] Y[3], 
        Dy}, {Y[6] \[ShortRightArrow] Y[7], 
        Dy}, {Y[6] \[ShortRightArrow] Y[11], 
        Dy}, {Y[6] \[ShortRightArrow] Y[12], 
        Dy}, {Y[6] \[ShortRightArrow] Y[22], 
        Dy}, {Y[7] \[ShortRightArrow] Y[3], 
        Dy}, {Y[7] \[ShortRightArrow] Y[6], 
        Dy}, {Y[7] \[ShortRightArrow] Y[8], 
        Dy}, {Y[7] \[ShortRightArrow] Y[11], 
        Dy}, {Y[7] \[ShortRightArrow] Y[13], 
        Dy}, {Y[8] \[ShortRightArrow] Y[1], 
        Dy}, {Y[8] \[ShortRightArrow] Y[2], 
        Dy}, {Y[8] \[ShortRightArrow] Y[3], 
        Dy}, {Y[8] \[ShortRightArrow] Y[5], 
        Dy}, {Y[8] \[ShortRightArrow] Y[7], 
        Dy}, {Y[8] \[ShortRightArrow] Y[13], 
        Dy}, {Y[8] \[ShortRightArrow] Y[14], 
        Dy}, {Y[8] \[ShortRightArrow] Y[17], 
        Dy}, {Y[9] \[ShortRightArrow] Y[4], 
        Dy}, {Y[9] \[ShortRightArrow] Y[5], 
        Dy}, {Y[9] \[ShortRightArrow] Y[10], 
        Dy}, {Y[9] \[ShortRightArrow] Y[14], 
        Dy}, {Y[9] \[ShortRightArrow] Y[18], 
        Dy}, {Y[9] \[ShortRightArrow] Y[27], 
        Dy}, {Y[10] \[ShortRightArrow] Y[4], 
        Dy}, {Y[10] \[ShortRightArrow] Y[9], 
        Dy}, {Y[10] \[ShortRightArrow] Y[18], 
        Dy}, {Y[10] \[ShortRightArrow] Y[19], 
        Dy}, {Y[10] \[ShortRightArrow] Y[28], 
        Dy}, {Y[11] \[ShortRightArrow] Y[6], 
        Dy}, {Y[11] \[ShortRightArrow] Y[7], 
        Dy}, {Y[11] \[ShortRightArrow] Y[13], 
        Dy}, {Y[11] \[ShortRightArrow] Y[22], 
        Dy}, {Y[11] \[ShortRightArrow] Y[24], 
        Dy}, {Y[11] \[ShortRightArrow] Y[25], 
        Dy}, {Y[11] \[ShortRightArrow] Y[26], 
        Dy}, {Y[12] \[ShortRightArrow] Y[6], 
        Dy}, {Y[12] \[ShortRightArrow] Y[16], 
        Dy}, {Y[12] \[ShortRightArrow] Y[22], 
        Dy}, {Y[12] \[ShortRightArrow] Y[30], 
        Dy}, {Y[13] \[ShortRightArrow] Y[7], 
        Dy}, {Y[13] \[ShortRightArrow] Y[8], 
        Dy}, {Y[13] \[ShortRightArrow] Y[11], 
        Dy}, {Y[13] \[ShortRightArrow] Y[17], 
        Dy}, {Y[13] \[ShortRightArrow] Y[26], 
        Dy}, {Y[13] \[ShortRightArrow] Y[39], 
        Dy}, {Y[14] \[ShortRightArrow] Y[5], 
        Dy}, {Y[14] \[ShortRightArrow] Y[8], 
        Dy}, {Y[14] \[ShortRightArrow] Y[9], 
        Dy}, {Y[14] \[ShortRightArrow] Y[17], 
        Dy}, {Y[14] \[ShortRightArrow] Y[23], 
        Dy}, {Y[14] \[ShortRightArrow] Y[27], 
        Dy}, {Y[14] \[ShortRightArrow] Y[33], 
        Dy}, {Y[15] \[ShortRightArrow] Y[20], 
        Dy}, {Y[15] \[ShortRightArrow] Y[21], 
        Dy}, {Y[15] \[ShortRightArrow] Y[29], 
        Dy}, {Y[15] \[ShortRightArrow] Y[34], 
        Dy}, {Y[15] \[ShortRightArrow] Y[35], 
        Dy}, {Y[16] \[ShortRightArrow] Y[12], 
        Dy}, {Y[16] \[ShortRightArrow] Y[30], 
        Dy}, {Y[17] \[ShortRightArrow] Y[8], 
        Dy}, {Y[17] \[ShortRightArrow] Y[13], 
        Dy}, {Y[17] \[ShortRightArrow] Y[14], 
        Dy}, {Y[17] \[ShortRightArrow] Y[23], 
        Dy}, {Y[17] \[ShortRightArrow] Y[39], 
        Dy}, {Y[17] \[ShortRightArrow] Y[53], 
        Dy}, {Y[17] \[ShortRightArrow] Y[54], 
        Dy}, {Y[18] \[ShortRightArrow] Y[9], 
        Dy}, {Y[18] \[ShortRightArrow] Y[10], 
        Dy}, {Y[18] \[ShortRightArrow] Y[27], 
        Dy}, {Y[18] \[ShortRightArrow] Y[28], 
        Dy}, {Y[18] \[ShortRightArrow] Y[31], 
        Dy}, {Y[19] \[ShortRightArrow] Y[10], 
        Dy}, {Y[19] \[ShortRightArrow] Y[20], 
        Dy}, {Y[19] \[ShortRightArrow] Y[28], 
        Dy}, {Y[19] \[ShortRightArrow] Y[32], 
        Dy}, {Y[19] \[ShortRightArrow] Y[38], 
        Dy}, {Y[19] \[ShortRightArrow] Y[40], 
        Dy}, {Y[20] \[ShortRightArrow] Y[15], 
        Dy}, {Y[20] \[ShortRightArrow] Y[19], 
        Dy}, {Y[20] \[ShortRightArrow] Y[34], 
        Dy}, {Y[20] \[ShortRightArrow] Y[40], 
        Dy}, {Y[21] \[ShortRightArrow] Y[15], 
        Dy}, {Y[21] \[ShortRightArrow] Y[29], 
        Dy}, {Y[21] \[ShortRightArrow] Y[36], 
        Dy}, {Y[21] \[ShortRightArrow] Y[47], 
        Dy}, {Y[22] \[ShortRightArrow] Y[6], 
        Dy}, {Y[22] \[ShortRightArrow] Y[11], 
        Dy}, {Y[22] \[ShortRightArrow] Y[12], 
        Dy}, {Y[22] \[ShortRightArrow] Y[24], 
        Dy}, {Y[22] \[ShortRightArrow] Y[37], 
        Dy}, {Y[22] \[ShortRightArrow] Y[43], 
        Dy}, {Y[23] \[ShortRightArrow] Y[14], 
        Dy}, {Y[23] \[ShortRightArrow] Y[17], 
        Dy}, {Y[23] \[ShortRightArrow] Y[33], 
        Dy}, {Y[23] \[ShortRightArrow] Y[45], 
        Dy}, {Y[23] \[ShortRightArrow] Y[54], 
        Dy}, {Y[24] \[ShortRightArrow] Y[11], 
        Dy}, {Y[24] \[ShortRightArrow] Y[22], 
        Dy}, {Y[24] \[ShortRightArrow] Y[25], 
        Dy}, {Y[24] \[ShortRightArrow] Y[37], 
        Dy}, {Y[25] \[ShortRightArrow] Y[11], 
        Dy}, {Y[25] \[ShortRightArrow] Y[24], 
        Dy}, {Y[25] \[ShortRightArrow] Y[26], 
        Dy}, {Y[25] \[ShortRightArrow] Y[37], 
        Dy}, {Y[25] \[ShortRightArrow] Y[39], 
        Dy}, {Y[26] \[ShortRightArrow] Y[11], 
        Dy}, {Y[26] \[ShortRightArrow] Y[13], 
        Dy}, {Y[26] \[ShortRightArrow] Y[25], 
        Dy}, {Y[26] \[ShortRightArrow] Y[39], 
        Dy}, {Y[27] \[ShortRightArrow] Y[9], 
        Dy}, {Y[27] \[ShortRightArrow] Y[14], 
        Dy}, {Y[27] \[ShortRightArrow] Y[18], 
        Dy}, {Y[27] \[ShortRightArrow] Y[31], 
        Dy}, {Y[27] \[ShortRightArrow] Y[33], 
        Dy}, {Y[28] \[ShortRightArrow] Y[10], 
        Dy}, {Y[28] \[ShortRightArrow] Y[18], 
        Dy}, {Y[28] \[ShortRightArrow] Y[19], 
        Dy}, {Y[28] \[ShortRightArrow] Y[31], 
        Dy}, {Y[28] \[ShortRightArrow] Y[32], 
        Dy}, {Y[28] \[ShortRightArrow] Y[44], 
        Dy}, {Y[29] \[ShortRightArrow] Y[15], 
        Dy}, {Y[29] \[ShortRightArrow] Y[21], 
        Dy}, {Y[29] \[ShortRightArrow] Y[35], 
        Dy}, {Y[29] \[ShortRightArrow] Y[47], 
        Dy}, {Y[29] \[ShortRightArrow] Y[49], 
        Dy}, {Y[29] \[ShortRightArrow] Y[57], 
        Dy}, {Y[30] \[ShortRightArrow] Y[12], 
        Dy}, {Y[30] \[ShortRightArrow] Y[16], 
        Dy}, {Y[30] \[ShortRightArrow] Y[43], 
        Dy}, {Y[30] \[ShortRightArrow] Y[50], 
        Dy}, {Y[31] \[ShortRightArrow] Y[18], 
        Dy}, {Y[31] \[ShortRightArrow] Y[27], 
        Dy}, {Y[31] \[ShortRightArrow] Y[28], 
        Dy}, {Y[31] \[ShortRightArrow] Y[33], 
        Dy}, {Y[31] \[ShortRightArrow] Y[44], 
        Dy}, {Y[31] \[ShortRightArrow] Y[46], 
        Dy}, {Y[32] \[ShortRightArrow] Y[19], 
        Dy}, {Y[32] \[ShortRightArrow] Y[28], 
        Dy}, {Y[32] \[ShortRightArrow] Y[38], 
        Dy}, {Y[32] \[ShortRightArrow] Y[44], 
        Dy}, {Y[33] \[ShortRightArrow] Y[14], 
        Dy}, {Y[33] \[ShortRightArrow] Y[23], 
        Dy}, {Y[33] \[ShortRightArrow] Y[27], 
        Dy}, {Y[33] \[ShortRightArrow] Y[31], 
        Dy}, {Y[33] \[ShortRightArrow] Y[45], 
        Dy}, {Y[33] \[ShortRightArrow] Y[46], 
        Dy}, {Y[34] \[ShortRightArrow] Y[15], 
        Dy}, {Y[34] \[ShortRightArrow] Y[20], 
        Dy}, {Y[34] \[ShortRightArrow] Y[35], 
        Dy}, {Y[34] \[ShortRightArrow] Y[40], 
        Dy}, {Y[34] \[ShortRightArrow] Y[41], 
        Dy}, {Y[34] \[ShortRightArrow] Y[51], 
        Dy}, {Y[34] \[ShortRightArrow] Y[52], 
        Dy}, {Y[35] \[ShortRightArrow] Y[15], 
        Dy}, {Y[35] \[ShortRightArrow] Y[29], 
        Dy}, {Y[35] \[ShortRightArrow] Y[34], 
        Dy}, {Y[35] \[ShortRightArrow] Y[41], 
        Dy}, {Y[35] \[ShortRightArrow] Y[57], 
        Dy}, {Y[35] \[ShortRightArrow] Y[60], 
        Dy}, {Y[36] \[ShortRightArrow] Y[21], 
        Dy}, {Y[36] \[ShortRightArrow] Y[42], 
        Dy}, {Y[36] \[ShortRightArrow] Y[47], 
        Dy}, {Y[36] \[ShortRightArrow] Y[48], 
        Dy}, {Y[37] \[ShortRightArrow] Y[22], 
        Dy}, {Y[37] \[ShortRightArrow] Y[24], 
        Dy}, {Y[37] \[ShortRightArrow] Y[25], 
        Dy}, {Y[37] \[ShortRightArrow] Y[39], 
        Dy}, {Y[37] \[ShortRightArrow] Y[43], 
        Dy}, {Y[37] \[ShortRightArrow] Y[59], 
        Dy}, {Y[38] \[ShortRightArrow] Y[19], 
        Dy}, {Y[38] \[ShortRightArrow] Y[32], 
        Dy}, {Y[38] \[ShortRightArrow] Y[40], 
        Dy}, {Y[38] \[ShortRightArrow] Y[44], 
        Dy}, {Y[38] \[ShortRightArrow] Y[56], 
        Dy}, {Y[38] \[ShortRightArrow] Y[67], 
        Dy}, {Y[39] \[ShortRightArrow] Y[13], 
        Dy}, {Y[39] \[ShortRightArrow] Y[17], 
        Dy}, {Y[39] \[ShortRightArrow] Y[25], 
        Dy}, {Y[39] \[ShortRightArrow] Y[26], 
        Dy}, {Y[39] \[ShortRightArrow] Y[37], 
        Dy}, {Y[39] \[ShortRightArrow] Y[53], 
        Dy}, {Y[39] \[ShortRightArrow] Y[59], 
        Dy}, {Y[39] \[ShortRightArrow] Y[65], 
        Dy}, {Y[40] \[ShortRightArrow] Y[19], 
        Dy}, {Y[40] \[ShortRightArrow] Y[20], 
        Dy}, {Y[40] \[ShortRightArrow] Y[34], 
        Dy}, {Y[40] \[ShortRightArrow] Y[38], 
        Dy}, {Y[40] \[ShortRightArrow] Y[51], 
        Dy}, {Y[40] \[ShortRightArrow] Y[56], 
        Dy}, {Y[41] \[ShortRightArrow] Y[34], 
        Dy}, {Y[41] \[ShortRightArrow] Y[35], 
        Dy}, {Y[41] \[ShortRightArrow] Y[52], 
        Dy}, {Y[41] \[ShortRightArrow] Y[60], 
        Dy}, {Y[42] \[ShortRightArrow] Y[36], 
        Dy}, {Y[42] \[ShortRightArrow] Y[48], 
        Dy}, {Y[42] \[ShortRightArrow] Y[58], 
        Dy}, {Y[43] \[ShortRightArrow] Y[22], 
        Dy}, {Y[43] \[ShortRightArrow] Y[30], 
        Dy}, {Y[43] \[ShortRightArrow] Y[37], 
        Dy}, {Y[43] \[ShortRightArrow] Y[50], 
        Dy}, {Y[43] \[ShortRightArrow] Y[59], 
        Dy}, {Y[43] \[ShortRightArrow] Y[61], 
        Dy}, {Y[43] \[ShortRightArrow] Y[64], 
        Dy}, {Y[44] \[ShortRightArrow] Y[28], 
        Dy}, {Y[44] \[ShortRightArrow] Y[31], 
        Dy}, {Y[44] \[ShortRightArrow] Y[32], 
        Dy}, {Y[44] \[ShortRightArrow] Y[38], 
        Dy}, {Y[44] \[ShortRightArrow] Y[46], 
        Dy}, {Y[44] \[ShortRightArrow] Y[55], 
        Dy}, {Y[44] \[ShortRightArrow] Y[66], 
        Dy}, {Y[44] \[ShortRightArrow] Y[67], 
        Dy}, {Y[45] \[ShortRightArrow] Y[23], 
        Dy}, {Y[45] \[ShortRightArrow] Y[33], 
        Dy}, {Y[45] \[ShortRightArrow] Y[46], 
        Dy}, {Y[45] \[ShortRightArrow] Y[54], 
        Dy}, {Y[45] \[ShortRightArrow] Y[75], 
        Dy}, {Y[46] \[ShortRightArrow] Y[31], 
        Dy}, {Y[46] \[ShortRightArrow] Y[33], 
        Dy}, {Y[46] \[ShortRightArrow] Y[44], 
        Dy}, {Y[46] \[ShortRightArrow] Y[45], 
        Dy}, {Y[46] \[ShortRightArrow] Y[55], 
        Dy}, {Y[46] \[ShortRightArrow] Y[68], 
        Dy}, {Y[46] \[ShortRightArrow] Y[69], 
        Dy}, {Y[47] \[ShortRightArrow] Y[21], 
        Dy}, {Y[47] \[ShortRightArrow] Y[29], 
        Dy}, {Y[47] \[ShortRightArrow] Y[36], 
        Dy}, {Y[47] \[ShortRightArrow] Y[48], 
        Dy}, {Y[47] \[ShortRightArrow] Y[49], 
        Dy}, {Y[47] \[ShortRightArrow] Y[63], 
        Dy}, {Y[48] \[ShortRightArrow] Y[36], 
        Dy}, {Y[48] \[ShortRightArrow] Y[42], 
        Dy}, {Y[48] \[ShortRightArrow] Y[47], 
        Dy}, {Y[48] \[ShortRightArrow] Y[58], 
        Dy}, {Y[48] \[ShortRightArrow] Y[63], 
        Dy}, {Y[48] \[ShortRightArrow] Y[73], 
        Dy}, {Y[48] \[ShortRightArrow] Y[77], 
        Dy}, {Y[49] \[ShortRightArrow] Y[29], 
        Dy}, {Y[49] \[ShortRightArrow] Y[47], 
        Dy}, {Y[49] \[ShortRightArrow] Y[57], 
        Dy}, {Y[49] \[ShortRightArrow] Y[63], 
        Dy}, {Y[49] \[ShortRightArrow] Y[76], 
        Dy}, {Y[50] \[ShortRightArrow] Y[30], 
        Dy}, {Y[50] \[ShortRightArrow] Y[43], 
        Dy}, {Y[50] \[ShortRightArrow] Y[61], 
        Dy}, {Y[50] \[ShortRightArrow] Y[82], 
        Dy}, {Y[51] \[ShortRightArrow] Y[34], 
        Dy}, {Y[51] \[ShortRightArrow] Y[40], 
        Dy}, {Y[51] \[ShortRightArrow] Y[52], 
        Dy}, {Y[51] \[ShortRightArrow] Y[56], 
        Dy}, {Y[51] \[ShortRightArrow] Y[71], 
        Dy}, {Y[51] \[ShortRightArrow] Y[72], 
        Dy}, {Y[51] \[ShortRightArrow] Y[84], 
        Dy}, {Y[52] \[ShortRightArrow] Y[34], 
        Dy}, {Y[52] \[ShortRightArrow] Y[41], 
        Dy}, {Y[52] \[ShortRightArrow] Y[51], 
        Dy}, {Y[52] \[ShortRightArrow] Y[60], 
        Dy}, {Y[52] \[ShortRightArrow] Y[72], 
        Dy}, {Y[53] \[ShortRightArrow] Y[17], 
        Dy}, {Y[53] \[ShortRightArrow] Y[39], 
        Dy}, {Y[53] \[ShortRightArrow] Y[54], 
        Dy}, {Y[53] \[ShortRightArrow] Y[65], 
        Dy}, {Y[53] \[ShortRightArrow] Y[70], 
        Dy}, {Y[53] \[ShortRightArrow] Y[74], 
        Dy}, {Y[54] \[ShortRightArrow] Y[17], 
        Dy}, {Y[54] \[ShortRightArrow] Y[23], 
        Dy}, {Y[54] \[ShortRightArrow] Y[45], 
        Dy}, {Y[54] \[ShortRightArrow] Y[53], 
        Dy}, {Y[54] \[ShortRightArrow] Y[74], 
        Dy}, {Y[54] \[ShortRightArrow] Y[75], 
        Dy}, {Y[55] \[ShortRightArrow] Y[44], 
        Dy}, {Y[55] \[ShortRightArrow] Y[46], 
        Dy}, {Y[55] \[ShortRightArrow] Y[66], 
        Dy}, {Y[55] \[ShortRightArrow] Y[69], 
        Dy}, {Y[55] \[ShortRightArrow] Y[86], 
        Dy}, {Y[56] \[ShortRightArrow] Y[38], 
        Dy}, {Y[56] \[ShortRightArrow] Y[40], 
        Dy}, {Y[56] \[ShortRightArrow] Y[51], 
        Dy}, {Y[56] \[ShortRightArrow] Y[62], 
        Dy}, {Y[56] \[ShortRightArrow] Y[67], 
        Dy}, {Y[56] \[ShortRightArrow] Y[71], 
        Dy}, {Y[57] \[ShortRightArrow] Y[29], 
        Dy}, {Y[57] \[ShortRightArrow] Y[35], 
        Dy}, {Y[57] \[ShortRightArrow] Y[49], 
        Dy}, {Y[57] \[ShortRightArrow] Y[60], 
        Dy}, {Y[57] \[ShortRightArrow] Y[76], 
        Dy}, {Y[57] \[ShortRightArrow] Y[81], 
        Dy}, {Y[57] \[ShortRightArrow] Y[85], 
        Dy}, {Y[58] \[ShortRightArrow] Y[42], 
        Dy}, {Y[58] \[ShortRightArrow] Y[48], 
        Dy}, {Y[58] \[ShortRightArrow] Y[77], 
        Dy}, {Y[58] \[ShortRightArrow] Y[78], 
        Dy}, {Y[59] \[ShortRightArrow] Y[37], 
        Dy}, {Y[59] \[ShortRightArrow] Y[39], 
        Dy}, {Y[59] \[ShortRightArrow] Y[43], 
        Dy}, {Y[59] \[ShortRightArrow] Y[64], 
        Dy}, {Y[59] \[ShortRightArrow] Y[65], 
        Dy}, {Y[59] \[ShortRightArrow] Y[83], 
        Dy}, {Y[59] \[ShortRightArrow] Y[87], 
        Dy}, {Y[60] \[ShortRightArrow] Y[35], 
        Dy}, {Y[60] \[ShortRightArrow] Y[41], 
        Dy}, {Y[60] \[ShortRightArrow] Y[52], 
        Dy}, {Y[60] \[ShortRightArrow] Y[57], 
        Dy}, {Y[60] \[ShortRightArrow] Y[72], 
        Dy}, {Y[60] \[ShortRightArrow] Y[80], 
        Dy}, {Y[60] \[ShortRightArrow] Y[85], 
        Dy}, {Y[61] \[ShortRightArrow] Y[43], 
        Dy}, {Y[61] \[ShortRightArrow] Y[50], 
        Dy}, {Y[61] \[ShortRightArrow] Y[64], 
        Dy}, {Y[61] \[ShortRightArrow] Y[82], 
        Dy}, {Y[61] \[ShortRightArrow] Y[89], 
        Dy}, {Y[61] \[ShortRightArrow] Y[96], 
        Dy}, {Y[62] \[ShortRightArrow] Y[56], 
        Dy}, {Y[62] \[ShortRightArrow] Y[67], 
        Dy}, {Y[62] \[ShortRightArrow] Y[71], 
        Dy}, {Y[62] \[ShortRightArrow] Y[79], 
        Dy}, {Y[63] \[ShortRightArrow] Y[47], 
        Dy}, {Y[63] \[ShortRightArrow] Y[48], 
        Dy}, {Y[63] \[ShortRightArrow] Y[49], 
        Dy}, {Y[63] \[ShortRightArrow] Y[73], 
        Dy}, {Y[63] \[ShortRightArrow] Y[76], 
        Dy}, {Y[64] \[ShortRightArrow] Y[43], 
        Dy}, {Y[64] \[ShortRightArrow] Y[59], 
        Dy}, {Y[64] \[ShortRightArrow] Y[61], 
        Dy}, {Y[64] \[ShortRightArrow] Y[83], 
        Dy}, {Y[64] \[ShortRightArrow] Y[96], 
        Dy}, {Y[65] \[ShortRightArrow] Y[39], 
        Dy}, {Y[65] \[ShortRightArrow] Y[53], 
        Dy}, {Y[65] \[ShortRightArrow] Y[59], 
        Dy}, {Y[65] \[ShortRightArrow] Y[70], 
        Dy}, {Y[65] \[ShortRightArrow] Y[87], 
        Dy}, {Y[65] \[ShortRightArrow] Y[97], 
        Dy}, {Y[65] \[ShortRightArrow] Y[100], 
        Dy}, {Y[66] \[ShortRightArrow] Y[44], 
        Dy}, {Y[66] \[ShortRightArrow] Y[55], 
        Dy}, {Y[66] \[ShortRightArrow] Y[67], 
        Dy}, {Y[66] \[ShortRightArrow] Y[79], 
        Dy}, {Y[66] \[ShortRightArrow] Y[86], 
        Dy}, {Y[66] \[ShortRightArrow] Y[91], 
        Dy}, {Y[67] \[ShortRightArrow] Y[38], 
        Dy}, {Y[67] \[ShortRightArrow] Y[44], 
        Dy}, {Y[67] \[ShortRightArrow] Y[56], 
        Dy}, {Y[67] \[ShortRightArrow] Y[62], 
        Dy}, {Y[67] \[ShortRightArrow] Y[66], 
        Dy}, {Y[67] \[ShortRightArrow] Y[79], 
        Dy}, {Y[68] \[ShortRightArrow] Y[46], 
        Dy}, {Y[68] \[ShortRightArrow] Y[69], 
        Dy}, {Y[68] \[ShortRightArrow] Y[75], 
        Dy}, {Y[68] \[ShortRightArrow] Y[94], 
        Dy}, {Y[69] \[ShortRightArrow] Y[46], 
        Dy}, {Y[69] \[ShortRightArrow] Y[55], 
        Dy}, {Y[69] \[ShortRightArrow] Y[68], 
        Dy}, {Y[69] \[ShortRightArrow] Y[86], 
        Dy}, {Y[69] \[ShortRightArrow] Y[94], 
        Dy}, {Y[69] \[ShortRightArrow] Y[98], 
        Dy}, {Y[70] \[ShortRightArrow] Y[53], 
        Dy}, {Y[70] \[ShortRightArrow] Y[65], 
        Dy}, {Y[70] \[ShortRightArrow] Y[74], 
        Dy}, {Y[70] \[ShortRightArrow] Y[93], 
        Dy}, {Y[70] \[ShortRightArrow] Y[97], 
        Dy}, {Y[71] \[ShortRightArrow] Y[51], 
        Dy}, {Y[71] \[ShortRightArrow] Y[56], 
        Dy}, {Y[71] \[ShortRightArrow] Y[62], 
        Dy}, {Y[71] \[ShortRightArrow] Y[79], 
        Dy}, {Y[71] \[ShortRightArrow] Y[84], 
        Dy}, {Y[72] \[ShortRightArrow] Y[51], 
        Dy}, {Y[72] \[ShortRightArrow] Y[52], 
        Dy}, {Y[72] \[ShortRightArrow] Y[60], 
        Dy}, {Y[72] \[ShortRightArrow] Y[80], 
        Dy}, {Y[72] \[ShortRightArrow] Y[84], 
        Dy}, {Y[72] \[ShortRightArrow] Y[102], 
        Dy}, {Y[73] \[ShortRightArrow] Y[48], 
        Dy}, {Y[73] \[ShortRightArrow] Y[63], 
        Dy}, {Y[73] \[ShortRightArrow] Y[76], 
        Dy}, {Y[73] \[ShortRightArrow] Y[77], 
        Dy}, {Y[73] \[ShortRightArrow] Y[92], 
        Dy}, {Y[74] \[ShortRightArrow] Y[53], 
        Dy}, {Y[74] \[ShortRightArrow] Y[54], 
        Dy}, {Y[74] \[ShortRightArrow] Y[70], 
        Dy}, {Y[74] \[ShortRightArrow] Y[75], 
        Dy}, {Y[74] \[ShortRightArrow] Y[90], 
        Dy}, {Y[74] \[ShortRightArrow] Y[93], 
        Dy}, {Y[75] \[ShortRightArrow] Y[45], 
        Dy}, {Y[75] \[ShortRightArrow] Y[54], 
        Dy}, {Y[75] \[ShortRightArrow] Y[68], 
        Dy}, {Y[75] \[ShortRightArrow] Y[74], 
        Dy}, {Y[75] \[ShortRightArrow] Y[90], 
        Dy}, {Y[75] \[ShortRightArrow] Y[94], 
        Dy}, {Y[76] \[ShortRightArrow] Y[49], 
        Dy}, {Y[76] \[ShortRightArrow] Y[57], 
        Dy}, {Y[76] \[ShortRightArrow] Y[63], 
        Dy}, {Y[76] \[ShortRightArrow] Y[73], 
        Dy}, {Y[76] \[ShortRightArrow] Y[81], 
        Dy}, {Y[76] \[ShortRightArrow] Y[92], 
        Dy}, {Y[76] \[ShortRightArrow] Y[95], 
        Dy}, {Y[77] \[ShortRightArrow] Y[48], 
        Dy}, {Y[77] \[ShortRightArrow] Y[58], 
        Dy}, {Y[77] \[ShortRightArrow] Y[73], 
        Dy}, {Y[77] \[ShortRightArrow] Y[78], 
        Dy}, {Y[77] \[ShortRightArrow] Y[92], 
        Dy}, {Y[77] \[ShortRightArrow] Y[103], 
        Dy}, {Y[77] \[ShortRightArrow] Y[107], 
        Dy}, {Y[78] \[ShortRightArrow] Y[58], 
        Dy}, {Y[78] \[ShortRightArrow] Y[77], 
        Dy}, {Y[78] \[ShortRightArrow] Y[107], 
        Dy}, {Y[79] \[ShortRightArrow] Y[62], 
        Dy}, {Y[79] \[ShortRightArrow] Y[66], 
        Dy}, {Y[79] \[ShortRightArrow] Y[67], 
        Dy}, {Y[79] \[ShortRightArrow] Y[71], 
        Dy}, {Y[79] \[ShortRightArrow] Y[84], 
        Dy}, {Y[79] \[ShortRightArrow] Y[91], 
        Dy}, {Y[79] \[ShortRightArrow] Y[99], 
        Dy}, {Y[79] \[ShortRightArrow] Y[101], 
        Dy}, {Y[80] \[ShortRightArrow] Y[60], 
        Dy}, {Y[80] \[ShortRightArrow] Y[72], 
        Dy}, {Y[80] \[ShortRightArrow] Y[85], 
        Dy}, {Y[80] \[ShortRightArrow] Y[88], 
        Dy}, {Y[80] \[ShortRightArrow] Y[102], 
        Dy}, {Y[80] \[ShortRightArrow] Y[110], 
        Dy}, {Y[81] \[ShortRightArrow] Y[57], 
        Dy}, {Y[81] \[ShortRightArrow] Y[76], 
        Dy}, {Y[81] \[ShortRightArrow] Y[85], 
        Dy}, {Y[81] \[ShortRightArrow] Y[95], 
        Dy}, {Y[82] \[ShortRightArrow] Y[50], 
        Dy}, {Y[82] \[ShortRightArrow] Y[61], 
        Dy}, {Y[82] \[ShortRightArrow] Y[89], 
        Dy}, {Y[82] \[ShortRightArrow] Y[113], 
        Dy}, {Y[83] \[ShortRightArrow] Y[59], 
        Dy}, {Y[83] \[ShortRightArrow] Y[64], 
        Dy}, {Y[83] \[ShortRightArrow] Y[87], 
        Dy}, {Y[83] \[ShortRightArrow] Y[96], 
        Dy}, {Y[83] \[ShortRightArrow] Y[100], 
        Dy}, {Y[83] \[ShortRightArrow] Y[123], 
        Dy}, {Y[84] \[ShortRightArrow] Y[51], 
        Dy}, {Y[84] \[ShortRightArrow] Y[71], 
        Dy}, {Y[84] \[ShortRightArrow] Y[72], 
        Dy}, {Y[84] \[ShortRightArrow] Y[79], 
        Dy}, {Y[84] \[ShortRightArrow] Y[101], 
        Dy}, {Y[84] \[ShortRightArrow] Y[102], 
        Dy}, {Y[84] \[ShortRightArrow] Y[109], 
        Dy}, {Y[85] \[ShortRightArrow] Y[57], 
        Dy}, {Y[85] \[ShortRightArrow] Y[60], 
        Dy}, {Y[85] \[ShortRightArrow] Y[80], 
        Dy}, {Y[85] \[ShortRightArrow] Y[81], 
        Dy}, {Y[85] \[ShortRightArrow] Y[88], 
        Dy}, {Y[85] \[ShortRightArrow] Y[95], 
        Dy}, {Y[86] \[ShortRightArrow] Y[55], 
        Dy}, {Y[86] \[ShortRightArrow] Y[66], 
        Dy}, {Y[86] \[ShortRightArrow] Y[69], 
        Dy}, {Y[86] \[ShortRightArrow] Y[91], 
        Dy}, {Y[86] \[ShortRightArrow] Y[98], 
        Dy}, {Y[86] \[ShortRightArrow] Y[106], 
        Dy}, {Y[87] \[ShortRightArrow] Y[59], 
        Dy}, {Y[87] \[ShortRightArrow] Y[65], 
        Dy}, {Y[87] \[ShortRightArrow] Y[83], 
        Dy}, {Y[87] \[ShortRightArrow] Y[100], 
        Dy}, {Y[88] \[ShortRightArrow] Y[80], 
        Dy}, {Y[88] \[ShortRightArrow] Y[85], 
        Dy}, {Y[88] \[ShortRightArrow] Y[95], 
        Dy}, {Y[88] \[ShortRightArrow] Y[110], 
        Dy}, {Y[88] \[ShortRightArrow] Y[112], 
        Dy}, {Y[88] \[ShortRightArrow] Y[120], 
        Dy}, {Y[89] \[ShortRightArrow] Y[61], 
        Dy}, {Y[89] \[ShortRightArrow] Y[82], 
        Dy}, {Y[89] \[ShortRightArrow] Y[96], 
        Dy}, {Y[89] \[ShortRightArrow] Y[113], 
        Dy}, {Y[90] \[ShortRightArrow] Y[74], 
        Dy}, {Y[90] \[ShortRightArrow] Y[75], 
        Dy}, {Y[90] \[ShortRightArrow] Y[93], 
        Dy}, {Y[90] \[ShortRightArrow] Y[105], 
        Dy}, {Y[90] \[ShortRightArrow] Y[108], 
        Dy}, {Y[90] \[ShortRightArrow] Y[116], 
        Dy}, {Y[91] \[ShortRightArrow] Y[66], 
        Dy}, {Y[91] \[ShortRightArrow] Y[79], 
        Dy}, {Y[91] \[ShortRightArrow] Y[86], 
        Dy}, {Y[91] \[ShortRightArrow] Y[99], 
        Dy}, {Y[91] \[ShortRightArrow] Y[106], 
        Dy}, {Y[91] \[ShortRightArrow] Y[118], 
        Dy}, {Y[92] \[ShortRightArrow] Y[73], 
        Dy}, {Y[92] \[ShortRightArrow] Y[76], 
        Dy}, {Y[92] \[ShortRightArrow] Y[77], 
        Dy}, {Y[92] \[ShortRightArrow] Y[95], 
        Dy}, {Y[92] \[ShortRightArrow] Y[103], 
        Dy}, {Y[92] \[ShortRightArrow] Y[111], 
        Dy}, {Y[93] \[ShortRightArrow] Y[70], 
        Dy}, {Y[93] \[ShortRightArrow] Y[74], 
        Dy}, {Y[93] \[ShortRightArrow] Y[90], 
        Dy}, {Y[93] \[ShortRightArrow] Y[97], 
        Dy}, {Y[93] \[ShortRightArrow] Y[104], 
        Dy}, {Y[93] \[ShortRightArrow] Y[105], 
        Dy}, {Y[93] \[ShortRightArrow] Y[115], 
        Dy}, {Y[94] \[ShortRightArrow] Y[68], 
        Dy}, {Y[94] \[ShortRightArrow] Y[69], 
        Dy}, {Y[94] \[ShortRightArrow] Y[75], 
        Dy}, {Y[94] \[ShortRightArrow] Y[98], 
        Dy}, {Y[94] \[ShortRightArrow] Y[108], 
        Dy}, {Y[94] \[ShortRightArrow] Y[117], 
        Dy}, {Y[95] \[ShortRightArrow] Y[76], 
        Dy}, {Y[95] \[ShortRightArrow] Y[81], 
        Dy}, {Y[95] \[ShortRightArrow] Y[85], 
        Dy}, {Y[95] \[ShortRightArrow] Y[88], 
        Dy}, {Y[95] \[ShortRightArrow] Y[92], 
        Dy}, {Y[95] \[ShortRightArrow] Y[111], 
        Dy}, {Y[95] \[ShortRightArrow] Y[120], 
        Dy}, {Y[95] \[ShortRightArrow] Y[121], 
        Dy}, {Y[96] \[ShortRightArrow] Y[61], 
        Dy}, {Y[96] \[ShortRightArrow] Y[64], 
        Dy}, {Y[96] \[ShortRightArrow] Y[83], 
        Dy}, {Y[96] \[ShortRightArrow] Y[89], 
        Dy}, {Y[96] \[ShortRightArrow] Y[113], 
        Dy}, {Y[96] \[ShortRightArrow] Y[123], 
        Dy}, {Y[96] \[ShortRightArrow] Y[127], 
        Dy}, {Y[97] \[ShortRightArrow] Y[65], 
        Dy}, {Y[97] \[ShortRightArrow] Y[70], 
        Dy}, {Y[97] \[ShortRightArrow] Y[93], 
        Dy}, {Y[97] \[ShortRightArrow] Y[100], 
        Dy}, {Y[97] \[ShortRightArrow] Y[104], 
        Dy}, {Y[97] \[ShortRightArrow] Y[124], 
        Dy}, {Y[98] \[ShortRightArrow] Y[69], 
        Dy}, {Y[98] \[ShortRightArrow] Y[86], 
        Dy}, {Y[98] \[ShortRightArrow] Y[94], 
        Dy}, {Y[98] \[ShortRightArrow] Y[106], 
        Dy}, {Y[98] \[ShortRightArrow] Y[117], 
        Dy}, {Y[98] \[ShortRightArrow] Y[125], 
        Dy}, {Y[99] \[ShortRightArrow] Y[79], 
        Dy}, {Y[99] \[ShortRightArrow] Y[91], 
        Dy}, {Y[99] \[ShortRightArrow] Y[101], 
        Dy}, {Y[99] \[ShortRightArrow] Y[118], 
        Dy}, {Y[99] \[ShortRightArrow] Y[119], 
        Dy}, {Y[100] \[ShortRightArrow] Y[65], 
        Dy}, {Y[100] \[ShortRightArrow] Y[83], 
        Dy}, {Y[100] \[ShortRightArrow] Y[87], 
        Dy}, {Y[100] \[ShortRightArrow] Y[97], 
        Dy}, {Y[100] \[ShortRightArrow] Y[114], 
        Dy}, {Y[100] \[ShortRightArrow] Y[123], 
        Dy}, {Y[100] \[ShortRightArrow] Y[124], 
        Dy}, {Y[100] \[ShortRightArrow] Y[132], 
        Dy}, {Y[101] \[ShortRightArrow] Y[79], 
        Dy}, {Y[101] \[ShortRightArrow] Y[84], 
        Dy}, {Y[101] \[ShortRightArrow] Y[99], 
        Dy}, {Y[101] \[ShortRightArrow] Y[109], 
        Dy}, {Y[101] \[ShortRightArrow] Y[119], 
        Dy}, {Y[101] \[ShortRightArrow] Y[131], 
        Dy}, {Y[102] \[ShortRightArrow] Y[72], 
        Dy}, {Y[102] \[ShortRightArrow] Y[80], 
        Dy}, {Y[102] \[ShortRightArrow] Y[84], 
        Dy}, {Y[102] \[ShortRightArrow] Y[109], 
        Dy}, {Y[102] \[ShortRightArrow] Y[110], 
        Dy}, {Y[102] \[ShortRightArrow] Y[129], 
        Dy}, {Y[103] \[ShortRightArrow] Y[77], 
        Dy}, {Y[103] \[ShortRightArrow] Y[92], 
        Dy}, {Y[103] \[ShortRightArrow] Y[107], 
        Dy}, {Y[103] \[ShortRightArrow] Y[111], 
        Dy}, {Y[103] \[ShortRightArrow] Y[136], 
        Dy}, {Y[103] \[ShortRightArrow] Y[137], 
        Dy}, {Y[104] \[ShortRightArrow] Y[93], 
        Dy}, {Y[104] \[ShortRightArrow] Y[97], 
        Dy}, {Y[104] \[ShortRightArrow] Y[115], 
        Dy}, {Y[104] \[ShortRightArrow] Y[124], 
        Dy}, {Y[104] \[ShortRightArrow] Y[128], 
        Dy}, {Y[104] \[ShortRightArrow] Y[130], 
        Dy}, {Y[105] \[ShortRightArrow] Y[90], 
        Dy}, {Y[105] \[ShortRightArrow] Y[93], 
        Dy}, {Y[105] \[ShortRightArrow] Y[115], 
        Dy}, {Y[105] \[ShortRightArrow] Y[116], 
        Dy}, {Y[106] \[ShortRightArrow] Y[86], 
        Dy}, {Y[106] \[ShortRightArrow] Y[91], 
        Dy}, {Y[106] \[ShortRightArrow] Y[98], 
        Dy}, {Y[106] \[ShortRightArrow] Y[118], 
        Dy}, {Y[106] \[ShortRightArrow] Y[125], 
        Dy}, {Y[107] \[ShortRightArrow] Y[77], 
        Dy}, {Y[107] \[ShortRightArrow] Y[78], 
        Dy}, {Y[107] \[ShortRightArrow] Y[103], 
        Dy}, {Y[107] \[ShortRightArrow] Y[122], 
        Dy}, {Y[107] \[ShortRightArrow] Y[137], 
        Dy}, {Y[108] \[ShortRightArrow] Y[90], 
        Dy}, {Y[108] \[ShortRightArrow] Y[94], 
        Dy}, {Y[108] \[ShortRightArrow] Y[116], 
        Dy}, {Y[108] \[ShortRightArrow] Y[117], 
        Dy}, {Y[109] \[ShortRightArrow] Y[84], 
        Dy}, {Y[109] \[ShortRightArrow] Y[101], 
        Dy}, {Y[109] \[ShortRightArrow] Y[102], 
        Dy}, {Y[109] \[ShortRightArrow] Y[129], 
        Dy}, {Y[109] \[ShortRightArrow] Y[131], 
        Dy}, {Y[110] \[ShortRightArrow] Y[80], 
        Dy}, {Y[110] \[ShortRightArrow] Y[88], 
        Dy}, {Y[110] \[ShortRightArrow] Y[102], 
        Dy}, {Y[110] \[ShortRightArrow] Y[112], 
        Dy}, {Y[110] \[ShortRightArrow] Y[129], 
        Dy}, {Y[111] \[ShortRightArrow] Y[92], 
        Dy}, {Y[111] \[ShortRightArrow] Y[95], 
        Dy}, {Y[111] \[ShortRightArrow] Y[103], 
        Dy}, {Y[111] \[ShortRightArrow] Y[121], 
        Dy}, {Y[111] \[ShortRightArrow] Y[136], 
        Dy}, {Y[112] \[ShortRightArrow] Y[88], 
        Dy}, {Y[112] \[ShortRightArrow] Y[110], 
        Dy}, {Y[112] \[ShortRightArrow] Y[120], 
        Dy}, {Y[112] \[ShortRightArrow] Y[129], 
        Dy}, {Y[112] \[ShortRightArrow] Y[144], 
        Dy}, {Y[112] \[ShortRightArrow] Y[149], 
        Dy}, {Y[113] \[ShortRightArrow] Y[82], 
        Dy}, {Y[113] \[ShortRightArrow] Y[89], 
        Dy}, {Y[113] \[ShortRightArrow] Y[96], 
        Dy}, {Y[113] \[ShortRightArrow] Y[127], 
        Dy}, {Y[113] \[ShortRightArrow] Y[134], 
        Dy}, {Y[114] \[ShortRightArrow] Y[100], 
        Dy}, {Y[114] \[ShortRightArrow] Y[124], 
        Dy}, {Y[114] \[ShortRightArrow] Y[132], 
        Dy}, {Y[114] \[ShortRightArrow] Y[145], 
        Dy}, {Y[115] \[ShortRightArrow] Y[93], 
        Dy}, {Y[115] \[ShortRightArrow] Y[104], 
        Dy}, {Y[115] \[ShortRightArrow] Y[105], 
        Dy}, {Y[115] \[ShortRightArrow] Y[116], 
        Dy}, {Y[115] \[ShortRightArrow] Y[130], 
        Dy}, {Y[115] \[ShortRightArrow] Y[142], 
        Dy}, {Y[116] \[ShortRightArrow] Y[90], 
        Dy}, {Y[116] \[ShortRightArrow] Y[105], 
        Dy}, {Y[116] \[ShortRightArrow] Y[108], 
        Dy}, {Y[116] \[ShortRightArrow] Y[115], 
        Dy}, {Y[116] \[ShortRightArrow] Y[117], 
        Dy}, {Y[116] \[ShortRightArrow] Y[143], 
        Dy}, {Y[117] \[ShortRightArrow] Y[94], 
        Dy}, {Y[117] \[ShortRightArrow] Y[98], 
        Dy}, {Y[117] \[ShortRightArrow] Y[108], 
        Dy}, {Y[117] \[ShortRightArrow] Y[116], 
        Dy}, {Y[117] \[ShortRightArrow] Y[125], 
        Dy}, {Y[117] \[ShortRightArrow] Y[143], 
        Dy}, {Y[117] \[ShortRightArrow] Y[154], 
        Dy}, {Y[118] \[ShortRightArrow] Y[91], 
        Dy}, {Y[118] \[ShortRightArrow] Y[99], 
        Dy}, {Y[118] \[ShortRightArrow] Y[106], 
        Dy}, {Y[118] \[ShortRightArrow] Y[119], 
        Dy}, {Y[118] \[ShortRightArrow] Y[125], 
        Dy}, {Y[118] \[ShortRightArrow] Y[135], 
        Dy}, {Y[119] \[ShortRightArrow] Y[99], 
        Dy}, {Y[119] \[ShortRightArrow] Y[101], 
        Dy}, {Y[119] \[ShortRightArrow] Y[118], 
        Dy}, {Y[119] \[ShortRightArrow] Y[131], 
        Dy}, {Y[119] \[ShortRightArrow] Y[135], 
        Dy}, {Y[120] \[ShortRightArrow] Y[88], 
        Dy}, {Y[120] \[ShortRightArrow] Y[95], 
        Dy}, {Y[120] \[ShortRightArrow] Y[112], 
        Dy}, {Y[120] \[ShortRightArrow] Y[121], 
        Dy}, {Y[120] \[ShortRightArrow] Y[126], 
        Dy}, {Y[120] \[ShortRightArrow] Y[149], 
        Dy}, {Y[121] \[ShortRightArrow] Y[95], 
        Dy}, {Y[121] \[ShortRightArrow] Y[111], 
        Dy}, {Y[121] \[ShortRightArrow] Y[120], 
        Dy}, {Y[121] \[ShortRightArrow] Y[126], 
        Dy}, {Y[121] \[ShortRightArrow] Y[136], 
        Dy}, {Y[121] \[ShortRightArrow] Y[138], 
        Dy}, {Y[121] \[ShortRightArrow] Y[139], 
        Dy}, {Y[122] \[ShortRightArrow] Y[107], 
        Dy}, {Y[122] \[ShortRightArrow] Y[137], 
        Dy}, {Y[122] \[ShortRightArrow] Y[150], 
        Dy}, {Y[123] \[ShortRightArrow] Y[83], 
        Dy}, {Y[123] \[ShortRightArrow] Y[96], 
        Dy}, {Y[123] \[ShortRightArrow] Y[100], 
        Dy}, {Y[123] \[ShortRightArrow] Y[127], 
        Dy}, {Y[123] \[ShortRightArrow] Y[132], 
        Dy}, {Y[123] \[ShortRightArrow] Y[141], 
        Dy}, {Y[124] \[ShortRightArrow] Y[97], 
        Dy}, {Y[124] \[ShortRightArrow] Y[100], 
        Dy}, {Y[124] \[ShortRightArrow] Y[104], 
        Dy}, {Y[124] \[ShortRightArrow] Y[114], 
        Dy}, {Y[124] \[ShortRightArrow] Y[128], 
        Dy}, {Y[124] \[ShortRightArrow] Y[140], 
        Dy}, {Y[124] \[ShortRightArrow] Y[145], 
        Dy}, {Y[125] \[ShortRightArrow] Y[98], 
        Dy}, {Y[125] \[ShortRightArrow] Y[106], 
        Dy}, {Y[125] \[ShortRightArrow] Y[117], 
        Dy}, {Y[125] \[ShortRightArrow] Y[118], 
        Dy}, {Y[125] \[ShortRightArrow] Y[135], 
        Dy}, {Y[125] \[ShortRightArrow] Y[154], 
        Dy}, {Y[125] \[ShortRightArrow] Y[155], 
        Dy}, {Y[125] \[ShortRightArrow] Y[162], 
        Dy}, {Y[126] \[ShortRightArrow] Y[120], 
        Dy}, {Y[126] \[ShortRightArrow] Y[121], 
        Dy}, {Y[126] \[ShortRightArrow] Y[138], 
        Dy}, {Y[126] \[ShortRightArrow] Y[149], 
        Dy}, {Y[127] \[ShortRightArrow] Y[96], 
        Dy}, {Y[127] \[ShortRightArrow] Y[113], 
        Dy}, {Y[127] \[ShortRightArrow] Y[123], 
        Dy}, {Y[127] \[ShortRightArrow] Y[134], 
        Dy}, {Y[127] \[ShortRightArrow] Y[141], 
        Dy}, {Y[128] \[ShortRightArrow] Y[104], 
        Dy}, {Y[128] \[ShortRightArrow] Y[124], 
        Dy}, {Y[128] \[ShortRightArrow] Y[130], 
        Dy}, {Y[128] \[ShortRightArrow] Y[140], 
        Dy}, {Y[129] \[ShortRightArrow] Y[102], 
        Dy}, {Y[129] \[ShortRightArrow] Y[109], 
        Dy}, {Y[129] \[ShortRightArrow] Y[110], 
        Dy}, {Y[129] \[ShortRightArrow] Y[112], 
        Dy}, {Y[129] \[ShortRightArrow] Y[131], 
        Dy}, {Y[129] \[ShortRightArrow] Y[133], 
        Dy}, {Y[129] \[ShortRightArrow] Y[144], 
        Dy}, {Y[130] \[ShortRightArrow] Y[104], 
        Dy}, {Y[130] \[ShortRightArrow] Y[115], 
        Dy}, {Y[130] \[ShortRightArrow] Y[128], 
        Dy}, {Y[130] \[ShortRightArrow] Y[140], 
        Dy}, {Y[130] \[ShortRightArrow] Y[142], 
        Dy}, {Y[130] \[ShortRightArrow] Y[146], 
        Dy}, {Y[130] \[ShortRightArrow] Y[156], 
        Dy}, {Y[131] \[ShortRightArrow] Y[101], 
        Dy}, {Y[131] \[ShortRightArrow] Y[109], 
        Dy}, {Y[131] \[ShortRightArrow] Y[119], 
        Dy}, {Y[131] \[ShortRightArrow] Y[129], 
        Dy}, {Y[131] \[ShortRightArrow] Y[133], 
        Dy}, {Y[131] \[ShortRightArrow] Y[135], 
        Dy}, {Y[131] \[ShortRightArrow] Y[147], 
        Dy}, {Y[131] \[ShortRightArrow] Y[148], 
        Dy}, {Y[131] \[ShortRightArrow] Y[158], 
        Dy}, {Y[132] \[ShortRightArrow] Y[100], 
        Dy}, {Y[132] \[ShortRightArrow] Y[114], 
        Dy}, {Y[132] \[ShortRightArrow] Y[123], 
        Dy}, {Y[132] \[ShortRightArrow] Y[141], 
        Dy}, {Y[132] \[ShortRightArrow] Y[145], 
        Dy}, {Y[132] \[ShortRightArrow] Y[164], 
        Dy}, {Y[133] \[ShortRightArrow] Y[129], 
        Dy}, {Y[133] \[ShortRightArrow] Y[131], 
        Dy}, {Y[133] \[ShortRightArrow] Y[144], 
        Dy}, {Y[133] \[ShortRightArrow] Y[148], 
        Dy}, {Y[134] \[ShortRightArrow] Y[113], 
        Dy}, {Y[134] \[ShortRightArrow] Y[127], 
        Dy}, {Y[134] \[ShortRightArrow] Y[141], 
        Dy}, {Y[134] \[ShortRightArrow] Y[152], 
        Dy}, {Y[134] \[ShortRightArrow] Y[153], 
        Dy}, {Y[135] \[ShortRightArrow] Y[118], 
        Dy}, {Y[135] \[ShortRightArrow] Y[119], 
        Dy}, {Y[135] \[ShortRightArrow] Y[125], 
        Dy}, {Y[135] \[ShortRightArrow] Y[131], 
        Dy}, {Y[135] \[ShortRightArrow] Y[147], 
        Dy}, {Y[135] \[ShortRightArrow] Y[155], 
        Dy}, {Y[136] \[ShortRightArrow] Y[103], 
        Dy}, {Y[136] \[ShortRightArrow] Y[111], 
        Dy}, {Y[136] \[ShortRightArrow] Y[121], 
        Dy}, {Y[136] \[ShortRightArrow] Y[137], 
        Dy}, {Y[136] \[ShortRightArrow] Y[139], 
        Dy}, {Y[136] \[ShortRightArrow] Y[157], 
        Dy}, {Y[136] \[ShortRightArrow] Y[159], 
        Dy}, {Y[137] \[ShortRightArrow] Y[103], 
        Dy}, {Y[137] \[ShortRightArrow] Y[107], 
        Dy}, {Y[137] \[ShortRightArrow] Y[122], 
        Dy}, {Y[137] \[ShortRightArrow] Y[136], 
        Dy}, {Y[137] \[ShortRightArrow] Y[150], 
        Dy}, {Y[137] \[ShortRightArrow] Y[159], 
        Dy}, {Y[137] \[ShortRightArrow] Y[171], 
        Dy}, {Y[138] \[ShortRightArrow] Y[121], 
        Dy}, {Y[138] \[ShortRightArrow] Y[126], 
        Dy}, {Y[138] \[ShortRightArrow] Y[139], 
        Dy}, {Y[138] \[ShortRightArrow] Y[149], 
        Dy}, {Y[138] \[ShortRightArrow] Y[157], 
        Dy}, {Y[138] \[ShortRightArrow] Y[163], 
        Dy}, {Y[138] \[ShortRightArrow] Y[170], 
        Dy}, {Y[139] \[ShortRightArrow] Y[121], 
        Dy}, {Y[139] \[ShortRightArrow] Y[136], 
        Dy}, {Y[139] \[ShortRightArrow] Y[138], 
        Dy}, {Y[139] \[ShortRightArrow] Y[157], 
        Dy}, {Y[140] \[ShortRightArrow] Y[124], 
        Dy}, {Y[140] \[ShortRightArrow] Y[128], 
        Dy}, {Y[140] \[ShortRightArrow] Y[130], 
        Dy}, {Y[140] \[ShortRightArrow] Y[145], 
        Dy}, {Y[140] \[ShortRightArrow] Y[156], 
        Dy}, {Y[141] \[ShortRightArrow] Y[123], 
        Dy}, {Y[141] \[ShortRightArrow] Y[127], 
        Dy}, {Y[141] \[ShortRightArrow] Y[132], 
        Dy}, {Y[141] \[ShortRightArrow] Y[134], 
        Dy}, {Y[141] \[ShortRightArrow] Y[153], 
        Dy}, {Y[141] \[ShortRightArrow] Y[164], 
        Dy}, {Y[142] \[ShortRightArrow] Y[115], 
        Dy}, {Y[142] \[ShortRightArrow] Y[130], 
        Dy}, {Y[142] \[ShortRightArrow] Y[143], 
        Dy}, {Y[142] \[ShortRightArrow] Y[146], 
        Dy}, {Y[142] \[ShortRightArrow] Y[151], 
        Dy}, {Y[143] \[ShortRightArrow] Y[116], 
        Dy}, {Y[143] \[ShortRightArrow] Y[117], 
        Dy}, {Y[143] \[ShortRightArrow] Y[142], 
        Dy}, {Y[143] \[ShortRightArrow] Y[151], 
        Dy}, {Y[143] \[ShortRightArrow] Y[154], 
        Dy}, {Y[144] \[ShortRightArrow] Y[112], 
        Dy}, {Y[144] \[ShortRightArrow] Y[129], 
        Dy}, {Y[144] \[ShortRightArrow] Y[133], 
        Dy}, {Y[144] \[ShortRightArrow] Y[148], 
        Dy}, {Y[144] \[ShortRightArrow] Y[149], 
        Dy}, {Y[144] \[ShortRightArrow] Y[165], 
        Dy}, {Y[144] \[ShortRightArrow] Y[169], 
        Dy}, {Y[145] \[ShortRightArrow] Y[114], 
        Dy}, {Y[145] \[ShortRightArrow] Y[124], 
        Dy}, {Y[145] \[ShortRightArrow] Y[132], 
        Dy}, {Y[145] \[ShortRightArrow] Y[140], 
        Dy}, {Y[145] \[ShortRightArrow] Y[156], 
        Dy}, {Y[145] \[ShortRightArrow] Y[160], 
        Dy}, {Y[145] \[ShortRightArrow] Y[164], 
        Dy}, {Y[145] \[ShortRightArrow] Y[188], 
        Dy}, {Y[146] \[ShortRightArrow] Y[130], 
        Dy}, {Y[146] \[ShortRightArrow] Y[142], 
        Dy}, {Y[146] \[ShortRightArrow] Y[151], 
        Dy}, {Y[146] \[ShortRightArrow] Y[156], 
        Dy}, {Y[146] \[ShortRightArrow] Y[161], 
        Dy}, {Y[147] \[ShortRightArrow] Y[131], 
        Dy}, {Y[147] \[ShortRightArrow] Y[135], 
        Dy}, {Y[147] \[ShortRightArrow] Y[155], 
        Dy}, {Y[147] \[ShortRightArrow] Y[158], 
        Dy}, {Y[147] \[ShortRightArrow] Y[167], 
        Dy}, {Y[148] \[ShortRightArrow] Y[131], 
        Dy}, {Y[148] \[ShortRightArrow] Y[133], 
        Dy}, {Y[148] \[ShortRightArrow] Y[144], 
        Dy}, {Y[148] \[ShortRightArrow] Y[158], 
        Dy}, {Y[148] \[ShortRightArrow] Y[168], 
        Dy}, {Y[148] \[ShortRightArrow] Y[169], 
        Dy}, {Y[149] \[ShortRightArrow] Y[112], 
        Dy}, {Y[149] \[ShortRightArrow] Y[120], 
        Dy}, {Y[149] \[ShortRightArrow] Y[126], 
        Dy}, {Y[149] \[ShortRightArrow] Y[138], 
        Dy}, {Y[149] \[ShortRightArrow] Y[144], 
        Dy}, {Y[149] \[ShortRightArrow] Y[163], 
        Dy}, {Y[149] \[ShortRightArrow] Y[165], 
        Dy}, {Y[150] \[ShortRightArrow] Y[122], 
        Dy}, {Y[150] \[ShortRightArrow] Y[137], 
        Dy}, {Y[150] \[ShortRightArrow] Y[171], 
        Dy}, {Y[151] \[ShortRightArrow] Y[142], 
        Dy}, {Y[151] \[ShortRightArrow] Y[143], 
        Dy}, {Y[151] \[ShortRightArrow] Y[146], 
        Dy}, {Y[151] \[ShortRightArrow] Y[154], 
        Dy}, {Y[151] \[ShortRightArrow] Y[161], 
        Dy}, {Y[151] \[ShortRightArrow] Y[166], 
        Dy}, {Y[151] \[ShortRightArrow] Y[175], 
        Dy}, {Y[152] \[ShortRightArrow] Y[134], 
        Dy}, {Y[152] \[ShortRightArrow] Y[153], 
        Dy}, {Y[152] \[ShortRightArrow] Y[172], 
        Dy}, {Y[152] \[ShortRightArrow] Y[178], 
        Dy}, {Y[153] \[ShortRightArrow] Y[134], 
        Dy}, {Y[153] \[ShortRightArrow] Y[141], 
        Dy}, {Y[153] \[ShortRightArrow] Y[152], 
        Dy}, {Y[153] \[ShortRightArrow] Y[164], 
        Dy}, {Y[153] \[ShortRightArrow] Y[172], 
        Dy}, {Y[153] \[ShortRightArrow] Y[176], 
        Dy}, {Y[154] \[ShortRightArrow] Y[117], 
        Dy}, {Y[154] \[ShortRightArrow] Y[125], 
        Dy}, {Y[154] \[ShortRightArrow] Y[143], 
        Dy}, {Y[154] \[ShortRightArrow] Y[151], 
        Dy}, {Y[154] \[ShortRightArrow] Y[162], 
        Dy}, {Y[154] \[ShortRightArrow] Y[166], 
        Dy}, {Y[155] \[ShortRightArrow] Y[125], 
        Dy}, {Y[155] \[ShortRightArrow] Y[135], 
        Dy}, {Y[155] \[ShortRightArrow] Y[147], 
        Dy}, {Y[155] \[ShortRightArrow] Y[162], 
        Dy}, {Y[155] \[ShortRightArrow] Y[167], 
        Dy}, {Y[155] \[ShortRightArrow] Y[173], 
        Dy}, {Y[156] \[ShortRightArrow] Y[130], 
        Dy}, {Y[156] \[ShortRightArrow] Y[140], 
        Dy}, {Y[156] \[ShortRightArrow] Y[145], 
        Dy}, {Y[156] \[ShortRightArrow] Y[146], 
        Dy}, {Y[156] \[ShortRightArrow] Y[160], 
        Dy}, {Y[156] \[ShortRightArrow] Y[161], 
        Dy}, {Y[157] \[ShortRightArrow] Y[136], 
        Dy}, {Y[157] \[ShortRightArrow] Y[138], 
        Dy}, {Y[157] \[ShortRightArrow] Y[139], 
        Dy}, {Y[157] \[ShortRightArrow] Y[159], 
        Dy}, {Y[157] \[ShortRightArrow] Y[170], 
        Dy}, {Y[158] \[ShortRightArrow] Y[131], 
        Dy}, {Y[158] \[ShortRightArrow] Y[147], 
        Dy}, {Y[158] \[ShortRightArrow] Y[148], 
        Dy}, {Y[158] \[ShortRightArrow] Y[167], 
        Dy}, {Y[158] \[ShortRightArrow] Y[168], 
        Dy}, {Y[158] \[ShortRightArrow] Y[179], 
        Dy}, {Y[159] \[ShortRightArrow] Y[136], 
        Dy}, {Y[159] \[ShortRightArrow] Y[137], 
        Dy}, {Y[159] \[ShortRightArrow] Y[157], 
        Dy}, {Y[159] \[ShortRightArrow] Y[170], 
        Dy}, {Y[159] \[ShortRightArrow] Y[171], 
        Dy}, {Y[159] \[ShortRightArrow] Y[181], 
        Dy}, {Y[159] \[ShortRightArrow] Y[182], 
        Dy}, {Y[160] \[ShortRightArrow] Y[145], 
        Dy}, {Y[160] \[ShortRightArrow] Y[156], 
        Dy}, {Y[160] \[ShortRightArrow] Y[161], 
        Dy}, {Y[160] \[ShortRightArrow] Y[186], 
        Dy}, {Y[160] \[ShortRightArrow] Y[188], 
        Dy}, {Y[161] \[ShortRightArrow] Y[146], 
        Dy}, {Y[161] \[ShortRightArrow] Y[151], 
        Dy}, {Y[161] \[ShortRightArrow] Y[156], 
        Dy}, {Y[161] \[ShortRightArrow] Y[160], 
        Dy}, {Y[161] \[ShortRightArrow] Y[175], 
        Dy}, {Y[161] \[ShortRightArrow] Y[186], 
        Dy}, {Y[161] \[ShortRightArrow] Y[190], 
        Dy}, {Y[162] \[ShortRightArrow] Y[125], 
        Dy}, {Y[162] \[ShortRightArrow] Y[154], 
        Dy}, {Y[162] \[ShortRightArrow] Y[155], 
        Dy}, {Y[162] \[ShortRightArrow] Y[166], 
        Dy}, {Y[162] \[ShortRightArrow] Y[173], 
        Dy}, {Y[162] \[ShortRightArrow] Y[183], 
        Dy}, {Y[162] \[ShortRightArrow] Y[184], 
        Dy}, {Y[163] \[ShortRightArrow] Y[138], 
        Dy}, {Y[163] \[ShortRightArrow] Y[149], 
        Dy}, {Y[163] \[ShortRightArrow] Y[165], 
        Dy}, {Y[163] \[ShortRightArrow] Y[170], 
        Dy}, {Y[163] \[ShortRightArrow] Y[180], 
        Dy}, {Y[164] \[ShortRightArrow] Y[132], 
        Dy}, {Y[164] \[ShortRightArrow] Y[141], 
        Dy}, {Y[164] \[ShortRightArrow] Y[145], 
        Dy}, {Y[164] \[ShortRightArrow] Y[153], 
        Dy}, {Y[164] \[ShortRightArrow] Y[176], 
        Dy}, {Y[164] \[ShortRightArrow] Y[188], 
        Dy}, {Y[164] \[ShortRightArrow] Y[201], 
        Dy}, {Y[165] \[ShortRightArrow] Y[144], 
        Dy}, {Y[165] \[ShortRightArrow] Y[149], 
        Dy}, {Y[165] \[ShortRightArrow] Y[163], 
        Dy}, {Y[165] \[ShortRightArrow] Y[169], 
        Dy}, {Y[165] \[ShortRightArrow] Y[177], 
        Dy}, {Y[165] \[ShortRightArrow] Y[180], 
        Dy}, {Y[166] \[ShortRightArrow] Y[151], 
        Dy}, {Y[166] \[ShortRightArrow] Y[154], 
        Dy}, {Y[166] \[ShortRightArrow] Y[162], 
        Dy}, {Y[166] \[ShortRightArrow] Y[175], 
        Dy}, {Y[166] \[ShortRightArrow] Y[183], 
        Dy}, {Y[167] \[ShortRightArrow] Y[147], 
        Dy}, {Y[167] \[ShortRightArrow] Y[155], 
        Dy}, {Y[167] \[ShortRightArrow] Y[158], 
        Dy}, {Y[167] \[ShortRightArrow] Y[173], 
        Dy}, {Y[167] \[ShortRightArrow] Y[174], 
        Dy}, {Y[167] \[ShortRightArrow] Y[179], 
        Dy}, {Y[168] \[ShortRightArrow] Y[148], 
        Dy}, {Y[168] \[ShortRightArrow] Y[158], 
        Dy}, {Y[168] \[ShortRightArrow] Y[169], 
        Dy}, {Y[168] \[ShortRightArrow] Y[179], 
        Dy}, {Y[169] \[ShortRightArrow] Y[144], 
        Dy}, {Y[169] \[ShortRightArrow] Y[148], 
        Dy}, {Y[169] \[ShortRightArrow] Y[165], 
        Dy}, {Y[169] \[ShortRightArrow] Y[168], 
        Dy}, {Y[169] \[ShortRightArrow] Y[177], 
        Dy}, {Y[169] \[ShortRightArrow] Y[179], 
        Dy}, {Y[169] \[ShortRightArrow] Y[192], 
        Dy}, {Y[169] \[ShortRightArrow] Y[193], 
        Dy}, {Y[170] \[ShortRightArrow] Y[138], 
        Dy}, {Y[170] \[ShortRightArrow] Y[157], 
        Dy}, {Y[170] \[ShortRightArrow] Y[159], 
        Dy}, {Y[170] \[ShortRightArrow] Y[163], 
        Dy}, {Y[170] \[ShortRightArrow] Y[180], 
        Dy}, {Y[170] \[ShortRightArrow] Y[181], 
        Dy}, {Y[171] \[ShortRightArrow] Y[137], 
        Dy}, {Y[171] \[ShortRightArrow] Y[150], 
        Dy}, {Y[171] \[ShortRightArrow] Y[159], 
        Dy}, {Y[171] \[ShortRightArrow] Y[182], 
        Dy}, {Y[172] \[ShortRightArrow] Y[152], 
        Dy}, {Y[172] \[ShortRightArrow] Y[153], 
        Dy}, {Y[172] \[ShortRightArrow] Y[176], 
        Dy}, {Y[172] \[ShortRightArrow] Y[178], 
        Dy}, {Y[172] \[ShortRightArrow] Y[185], 
        Dy}, {Y[173] \[ShortRightArrow] Y[155], 
        Dy}, {Y[173] \[ShortRightArrow] Y[162], 
        Dy}, {Y[173] \[ShortRightArrow] Y[167], 
        Dy}, {Y[173] \[ShortRightArrow] Y[174], 
        Dy}, {Y[173] \[ShortRightArrow] Y[184], 
        Dy}, {Y[173] \[ShortRightArrow] Y[189], 
        Dy}, {Y[174] \[ShortRightArrow] Y[167], 
        Dy}, {Y[174] \[ShortRightArrow] Y[173], 
        Dy}, {Y[174] \[ShortRightArrow] Y[179], 
        Dy}, {Y[174] \[ShortRightArrow] Y[187], 
        Dy}, {Y[174] \[ShortRightArrow] Y[189], 
        Dy}, {Y[175] \[ShortRightArrow] Y[151], 
        Dy}, {Y[175] \[ShortRightArrow] Y[161], 
        Dy}, {Y[175] \[ShortRightArrow] Y[166], 
        Dy}, {Y[175] \[ShortRightArrow] Y[183], 
        Dy}, {Y[175] \[ShortRightArrow] Y[190], 
        Dy}, {Y[175] \[ShortRightArrow] Y[199], 
        Dy}, {Y[176] \[ShortRightArrow] Y[153], 
        Dy}, {Y[176] \[ShortRightArrow] Y[164], 
        Dy}, {Y[176] \[ShortRightArrow] Y[172], 
        Dy}, {Y[176] \[ShortRightArrow] Y[185], 
        Dy}, {Y[176] \[ShortRightArrow] Y[197], 
        Dy}, {Y[176] \[ShortRightArrow] Y[201], 
        Dy}, {Y[177] \[ShortRightArrow] Y[165], 
        Dy}, {Y[177] \[ShortRightArrow] Y[169], 
        Dy}, {Y[177] \[ShortRightArrow] Y[180], 
        Dy}, {Y[177] \[ShortRightArrow] Y[193], 
        Dy}, {Y[177] \[ShortRightArrow] Y[194], 
        Dy}, {Y[178] \[ShortRightArrow] Y[152], 
        Dy}, {Y[178] \[ShortRightArrow] Y[172], 
        Dy}, {Y[178] \[ShortRightArrow] Y[185], 
        Dy}, {Y[178] \[ShortRightArrow] Y[203], 
        Dy}, {Y[179] \[ShortRightArrow] Y[158], 
        Dy}, {Y[179] \[ShortRightArrow] Y[167], 
        Dy}, {Y[179] \[ShortRightArrow] Y[168], 
        Dy}, {Y[179] \[ShortRightArrow] Y[169], 
        Dy}, {Y[179] \[ShortRightArrow] Y[174], 
        Dy}, {Y[179] \[ShortRightArrow] Y[187], 
        Dy}, {Y[179] \[ShortRightArrow] Y[191], 
        Dy}, {Y[179] \[ShortRightArrow] Y[192], 
        Dy}, {Y[180] \[ShortRightArrow] Y[163], 
        Dy}, {Y[180] \[ShortRightArrow] Y[165], 
        Dy}, {Y[180] \[ShortRightArrow] Y[170], 
        Dy}, {Y[180] \[ShortRightArrow] Y[177], 
        Dy}, {Y[180] \[ShortRightArrow] Y[181], 
        Dy}, {Y[180] \[ShortRightArrow] Y[194], 
        Dy}, {Y[180] \[ShortRightArrow] Y[196], 
        Dy}, {Y[180] \[ShortRightArrow] Y[204], 
        Dy}, {Y[181] \[ShortRightArrow] Y[159], 
        Dy}, {Y[181] \[ShortRightArrow] Y[170], 
        Dy}, {Y[181] \[ShortRightArrow] Y[180], 
        Dy}, {Y[181] \[ShortRightArrow] Y[182], 
        Dy}, {Y[181] \[ShortRightArrow] Y[196], 
        Dy}, {Y[181] \[ShortRightArrow] Y[200], 
        Dy}, {Y[182] \[ShortRightArrow] Y[159], 
        Dy}, {Y[182] \[ShortRightArrow] Y[171], 
        Dy}, {Y[182] \[ShortRightArrow] Y[181], 
        Dy}, {Y[182] \[ShortRightArrow] Y[200], 
        Dy}, {Y[183] \[ShortRightArrow] Y[162], 
        Dy}, {Y[183] \[ShortRightArrow] Y[166], 
        Dy}, {Y[183] \[ShortRightArrow] Y[175], 
        Dy}, {Y[183] \[ShortRightArrow] Y[184], 
        Dy}, {Y[183] \[ShortRightArrow] Y[195], 
        Dy}, {Y[183] \[ShortRightArrow] Y[199], 
        Dy}, {Y[184] \[ShortRightArrow] Y[162], 
        Dy}, {Y[184] \[ShortRightArrow] Y[173], 
        Dy}, {Y[184] \[ShortRightArrow] Y[183], 
        Dy}, {Y[184] \[ShortRightArrow] Y[189], 
        Dy}, {Y[184] \[ShortRightArrow] Y[195], 
        Dy}, {Y[184] \[ShortRightArrow] Y[202], 
        Dy}, {Y[185] \[ShortRightArrow] Y[172], 
        Dy}, {Y[185] \[ShortRightArrow] Y[176], 
        Dy}, {Y[185] \[ShortRightArrow] Y[178], 
        Dy}, {Y[185] \[ShortRightArrow] Y[197], 
        Dy}, {Y[185] \[ShortRightArrow] Y[203], 
        Dy}, {Y[185] \[ShortRightArrow] Y[208], 
        Dy}, {Y[186] \[ShortRightArrow] Y[160], 
        Dy}, {Y[186] \[ShortRightArrow] Y[161], 
        Dy}, {Y[186] \[ShortRightArrow] Y[188], 
        Dy}, {Y[186] \[ShortRightArrow] Y[190], 
        Dy}, {Y[186] \[ShortRightArrow] Y[198], 
        Dy}, {Y[187] \[ShortRightArrow] Y[174], 
        Dy}, {Y[187] \[ShortRightArrow] Y[179], 
        Dy}, {Y[187] \[ShortRightArrow] Y[189], 
        Dy}, {Y[187] \[ShortRightArrow] Y[191], 
        Dy}, {Y[187] \[ShortRightArrow] Y[205], 
        Dy}, {Y[188] \[ShortRightArrow] Y[145], 
        Dy}, {Y[188] \[ShortRightArrow] Y[160], 
        Dy}, {Y[188] \[ShortRightArrow] Y[164], 
        Dy}, {Y[188] \[ShortRightArrow] Y[186], 
        Dy}, {Y[188] \[ShortRightArrow] Y[198], 
        Dy}, {Y[188] \[ShortRightArrow] Y[201], 
        Dy}, {Y[188] \[ShortRightArrow] Y[218], 
        Dy}, {Y[189] \[ShortRightArrow] Y[173], 
        Dy}, {Y[189] \[ShortRightArrow] Y[174], 
        Dy}, {Y[189] \[ShortRightArrow] Y[184], 
        Dy}, {Y[189] \[ShortRightArrow] Y[187], 
        Dy}, {Y[189] \[ShortRightArrow] Y[202], 
        Dy}, {Y[189] \[ShortRightArrow] Y[205], 
        Dy}, {Y[190] \[ShortRightArrow] Y[161], 
        Dy}, {Y[190] \[ShortRightArrow] Y[175], 
        Dy}, {Y[190] \[ShortRightArrow] Y[186], 
        Dy}, {Y[190] \[ShortRightArrow] Y[198], 
        Dy}, {Y[190] \[ShortRightArrow] Y[199], 
        Dy}, {Y[190] \[ShortRightArrow] Y[207], 
        Dy}, {Y[190] \[ShortRightArrow] Y[215], 
        Dy}, {Y[191] \[ShortRightArrow] Y[179], 
        Dy}, {Y[191] \[ShortRightArrow] Y[187], 
        Dy}, {Y[191] \[ShortRightArrow] Y[192], 
        Dy}, {Y[191] \[ShortRightArrow] Y[205], 
        Dy}, {Y[191] \[ShortRightArrow] Y[206], 
        Dy}, {Y[191] \[ShortRightArrow] Y[216], 
        Dy}, {Y[192] \[ShortRightArrow] Y[169], 
        Dy}, {Y[192] \[ShortRightArrow] Y[179], 
        Dy}, {Y[192] \[ShortRightArrow] Y[191], 
        Dy}, {Y[192] \[ShortRightArrow] Y[193], 
        Dy}, {Y[192] \[ShortRightArrow] Y[206], 
        Dy}, {Y[193] \[ShortRightArrow] Y[169], 
        Dy}, {Y[193] \[ShortRightArrow] Y[177], 
        Dy}, {Y[193] \[ShortRightArrow] Y[192], 
        Dy}, {Y[193] \[ShortRightArrow] Y[194], 
        Dy}, {Y[193] \[ShortRightArrow] Y[206], 
        Dy}, {Y[194] \[ShortRightArrow] Y[177], 
        Dy}, {Y[194] \[ShortRightArrow] Y[180], 
        Dy}, {Y[194] \[ShortRightArrow] Y[193], 
        Dy}, {Y[194] \[ShortRightArrow] Y[204], 
        Dy}, {Y[194] \[ShortRightArrow] Y[206], 
        Dy}, {Y[195] \[ShortRightArrow] Y[183], 
        Dy}, {Y[195] \[ShortRightArrow] Y[184], 
        Dy}, {Y[195] \[ShortRightArrow] Y[199], 
        Dy}, {Y[195] \[ShortRightArrow] Y[202], 
        Dy}, {Y[195] \[ShortRightArrow] Y[213], 
        Dy}, {Y[195] \[ShortRightArrow] Y[222], 
        Dy}, {Y[196] \[ShortRightArrow] Y[180], 
        Dy}, {Y[196] \[ShortRightArrow] Y[181], 
        Dy}, {Y[196] \[ShortRightArrow] Y[200], 
        Dy}, {Y[196] \[ShortRightArrow] Y[204], 
        Dy}, {Y[196] \[ShortRightArrow] Y[211], 
        Dy}, {Y[196] \[ShortRightArrow] Y[214], 
        Dy}, {Y[197] \[ShortRightArrow] Y[176], 
        Dy}, {Y[197] \[ShortRightArrow] Y[185], 
        Dy}, {Y[197] \[ShortRightArrow] Y[201], 
        Dy}, {Y[197] \[ShortRightArrow] Y[208], 
        Dy}, {Y[197] \[ShortRightArrow] Y[209], 
        Dy}, {Y[198] \[ShortRightArrow] Y[186], 
        Dy}, {Y[198] \[ShortRightArrow] Y[188], 
        Dy}, {Y[198] \[ShortRightArrow] Y[190], 
        Dy}, {Y[198] \[ShortRightArrow] Y[215], 
        Dy}, {Y[198] \[ShortRightArrow] Y[218], 
        Dy}, {Y[199] \[ShortRightArrow] Y[175], 
        Dy}, {Y[199] \[ShortRightArrow] Y[183], 
        Dy}, {Y[199] \[ShortRightArrow] Y[190], 
        Dy}, {Y[199] \[ShortRightArrow] Y[195], 
        Dy}, {Y[199] \[ShortRightArrow] Y[207], 
        Dy}, {Y[199] \[ShortRightArrow] Y[212], 
        Dy}, {Y[199] \[ShortRightArrow] Y[222], 
        Dy}, {Y[200] \[ShortRightArrow] Y[181], 
        Dy}, {Y[200] \[ShortRightArrow] Y[182], 
        Dy}, {Y[200] \[ShortRightArrow] Y[196], 
        Dy}, {Y[200] \[ShortRightArrow] Y[211], 
        Dy}, {Y[201] \[ShortRightArrow] Y[164], 
        Dy}, {Y[201] \[ShortRightArrow] Y[176], 
        Dy}, {Y[201] \[ShortRightArrow] Y[188], 
        Dy}, {Y[201] \[ShortRightArrow] Y[197], 
        Dy}, {Y[201] \[ShortRightArrow] Y[209], 
        Dy}, {Y[201] \[ShortRightArrow] Y[218], 
        Dy}, {Y[201] \[ShortRightArrow] Y[220], 
        Dy}, {Y[202] \[ShortRightArrow] Y[184], 
        Dy}, {Y[202] \[ShortRightArrow] Y[189], 
        Dy}, {Y[202] \[ShortRightArrow] Y[195], 
        Dy}, {Y[202] \[ShortRightArrow] Y[205], 
        Dy}, {Y[202] \[ShortRightArrow] Y[210], 
        Dy}, {Y[202] \[ShortRightArrow] Y[213], 
        Dy}, {Y[203] \[ShortRightArrow] Y[178], 
        Dy}, {Y[203] \[ShortRightArrow] Y[185], 
        Dy}, {Y[203] \[ShortRightArrow] Y[208], 
        Dy}, {Y[203] \[ShortRightArrow] Y[219], 
        Dy}, {Y[204] \[ShortRightArrow] Y[180], 
        Dy}, {Y[204] \[ShortRightArrow] Y[194], 
        Dy}, {Y[204] \[ShortRightArrow] Y[196], 
        Dy}, {Y[204] \[ShortRightArrow] Y[206], 
        Dy}, {Y[204] \[ShortRightArrow] Y[214], 
        Dy}, {Y[204] \[ShortRightArrow] Y[217], 
        Dy}, {Y[205] \[ShortRightArrow] Y[187], 
        Dy}, {Y[205] \[ShortRightArrow] Y[189], 
        Dy}, {Y[205] \[ShortRightArrow] Y[191], 
        Dy}, {Y[205] \[ShortRightArrow] Y[202], 
        Dy}, {Y[205] \[ShortRightArrow] Y[210], 
        Dy}, {Y[205] \[ShortRightArrow] Y[216], 
        Dy}, {Y[205] \[ShortRightArrow] Y[225], 
        Dy}, {Y[206] \[ShortRightArrow] Y[191], 
        Dy}, {Y[206] \[ShortRightArrow] Y[192], 
        Dy}, {Y[206] \[ShortRightArrow] Y[193], 
        Dy}, {Y[206] \[ShortRightArrow] Y[194], 
        Dy}, {Y[206] \[ShortRightArrow] Y[204], 
        Dy}, {Y[206] \[ShortRightArrow] Y[216], 
        Dy}, {Y[206] \[ShortRightArrow] Y[217], 
        Dy}, {Y[206] \[ShortRightArrow] Y[221], 
        Dy}, {Y[207] \[ShortRightArrow] Y[190], 
        Dy}, {Y[207] \[ShortRightArrow] Y[199], 
        Dy}, {Y[207] \[ShortRightArrow] Y[212], 
        Dy}, {Y[207] \[ShortRightArrow] Y[215], 
        Dy}, {Y[208] \[ShortRightArrow] Y[185], 
        Dy}, {Y[208] \[ShortRightArrow] Y[197], 
        Dy}, {Y[208] \[ShortRightArrow] Y[203], 
        Dy}, {Y[208] \[ShortRightArrow] Y[209], 
        Dy}, {Y[208] \[ShortRightArrow] Y[219], 
        Dy}, {Y[208] \[ShortRightArrow] Y[226], 
        Dy}, {Y[209] \[ShortRightArrow] Y[197], 
        Dy}, {Y[209] \[ShortRightArrow] Y[201], 
        Dy}, {Y[209] \[ShortRightArrow] Y[208], 
        Dy}, {Y[209] \[ShortRightArrow] Y[220], 
        Dy}, {Y[209] \[ShortRightArrow] Y[226], 
        Dy}, {Y[209] \[ShortRightArrow] Y[227], 
        Dy}, {Y[210] \[ShortRightArrow] Y[202], 
        Dy}, {Y[210] \[ShortRightArrow] Y[205], 
        Dy}, {Y[210] \[ShortRightArrow] Y[213], 
        Dy}, {Y[210] \[ShortRightArrow] Y[224], 
        Dy}, {Y[210] \[ShortRightArrow] Y[225], 
        Dy}, {Y[211] \[ShortRightArrow] Y[196], 
        Dy}, {Y[211] \[ShortRightArrow] Y[200], 
        Dy}, {Y[211] \[ShortRightArrow] Y[214], 
        Dy}, {Y[212] \[ShortRightArrow] Y[199], 
        Dy}, {Y[212] \[ShortRightArrow] Y[207], 
        Dy}, {Y[212] \[ShortRightArrow] Y[215], 
        Dy}, {Y[212] \[ShortRightArrow] Y[222], 
        Dy}, {Y[212] \[ShortRightArrow] Y[223], 
        Dy}, {Y[212] \[ShortRightArrow] Y[230], 
        Dy}, {Y[213] \[ShortRightArrow] Y[195], 
        Dy}, {Y[213] \[ShortRightArrow] Y[202], 
        Dy}, {Y[213] \[ShortRightArrow] Y[210], 
        Dy}, {Y[213] \[ShortRightArrow] Y[222], 
        Dy}, {Y[213] \[ShortRightArrow] Y[224], 
        Dy}, {Y[214] \[ShortRightArrow] Y[196], 
        Dy}, {Y[214] \[ShortRightArrow] Y[204], 
        Dy}, {Y[214] \[ShortRightArrow] Y[211], 
        Dy}, {Y[214] \[ShortRightArrow] Y[217], 
        Dy}, {Y[215] \[ShortRightArrow] Y[190], 
        Dy}, {Y[215] \[ShortRightArrow] Y[198], 
        Dy}, {Y[215] \[ShortRightArrow] Y[207], 
        Dy}, {Y[215] \[ShortRightArrow] Y[212], 
        Dy}, {Y[215] \[ShortRightArrow] Y[218], 
        Dy}, {Y[215] \[ShortRightArrow] Y[228], 
        Dy}, {Y[215] \[ShortRightArrow] Y[230], 
        Dy}, {Y[215] \[ShortRightArrow] Y[232], 
        Dy}, {Y[215] \[ShortRightArrow] Y[233], 
        Dy}, {Y[215] \[ShortRightArrow] Y[235], 
        Dy}, {Y[216] \[ShortRightArrow] Y[191], 
        Dy}, {Y[216] \[ShortRightArrow] Y[205], 
        Dy}, {Y[216] \[ShortRightArrow] Y[206], 
        Dy}, {Y[216] \[ShortRightArrow] Y[221], 
        Dy}, {Y[216] \[ShortRightArrow] Y[225], 
        Dy}, {Y[216] \[ShortRightArrow] Y[234], 
        Dy}, {Y[217] \[ShortRightArrow] Y[204], 
        Dy}, {Y[217] \[ShortRightArrow] Y[206], 
        Dy}, {Y[217] \[ShortRightArrow] Y[214], 
        Dy}, {Y[217] \[ShortRightArrow] Y[221], 
        Dy}, {Y[218] \[ShortRightArrow] Y[188], 
        Dy}, {Y[218] \[ShortRightArrow] Y[198], 
        Dy}, {Y[218] \[ShortRightArrow] Y[201], 
        Dy}, {Y[218] \[ShortRightArrow] Y[215], 
        Dy}, {Y[218] \[ShortRightArrow] Y[220], 
        Dy}, {Y[218] \[ShortRightArrow] Y[228], 
        Dy}, {Y[218] \[ShortRightArrow] Y[229], 
        Dy}, {Y[219] \[ShortRightArrow] Y[203], 
        Dy}, {Y[219] \[ShortRightArrow] Y[208], 
        Dy}, {Y[219] \[ShortRightArrow] Y[226], 
        Dy}, {Y[219] \[ShortRightArrow] Y[237], 
        Dy}, {Y[220] \[ShortRightArrow] Y[201], 
        Dy}, {Y[220] \[ShortRightArrow] Y[209], 
        Dy}, {Y[220] \[ShortRightArrow] Y[218], 
        Dy}, {Y[220] \[ShortRightArrow] Y[227], 
        Dy}, {Y[220] \[ShortRightArrow] Y[229], 
        Dy}, {Y[221] \[ShortRightArrow] Y[206], 
        Dy}, {Y[221] \[ShortRightArrow] Y[216], 
        Dy}, {Y[221] \[ShortRightArrow] Y[217], 
        Dy}, {Y[222] \[ShortRightArrow] Y[195], 
        Dy}, {Y[222] \[ShortRightArrow] Y[199], 
        Dy}, {Y[222] \[ShortRightArrow] Y[212], 
        Dy}, {Y[222] \[ShortRightArrow] Y[213], 
        Dy}, {Y[222] \[ShortRightArrow] Y[223], 
        Dy}, {Y[222] \[ShortRightArrow] Y[224], 
        Dy}, {Y[222] \[ShortRightArrow] Y[231], 
        Dy}, {Y[223] \[ShortRightArrow] Y[212], 
        Dy}, {Y[223] \[ShortRightArrow] Y[222], 
        Dy}, {Y[223] \[ShortRightArrow] Y[230], 
        Dy}, {Y[223] \[ShortRightArrow] Y[231], 
        Dy}, {Y[223] \[ShortRightArrow] Y[236], 
        Dy}, {Y[223] \[ShortRightArrow] Y[238], 
        Dy}, {Y[224] \[ShortRightArrow] Y[210], 
        Dy}, {Y[224] \[ShortRightArrow] Y[213], 
        Dy}, {Y[224] \[ShortRightArrow] Y[222], 
        Dy}, {Y[224] \[ShortRightArrow] Y[225], 
        Dy}, {Y[224] \[ShortRightArrow] Y[231], 
        Dy}, {Y[225] \[ShortRightArrow] Y[205], 
        Dy}, {Y[225] \[ShortRightArrow] Y[210], 
        Dy}, {Y[225] \[ShortRightArrow] Y[216], 
        Dy}, {Y[225] \[ShortRightArrow] Y[224], 
        Dy}, {Y[225] \[ShortRightArrow] Y[231], 
        Dy}, {Y[225] \[ShortRightArrow] Y[234], 
        Dy}, {Y[226] \[ShortRightArrow] Y[208], 
        Dy}, {Y[226] \[ShortRightArrow] Y[209], 
        Dy}, {Y[226] \[ShortRightArrow] Y[219], 
        Dy}, {Y[226] \[ShortRightArrow] Y[227], 
        Dy}, {Y[226] \[ShortRightArrow] Y[237], 
        Dy}, {Y[226] \[ShortRightArrow] Y[239], 
        Dy}, {Y[227] \[ShortRightArrow] Y[209], 
        Dy}, {Y[227] \[ShortRightArrow] Y[220], 
        Dy}, {Y[227] \[ShortRightArrow] Y[226], 
        Dy}, {Y[227] \[ShortRightArrow] Y[229], 
        Dy}, {Y[227] \[ShortRightArrow] Y[239], 
        Dy}, {Y[228] \[ShortRightArrow] Y[215], 
        Dy}, {Y[228] \[ShortRightArrow] Y[218], 
        Dy}, {Y[228] \[ShortRightArrow] Y[229], 
        Dy}, {Y[228] \[ShortRightArrow] Y[235], 
        Dy}, {Y[228] \[ShortRightArrow] Y[240], 
        Dy}, {Y[229] \[ShortRightArrow] Y[218], 
        Dy}, {Y[229] \[ShortRightArrow] Y[220], 
        Dy}, {Y[229] \[ShortRightArrow] Y[227], 
        Dy}, {Y[229] \[ShortRightArrow] Y[228], 
        Dy}, {Y[229] \[ShortRightArrow] Y[239], 
        Dy}, {Y[229] \[ShortRightArrow] Y[240], 
        Dy}, {Y[229] \[ShortRightArrow] Y[242], 
        Dy}, {Y[230] \[ShortRightArrow] Y[212], 
        Dy}, {Y[230] \[ShortRightArrow] Y[215], 
        Dy}, {Y[230] \[ShortRightArrow] Y[223], 
        Dy}, {Y[230] \[ShortRightArrow] Y[232], 
        Dy}, {Y[230] \[ShortRightArrow] Y[236], 
        Dy}, {Y[230] \[ShortRightArrow] Y[245], 
        Dy}, {Y[231] \[ShortRightArrow] Y[222], 
        Dy}, {Y[231] \[ShortRightArrow] Y[223], 
        Dy}, {Y[231] \[ShortRightArrow] Y[224], 
        Dy}, {Y[231] \[ShortRightArrow] Y[225], 
        Dy}, {Y[231] \[ShortRightArrow] Y[234], 
        Dy}, {Y[231] \[ShortRightArrow] Y[238], 
        Dy}, {Y[231] \[ShortRightArrow] Y[244], 
        Dy}, {Y[232] \[ShortRightArrow] Y[215], 
        Dy}, {Y[232] \[ShortRightArrow] Y[230], 
        Dy}, {Y[232] \[ShortRightArrow] Y[233], 
        Dy}, {Y[232] \[ShortRightArrow] Y[245], 
        Dy}, {Y[233] \[ShortRightArrow] Y[215], 
        Dy}, {Y[233] \[ShortRightArrow] Y[232], 
        Dy}, {Y[233] \[ShortRightArrow] Y[235], 
        Dy}, {Y[233] \[ShortRightArrow] Y[241], 
        Dy}, {Y[233] \[ShortRightArrow] Y[245], 
        Dy}, {Y[234] \[ShortRightArrow] Y[216], 
        Dy}, {Y[234] \[ShortRightArrow] Y[225], 
        Dy}, {Y[234] \[ShortRightArrow] Y[231], 
        Dy}, {Y[234] \[ShortRightArrow] Y[244], 
        Dy}, {Y[235] \[ShortRightArrow] Y[215], 
        Dy}, {Y[235] \[ShortRightArrow] Y[228], 
        Dy}, {Y[235] \[ShortRightArrow] Y[233], 
        Dy}, {Y[235] \[ShortRightArrow] Y[240], 
        Dy}, {Y[235] \[ShortRightArrow] Y[241], 
        Dy}, {Y[235] \[ShortRightArrow] Y[243], 
        Dy}, {Y[236] \[ShortRightArrow] Y[223], 
        Dy}, {Y[236] \[ShortRightArrow] Y[230], 
        Dy}, {Y[236] \[ShortRightArrow] Y[238], 
        Dy}, {Y[236] \[ShortRightArrow] Y[245], 
        Dy}, {Y[236] \[ShortRightArrow] Y[248], 
        Dy}, {Y[237] \[ShortRightArrow] Y[219], 
        Dy}, {Y[237] \[ShortRightArrow] Y[226], 
        Dy}, {Y[237] \[ShortRightArrow] Y[239], 
        Dy}, {Y[237] \[ShortRightArrow] Y[249], 
        Dy}, {Y[238] \[ShortRightArrow] Y[223], 
        Dy}, {Y[238] \[ShortRightArrow] Y[231], 
        Dy}, {Y[238] \[ShortRightArrow] Y[236], 
        Dy}, {Y[238] \[ShortRightArrow] Y[244], 
        Dy}, {Y[238] \[ShortRightArrow] Y[246], 
        Dy}, {Y[238] \[ShortRightArrow] Y[248], 
        Dy}, {Y[239] \[ShortRightArrow] Y[226], 
        Dy}, {Y[239] \[ShortRightArrow] Y[227], 
        Dy}, {Y[239] \[ShortRightArrow] Y[229], 
        Dy}, {Y[239] \[ShortRightArrow] Y[237], 
        Dy}, {Y[239] \[ShortRightArrow] Y[242], 
        Dy}, {Y[239] \[ShortRightArrow] Y[249], 
        Dy}, {Y[239] \[ShortRightArrow] Y[250], 
        Dy}, {Y[240] \[ShortRightArrow] Y[228], 
        Dy}, {Y[240] \[ShortRightArrow] Y[229], 
        Dy}, {Y[240] \[ShortRightArrow] Y[235], 
        Dy}, {Y[240] \[ShortRightArrow] Y[242], 
        Dy}, {Y[240] \[ShortRightArrow] Y[243], 
        Dy}, {Y[240] \[ShortRightArrow] Y[247], 
        Dy}, {Y[241] \[ShortRightArrow] Y[233], 
        Dy}, {Y[241] \[ShortRightArrow] Y[235], 
        Dy}, {Y[241] \[ShortRightArrow] Y[243], 
        Dy}, {Y[241] \[ShortRightArrow] Y[245], 
        Dy}, {Y[241] \[ShortRightArrow] Y[247], 
        Dy}, {Y[241] \[ShortRightArrow] Y[251], 
        Dy}, {Y[241] \[ShortRightArrow] Y[253], 
        Dy}, {Y[242] \[ShortRightArrow] Y[229], 
        Dy}, {Y[242] \[ShortRightArrow] Y[239], 
        Dy}, {Y[242] \[ShortRightArrow] Y[240], 
        Dy}, {Y[242] \[ShortRightArrow] Y[247], 
        Dy}, {Y[242] \[ShortRightArrow] Y[250], 
        Dy}, {Y[242] \[ShortRightArrow] Y[252], 
        Dy}, {Y[243] \[ShortRightArrow] Y[235], 
        Dy}, {Y[243] \[ShortRightArrow] Y[240], 
        Dy}, {Y[243] \[ShortRightArrow] Y[241], 
        Dy}, {Y[243] \[ShortRightArrow] Y[247], 
        Dy}, {Y[244] \[ShortRightArrow] Y[231], 
        Dy}, {Y[244] \[ShortRightArrow] Y[234], 
        Dy}, {Y[244] \[ShortRightArrow] Y[238], 
        Dy}, {Y[244] \[ShortRightArrow] Y[246], 
        Dy}, {Y[245] \[ShortRightArrow] Y[230], 
        Dy}, {Y[245] \[ShortRightArrow] Y[232], 
        Dy}, {Y[245] \[ShortRightArrow] Y[233], 
        Dy}, {Y[245] \[ShortRightArrow] Y[236], 
        Dy}, {Y[245] \[ShortRightArrow] Y[241], 
        Dy}, {Y[245] \[ShortRightArrow] Y[248], 
        Dy}, {Y[245] \[ShortRightArrow] Y[251], 
        Dy}, {Y[246] \[ShortRightArrow] Y[238], 
        Dy}, {Y[246] \[ShortRightArrow] Y[244], 
        Dy}, {Y[246] \[ShortRightArrow] Y[248], 
        Dy}, {Y[247] \[ShortRightArrow] Y[240], 
        Dy}, {Y[247] \[ShortRightArrow] Y[241], 
        Dy}, {Y[247] \[ShortRightArrow] Y[242], 
        Dy}, {Y[247] \[ShortRightArrow] Y[243], 
        Dy}, {Y[247] \[ShortRightArrow] Y[252], 
        Dy}, {Y[247] \[ShortRightArrow] Y[253], 
        Dy}, {Y[248] \[ShortRightArrow] Y[236], 
        Dy}, {Y[248] \[ShortRightArrow] Y[238], 
        Dy}, {Y[248] \[ShortRightArrow] Y[245], 
        Dy}, {Y[248] \[ShortRightArrow] Y[246], 
        Dy}, {Y[249] \[ShortRightArrow] Y[237], 
        Dy}, {Y[249] \[ShortRightArrow] Y[239], 
        Dy}, {Y[249] \[ShortRightArrow] Y[250], 
        Dy}, {Y[250] \[ShortRightArrow] Y[239], 
        Dy}, {Y[250] \[ShortRightArrow] Y[242], 
        Dy}, {Y[250] \[ShortRightArrow] Y[249], 
        Dy}, {Y[250] \[ShortRightArrow] Y[252], 
        Dy}, {Y[251] \[ShortRightArrow] Y[241], 
        Dy}, {Y[251] \[ShortRightArrow] Y[245], 
        Dy}, {Y[251] \[ShortRightArrow] Y[253], 
        Dy}, {Y[252] \[ShortRightArrow] Y[242], 
        Dy}, {Y[252] \[ShortRightArrow] Y[247], 
        Dy}, {Y[252] \[ShortRightArrow] Y[250], 
        Dy}, {Y[252] \[ShortRightArrow] Y[253], 
        Dy}, {Y[253] \[ShortRightArrow] Y[241], 
        Dy}, {Y[253] \[ShortRightArrow] Y[247], 
        Dy}, {Y[253] \[ShortRightArrow] Y[251], 
        Dy}, {Y[253] \[ShortRightArrow] Y[252], Dy}}\)], "Output"]
}, Closed]],

Cell[BoxData[
    \(\(myic[j_] := 
        Join[\[IndentingNewLine]Table[\(W[i]\)[0] == \ 0, {i, 1, 
              j}], \[IndentingNewLine]Table[\(Y[i]\)[0] \[Equal] 0, {i, 1, 
              j}], \[IndentingNewLine]Table[\(A[i]\)[0] \[Equal] 0, {i, 1, 
              j}], \[IndentingNewLine]Table[\(B[i]\)[0] \[Equal] 0, {i, 1, 
              j}]\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({cpu, istn} = Timing[interpret[STN]]; Print[cpu];\)], "Input"],

Cell[BoxData[
    \(41.776264`\ Second\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(istn\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a - b\ \(A[1]\)[t] - 3\ Da\ \(A[1]\)[t] + 
                Da\ \(A[2]\)[t] + Da\ \(A[3]\)[t] + Da\ \(A[8]\)[t] + 
                c\ \(A[1]\)[t]\^2\ \(B[1]\)[t] - \(A[1]\)[
                    t]\ \((beta + d\ \(Y[1]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[1]\)[t] - b\ \(A[2]\)[t] - 
                4\ Da\ \(A[2]\)[t] + Da\ \(A[4]\)[t] + Da\ \(A[5]\)[t] + 
                Da\ \(A[8]\)[t] + 
                c\ \(A[2]\)[t]\^2\ \(B[2]\)[t] - \(A[2]\)[
                    t]\ \((beta + d\ \(Y[2]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[1]\)[t] - b\ \(A[3]\)[t] - 
                4\ Da\ \(A[3]\)[t] + Da\ \(A[6]\)[t] + Da\ \(A[7]\)[t] + 
                Da\ \(A[8]\)[t] + 
                c\ \(A[3]\)[t]\^2\ \(B[3]\)[t] - \(A[3]\)[
                    t]\ \((beta + d\ \(Y[3]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[2]\)[t] - b\ \(A[4]\)[t] - 
                4\ Da\ \(A[4]\)[t] + Da\ \(A[5]\)[t] + Da\ \(A[9]\)[t] + 
                Da\ \(A[10]\)[t] + 
                c\ \(A[4]\)[t]\^2\ \(B[4]\)[t] - \(A[4]\)[
                    t]\ \((beta + d\ \(Y[4]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[2]\)[t] + Da\ \(A[4]\)[t] - 
                b\ \(A[5]\)[t] - 5\ Da\ \(A[5]\)[t] + Da\ \(A[8]\)[t] + 
                Da\ \(A[9]\)[t] + Da\ \(A[14]\)[t] + 
                c\ \(A[5]\)[t]\^2\ \(B[5]\)[t] - \(A[5]\)[
                    t]\ \((beta + d\ \(Y[5]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[3]\)[t] - b\ \(A[6]\)[t] - 
                5\ Da\ \(A[6]\)[t] + Da\ \(A[7]\)[t] + Da\ \(A[11]\)[t] + 
                Da\ \(A[12]\)[t] + Da\ \(A[22]\)[t] + 
                c\ \(A[6]\)[t]\^2\ \(B[6]\)[t] - \(A[6]\)[
                    t]\ \((beta + d\ \(Y[6]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[3]\)[t] + Da\ \(A[6]\)[t] - 
                b\ \(A[7]\)[t] - 5\ Da\ \(A[7]\)[t] + Da\ \(A[8]\)[t] + 
                Da\ \(A[11]\)[t] + Da\ \(A[13]\)[t] + 
                c\ \(A[7]\)[t]\^2\ \(B[7]\)[t] - \(A[7]\)[
                    t]\ \((beta + d\ \(Y[7]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[8]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[1]\)[t] + Da\ \(A[2]\)[t] + 
                Da\ \(A[3]\)[t] + Da\ \(A[5]\)[t] + Da\ \(A[7]\)[t] - 
                b\ \(A[8]\)[t] - 8\ Da\ \(A[8]\)[t] + Da\ \(A[13]\)[t] + 
                Da\ \(A[14]\)[t] + Da\ \(A[17]\)[t] + 
                c\ \(A[8]\)[t]\^2\ \(B[8]\)[t] - \(A[8]\)[
                    t]\ \((beta + d\ \(Y[8]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[9]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[4]\)[t] + Da\ \(A[5]\)[t] - 
                b\ \(A[9]\)[t] - 6\ Da\ \(A[9]\)[t] + Da\ \(A[10]\)[t] + 
                Da\ \(A[14]\)[t] + Da\ \(A[18]\)[t] + Da\ \(A[27]\)[t] + 
                c\ \(A[9]\)[t]\^2\ \(B[9]\)[t] - \(A[9]\)[
                    t]\ \((beta + d\ \(Y[9]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[10]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[4]\)[t] + Da\ \(A[9]\)[t] - 
                b\ \(A[10]\)[t] - 5\ Da\ \(A[10]\)[t] + Da\ \(A[18]\)[t] + 
                Da\ \(A[19]\)[t] + Da\ \(A[28]\)[t] + 
                c\ \(A[10]\)[t]\^2\ \(B[10]\)[t] - \(A[10]\)[
                    t]\ \((beta + d\ \(Y[10]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[11]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[6]\)[t] + Da\ \(A[7]\)[t] - 
                b\ \(A[11]\)[t] - 7\ Da\ \(A[11]\)[t] + Da\ \(A[13]\)[t] + 
                Da\ \(A[22]\)[t] + Da\ \(A[24]\)[t] + Da\ \(A[25]\)[t] + 
                Da\ \(A[26]\)[t] + 
                c\ \(A[11]\)[t]\^2\ \(B[11]\)[t] - \(A[11]\)[
                    t]\ \((beta + d\ \(Y[11]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[12]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[6]\)[t] - b\ \(A[12]\)[t] - 
                4\ Da\ \(A[12]\)[t] + Da\ \(A[16]\)[t] + Da\ \(A[22]\)[t] + 
                Da\ \(A[30]\)[t] + 
                c\ \(A[12]\)[t]\^2\ \(B[12]\)[t] - \(A[12]\)[
                    t]\ \((beta + d\ \(Y[12]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[13]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[7]\)[t] + Da\ \(A[8]\)[t] + 
                Da\ \(A[11]\)[t] - b\ \(A[13]\)[t] - 6\ Da\ \(A[13]\)[t] + 
                Da\ \(A[17]\)[t] + Da\ \(A[26]\)[t] + Da\ \(A[39]\)[t] + 
                c\ \(A[13]\)[t]\^2\ \(B[13]\)[t] - \(A[13]\)[
                    t]\ \((beta + d\ \(Y[13]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[14]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[5]\)[t] + Da\ \(A[8]\)[t] + 
                Da\ \(A[9]\)[t] - b\ \(A[14]\)[t] - 7\ Da\ \(A[14]\)[t] + 
                Da\ \(A[17]\)[t] + Da\ \(A[23]\)[t] + Da\ \(A[27]\)[t] + 
                Da\ \(A[33]\)[t] + 
                c\ \(A[14]\)[t]\^2\ \(B[14]\)[t] - \(A[14]\)[
                    t]\ \((beta + d\ \(Y[14]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[15]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a - b\ \(A[15]\)[t] - 5\ Da\ \(A[15]\)[t] + 
                Da\ \(A[20]\)[t] + Da\ \(A[21]\)[t] + Da\ \(A[29]\)[t] + 
                Da\ \(A[34]\)[t] + Da\ \(A[35]\)[t] + 
                c\ \(A[15]\)[t]\^2\ \(B[15]\)[t] - \(A[15]\)[
                    t]\ \((beta + d\ \(Y[15]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[16]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[12]\)[t] - b\ \(A[16]\)[t] - 
                2\ Da\ \(A[16]\)[t] + Da\ \(A[30]\)[t] + 
                c\ \(A[16]\)[t]\^2\ \(B[16]\)[t] - \(A[16]\)[
                    t]\ \((beta + d\ \(Y[16]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[17]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[8]\)[t] + Da\ \(A[13]\)[t] + 
                Da\ \(A[14]\)[t] - b\ \(A[17]\)[t] - 7\ Da\ \(A[17]\)[t] + 
                Da\ \(A[23]\)[t] + Da\ \(A[39]\)[t] + Da\ \(A[53]\)[t] + 
                Da\ \(A[54]\)[t] + 
                c\ \(A[17]\)[t]\^2\ \(B[17]\)[t] - \(A[17]\)[
                    t]\ \((beta + d\ \(Y[17]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[18]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[9]\)[t] + Da\ \(A[10]\)[t] - 
                b\ \(A[18]\)[t] - 5\ Da\ \(A[18]\)[t] + Da\ \(A[27]\)[t] + 
                Da\ \(A[28]\)[t] + Da\ \(A[31]\)[t] + 
                c\ \(A[18]\)[t]\^2\ \(B[18]\)[t] - \(A[18]\)[
                    t]\ \((beta + d\ \(Y[18]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[19]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[10]\)[t] - b\ \(A[19]\)[t] - 
                6\ Da\ \(A[19]\)[t] + Da\ \(A[20]\)[t] + Da\ \(A[28]\)[t] + 
                Da\ \(A[32]\)[t] + Da\ \(A[38]\)[t] + Da\ \(A[40]\)[t] + 
                c\ \(A[19]\)[t]\^2\ \(B[19]\)[t] - \(A[19]\)[
                    t]\ \((beta + d\ \(Y[19]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[20]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[15]\)[t] + Da\ \(A[19]\)[t] - 
                b\ \(A[20]\)[t] - 4\ Da\ \(A[20]\)[t] + Da\ \(A[34]\)[t] + 
                Da\ \(A[40]\)[t] + 
                c\ \(A[20]\)[t]\^2\ \(B[20]\)[t] - \(A[20]\)[
                    t]\ \((beta + d\ \(Y[20]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[21]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[15]\)[t] - b\ \(A[21]\)[t] - 
                4\ Da\ \(A[21]\)[t] + Da\ \(A[29]\)[t] + Da\ \(A[36]\)[t] + 
                Da\ \(A[47]\)[t] + 
                c\ \(A[21]\)[t]\^2\ \(B[21]\)[t] - \(A[21]\)[
                    t]\ \((beta + d\ \(Y[21]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[22]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[6]\)[t] + Da\ \(A[11]\)[t] + 
                Da\ \(A[12]\)[t] - b\ \(A[22]\)[t] - 6\ Da\ \(A[22]\)[t] + 
                Da\ \(A[24]\)[t] + Da\ \(A[37]\)[t] + Da\ \(A[43]\)[t] + 
                c\ \(A[22]\)[t]\^2\ \(B[22]\)[t] - \(A[22]\)[
                    t]\ \((beta + d\ \(Y[22]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[23]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[14]\)[t] + Da\ \(A[17]\)[t] - 
                b\ \(A[23]\)[t] - 5\ Da\ \(A[23]\)[t] + Da\ \(A[33]\)[t] + 
                Da\ \(A[45]\)[t] + Da\ \(A[54]\)[t] + 
                c\ \(A[23]\)[t]\^2\ \(B[23]\)[t] - \(A[23]\)[
                    t]\ \((beta + d\ \(Y[23]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[24]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[11]\)[t] + Da\ \(A[22]\)[t] - 
                b\ \(A[24]\)[t] - 4\ Da\ \(A[24]\)[t] + Da\ \(A[25]\)[t] + 
                Da\ \(A[37]\)[t] + 
                c\ \(A[24]\)[t]\^2\ \(B[24]\)[t] - \(A[24]\)[
                    t]\ \((beta + d\ \(Y[24]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[25]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[11]\)[t] + Da\ \(A[24]\)[t] - 
                b\ \(A[25]\)[t] - 5\ Da\ \(A[25]\)[t] + Da\ \(A[26]\)[t] + 
                Da\ \(A[37]\)[t] + Da\ \(A[39]\)[t] + 
                c\ \(A[25]\)[t]\^2\ \(B[25]\)[t] - \(A[25]\)[
                    t]\ \((beta + d\ \(Y[25]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[26]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[11]\)[t] + Da\ \(A[13]\)[t] + 
                Da\ \(A[25]\)[t] - b\ \(A[26]\)[t] - 4\ Da\ \(A[26]\)[t] + 
                Da\ \(A[39]\)[t] + 
                c\ \(A[26]\)[t]\^2\ \(B[26]\)[t] - \(A[26]\)[
                    t]\ \((beta + d\ \(Y[26]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[27]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[9]\)[t] + Da\ \(A[14]\)[t] + 
                Da\ \(A[18]\)[t] - b\ \(A[27]\)[t] - 5\ Da\ \(A[27]\)[t] + 
                Da\ \(A[31]\)[t] + Da\ \(A[33]\)[t] + 
                c\ \(A[27]\)[t]\^2\ \(B[27]\)[t] - \(A[27]\)[
                    t]\ \((beta + d\ \(Y[27]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[28]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[10]\)[t] + Da\ \(A[18]\)[t] + 
                Da\ \(A[19]\)[t] - b\ \(A[28]\)[t] - 6\ Da\ \(A[28]\)[t] + 
                Da\ \(A[31]\)[t] + Da\ \(A[32]\)[t] + Da\ \(A[44]\)[t] + 
                c\ \(A[28]\)[t]\^2\ \(B[28]\)[t] - \(A[28]\)[
                    t]\ \((beta + d\ \(Y[28]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[29]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[15]\)[t] + Da\ \(A[21]\)[t] - 
                b\ \(A[29]\)[t] - 6\ Da\ \(A[29]\)[t] + Da\ \(A[35]\)[t] + 
                Da\ \(A[47]\)[t] + Da\ \(A[49]\)[t] + Da\ \(A[57]\)[t] + 
                c\ \(A[29]\)[t]\^2\ \(B[29]\)[t] - \(A[29]\)[
                    t]\ \((beta + d\ \(Y[29]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[30]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[12]\)[t] + Da\ \(A[16]\)[t] - 
                b\ \(A[30]\)[t] - 4\ Da\ \(A[30]\)[t] + Da\ \(A[43]\)[t] + 
                Da\ \(A[50]\)[t] + 
                c\ \(A[30]\)[t]\^2\ \(B[30]\)[t] - \(A[30]\)[
                    t]\ \((beta + d\ \(Y[30]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[31]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[18]\)[t] + Da\ \(A[27]\)[t] + 
                Da\ \(A[28]\)[t] - b\ \(A[31]\)[t] - 6\ Da\ \(A[31]\)[t] + 
                Da\ \(A[33]\)[t] + Da\ \(A[44]\)[t] + Da\ \(A[46]\)[t] + 
                c\ \(A[31]\)[t]\^2\ \(B[31]\)[t] - \(A[31]\)[
                    t]\ \((beta + d\ \(Y[31]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[32]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[19]\)[t] + Da\ \(A[28]\)[t] - 
                b\ \(A[32]\)[t] - 4\ Da\ \(A[32]\)[t] + Da\ \(A[38]\)[t] + 
                Da\ \(A[44]\)[t] + 
                c\ \(A[32]\)[t]\^2\ \(B[32]\)[t] - \(A[32]\)[
                    t]\ \((beta + d\ \(Y[32]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[33]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[14]\)[t] + Da\ \(A[23]\)[t] + 
                Da\ \(A[27]\)[t] + Da\ \(A[31]\)[t] - b\ \(A[33]\)[t] - 
                6\ Da\ \(A[33]\)[t] + Da\ \(A[45]\)[t] + Da\ \(A[46]\)[t] + 
                c\ \(A[33]\)[t]\^2\ \(B[33]\)[t] - \(A[33]\)[
                    t]\ \((beta + d\ \(Y[33]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[34]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[15]\)[t] + Da\ \(A[20]\)[t] - 
                b\ \(A[34]\)[t] - 7\ Da\ \(A[34]\)[t] + Da\ \(A[35]\)[t] + 
                Da\ \(A[40]\)[t] + Da\ \(A[41]\)[t] + Da\ \(A[51]\)[t] + 
                Da\ \(A[52]\)[t] + 
                c\ \(A[34]\)[t]\^2\ \(B[34]\)[t] - \(A[34]\)[
                    t]\ \((beta + d\ \(Y[34]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[35]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[15]\)[t] + Da\ \(A[29]\)[t] + 
                Da\ \(A[34]\)[t] - b\ \(A[35]\)[t] - 6\ Da\ \(A[35]\)[t] + 
                Da\ \(A[41]\)[t] + Da\ \(A[57]\)[t] + Da\ \(A[60]\)[t] + 
                c\ \(A[35]\)[t]\^2\ \(B[35]\)[t] - \(A[35]\)[
                    t]\ \((beta + d\ \(Y[35]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[36]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[21]\)[t] - b\ \(A[36]\)[t] - 
                4\ Da\ \(A[36]\)[t] + Da\ \(A[42]\)[t] + Da\ \(A[47]\)[t] + 
                Da\ \(A[48]\)[t] + 
                c\ \(A[36]\)[t]\^2\ \(B[36]\)[t] - \(A[36]\)[
                    t]\ \((beta + d\ \(Y[36]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[37]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[22]\)[t] + Da\ \(A[24]\)[t] + 
                Da\ \(A[25]\)[t] - b\ \(A[37]\)[t] - 6\ Da\ \(A[37]\)[t] + 
                Da\ \(A[39]\)[t] + Da\ \(A[43]\)[t] + Da\ \(A[59]\)[t] + 
                c\ \(A[37]\)[t]\^2\ \(B[37]\)[t] - \(A[37]\)[
                    t]\ \((beta + d\ \(Y[37]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[38]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[19]\)[t] + Da\ \(A[32]\)[t] - 
                b\ \(A[38]\)[t] - 6\ Da\ \(A[38]\)[t] + Da\ \(A[40]\)[t] + 
                Da\ \(A[44]\)[t] + Da\ \(A[56]\)[t] + Da\ \(A[67]\)[t] + 
                c\ \(A[38]\)[t]\^2\ \(B[38]\)[t] - \(A[38]\)[
                    t]\ \((beta + d\ \(Y[38]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[39]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[13]\)[t] + Da\ \(A[17]\)[t] + 
                Da\ \(A[25]\)[t] + Da\ \(A[26]\)[t] + Da\ \(A[37]\)[t] - 
                b\ \(A[39]\)[t] - 8\ Da\ \(A[39]\)[t] + Da\ \(A[53]\)[t] + 
                Da\ \(A[59]\)[t] + Da\ \(A[65]\)[t] + 
                c\ \(A[39]\)[t]\^2\ \(B[39]\)[t] - \(A[39]\)[
                    t]\ \((beta + d\ \(Y[39]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[40]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[19]\)[t] + Da\ \(A[20]\)[t] + 
                Da\ \(A[34]\)[t] + Da\ \(A[38]\)[t] - b\ \(A[40]\)[t] - 
                6\ Da\ \(A[40]\)[t] + Da\ \(A[51]\)[t] + Da\ \(A[56]\)[t] + 
                c\ \(A[40]\)[t]\^2\ \(B[40]\)[t] - \(A[40]\)[
                    t]\ \((beta + d\ \(Y[40]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[41]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[34]\)[t] + Da\ \(A[35]\)[t] - 
                b\ \(A[41]\)[t] - 4\ Da\ \(A[41]\)[t] + Da\ \(A[52]\)[t] + 
                Da\ \(A[60]\)[t] + 
                c\ \(A[41]\)[t]\^2\ \(B[41]\)[t] - \(A[41]\)[
                    t]\ \((beta + d\ \(Y[41]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[42]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[36]\)[t] - b\ \(A[42]\)[t] - 
                3\ Da\ \(A[42]\)[t] + Da\ \(A[48]\)[t] + Da\ \(A[58]\)[t] + 
                c\ \(A[42]\)[t]\^2\ \(B[42]\)[t] - \(A[42]\)[
                    t]\ \((beta + d\ \(Y[42]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[43]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[22]\)[t] + Da\ \(A[30]\)[t] + 
                Da\ \(A[37]\)[t] - b\ \(A[43]\)[t] - 7\ Da\ \(A[43]\)[t] + 
                Da\ \(A[50]\)[t] + Da\ \(A[59]\)[t] + Da\ \(A[61]\)[t] + 
                Da\ \(A[64]\)[t] + 
                c\ \(A[43]\)[t]\^2\ \(B[43]\)[t] - \(A[43]\)[
                    t]\ \((beta + d\ \(Y[43]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[44]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[28]\)[t] + Da\ \(A[31]\)[t] + 
                Da\ \(A[32]\)[t] + Da\ \(A[38]\)[t] - b\ \(A[44]\)[t] - 
                8\ Da\ \(A[44]\)[t] + Da\ \(A[46]\)[t] + Da\ \(A[55]\)[t] + 
                Da\ \(A[66]\)[t] + Da\ \(A[67]\)[t] + 
                c\ \(A[44]\)[t]\^2\ \(B[44]\)[t] - \(A[44]\)[
                    t]\ \((beta + d\ \(Y[44]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[45]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[23]\)[t] + Da\ \(A[33]\)[t] - 
                b\ \(A[45]\)[t] - 5\ Da\ \(A[45]\)[t] + Da\ \(A[46]\)[t] + 
                Da\ \(A[54]\)[t] + Da\ \(A[75]\)[t] + 
                c\ \(A[45]\)[t]\^2\ \(B[45]\)[t] - \(A[45]\)[
                    t]\ \((beta + d\ \(Y[45]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[46]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[31]\)[t] + Da\ \(A[33]\)[t] + 
                Da\ \(A[44]\)[t] + Da\ \(A[45]\)[t] - b\ \(A[46]\)[t] - 
                7\ Da\ \(A[46]\)[t] + Da\ \(A[55]\)[t] + Da\ \(A[68]\)[t] + 
                Da\ \(A[69]\)[t] + 
                c\ \(A[46]\)[t]\^2\ \(B[46]\)[t] - \(A[46]\)[
                    t]\ \((beta + d\ \(Y[46]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[47]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[21]\)[t] + Da\ \(A[29]\)[t] + 
                Da\ \(A[36]\)[t] - b\ \(A[47]\)[t] - 6\ Da\ \(A[47]\)[t] + 
                Da\ \(A[48]\)[t] + Da\ \(A[49]\)[t] + Da\ \(A[63]\)[t] + 
                c\ \(A[47]\)[t]\^2\ \(B[47]\)[t] - \(A[47]\)[
                    t]\ \((beta + d\ \(Y[47]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[48]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[36]\)[t] + Da\ \(A[42]\)[t] + 
                Da\ \(A[47]\)[t] - b\ \(A[48]\)[t] - 7\ Da\ \(A[48]\)[t] + 
                Da\ \(A[58]\)[t] + Da\ \(A[63]\)[t] + Da\ \(A[73]\)[t] + 
                Da\ \(A[77]\)[t] + 
                c\ \(A[48]\)[t]\^2\ \(B[48]\)[t] - \(A[48]\)[
                    t]\ \((beta + d\ \(Y[48]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[49]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[29]\)[t] + Da\ \(A[47]\)[t] - 
                b\ \(A[49]\)[t] - 5\ Da\ \(A[49]\)[t] + Da\ \(A[57]\)[t] + 
                Da\ \(A[63]\)[t] + Da\ \(A[76]\)[t] + 
                c\ \(A[49]\)[t]\^2\ \(B[49]\)[t] - \(A[49]\)[
                    t]\ \((beta + d\ \(Y[49]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[50]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[30]\)[t] + Da\ \(A[43]\)[t] - 
                b\ \(A[50]\)[t] - 4\ Da\ \(A[50]\)[t] + Da\ \(A[61]\)[t] + 
                Da\ \(A[82]\)[t] + 
                c\ \(A[50]\)[t]\^2\ \(B[50]\)[t] - \(A[50]\)[
                    t]\ \((beta + d\ \(Y[50]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[51]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[34]\)[t] + Da\ \(A[40]\)[t] - 
                b\ \(A[51]\)[t] - 7\ Da\ \(A[51]\)[t] + Da\ \(A[52]\)[t] + 
                Da\ \(A[56]\)[t] + Da\ \(A[71]\)[t] + Da\ \(A[72]\)[t] + 
                Da\ \(A[84]\)[t] + 
                c\ \(A[51]\)[t]\^2\ \(B[51]\)[t] - \(A[51]\)[
                    t]\ \((beta + d\ \(Y[51]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[52]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[34]\)[t] + Da\ \(A[41]\)[t] + 
                Da\ \(A[51]\)[t] - b\ \(A[52]\)[t] - 5\ Da\ \(A[52]\)[t] + 
                Da\ \(A[60]\)[t] + Da\ \(A[72]\)[t] + 
                c\ \(A[52]\)[t]\^2\ \(B[52]\)[t] - \(A[52]\)[
                    t]\ \((beta + d\ \(Y[52]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[53]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[17]\)[t] + Da\ \(A[39]\)[t] - 
                b\ \(A[53]\)[t] - 6\ Da\ \(A[53]\)[t] + Da\ \(A[54]\)[t] + 
                Da\ \(A[65]\)[t] + Da\ \(A[70]\)[t] + Da\ \(A[74]\)[t] + 
                c\ \(A[53]\)[t]\^2\ \(B[53]\)[t] - \(A[53]\)[
                    t]\ \((beta + d\ \(Y[53]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[54]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[17]\)[t] + Da\ \(A[23]\)[t] + 
                Da\ \(A[45]\)[t] + Da\ \(A[53]\)[t] - b\ \(A[54]\)[t] - 
                6\ Da\ \(A[54]\)[t] + Da\ \(A[74]\)[t] + Da\ \(A[75]\)[t] + 
                c\ \(A[54]\)[t]\^2\ \(B[54]\)[t] - \(A[54]\)[
                    t]\ \((beta + d\ \(Y[54]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[55]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[44]\)[t] + Da\ \(A[46]\)[t] - 
                b\ \(A[55]\)[t] - 5\ Da\ \(A[55]\)[t] + Da\ \(A[66]\)[t] + 
                Da\ \(A[69]\)[t] + Da\ \(A[86]\)[t] + 
                c\ \(A[55]\)[t]\^2\ \(B[55]\)[t] - \(A[55]\)[
                    t]\ \((beta + d\ \(Y[55]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[56]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[38]\)[t] + Da\ \(A[40]\)[t] + 
                Da\ \(A[51]\)[t] - b\ \(A[56]\)[t] - 6\ Da\ \(A[56]\)[t] + 
                Da\ \(A[62]\)[t] + Da\ \(A[67]\)[t] + Da\ \(A[71]\)[t] + 
                c\ \(A[56]\)[t]\^2\ \(B[56]\)[t] - \(A[56]\)[
                    t]\ \((beta + d\ \(Y[56]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[57]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[29]\)[t] + Da\ \(A[35]\)[t] + 
                Da\ \(A[49]\)[t] - b\ \(A[57]\)[t] - 7\ Da\ \(A[57]\)[t] + 
                Da\ \(A[60]\)[t] + Da\ \(A[76]\)[t] + Da\ \(A[81]\)[t] + 
                Da\ \(A[85]\)[t] + 
                c\ \(A[57]\)[t]\^2\ \(B[57]\)[t] - \(A[57]\)[
                    t]\ \((beta + d\ \(Y[57]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[58]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[42]\)[t] + Da\ \(A[48]\)[t] - 
                b\ \(A[58]\)[t] - 4\ Da\ \(A[58]\)[t] + Da\ \(A[77]\)[t] + 
                Da\ \(A[78]\)[t] + 
                c\ \(A[58]\)[t]\^2\ \(B[58]\)[t] - \(A[58]\)[
                    t]\ \((beta + d\ \(Y[58]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[59]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[37]\)[t] + Da\ \(A[39]\)[t] + 
                Da\ \(A[43]\)[t] - b\ \(A[59]\)[t] - 7\ Da\ \(A[59]\)[t] + 
                Da\ \(A[64]\)[t] + Da\ \(A[65]\)[t] + Da\ \(A[83]\)[t] + 
                Da\ \(A[87]\)[t] + 
                c\ \(A[59]\)[t]\^2\ \(B[59]\)[t] - \(A[59]\)[
                    t]\ \((beta + d\ \(Y[59]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[60]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[35]\)[t] + Da\ \(A[41]\)[t] + 
                Da\ \(A[52]\)[t] + Da\ \(A[57]\)[t] - b\ \(A[60]\)[t] - 
                7\ Da\ \(A[60]\)[t] + Da\ \(A[72]\)[t] + Da\ \(A[80]\)[t] + 
                Da\ \(A[85]\)[t] + 
                c\ \(A[60]\)[t]\^2\ \(B[60]\)[t] - \(A[60]\)[
                    t]\ \((beta + d\ \(Y[60]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[61]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[43]\)[t] + Da\ \(A[50]\)[t] - 
                b\ \(A[61]\)[t] - 6\ Da\ \(A[61]\)[t] + Da\ \(A[64]\)[t] + 
                Da\ \(A[82]\)[t] + Da\ \(A[89]\)[t] + Da\ \(A[96]\)[t] + 
                c\ \(A[61]\)[t]\^2\ \(B[61]\)[t] - \(A[61]\)[
                    t]\ \((beta + d\ \(Y[61]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[62]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[56]\)[t] - b\ \(A[62]\)[t] - 
                4\ Da\ \(A[62]\)[t] + Da\ \(A[67]\)[t] + Da\ \(A[71]\)[t] + 
                Da\ \(A[79]\)[t] + 
                c\ \(A[62]\)[t]\^2\ \(B[62]\)[t] - \(A[62]\)[
                    t]\ \((beta + d\ \(Y[62]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[63]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[47]\)[t] + Da\ \(A[48]\)[t] + 
                Da\ \(A[49]\)[t] - b\ \(A[63]\)[t] - 5\ Da\ \(A[63]\)[t] + 
                Da\ \(A[73]\)[t] + Da\ \(A[76]\)[t] + 
                c\ \(A[63]\)[t]\^2\ \(B[63]\)[t] - \(A[63]\)[
                    t]\ \((beta + d\ \(Y[63]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[64]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[43]\)[t] + Da\ \(A[59]\)[t] + 
                Da\ \(A[61]\)[t] - b\ \(A[64]\)[t] - 5\ Da\ \(A[64]\)[t] + 
                Da\ \(A[83]\)[t] + Da\ \(A[96]\)[t] + 
                c\ \(A[64]\)[t]\^2\ \(B[64]\)[t] - \(A[64]\)[
                    t]\ \((beta + d\ \(Y[64]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[65]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[39]\)[t] + Da\ \(A[53]\)[t] + 
                Da\ \(A[59]\)[t] - b\ \(A[65]\)[t] - 7\ Da\ \(A[65]\)[t] + 
                Da\ \(A[70]\)[t] + Da\ \(A[87]\)[t] + Da\ \(A[97]\)[t] + 
                Da\ \(A[100]\)[t] + 
                c\ \(A[65]\)[t]\^2\ \(B[65]\)[t] - \(A[65]\)[
                    t]\ \((beta + d\ \(Y[65]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[66]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[44]\)[t] + Da\ \(A[55]\)[t] - 
                b\ \(A[66]\)[t] - 6\ Da\ \(A[66]\)[t] + Da\ \(A[67]\)[t] + 
                Da\ \(A[79]\)[t] + Da\ \(A[86]\)[t] + Da\ \(A[91]\)[t] + 
                c\ \(A[66]\)[t]\^2\ \(B[66]\)[t] - \(A[66]\)[
                    t]\ \((beta + d\ \(Y[66]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[67]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[38]\)[t] + Da\ \(A[44]\)[t] + 
                Da\ \(A[56]\)[t] + Da\ \(A[62]\)[t] + Da\ \(A[66]\)[t] - 
                b\ \(A[67]\)[t] - 6\ Da\ \(A[67]\)[t] + Da\ \(A[79]\)[t] + 
                c\ \(A[67]\)[t]\^2\ \(B[67]\)[t] - \(A[67]\)[
                    t]\ \((beta + d\ \(Y[67]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[68]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[46]\)[t] - b\ \(A[68]\)[t] - 
                4\ Da\ \(A[68]\)[t] + Da\ \(A[69]\)[t] + Da\ \(A[75]\)[t] + 
                Da\ \(A[94]\)[t] + 
                c\ \(A[68]\)[t]\^2\ \(B[68]\)[t] - \(A[68]\)[
                    t]\ \((beta + d\ \(Y[68]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[69]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[46]\)[t] + Da\ \(A[55]\)[t] + 
                Da\ \(A[68]\)[t] - b\ \(A[69]\)[t] - 6\ Da\ \(A[69]\)[t] + 
                Da\ \(A[86]\)[t] + Da\ \(A[94]\)[t] + Da\ \(A[98]\)[t] + 
                c\ \(A[69]\)[t]\^2\ \(B[69]\)[t] - \(A[69]\)[
                    t]\ \((beta + d\ \(Y[69]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[70]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[53]\)[t] + Da\ \(A[65]\)[t] - 
                b\ \(A[70]\)[t] - 5\ Da\ \(A[70]\)[t] + Da\ \(A[74]\)[t] + 
                Da\ \(A[93]\)[t] + Da\ \(A[97]\)[t] + 
                c\ \(A[70]\)[t]\^2\ \(B[70]\)[t] - \(A[70]\)[
                    t]\ \((beta + d\ \(Y[70]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[71]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[51]\)[t] + Da\ \(A[56]\)[t] + 
                Da\ \(A[62]\)[t] - b\ \(A[71]\)[t] - 5\ Da\ \(A[71]\)[t] + 
                Da\ \(A[79]\)[t] + Da\ \(A[84]\)[t] + 
                c\ \(A[71]\)[t]\^2\ \(B[71]\)[t] - \(A[71]\)[
                    t]\ \((beta + d\ \(Y[71]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[72]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[51]\)[t] + Da\ \(A[52]\)[t] + 
                Da\ \(A[60]\)[t] - b\ \(A[72]\)[t] - 6\ Da\ \(A[72]\)[t] + 
                Da\ \(A[80]\)[t] + Da\ \(A[84]\)[t] + Da\ \(A[102]\)[t] + 
                c\ \(A[72]\)[t]\^2\ \(B[72]\)[t] - \(A[72]\)[
                    t]\ \((beta + d\ \(Y[72]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[73]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[48]\)[t] + Da\ \(A[63]\)[t] - 
                b\ \(A[73]\)[t] - 5\ Da\ \(A[73]\)[t] + Da\ \(A[76]\)[t] + 
                Da\ \(A[77]\)[t] + Da\ \(A[92]\)[t] + 
                c\ \(A[73]\)[t]\^2\ \(B[73]\)[t] - \(A[73]\)[
                    t]\ \((beta + d\ \(Y[73]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[74]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[53]\)[t] + Da\ \(A[54]\)[t] + 
                Da\ \(A[70]\)[t] - b\ \(A[74]\)[t] - 6\ Da\ \(A[74]\)[t] + 
                Da\ \(A[75]\)[t] + Da\ \(A[90]\)[t] + Da\ \(A[93]\)[t] + 
                c\ \(A[74]\)[t]\^2\ \(B[74]\)[t] - \(A[74]\)[
                    t]\ \((beta + d\ \(Y[74]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[75]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[45]\)[t] + Da\ \(A[54]\)[t] + 
                Da\ \(A[68]\)[t] + Da\ \(A[74]\)[t] - b\ \(A[75]\)[t] - 
                6\ Da\ \(A[75]\)[t] + Da\ \(A[90]\)[t] + Da\ \(A[94]\)[t] + 
                c\ \(A[75]\)[t]\^2\ \(B[75]\)[t] - \(A[75]\)[
                    t]\ \((beta + d\ \(Y[75]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[76]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[49]\)[t] + Da\ \(A[57]\)[t] + 
                Da\ \(A[63]\)[t] + Da\ \(A[73]\)[t] - b\ \(A[76]\)[t] - 
                7\ Da\ \(A[76]\)[t] + Da\ \(A[81]\)[t] + Da\ \(A[92]\)[t] + 
                Da\ \(A[95]\)[t] + 
                c\ \(A[76]\)[t]\^2\ \(B[76]\)[t] - \(A[76]\)[
                    t]\ \((beta + d\ \(Y[76]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[77]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[48]\)[t] + Da\ \(A[58]\)[t] + 
                Da\ \(A[73]\)[t] - b\ \(A[77]\)[t] - 7\ Da\ \(A[77]\)[t] + 
                Da\ \(A[78]\)[t] + Da\ \(A[92]\)[t] + Da\ \(A[103]\)[t] + 
                Da\ \(A[107]\)[t] + 
                c\ \(A[77]\)[t]\^2\ \(B[77]\)[t] - \(A[77]\)[
                    t]\ \((beta + d\ \(Y[77]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[78]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[58]\)[t] + Da\ \(A[77]\)[t] - 
                b\ \(A[78]\)[t] - 3\ Da\ \(A[78]\)[t] + Da\ \(A[107]\)[t] + 
                c\ \(A[78]\)[t]\^2\ \(B[78]\)[t] - \(A[78]\)[
                    t]\ \((beta + d\ \(Y[78]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[79]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[62]\)[t] + Da\ \(A[66]\)[t] + 
                Da\ \(A[67]\)[t] + Da\ \(A[71]\)[t] - b\ \(A[79]\)[t] - 
                8\ Da\ \(A[79]\)[t] + Da\ \(A[84]\)[t] + Da\ \(A[91]\)[t] + 
                Da\ \(A[99]\)[t] + Da\ \(A[101]\)[t] + 
                c\ \(A[79]\)[t]\^2\ \(B[79]\)[t] - \(A[79]\)[
                    t]\ \((beta + d\ \(Y[79]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[80]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[60]\)[t] + Da\ \(A[72]\)[t] - 
                b\ \(A[80]\)[t] - 6\ Da\ \(A[80]\)[t] + Da\ \(A[85]\)[t] + 
                Da\ \(A[88]\)[t] + Da\ \(A[102]\)[t] + Da\ \(A[110]\)[t] + 
                c\ \(A[80]\)[t]\^2\ \(B[80]\)[t] - \(A[80]\)[
                    t]\ \((beta + d\ \(Y[80]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[81]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[57]\)[t] + Da\ \(A[76]\)[t] - 
                b\ \(A[81]\)[t] - 4\ Da\ \(A[81]\)[t] + Da\ \(A[85]\)[t] + 
                Da\ \(A[95]\)[t] + 
                c\ \(A[81]\)[t]\^2\ \(B[81]\)[t] - \(A[81]\)[
                    t]\ \((beta + d\ \(Y[81]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[82]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[50]\)[t] + Da\ \(A[61]\)[t] - 
                b\ \(A[82]\)[t] - 4\ Da\ \(A[82]\)[t] + Da\ \(A[89]\)[t] + 
                Da\ \(A[113]\)[t] + 
                c\ \(A[82]\)[t]\^2\ \(B[82]\)[t] - \(A[82]\)[
                    t]\ \((beta + d\ \(Y[82]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[83]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[59]\)[t] + Da\ \(A[64]\)[t] - 
                b\ \(A[83]\)[t] - 6\ Da\ \(A[83]\)[t] + Da\ \(A[87]\)[t] + 
                Da\ \(A[96]\)[t] + Da\ \(A[100]\)[t] + Da\ \(A[123]\)[t] + 
                c\ \(A[83]\)[t]\^2\ \(B[83]\)[t] - \(A[83]\)[
                    t]\ \((beta + d\ \(Y[83]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[84]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[51]\)[t] + Da\ \(A[71]\)[t] + 
                Da\ \(A[72]\)[t] + Da\ \(A[79]\)[t] - b\ \(A[84]\)[t] - 
                7\ Da\ \(A[84]\)[t] + Da\ \(A[101]\)[t] + Da\ \(A[102]\)[t] + 
                Da\ \(A[109]\)[t] + 
                c\ \(A[84]\)[t]\^2\ \(B[84]\)[t] - \(A[84]\)[
                    t]\ \((beta + d\ \(Y[84]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[85]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[57]\)[t] + Da\ \(A[60]\)[t] + 
                Da\ \(A[80]\)[t] + Da\ \(A[81]\)[t] - b\ \(A[85]\)[t] - 
                6\ Da\ \(A[85]\)[t] + Da\ \(A[88]\)[t] + Da\ \(A[95]\)[t] + 
                c\ \(A[85]\)[t]\^2\ \(B[85]\)[t] - \(A[85]\)[
                    t]\ \((beta + d\ \(Y[85]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[86]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[55]\)[t] + Da\ \(A[66]\)[t] + 
                Da\ \(A[69]\)[t] - b\ \(A[86]\)[t] - 6\ Da\ \(A[86]\)[t] + 
                Da\ \(A[91]\)[t] + Da\ \(A[98]\)[t] + Da\ \(A[106]\)[t] + 
                c\ \(A[86]\)[t]\^2\ \(B[86]\)[t] - \(A[86]\)[
                    t]\ \((beta + d\ \(Y[86]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[87]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[59]\)[t] + Da\ \(A[65]\)[t] + 
                Da\ \(A[83]\)[t] - b\ \(A[87]\)[t] - 4\ Da\ \(A[87]\)[t] + 
                Da\ \(A[100]\)[t] + 
                c\ \(A[87]\)[t]\^2\ \(B[87]\)[t] - \(A[87]\)[
                    t]\ \((beta + d\ \(Y[87]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[88]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[80]\)[t] + Da\ \(A[85]\)[t] - 
                b\ \(A[88]\)[t] - 6\ Da\ \(A[88]\)[t] + Da\ \(A[95]\)[t] + 
                Da\ \(A[110]\)[t] + Da\ \(A[112]\)[t] + Da\ \(A[120]\)[t] + 
                c\ \(A[88]\)[t]\^2\ \(B[88]\)[t] - \(A[88]\)[
                    t]\ \((beta + d\ \(Y[88]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[89]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[61]\)[t] + Da\ \(A[82]\)[t] - 
                b\ \(A[89]\)[t] - 4\ Da\ \(A[89]\)[t] + Da\ \(A[96]\)[t] + 
                Da\ \(A[113]\)[t] + 
                c\ \(A[89]\)[t]\^2\ \(B[89]\)[t] - \(A[89]\)[
                    t]\ \((beta + d\ \(Y[89]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[90]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[74]\)[t] + Da\ \(A[75]\)[t] - 
                b\ \(A[90]\)[t] - 6\ Da\ \(A[90]\)[t] + Da\ \(A[93]\)[t] + 
                Da\ \(A[105]\)[t] + Da\ \(A[108]\)[t] + Da\ \(A[116]\)[t] + 
                c\ \(A[90]\)[t]\^2\ \(B[90]\)[t] - \(A[90]\)[
                    t]\ \((beta + d\ \(Y[90]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[91]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[66]\)[t] + Da\ \(A[79]\)[t] + 
                Da\ \(A[86]\)[t] - b\ \(A[91]\)[t] - 6\ Da\ \(A[91]\)[t] + 
                Da\ \(A[99]\)[t] + Da\ \(A[106]\)[t] + Da\ \(A[118]\)[t] + 
                c\ \(A[91]\)[t]\^2\ \(B[91]\)[t] - \(A[91]\)[
                    t]\ \((beta + d\ \(Y[91]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[92]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[73]\)[t] + Da\ \(A[76]\)[t] + 
                Da\ \(A[77]\)[t] - b\ \(A[92]\)[t] - 6\ Da\ \(A[92]\)[t] + 
                Da\ \(A[95]\)[t] + Da\ \(A[103]\)[t] + Da\ \(A[111]\)[t] + 
                c\ \(A[92]\)[t]\^2\ \(B[92]\)[t] - \(A[92]\)[
                    t]\ \((beta + d\ \(Y[92]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[93]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[70]\)[t] + Da\ \(A[74]\)[t] + 
                Da\ \(A[90]\)[t] - b\ \(A[93]\)[t] - 7\ Da\ \(A[93]\)[t] + 
                Da\ \(A[97]\)[t] + Da\ \(A[104]\)[t] + Da\ \(A[105]\)[t] + 
                Da\ \(A[115]\)[t] + 
                c\ \(A[93]\)[t]\^2\ \(B[93]\)[t] - \(A[93]\)[
                    t]\ \((beta + d\ \(Y[93]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[94]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[68]\)[t] + Da\ \(A[69]\)[t] + 
                Da\ \(A[75]\)[t] - b\ \(A[94]\)[t] - 6\ Da\ \(A[94]\)[t] + 
                Da\ \(A[98]\)[t] + Da\ \(A[108]\)[t] + Da\ \(A[117]\)[t] + 
                c\ \(A[94]\)[t]\^2\ \(B[94]\)[t] - \(A[94]\)[
                    t]\ \((beta + d\ \(Y[94]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[95]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[76]\)[t] + Da\ \(A[81]\)[t] + 
                Da\ \(A[85]\)[t] + Da\ \(A[88]\)[t] + Da\ \(A[92]\)[t] - 
                b\ \(A[95]\)[t] - 8\ Da\ \(A[95]\)[t] + Da\ \(A[111]\)[t] + 
                Da\ \(A[120]\)[t] + Da\ \(A[121]\)[t] + 
                c\ \(A[95]\)[t]\^2\ \(B[95]\)[t] - \(A[95]\)[
                    t]\ \((beta + d\ \(Y[95]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[96]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[61]\)[t] + Da\ \(A[64]\)[t] + 
                Da\ \(A[83]\)[t] + Da\ \(A[89]\)[t] - b\ \(A[96]\)[t] - 
                7\ Da\ \(A[96]\)[t] + Da\ \(A[113]\)[t] + Da\ \(A[123]\)[t] + 
                Da\ \(A[127]\)[t] + 
                c\ \(A[96]\)[t]\^2\ \(B[96]\)[t] - \(A[96]\)[
                    t]\ \((beta + d\ \(Y[96]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[97]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[65]\)[t] + Da\ \(A[70]\)[t] + 
                Da\ \(A[93]\)[t] - b\ \(A[97]\)[t] - 6\ Da\ \(A[97]\)[t] + 
                Da\ \(A[100]\)[t] + Da\ \(A[104]\)[t] + Da\ \(A[124]\)[t] + 
                c\ \(A[97]\)[t]\^2\ \(B[97]\)[t] - \(A[97]\)[
                    t]\ \((beta + d\ \(Y[97]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[98]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[69]\)[t] + Da\ \(A[86]\)[t] + 
                Da\ \(A[94]\)[t] - b\ \(A[98]\)[t] - 6\ Da\ \(A[98]\)[t] + 
                Da\ \(A[106]\)[t] + Da\ \(A[117]\)[t] + Da\ \(A[125]\)[t] + 
                c\ \(A[98]\)[t]\^2\ \(B[98]\)[t] - \(A[98]\)[
                    t]\ \((beta + d\ \(Y[98]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[99]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[79]\)[t] + Da\ \(A[91]\)[t] - 
                b\ \(A[99]\)[t] - 5\ Da\ \(A[99]\)[t] + Da\ \(A[101]\)[t] + 
                Da\ \(A[118]\)[t] + Da\ \(A[119]\)[t] + 
                c\ \(A[99]\)[t]\^2\ \(B[99]\)[t] - \(A[99]\)[
                    t]\ \((beta + d\ \(Y[99]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[100]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[65]\)[t] + Da\ \(A[83]\)[t] + 
                Da\ \(A[87]\)[t] + Da\ \(A[97]\)[t] - b\ \(A[100]\)[t] - 
                8\ Da\ \(A[100]\)[t] + Da\ \(A[114]\)[t] + 
                Da\ \(A[123]\)[t] + Da\ \(A[124]\)[t] + Da\ \(A[132]\)[t] + 
                c\ \(A[100]\)[t]\^2\ \(B[100]\)[t] - \(A[100]\)[
                    t]\ \((beta + d\ \(Y[100]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[101]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[79]\)[t] + Da\ \(A[84]\)[t] + 
                Da\ \(A[99]\)[t] - b\ \(A[101]\)[t] - 6\ Da\ \(A[101]\)[t] + 
                Da\ \(A[109]\)[t] + Da\ \(A[119]\)[t] + Da\ \(A[131]\)[t] + 
                c\ \(A[101]\)[t]\^2\ \(B[101]\)[t] - \(A[101]\)[
                    t]\ \((beta + d\ \(Y[101]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[102]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[72]\)[t] + Da\ \(A[80]\)[t] + 
                Da\ \(A[84]\)[t] - b\ \(A[102]\)[t] - 6\ Da\ \(A[102]\)[t] + 
                Da\ \(A[109]\)[t] + Da\ \(A[110]\)[t] + Da\ \(A[129]\)[t] + 
                c\ \(A[102]\)[t]\^2\ \(B[102]\)[t] - \(A[102]\)[
                    t]\ \((beta + d\ \(Y[102]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[103]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[77]\)[t] + Da\ \(A[92]\)[t] - 
                b\ \(A[103]\)[t] - 6\ Da\ \(A[103]\)[t] + Da\ \(A[107]\)[t] + 
                Da\ \(A[111]\)[t] + Da\ \(A[136]\)[t] + Da\ \(A[137]\)[t] + 
                c\ \(A[103]\)[t]\^2\ \(B[103]\)[t] - \(A[103]\)[
                    t]\ \((beta + d\ \(Y[103]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[104]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[93]\)[t] + Da\ \(A[97]\)[t] - 
                b\ \(A[104]\)[t] - 6\ Da\ \(A[104]\)[t] + Da\ \(A[115]\)[t] + 
                Da\ \(A[124]\)[t] + Da\ \(A[128]\)[t] + Da\ \(A[130]\)[t] + 
                c\ \(A[104]\)[t]\^2\ \(B[104]\)[t] - \(A[104]\)[
                    t]\ \((beta + d\ \(Y[104]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[105]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[90]\)[t] + Da\ \(A[93]\)[t] - 
                b\ \(A[105]\)[t] - 4\ Da\ \(A[105]\)[t] + Da\ \(A[115]\)[t] + 
                Da\ \(A[116]\)[t] + 
                c\ \(A[105]\)[t]\^2\ \(B[105]\)[t] - \(A[105]\)[
                    t]\ \((beta + d\ \(Y[105]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[106]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[86]\)[t] + Da\ \(A[91]\)[t] + 
                Da\ \(A[98]\)[t] - b\ \(A[106]\)[t] - 5\ Da\ \(A[106]\)[t] + 
                Da\ \(A[118]\)[t] + Da\ \(A[125]\)[t] + 
                c\ \(A[106]\)[t]\^2\ \(B[106]\)[t] - \(A[106]\)[
                    t]\ \((beta + d\ \(Y[106]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[107]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[77]\)[t] + Da\ \(A[78]\)[t] + 
                Da\ \(A[103]\)[t] - b\ \(A[107]\)[t] - 5\ Da\ \(A[107]\)[t] + 
                Da\ \(A[122]\)[t] + Da\ \(A[137]\)[t] + 
                c\ \(A[107]\)[t]\^2\ \(B[107]\)[t] - \(A[107]\)[
                    t]\ \((beta + d\ \(Y[107]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[108]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[90]\)[t] + Da\ \(A[94]\)[t] - 
                b\ \(A[108]\)[t] - 4\ Da\ \(A[108]\)[t] + Da\ \(A[116]\)[t] + 
                Da\ \(A[117]\)[t] + 
                c\ \(A[108]\)[t]\^2\ \(B[108]\)[t] - \(A[108]\)[
                    t]\ \((beta + d\ \(Y[108]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[109]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[84]\)[t] + Da\ \(A[101]\)[t] + 
                Da\ \(A[102]\)[t] - b\ \(A[109]\)[t] - 5\ Da\ \(A[109]\)[t] + 
                Da\ \(A[129]\)[t] + Da\ \(A[131]\)[t] + 
                c\ \(A[109]\)[t]\^2\ \(B[109]\)[t] - \(A[109]\)[
                    t]\ \((beta + d\ \(Y[109]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[110]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[80]\)[t] + Da\ \(A[88]\)[t] + 
                Da\ \(A[102]\)[t] - b\ \(A[110]\)[t] - 5\ Da\ \(A[110]\)[t] + 
                Da\ \(A[112]\)[t] + Da\ \(A[129]\)[t] + 
                c\ \(A[110]\)[t]\^2\ \(B[110]\)[t] - \(A[110]\)[
                    t]\ \((beta + d\ \(Y[110]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[111]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[92]\)[t] + Da\ \(A[95]\)[t] + 
                Da\ \(A[103]\)[t] - b\ \(A[111]\)[t] - 5\ Da\ \(A[111]\)[t] + 
                Da\ \(A[121]\)[t] + Da\ \(A[136]\)[t] + 
                c\ \(A[111]\)[t]\^2\ \(B[111]\)[t] - \(A[111]\)[
                    t]\ \((beta + d\ \(Y[111]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[112]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[88]\)[t] + Da\ \(A[110]\)[t] - 
                b\ \(A[112]\)[t] - 6\ Da\ \(A[112]\)[t] + Da\ \(A[120]\)[t] + 
                Da\ \(A[129]\)[t] + Da\ \(A[144]\)[t] + Da\ \(A[149]\)[t] + 
                c\ \(A[112]\)[t]\^2\ \(B[112]\)[t] - \(A[112]\)[
                    t]\ \((beta + d\ \(Y[112]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[113]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[82]\)[t] + Da\ \(A[89]\)[t] + 
                Da\ \(A[96]\)[t] - b\ \(A[113]\)[t] - 5\ Da\ \(A[113]\)[t] + 
                Da\ \(A[127]\)[t] + Da\ \(A[134]\)[t] + 
                c\ \(A[113]\)[t]\^2\ \(B[113]\)[t] - \(A[113]\)[
                    t]\ \((beta + d\ \(Y[113]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[114]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[100]\)[t] - b\ \(A[114]\)[t] - 
                4\ Da\ \(A[114]\)[t] + Da\ \(A[124]\)[t] + 
                Da\ \(A[132]\)[t] + Da\ \(A[145]\)[t] + 
                c\ \(A[114]\)[t]\^2\ \(B[114]\)[t] - \(A[114]\)[
                    t]\ \((beta + d\ \(Y[114]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[115]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[93]\)[t] + Da\ \(A[104]\)[t] + 
                Da\ \(A[105]\)[t] - b\ \(A[115]\)[t] - 6\ Da\ \(A[115]\)[t] + 
                Da\ \(A[116]\)[t] + Da\ \(A[130]\)[t] + Da\ \(A[142]\)[t] + 
                c\ \(A[115]\)[t]\^2\ \(B[115]\)[t] - \(A[115]\)[
                    t]\ \((beta + d\ \(Y[115]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[116]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[90]\)[t] + Da\ \(A[105]\)[t] + 
                Da\ \(A[108]\)[t] + Da\ \(A[115]\)[t] - b\ \(A[116]\)[t] - 
                6\ Da\ \(A[116]\)[t] + Da\ \(A[117]\)[t] + 
                Da\ \(A[143]\)[t] + 
                c\ \(A[116]\)[t]\^2\ \(B[116]\)[t] - \(A[116]\)[
                    t]\ \((beta + d\ \(Y[116]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[117]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[94]\)[t] + Da\ \(A[98]\)[t] + 
                Da\ \(A[108]\)[t] + Da\ \(A[116]\)[t] - b\ \(A[117]\)[t] - 
                7\ Da\ \(A[117]\)[t] + Da\ \(A[125]\)[t] + 
                Da\ \(A[143]\)[t] + Da\ \(A[154]\)[t] + 
                c\ \(A[117]\)[t]\^2\ \(B[117]\)[t] - \(A[117]\)[
                    t]\ \((beta + d\ \(Y[117]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[118]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[91]\)[t] + Da\ \(A[99]\)[t] + 
                Da\ \(A[106]\)[t] - b\ \(A[118]\)[t] - 6\ Da\ \(A[118]\)[t] + 
                Da\ \(A[119]\)[t] + Da\ \(A[125]\)[t] + Da\ \(A[135]\)[t] + 
                c\ \(A[118]\)[t]\^2\ \(B[118]\)[t] - \(A[118]\)[
                    t]\ \((beta + d\ \(Y[118]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[119]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[99]\)[t] + Da\ \(A[101]\)[t] + 
                Da\ \(A[118]\)[t] - b\ \(A[119]\)[t] - 5\ Da\ \(A[119]\)[t] + 
                Da\ \(A[131]\)[t] + Da\ \(A[135]\)[t] + 
                c\ \(A[119]\)[t]\^2\ \(B[119]\)[t] - \(A[119]\)[
                    t]\ \((beta + d\ \(Y[119]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[120]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[88]\)[t] + Da\ \(A[95]\)[t] + 
                Da\ \(A[112]\)[t] - b\ \(A[120]\)[t] - 6\ Da\ \(A[120]\)[t] + 
                Da\ \(A[121]\)[t] + Da\ \(A[126]\)[t] + Da\ \(A[149]\)[t] + 
                c\ \(A[120]\)[t]\^2\ \(B[120]\)[t] - \(A[120]\)[
                    t]\ \((beta + d\ \(Y[120]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[121]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[95]\)[t] + Da\ \(A[111]\)[t] + 
                Da\ \(A[120]\)[t] - b\ \(A[121]\)[t] - 7\ Da\ \(A[121]\)[t] + 
                Da\ \(A[126]\)[t] + Da\ \(A[136]\)[t] + Da\ \(A[138]\)[t] + 
                Da\ \(A[139]\)[t] + 
                c\ \(A[121]\)[t]\^2\ \(B[121]\)[t] - \(A[121]\)[
                    t]\ \((beta + d\ \(Y[121]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[122]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[107]\)[t] - b\ \(A[122]\)[t] - 
                3\ Da\ \(A[122]\)[t] + Da\ \(A[137]\)[t] + 
                Da\ \(A[150]\)[t] + 
                c\ \(A[122]\)[t]\^2\ \(B[122]\)[t] - \(A[122]\)[
                    t]\ \((beta + d\ \(Y[122]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[123]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[83]\)[t] + Da\ \(A[96]\)[t] + 
                Da\ \(A[100]\)[t] - b\ \(A[123]\)[t] - 6\ Da\ \(A[123]\)[t] + 
                Da\ \(A[127]\)[t] + Da\ \(A[132]\)[t] + Da\ \(A[141]\)[t] + 
                c\ \(A[123]\)[t]\^2\ \(B[123]\)[t] - \(A[123]\)[
                    t]\ \((beta + d\ \(Y[123]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[124]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[97]\)[t] + Da\ \(A[100]\)[t] + 
                Da\ \(A[104]\)[t] + Da\ \(A[114]\)[t] - b\ \(A[124]\)[t] - 
                7\ Da\ \(A[124]\)[t] + Da\ \(A[128]\)[t] + 
                Da\ \(A[140]\)[t] + Da\ \(A[145]\)[t] + 
                c\ \(A[124]\)[t]\^2\ \(B[124]\)[t] - \(A[124]\)[
                    t]\ \((beta + d\ \(Y[124]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[125]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[98]\)[t] + Da\ \(A[106]\)[t] + 
                Da\ \(A[117]\)[t] + Da\ \(A[118]\)[t] - b\ \(A[125]\)[t] - 
                8\ Da\ \(A[125]\)[t] + Da\ \(A[135]\)[t] + 
                Da\ \(A[154]\)[t] + Da\ \(A[155]\)[t] + Da\ \(A[162]\)[t] + 
                c\ \(A[125]\)[t]\^2\ \(B[125]\)[t] - \(A[125]\)[
                    t]\ \((beta + d\ \(Y[125]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[126]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[120]\)[t] + Da\ \(A[121]\)[t] - 
                b\ \(A[126]\)[t] - 4\ Da\ \(A[126]\)[t] + Da\ \(A[138]\)[t] + 
                Da\ \(A[149]\)[t] + 
                c\ \(A[126]\)[t]\^2\ \(B[126]\)[t] - \(A[126]\)[
                    t]\ \((beta + d\ \(Y[126]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[127]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[96]\)[t] + Da\ \(A[113]\)[t] + 
                Da\ \(A[123]\)[t] - b\ \(A[127]\)[t] - 5\ Da\ \(A[127]\)[t] + 
                Da\ \(A[134]\)[t] + Da\ \(A[141]\)[t] + 
                c\ \(A[127]\)[t]\^2\ \(B[127]\)[t] - \(A[127]\)[
                    t]\ \((beta + d\ \(Y[127]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[128]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[104]\)[t] + Da\ \(A[124]\)[t] - 
                b\ \(A[128]\)[t] - 4\ Da\ \(A[128]\)[t] + Da\ \(A[130]\)[t] + 
                Da\ \(A[140]\)[t] + 
                c\ \(A[128]\)[t]\^2\ \(B[128]\)[t] - \(A[128]\)[
                    t]\ \((beta + d\ \(Y[128]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[129]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[102]\)[t] + Da\ \(A[109]\)[t] + 
                Da\ \(A[110]\)[t] + Da\ \(A[112]\)[t] - b\ \(A[129]\)[t] - 
                7\ Da\ \(A[129]\)[t] + Da\ \(A[131]\)[t] + 
                Da\ \(A[133]\)[t] + Da\ \(A[144]\)[t] + 
                c\ \(A[129]\)[t]\^2\ \(B[129]\)[t] - \(A[129]\)[
                    t]\ \((beta + d\ \(Y[129]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[130]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[104]\)[t] + Da\ \(A[115]\)[t] + 
                Da\ \(A[128]\)[t] - b\ \(A[130]\)[t] - 7\ Da\ \(A[130]\)[t] + 
                Da\ \(A[140]\)[t] + Da\ \(A[142]\)[t] + Da\ \(A[146]\)[t] + 
                Da\ \(A[156]\)[t] + 
                c\ \(A[130]\)[t]\^2\ \(B[130]\)[t] - \(A[130]\)[
                    t]\ \((beta + d\ \(Y[130]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[131]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[101]\)[t] + Da\ \(A[109]\)[t] + 
                Da\ \(A[119]\)[t] + Da\ \(A[129]\)[t] - b\ \(A[131]\)[t] - 
                9\ Da\ \(A[131]\)[t] + Da\ \(A[133]\)[t] + 
                Da\ \(A[135]\)[t] + Da\ \(A[147]\)[t] + Da\ \(A[148]\)[t] + 
                Da\ \(A[158]\)[t] + 
                c\ \(A[131]\)[t]\^2\ \(B[131]\)[t] - \(A[131]\)[
                    t]\ \((beta + d\ \(Y[131]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[132]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[100]\)[t] + Da\ \(A[114]\)[t] + 
                Da\ \(A[123]\)[t] - b\ \(A[132]\)[t] - 6\ Da\ \(A[132]\)[t] + 
                Da\ \(A[141]\)[t] + Da\ \(A[145]\)[t] + Da\ \(A[164]\)[t] + 
                c\ \(A[132]\)[t]\^2\ \(B[132]\)[t] - \(A[132]\)[
                    t]\ \((beta + d\ \(Y[132]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[133]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[129]\)[t] + Da\ \(A[131]\)[t] - 
                b\ \(A[133]\)[t] - 4\ Da\ \(A[133]\)[t] + Da\ \(A[144]\)[t] + 
                Da\ \(A[148]\)[t] + 
                c\ \(A[133]\)[t]\^2\ \(B[133]\)[t] - \(A[133]\)[
                    t]\ \((beta + d\ \(Y[133]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[134]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[113]\)[t] + Da\ \(A[127]\)[t] - 
                b\ \(A[134]\)[t] - 5\ Da\ \(A[134]\)[t] + Da\ \(A[141]\)[t] + 
                Da\ \(A[152]\)[t] + Da\ \(A[153]\)[t] + 
                c\ \(A[134]\)[t]\^2\ \(B[134]\)[t] - \(A[134]\)[
                    t]\ \((beta + d\ \(Y[134]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[135]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[118]\)[t] + Da\ \(A[119]\)[t] + 
                Da\ \(A[125]\)[t] + Da\ \(A[131]\)[t] - b\ \(A[135]\)[t] - 
                6\ Da\ \(A[135]\)[t] + Da\ \(A[147]\)[t] + 
                Da\ \(A[155]\)[t] + 
                c\ \(A[135]\)[t]\^2\ \(B[135]\)[t] - \(A[135]\)[
                    t]\ \((beta + d\ \(Y[135]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[136]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[103]\)[t] + Da\ \(A[111]\)[t] + 
                Da\ \(A[121]\)[t] - b\ \(A[136]\)[t] - 7\ Da\ \(A[136]\)[t] + 
                Da\ \(A[137]\)[t] + Da\ \(A[139]\)[t] + Da\ \(A[157]\)[t] + 
                Da\ \(A[159]\)[t] + 
                c\ \(A[136]\)[t]\^2\ \(B[136]\)[t] - \(A[136]\)[
                    t]\ \((beta + d\ \(Y[136]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[137]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[103]\)[t] + Da\ \(A[107]\)[t] + 
                Da\ \(A[122]\)[t] + Da\ \(A[136]\)[t] - b\ \(A[137]\)[t] - 
                7\ Da\ \(A[137]\)[t] + Da\ \(A[150]\)[t] + 
                Da\ \(A[159]\)[t] + Da\ \(A[171]\)[t] + 
                c\ \(A[137]\)[t]\^2\ \(B[137]\)[t] - \(A[137]\)[
                    t]\ \((beta + d\ \(Y[137]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[138]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[121]\)[t] + Da\ \(A[126]\)[t] - 
                b\ \(A[138]\)[t] - 7\ Da\ \(A[138]\)[t] + Da\ \(A[139]\)[t] + 
                Da\ \(A[149]\)[t] + Da\ \(A[157]\)[t] + Da\ \(A[163]\)[t] + 
                Da\ \(A[170]\)[t] + 
                c\ \(A[138]\)[t]\^2\ \(B[138]\)[t] - \(A[138]\)[
                    t]\ \((beta + d\ \(Y[138]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[139]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[121]\)[t] + Da\ \(A[136]\)[t] + 
                Da\ \(A[138]\)[t] - b\ \(A[139]\)[t] - 4\ Da\ \(A[139]\)[t] + 
                Da\ \(A[157]\)[t] + 
                c\ \(A[139]\)[t]\^2\ \(B[139]\)[t] - \(A[139]\)[
                    t]\ \((beta + d\ \(Y[139]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[140]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[124]\)[t] + Da\ \(A[128]\)[t] + 
                Da\ \(A[130]\)[t] - b\ \(A[140]\)[t] - 5\ Da\ \(A[140]\)[t] + 
                Da\ \(A[145]\)[t] + Da\ \(A[156]\)[t] + 
                c\ \(A[140]\)[t]\^2\ \(B[140]\)[t] - \(A[140]\)[
                    t]\ \((beta + d\ \(Y[140]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[141]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[123]\)[t] + Da\ \(A[127]\)[t] + 
                Da\ \(A[132]\)[t] + Da\ \(A[134]\)[t] - b\ \(A[141]\)[t] - 
                6\ Da\ \(A[141]\)[t] + Da\ \(A[153]\)[t] + 
                Da\ \(A[164]\)[t] + 
                c\ \(A[141]\)[t]\^2\ \(B[141]\)[t] - \(A[141]\)[
                    t]\ \((beta + d\ \(Y[141]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[142]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[115]\)[t] + Da\ \(A[130]\)[t] - 
                b\ \(A[142]\)[t] - 5\ Da\ \(A[142]\)[t] + Da\ \(A[143]\)[t] + 
                Da\ \(A[146]\)[t] + Da\ \(A[151]\)[t] + 
                c\ \(A[142]\)[t]\^2\ \(B[142]\)[t] - \(A[142]\)[
                    t]\ \((beta + d\ \(Y[142]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[143]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[116]\)[t] + Da\ \(A[117]\)[t] + 
                Da\ \(A[142]\)[t] - b\ \(A[143]\)[t] - 5\ Da\ \(A[143]\)[t] + 
                Da\ \(A[151]\)[t] + Da\ \(A[154]\)[t] + 
                c\ \(A[143]\)[t]\^2\ \(B[143]\)[t] - \(A[143]\)[
                    t]\ \((beta + d\ \(Y[143]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[144]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[112]\)[t] + Da\ \(A[129]\)[t] + 
                Da\ \(A[133]\)[t] - b\ \(A[144]\)[t] - 7\ Da\ \(A[144]\)[t] + 
                Da\ \(A[148]\)[t] + Da\ \(A[149]\)[t] + Da\ \(A[165]\)[t] + 
                Da\ \(A[169]\)[t] + 
                c\ \(A[144]\)[t]\^2\ \(B[144]\)[t] - \(A[144]\)[
                    t]\ \((beta + d\ \(Y[144]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[145]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[114]\)[t] + Da\ \(A[124]\)[t] + 
                Da\ \(A[132]\)[t] + Da\ \(A[140]\)[t] - b\ \(A[145]\)[t] - 
                8\ Da\ \(A[145]\)[t] + Da\ \(A[156]\)[t] + 
                Da\ \(A[160]\)[t] + Da\ \(A[164]\)[t] + Da\ \(A[188]\)[t] + 
                c\ \(A[145]\)[t]\^2\ \(B[145]\)[t] - \(A[145]\)[
                    t]\ \((beta + d\ \(Y[145]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[146]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[130]\)[t] + Da\ \(A[142]\)[t] - 
                b\ \(A[146]\)[t] - 5\ Da\ \(A[146]\)[t] + Da\ \(A[151]\)[t] + 
                Da\ \(A[156]\)[t] + Da\ \(A[161]\)[t] + 
                c\ \(A[146]\)[t]\^2\ \(B[146]\)[t] - \(A[146]\)[
                    t]\ \((beta + d\ \(Y[146]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[147]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[131]\)[t] + Da\ \(A[135]\)[t] - 
                b\ \(A[147]\)[t] - 5\ Da\ \(A[147]\)[t] + Da\ \(A[155]\)[t] + 
                Da\ \(A[158]\)[t] + Da\ \(A[167]\)[t] + 
                c\ \(A[147]\)[t]\^2\ \(B[147]\)[t] - \(A[147]\)[
                    t]\ \((beta + d\ \(Y[147]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[148]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[131]\)[t] + Da\ \(A[133]\)[t] + 
                Da\ \(A[144]\)[t] - b\ \(A[148]\)[t] - 6\ Da\ \(A[148]\)[t] + 
                Da\ \(A[158]\)[t] + Da\ \(A[168]\)[t] + Da\ \(A[169]\)[t] + 
                c\ \(A[148]\)[t]\^2\ \(B[148]\)[t] - \(A[148]\)[
                    t]\ \((beta + d\ \(Y[148]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[149]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[112]\)[t] + Da\ \(A[120]\)[t] + 
                Da\ \(A[126]\)[t] + Da\ \(A[138]\)[t] + Da\ \(A[144]\)[t] - 
                b\ \(A[149]\)[t] - 7\ Da\ \(A[149]\)[t] + Da\ \(A[163]\)[t] + 
                Da\ \(A[165]\)[t] + 
                c\ \(A[149]\)[t]\^2\ \(B[149]\)[t] - \(A[149]\)[
                    t]\ \((beta + d\ \(Y[149]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[150]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[122]\)[t] + Da\ \(A[137]\)[t] - 
                b\ \(A[150]\)[t] - 3\ Da\ \(A[150]\)[t] + Da\ \(A[171]\)[t] + 
                c\ \(A[150]\)[t]\^2\ \(B[150]\)[t] - \(A[150]\)[
                    t]\ \((beta + d\ \(Y[150]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[151]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[142]\)[t] + Da\ \(A[143]\)[t] + 
                Da\ \(A[146]\)[t] - b\ \(A[151]\)[t] - 7\ Da\ \(A[151]\)[t] + 
                Da\ \(A[154]\)[t] + Da\ \(A[161]\)[t] + Da\ \(A[166]\)[t] + 
                Da\ \(A[175]\)[t] + 
                c\ \(A[151]\)[t]\^2\ \(B[151]\)[t] - \(A[151]\)[
                    t]\ \((beta + d\ \(Y[151]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[152]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[134]\)[t] - b\ \(A[152]\)[t] - 
                4\ Da\ \(A[152]\)[t] + Da\ \(A[153]\)[t] + 
                Da\ \(A[172]\)[t] + Da\ \(A[178]\)[t] + 
                c\ \(A[152]\)[t]\^2\ \(B[152]\)[t] - \(A[152]\)[
                    t]\ \((beta + d\ \(Y[152]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[153]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[134]\)[t] + Da\ \(A[141]\)[t] + 
                Da\ \(A[152]\)[t] - b\ \(A[153]\)[t] - 6\ Da\ \(A[153]\)[t] + 
                Da\ \(A[164]\)[t] + Da\ \(A[172]\)[t] + Da\ \(A[176]\)[t] + 
                c\ \(A[153]\)[t]\^2\ \(B[153]\)[t] - \(A[153]\)[
                    t]\ \((beta + d\ \(Y[153]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[154]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[117]\)[t] + Da\ \(A[125]\)[t] + 
                Da\ \(A[143]\)[t] + Da\ \(A[151]\)[t] - b\ \(A[154]\)[t] - 
                6\ Da\ \(A[154]\)[t] + Da\ \(A[162]\)[t] + 
                Da\ \(A[166]\)[t] + 
                c\ \(A[154]\)[t]\^2\ \(B[154]\)[t] - \(A[154]\)[
                    t]\ \((beta + d\ \(Y[154]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[155]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[125]\)[t] + Da\ \(A[135]\)[t] + 
                Da\ \(A[147]\)[t] - b\ \(A[155]\)[t] - 6\ Da\ \(A[155]\)[t] + 
                Da\ \(A[162]\)[t] + Da\ \(A[167]\)[t] + Da\ \(A[173]\)[t] + 
                c\ \(A[155]\)[t]\^2\ \(B[155]\)[t] - \(A[155]\)[
                    t]\ \((beta + d\ \(Y[155]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[156]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[130]\)[t] + Da\ \(A[140]\)[t] + 
                Da\ \(A[145]\)[t] + Da\ \(A[146]\)[t] - b\ \(A[156]\)[t] - 
                6\ Da\ \(A[156]\)[t] + Da\ \(A[160]\)[t] + 
                Da\ \(A[161]\)[t] + 
                c\ \(A[156]\)[t]\^2\ \(B[156]\)[t] - \(A[156]\)[
                    t]\ \((beta + d\ \(Y[156]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[157]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[136]\)[t] + Da\ \(A[138]\)[t] + 
                Da\ \(A[139]\)[t] - b\ \(A[157]\)[t] - 5\ Da\ \(A[157]\)[t] + 
                Da\ \(A[159]\)[t] + Da\ \(A[170]\)[t] + 
                c\ \(A[157]\)[t]\^2\ \(B[157]\)[t] - \(A[157]\)[
                    t]\ \((beta + d\ \(Y[157]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[158]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[131]\)[t] + Da\ \(A[147]\)[t] + 
                Da\ \(A[148]\)[t] - b\ \(A[158]\)[t] - 6\ Da\ \(A[158]\)[t] + 
                Da\ \(A[167]\)[t] + Da\ \(A[168]\)[t] + Da\ \(A[179]\)[t] + 
                c\ \(A[158]\)[t]\^2\ \(B[158]\)[t] - \(A[158]\)[
                    t]\ \((beta + d\ \(Y[158]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[159]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[136]\)[t] + Da\ \(A[137]\)[t] + 
                Da\ \(A[157]\)[t] - b\ \(A[159]\)[t] - 7\ Da\ \(A[159]\)[t] + 
                Da\ \(A[170]\)[t] + Da\ \(A[171]\)[t] + Da\ \(A[181]\)[t] + 
                Da\ \(A[182]\)[t] + 
                c\ \(A[159]\)[t]\^2\ \(B[159]\)[t] - \(A[159]\)[
                    t]\ \((beta + d\ \(Y[159]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[160]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[145]\)[t] + Da\ \(A[156]\)[t] - 
                b\ \(A[160]\)[t] - 5\ Da\ \(A[160]\)[t] + Da\ \(A[161]\)[t] + 
                Da\ \(A[186]\)[t] + Da\ \(A[188]\)[t] + 
                c\ \(A[160]\)[t]\^2\ \(B[160]\)[t] - \(A[160]\)[
                    t]\ \((beta + d\ \(Y[160]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[161]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[146]\)[t] + Da\ \(A[151]\)[t] + 
                Da\ \(A[156]\)[t] + Da\ \(A[160]\)[t] - b\ \(A[161]\)[t] - 
                7\ Da\ \(A[161]\)[t] + Da\ \(A[175]\)[t] + 
                Da\ \(A[186]\)[t] + Da\ \(A[190]\)[t] + 
                c\ \(A[161]\)[t]\^2\ \(B[161]\)[t] - \(A[161]\)[
                    t]\ \((beta + d\ \(Y[161]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[162]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[125]\)[t] + Da\ \(A[154]\)[t] + 
                Da\ \(A[155]\)[t] - b\ \(A[162]\)[t] - 7\ Da\ \(A[162]\)[t] + 
                Da\ \(A[166]\)[t] + Da\ \(A[173]\)[t] + Da\ \(A[183]\)[t] + 
                Da\ \(A[184]\)[t] + 
                c\ \(A[162]\)[t]\^2\ \(B[162]\)[t] - \(A[162]\)[
                    t]\ \((beta + d\ \(Y[162]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[163]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[138]\)[t] + Da\ \(A[149]\)[t] - 
                b\ \(A[163]\)[t] - 5\ Da\ \(A[163]\)[t] + Da\ \(A[165]\)[t] + 
                Da\ \(A[170]\)[t] + Da\ \(A[180]\)[t] + 
                c\ \(A[163]\)[t]\^2\ \(B[163]\)[t] - \(A[163]\)[
                    t]\ \((beta + d\ \(Y[163]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[164]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[132]\)[t] + Da\ \(A[141]\)[t] + 
                Da\ \(A[145]\)[t] + Da\ \(A[153]\)[t] - b\ \(A[164]\)[t] - 
                7\ Da\ \(A[164]\)[t] + Da\ \(A[176]\)[t] + 
                Da\ \(A[188]\)[t] + Da\ \(A[201]\)[t] + 
                c\ \(A[164]\)[t]\^2\ \(B[164]\)[t] - \(A[164]\)[
                    t]\ \((beta + d\ \(Y[164]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[165]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[144]\)[t] + Da\ \(A[149]\)[t] + 
                Da\ \(A[163]\)[t] - b\ \(A[165]\)[t] - 6\ Da\ \(A[165]\)[t] + 
                Da\ \(A[169]\)[t] + Da\ \(A[177]\)[t] + Da\ \(A[180]\)[t] + 
                c\ \(A[165]\)[t]\^2\ \(B[165]\)[t] - \(A[165]\)[
                    t]\ \((beta + d\ \(Y[165]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[166]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[151]\)[t] + Da\ \(A[154]\)[t] + 
                Da\ \(A[162]\)[t] - b\ \(A[166]\)[t] - 5\ Da\ \(A[166]\)[t] + 
                Da\ \(A[175]\)[t] + Da\ \(A[183]\)[t] + 
                c\ \(A[166]\)[t]\^2\ \(B[166]\)[t] - \(A[166]\)[
                    t]\ \((beta + d\ \(Y[166]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[167]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[147]\)[t] + Da\ \(A[155]\)[t] + 
                Da\ \(A[158]\)[t] - b\ \(A[167]\)[t] - 6\ Da\ \(A[167]\)[t] + 
                Da\ \(A[173]\)[t] + Da\ \(A[174]\)[t] + Da\ \(A[179]\)[t] + 
                c\ \(A[167]\)[t]\^2\ \(B[167]\)[t] - \(A[167]\)[
                    t]\ \((beta + d\ \(Y[167]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[168]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[148]\)[t] + Da\ \(A[158]\)[t] - 
                b\ \(A[168]\)[t] - 4\ Da\ \(A[168]\)[t] + Da\ \(A[169]\)[t] + 
                Da\ \(A[179]\)[t] + 
                c\ \(A[168]\)[t]\^2\ \(B[168]\)[t] - \(A[168]\)[
                    t]\ \((beta + d\ \(Y[168]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[169]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[144]\)[t] + Da\ \(A[148]\)[t] + 
                Da\ \(A[165]\)[t] + Da\ \(A[168]\)[t] - b\ \(A[169]\)[t] - 
                8\ Da\ \(A[169]\)[t] + Da\ \(A[177]\)[t] + 
                Da\ \(A[179]\)[t] + Da\ \(A[192]\)[t] + Da\ \(A[193]\)[t] + 
                c\ \(A[169]\)[t]\^2\ \(B[169]\)[t] - \(A[169]\)[
                    t]\ \((beta + d\ \(Y[169]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[170]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[138]\)[t] + Da\ \(A[157]\)[t] + 
                Da\ \(A[159]\)[t] + Da\ \(A[163]\)[t] - b\ \(A[170]\)[t] - 
                6\ Da\ \(A[170]\)[t] + Da\ \(A[180]\)[t] + 
                Da\ \(A[181]\)[t] + 
                c\ \(A[170]\)[t]\^2\ \(B[170]\)[t] - \(A[170]\)[
                    t]\ \((beta + d\ \(Y[170]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[171]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[137]\)[t] + Da\ \(A[150]\)[t] + 
                Da\ \(A[159]\)[t] - b\ \(A[171]\)[t] - 4\ Da\ \(A[171]\)[t] + 
                Da\ \(A[182]\)[t] + 
                c\ \(A[171]\)[t]\^2\ \(B[171]\)[t] - \(A[171]\)[
                    t]\ \((beta + d\ \(Y[171]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[172]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[152]\)[t] + Da\ \(A[153]\)[t] - 
                b\ \(A[172]\)[t] - 5\ Da\ \(A[172]\)[t] + Da\ \(A[176]\)[t] + 
                Da\ \(A[178]\)[t] + Da\ \(A[185]\)[t] + 
                c\ \(A[172]\)[t]\^2\ \(B[172]\)[t] - \(A[172]\)[
                    t]\ \((beta + d\ \(Y[172]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[173]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[155]\)[t] + Da\ \(A[162]\)[t] + 
                Da\ \(A[167]\)[t] - b\ \(A[173]\)[t] - 6\ Da\ \(A[173]\)[t] + 
                Da\ \(A[174]\)[t] + Da\ \(A[184]\)[t] + Da\ \(A[189]\)[t] + 
                c\ \(A[173]\)[t]\^2\ \(B[173]\)[t] - \(A[173]\)[
                    t]\ \((beta + d\ \(Y[173]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[174]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[167]\)[t] + Da\ \(A[173]\)[t] - 
                b\ \(A[174]\)[t] - 5\ Da\ \(A[174]\)[t] + Da\ \(A[179]\)[t] + 
                Da\ \(A[187]\)[t] + Da\ \(A[189]\)[t] + 
                c\ \(A[174]\)[t]\^2\ \(B[174]\)[t] - \(A[174]\)[
                    t]\ \((beta + d\ \(Y[174]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[175]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[151]\)[t] + Da\ \(A[161]\)[t] + 
                Da\ \(A[166]\)[t] - b\ \(A[175]\)[t] - 6\ Da\ \(A[175]\)[t] + 
                Da\ \(A[183]\)[t] + Da\ \(A[190]\)[t] + Da\ \(A[199]\)[t] + 
                c\ \(A[175]\)[t]\^2\ \(B[175]\)[t] - \(A[175]\)[
                    t]\ \((beta + d\ \(Y[175]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[176]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[153]\)[t] + Da\ \(A[164]\)[t] + 
                Da\ \(A[172]\)[t] - b\ \(A[176]\)[t] - 6\ Da\ \(A[176]\)[t] + 
                Da\ \(A[185]\)[t] + Da\ \(A[197]\)[t] + Da\ \(A[201]\)[t] + 
                c\ \(A[176]\)[t]\^2\ \(B[176]\)[t] - \(A[176]\)[
                    t]\ \((beta + d\ \(Y[176]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[177]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[165]\)[t] + Da\ \(A[169]\)[t] - 
                b\ \(A[177]\)[t] - 5\ Da\ \(A[177]\)[t] + Da\ \(A[180]\)[t] + 
                Da\ \(A[193]\)[t] + Da\ \(A[194]\)[t] + 
                c\ \(A[177]\)[t]\^2\ \(B[177]\)[t] - \(A[177]\)[
                    t]\ \((beta + d\ \(Y[177]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[178]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[152]\)[t] + Da\ \(A[172]\)[t] - 
                b\ \(A[178]\)[t] - 4\ Da\ \(A[178]\)[t] + Da\ \(A[185]\)[t] + 
                Da\ \(A[203]\)[t] + 
                c\ \(A[178]\)[t]\^2\ \(B[178]\)[t] - \(A[178]\)[
                    t]\ \((beta + d\ \(Y[178]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[179]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[158]\)[t] + Da\ \(A[167]\)[t] + 
                Da\ \(A[168]\)[t] + Da\ \(A[169]\)[t] + Da\ \(A[174]\)[t] - 
                b\ \(A[179]\)[t] - 8\ Da\ \(A[179]\)[t] + Da\ \(A[187]\)[t] + 
                Da\ \(A[191]\)[t] + Da\ \(A[192]\)[t] + 
                c\ \(A[179]\)[t]\^2\ \(B[179]\)[t] - \(A[179]\)[
                    t]\ \((beta + d\ \(Y[179]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[180]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[163]\)[t] + Da\ \(A[165]\)[t] + 
                Da\ \(A[170]\)[t] + Da\ \(A[177]\)[t] - b\ \(A[180]\)[t] - 
                8\ Da\ \(A[180]\)[t] + Da\ \(A[181]\)[t] + 
                Da\ \(A[194]\)[t] + Da\ \(A[196]\)[t] + Da\ \(A[204]\)[t] + 
                c\ \(A[180]\)[t]\^2\ \(B[180]\)[t] - \(A[180]\)[
                    t]\ \((beta + d\ \(Y[180]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[181]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[159]\)[t] + Da\ \(A[170]\)[t] + 
                Da\ \(A[180]\)[t] - b\ \(A[181]\)[t] - 6\ Da\ \(A[181]\)[t] + 
                Da\ \(A[182]\)[t] + Da\ \(A[196]\)[t] + Da\ \(A[200]\)[t] + 
                c\ \(A[181]\)[t]\^2\ \(B[181]\)[t] - \(A[181]\)[
                    t]\ \((beta + d\ \(Y[181]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[182]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[159]\)[t] + Da\ \(A[171]\)[t] + 
                Da\ \(A[181]\)[t] - b\ \(A[182]\)[t] - 4\ Da\ \(A[182]\)[t] + 
                Da\ \(A[200]\)[t] + 
                c\ \(A[182]\)[t]\^2\ \(B[182]\)[t] - \(A[182]\)[
                    t]\ \((beta + d\ \(Y[182]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[183]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[162]\)[t] + Da\ \(A[166]\)[t] + 
                Da\ \(A[175]\)[t] - b\ \(A[183]\)[t] - 6\ Da\ \(A[183]\)[t] + 
                Da\ \(A[184]\)[t] + Da\ \(A[195]\)[t] + Da\ \(A[199]\)[t] + 
                c\ \(A[183]\)[t]\^2\ \(B[183]\)[t] - \(A[183]\)[
                    t]\ \((beta + d\ \(Y[183]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[184]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[162]\)[t] + Da\ \(A[173]\)[t] + 
                Da\ \(A[183]\)[t] - b\ \(A[184]\)[t] - 6\ Da\ \(A[184]\)[t] + 
                Da\ \(A[189]\)[t] + Da\ \(A[195]\)[t] + Da\ \(A[202]\)[t] + 
                c\ \(A[184]\)[t]\^2\ \(B[184]\)[t] - \(A[184]\)[
                    t]\ \((beta + d\ \(Y[184]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[185]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[172]\)[t] + Da\ \(A[176]\)[t] + 
                Da\ \(A[178]\)[t] - b\ \(A[185]\)[t] - 6\ Da\ \(A[185]\)[t] + 
                Da\ \(A[197]\)[t] + Da\ \(A[203]\)[t] + Da\ \(A[208]\)[t] + 
                c\ \(A[185]\)[t]\^2\ \(B[185]\)[t] - \(A[185]\)[
                    t]\ \((beta + d\ \(Y[185]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[186]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[160]\)[t] + Da\ \(A[161]\)[t] - 
                b\ \(A[186]\)[t] - 5\ Da\ \(A[186]\)[t] + Da\ \(A[188]\)[t] + 
                Da\ \(A[190]\)[t] + Da\ \(A[198]\)[t] + 
                c\ \(A[186]\)[t]\^2\ \(B[186]\)[t] - \(A[186]\)[
                    t]\ \((beta + d\ \(Y[186]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[187]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[174]\)[t] + Da\ \(A[179]\)[t] - 
                b\ \(A[187]\)[t] - 5\ Da\ \(A[187]\)[t] + Da\ \(A[189]\)[t] + 
                Da\ \(A[191]\)[t] + Da\ \(A[205]\)[t] + 
                c\ \(A[187]\)[t]\^2\ \(B[187]\)[t] - \(A[187]\)[
                    t]\ \((beta + d\ \(Y[187]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[188]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[145]\)[t] + Da\ \(A[160]\)[t] + 
                Da\ \(A[164]\)[t] + Da\ \(A[186]\)[t] - b\ \(A[188]\)[t] - 
                7\ Da\ \(A[188]\)[t] + Da\ \(A[198]\)[t] + 
                Da\ \(A[201]\)[t] + Da\ \(A[218]\)[t] + 
                c\ \(A[188]\)[t]\^2\ \(B[188]\)[t] - \(A[188]\)[
                    t]\ \((beta + d\ \(Y[188]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[189]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[173]\)[t] + Da\ \(A[174]\)[t] + 
                Da\ \(A[184]\)[t] + Da\ \(A[187]\)[t] - b\ \(A[189]\)[t] - 
                6\ Da\ \(A[189]\)[t] + Da\ \(A[202]\)[t] + 
                Da\ \(A[205]\)[t] + 
                c\ \(A[189]\)[t]\^2\ \(B[189]\)[t] - \(A[189]\)[
                    t]\ \((beta + d\ \(Y[189]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[190]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[161]\)[t] + Da\ \(A[175]\)[t] + 
                Da\ \(A[186]\)[t] - b\ \(A[190]\)[t] - 7\ Da\ \(A[190]\)[t] + 
                Da\ \(A[198]\)[t] + Da\ \(A[199]\)[t] + Da\ \(A[207]\)[t] + 
                Da\ \(A[215]\)[t] + 
                c\ \(A[190]\)[t]\^2\ \(B[190]\)[t] - \(A[190]\)[
                    t]\ \((beta + d\ \(Y[190]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[191]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[179]\)[t] + Da\ \(A[187]\)[t] - 
                b\ \(A[191]\)[t] - 6\ Da\ \(A[191]\)[t] + Da\ \(A[192]\)[t] + 
                Da\ \(A[205]\)[t] + Da\ \(A[206]\)[t] + Da\ \(A[216]\)[t] + 
                c\ \(A[191]\)[t]\^2\ \(B[191]\)[t] - \(A[191]\)[
                    t]\ \((beta + d\ \(Y[191]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[192]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[169]\)[t] + Da\ \(A[179]\)[t] + 
                Da\ \(A[191]\)[t] - b\ \(A[192]\)[t] - 5\ Da\ \(A[192]\)[t] + 
                Da\ \(A[193]\)[t] + Da\ \(A[206]\)[t] + 
                c\ \(A[192]\)[t]\^2\ \(B[192]\)[t] - \(A[192]\)[
                    t]\ \((beta + d\ \(Y[192]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[193]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[169]\)[t] + Da\ \(A[177]\)[t] + 
                Da\ \(A[192]\)[t] - b\ \(A[193]\)[t] - 5\ Da\ \(A[193]\)[t] + 
                Da\ \(A[194]\)[t] + Da\ \(A[206]\)[t] + 
                c\ \(A[193]\)[t]\^2\ \(B[193]\)[t] - \(A[193]\)[
                    t]\ \((beta + d\ \(Y[193]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[194]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[177]\)[t] + Da\ \(A[180]\)[t] + 
                Da\ \(A[193]\)[t] - b\ \(A[194]\)[t] - 5\ Da\ \(A[194]\)[t] + 
                Da\ \(A[204]\)[t] + Da\ \(A[206]\)[t] + 
                c\ \(A[194]\)[t]\^2\ \(B[194]\)[t] - \(A[194]\)[
                    t]\ \((beta + d\ \(Y[194]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[195]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[183]\)[t] + Da\ \(A[184]\)[t] - 
                b\ \(A[195]\)[t] - 6\ Da\ \(A[195]\)[t] + Da\ \(A[199]\)[t] + 
                Da\ \(A[202]\)[t] + Da\ \(A[213]\)[t] + Da\ \(A[222]\)[t] + 
                c\ \(A[195]\)[t]\^2\ \(B[195]\)[t] - \(A[195]\)[
                    t]\ \((beta + d\ \(Y[195]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[196]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[180]\)[t] + Da\ \(A[181]\)[t] - 
                b\ \(A[196]\)[t] - 6\ Da\ \(A[196]\)[t] + Da\ \(A[200]\)[t] + 
                Da\ \(A[204]\)[t] + Da\ \(A[211]\)[t] + Da\ \(A[214]\)[t] + 
                c\ \(A[196]\)[t]\^2\ \(B[196]\)[t] - \(A[196]\)[
                    t]\ \((beta + d\ \(Y[196]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[197]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[176]\)[t] + Da\ \(A[185]\)[t] - 
                b\ \(A[197]\)[t] - 5\ Da\ \(A[197]\)[t] + Da\ \(A[201]\)[t] + 
                Da\ \(A[208]\)[t] + Da\ \(A[209]\)[t] + 
                c\ \(A[197]\)[t]\^2\ \(B[197]\)[t] - \(A[197]\)[
                    t]\ \((beta + d\ \(Y[197]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[198]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[186]\)[t] + Da\ \(A[188]\)[t] + 
                Da\ \(A[190]\)[t] - b\ \(A[198]\)[t] - 5\ Da\ \(A[198]\)[t] + 
                Da\ \(A[215]\)[t] + Da\ \(A[218]\)[t] + 
                c\ \(A[198]\)[t]\^2\ \(B[198]\)[t] - \(A[198]\)[
                    t]\ \((beta + d\ \(Y[198]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[199]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[175]\)[t] + Da\ \(A[183]\)[t] + 
                Da\ \(A[190]\)[t] + Da\ \(A[195]\)[t] - b\ \(A[199]\)[t] - 
                7\ Da\ \(A[199]\)[t] + Da\ \(A[207]\)[t] + 
                Da\ \(A[212]\)[t] + Da\ \(A[222]\)[t] + 
                c\ \(A[199]\)[t]\^2\ \(B[199]\)[t] - \(A[199]\)[
                    t]\ \((beta + d\ \(Y[199]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[200]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[181]\)[t] + Da\ \(A[182]\)[t] + 
                Da\ \(A[196]\)[t] - b\ \(A[200]\)[t] - 4\ Da\ \(A[200]\)[t] + 
                Da\ \(A[211]\)[t] + 
                c\ \(A[200]\)[t]\^2\ \(B[200]\)[t] - \(A[200]\)[
                    t]\ \((beta + d\ \(Y[200]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[201]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[164]\)[t] + Da\ \(A[176]\)[t] + 
                Da\ \(A[188]\)[t] + Da\ \(A[197]\)[t] - b\ \(A[201]\)[t] - 
                7\ Da\ \(A[201]\)[t] + Da\ \(A[209]\)[t] + 
                Da\ \(A[218]\)[t] + Da\ \(A[220]\)[t] + 
                c\ \(A[201]\)[t]\^2\ \(B[201]\)[t] - \(A[201]\)[
                    t]\ \((beta + d\ \(Y[201]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[202]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[184]\)[t] + Da\ \(A[189]\)[t] + 
                Da\ \(A[195]\)[t] - b\ \(A[202]\)[t] - 6\ Da\ \(A[202]\)[t] + 
                Da\ \(A[205]\)[t] + Da\ \(A[210]\)[t] + Da\ \(A[213]\)[t] + 
                c\ \(A[202]\)[t]\^2\ \(B[202]\)[t] - \(A[202]\)[
                    t]\ \((beta + d\ \(Y[202]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[203]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[178]\)[t] + Da\ \(A[185]\)[t] - 
                b\ \(A[203]\)[t] - 4\ Da\ \(A[203]\)[t] + Da\ \(A[208]\)[t] + 
                Da\ \(A[219]\)[t] + 
                c\ \(A[203]\)[t]\^2\ \(B[203]\)[t] - \(A[203]\)[
                    t]\ \((beta + d\ \(Y[203]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[204]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[180]\)[t] + Da\ \(A[194]\)[t] + 
                Da\ \(A[196]\)[t] - b\ \(A[204]\)[t] - 6\ Da\ \(A[204]\)[t] + 
                Da\ \(A[206]\)[t] + Da\ \(A[214]\)[t] + Da\ \(A[217]\)[t] + 
                c\ \(A[204]\)[t]\^2\ \(B[204]\)[t] - \(A[204]\)[
                    t]\ \((beta + d\ \(Y[204]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[205]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[187]\)[t] + Da\ \(A[189]\)[t] + 
                Da\ \(A[191]\)[t] + Da\ \(A[202]\)[t] - b\ \(A[205]\)[t] - 
                7\ Da\ \(A[205]\)[t] + Da\ \(A[210]\)[t] + 
                Da\ \(A[216]\)[t] + Da\ \(A[225]\)[t] + 
                c\ \(A[205]\)[t]\^2\ \(B[205]\)[t] - \(A[205]\)[
                    t]\ \((beta + d\ \(Y[205]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[206]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[191]\)[t] + Da\ \(A[192]\)[t] + 
                Da\ \(A[193]\)[t] + Da\ \(A[194]\)[t] + Da\ \(A[204]\)[t] - 
                b\ \(A[206]\)[t] - 8\ Da\ \(A[206]\)[t] + Da\ \(A[216]\)[t] + 
                Da\ \(A[217]\)[t] + Da\ \(A[221]\)[t] + 
                c\ \(A[206]\)[t]\^2\ \(B[206]\)[t] - \(A[206]\)[
                    t]\ \((beta + d\ \(Y[206]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[207]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[190]\)[t] + Da\ \(A[199]\)[t] - 
                b\ \(A[207]\)[t] - 4\ Da\ \(A[207]\)[t] + Da\ \(A[212]\)[t] + 
                Da\ \(A[215]\)[t] + 
                c\ \(A[207]\)[t]\^2\ \(B[207]\)[t] - \(A[207]\)[
                    t]\ \((beta + d\ \(Y[207]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[208]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[185]\)[t] + Da\ \(A[197]\)[t] + 
                Da\ \(A[203]\)[t] - b\ \(A[208]\)[t] - 6\ Da\ \(A[208]\)[t] + 
                Da\ \(A[209]\)[t] + Da\ \(A[219]\)[t] + Da\ \(A[226]\)[t] + 
                c\ \(A[208]\)[t]\^2\ \(B[208]\)[t] - \(A[208]\)[
                    t]\ \((beta + d\ \(Y[208]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[209]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[197]\)[t] + Da\ \(A[201]\)[t] + 
                Da\ \(A[208]\)[t] - b\ \(A[209]\)[t] - 6\ Da\ \(A[209]\)[t] + 
                Da\ \(A[220]\)[t] + Da\ \(A[226]\)[t] + Da\ \(A[227]\)[t] + 
                c\ \(A[209]\)[t]\^2\ \(B[209]\)[t] - \(A[209]\)[
                    t]\ \((beta + d\ \(Y[209]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[210]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[202]\)[t] + Da\ \(A[205]\)[t] - 
                b\ \(A[210]\)[t] - 5\ Da\ \(A[210]\)[t] + Da\ \(A[213]\)[t] + 
                Da\ \(A[224]\)[t] + Da\ \(A[225]\)[t] + 
                c\ \(A[210]\)[t]\^2\ \(B[210]\)[t] - \(A[210]\)[
                    t]\ \((beta + d\ \(Y[210]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[211]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[196]\)[t] + Da\ \(A[200]\)[t] - 
                b\ \(A[211]\)[t] - 3\ Da\ \(A[211]\)[t] + Da\ \(A[214]\)[t] + 
                c\ \(A[211]\)[t]\^2\ \(B[211]\)[t] - \(A[211]\)[
                    t]\ \((beta + d\ \(Y[211]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[212]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[199]\)[t] + Da\ \(A[207]\)[t] - 
                b\ \(A[212]\)[t] - 6\ Da\ \(A[212]\)[t] + Da\ \(A[215]\)[t] + 
                Da\ \(A[222]\)[t] + Da\ \(A[223]\)[t] + Da\ \(A[230]\)[t] + 
                c\ \(A[212]\)[t]\^2\ \(B[212]\)[t] - \(A[212]\)[
                    t]\ \((beta + d\ \(Y[212]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[213]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[195]\)[t] + Da\ \(A[202]\)[t] + 
                Da\ \(A[210]\)[t] - b\ \(A[213]\)[t] - 5\ Da\ \(A[213]\)[t] + 
                Da\ \(A[222]\)[t] + Da\ \(A[224]\)[t] + 
                c\ \(A[213]\)[t]\^2\ \(B[213]\)[t] - \(A[213]\)[
                    t]\ \((beta + d\ \(Y[213]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[214]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[196]\)[t] + Da\ \(A[204]\)[t] + 
                Da\ \(A[211]\)[t] - b\ \(A[214]\)[t] - 4\ Da\ \(A[214]\)[t] + 
                Da\ \(A[217]\)[t] + 
                c\ \(A[214]\)[t]\^2\ \(B[214]\)[t] - \(A[214]\)[
                    t]\ \((beta + d\ \(Y[214]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[215]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[190]\)[t] + Da\ \(A[198]\)[t] + 
                Da\ \(A[207]\)[t] + Da\ \(A[212]\)[t] - b\ \(A[215]\)[t] - 
                10\ Da\ \(A[215]\)[t] + Da\ \(A[218]\)[t] + 
                Da\ \(A[228]\)[t] + Da\ \(A[230]\)[t] + Da\ \(A[232]\)[t] + 
                Da\ \(A[233]\)[t] + Da\ \(A[235]\)[t] + 
                c\ \(A[215]\)[t]\^2\ \(B[215]\)[t] - \(A[215]\)[
                    t]\ \((beta + d\ \(Y[215]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[216]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[191]\)[t] + Da\ \(A[205]\)[t] + 
                Da\ \(A[206]\)[t] - b\ \(A[216]\)[t] - 6\ Da\ \(A[216]\)[t] + 
                Da\ \(A[221]\)[t] + Da\ \(A[225]\)[t] + Da\ \(A[234]\)[t] + 
                c\ \(A[216]\)[t]\^2\ \(B[216]\)[t] - \(A[216]\)[
                    t]\ \((beta + d\ \(Y[216]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[217]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[204]\)[t] + Da\ \(A[206]\)[t] + 
                Da\ \(A[214]\)[t] - b\ \(A[217]\)[t] - 4\ Da\ \(A[217]\)[t] + 
                Da\ \(A[221]\)[t] + 
                c\ \(A[217]\)[t]\^2\ \(B[217]\)[t] - \(A[217]\)[
                    t]\ \((beta + d\ \(Y[217]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[218]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[188]\)[t] + Da\ \(A[198]\)[t] + 
                Da\ \(A[201]\)[t] + Da\ \(A[215]\)[t] - b\ \(A[218]\)[t] - 
                7\ Da\ \(A[218]\)[t] + Da\ \(A[220]\)[t] + 
                Da\ \(A[228]\)[t] + Da\ \(A[229]\)[t] + 
                c\ \(A[218]\)[t]\^2\ \(B[218]\)[t] - \(A[218]\)[
                    t]\ \((beta + d\ \(Y[218]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[219]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[203]\)[t] + Da\ \(A[208]\)[t] - 
                b\ \(A[219]\)[t] - 4\ Da\ \(A[219]\)[t] + Da\ \(A[226]\)[t] + 
                Da\ \(A[237]\)[t] + 
                c\ \(A[219]\)[t]\^2\ \(B[219]\)[t] - \(A[219]\)[
                    t]\ \((beta + d\ \(Y[219]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[220]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[201]\)[t] + Da\ \(A[209]\)[t] + 
                Da\ \(A[218]\)[t] - b\ \(A[220]\)[t] - 5\ Da\ \(A[220]\)[t] + 
                Da\ \(A[227]\)[t] + Da\ \(A[229]\)[t] + 
                c\ \(A[220]\)[t]\^2\ \(B[220]\)[t] - \(A[220]\)[
                    t]\ \((beta + d\ \(Y[220]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[221]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[206]\)[t] + Da\ \(A[216]\)[t] + 
                Da\ \(A[217]\)[t] - b\ \(A[221]\)[t] - 3\ Da\ \(A[221]\)[t] + 
                c\ \(A[221]\)[t]\^2\ \(B[221]\)[t] - \(A[221]\)[
                    t]\ \((beta + d\ \(Y[221]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[222]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[195]\)[t] + Da\ \(A[199]\)[t] + 
                Da\ \(A[212]\)[t] + Da\ \(A[213]\)[t] - b\ \(A[222]\)[t] - 
                7\ Da\ \(A[222]\)[t] + Da\ \(A[223]\)[t] + 
                Da\ \(A[224]\)[t] + Da\ \(A[231]\)[t] + 
                c\ \(A[222]\)[t]\^2\ \(B[222]\)[t] - \(A[222]\)[
                    t]\ \((beta + d\ \(Y[222]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[223]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[212]\)[t] + Da\ \(A[222]\)[t] - 
                b\ \(A[223]\)[t] - 6\ Da\ \(A[223]\)[t] + Da\ \(A[230]\)[t] + 
                Da\ \(A[231]\)[t] + Da\ \(A[236]\)[t] + Da\ \(A[238]\)[t] + 
                c\ \(A[223]\)[t]\^2\ \(B[223]\)[t] - \(A[223]\)[
                    t]\ \((beta + d\ \(Y[223]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[224]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[210]\)[t] + Da\ \(A[213]\)[t] + 
                Da\ \(A[222]\)[t] - b\ \(A[224]\)[t] - 5\ Da\ \(A[224]\)[t] + 
                Da\ \(A[225]\)[t] + Da\ \(A[231]\)[t] + 
                c\ \(A[224]\)[t]\^2\ \(B[224]\)[t] - \(A[224]\)[
                    t]\ \((beta + d\ \(Y[224]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[225]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[205]\)[t] + Da\ \(A[210]\)[t] + 
                Da\ \(A[216]\)[t] + Da\ \(A[224]\)[t] - b\ \(A[225]\)[t] - 
                6\ Da\ \(A[225]\)[t] + Da\ \(A[231]\)[t] + 
                Da\ \(A[234]\)[t] + 
                c\ \(A[225]\)[t]\^2\ \(B[225]\)[t] - \(A[225]\)[
                    t]\ \((beta + d\ \(Y[225]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[226]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[208]\)[t] + Da\ \(A[209]\)[t] + 
                Da\ \(A[219]\)[t] - b\ \(A[226]\)[t] - 6\ Da\ \(A[226]\)[t] + 
                Da\ \(A[227]\)[t] + Da\ \(A[237]\)[t] + Da\ \(A[239]\)[t] + 
                c\ \(A[226]\)[t]\^2\ \(B[226]\)[t] - \(A[226]\)[
                    t]\ \((beta + d\ \(Y[226]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[227]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[209]\)[t] + Da\ \(A[220]\)[t] + 
                Da\ \(A[226]\)[t] - b\ \(A[227]\)[t] - 5\ Da\ \(A[227]\)[t] + 
                Da\ \(A[229]\)[t] + Da\ \(A[239]\)[t] + 
                c\ \(A[227]\)[t]\^2\ \(B[227]\)[t] - \(A[227]\)[
                    t]\ \((beta + d\ \(Y[227]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[228]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[215]\)[t] + Da\ \(A[218]\)[t] - 
                b\ \(A[228]\)[t] - 5\ Da\ \(A[228]\)[t] + Da\ \(A[229]\)[t] + 
                Da\ \(A[235]\)[t] + Da\ \(A[240]\)[t] + 
                c\ \(A[228]\)[t]\^2\ \(B[228]\)[t] - \(A[228]\)[
                    t]\ \((beta + d\ \(Y[228]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[229]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[218]\)[t] + Da\ \(A[220]\)[t] + 
                Da\ \(A[227]\)[t] + Da\ \(A[228]\)[t] - b\ \(A[229]\)[t] - 
                7\ Da\ \(A[229]\)[t] + Da\ \(A[239]\)[t] + 
                Da\ \(A[240]\)[t] + Da\ \(A[242]\)[t] + 
                c\ \(A[229]\)[t]\^2\ \(B[229]\)[t] - \(A[229]\)[
                    t]\ \((beta + d\ \(Y[229]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[230]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[212]\)[t] + Da\ \(A[215]\)[t] + 
                Da\ \(A[223]\)[t] - b\ \(A[230]\)[t] - 6\ Da\ \(A[230]\)[t] + 
                Da\ \(A[232]\)[t] + Da\ \(A[236]\)[t] + Da\ \(A[245]\)[t] + 
                c\ \(A[230]\)[t]\^2\ \(B[230]\)[t] - \(A[230]\)[
                    t]\ \((beta + d\ \(Y[230]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[231]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[222]\)[t] + Da\ \(A[223]\)[t] + 
                Da\ \(A[224]\)[t] + Da\ \(A[225]\)[t] - b\ \(A[231]\)[t] - 
                7\ Da\ \(A[231]\)[t] + Da\ \(A[234]\)[t] + 
                Da\ \(A[238]\)[t] + Da\ \(A[244]\)[t] + 
                c\ \(A[231]\)[t]\^2\ \(B[231]\)[t] - \(A[231]\)[
                    t]\ \((beta + d\ \(Y[231]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[232]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[215]\)[t] + Da\ \(A[230]\)[t] - 
                b\ \(A[232]\)[t] - 4\ Da\ \(A[232]\)[t] + Da\ \(A[233]\)[t] + 
                Da\ \(A[245]\)[t] + 
                c\ \(A[232]\)[t]\^2\ \(B[232]\)[t] - \(A[232]\)[
                    t]\ \((beta + d\ \(Y[232]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[233]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[215]\)[t] + Da\ \(A[232]\)[t] - 
                b\ \(A[233]\)[t] - 5\ Da\ \(A[233]\)[t] + Da\ \(A[235]\)[t] + 
                Da\ \(A[241]\)[t] + Da\ \(A[245]\)[t] + 
                c\ \(A[233]\)[t]\^2\ \(B[233]\)[t] - \(A[233]\)[
                    t]\ \((beta + d\ \(Y[233]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[234]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[216]\)[t] + Da\ \(A[225]\)[t] + 
                Da\ \(A[231]\)[t] - b\ \(A[234]\)[t] - 4\ Da\ \(A[234]\)[t] + 
                Da\ \(A[244]\)[t] + 
                c\ \(A[234]\)[t]\^2\ \(B[234]\)[t] - \(A[234]\)[
                    t]\ \((beta + d\ \(Y[234]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[235]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[215]\)[t] + Da\ \(A[228]\)[t] + 
                Da\ \(A[233]\)[t] - b\ \(A[235]\)[t] - 6\ Da\ \(A[235]\)[t] + 
                Da\ \(A[240]\)[t] + Da\ \(A[241]\)[t] + Da\ \(A[243]\)[t] + 
                c\ \(A[235]\)[t]\^2\ \(B[235]\)[t] - \(A[235]\)[
                    t]\ \((beta + d\ \(Y[235]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[236]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[223]\)[t] + Da\ \(A[230]\)[t] - 
                b\ \(A[236]\)[t] - 5\ Da\ \(A[236]\)[t] + Da\ \(A[238]\)[t] + 
                Da\ \(A[245]\)[t] + Da\ \(A[248]\)[t] + 
                c\ \(A[236]\)[t]\^2\ \(B[236]\)[t] - \(A[236]\)[
                    t]\ \((beta + d\ \(Y[236]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[237]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[219]\)[t] + Da\ \(A[226]\)[t] - 
                b\ \(A[237]\)[t] - 4\ Da\ \(A[237]\)[t] + Da\ \(A[239]\)[t] + 
                Da\ \(A[249]\)[t] + 
                c\ \(A[237]\)[t]\^2\ \(B[237]\)[t] - \(A[237]\)[
                    t]\ \((beta + d\ \(Y[237]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[238]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[223]\)[t] + Da\ \(A[231]\)[t] + 
                Da\ \(A[236]\)[t] - b\ \(A[238]\)[t] - 6\ Da\ \(A[238]\)[t] + 
                Da\ \(A[244]\)[t] + Da\ \(A[246]\)[t] + Da\ \(A[248]\)[t] + 
                c\ \(A[238]\)[t]\^2\ \(B[238]\)[t] - \(A[238]\)[
                    t]\ \((beta + d\ \(Y[238]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[239]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[226]\)[t] + Da\ \(A[227]\)[t] + 
                Da\ \(A[229]\)[t] + Da\ \(A[237]\)[t] - b\ \(A[239]\)[t] - 
                7\ Da\ \(A[239]\)[t] + Da\ \(A[242]\)[t] + 
                Da\ \(A[249]\)[t] + Da\ \(A[250]\)[t] + 
                c\ \(A[239]\)[t]\^2\ \(B[239]\)[t] - \(A[239]\)[
                    t]\ \((beta + d\ \(Y[239]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[240]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[228]\)[t] + Da\ \(A[229]\)[t] + 
                Da\ \(A[235]\)[t] - b\ \(A[240]\)[t] - 6\ Da\ \(A[240]\)[t] + 
                Da\ \(A[242]\)[t] + Da\ \(A[243]\)[t] + Da\ \(A[247]\)[t] + 
                c\ \(A[240]\)[t]\^2\ \(B[240]\)[t] - \(A[240]\)[
                    t]\ \((beta + d\ \(Y[240]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[241]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[233]\)[t] + Da\ \(A[235]\)[t] - 
                b\ \(A[241]\)[t] - 7\ Da\ \(A[241]\)[t] + Da\ \(A[243]\)[t] + 
                Da\ \(A[245]\)[t] + Da\ \(A[247]\)[t] + Da\ \(A[251]\)[t] + 
                Da\ \(A[253]\)[t] + 
                c\ \(A[241]\)[t]\^2\ \(B[241]\)[t] - \(A[241]\)[
                    t]\ \((beta + d\ \(Y[241]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[242]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[229]\)[t] + Da\ \(A[239]\)[t] + 
                Da\ \(A[240]\)[t] - b\ \(A[242]\)[t] - 6\ Da\ \(A[242]\)[t] + 
                Da\ \(A[247]\)[t] + Da\ \(A[250]\)[t] + Da\ \(A[252]\)[t] + 
                c\ \(A[242]\)[t]\^2\ \(B[242]\)[t] - \(A[242]\)[
                    t]\ \((beta + d\ \(Y[242]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[243]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[235]\)[t] + Da\ \(A[240]\)[t] + 
                Da\ \(A[241]\)[t] - b\ \(A[243]\)[t] - 4\ Da\ \(A[243]\)[t] + 
                Da\ \(A[247]\)[t] + 
                c\ \(A[243]\)[t]\^2\ \(B[243]\)[t] - \(A[243]\)[
                    t]\ \((beta + d\ \(Y[243]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[244]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[231]\)[t] + Da\ \(A[234]\)[t] + 
                Da\ \(A[238]\)[t] - b\ \(A[244]\)[t] - 4\ Da\ \(A[244]\)[t] + 
                Da\ \(A[246]\)[t] + 
                c\ \(A[244]\)[t]\^2\ \(B[244]\)[t] - \(A[244]\)[
                    t]\ \((beta + d\ \(Y[244]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[245]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[230]\)[t] + Da\ \(A[232]\)[t] + 
                Da\ \(A[233]\)[t] + Da\ \(A[236]\)[t] + Da\ \(A[241]\)[t] - 
                b\ \(A[245]\)[t] - 7\ Da\ \(A[245]\)[t] + Da\ \(A[248]\)[t] + 
                Da\ \(A[251]\)[t] + 
                c\ \(A[245]\)[t]\^2\ \(B[245]\)[t] - \(A[245]\)[
                    t]\ \((beta + d\ \(Y[245]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[246]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[238]\)[t] + Da\ \(A[244]\)[t] - 
                b\ \(A[246]\)[t] - 3\ Da\ \(A[246]\)[t] + Da\ \(A[248]\)[t] + 
                c\ \(A[246]\)[t]\^2\ \(B[246]\)[t] - \(A[246]\)[
                    t]\ \((beta + d\ \(Y[246]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[247]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[240]\)[t] + Da\ \(A[241]\)[t] + 
                Da\ \(A[242]\)[t] + Da\ \(A[243]\)[t] - b\ \(A[247]\)[t] - 
                6\ Da\ \(A[247]\)[t] + Da\ \(A[252]\)[t] + 
                Da\ \(A[253]\)[t] + 
                c\ \(A[247]\)[t]\^2\ \(B[247]\)[t] - \(A[247]\)[
                    t]\ \((beta + d\ \(Y[247]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[248]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[236]\)[t] + Da\ \(A[238]\)[t] + 
                Da\ \(A[245]\)[t] + Da\ \(A[246]\)[t] - b\ \(A[248]\)[t] - 
                4\ Da\ \(A[248]\)[t] + 
                c\ \(A[248]\)[t]\^2\ \(B[248]\)[t] - \(A[248]\)[
                    t]\ \((beta + d\ \(Y[248]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[249]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[237]\)[t] + Da\ \(A[239]\)[t] - 
                b\ \(A[249]\)[t] - 3\ Da\ \(A[249]\)[t] + Da\ \(A[250]\)[t] + 
                c\ \(A[249]\)[t]\^2\ \(B[249]\)[t] - \(A[249]\)[
                    t]\ \((beta + d\ \(Y[249]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[250]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[239]\)[t] + Da\ \(A[242]\)[t] + 
                Da\ \(A[249]\)[t] - b\ \(A[250]\)[t] - 4\ Da\ \(A[250]\)[t] + 
                Da\ \(A[252]\)[t] + 
                c\ \(A[250]\)[t]\^2\ \(B[250]\)[t] - \(A[250]\)[
                    t]\ \((beta + d\ \(Y[250]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[251]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[241]\)[t] + Da\ \(A[245]\)[t] - 
                b\ \(A[251]\)[t] - 3\ Da\ \(A[251]\)[t] + Da\ \(A[253]\)[t] + 
                c\ \(A[251]\)[t]\^2\ \(B[251]\)[t] - \(A[251]\)[
                    t]\ \((beta + d\ \(Y[251]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[252]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[242]\)[t] + Da\ \(A[247]\)[t] + 
                Da\ \(A[250]\)[t] - b\ \(A[252]\)[t] - 4\ Da\ \(A[252]\)[t] + 
                Da\ \(A[253]\)[t] + 
                c\ \(A[252]\)[t]\^2\ \(B[252]\)[t] - \(A[252]\)[
                    t]\ \((beta + d\ \(Y[252]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(A[253]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(a + Da\ \(A[241]\)[t] + Da\ \(A[247]\)[t] + 
                Da\ \(A[251]\)[t] + Da\ \(A[252]\)[t] - b\ \(A[253]\)[t] - 
                4\ Da\ \(A[253]\)[t] + 
                c\ \(A[253]\)[t]\^2\ \(B[253]\)[t] - \(A[253]\)[
                    t]\ \((beta + d\ \(Y[253]\)[t])\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[1]\)[t] - 3\ Db\ \(B[1]\)[t] - 
                c\ \(A[1]\)[t]\^2\ \(B[1]\)[t] + Db\ \(B[2]\)[t] + 
                Db\ \(B[3]\)[t] + Db\ \(B[8]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[2]\)[t] + Db\ \(B[1]\)[t] - 
                4\ Db\ \(B[2]\)[t] - c\ \(A[2]\)[t]\^2\ \(B[2]\)[t] + 
                Db\ \(B[4]\)[t] + Db\ \(B[5]\)[t] + Db\ \(B[8]\)[t]\)}], ",", 
            
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[3]\)[t] + Db\ \(B[1]\)[t] - 
                4\ Db\ \(B[3]\)[t] - c\ \(A[3]\)[t]\^2\ \(B[3]\)[t] + 
                Db\ \(B[6]\)[t] + Db\ \(B[7]\)[t] + Db\ \(B[8]\)[t]\)}], ",", 
            
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[4]\)[t] + Db\ \(B[2]\)[t] - 
                4\ Db\ \(B[4]\)[t] - c\ \(A[4]\)[t]\^2\ \(B[4]\)[t] + 
                Db\ \(B[5]\)[t] + Db\ \(B[9]\)[t] + Db\ \(B[10]\)[t]\)}], ",",
             
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[5]\)[t] + Db\ \(B[2]\)[t] + 
                Db\ \(B[4]\)[t] - 5\ Db\ \(B[5]\)[t] - 
                c\ \(A[5]\)[t]\^2\ \(B[5]\)[t] + Db\ \(B[8]\)[t] + 
                Db\ \(B[9]\)[t] + Db\ \(B[14]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[6]\)[t] + Db\ \(B[3]\)[t] - 
                5\ Db\ \(B[6]\)[t] - c\ \(A[6]\)[t]\^2\ \(B[6]\)[t] + 
                Db\ \(B[7]\)[t] + Db\ \(B[11]\)[t] + Db\ \(B[12]\)[t] + 
                Db\ \(B[22]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[7]\)[t] + Db\ \(B[3]\)[t] + 
                Db\ \(B[6]\)[t] - 5\ Db\ \(B[7]\)[t] - 
                c\ \(A[7]\)[t]\^2\ \(B[7]\)[t] + Db\ \(B[8]\)[t] + 
                Db\ \(B[11]\)[t] + Db\ \(B[13]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[8]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[8]\)[t] + Db\ \(B[1]\)[t] + 
                Db\ \(B[2]\)[t] + Db\ \(B[3]\)[t] + Db\ \(B[5]\)[t] + 
                Db\ \(B[7]\)[t] - 8\ Db\ \(B[8]\)[t] - 
                c\ \(A[8]\)[t]\^2\ \(B[8]\)[t] + Db\ \(B[13]\)[t] + 
                Db\ \(B[14]\)[t] + Db\ \(B[17]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[9]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[9]\)[t] + Db\ \(B[4]\)[t] + 
                Db\ \(B[5]\)[t] - 6\ Db\ \(B[9]\)[t] - 
                c\ \(A[9]\)[t]\^2\ \(B[9]\)[t] + Db\ \(B[10]\)[t] + 
                Db\ \(B[14]\)[t] + Db\ \(B[18]\)[t] + Db\ \(B[27]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[10]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[10]\)[t] + Db\ \(B[4]\)[t] + 
                Db\ \(B[9]\)[t] - 5\ Db\ \(B[10]\)[t] - 
                c\ \(A[10]\)[t]\^2\ \(B[10]\)[t] + Db\ \(B[18]\)[t] + 
                Db\ \(B[19]\)[t] + Db\ \(B[28]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[11]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[11]\)[t] + Db\ \(B[6]\)[t] + 
                Db\ \(B[7]\)[t] - 7\ Db\ \(B[11]\)[t] - 
                c\ \(A[11]\)[t]\^2\ \(B[11]\)[t] + Db\ \(B[13]\)[t] + 
                Db\ \(B[22]\)[t] + Db\ \(B[24]\)[t] + Db\ \(B[25]\)[t] + 
                Db\ \(B[26]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[12]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[12]\)[t] + Db\ \(B[6]\)[t] - 
                4\ Db\ \(B[12]\)[t] - c\ \(A[12]\)[t]\^2\ \(B[12]\)[t] + 
                Db\ \(B[16]\)[t] + Db\ \(B[22]\)[t] + Db\ \(B[30]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[13]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[13]\)[t] + Db\ \(B[7]\)[t] + 
                Db\ \(B[8]\)[t] + Db\ \(B[11]\)[t] - 6\ Db\ \(B[13]\)[t] - 
                c\ \(A[13]\)[t]\^2\ \(B[13]\)[t] + Db\ \(B[17]\)[t] + 
                Db\ \(B[26]\)[t] + Db\ \(B[39]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[14]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[14]\)[t] + Db\ \(B[5]\)[t] + 
                Db\ \(B[8]\)[t] + Db\ \(B[9]\)[t] - 7\ Db\ \(B[14]\)[t] - 
                c\ \(A[14]\)[t]\^2\ \(B[14]\)[t] + Db\ \(B[17]\)[t] + 
                Db\ \(B[23]\)[t] + Db\ \(B[27]\)[t] + Db\ \(B[33]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[15]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[15]\)[t] - 5\ Db\ \(B[15]\)[t] - 
                c\ \(A[15]\)[t]\^2\ \(B[15]\)[t] + Db\ \(B[20]\)[t] + 
                Db\ \(B[21]\)[t] + Db\ \(B[29]\)[t] + Db\ \(B[34]\)[t] + 
                Db\ \(B[35]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[16]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[16]\)[t] + Db\ \(B[12]\)[t] - 
                2\ Db\ \(B[16]\)[t] - c\ \(A[16]\)[t]\^2\ \(B[16]\)[t] + 
                Db\ \(B[30]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[17]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[17]\)[t] + Db\ \(B[8]\)[t] + 
                Db\ \(B[13]\)[t] + Db\ \(B[14]\)[t] - 7\ Db\ \(B[17]\)[t] - 
                c\ \(A[17]\)[t]\^2\ \(B[17]\)[t] + Db\ \(B[23]\)[t] + 
                Db\ \(B[39]\)[t] + Db\ \(B[53]\)[t] + Db\ \(B[54]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[18]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[18]\)[t] + Db\ \(B[9]\)[t] + 
                Db\ \(B[10]\)[t] - 5\ Db\ \(B[18]\)[t] - 
                c\ \(A[18]\)[t]\^2\ \(B[18]\)[t] + Db\ \(B[27]\)[t] + 
                Db\ \(B[28]\)[t] + Db\ \(B[31]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[19]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[19]\)[t] + Db\ \(B[10]\)[t] - 
                6\ Db\ \(B[19]\)[t] - c\ \(A[19]\)[t]\^2\ \(B[19]\)[t] + 
                Db\ \(B[20]\)[t] + Db\ \(B[28]\)[t] + Db\ \(B[32]\)[t] + 
                Db\ \(B[38]\)[t] + Db\ \(B[40]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[20]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[20]\)[t] + Db\ \(B[15]\)[t] + 
                Db\ \(B[19]\)[t] - 4\ Db\ \(B[20]\)[t] - 
                c\ \(A[20]\)[t]\^2\ \(B[20]\)[t] + Db\ \(B[34]\)[t] + 
                Db\ \(B[40]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[21]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[21]\)[t] + Db\ \(B[15]\)[t] - 
                4\ Db\ \(B[21]\)[t] - c\ \(A[21]\)[t]\^2\ \(B[21]\)[t] + 
                Db\ \(B[29]\)[t] + Db\ \(B[36]\)[t] + Db\ \(B[47]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[22]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[22]\)[t] + Db\ \(B[6]\)[t] + 
                Db\ \(B[11]\)[t] + Db\ \(B[12]\)[t] - 6\ Db\ \(B[22]\)[t] - 
                c\ \(A[22]\)[t]\^2\ \(B[22]\)[t] + Db\ \(B[24]\)[t] + 
                Db\ \(B[37]\)[t] + Db\ \(B[43]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[23]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[23]\)[t] + Db\ \(B[14]\)[t] + 
                Db\ \(B[17]\)[t] - 5\ Db\ \(B[23]\)[t] - 
                c\ \(A[23]\)[t]\^2\ \(B[23]\)[t] + Db\ \(B[33]\)[t] + 
                Db\ \(B[45]\)[t] + Db\ \(B[54]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[24]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[24]\)[t] + Db\ \(B[11]\)[t] + 
                Db\ \(B[22]\)[t] - 4\ Db\ \(B[24]\)[t] - 
                c\ \(A[24]\)[t]\^2\ \(B[24]\)[t] + Db\ \(B[25]\)[t] + 
                Db\ \(B[37]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[25]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[25]\)[t] + Db\ \(B[11]\)[t] + 
                Db\ \(B[24]\)[t] - 5\ Db\ \(B[25]\)[t] - 
                c\ \(A[25]\)[t]\^2\ \(B[25]\)[t] + Db\ \(B[26]\)[t] + 
                Db\ \(B[37]\)[t] + Db\ \(B[39]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[26]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[26]\)[t] + Db\ \(B[11]\)[t] + 
                Db\ \(B[13]\)[t] + Db\ \(B[25]\)[t] - 4\ Db\ \(B[26]\)[t] - 
                c\ \(A[26]\)[t]\^2\ \(B[26]\)[t] + Db\ \(B[39]\)[t]\)}], ",", 
            
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[27]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[27]\)[t] + Db\ \(B[9]\)[t] + 
                Db\ \(B[14]\)[t] + Db\ \(B[18]\)[t] - 5\ Db\ \(B[27]\)[t] - 
                c\ \(A[27]\)[t]\^2\ \(B[27]\)[t] + Db\ \(B[31]\)[t] + 
                Db\ \(B[33]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[28]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[28]\)[t] + Db\ \(B[10]\)[t] + 
                Db\ \(B[18]\)[t] + Db\ \(B[19]\)[t] - 6\ Db\ \(B[28]\)[t] - 
                c\ \(A[28]\)[t]\^2\ \(B[28]\)[t] + Db\ \(B[31]\)[t] + 
                Db\ \(B[32]\)[t] + Db\ \(B[44]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[29]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[29]\)[t] + Db\ \(B[15]\)[t] + 
                Db\ \(B[21]\)[t] - 6\ Db\ \(B[29]\)[t] - 
                c\ \(A[29]\)[t]\^2\ \(B[29]\)[t] + Db\ \(B[35]\)[t] + 
                Db\ \(B[47]\)[t] + Db\ \(B[49]\)[t] + Db\ \(B[57]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[30]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[30]\)[t] + Db\ \(B[12]\)[t] + 
                Db\ \(B[16]\)[t] - 4\ Db\ \(B[30]\)[t] - 
                c\ \(A[30]\)[t]\^2\ \(B[30]\)[t] + Db\ \(B[43]\)[t] + 
                Db\ \(B[50]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[31]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[31]\)[t] + Db\ \(B[18]\)[t] + 
                Db\ \(B[27]\)[t] + Db\ \(B[28]\)[t] - 6\ Db\ \(B[31]\)[t] - 
                c\ \(A[31]\)[t]\^2\ \(B[31]\)[t] + Db\ \(B[33]\)[t] + 
                Db\ \(B[44]\)[t] + Db\ \(B[46]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[32]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[32]\)[t] + Db\ \(B[19]\)[t] + 
                Db\ \(B[28]\)[t] - 4\ Db\ \(B[32]\)[t] - 
                c\ \(A[32]\)[t]\^2\ \(B[32]\)[t] + Db\ \(B[38]\)[t] + 
                Db\ \(B[44]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[33]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[33]\)[t] + Db\ \(B[14]\)[t] + 
                Db\ \(B[23]\)[t] + Db\ \(B[27]\)[t] + Db\ \(B[31]\)[t] - 
                6\ Db\ \(B[33]\)[t] - c\ \(A[33]\)[t]\^2\ \(B[33]\)[t] + 
                Db\ \(B[45]\)[t] + Db\ \(B[46]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[34]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[34]\)[t] + Db\ \(B[15]\)[t] + 
                Db\ \(B[20]\)[t] - 7\ Db\ \(B[34]\)[t] - 
                c\ \(A[34]\)[t]\^2\ \(B[34]\)[t] + Db\ \(B[35]\)[t] + 
                Db\ \(B[40]\)[t] + Db\ \(B[41]\)[t] + Db\ \(B[51]\)[t] + 
                Db\ \(B[52]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[35]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[35]\)[t] + Db\ \(B[15]\)[t] + 
                Db\ \(B[29]\)[t] + Db\ \(B[34]\)[t] - 6\ Db\ \(B[35]\)[t] - 
                c\ \(A[35]\)[t]\^2\ \(B[35]\)[t] + Db\ \(B[41]\)[t] + 
                Db\ \(B[57]\)[t] + Db\ \(B[60]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[36]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[36]\)[t] + Db\ \(B[21]\)[t] - 
                4\ Db\ \(B[36]\)[t] - c\ \(A[36]\)[t]\^2\ \(B[36]\)[t] + 
                Db\ \(B[42]\)[t] + Db\ \(B[47]\)[t] + Db\ \(B[48]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[37]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[37]\)[t] + Db\ \(B[22]\)[t] + 
                Db\ \(B[24]\)[t] + Db\ \(B[25]\)[t] - 6\ Db\ \(B[37]\)[t] - 
                c\ \(A[37]\)[t]\^2\ \(B[37]\)[t] + Db\ \(B[39]\)[t] + 
                Db\ \(B[43]\)[t] + Db\ \(B[59]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[38]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[38]\)[t] + Db\ \(B[19]\)[t] + 
                Db\ \(B[32]\)[t] - 6\ Db\ \(B[38]\)[t] - 
                c\ \(A[38]\)[t]\^2\ \(B[38]\)[t] + Db\ \(B[40]\)[t] + 
                Db\ \(B[44]\)[t] + Db\ \(B[56]\)[t] + Db\ \(B[67]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[39]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[39]\)[t] + Db\ \(B[13]\)[t] + 
                Db\ \(B[17]\)[t] + Db\ \(B[25]\)[t] + Db\ \(B[26]\)[t] + 
                Db\ \(B[37]\)[t] - 8\ Db\ \(B[39]\)[t] - 
                c\ \(A[39]\)[t]\^2\ \(B[39]\)[t] + Db\ \(B[53]\)[t] + 
                Db\ \(B[59]\)[t] + Db\ \(B[65]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[40]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[40]\)[t] + Db\ \(B[19]\)[t] + 
                Db\ \(B[20]\)[t] + Db\ \(B[34]\)[t] + Db\ \(B[38]\)[t] - 
                6\ Db\ \(B[40]\)[t] - c\ \(A[40]\)[t]\^2\ \(B[40]\)[t] + 
                Db\ \(B[51]\)[t] + Db\ \(B[56]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[41]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[41]\)[t] + Db\ \(B[34]\)[t] + 
                Db\ \(B[35]\)[t] - 4\ Db\ \(B[41]\)[t] - 
                c\ \(A[41]\)[t]\^2\ \(B[41]\)[t] + Db\ \(B[52]\)[t] + 
                Db\ \(B[60]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[42]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[42]\)[t] + Db\ \(B[36]\)[t] - 
                3\ Db\ \(B[42]\)[t] - c\ \(A[42]\)[t]\^2\ \(B[42]\)[t] + 
                Db\ \(B[48]\)[t] + Db\ \(B[58]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[43]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[43]\)[t] + Db\ \(B[22]\)[t] + 
                Db\ \(B[30]\)[t] + Db\ \(B[37]\)[t] - 7\ Db\ \(B[43]\)[t] - 
                c\ \(A[43]\)[t]\^2\ \(B[43]\)[t] + Db\ \(B[50]\)[t] + 
                Db\ \(B[59]\)[t] + Db\ \(B[61]\)[t] + Db\ \(B[64]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[44]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[44]\)[t] + Db\ \(B[28]\)[t] + 
                Db\ \(B[31]\)[t] + Db\ \(B[32]\)[t] + Db\ \(B[38]\)[t] - 
                8\ Db\ \(B[44]\)[t] - c\ \(A[44]\)[t]\^2\ \(B[44]\)[t] + 
                Db\ \(B[46]\)[t] + Db\ \(B[55]\)[t] + Db\ \(B[66]\)[t] + 
                Db\ \(B[67]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[45]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[45]\)[t] + Db\ \(B[23]\)[t] + 
                Db\ \(B[33]\)[t] - 5\ Db\ \(B[45]\)[t] - 
                c\ \(A[45]\)[t]\^2\ \(B[45]\)[t] + Db\ \(B[46]\)[t] + 
                Db\ \(B[54]\)[t] + Db\ \(B[75]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[46]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[46]\)[t] + Db\ \(B[31]\)[t] + 
                Db\ \(B[33]\)[t] + Db\ \(B[44]\)[t] + Db\ \(B[45]\)[t] - 
                7\ Db\ \(B[46]\)[t] - c\ \(A[46]\)[t]\^2\ \(B[46]\)[t] + 
                Db\ \(B[55]\)[t] + Db\ \(B[68]\)[t] + Db\ \(B[69]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[47]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[47]\)[t] + Db\ \(B[21]\)[t] + 
                Db\ \(B[29]\)[t] + Db\ \(B[36]\)[t] - 6\ Db\ \(B[47]\)[t] - 
                c\ \(A[47]\)[t]\^2\ \(B[47]\)[t] + Db\ \(B[48]\)[t] + 
                Db\ \(B[49]\)[t] + Db\ \(B[63]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[48]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[48]\)[t] + Db\ \(B[36]\)[t] + 
                Db\ \(B[42]\)[t] + Db\ \(B[47]\)[t] - 7\ Db\ \(B[48]\)[t] - 
                c\ \(A[48]\)[t]\^2\ \(B[48]\)[t] + Db\ \(B[58]\)[t] + 
                Db\ \(B[63]\)[t] + Db\ \(B[73]\)[t] + Db\ \(B[77]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[49]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[49]\)[t] + Db\ \(B[29]\)[t] + 
                Db\ \(B[47]\)[t] - 5\ Db\ \(B[49]\)[t] - 
                c\ \(A[49]\)[t]\^2\ \(B[49]\)[t] + Db\ \(B[57]\)[t] + 
                Db\ \(B[63]\)[t] + Db\ \(B[76]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[50]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[50]\)[t] + Db\ \(B[30]\)[t] + 
                Db\ \(B[43]\)[t] - 4\ Db\ \(B[50]\)[t] - 
                c\ \(A[50]\)[t]\^2\ \(B[50]\)[t] + Db\ \(B[61]\)[t] + 
                Db\ \(B[82]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[51]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[51]\)[t] + Db\ \(B[34]\)[t] + 
                Db\ \(B[40]\)[t] - 7\ Db\ \(B[51]\)[t] - 
                c\ \(A[51]\)[t]\^2\ \(B[51]\)[t] + Db\ \(B[52]\)[t] + 
                Db\ \(B[56]\)[t] + Db\ \(B[71]\)[t] + Db\ \(B[72]\)[t] + 
                Db\ \(B[84]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[52]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[52]\)[t] + Db\ \(B[34]\)[t] + 
                Db\ \(B[41]\)[t] + Db\ \(B[51]\)[t] - 5\ Db\ \(B[52]\)[t] - 
                c\ \(A[52]\)[t]\^2\ \(B[52]\)[t] + Db\ \(B[60]\)[t] + 
                Db\ \(B[72]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[53]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[53]\)[t] + Db\ \(B[17]\)[t] + 
                Db\ \(B[39]\)[t] - 6\ Db\ \(B[53]\)[t] - 
                c\ \(A[53]\)[t]\^2\ \(B[53]\)[t] + Db\ \(B[54]\)[t] + 
                Db\ \(B[65]\)[t] + Db\ \(B[70]\)[t] + Db\ \(B[74]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[54]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[54]\)[t] + Db\ \(B[17]\)[t] + 
                Db\ \(B[23]\)[t] + Db\ \(B[45]\)[t] + Db\ \(B[53]\)[t] - 
                6\ Db\ \(B[54]\)[t] - c\ \(A[54]\)[t]\^2\ \(B[54]\)[t] + 
                Db\ \(B[74]\)[t] + Db\ \(B[75]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[55]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[55]\)[t] + Db\ \(B[44]\)[t] + 
                Db\ \(B[46]\)[t] - 5\ Db\ \(B[55]\)[t] - 
                c\ \(A[55]\)[t]\^2\ \(B[55]\)[t] + Db\ \(B[66]\)[t] + 
                Db\ \(B[69]\)[t] + Db\ \(B[86]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[56]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[56]\)[t] + Db\ \(B[38]\)[t] + 
                Db\ \(B[40]\)[t] + Db\ \(B[51]\)[t] - 6\ Db\ \(B[56]\)[t] - 
                c\ \(A[56]\)[t]\^2\ \(B[56]\)[t] + Db\ \(B[62]\)[t] + 
                Db\ \(B[67]\)[t] + Db\ \(B[71]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[57]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[57]\)[t] + Db\ \(B[29]\)[t] + 
                Db\ \(B[35]\)[t] + Db\ \(B[49]\)[t] - 7\ Db\ \(B[57]\)[t] - 
                c\ \(A[57]\)[t]\^2\ \(B[57]\)[t] + Db\ \(B[60]\)[t] + 
                Db\ \(B[76]\)[t] + Db\ \(B[81]\)[t] + Db\ \(B[85]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[58]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[58]\)[t] + Db\ \(B[42]\)[t] + 
                Db\ \(B[48]\)[t] - 4\ Db\ \(B[58]\)[t] - 
                c\ \(A[58]\)[t]\^2\ \(B[58]\)[t] + Db\ \(B[77]\)[t] + 
                Db\ \(B[78]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[59]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[59]\)[t] + Db\ \(B[37]\)[t] + 
                Db\ \(B[39]\)[t] + Db\ \(B[43]\)[t] - 7\ Db\ \(B[59]\)[t] - 
                c\ \(A[59]\)[t]\^2\ \(B[59]\)[t] + Db\ \(B[64]\)[t] + 
                Db\ \(B[65]\)[t] + Db\ \(B[83]\)[t] + Db\ \(B[87]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[60]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[60]\)[t] + Db\ \(B[35]\)[t] + 
                Db\ \(B[41]\)[t] + Db\ \(B[52]\)[t] + Db\ \(B[57]\)[t] - 
                7\ Db\ \(B[60]\)[t] - c\ \(A[60]\)[t]\^2\ \(B[60]\)[t] + 
                Db\ \(B[72]\)[t] + Db\ \(B[80]\)[t] + Db\ \(B[85]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[61]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[61]\)[t] + Db\ \(B[43]\)[t] + 
                Db\ \(B[50]\)[t] - 6\ Db\ \(B[61]\)[t] - 
                c\ \(A[61]\)[t]\^2\ \(B[61]\)[t] + Db\ \(B[64]\)[t] + 
                Db\ \(B[82]\)[t] + Db\ \(B[89]\)[t] + Db\ \(B[96]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[62]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[62]\)[t] + Db\ \(B[56]\)[t] - 
                4\ Db\ \(B[62]\)[t] - c\ \(A[62]\)[t]\^2\ \(B[62]\)[t] + 
                Db\ \(B[67]\)[t] + Db\ \(B[71]\)[t] + Db\ \(B[79]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[63]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[63]\)[t] + Db\ \(B[47]\)[t] + 
                Db\ \(B[48]\)[t] + Db\ \(B[49]\)[t] - 5\ Db\ \(B[63]\)[t] - 
                c\ \(A[63]\)[t]\^2\ \(B[63]\)[t] + Db\ \(B[73]\)[t] + 
                Db\ \(B[76]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[64]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[64]\)[t] + Db\ \(B[43]\)[t] + 
                Db\ \(B[59]\)[t] + Db\ \(B[61]\)[t] - 5\ Db\ \(B[64]\)[t] - 
                c\ \(A[64]\)[t]\^2\ \(B[64]\)[t] + Db\ \(B[83]\)[t] + 
                Db\ \(B[96]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[65]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[65]\)[t] + Db\ \(B[39]\)[t] + 
                Db\ \(B[53]\)[t] + Db\ \(B[59]\)[t] - 7\ Db\ \(B[65]\)[t] - 
                c\ \(A[65]\)[t]\^2\ \(B[65]\)[t] + Db\ \(B[70]\)[t] + 
                Db\ \(B[87]\)[t] + Db\ \(B[97]\)[t] + Db\ \(B[100]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[66]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[66]\)[t] + Db\ \(B[44]\)[t] + 
                Db\ \(B[55]\)[t] - 6\ Db\ \(B[66]\)[t] - 
                c\ \(A[66]\)[t]\^2\ \(B[66]\)[t] + Db\ \(B[67]\)[t] + 
                Db\ \(B[79]\)[t] + Db\ \(B[86]\)[t] + Db\ \(B[91]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[67]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[67]\)[t] + Db\ \(B[38]\)[t] + 
                Db\ \(B[44]\)[t] + Db\ \(B[56]\)[t] + Db\ \(B[62]\)[t] + 
                Db\ \(B[66]\)[t] - 6\ Db\ \(B[67]\)[t] - 
                c\ \(A[67]\)[t]\^2\ \(B[67]\)[t] + Db\ \(B[79]\)[t]\)}], ",", 
            
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[68]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[68]\)[t] + Db\ \(B[46]\)[t] - 
                4\ Db\ \(B[68]\)[t] - c\ \(A[68]\)[t]\^2\ \(B[68]\)[t] + 
                Db\ \(B[69]\)[t] + Db\ \(B[75]\)[t] + Db\ \(B[94]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[69]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[69]\)[t] + Db\ \(B[46]\)[t] + 
                Db\ \(B[55]\)[t] + Db\ \(B[68]\)[t] - 6\ Db\ \(B[69]\)[t] - 
                c\ \(A[69]\)[t]\^2\ \(B[69]\)[t] + Db\ \(B[86]\)[t] + 
                Db\ \(B[94]\)[t] + Db\ \(B[98]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[70]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[70]\)[t] + Db\ \(B[53]\)[t] + 
                Db\ \(B[65]\)[t] - 5\ Db\ \(B[70]\)[t] - 
                c\ \(A[70]\)[t]\^2\ \(B[70]\)[t] + Db\ \(B[74]\)[t] + 
                Db\ \(B[93]\)[t] + Db\ \(B[97]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[71]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[71]\)[t] + Db\ \(B[51]\)[t] + 
                Db\ \(B[56]\)[t] + Db\ \(B[62]\)[t] - 5\ Db\ \(B[71]\)[t] - 
                c\ \(A[71]\)[t]\^2\ \(B[71]\)[t] + Db\ \(B[79]\)[t] + 
                Db\ \(B[84]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[72]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[72]\)[t] + Db\ \(B[51]\)[t] + 
                Db\ \(B[52]\)[t] + Db\ \(B[60]\)[t] - 6\ Db\ \(B[72]\)[t] - 
                c\ \(A[72]\)[t]\^2\ \(B[72]\)[t] + Db\ \(B[80]\)[t] + 
                Db\ \(B[84]\)[t] + Db\ \(B[102]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[73]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[73]\)[t] + Db\ \(B[48]\)[t] + 
                Db\ \(B[63]\)[t] - 5\ Db\ \(B[73]\)[t] - 
                c\ \(A[73]\)[t]\^2\ \(B[73]\)[t] + Db\ \(B[76]\)[t] + 
                Db\ \(B[77]\)[t] + Db\ \(B[92]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[74]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[74]\)[t] + Db\ \(B[53]\)[t] + 
                Db\ \(B[54]\)[t] + Db\ \(B[70]\)[t] - 6\ Db\ \(B[74]\)[t] - 
                c\ \(A[74]\)[t]\^2\ \(B[74]\)[t] + Db\ \(B[75]\)[t] + 
                Db\ \(B[90]\)[t] + Db\ \(B[93]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[75]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[75]\)[t] + Db\ \(B[45]\)[t] + 
                Db\ \(B[54]\)[t] + Db\ \(B[68]\)[t] + Db\ \(B[74]\)[t] - 
                6\ Db\ \(B[75]\)[t] - c\ \(A[75]\)[t]\^2\ \(B[75]\)[t] + 
                Db\ \(B[90]\)[t] + Db\ \(B[94]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[76]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[76]\)[t] + Db\ \(B[49]\)[t] + 
                Db\ \(B[57]\)[t] + Db\ \(B[63]\)[t] + Db\ \(B[73]\)[t] - 
                7\ Db\ \(B[76]\)[t] - c\ \(A[76]\)[t]\^2\ \(B[76]\)[t] + 
                Db\ \(B[81]\)[t] + Db\ \(B[92]\)[t] + Db\ \(B[95]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[77]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[77]\)[t] + Db\ \(B[48]\)[t] + 
                Db\ \(B[58]\)[t] + Db\ \(B[73]\)[t] - 7\ Db\ \(B[77]\)[t] - 
                c\ \(A[77]\)[t]\^2\ \(B[77]\)[t] + Db\ \(B[78]\)[t] + 
                Db\ \(B[92]\)[t] + Db\ \(B[103]\)[t] + Db\ \(B[107]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[78]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[78]\)[t] + Db\ \(B[58]\)[t] + 
                Db\ \(B[77]\)[t] - 3\ Db\ \(B[78]\)[t] - 
                c\ \(A[78]\)[t]\^2\ \(B[78]\)[t] + Db\ \(B[107]\)[t]\)}], ",",
             
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[79]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[79]\)[t] + Db\ \(B[62]\)[t] + 
                Db\ \(B[66]\)[t] + Db\ \(B[67]\)[t] + Db\ \(B[71]\)[t] - 
                8\ Db\ \(B[79]\)[t] - c\ \(A[79]\)[t]\^2\ \(B[79]\)[t] + 
                Db\ \(B[84]\)[t] + Db\ \(B[91]\)[t] + Db\ \(B[99]\)[t] + 
                Db\ \(B[101]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[80]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[80]\)[t] + Db\ \(B[60]\)[t] + 
                Db\ \(B[72]\)[t] - 6\ Db\ \(B[80]\)[t] - 
                c\ \(A[80]\)[t]\^2\ \(B[80]\)[t] + Db\ \(B[85]\)[t] + 
                Db\ \(B[88]\)[t] + Db\ \(B[102]\)[t] + Db\ \(B[110]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[81]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[81]\)[t] + Db\ \(B[57]\)[t] + 
                Db\ \(B[76]\)[t] - 4\ Db\ \(B[81]\)[t] - 
                c\ \(A[81]\)[t]\^2\ \(B[81]\)[t] + Db\ \(B[85]\)[t] + 
                Db\ \(B[95]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[82]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[82]\)[t] + Db\ \(B[50]\)[t] + 
                Db\ \(B[61]\)[t] - 4\ Db\ \(B[82]\)[t] - 
                c\ \(A[82]\)[t]\^2\ \(B[82]\)[t] + Db\ \(B[89]\)[t] + 
                Db\ \(B[113]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[83]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[83]\)[t] + Db\ \(B[59]\)[t] + 
                Db\ \(B[64]\)[t] - 6\ Db\ \(B[83]\)[t] - 
                c\ \(A[83]\)[t]\^2\ \(B[83]\)[t] + Db\ \(B[87]\)[t] + 
                Db\ \(B[96]\)[t] + Db\ \(B[100]\)[t] + Db\ \(B[123]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[84]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[84]\)[t] + Db\ \(B[51]\)[t] + 
                Db\ \(B[71]\)[t] + Db\ \(B[72]\)[t] + Db\ \(B[79]\)[t] - 
                7\ Db\ \(B[84]\)[t] - c\ \(A[84]\)[t]\^2\ \(B[84]\)[t] + 
                Db\ \(B[101]\)[t] + Db\ \(B[102]\)[t] + Db\ \(B[109]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[85]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[85]\)[t] + Db\ \(B[57]\)[t] + 
                Db\ \(B[60]\)[t] + Db\ \(B[80]\)[t] + Db\ \(B[81]\)[t] - 
                6\ Db\ \(B[85]\)[t] - c\ \(A[85]\)[t]\^2\ \(B[85]\)[t] + 
                Db\ \(B[88]\)[t] + Db\ \(B[95]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[86]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[86]\)[t] + Db\ \(B[55]\)[t] + 
                Db\ \(B[66]\)[t] + Db\ \(B[69]\)[t] - 6\ Db\ \(B[86]\)[t] - 
                c\ \(A[86]\)[t]\^2\ \(B[86]\)[t] + Db\ \(B[91]\)[t] + 
                Db\ \(B[98]\)[t] + Db\ \(B[106]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[87]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[87]\)[t] + Db\ \(B[59]\)[t] + 
                Db\ \(B[65]\)[t] + Db\ \(B[83]\)[t] - 4\ Db\ \(B[87]\)[t] - 
                c\ \(A[87]\)[t]\^2\ \(B[87]\)[t] + Db\ \(B[100]\)[t]\)}], ",",
             
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[88]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[88]\)[t] + Db\ \(B[80]\)[t] + 
                Db\ \(B[85]\)[t] - 6\ Db\ \(B[88]\)[t] - 
                c\ \(A[88]\)[t]\^2\ \(B[88]\)[t] + Db\ \(B[95]\)[t] + 
                Db\ \(B[110]\)[t] + Db\ \(B[112]\)[t] + Db\ \(B[120]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[89]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[89]\)[t] + Db\ \(B[61]\)[t] + 
                Db\ \(B[82]\)[t] - 4\ Db\ \(B[89]\)[t] - 
                c\ \(A[89]\)[t]\^2\ \(B[89]\)[t] + Db\ \(B[96]\)[t] + 
                Db\ \(B[113]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[90]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[90]\)[t] + Db\ \(B[74]\)[t] + 
                Db\ \(B[75]\)[t] - 6\ Db\ \(B[90]\)[t] - 
                c\ \(A[90]\)[t]\^2\ \(B[90]\)[t] + Db\ \(B[93]\)[t] + 
                Db\ \(B[105]\)[t] + Db\ \(B[108]\)[t] + Db\ \(B[116]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[91]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[91]\)[t] + Db\ \(B[66]\)[t] + 
                Db\ \(B[79]\)[t] + Db\ \(B[86]\)[t] - 6\ Db\ \(B[91]\)[t] - 
                c\ \(A[91]\)[t]\^2\ \(B[91]\)[t] + Db\ \(B[99]\)[t] + 
                Db\ \(B[106]\)[t] + Db\ \(B[118]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[92]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[92]\)[t] + Db\ \(B[73]\)[t] + 
                Db\ \(B[76]\)[t] + Db\ \(B[77]\)[t] - 6\ Db\ \(B[92]\)[t] - 
                c\ \(A[92]\)[t]\^2\ \(B[92]\)[t] + Db\ \(B[95]\)[t] + 
                Db\ \(B[103]\)[t] + Db\ \(B[111]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[93]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[93]\)[t] + Db\ \(B[70]\)[t] + 
                Db\ \(B[74]\)[t] + Db\ \(B[90]\)[t] - 7\ Db\ \(B[93]\)[t] - 
                c\ \(A[93]\)[t]\^2\ \(B[93]\)[t] + Db\ \(B[97]\)[t] + 
                Db\ \(B[104]\)[t] + Db\ \(B[105]\)[t] + Db\ \(B[115]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[94]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[94]\)[t] + Db\ \(B[68]\)[t] + 
                Db\ \(B[69]\)[t] + Db\ \(B[75]\)[t] - 6\ Db\ \(B[94]\)[t] - 
                c\ \(A[94]\)[t]\^2\ \(B[94]\)[t] + Db\ \(B[98]\)[t] + 
                Db\ \(B[108]\)[t] + Db\ \(B[117]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[95]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[95]\)[t] + Db\ \(B[76]\)[t] + 
                Db\ \(B[81]\)[t] + Db\ \(B[85]\)[t] + Db\ \(B[88]\)[t] + 
                Db\ \(B[92]\)[t] - 8\ Db\ \(B[95]\)[t] - 
                c\ \(A[95]\)[t]\^2\ \(B[95]\)[t] + Db\ \(B[111]\)[t] + 
                Db\ \(B[120]\)[t] + Db\ \(B[121]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[96]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[96]\)[t] + Db\ \(B[61]\)[t] + 
                Db\ \(B[64]\)[t] + Db\ \(B[83]\)[t] + Db\ \(B[89]\)[t] - 
                7\ Db\ \(B[96]\)[t] - c\ \(A[96]\)[t]\^2\ \(B[96]\)[t] + 
                Db\ \(B[113]\)[t] + Db\ \(B[123]\)[t] + Db\ \(B[127]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[97]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[97]\)[t] + Db\ \(B[65]\)[t] + 
                Db\ \(B[70]\)[t] + Db\ \(B[93]\)[t] - 6\ Db\ \(B[97]\)[t] - 
                c\ \(A[97]\)[t]\^2\ \(B[97]\)[t] + Db\ \(B[100]\)[t] + 
                Db\ \(B[104]\)[t] + Db\ \(B[124]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[98]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[98]\)[t] + Db\ \(B[69]\)[t] + 
                Db\ \(B[86]\)[t] + Db\ \(B[94]\)[t] - 6\ Db\ \(B[98]\)[t] - 
                c\ \(A[98]\)[t]\^2\ \(B[98]\)[t] + Db\ \(B[106]\)[t] + 
                Db\ \(B[117]\)[t] + Db\ \(B[125]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[99]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[99]\)[t] + Db\ \(B[79]\)[t] + 
                Db\ \(B[91]\)[t] - 5\ Db\ \(B[99]\)[t] - 
                c\ \(A[99]\)[t]\^2\ \(B[99]\)[t] + Db\ \(B[101]\)[t] + 
                Db\ \(B[118]\)[t] + Db\ \(B[119]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[100]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[100]\)[t] + Db\ \(B[65]\)[t] + 
                Db\ \(B[83]\)[t] + Db\ \(B[87]\)[t] + Db\ \(B[97]\)[t] - 
                8\ Db\ \(B[100]\)[t] - c\ \(A[100]\)[t]\^2\ \(B[100]\)[t] + 
                Db\ \(B[114]\)[t] + Db\ \(B[123]\)[t] + Db\ \(B[124]\)[t] + 
                Db\ \(B[132]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[101]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[101]\)[t] + Db\ \(B[79]\)[t] + 
                Db\ \(B[84]\)[t] + Db\ \(B[99]\)[t] - 6\ Db\ \(B[101]\)[t] - 
                c\ \(A[101]\)[t]\^2\ \(B[101]\)[t] + Db\ \(B[109]\)[t] + 
                Db\ \(B[119]\)[t] + Db\ \(B[131]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[102]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[102]\)[t] + Db\ \(B[72]\)[t] + 
                Db\ \(B[80]\)[t] + Db\ \(B[84]\)[t] - 6\ Db\ \(B[102]\)[t] - 
                c\ \(A[102]\)[t]\^2\ \(B[102]\)[t] + Db\ \(B[109]\)[t] + 
                Db\ \(B[110]\)[t] + Db\ \(B[129]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[103]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[103]\)[t] + Db\ \(B[77]\)[t] + 
                Db\ \(B[92]\)[t] - 6\ Db\ \(B[103]\)[t] - 
                c\ \(A[103]\)[t]\^2\ \(B[103]\)[t] + Db\ \(B[107]\)[t] + 
                Db\ \(B[111]\)[t] + Db\ \(B[136]\)[t] + Db\ \(B[137]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[104]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[104]\)[t] + Db\ \(B[93]\)[t] + 
                Db\ \(B[97]\)[t] - 6\ Db\ \(B[104]\)[t] - 
                c\ \(A[104]\)[t]\^2\ \(B[104]\)[t] + Db\ \(B[115]\)[t] + 
                Db\ \(B[124]\)[t] + Db\ \(B[128]\)[t] + Db\ \(B[130]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[105]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[105]\)[t] + Db\ \(B[90]\)[t] + 
                Db\ \(B[93]\)[t] - 4\ Db\ \(B[105]\)[t] - 
                c\ \(A[105]\)[t]\^2\ \(B[105]\)[t] + Db\ \(B[115]\)[t] + 
                Db\ \(B[116]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[106]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[106]\)[t] + Db\ \(B[86]\)[t] + 
                Db\ \(B[91]\)[t] + Db\ \(B[98]\)[t] - 5\ Db\ \(B[106]\)[t] - 
                c\ \(A[106]\)[t]\^2\ \(B[106]\)[t] + Db\ \(B[118]\)[t] + 
                Db\ \(B[125]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[107]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[107]\)[t] + Db\ \(B[77]\)[t] + 
                Db\ \(B[78]\)[t] + Db\ \(B[103]\)[t] - 5\ Db\ \(B[107]\)[t] - 
                c\ \(A[107]\)[t]\^2\ \(B[107]\)[t] + Db\ \(B[122]\)[t] + 
                Db\ \(B[137]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[108]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[108]\)[t] + Db\ \(B[90]\)[t] + 
                Db\ \(B[94]\)[t] - 4\ Db\ \(B[108]\)[t] - 
                c\ \(A[108]\)[t]\^2\ \(B[108]\)[t] + Db\ \(B[116]\)[t] + 
                Db\ \(B[117]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[109]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[109]\)[t] + Db\ \(B[84]\)[t] + 
                Db\ \(B[101]\)[t] + Db\ \(B[102]\)[t] - 
                5\ Db\ \(B[109]\)[t] - c\ \(A[109]\)[t]\^2\ \(B[109]\)[t] + 
                Db\ \(B[129]\)[t] + Db\ \(B[131]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[110]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[110]\)[t] + Db\ \(B[80]\)[t] + 
                Db\ \(B[88]\)[t] + Db\ \(B[102]\)[t] - 5\ Db\ \(B[110]\)[t] - 
                c\ \(A[110]\)[t]\^2\ \(B[110]\)[t] + Db\ \(B[112]\)[t] + 
                Db\ \(B[129]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[111]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[111]\)[t] + Db\ \(B[92]\)[t] + 
                Db\ \(B[95]\)[t] + Db\ \(B[103]\)[t] - 5\ Db\ \(B[111]\)[t] - 
                c\ \(A[111]\)[t]\^2\ \(B[111]\)[t] + Db\ \(B[121]\)[t] + 
                Db\ \(B[136]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[112]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[112]\)[t] + Db\ \(B[88]\)[t] + 
                Db\ \(B[110]\)[t] - 6\ Db\ \(B[112]\)[t] - 
                c\ \(A[112]\)[t]\^2\ \(B[112]\)[t] + Db\ \(B[120]\)[t] + 
                Db\ \(B[129]\)[t] + Db\ \(B[144]\)[t] + Db\ \(B[149]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[113]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[113]\)[t] + Db\ \(B[82]\)[t] + 
                Db\ \(B[89]\)[t] + Db\ \(B[96]\)[t] - 5\ Db\ \(B[113]\)[t] - 
                c\ \(A[113]\)[t]\^2\ \(B[113]\)[t] + Db\ \(B[127]\)[t] + 
                Db\ \(B[134]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[114]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[114]\)[t] + Db\ \(B[100]\)[t] - 
                4\ Db\ \(B[114]\)[t] - c\ \(A[114]\)[t]\^2\ \(B[114]\)[t] + 
                Db\ \(B[124]\)[t] + Db\ \(B[132]\)[t] + Db\ \(B[145]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[115]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[115]\)[t] + Db\ \(B[93]\)[t] + 
                Db\ \(B[104]\)[t] + Db\ \(B[105]\)[t] - 
                6\ Db\ \(B[115]\)[t] - c\ \(A[115]\)[t]\^2\ \(B[115]\)[t] + 
                Db\ \(B[116]\)[t] + Db\ \(B[130]\)[t] + Db\ \(B[142]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[116]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[116]\)[t] + Db\ \(B[90]\)[t] + 
                Db\ \(B[105]\)[t] + Db\ \(B[108]\)[t] + Db\ \(B[115]\)[t] - 
                6\ Db\ \(B[116]\)[t] - c\ \(A[116]\)[t]\^2\ \(B[116]\)[t] + 
                Db\ \(B[117]\)[t] + Db\ \(B[143]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[117]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[117]\)[t] + Db\ \(B[94]\)[t] + 
                Db\ \(B[98]\)[t] + Db\ \(B[108]\)[t] + Db\ \(B[116]\)[t] - 
                7\ Db\ \(B[117]\)[t] - c\ \(A[117]\)[t]\^2\ \(B[117]\)[t] + 
                Db\ \(B[125]\)[t] + Db\ \(B[143]\)[t] + Db\ \(B[154]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[118]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[118]\)[t] + Db\ \(B[91]\)[t] + 
                Db\ \(B[99]\)[t] + Db\ \(B[106]\)[t] - 6\ Db\ \(B[118]\)[t] - 
                c\ \(A[118]\)[t]\^2\ \(B[118]\)[t] + Db\ \(B[119]\)[t] + 
                Db\ \(B[125]\)[t] + Db\ \(B[135]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[119]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[119]\)[t] + Db\ \(B[99]\)[t] + 
                Db\ \(B[101]\)[t] + Db\ \(B[118]\)[t] - 
                5\ Db\ \(B[119]\)[t] - c\ \(A[119]\)[t]\^2\ \(B[119]\)[t] + 
                Db\ \(B[131]\)[t] + Db\ \(B[135]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[120]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[120]\)[t] + Db\ \(B[88]\)[t] + 
                Db\ \(B[95]\)[t] + Db\ \(B[112]\)[t] - 6\ Db\ \(B[120]\)[t] - 
                c\ \(A[120]\)[t]\^2\ \(B[120]\)[t] + Db\ \(B[121]\)[t] + 
                Db\ \(B[126]\)[t] + Db\ \(B[149]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[121]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[121]\)[t] + Db\ \(B[95]\)[t] + 
                Db\ \(B[111]\)[t] + Db\ \(B[120]\)[t] - 
                7\ Db\ \(B[121]\)[t] - c\ \(A[121]\)[t]\^2\ \(B[121]\)[t] + 
                Db\ \(B[126]\)[t] + Db\ \(B[136]\)[t] + Db\ \(B[138]\)[t] + 
                Db\ \(B[139]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[122]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[122]\)[t] + Db\ \(B[107]\)[t] - 
                3\ Db\ \(B[122]\)[t] - c\ \(A[122]\)[t]\^2\ \(B[122]\)[t] + 
                Db\ \(B[137]\)[t] + Db\ \(B[150]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[123]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[123]\)[t] + Db\ \(B[83]\)[t] + 
                Db\ \(B[96]\)[t] + Db\ \(B[100]\)[t] - 6\ Db\ \(B[123]\)[t] - 
                c\ \(A[123]\)[t]\^2\ \(B[123]\)[t] + Db\ \(B[127]\)[t] + 
                Db\ \(B[132]\)[t] + Db\ \(B[141]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[124]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[124]\)[t] + Db\ \(B[97]\)[t] + 
                Db\ \(B[100]\)[t] + Db\ \(B[104]\)[t] + Db\ \(B[114]\)[t] - 
                7\ Db\ \(B[124]\)[t] - c\ \(A[124]\)[t]\^2\ \(B[124]\)[t] + 
                Db\ \(B[128]\)[t] + Db\ \(B[140]\)[t] + Db\ \(B[145]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[125]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[125]\)[t] + Db\ \(B[98]\)[t] + 
                Db\ \(B[106]\)[t] + Db\ \(B[117]\)[t] + Db\ \(B[118]\)[t] - 
                8\ Db\ \(B[125]\)[t] - c\ \(A[125]\)[t]\^2\ \(B[125]\)[t] + 
                Db\ \(B[135]\)[t] + Db\ \(B[154]\)[t] + Db\ \(B[155]\)[t] + 
                Db\ \(B[162]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[126]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[126]\)[t] + Db\ \(B[120]\)[t] + 
                Db\ \(B[121]\)[t] - 4\ Db\ \(B[126]\)[t] - 
                c\ \(A[126]\)[t]\^2\ \(B[126]\)[t] + Db\ \(B[138]\)[t] + 
                Db\ \(B[149]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[127]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[127]\)[t] + Db\ \(B[96]\)[t] + 
                Db\ \(B[113]\)[t] + Db\ \(B[123]\)[t] - 
                5\ Db\ \(B[127]\)[t] - c\ \(A[127]\)[t]\^2\ \(B[127]\)[t] + 
                Db\ \(B[134]\)[t] + Db\ \(B[141]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[128]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[128]\)[t] + Db\ \(B[104]\)[t] + 
                Db\ \(B[124]\)[t] - 4\ Db\ \(B[128]\)[t] - 
                c\ \(A[128]\)[t]\^2\ \(B[128]\)[t] + Db\ \(B[130]\)[t] + 
                Db\ \(B[140]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[129]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[129]\)[t] + Db\ \(B[102]\)[t] + 
                Db\ \(B[109]\)[t] + Db\ \(B[110]\)[t] + Db\ \(B[112]\)[t] - 
                7\ Db\ \(B[129]\)[t] - c\ \(A[129]\)[t]\^2\ \(B[129]\)[t] + 
                Db\ \(B[131]\)[t] + Db\ \(B[133]\)[t] + Db\ \(B[144]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[130]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[130]\)[t] + Db\ \(B[104]\)[t] + 
                Db\ \(B[115]\)[t] + Db\ \(B[128]\)[t] - 
                7\ Db\ \(B[130]\)[t] - c\ \(A[130]\)[t]\^2\ \(B[130]\)[t] + 
                Db\ \(B[140]\)[t] + Db\ \(B[142]\)[t] + Db\ \(B[146]\)[t] + 
                Db\ \(B[156]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[131]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[131]\)[t] + Db\ \(B[101]\)[t] + 
                Db\ \(B[109]\)[t] + Db\ \(B[119]\)[t] + Db\ \(B[129]\)[t] - 
                9\ Db\ \(B[131]\)[t] - c\ \(A[131]\)[t]\^2\ \(B[131]\)[t] + 
                Db\ \(B[133]\)[t] + Db\ \(B[135]\)[t] + Db\ \(B[147]\)[t] + 
                Db\ \(B[148]\)[t] + Db\ \(B[158]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[132]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[132]\)[t] + Db\ \(B[100]\)[t] + 
                Db\ \(B[114]\)[t] + Db\ \(B[123]\)[t] - 
                6\ Db\ \(B[132]\)[t] - c\ \(A[132]\)[t]\^2\ \(B[132]\)[t] + 
                Db\ \(B[141]\)[t] + Db\ \(B[145]\)[t] + Db\ \(B[164]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[133]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[133]\)[t] + Db\ \(B[129]\)[t] + 
                Db\ \(B[131]\)[t] - 4\ Db\ \(B[133]\)[t] - 
                c\ \(A[133]\)[t]\^2\ \(B[133]\)[t] + Db\ \(B[144]\)[t] + 
                Db\ \(B[148]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[134]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[134]\)[t] + Db\ \(B[113]\)[t] + 
                Db\ \(B[127]\)[t] - 5\ Db\ \(B[134]\)[t] - 
                c\ \(A[134]\)[t]\^2\ \(B[134]\)[t] + Db\ \(B[141]\)[t] + 
                Db\ \(B[152]\)[t] + Db\ \(B[153]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[135]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[135]\)[t] + Db\ \(B[118]\)[t] + 
                Db\ \(B[119]\)[t] + Db\ \(B[125]\)[t] + Db\ \(B[131]\)[t] - 
                6\ Db\ \(B[135]\)[t] - c\ \(A[135]\)[t]\^2\ \(B[135]\)[t] + 
                Db\ \(B[147]\)[t] + Db\ \(B[155]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[136]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[136]\)[t] + Db\ \(B[103]\)[t] + 
                Db\ \(B[111]\)[t] + Db\ \(B[121]\)[t] - 
                7\ Db\ \(B[136]\)[t] - c\ \(A[136]\)[t]\^2\ \(B[136]\)[t] + 
                Db\ \(B[137]\)[t] + Db\ \(B[139]\)[t] + Db\ \(B[157]\)[t] + 
                Db\ \(B[159]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[137]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[137]\)[t] + Db\ \(B[103]\)[t] + 
                Db\ \(B[107]\)[t] + Db\ \(B[122]\)[t] + Db\ \(B[136]\)[t] - 
                7\ Db\ \(B[137]\)[t] - c\ \(A[137]\)[t]\^2\ \(B[137]\)[t] + 
                Db\ \(B[150]\)[t] + Db\ \(B[159]\)[t] + Db\ \(B[171]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[138]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[138]\)[t] + Db\ \(B[121]\)[t] + 
                Db\ \(B[126]\)[t] - 7\ Db\ \(B[138]\)[t] - 
                c\ \(A[138]\)[t]\^2\ \(B[138]\)[t] + Db\ \(B[139]\)[t] + 
                Db\ \(B[149]\)[t] + Db\ \(B[157]\)[t] + Db\ \(B[163]\)[t] + 
                Db\ \(B[170]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[139]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[139]\)[t] + Db\ \(B[121]\)[t] + 
                Db\ \(B[136]\)[t] + Db\ \(B[138]\)[t] - 
                4\ Db\ \(B[139]\)[t] - c\ \(A[139]\)[t]\^2\ \(B[139]\)[t] + 
                Db\ \(B[157]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[140]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[140]\)[t] + Db\ \(B[124]\)[t] + 
                Db\ \(B[128]\)[t] + Db\ \(B[130]\)[t] - 
                5\ Db\ \(B[140]\)[t] - c\ \(A[140]\)[t]\^2\ \(B[140]\)[t] + 
                Db\ \(B[145]\)[t] + Db\ \(B[156]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[141]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[141]\)[t] + Db\ \(B[123]\)[t] + 
                Db\ \(B[127]\)[t] + Db\ \(B[132]\)[t] + Db\ \(B[134]\)[t] - 
                6\ Db\ \(B[141]\)[t] - c\ \(A[141]\)[t]\^2\ \(B[141]\)[t] + 
                Db\ \(B[153]\)[t] + Db\ \(B[164]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[142]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[142]\)[t] + Db\ \(B[115]\)[t] + 
                Db\ \(B[130]\)[t] - 5\ Db\ \(B[142]\)[t] - 
                c\ \(A[142]\)[t]\^2\ \(B[142]\)[t] + Db\ \(B[143]\)[t] + 
                Db\ \(B[146]\)[t] + Db\ \(B[151]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[143]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[143]\)[t] + Db\ \(B[116]\)[t] + 
                Db\ \(B[117]\)[t] + Db\ \(B[142]\)[t] - 
                5\ Db\ \(B[143]\)[t] - c\ \(A[143]\)[t]\^2\ \(B[143]\)[t] + 
                Db\ \(B[151]\)[t] + Db\ \(B[154]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[144]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[144]\)[t] + Db\ \(B[112]\)[t] + 
                Db\ \(B[129]\)[t] + Db\ \(B[133]\)[t] - 
                7\ Db\ \(B[144]\)[t] - c\ \(A[144]\)[t]\^2\ \(B[144]\)[t] + 
                Db\ \(B[148]\)[t] + Db\ \(B[149]\)[t] + Db\ \(B[165]\)[t] + 
                Db\ \(B[169]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[145]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[145]\)[t] + Db\ \(B[114]\)[t] + 
                Db\ \(B[124]\)[t] + Db\ \(B[132]\)[t] + Db\ \(B[140]\)[t] - 
                8\ Db\ \(B[145]\)[t] - c\ \(A[145]\)[t]\^2\ \(B[145]\)[t] + 
                Db\ \(B[156]\)[t] + Db\ \(B[160]\)[t] + Db\ \(B[164]\)[t] + 
                Db\ \(B[188]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[146]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[146]\)[t] + Db\ \(B[130]\)[t] + 
                Db\ \(B[142]\)[t] - 5\ Db\ \(B[146]\)[t] - 
                c\ \(A[146]\)[t]\^2\ \(B[146]\)[t] + Db\ \(B[151]\)[t] + 
                Db\ \(B[156]\)[t] + Db\ \(B[161]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[147]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[147]\)[t] + Db\ \(B[131]\)[t] + 
                Db\ \(B[135]\)[t] - 5\ Db\ \(B[147]\)[t] - 
                c\ \(A[147]\)[t]\^2\ \(B[147]\)[t] + Db\ \(B[155]\)[t] + 
                Db\ \(B[158]\)[t] + Db\ \(B[167]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[148]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[148]\)[t] + Db\ \(B[131]\)[t] + 
                Db\ \(B[133]\)[t] + Db\ \(B[144]\)[t] - 
                6\ Db\ \(B[148]\)[t] - c\ \(A[148]\)[t]\^2\ \(B[148]\)[t] + 
                Db\ \(B[158]\)[t] + Db\ \(B[168]\)[t] + Db\ \(B[169]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[149]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[149]\)[t] + Db\ \(B[112]\)[t] + 
                Db\ \(B[120]\)[t] + Db\ \(B[126]\)[t] + Db\ \(B[138]\)[t] + 
                Db\ \(B[144]\)[t] - 7\ Db\ \(B[149]\)[t] - 
                c\ \(A[149]\)[t]\^2\ \(B[149]\)[t] + Db\ \(B[163]\)[t] + 
                Db\ \(B[165]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[150]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[150]\)[t] + Db\ \(B[122]\)[t] + 
                Db\ \(B[137]\)[t] - 3\ Db\ \(B[150]\)[t] - 
                c\ \(A[150]\)[t]\^2\ \(B[150]\)[t] + Db\ \(B[171]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[151]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[151]\)[t] + Db\ \(B[142]\)[t] + 
                Db\ \(B[143]\)[t] + Db\ \(B[146]\)[t] - 
                7\ Db\ \(B[151]\)[t] - c\ \(A[151]\)[t]\^2\ \(B[151]\)[t] + 
                Db\ \(B[154]\)[t] + Db\ \(B[161]\)[t] + Db\ \(B[166]\)[t] + 
                Db\ \(B[175]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[152]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[152]\)[t] + Db\ \(B[134]\)[t] - 
                4\ Db\ \(B[152]\)[t] - c\ \(A[152]\)[t]\^2\ \(B[152]\)[t] + 
                Db\ \(B[153]\)[t] + Db\ \(B[172]\)[t] + Db\ \(B[178]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[153]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[153]\)[t] + Db\ \(B[134]\)[t] + 
                Db\ \(B[141]\)[t] + Db\ \(B[152]\)[t] - 
                6\ Db\ \(B[153]\)[t] - c\ \(A[153]\)[t]\^2\ \(B[153]\)[t] + 
                Db\ \(B[164]\)[t] + Db\ \(B[172]\)[t] + Db\ \(B[176]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[154]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[154]\)[t] + Db\ \(B[117]\)[t] + 
                Db\ \(B[125]\)[t] + Db\ \(B[143]\)[t] + Db\ \(B[151]\)[t] - 
                6\ Db\ \(B[154]\)[t] - c\ \(A[154]\)[t]\^2\ \(B[154]\)[t] + 
                Db\ \(B[162]\)[t] + Db\ \(B[166]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[155]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[155]\)[t] + Db\ \(B[125]\)[t] + 
                Db\ \(B[135]\)[t] + Db\ \(B[147]\)[t] - 
                6\ Db\ \(B[155]\)[t] - c\ \(A[155]\)[t]\^2\ \(B[155]\)[t] + 
                Db\ \(B[162]\)[t] + Db\ \(B[167]\)[t] + Db\ \(B[173]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[156]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[156]\)[t] + Db\ \(B[130]\)[t] + 
                Db\ \(B[140]\)[t] + Db\ \(B[145]\)[t] + Db\ \(B[146]\)[t] - 
                6\ Db\ \(B[156]\)[t] - c\ \(A[156]\)[t]\^2\ \(B[156]\)[t] + 
                Db\ \(B[160]\)[t] + Db\ \(B[161]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[157]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[157]\)[t] + Db\ \(B[136]\)[t] + 
                Db\ \(B[138]\)[t] + Db\ \(B[139]\)[t] - 
                5\ Db\ \(B[157]\)[t] - c\ \(A[157]\)[t]\^2\ \(B[157]\)[t] + 
                Db\ \(B[159]\)[t] + Db\ \(B[170]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[158]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[158]\)[t] + Db\ \(B[131]\)[t] + 
                Db\ \(B[147]\)[t] + Db\ \(B[148]\)[t] - 
                6\ Db\ \(B[158]\)[t] - c\ \(A[158]\)[t]\^2\ \(B[158]\)[t] + 
                Db\ \(B[167]\)[t] + Db\ \(B[168]\)[t] + Db\ \(B[179]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[159]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[159]\)[t] + Db\ \(B[136]\)[t] + 
                Db\ \(B[137]\)[t] + Db\ \(B[157]\)[t] - 
                7\ Db\ \(B[159]\)[t] - c\ \(A[159]\)[t]\^2\ \(B[159]\)[t] + 
                Db\ \(B[170]\)[t] + Db\ \(B[171]\)[t] + Db\ \(B[181]\)[t] + 
                Db\ \(B[182]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[160]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[160]\)[t] + Db\ \(B[145]\)[t] + 
                Db\ \(B[156]\)[t] - 5\ Db\ \(B[160]\)[t] - 
                c\ \(A[160]\)[t]\^2\ \(B[160]\)[t] + Db\ \(B[161]\)[t] + 
                Db\ \(B[186]\)[t] + Db\ \(B[188]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[161]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[161]\)[t] + Db\ \(B[146]\)[t] + 
                Db\ \(B[151]\)[t] + Db\ \(B[156]\)[t] + Db\ \(B[160]\)[t] - 
                7\ Db\ \(B[161]\)[t] - c\ \(A[161]\)[t]\^2\ \(B[161]\)[t] + 
                Db\ \(B[175]\)[t] + Db\ \(B[186]\)[t] + Db\ \(B[190]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[162]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[162]\)[t] + Db\ \(B[125]\)[t] + 
                Db\ \(B[154]\)[t] + Db\ \(B[155]\)[t] - 
                7\ Db\ \(B[162]\)[t] - c\ \(A[162]\)[t]\^2\ \(B[162]\)[t] + 
                Db\ \(B[166]\)[t] + Db\ \(B[173]\)[t] + Db\ \(B[183]\)[t] + 
                Db\ \(B[184]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[163]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[163]\)[t] + Db\ \(B[138]\)[t] + 
                Db\ \(B[149]\)[t] - 5\ Db\ \(B[163]\)[t] - 
                c\ \(A[163]\)[t]\^2\ \(B[163]\)[t] + Db\ \(B[165]\)[t] + 
                Db\ \(B[170]\)[t] + Db\ \(B[180]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[164]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[164]\)[t] + Db\ \(B[132]\)[t] + 
                Db\ \(B[141]\)[t] + Db\ \(B[145]\)[t] + Db\ \(B[153]\)[t] - 
                7\ Db\ \(B[164]\)[t] - c\ \(A[164]\)[t]\^2\ \(B[164]\)[t] + 
                Db\ \(B[176]\)[t] + Db\ \(B[188]\)[t] + Db\ \(B[201]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[165]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[165]\)[t] + Db\ \(B[144]\)[t] + 
                Db\ \(B[149]\)[t] + Db\ \(B[163]\)[t] - 
                6\ Db\ \(B[165]\)[t] - c\ \(A[165]\)[t]\^2\ \(B[165]\)[t] + 
                Db\ \(B[169]\)[t] + Db\ \(B[177]\)[t] + Db\ \(B[180]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[166]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[166]\)[t] + Db\ \(B[151]\)[t] + 
                Db\ \(B[154]\)[t] + Db\ \(B[162]\)[t] - 
                5\ Db\ \(B[166]\)[t] - c\ \(A[166]\)[t]\^2\ \(B[166]\)[t] + 
                Db\ \(B[175]\)[t] + Db\ \(B[183]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[167]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[167]\)[t] + Db\ \(B[147]\)[t] + 
                Db\ \(B[155]\)[t] + Db\ \(B[158]\)[t] - 
                6\ Db\ \(B[167]\)[t] - c\ \(A[167]\)[t]\^2\ \(B[167]\)[t] + 
                Db\ \(B[173]\)[t] + Db\ \(B[174]\)[t] + Db\ \(B[179]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[168]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[168]\)[t] + Db\ \(B[148]\)[t] + 
                Db\ \(B[158]\)[t] - 4\ Db\ \(B[168]\)[t] - 
                c\ \(A[168]\)[t]\^2\ \(B[168]\)[t] + Db\ \(B[169]\)[t] + 
                Db\ \(B[179]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[169]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[169]\)[t] + Db\ \(B[144]\)[t] + 
                Db\ \(B[148]\)[t] + Db\ \(B[165]\)[t] + Db\ \(B[168]\)[t] - 
                8\ Db\ \(B[169]\)[t] - c\ \(A[169]\)[t]\^2\ \(B[169]\)[t] + 
                Db\ \(B[177]\)[t] + Db\ \(B[179]\)[t] + Db\ \(B[192]\)[t] + 
                Db\ \(B[193]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[170]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[170]\)[t] + Db\ \(B[138]\)[t] + 
                Db\ \(B[157]\)[t] + Db\ \(B[159]\)[t] + Db\ \(B[163]\)[t] - 
                6\ Db\ \(B[170]\)[t] - c\ \(A[170]\)[t]\^2\ \(B[170]\)[t] + 
                Db\ \(B[180]\)[t] + Db\ \(B[181]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[171]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[171]\)[t] + Db\ \(B[137]\)[t] + 
                Db\ \(B[150]\)[t] + Db\ \(B[159]\)[t] - 
                4\ Db\ \(B[171]\)[t] - c\ \(A[171]\)[t]\^2\ \(B[171]\)[t] + 
                Db\ \(B[182]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[172]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[172]\)[t] + Db\ \(B[152]\)[t] + 
                Db\ \(B[153]\)[t] - 5\ Db\ \(B[172]\)[t] - 
                c\ \(A[172]\)[t]\^2\ \(B[172]\)[t] + Db\ \(B[176]\)[t] + 
                Db\ \(B[178]\)[t] + Db\ \(B[185]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[173]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[173]\)[t] + Db\ \(B[155]\)[t] + 
                Db\ \(B[162]\)[t] + Db\ \(B[167]\)[t] - 
                6\ Db\ \(B[173]\)[t] - c\ \(A[173]\)[t]\^2\ \(B[173]\)[t] + 
                Db\ \(B[174]\)[t] + Db\ \(B[184]\)[t] + Db\ \(B[189]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[174]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[174]\)[t] + Db\ \(B[167]\)[t] + 
                Db\ \(B[173]\)[t] - 5\ Db\ \(B[174]\)[t] - 
                c\ \(A[174]\)[t]\^2\ \(B[174]\)[t] + Db\ \(B[179]\)[t] + 
                Db\ \(B[187]\)[t] + Db\ \(B[189]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[175]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[175]\)[t] + Db\ \(B[151]\)[t] + 
                Db\ \(B[161]\)[t] + Db\ \(B[166]\)[t] - 
                6\ Db\ \(B[175]\)[t] - c\ \(A[175]\)[t]\^2\ \(B[175]\)[t] + 
                Db\ \(B[183]\)[t] + Db\ \(B[190]\)[t] + Db\ \(B[199]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[176]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[176]\)[t] + Db\ \(B[153]\)[t] + 
                Db\ \(B[164]\)[t] + Db\ \(B[172]\)[t] - 
                6\ Db\ \(B[176]\)[t] - c\ \(A[176]\)[t]\^2\ \(B[176]\)[t] + 
                Db\ \(B[185]\)[t] + Db\ \(B[197]\)[t] + Db\ \(B[201]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[177]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[177]\)[t] + Db\ \(B[165]\)[t] + 
                Db\ \(B[169]\)[t] - 5\ Db\ \(B[177]\)[t] - 
                c\ \(A[177]\)[t]\^2\ \(B[177]\)[t] + Db\ \(B[180]\)[t] + 
                Db\ \(B[193]\)[t] + Db\ \(B[194]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[178]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[178]\)[t] + Db\ \(B[152]\)[t] + 
                Db\ \(B[172]\)[t] - 4\ Db\ \(B[178]\)[t] - 
                c\ \(A[178]\)[t]\^2\ \(B[178]\)[t] + Db\ \(B[185]\)[t] + 
                Db\ \(B[203]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[179]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[179]\)[t] + Db\ \(B[158]\)[t] + 
                Db\ \(B[167]\)[t] + Db\ \(B[168]\)[t] + Db\ \(B[169]\)[t] + 
                Db\ \(B[174]\)[t] - 8\ Db\ \(B[179]\)[t] - 
                c\ \(A[179]\)[t]\^2\ \(B[179]\)[t] + Db\ \(B[187]\)[t] + 
                Db\ \(B[191]\)[t] + Db\ \(B[192]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[180]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[180]\)[t] + Db\ \(B[163]\)[t] + 
                Db\ \(B[165]\)[t] + Db\ \(B[170]\)[t] + Db\ \(B[177]\)[t] - 
                8\ Db\ \(B[180]\)[t] - c\ \(A[180]\)[t]\^2\ \(B[180]\)[t] + 
                Db\ \(B[181]\)[t] + Db\ \(B[194]\)[t] + Db\ \(B[196]\)[t] + 
                Db\ \(B[204]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[181]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[181]\)[t] + Db\ \(B[159]\)[t] + 
                Db\ \(B[170]\)[t] + Db\ \(B[180]\)[t] - 
                6\ Db\ \(B[181]\)[t] - c\ \(A[181]\)[t]\^2\ \(B[181]\)[t] + 
                Db\ \(B[182]\)[t] + Db\ \(B[196]\)[t] + Db\ \(B[200]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[182]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[182]\)[t] + Db\ \(B[159]\)[t] + 
                Db\ \(B[171]\)[t] + Db\ \(B[181]\)[t] - 
                4\ Db\ \(B[182]\)[t] - c\ \(A[182]\)[t]\^2\ \(B[182]\)[t] + 
                Db\ \(B[200]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[183]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[183]\)[t] + Db\ \(B[162]\)[t] + 
                Db\ \(B[166]\)[t] + Db\ \(B[175]\)[t] - 
                6\ Db\ \(B[183]\)[t] - c\ \(A[183]\)[t]\^2\ \(B[183]\)[t] + 
                Db\ \(B[184]\)[t] + Db\ \(B[195]\)[t] + Db\ \(B[199]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[184]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[184]\)[t] + Db\ \(B[162]\)[t] + 
                Db\ \(B[173]\)[t] + Db\ \(B[183]\)[t] - 
                6\ Db\ \(B[184]\)[t] - c\ \(A[184]\)[t]\^2\ \(B[184]\)[t] + 
                Db\ \(B[189]\)[t] + Db\ \(B[195]\)[t] + Db\ \(B[202]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[185]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[185]\)[t] + Db\ \(B[172]\)[t] + 
                Db\ \(B[176]\)[t] + Db\ \(B[178]\)[t] - 
                6\ Db\ \(B[185]\)[t] - c\ \(A[185]\)[t]\^2\ \(B[185]\)[t] + 
                Db\ \(B[197]\)[t] + Db\ \(B[203]\)[t] + Db\ \(B[208]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[186]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[186]\)[t] + Db\ \(B[160]\)[t] + 
                Db\ \(B[161]\)[t] - 5\ Db\ \(B[186]\)[t] - 
                c\ \(A[186]\)[t]\^2\ \(B[186]\)[t] + Db\ \(B[188]\)[t] + 
                Db\ \(B[190]\)[t] + Db\ \(B[198]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[187]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[187]\)[t] + Db\ \(B[174]\)[t] + 
                Db\ \(B[179]\)[t] - 5\ Db\ \(B[187]\)[t] - 
                c\ \(A[187]\)[t]\^2\ \(B[187]\)[t] + Db\ \(B[189]\)[t] + 
                Db\ \(B[191]\)[t] + Db\ \(B[205]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[188]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[188]\)[t] + Db\ \(B[145]\)[t] + 
                Db\ \(B[160]\)[t] + Db\ \(B[164]\)[t] + Db\ \(B[186]\)[t] - 
                7\ Db\ \(B[188]\)[t] - c\ \(A[188]\)[t]\^2\ \(B[188]\)[t] + 
                Db\ \(B[198]\)[t] + Db\ \(B[201]\)[t] + Db\ \(B[218]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[189]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[189]\)[t] + Db\ \(B[173]\)[t] + 
                Db\ \(B[174]\)[t] + Db\ \(B[184]\)[t] + Db\ \(B[187]\)[t] - 
                6\ Db\ \(B[189]\)[t] - c\ \(A[189]\)[t]\^2\ \(B[189]\)[t] + 
                Db\ \(B[202]\)[t] + Db\ \(B[205]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[190]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[190]\)[t] + Db\ \(B[161]\)[t] + 
                Db\ \(B[175]\)[t] + Db\ \(B[186]\)[t] - 
                7\ Db\ \(B[190]\)[t] - c\ \(A[190]\)[t]\^2\ \(B[190]\)[t] + 
                Db\ \(B[198]\)[t] + Db\ \(B[199]\)[t] + Db\ \(B[207]\)[t] + 
                Db\ \(B[215]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[191]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[191]\)[t] + Db\ \(B[179]\)[t] + 
                Db\ \(B[187]\)[t] - 6\ Db\ \(B[191]\)[t] - 
                c\ \(A[191]\)[t]\^2\ \(B[191]\)[t] + Db\ \(B[192]\)[t] + 
                Db\ \(B[205]\)[t] + Db\ \(B[206]\)[t] + Db\ \(B[216]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[192]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[192]\)[t] + Db\ \(B[169]\)[t] + 
                Db\ \(B[179]\)[t] + Db\ \(B[191]\)[t] - 
                5\ Db\ \(B[192]\)[t] - c\ \(A[192]\)[t]\^2\ \(B[192]\)[t] + 
                Db\ \(B[193]\)[t] + Db\ \(B[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[193]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[193]\)[t] + Db\ \(B[169]\)[t] + 
                Db\ \(B[177]\)[t] + Db\ \(B[192]\)[t] - 
                5\ Db\ \(B[193]\)[t] - c\ \(A[193]\)[t]\^2\ \(B[193]\)[t] + 
                Db\ \(B[194]\)[t] + Db\ \(B[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[194]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[194]\)[t] + Db\ \(B[177]\)[t] + 
                Db\ \(B[180]\)[t] + Db\ \(B[193]\)[t] - 
                5\ Db\ \(B[194]\)[t] - c\ \(A[194]\)[t]\^2\ \(B[194]\)[t] + 
                Db\ \(B[204]\)[t] + Db\ \(B[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[195]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[195]\)[t] + Db\ \(B[183]\)[t] + 
                Db\ \(B[184]\)[t] - 6\ Db\ \(B[195]\)[t] - 
                c\ \(A[195]\)[t]\^2\ \(B[195]\)[t] + Db\ \(B[199]\)[t] + 
                Db\ \(B[202]\)[t] + Db\ \(B[213]\)[t] + Db\ \(B[222]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[196]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[196]\)[t] + Db\ \(B[180]\)[t] + 
                Db\ \(B[181]\)[t] - 6\ Db\ \(B[196]\)[t] - 
                c\ \(A[196]\)[t]\^2\ \(B[196]\)[t] + Db\ \(B[200]\)[t] + 
                Db\ \(B[204]\)[t] + Db\ \(B[211]\)[t] + Db\ \(B[214]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[197]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[197]\)[t] + Db\ \(B[176]\)[t] + 
                Db\ \(B[185]\)[t] - 5\ Db\ \(B[197]\)[t] - 
                c\ \(A[197]\)[t]\^2\ \(B[197]\)[t] + Db\ \(B[201]\)[t] + 
                Db\ \(B[208]\)[t] + Db\ \(B[209]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[198]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[198]\)[t] + Db\ \(B[186]\)[t] + 
                Db\ \(B[188]\)[t] + Db\ \(B[190]\)[t] - 
                5\ Db\ \(B[198]\)[t] - c\ \(A[198]\)[t]\^2\ \(B[198]\)[t] + 
                Db\ \(B[215]\)[t] + Db\ \(B[218]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[199]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[199]\)[t] + Db\ \(B[175]\)[t] + 
                Db\ \(B[183]\)[t] + Db\ \(B[190]\)[t] + Db\ \(B[195]\)[t] - 
                7\ Db\ \(B[199]\)[t] - c\ \(A[199]\)[t]\^2\ \(B[199]\)[t] + 
                Db\ \(B[207]\)[t] + Db\ \(B[212]\)[t] + Db\ \(B[222]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[200]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[200]\)[t] + Db\ \(B[181]\)[t] + 
                Db\ \(B[182]\)[t] + Db\ \(B[196]\)[t] - 
                4\ Db\ \(B[200]\)[t] - c\ \(A[200]\)[t]\^2\ \(B[200]\)[t] + 
                Db\ \(B[211]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[201]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[201]\)[t] + Db\ \(B[164]\)[t] + 
                Db\ \(B[176]\)[t] + Db\ \(B[188]\)[t] + Db\ \(B[197]\)[t] - 
                7\ Db\ \(B[201]\)[t] - c\ \(A[201]\)[t]\^2\ \(B[201]\)[t] + 
                Db\ \(B[209]\)[t] + Db\ \(B[218]\)[t] + Db\ \(B[220]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[202]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[202]\)[t] + Db\ \(B[184]\)[t] + 
                Db\ \(B[189]\)[t] + Db\ \(B[195]\)[t] - 
                6\ Db\ \(B[202]\)[t] - c\ \(A[202]\)[t]\^2\ \(B[202]\)[t] + 
                Db\ \(B[205]\)[t] + Db\ \(B[210]\)[t] + Db\ \(B[213]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[203]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[203]\)[t] + Db\ \(B[178]\)[t] + 
                Db\ \(B[185]\)[t] - 4\ Db\ \(B[203]\)[t] - 
                c\ \(A[203]\)[t]\^2\ \(B[203]\)[t] + Db\ \(B[208]\)[t] + 
                Db\ \(B[219]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[204]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[204]\)[t] + Db\ \(B[180]\)[t] + 
                Db\ \(B[194]\)[t] + Db\ \(B[196]\)[t] - 
                6\ Db\ \(B[204]\)[t] - c\ \(A[204]\)[t]\^2\ \(B[204]\)[t] + 
                Db\ \(B[206]\)[t] + Db\ \(B[214]\)[t] + Db\ \(B[217]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[205]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[205]\)[t] + Db\ \(B[187]\)[t] + 
                Db\ \(B[189]\)[t] + Db\ \(B[191]\)[t] + Db\ \(B[202]\)[t] - 
                7\ Db\ \(B[205]\)[t] - c\ \(A[205]\)[t]\^2\ \(B[205]\)[t] + 
                Db\ \(B[210]\)[t] + Db\ \(B[216]\)[t] + Db\ \(B[225]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[206]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[206]\)[t] + Db\ \(B[191]\)[t] + 
                Db\ \(B[192]\)[t] + Db\ \(B[193]\)[t] + Db\ \(B[194]\)[t] + 
                Db\ \(B[204]\)[t] - 8\ Db\ \(B[206]\)[t] - 
                c\ \(A[206]\)[t]\^2\ \(B[206]\)[t] + Db\ \(B[216]\)[t] + 
                Db\ \(B[217]\)[t] + Db\ \(B[221]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[207]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[207]\)[t] + Db\ \(B[190]\)[t] + 
                Db\ \(B[199]\)[t] - 4\ Db\ \(B[207]\)[t] - 
                c\ \(A[207]\)[t]\^2\ \(B[207]\)[t] + Db\ \(B[212]\)[t] + 
                Db\ \(B[215]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[208]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[208]\)[t] + Db\ \(B[185]\)[t] + 
                Db\ \(B[197]\)[t] + Db\ \(B[203]\)[t] - 
                6\ Db\ \(B[208]\)[t] - c\ \(A[208]\)[t]\^2\ \(B[208]\)[t] + 
                Db\ \(B[209]\)[t] + Db\ \(B[219]\)[t] + Db\ \(B[226]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[209]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[209]\)[t] + Db\ \(B[197]\)[t] + 
                Db\ \(B[201]\)[t] + Db\ \(B[208]\)[t] - 
                6\ Db\ \(B[209]\)[t] - c\ \(A[209]\)[t]\^2\ \(B[209]\)[t] + 
                Db\ \(B[220]\)[t] + Db\ \(B[226]\)[t] + Db\ \(B[227]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[210]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[210]\)[t] + Db\ \(B[202]\)[t] + 
                Db\ \(B[205]\)[t] - 5\ Db\ \(B[210]\)[t] - 
                c\ \(A[210]\)[t]\^2\ \(B[210]\)[t] + Db\ \(B[213]\)[t] + 
                Db\ \(B[224]\)[t] + Db\ \(B[225]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[211]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[211]\)[t] + Db\ \(B[196]\)[t] + 
                Db\ \(B[200]\)[t] - 3\ Db\ \(B[211]\)[t] - 
                c\ \(A[211]\)[t]\^2\ \(B[211]\)[t] + Db\ \(B[214]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[212]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[212]\)[t] + Db\ \(B[199]\)[t] + 
                Db\ \(B[207]\)[t] - 6\ Db\ \(B[212]\)[t] - 
                c\ \(A[212]\)[t]\^2\ \(B[212]\)[t] + Db\ \(B[215]\)[t] + 
                Db\ \(B[222]\)[t] + Db\ \(B[223]\)[t] + Db\ \(B[230]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[213]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[213]\)[t] + Db\ \(B[195]\)[t] + 
                Db\ \(B[202]\)[t] + Db\ \(B[210]\)[t] - 
                5\ Db\ \(B[213]\)[t] - c\ \(A[213]\)[t]\^2\ \(B[213]\)[t] + 
                Db\ \(B[222]\)[t] + Db\ \(B[224]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[214]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[214]\)[t] + Db\ \(B[196]\)[t] + 
                Db\ \(B[204]\)[t] + Db\ \(B[211]\)[t] - 
                4\ Db\ \(B[214]\)[t] - c\ \(A[214]\)[t]\^2\ \(B[214]\)[t] + 
                Db\ \(B[217]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[215]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[215]\)[t] + Db\ \(B[190]\)[t] + 
                Db\ \(B[198]\)[t] + Db\ \(B[207]\)[t] + Db\ \(B[212]\)[t] - 
                10\ Db\ \(B[215]\)[t] - c\ \(A[215]\)[t]\^2\ \(B[215]\)[t] + 
                Db\ \(B[218]\)[t] + Db\ \(B[228]\)[t] + Db\ \(B[230]\)[t] + 
                Db\ \(B[232]\)[t] + Db\ \(B[233]\)[t] + Db\ \(B[235]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[216]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[216]\)[t] + Db\ \(B[191]\)[t] + 
                Db\ \(B[205]\)[t] + Db\ \(B[206]\)[t] - 
                6\ Db\ \(B[216]\)[t] - c\ \(A[216]\)[t]\^2\ \(B[216]\)[t] + 
                Db\ \(B[221]\)[t] + Db\ \(B[225]\)[t] + Db\ \(B[234]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[217]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[217]\)[t] + Db\ \(B[204]\)[t] + 
                Db\ \(B[206]\)[t] + Db\ \(B[214]\)[t] - 
                4\ Db\ \(B[217]\)[t] - c\ \(A[217]\)[t]\^2\ \(B[217]\)[t] + 
                Db\ \(B[221]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[218]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[218]\)[t] + Db\ \(B[188]\)[t] + 
                Db\ \(B[198]\)[t] + Db\ \(B[201]\)[t] + Db\ \(B[215]\)[t] - 
                7\ Db\ \(B[218]\)[t] - c\ \(A[218]\)[t]\^2\ \(B[218]\)[t] + 
                Db\ \(B[220]\)[t] + Db\ \(B[228]\)[t] + Db\ \(B[229]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[219]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[219]\)[t] + Db\ \(B[203]\)[t] + 
                Db\ \(B[208]\)[t] - 4\ Db\ \(B[219]\)[t] - 
                c\ \(A[219]\)[t]\^2\ \(B[219]\)[t] + Db\ \(B[226]\)[t] + 
                Db\ \(B[237]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[220]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[220]\)[t] + Db\ \(B[201]\)[t] + 
                Db\ \(B[209]\)[t] + Db\ \(B[218]\)[t] - 
                5\ Db\ \(B[220]\)[t] - c\ \(A[220]\)[t]\^2\ \(B[220]\)[t] + 
                Db\ \(B[227]\)[t] + Db\ \(B[229]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[221]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[221]\)[t] + Db\ \(B[206]\)[t] + 
                Db\ \(B[216]\)[t] + Db\ \(B[217]\)[t] - 
                3\ Db\ \(B[221]\)[t] - c\ \(A[221]\)[t]\^2\ \(B[221]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[222]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[222]\)[t] + Db\ \(B[195]\)[t] + 
                Db\ \(B[199]\)[t] + Db\ \(B[212]\)[t] + Db\ \(B[213]\)[t] - 
                7\ Db\ \(B[222]\)[t] - c\ \(A[222]\)[t]\^2\ \(B[222]\)[t] + 
                Db\ \(B[223]\)[t] + Db\ \(B[224]\)[t] + Db\ \(B[231]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[223]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[223]\)[t] + Db\ \(B[212]\)[t] + 
                Db\ \(B[222]\)[t] - 6\ Db\ \(B[223]\)[t] - 
                c\ \(A[223]\)[t]\^2\ \(B[223]\)[t] + Db\ \(B[230]\)[t] + 
                Db\ \(B[231]\)[t] + Db\ \(B[236]\)[t] + Db\ \(B[238]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[224]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[224]\)[t] + Db\ \(B[210]\)[t] + 
                Db\ \(B[213]\)[t] + Db\ \(B[222]\)[t] - 
                5\ Db\ \(B[224]\)[t] - c\ \(A[224]\)[t]\^2\ \(B[224]\)[t] + 
                Db\ \(B[225]\)[t] + Db\ \(B[231]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[225]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[225]\)[t] + Db\ \(B[205]\)[t] + 
                Db\ \(B[210]\)[t] + Db\ \(B[216]\)[t] + Db\ \(B[224]\)[t] - 
                6\ Db\ \(B[225]\)[t] - c\ \(A[225]\)[t]\^2\ \(B[225]\)[t] + 
                Db\ \(B[231]\)[t] + Db\ \(B[234]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[226]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[226]\)[t] + Db\ \(B[208]\)[t] + 
                Db\ \(B[209]\)[t] + Db\ \(B[219]\)[t] - 
                6\ Db\ \(B[226]\)[t] - c\ \(A[226]\)[t]\^2\ \(B[226]\)[t] + 
                Db\ \(B[227]\)[t] + Db\ \(B[237]\)[t] + Db\ \(B[239]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[227]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[227]\)[t] + Db\ \(B[209]\)[t] + 
                Db\ \(B[220]\)[t] + Db\ \(B[226]\)[t] - 
                5\ Db\ \(B[227]\)[t] - c\ \(A[227]\)[t]\^2\ \(B[227]\)[t] + 
                Db\ \(B[229]\)[t] + Db\ \(B[239]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[228]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[228]\)[t] + Db\ \(B[215]\)[t] + 
                Db\ \(B[218]\)[t] - 5\ Db\ \(B[228]\)[t] - 
                c\ \(A[228]\)[t]\^2\ \(B[228]\)[t] + Db\ \(B[229]\)[t] + 
                Db\ \(B[235]\)[t] + Db\ \(B[240]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[229]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[229]\)[t] + Db\ \(B[218]\)[t] + 
                Db\ \(B[220]\)[t] + Db\ \(B[227]\)[t] + Db\ \(B[228]\)[t] - 
                7\ Db\ \(B[229]\)[t] - c\ \(A[229]\)[t]\^2\ \(B[229]\)[t] + 
                Db\ \(B[239]\)[t] + Db\ \(B[240]\)[t] + Db\ \(B[242]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[230]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[230]\)[t] + Db\ \(B[212]\)[t] + 
                Db\ \(B[215]\)[t] + Db\ \(B[223]\)[t] - 
                6\ Db\ \(B[230]\)[t] - c\ \(A[230]\)[t]\^2\ \(B[230]\)[t] + 
                Db\ \(B[232]\)[t] + Db\ \(B[236]\)[t] + Db\ \(B[245]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[231]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[231]\)[t] + Db\ \(B[222]\)[t] + 
                Db\ \(B[223]\)[t] + Db\ \(B[224]\)[t] + Db\ \(B[225]\)[t] - 
                7\ Db\ \(B[231]\)[t] - c\ \(A[231]\)[t]\^2\ \(B[231]\)[t] + 
                Db\ \(B[234]\)[t] + Db\ \(B[238]\)[t] + Db\ \(B[244]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[232]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[232]\)[t] + Db\ \(B[215]\)[t] + 
                Db\ \(B[230]\)[t] - 4\ Db\ \(B[232]\)[t] - 
                c\ \(A[232]\)[t]\^2\ \(B[232]\)[t] + Db\ \(B[233]\)[t] + 
                Db\ \(B[245]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[233]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[233]\)[t] + Db\ \(B[215]\)[t] + 
                Db\ \(B[232]\)[t] - 5\ Db\ \(B[233]\)[t] - 
                c\ \(A[233]\)[t]\^2\ \(B[233]\)[t] + Db\ \(B[235]\)[t] + 
                Db\ \(B[241]\)[t] + Db\ \(B[245]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[234]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[234]\)[t] + Db\ \(B[216]\)[t] + 
                Db\ \(B[225]\)[t] + Db\ \(B[231]\)[t] - 
                4\ Db\ \(B[234]\)[t] - c\ \(A[234]\)[t]\^2\ \(B[234]\)[t] + 
                Db\ \(B[244]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[235]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[235]\)[t] + Db\ \(B[215]\)[t] + 
                Db\ \(B[228]\)[t] + Db\ \(B[233]\)[t] - 
                6\ Db\ \(B[235]\)[t] - c\ \(A[235]\)[t]\^2\ \(B[235]\)[t] + 
                Db\ \(B[240]\)[t] + Db\ \(B[241]\)[t] + Db\ \(B[243]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[236]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[236]\)[t] + Db\ \(B[223]\)[t] + 
                Db\ \(B[230]\)[t] - 5\ Db\ \(B[236]\)[t] - 
                c\ \(A[236]\)[t]\^2\ \(B[236]\)[t] + Db\ \(B[238]\)[t] + 
                Db\ \(B[245]\)[t] + Db\ \(B[248]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[237]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[237]\)[t] + Db\ \(B[219]\)[t] + 
                Db\ \(B[226]\)[t] - 4\ Db\ \(B[237]\)[t] - 
                c\ \(A[237]\)[t]\^2\ \(B[237]\)[t] + Db\ \(B[239]\)[t] + 
                Db\ \(B[249]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[238]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[238]\)[t] + Db\ \(B[223]\)[t] + 
                Db\ \(B[231]\)[t] + Db\ \(B[236]\)[t] - 
                6\ Db\ \(B[238]\)[t] - c\ \(A[238]\)[t]\^2\ \(B[238]\)[t] + 
                Db\ \(B[244]\)[t] + Db\ \(B[246]\)[t] + Db\ \(B[248]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[239]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[239]\)[t] + Db\ \(B[226]\)[t] + 
                Db\ \(B[227]\)[t] + Db\ \(B[229]\)[t] + Db\ \(B[237]\)[t] - 
                7\ Db\ \(B[239]\)[t] - c\ \(A[239]\)[t]\^2\ \(B[239]\)[t] + 
                Db\ \(B[242]\)[t] + Db\ \(B[249]\)[t] + Db\ \(B[250]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[240]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[240]\)[t] + Db\ \(B[228]\)[t] + 
                Db\ \(B[229]\)[t] + Db\ \(B[235]\)[t] - 
                6\ Db\ \(B[240]\)[t] - c\ \(A[240]\)[t]\^2\ \(B[240]\)[t] + 
                Db\ \(B[242]\)[t] + Db\ \(B[243]\)[t] + Db\ \(B[247]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[241]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[241]\)[t] + Db\ \(B[233]\)[t] + 
                Db\ \(B[235]\)[t] - 7\ Db\ \(B[241]\)[t] - 
                c\ \(A[241]\)[t]\^2\ \(B[241]\)[t] + Db\ \(B[243]\)[t] + 
                Db\ \(B[245]\)[t] + Db\ \(B[247]\)[t] + Db\ \(B[251]\)[t] + 
                Db\ \(B[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[242]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[242]\)[t] + Db\ \(B[229]\)[t] + 
                Db\ \(B[239]\)[t] + Db\ \(B[240]\)[t] - 
                6\ Db\ \(B[242]\)[t] - c\ \(A[242]\)[t]\^2\ \(B[242]\)[t] + 
                Db\ \(B[247]\)[t] + Db\ \(B[250]\)[t] + Db\ \(B[252]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[243]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[243]\)[t] + Db\ \(B[235]\)[t] + 
                Db\ \(B[240]\)[t] + Db\ \(B[241]\)[t] - 
                4\ Db\ \(B[243]\)[t] - c\ \(A[243]\)[t]\^2\ \(B[243]\)[t] + 
                Db\ \(B[247]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[244]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[244]\)[t] + Db\ \(B[231]\)[t] + 
                Db\ \(B[234]\)[t] + Db\ \(B[238]\)[t] - 
                4\ Db\ \(B[244]\)[t] - c\ \(A[244]\)[t]\^2\ \(B[244]\)[t] + 
                Db\ \(B[246]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[245]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[245]\)[t] + Db\ \(B[230]\)[t] + 
                Db\ \(B[232]\)[t] + Db\ \(B[233]\)[t] + Db\ \(B[236]\)[t] + 
                Db\ \(B[241]\)[t] - 7\ Db\ \(B[245]\)[t] - 
                c\ \(A[245]\)[t]\^2\ \(B[245]\)[t] + Db\ \(B[248]\)[t] + 
                Db\ \(B[251]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[246]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[246]\)[t] + Db\ \(B[238]\)[t] + 
                Db\ \(B[244]\)[t] - 3\ Db\ \(B[246]\)[t] - 
                c\ \(A[246]\)[t]\^2\ \(B[246]\)[t] + Db\ \(B[248]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[247]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[247]\)[t] + Db\ \(B[240]\)[t] + 
                Db\ \(B[241]\)[t] + Db\ \(B[242]\)[t] + Db\ \(B[243]\)[t] - 
                6\ Db\ \(B[247]\)[t] - c\ \(A[247]\)[t]\^2\ \(B[247]\)[t] + 
                Db\ \(B[252]\)[t] + Db\ \(B[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[248]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[248]\)[t] + Db\ \(B[236]\)[t] + 
                Db\ \(B[238]\)[t] + Db\ \(B[245]\)[t] + Db\ \(B[246]\)[t] - 
                4\ Db\ \(B[248]\)[t] - c\ \(A[248]\)[t]\^2\ \(B[248]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[249]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[249]\)[t] + Db\ \(B[237]\)[t] + 
                Db\ \(B[239]\)[t] - 3\ Db\ \(B[249]\)[t] - 
                c\ \(A[249]\)[t]\^2\ \(B[249]\)[t] + Db\ \(B[250]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[250]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[250]\)[t] + Db\ \(B[239]\)[t] + 
                Db\ \(B[242]\)[t] + Db\ \(B[249]\)[t] - 
                4\ Db\ \(B[250]\)[t] - c\ \(A[250]\)[t]\^2\ \(B[250]\)[t] + 
                Db\ \(B[252]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[251]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[251]\)[t] + Db\ \(B[241]\)[t] + 
                Db\ \(B[245]\)[t] - 3\ Db\ \(B[251]\)[t] - 
                c\ \(A[251]\)[t]\^2\ \(B[251]\)[t] + Db\ \(B[253]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[252]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[252]\)[t] + Db\ \(B[242]\)[t] + 
                Db\ \(B[247]\)[t] + Db\ \(B[250]\)[t] - 
                4\ Db\ \(B[252]\)[t] - c\ \(A[252]\)[t]\^2\ \(B[252]\)[t] + 
                Db\ \(B[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(B[253]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(b\ \(A[253]\)[t] + Db\ \(B[241]\)[t] + 
                Db\ \(B[247]\)[t] + Db\ \(B[251]\)[t] + Db\ \(B[252]\)[t] - 
                4\ Db\ \(B[253]\)[t] - c\ \(A[253]\)[t]\^2\ \(B[253]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[1]\)[
                    t] + \(1 + \(hw + Twa\ \(A[1]\)[t] + Twy\ \(Y[1]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[1]\)[t] + Twy\ \(Y[1]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[2]\)[
                    t] + \(1 + \(hw + Twa\ \(A[2]\)[t] + Twy\ \(Y[2]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[2]\)[t] + Twy\ \(Y[2]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[3]\)[
                    t] + \(1 + \(hw + Twa\ \(A[3]\)[t] + Twy\ \(Y[3]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[3]\)[t] + Twy\ \(Y[3]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[4]\)[
                    t] + \(1 + \(hw + Twa\ \(A[4]\)[t] + Twy\ \(Y[4]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[4]\)[t] + Twy\ \(Y[4]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[5]\)[
                    t] + \(1 + \(hw + Twa\ \(A[5]\)[t] + Twy\ \(Y[5]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[5]\)[t] + Twy\ \(Y[5]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[6]\)[
                    t] + \(1 + \(hw + Twa\ \(A[6]\)[t] + Twy\ \(Y[6]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[6]\)[t] + Twy\ \(Y[6]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[7]\)[
                    t] + \(1 + \(hw + Twa\ \(A[7]\)[t] + Twy\ \(Y[7]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[7]\)[t] + Twy\ \(Y[7]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[8]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[8]\)[
                    t] + \(1 + \(hw + Twa\ \(A[8]\)[t] + Twy\ \(Y[8]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[8]\)[t] + Twy\ \(Y[8]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[9]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[9]\)[
                    t] + \(1 + \(hw + Twa\ \(A[9]\)[t] + Twy\ \(Y[9]\)[t]\)\/\
\@\(1 + \((hw + Twa\ \(A[9]\)[t] + Twy\ \(Y[9]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[10]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[10]\)[
                    t] + \(1 + \(hw + Twa\ \(A[10]\)[t] + Twy\ \(Y[10]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[10]\)[t] + Twy\ \(Y[10]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[11]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[11]\)[
                    t] + \(1 + \(hw + Twa\ \(A[11]\)[t] + Twy\ \(Y[11]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[11]\)[t] + Twy\ \(Y[11]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[12]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[12]\)[
                    t] + \(1 + \(hw + Twa\ \(A[12]\)[t] + Twy\ \(Y[12]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[12]\)[t] + Twy\ \(Y[12]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[13]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[13]\)[
                    t] + \(1 + \(hw + Twa\ \(A[13]\)[t] + Twy\ \(Y[13]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[13]\)[t] + Twy\ \(Y[13]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[14]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[14]\)[
                    t] + \(1 + \(hw + Twa\ \(A[14]\)[t] + Twy\ \(Y[14]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[14]\)[t] + Twy\ \(Y[14]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[15]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[15]\)[
                    t] + \(1 + \(hw + Twa\ \(A[15]\)[t] + Twy\ \(Y[15]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[15]\)[t] + Twy\ \(Y[15]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[16]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[16]\)[
                    t] + \(1 + \(hw + Twa\ \(A[16]\)[t] + Twy\ \(Y[16]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[16]\)[t] + Twy\ \(Y[16]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[17]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[17]\)[
                    t] + \(1 + \(hw + Twa\ \(A[17]\)[t] + Twy\ \(Y[17]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[17]\)[t] + Twy\ \(Y[17]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[18]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[18]\)[
                    t] + \(1 + \(hw + Twa\ \(A[18]\)[t] + Twy\ \(Y[18]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[18]\)[t] + Twy\ \(Y[18]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[19]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[19]\)[
                    t] + \(1 + \(hw + Twa\ \(A[19]\)[t] + Twy\ \(Y[19]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[19]\)[t] + Twy\ \(Y[19]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[20]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[20]\)[
                    t] + \(1 + \(hw + Twa\ \(A[20]\)[t] + Twy\ \(Y[20]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[20]\)[t] + Twy\ \(Y[20]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[21]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[21]\)[
                    t] + \(1 + \(hw + Twa\ \(A[21]\)[t] + Twy\ \(Y[21]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[21]\)[t] + Twy\ \(Y[21]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[22]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[22]\)[
                    t] + \(1 + \(hw + Twa\ \(A[22]\)[t] + Twy\ \(Y[22]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[22]\)[t] + Twy\ \(Y[22]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[23]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[23]\)[
                    t] + \(1 + \(hw + Twa\ \(A[23]\)[t] + Twy\ \(Y[23]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[23]\)[t] + Twy\ \(Y[23]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[24]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[24]\)[
                    t] + \(1 + \(hw + Twa\ \(A[24]\)[t] + Twy\ \(Y[24]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[24]\)[t] + Twy\ \(Y[24]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[25]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[25]\)[
                    t] + \(1 + \(hw + Twa\ \(A[25]\)[t] + Twy\ \(Y[25]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[25]\)[t] + Twy\ \(Y[25]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[26]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[26]\)[
                    t] + \(1 + \(hw + Twa\ \(A[26]\)[t] + Twy\ \(Y[26]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[26]\)[t] + Twy\ \(Y[26]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[27]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[27]\)[
                    t] + \(1 + \(hw + Twa\ \(A[27]\)[t] + Twy\ \(Y[27]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[27]\)[t] + Twy\ \(Y[27]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[28]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[28]\)[
                    t] + \(1 + \(hw + Twa\ \(A[28]\)[t] + Twy\ \(Y[28]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[28]\)[t] + Twy\ \(Y[28]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[29]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[29]\)[
                    t] + \(1 + \(hw + Twa\ \(A[29]\)[t] + Twy\ \(Y[29]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[29]\)[t] + Twy\ \(Y[29]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[30]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[30]\)[
                    t] + \(1 + \(hw + Twa\ \(A[30]\)[t] + Twy\ \(Y[30]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[30]\)[t] + Twy\ \(Y[30]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[31]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[31]\)[
                    t] + \(1 + \(hw + Twa\ \(A[31]\)[t] + Twy\ \(Y[31]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[31]\)[t] + Twy\ \(Y[31]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[32]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[32]\)[
                    t] + \(1 + \(hw + Twa\ \(A[32]\)[t] + Twy\ \(Y[32]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[32]\)[t] + Twy\ \(Y[32]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[33]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[33]\)[
                    t] + \(1 + \(hw + Twa\ \(A[33]\)[t] + Twy\ \(Y[33]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[33]\)[t] + Twy\ \(Y[33]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[34]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[34]\)[
                    t] + \(1 + \(hw + Twa\ \(A[34]\)[t] + Twy\ \(Y[34]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[34]\)[t] + Twy\ \(Y[34]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[35]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[35]\)[
                    t] + \(1 + \(hw + Twa\ \(A[35]\)[t] + Twy\ \(Y[35]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[35]\)[t] + Twy\ \(Y[35]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[36]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[36]\)[
                    t] + \(1 + \(hw + Twa\ \(A[36]\)[t] + Twy\ \(Y[36]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[36]\)[t] + Twy\ \(Y[36]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[37]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[37]\)[
                    t] + \(1 + \(hw + Twa\ \(A[37]\)[t] + Twy\ \(Y[37]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[37]\)[t] + Twy\ \(Y[37]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[38]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[38]\)[
                    t] + \(1 + \(hw + Twa\ \(A[38]\)[t] + Twy\ \(Y[38]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[38]\)[t] + Twy\ \(Y[38]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[39]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[39]\)[
                    t] + \(1 + \(hw + Twa\ \(A[39]\)[t] + Twy\ \(Y[39]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[39]\)[t] + Twy\ \(Y[39]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[40]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[40]\)[
                    t] + \(1 + \(hw + Twa\ \(A[40]\)[t] + Twy\ \(Y[40]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[40]\)[t] + Twy\ \(Y[40]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[41]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[41]\)[
                    t] + \(1 + \(hw + Twa\ \(A[41]\)[t] + Twy\ \(Y[41]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[41]\)[t] + Twy\ \(Y[41]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[42]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[42]\)[
                    t] + \(1 + \(hw + Twa\ \(A[42]\)[t] + Twy\ \(Y[42]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[42]\)[t] + Twy\ \(Y[42]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[43]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[43]\)[
                    t] + \(1 + \(hw + Twa\ \(A[43]\)[t] + Twy\ \(Y[43]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[43]\)[t] + Twy\ \(Y[43]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[44]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[44]\)[
                    t] + \(1 + \(hw + Twa\ \(A[44]\)[t] + Twy\ \(Y[44]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[44]\)[t] + Twy\ \(Y[44]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[45]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[45]\)[
                    t] + \(1 + \(hw + Twa\ \(A[45]\)[t] + Twy\ \(Y[45]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[45]\)[t] + Twy\ \(Y[45]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[46]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[46]\)[
                    t] + \(1 + \(hw + Twa\ \(A[46]\)[t] + Twy\ \(Y[46]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[46]\)[t] + Twy\ \(Y[46]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[47]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[47]\)[
                    t] + \(1 + \(hw + Twa\ \(A[47]\)[t] + Twy\ \(Y[47]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[47]\)[t] + Twy\ \(Y[47]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[48]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[48]\)[
                    t] + \(1 + \(hw + Twa\ \(A[48]\)[t] + Twy\ \(Y[48]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[48]\)[t] + Twy\ \(Y[48]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[49]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[49]\)[
                    t] + \(1 + \(hw + Twa\ \(A[49]\)[t] + Twy\ \(Y[49]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[49]\)[t] + Twy\ \(Y[49]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[50]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[50]\)[
                    t] + \(1 + \(hw + Twa\ \(A[50]\)[t] + Twy\ \(Y[50]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[50]\)[t] + Twy\ \(Y[50]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[51]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[51]\)[
                    t] + \(1 + \(hw + Twa\ \(A[51]\)[t] + Twy\ \(Y[51]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[51]\)[t] + Twy\ \(Y[51]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[52]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[52]\)[
                    t] + \(1 + \(hw + Twa\ \(A[52]\)[t] + Twy\ \(Y[52]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[52]\)[t] + Twy\ \(Y[52]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[53]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[53]\)[
                    t] + \(1 + \(hw + Twa\ \(A[53]\)[t] + Twy\ \(Y[53]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[53]\)[t] + Twy\ \(Y[53]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[54]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[54]\)[
                    t] + \(1 + \(hw + Twa\ \(A[54]\)[t] + Twy\ \(Y[54]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[54]\)[t] + Twy\ \(Y[54]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[55]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[55]\)[
                    t] + \(1 + \(hw + Twa\ \(A[55]\)[t] + Twy\ \(Y[55]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[55]\)[t] + Twy\ \(Y[55]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[56]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[56]\)[
                    t] + \(1 + \(hw + Twa\ \(A[56]\)[t] + Twy\ \(Y[56]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[56]\)[t] + Twy\ \(Y[56]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[57]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[57]\)[
                    t] + \(1 + \(hw + Twa\ \(A[57]\)[t] + Twy\ \(Y[57]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[57]\)[t] + Twy\ \(Y[57]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[58]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[58]\)[
                    t] + \(1 + \(hw + Twa\ \(A[58]\)[t] + Twy\ \(Y[58]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[58]\)[t] + Twy\ \(Y[58]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[59]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[59]\)[
                    t] + \(1 + \(hw + Twa\ \(A[59]\)[t] + Twy\ \(Y[59]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[59]\)[t] + Twy\ \(Y[59]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[60]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[60]\)[
                    t] + \(1 + \(hw + Twa\ \(A[60]\)[t] + Twy\ \(Y[60]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[60]\)[t] + Twy\ \(Y[60]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[61]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[61]\)[
                    t] + \(1 + \(hw + Twa\ \(A[61]\)[t] + Twy\ \(Y[61]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[61]\)[t] + Twy\ \(Y[61]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[62]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[62]\)[
                    t] + \(1 + \(hw + Twa\ \(A[62]\)[t] + Twy\ \(Y[62]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[62]\)[t] + Twy\ \(Y[62]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[63]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[63]\)[
                    t] + \(1 + \(hw + Twa\ \(A[63]\)[t] + Twy\ \(Y[63]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[63]\)[t] + Twy\ \(Y[63]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[64]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[64]\)[
                    t] + \(1 + \(hw + Twa\ \(A[64]\)[t] + Twy\ \(Y[64]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[64]\)[t] + Twy\ \(Y[64]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[65]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[65]\)[
                    t] + \(1 + \(hw + Twa\ \(A[65]\)[t] + Twy\ \(Y[65]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[65]\)[t] + Twy\ \(Y[65]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[66]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[66]\)[
                    t] + \(1 + \(hw + Twa\ \(A[66]\)[t] + Twy\ \(Y[66]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[66]\)[t] + Twy\ \(Y[66]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[67]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[67]\)[
                    t] + \(1 + \(hw + Twa\ \(A[67]\)[t] + Twy\ \(Y[67]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[67]\)[t] + Twy\ \(Y[67]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[68]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[68]\)[
                    t] + \(1 + \(hw + Twa\ \(A[68]\)[t] + Twy\ \(Y[68]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[68]\)[t] + Twy\ \(Y[68]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[69]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[69]\)[
                    t] + \(1 + \(hw + Twa\ \(A[69]\)[t] + Twy\ \(Y[69]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[69]\)[t] + Twy\ \(Y[69]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[70]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[70]\)[
                    t] + \(1 + \(hw + Twa\ \(A[70]\)[t] + Twy\ \(Y[70]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[70]\)[t] + Twy\ \(Y[70]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[71]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[71]\)[
                    t] + \(1 + \(hw + Twa\ \(A[71]\)[t] + Twy\ \(Y[71]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[71]\)[t] + Twy\ \(Y[71]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[72]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[72]\)[
                    t] + \(1 + \(hw + Twa\ \(A[72]\)[t] + Twy\ \(Y[72]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[72]\)[t] + Twy\ \(Y[72]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[73]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[73]\)[
                    t] + \(1 + \(hw + Twa\ \(A[73]\)[t] + Twy\ \(Y[73]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[73]\)[t] + Twy\ \(Y[73]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[74]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[74]\)[
                    t] + \(1 + \(hw + Twa\ \(A[74]\)[t] + Twy\ \(Y[74]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[74]\)[t] + Twy\ \(Y[74]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[75]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[75]\)[
                    t] + \(1 + \(hw + Twa\ \(A[75]\)[t] + Twy\ \(Y[75]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[75]\)[t] + Twy\ \(Y[75]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[76]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[76]\)[
                    t] + \(1 + \(hw + Twa\ \(A[76]\)[t] + Twy\ \(Y[76]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[76]\)[t] + Twy\ \(Y[76]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[77]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[77]\)[
                    t] + \(1 + \(hw + Twa\ \(A[77]\)[t] + Twy\ \(Y[77]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[77]\)[t] + Twy\ \(Y[77]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[78]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[78]\)[
                    t] + \(1 + \(hw + Twa\ \(A[78]\)[t] + Twy\ \(Y[78]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[78]\)[t] + Twy\ \(Y[78]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[79]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[79]\)[
                    t] + \(1 + \(hw + Twa\ \(A[79]\)[t] + Twy\ \(Y[79]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[79]\)[t] + Twy\ \(Y[79]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[80]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[80]\)[
                    t] + \(1 + \(hw + Twa\ \(A[80]\)[t] + Twy\ \(Y[80]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[80]\)[t] + Twy\ \(Y[80]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[81]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[81]\)[
                    t] + \(1 + \(hw + Twa\ \(A[81]\)[t] + Twy\ \(Y[81]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[81]\)[t] + Twy\ \(Y[81]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[82]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[82]\)[
                    t] + \(1 + \(hw + Twa\ \(A[82]\)[t] + Twy\ \(Y[82]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[82]\)[t] + Twy\ \(Y[82]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[83]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[83]\)[
                    t] + \(1 + \(hw + Twa\ \(A[83]\)[t] + Twy\ \(Y[83]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[83]\)[t] + Twy\ \(Y[83]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[84]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[84]\)[
                    t] + \(1 + \(hw + Twa\ \(A[84]\)[t] + Twy\ \(Y[84]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[84]\)[t] + Twy\ \(Y[84]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[85]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[85]\)[
                    t] + \(1 + \(hw + Twa\ \(A[85]\)[t] + Twy\ \(Y[85]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[85]\)[t] + Twy\ \(Y[85]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[86]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[86]\)[
                    t] + \(1 + \(hw + Twa\ \(A[86]\)[t] + Twy\ \(Y[86]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[86]\)[t] + Twy\ \(Y[86]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[87]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[87]\)[
                    t] + \(1 + \(hw + Twa\ \(A[87]\)[t] + Twy\ \(Y[87]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[87]\)[t] + Twy\ \(Y[87]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[88]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[88]\)[
                    t] + \(1 + \(hw + Twa\ \(A[88]\)[t] + Twy\ \(Y[88]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[88]\)[t] + Twy\ \(Y[88]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[89]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[89]\)[
                    t] + \(1 + \(hw + Twa\ \(A[89]\)[t] + Twy\ \(Y[89]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[89]\)[t] + Twy\ \(Y[89]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[90]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[90]\)[
                    t] + \(1 + \(hw + Twa\ \(A[90]\)[t] + Twy\ \(Y[90]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[90]\)[t] + Twy\ \(Y[90]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[91]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[91]\)[
                    t] + \(1 + \(hw + Twa\ \(A[91]\)[t] + Twy\ \(Y[91]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[91]\)[t] + Twy\ \(Y[91]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[92]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[92]\)[
                    t] + \(1 + \(hw + Twa\ \(A[92]\)[t] + Twy\ \(Y[92]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[92]\)[t] + Twy\ \(Y[92]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[93]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[93]\)[
                    t] + \(1 + \(hw + Twa\ \(A[93]\)[t] + Twy\ \(Y[93]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[93]\)[t] + Twy\ \(Y[93]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[94]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[94]\)[
                    t] + \(1 + \(hw + Twa\ \(A[94]\)[t] + Twy\ \(Y[94]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[94]\)[t] + Twy\ \(Y[94]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[95]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[95]\)[
                    t] + \(1 + \(hw + Twa\ \(A[95]\)[t] + Twy\ \(Y[95]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[95]\)[t] + Twy\ \(Y[95]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[96]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[96]\)[
                    t] + \(1 + \(hw + Twa\ \(A[96]\)[t] + Twy\ \(Y[96]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[96]\)[t] + Twy\ \(Y[96]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[97]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[97]\)[
                    t] + \(1 + \(hw + Twa\ \(A[97]\)[t] + Twy\ \(Y[97]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[97]\)[t] + Twy\ \(Y[97]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[98]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[98]\)[
                    t] + \(1 + \(hw + Twa\ \(A[98]\)[t] + Twy\ \(Y[98]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[98]\)[t] + Twy\ \(Y[98]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[99]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[99]\)[
                    t] + \(1 + \(hw + Twa\ \(A[99]\)[t] + Twy\ \(Y[99]\)[t]\)\
\/\@\(1 + \((hw + Twa\ \(A[99]\)[t] + Twy\ \(Y[99]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[100]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[100]\)[
                    t] + \(1 + \(hw + Twa\ \(A[100]\)[t] + Twy\ \(Y[100]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[100]\)[t] + Twy\ \(Y[100]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[101]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[101]\)[
                    t] + \(1 + \(hw + Twa\ \(A[101]\)[t] + Twy\ \(Y[101]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[101]\)[t] + Twy\ \(Y[101]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[102]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[102]\)[
                    t] + \(1 + \(hw + Twa\ \(A[102]\)[t] + Twy\ \(Y[102]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[102]\)[t] + Twy\ \(Y[102]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[103]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[103]\)[
                    t] + \(1 + \(hw + Twa\ \(A[103]\)[t] + Twy\ \(Y[103]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[103]\)[t] + Twy\ \(Y[103]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[104]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[104]\)[
                    t] + \(1 + \(hw + Twa\ \(A[104]\)[t] + Twy\ \(Y[104]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[104]\)[t] + Twy\ \(Y[104]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[105]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[105]\)[
                    t] + \(1 + \(hw + Twa\ \(A[105]\)[t] + Twy\ \(Y[105]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[105]\)[t] + Twy\ \(Y[105]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[106]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[106]\)[
                    t] + \(1 + \(hw + Twa\ \(A[106]\)[t] + Twy\ \(Y[106]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[106]\)[t] + Twy\ \(Y[106]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[107]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[107]\)[
                    t] + \(1 + \(hw + Twa\ \(A[107]\)[t] + Twy\ \(Y[107]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[107]\)[t] + Twy\ \(Y[107]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[108]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[108]\)[
                    t] + \(1 + \(hw + Twa\ \(A[108]\)[t] + Twy\ \(Y[108]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[108]\)[t] + Twy\ \(Y[108]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[109]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[109]\)[
                    t] + \(1 + \(hw + Twa\ \(A[109]\)[t] + Twy\ \(Y[109]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[109]\)[t] + Twy\ \(Y[109]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[110]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[110]\)[
                    t] + \(1 + \(hw + Twa\ \(A[110]\)[t] + Twy\ \(Y[110]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[110]\)[t] + Twy\ \(Y[110]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[111]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[111]\)[
                    t] + \(1 + \(hw + Twa\ \(A[111]\)[t] + Twy\ \(Y[111]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[111]\)[t] + Twy\ \(Y[111]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[112]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[112]\)[
                    t] + \(1 + \(hw + Twa\ \(A[112]\)[t] + Twy\ \(Y[112]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[112]\)[t] + Twy\ \(Y[112]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[113]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[113]\)[
                    t] + \(1 + \(hw + Twa\ \(A[113]\)[t] + Twy\ \(Y[113]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[113]\)[t] + Twy\ \(Y[113]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[114]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[114]\)[
                    t] + \(1 + \(hw + Twa\ \(A[114]\)[t] + Twy\ \(Y[114]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[114]\)[t] + Twy\ \(Y[114]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[115]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[115]\)[
                    t] + \(1 + \(hw + Twa\ \(A[115]\)[t] + Twy\ \(Y[115]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[115]\)[t] + Twy\ \(Y[115]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[116]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[116]\)[
                    t] + \(1 + \(hw + Twa\ \(A[116]\)[t] + Twy\ \(Y[116]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[116]\)[t] + Twy\ \(Y[116]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[117]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[117]\)[
                    t] + \(1 + \(hw + Twa\ \(A[117]\)[t] + Twy\ \(Y[117]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[117]\)[t] + Twy\ \(Y[117]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[118]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[118]\)[
                    t] + \(1 + \(hw + Twa\ \(A[118]\)[t] + Twy\ \(Y[118]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[118]\)[t] + Twy\ \(Y[118]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[119]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[119]\)[
                    t] + \(1 + \(hw + Twa\ \(A[119]\)[t] + Twy\ \(Y[119]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[119]\)[t] + Twy\ \(Y[119]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[120]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[120]\)[
                    t] + \(1 + \(hw + Twa\ \(A[120]\)[t] + Twy\ \(Y[120]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[120]\)[t] + Twy\ \(Y[120]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[121]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[121]\)[
                    t] + \(1 + \(hw + Twa\ \(A[121]\)[t] + Twy\ \(Y[121]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[121]\)[t] + Twy\ \(Y[121]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[122]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[122]\)[
                    t] + \(1 + \(hw + Twa\ \(A[122]\)[t] + Twy\ \(Y[122]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[122]\)[t] + Twy\ \(Y[122]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[123]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[123]\)[
                    t] + \(1 + \(hw + Twa\ \(A[123]\)[t] + Twy\ \(Y[123]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[123]\)[t] + Twy\ \(Y[123]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[124]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[124]\)[
                    t] + \(1 + \(hw + Twa\ \(A[124]\)[t] + Twy\ \(Y[124]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[124]\)[t] + Twy\ \(Y[124]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[125]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[125]\)[
                    t] + \(1 + \(hw + Twa\ \(A[125]\)[t] + Twy\ \(Y[125]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[125]\)[t] + Twy\ \(Y[125]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[126]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[126]\)[
                    t] + \(1 + \(hw + Twa\ \(A[126]\)[t] + Twy\ \(Y[126]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[126]\)[t] + Twy\ \(Y[126]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[127]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[127]\)[
                    t] + \(1 + \(hw + Twa\ \(A[127]\)[t] + Twy\ \(Y[127]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[127]\)[t] + Twy\ \(Y[127]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[128]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[128]\)[
                    t] + \(1 + \(hw + Twa\ \(A[128]\)[t] + Twy\ \(Y[128]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[128]\)[t] + Twy\ \(Y[128]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[129]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[129]\)[
                    t] + \(1 + \(hw + Twa\ \(A[129]\)[t] + Twy\ \(Y[129]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[129]\)[t] + Twy\ \(Y[129]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[130]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[130]\)[
                    t] + \(1 + \(hw + Twa\ \(A[130]\)[t] + Twy\ \(Y[130]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[130]\)[t] + Twy\ \(Y[130]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[131]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[131]\)[
                    t] + \(1 + \(hw + Twa\ \(A[131]\)[t] + Twy\ \(Y[131]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[131]\)[t] + Twy\ \(Y[131]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[132]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[132]\)[
                    t] + \(1 + \(hw + Twa\ \(A[132]\)[t] + Twy\ \(Y[132]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[132]\)[t] + Twy\ \(Y[132]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[133]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[133]\)[
                    t] + \(1 + \(hw + Twa\ \(A[133]\)[t] + Twy\ \(Y[133]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[133]\)[t] + Twy\ \(Y[133]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[134]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[134]\)[
                    t] + \(1 + \(hw + Twa\ \(A[134]\)[t] + Twy\ \(Y[134]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[134]\)[t] + Twy\ \(Y[134]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[135]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[135]\)[
                    t] + \(1 + \(hw + Twa\ \(A[135]\)[t] + Twy\ \(Y[135]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[135]\)[t] + Twy\ \(Y[135]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[136]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[136]\)[
                    t] + \(1 + \(hw + Twa\ \(A[136]\)[t] + Twy\ \(Y[136]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[136]\)[t] + Twy\ \(Y[136]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[137]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[137]\)[
                    t] + \(1 + \(hw + Twa\ \(A[137]\)[t] + Twy\ \(Y[137]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[137]\)[t] + Twy\ \(Y[137]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[138]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[138]\)[
                    t] + \(1 + \(hw + Twa\ \(A[138]\)[t] + Twy\ \(Y[138]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[138]\)[t] + Twy\ \(Y[138]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[139]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[139]\)[
                    t] + \(1 + \(hw + Twa\ \(A[139]\)[t] + Twy\ \(Y[139]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[139]\)[t] + Twy\ \(Y[139]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[140]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[140]\)[
                    t] + \(1 + \(hw + Twa\ \(A[140]\)[t] + Twy\ \(Y[140]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[140]\)[t] + Twy\ \(Y[140]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[141]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[141]\)[
                    t] + \(1 + \(hw + Twa\ \(A[141]\)[t] + Twy\ \(Y[141]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[141]\)[t] + Twy\ \(Y[141]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[142]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[142]\)[
                    t] + \(1 + \(hw + Twa\ \(A[142]\)[t] + Twy\ \(Y[142]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[142]\)[t] + Twy\ \(Y[142]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[143]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[143]\)[
                    t] + \(1 + \(hw + Twa\ \(A[143]\)[t] + Twy\ \(Y[143]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[143]\)[t] + Twy\ \(Y[143]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[144]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[144]\)[
                    t] + \(1 + \(hw + Twa\ \(A[144]\)[t] + Twy\ \(Y[144]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[144]\)[t] + Twy\ \(Y[144]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[145]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[145]\)[
                    t] + \(1 + \(hw + Twa\ \(A[145]\)[t] + Twy\ \(Y[145]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[145]\)[t] + Twy\ \(Y[145]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[146]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[146]\)[
                    t] + \(1 + \(hw + Twa\ \(A[146]\)[t] + Twy\ \(Y[146]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[146]\)[t] + Twy\ \(Y[146]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[147]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[147]\)[
                    t] + \(1 + \(hw + Twa\ \(A[147]\)[t] + Twy\ \(Y[147]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[147]\)[t] + Twy\ \(Y[147]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[148]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[148]\)[
                    t] + \(1 + \(hw + Twa\ \(A[148]\)[t] + Twy\ \(Y[148]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[148]\)[t] + Twy\ \(Y[148]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[149]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[149]\)[
                    t] + \(1 + \(hw + Twa\ \(A[149]\)[t] + Twy\ \(Y[149]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[149]\)[t] + Twy\ \(Y[149]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[150]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[150]\)[
                    t] + \(1 + \(hw + Twa\ \(A[150]\)[t] + Twy\ \(Y[150]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[150]\)[t] + Twy\ \(Y[150]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[151]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[151]\)[
                    t] + \(1 + \(hw + Twa\ \(A[151]\)[t] + Twy\ \(Y[151]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[151]\)[t] + Twy\ \(Y[151]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[152]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[152]\)[
                    t] + \(1 + \(hw + Twa\ \(A[152]\)[t] + Twy\ \(Y[152]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[152]\)[t] + Twy\ \(Y[152]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[153]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[153]\)[
                    t] + \(1 + \(hw + Twa\ \(A[153]\)[t] + Twy\ \(Y[153]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[153]\)[t] + Twy\ \(Y[153]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[154]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[154]\)[
                    t] + \(1 + \(hw + Twa\ \(A[154]\)[t] + Twy\ \(Y[154]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[154]\)[t] + Twy\ \(Y[154]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[155]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[155]\)[
                    t] + \(1 + \(hw + Twa\ \(A[155]\)[t] + Twy\ \(Y[155]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[155]\)[t] + Twy\ \(Y[155]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[156]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[156]\)[
                    t] + \(1 + \(hw + Twa\ \(A[156]\)[t] + Twy\ \(Y[156]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[156]\)[t] + Twy\ \(Y[156]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[157]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[157]\)[
                    t] + \(1 + \(hw + Twa\ \(A[157]\)[t] + Twy\ \(Y[157]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[157]\)[t] + Twy\ \(Y[157]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[158]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[158]\)[
                    t] + \(1 + \(hw + Twa\ \(A[158]\)[t] + Twy\ \(Y[158]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[158]\)[t] + Twy\ \(Y[158]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[159]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[159]\)[
                    t] + \(1 + \(hw + Twa\ \(A[159]\)[t] + Twy\ \(Y[159]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[159]\)[t] + Twy\ \(Y[159]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[160]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[160]\)[
                    t] + \(1 + \(hw + Twa\ \(A[160]\)[t] + Twy\ \(Y[160]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[160]\)[t] + Twy\ \(Y[160]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[161]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[161]\)[
                    t] + \(1 + \(hw + Twa\ \(A[161]\)[t] + Twy\ \(Y[161]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[161]\)[t] + Twy\ \(Y[161]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[162]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[162]\)[
                    t] + \(1 + \(hw + Twa\ \(A[162]\)[t] + Twy\ \(Y[162]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[162]\)[t] + Twy\ \(Y[162]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[163]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[163]\)[
                    t] + \(1 + \(hw + Twa\ \(A[163]\)[t] + Twy\ \(Y[163]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[163]\)[t] + Twy\ \(Y[163]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[164]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[164]\)[
                    t] + \(1 + \(hw + Twa\ \(A[164]\)[t] + Twy\ \(Y[164]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[164]\)[t] + Twy\ \(Y[164]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[165]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[165]\)[
                    t] + \(1 + \(hw + Twa\ \(A[165]\)[t] + Twy\ \(Y[165]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[165]\)[t] + Twy\ \(Y[165]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[166]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[166]\)[
                    t] + \(1 + \(hw + Twa\ \(A[166]\)[t] + Twy\ \(Y[166]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[166]\)[t] + Twy\ \(Y[166]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[167]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[167]\)[
                    t] + \(1 + \(hw + Twa\ \(A[167]\)[t] + Twy\ \(Y[167]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[167]\)[t] + Twy\ \(Y[167]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[168]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[168]\)[
                    t] + \(1 + \(hw + Twa\ \(A[168]\)[t] + Twy\ \(Y[168]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[168]\)[t] + Twy\ \(Y[168]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[169]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[169]\)[
                    t] + \(1 + \(hw + Twa\ \(A[169]\)[t] + Twy\ \(Y[169]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[169]\)[t] + Twy\ \(Y[169]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[170]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[170]\)[
                    t] + \(1 + \(hw + Twa\ \(A[170]\)[t] + Twy\ \(Y[170]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[170]\)[t] + Twy\ \(Y[170]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[171]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[171]\)[
                    t] + \(1 + \(hw + Twa\ \(A[171]\)[t] + Twy\ \(Y[171]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[171]\)[t] + Twy\ \(Y[171]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[172]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[172]\)[
                    t] + \(1 + \(hw + Twa\ \(A[172]\)[t] + Twy\ \(Y[172]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[172]\)[t] + Twy\ \(Y[172]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[173]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[173]\)[
                    t] + \(1 + \(hw + Twa\ \(A[173]\)[t] + Twy\ \(Y[173]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[173]\)[t] + Twy\ \(Y[173]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[174]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[174]\)[
                    t] + \(1 + \(hw + Twa\ \(A[174]\)[t] + Twy\ \(Y[174]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[174]\)[t] + Twy\ \(Y[174]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[175]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[175]\)[
                    t] + \(1 + \(hw + Twa\ \(A[175]\)[t] + Twy\ \(Y[175]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[175]\)[t] + Twy\ \(Y[175]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[176]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[176]\)[
                    t] + \(1 + \(hw + Twa\ \(A[176]\)[t] + Twy\ \(Y[176]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[176]\)[t] + Twy\ \(Y[176]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[177]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[177]\)[
                    t] + \(1 + \(hw + Twa\ \(A[177]\)[t] + Twy\ \(Y[177]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[177]\)[t] + Twy\ \(Y[177]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[178]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[178]\)[
                    t] + \(1 + \(hw + Twa\ \(A[178]\)[t] + Twy\ \(Y[178]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[178]\)[t] + Twy\ \(Y[178]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[179]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[179]\)[
                    t] + \(1 + \(hw + Twa\ \(A[179]\)[t] + Twy\ \(Y[179]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[179]\)[t] + Twy\ \(Y[179]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[180]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[180]\)[
                    t] + \(1 + \(hw + Twa\ \(A[180]\)[t] + Twy\ \(Y[180]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[180]\)[t] + Twy\ \(Y[180]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[181]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[181]\)[
                    t] + \(1 + \(hw + Twa\ \(A[181]\)[t] + Twy\ \(Y[181]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[181]\)[t] + Twy\ \(Y[181]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[182]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[182]\)[
                    t] + \(1 + \(hw + Twa\ \(A[182]\)[t] + Twy\ \(Y[182]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[182]\)[t] + Twy\ \(Y[182]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[183]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[183]\)[
                    t] + \(1 + \(hw + Twa\ \(A[183]\)[t] + Twy\ \(Y[183]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[183]\)[t] + Twy\ \(Y[183]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[184]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[184]\)[
                    t] + \(1 + \(hw + Twa\ \(A[184]\)[t] + Twy\ \(Y[184]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[184]\)[t] + Twy\ \(Y[184]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[185]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[185]\)[
                    t] + \(1 + \(hw + Twa\ \(A[185]\)[t] + Twy\ \(Y[185]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[185]\)[t] + Twy\ \(Y[185]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[186]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[186]\)[
                    t] + \(1 + \(hw + Twa\ \(A[186]\)[t] + Twy\ \(Y[186]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[186]\)[t] + Twy\ \(Y[186]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[187]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[187]\)[
                    t] + \(1 + \(hw + Twa\ \(A[187]\)[t] + Twy\ \(Y[187]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[187]\)[t] + Twy\ \(Y[187]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[188]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[188]\)[
                    t] + \(1 + \(hw + Twa\ \(A[188]\)[t] + Twy\ \(Y[188]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[188]\)[t] + Twy\ \(Y[188]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[189]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[189]\)[
                    t] + \(1 + \(hw + Twa\ \(A[189]\)[t] + Twy\ \(Y[189]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[189]\)[t] + Twy\ \(Y[189]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[190]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[190]\)[
                    t] + \(1 + \(hw + Twa\ \(A[190]\)[t] + Twy\ \(Y[190]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[190]\)[t] + Twy\ \(Y[190]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[191]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[191]\)[
                    t] + \(1 + \(hw + Twa\ \(A[191]\)[t] + Twy\ \(Y[191]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[191]\)[t] + Twy\ \(Y[191]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[192]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[192]\)[
                    t] + \(1 + \(hw + Twa\ \(A[192]\)[t] + Twy\ \(Y[192]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[192]\)[t] + Twy\ \(Y[192]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[193]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[193]\)[
                    t] + \(1 + \(hw + Twa\ \(A[193]\)[t] + Twy\ \(Y[193]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[193]\)[t] + Twy\ \(Y[193]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[194]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[194]\)[
                    t] + \(1 + \(hw + Twa\ \(A[194]\)[t] + Twy\ \(Y[194]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[194]\)[t] + Twy\ \(Y[194]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[195]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[195]\)[
                    t] + \(1 + \(hw + Twa\ \(A[195]\)[t] + Twy\ \(Y[195]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[195]\)[t] + Twy\ \(Y[195]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[196]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[196]\)[
                    t] + \(1 + \(hw + Twa\ \(A[196]\)[t] + Twy\ \(Y[196]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[196]\)[t] + Twy\ \(Y[196]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[197]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[197]\)[
                    t] + \(1 + \(hw + Twa\ \(A[197]\)[t] + Twy\ \(Y[197]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[197]\)[t] + Twy\ \(Y[197]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[198]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[198]\)[
                    t] + \(1 + \(hw + Twa\ \(A[198]\)[t] + Twy\ \(Y[198]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[198]\)[t] + Twy\ \(Y[198]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[199]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[199]\)[
                    t] + \(1 + \(hw + Twa\ \(A[199]\)[t] + Twy\ \(Y[199]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[199]\)[t] + Twy\ \(Y[199]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[200]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[200]\)[
                    t] + \(1 + \(hw + Twa\ \(A[200]\)[t] + Twy\ \(Y[200]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[200]\)[t] + Twy\ \(Y[200]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[201]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[201]\)[
                    t] + \(1 + \(hw + Twa\ \(A[201]\)[t] + Twy\ \(Y[201]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[201]\)[t] + Twy\ \(Y[201]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[202]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[202]\)[
                    t] + \(1 + \(hw + Twa\ \(A[202]\)[t] + Twy\ \(Y[202]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[202]\)[t] + Twy\ \(Y[202]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[203]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[203]\)[
                    t] + \(1 + \(hw + Twa\ \(A[203]\)[t] + Twy\ \(Y[203]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[203]\)[t] + Twy\ \(Y[203]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[204]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[204]\)[
                    t] + \(1 + \(hw + Twa\ \(A[204]\)[t] + Twy\ \(Y[204]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[204]\)[t] + Twy\ \(Y[204]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[205]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[205]\)[
                    t] + \(1 + \(hw + Twa\ \(A[205]\)[t] + Twy\ \(Y[205]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[205]\)[t] + Twy\ \(Y[205]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[206]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[206]\)[
                    t] + \(1 + \(hw + Twa\ \(A[206]\)[t] + Twy\ \(Y[206]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[206]\)[t] + Twy\ \(Y[206]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[207]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[207]\)[
                    t] + \(1 + \(hw + Twa\ \(A[207]\)[t] + Twy\ \(Y[207]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[207]\)[t] + Twy\ \(Y[207]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[208]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[208]\)[
                    t] + \(1 + \(hw + Twa\ \(A[208]\)[t] + Twy\ \(Y[208]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[208]\)[t] + Twy\ \(Y[208]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[209]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[209]\)[
                    t] + \(1 + \(hw + Twa\ \(A[209]\)[t] + Twy\ \(Y[209]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[209]\)[t] + Twy\ \(Y[209]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[210]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[210]\)[
                    t] + \(1 + \(hw + Twa\ \(A[210]\)[t] + Twy\ \(Y[210]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[210]\)[t] + Twy\ \(Y[210]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[211]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[211]\)[
                    t] + \(1 + \(hw + Twa\ \(A[211]\)[t] + Twy\ \(Y[211]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[211]\)[t] + Twy\ \(Y[211]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[212]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[212]\)[
                    t] + \(1 + \(hw + Twa\ \(A[212]\)[t] + Twy\ \(Y[212]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[212]\)[t] + Twy\ \(Y[212]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[213]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[213]\)[
                    t] + \(1 + \(hw + Twa\ \(A[213]\)[t] + Twy\ \(Y[213]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[213]\)[t] + Twy\ \(Y[213]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[214]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[214]\)[
                    t] + \(1 + \(hw + Twa\ \(A[214]\)[t] + Twy\ \(Y[214]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[214]\)[t] + Twy\ \(Y[214]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[215]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[215]\)[
                    t] + \(1 + \(hw + Twa\ \(A[215]\)[t] + Twy\ \(Y[215]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[215]\)[t] + Twy\ \(Y[215]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[216]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[216]\)[
                    t] + \(1 + \(hw + Twa\ \(A[216]\)[t] + Twy\ \(Y[216]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[216]\)[t] + Twy\ \(Y[216]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[217]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[217]\)[
                    t] + \(1 + \(hw + Twa\ \(A[217]\)[t] + Twy\ \(Y[217]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[217]\)[t] + Twy\ \(Y[217]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[218]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[218]\)[
                    t] + \(1 + \(hw + Twa\ \(A[218]\)[t] + Twy\ \(Y[218]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[218]\)[t] + Twy\ \(Y[218]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[219]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[219]\)[
                    t] + \(1 + \(hw + Twa\ \(A[219]\)[t] + Twy\ \(Y[219]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[219]\)[t] + Twy\ \(Y[219]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[220]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[220]\)[
                    t] + \(1 + \(hw + Twa\ \(A[220]\)[t] + Twy\ \(Y[220]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[220]\)[t] + Twy\ \(Y[220]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[221]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[221]\)[
                    t] + \(1 + \(hw + Twa\ \(A[221]\)[t] + Twy\ \(Y[221]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[221]\)[t] + Twy\ \(Y[221]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[222]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[222]\)[
                    t] + \(1 + \(hw + Twa\ \(A[222]\)[t] + Twy\ \(Y[222]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[222]\)[t] + Twy\ \(Y[222]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[223]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[223]\)[
                    t] + \(1 + \(hw + Twa\ \(A[223]\)[t] + Twy\ \(Y[223]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[223]\)[t] + Twy\ \(Y[223]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[224]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[224]\)[
                    t] + \(1 + \(hw + Twa\ \(A[224]\)[t] + Twy\ \(Y[224]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[224]\)[t] + Twy\ \(Y[224]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[225]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[225]\)[
                    t] + \(1 + \(hw + Twa\ \(A[225]\)[t] + Twy\ \(Y[225]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[225]\)[t] + Twy\ \(Y[225]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[226]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[226]\)[
                    t] + \(1 + \(hw + Twa\ \(A[226]\)[t] + Twy\ \(Y[226]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[226]\)[t] + Twy\ \(Y[226]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[227]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[227]\)[
                    t] + \(1 + \(hw + Twa\ \(A[227]\)[t] + Twy\ \(Y[227]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[227]\)[t] + Twy\ \(Y[227]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[228]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[228]\)[
                    t] + \(1 + \(hw + Twa\ \(A[228]\)[t] + Twy\ \(Y[228]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[228]\)[t] + Twy\ \(Y[228]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[229]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[229]\)[
                    t] + \(1 + \(hw + Twa\ \(A[229]\)[t] + Twy\ \(Y[229]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[229]\)[t] + Twy\ \(Y[229]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[230]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[230]\)[
                    t] + \(1 + \(hw + Twa\ \(A[230]\)[t] + Twy\ \(Y[230]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[230]\)[t] + Twy\ \(Y[230]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[231]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[231]\)[
                    t] + \(1 + \(hw + Twa\ \(A[231]\)[t] + Twy\ \(Y[231]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[231]\)[t] + Twy\ \(Y[231]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[232]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[232]\)[
                    t] + \(1 + \(hw + Twa\ \(A[232]\)[t] + Twy\ \(Y[232]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[232]\)[t] + Twy\ \(Y[232]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[233]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[233]\)[
                    t] + \(1 + \(hw + Twa\ \(A[233]\)[t] + Twy\ \(Y[233]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[233]\)[t] + Twy\ \(Y[233]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[234]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[234]\)[
                    t] + \(1 + \(hw + Twa\ \(A[234]\)[t] + Twy\ \(Y[234]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[234]\)[t] + Twy\ \(Y[234]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[235]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[235]\)[
                    t] + \(1 + \(hw + Twa\ \(A[235]\)[t] + Twy\ \(Y[235]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[235]\)[t] + Twy\ \(Y[235]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[236]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[236]\)[
                    t] + \(1 + \(hw + Twa\ \(A[236]\)[t] + Twy\ \(Y[236]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[236]\)[t] + Twy\ \(Y[236]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[237]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[237]\)[
                    t] + \(1 + \(hw + Twa\ \(A[237]\)[t] + Twy\ \(Y[237]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[237]\)[t] + Twy\ \(Y[237]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[238]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[238]\)[
                    t] + \(1 + \(hw + Twa\ \(A[238]\)[t] + Twy\ \(Y[238]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[238]\)[t] + Twy\ \(Y[238]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[239]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[239]\)[
                    t] + \(1 + \(hw + Twa\ \(A[239]\)[t] + Twy\ \(Y[239]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[239]\)[t] + Twy\ \(Y[239]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[240]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[240]\)[
                    t] + \(1 + \(hw + Twa\ \(A[240]\)[t] + Twy\ \(Y[240]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[240]\)[t] + Twy\ \(Y[240]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[241]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[241]\)[
                    t] + \(1 + \(hw + Twa\ \(A[241]\)[t] + Twy\ \(Y[241]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[241]\)[t] + Twy\ \(Y[241]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[242]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[242]\)[
                    t] + \(1 + \(hw + Twa\ \(A[242]\)[t] + Twy\ \(Y[242]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[242]\)[t] + Twy\ \(Y[242]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[243]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[243]\)[
                    t] + \(1 + \(hw + Twa\ \(A[243]\)[t] + Twy\ \(Y[243]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[243]\)[t] + Twy\ \(Y[243]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[244]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[244]\)[
                    t] + \(1 + \(hw + Twa\ \(A[244]\)[t] + Twy\ \(Y[244]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[244]\)[t] + Twy\ \(Y[244]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[245]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[245]\)[
                    t] + \(1 + \(hw + Twa\ \(A[245]\)[t] + Twy\ \(Y[245]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[245]\)[t] + Twy\ \(Y[245]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[246]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[246]\)[
                    t] + \(1 + \(hw + Twa\ \(A[246]\)[t] + Twy\ \(Y[246]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[246]\)[t] + Twy\ \(Y[246]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[247]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[247]\)[
                    t] + \(1 + \(hw + Twa\ \(A[247]\)[t] + Twy\ \(Y[247]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[247]\)[t] + Twy\ \(Y[247]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[248]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[248]\)[
                    t] + \(1 + \(hw + Twa\ \(A[248]\)[t] + Twy\ \(Y[248]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[248]\)[t] + Twy\ \(Y[248]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[249]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[249]\)[
                    t] + \(1 + \(hw + Twa\ \(A[249]\)[t] + Twy\ \(Y[249]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[249]\)[t] + Twy\ \(Y[249]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[250]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[250]\)[
                    t] + \(1 + \(hw + Twa\ \(A[250]\)[t] + Twy\ \(Y[250]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[250]\)[t] + Twy\ \(Y[250]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[251]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[251]\)[
                    t] + \(1 + \(hw + Twa\ \(A[251]\)[t] + Twy\ \(Y[251]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[251]\)[t] + Twy\ \(Y[251]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[252]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[252]\)[
                    t] + \(1 + \(hw + Twa\ \(A[252]\)[t] + Twy\ \(Y[252]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[252]\)[t] + Twy\ \(Y[252]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(W[253]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(\(-dw\)\ \(W[253]\)[
                    t] + \(1 + \(hw + Twa\ \(A[253]\)[t] + Twy\ \(Y[253]\)[t]\
\)\/\@\(1 + \((hw + Twa\ \(A[253]\)[t] + Twy\ \(Y[253]\)[t])\)\^2\)\)\/\(2\ \
tauw\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[1]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[1] - dy\ \(Y[1]\)[t] - 
                3\ Dy\ \(Y[1]\)[t] + Dy\ \(Y[2]\)[t] + Dy\ \(Y[3]\)[t] + 
                Dy\ \(Y[8]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[2] + Dy\ \(Y[1]\)[t] - dy\ \(Y[2]\)[t] - 
                4\ Dy\ \(Y[2]\)[t] + Dy\ \(Y[4]\)[t] + Dy\ \(Y[5]\)[t] + 
                Dy\ \(Y[8]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[3]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[3] + Dy\ \(Y[1]\)[t] - dy\ \(Y[3]\)[t] - 
                4\ Dy\ \(Y[3]\)[t] + Dy\ \(Y[6]\)[t] + Dy\ \(Y[7]\)[t] + 
                Dy\ \(Y[8]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[4]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[4] + Dy\ \(Y[2]\)[t] - dy\ \(Y[4]\)[t] - 
                4\ Dy\ \(Y[4]\)[t] + Dy\ \(Y[5]\)[t] + Dy\ \(Y[9]\)[t] + 
                Dy\ \(Y[10]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[5]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[5] + Dy\ \(Y[2]\)[t] + Dy\ \(Y[4]\)[t] - 
                dy\ \(Y[5]\)[t] - 5\ Dy\ \(Y[5]\)[t] + Dy\ \(Y[8]\)[t] + 
                Dy\ \(Y[9]\)[t] + Dy\ \(Y[14]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[6]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[6] + Dy\ \(Y[3]\)[t] - dy\ \(Y[6]\)[t] - 
                5\ Dy\ \(Y[6]\)[t] + Dy\ \(Y[7]\)[t] + Dy\ \(Y[11]\)[t] + 
                Dy\ \(Y[12]\)[t] + Dy\ \(Y[22]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[7]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[7] + Dy\ \(Y[3]\)[t] + Dy\ \(Y[6]\)[t] - 
                dy\ \(Y[7]\)[t] - 5\ Dy\ \(Y[7]\)[t] + Dy\ \(Y[8]\)[t] + 
                Dy\ \(Y[11]\)[t] + Dy\ \(Y[13]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[8]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[8] + Dy\ \(Y[1]\)[t] + Dy\ \(Y[2]\)[t] + 
                Dy\ \(Y[3]\)[t] + Dy\ \(Y[5]\)[t] + Dy\ \(Y[7]\)[t] - 
                dy\ \(Y[8]\)[t] - 8\ Dy\ \(Y[8]\)[t] + Dy\ \(Y[13]\)[t] + 
                Dy\ \(Y[14]\)[t] + Dy\ \(Y[17]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[9]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[9] + Dy\ \(Y[4]\)[t] + Dy\ \(Y[5]\)[t] - 
                dy\ \(Y[9]\)[t] - 6\ Dy\ \(Y[9]\)[t] + Dy\ \(Y[10]\)[t] + 
                Dy\ \(Y[14]\)[t] + Dy\ \(Y[18]\)[t] + Dy\ \(Y[27]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[10]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[10] + Dy\ \(Y[4]\)[t] + Dy\ \(Y[9]\)[t] - 
                dy\ \(Y[10]\)[t] - 5\ Dy\ \(Y[10]\)[t] + Dy\ \(Y[18]\)[t] + 
                Dy\ \(Y[19]\)[t] + Dy\ \(Y[28]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[11]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[11] + Dy\ \(Y[6]\)[t] + Dy\ \(Y[7]\)[t] - 
                dy\ \(Y[11]\)[t] - 7\ Dy\ \(Y[11]\)[t] + Dy\ \(Y[13]\)[t] + 
                Dy\ \(Y[22]\)[t] + Dy\ \(Y[24]\)[t] + Dy\ \(Y[25]\)[t] + 
                Dy\ \(Y[26]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[12]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[12] + Dy\ \(Y[6]\)[t] - dy\ \(Y[12]\)[t] - 
                4\ Dy\ \(Y[12]\)[t] + Dy\ \(Y[16]\)[t] + Dy\ \(Y[22]\)[t] + 
                Dy\ \(Y[30]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[13]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[13] + Dy\ \(Y[7]\)[t] + Dy\ \(Y[8]\)[t] + 
                Dy\ \(Y[11]\)[t] - dy\ \(Y[13]\)[t] - 6\ Dy\ \(Y[13]\)[t] + 
                Dy\ \(Y[17]\)[t] + Dy\ \(Y[26]\)[t] + Dy\ \(Y[39]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[14]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[14] + Dy\ \(Y[5]\)[t] + Dy\ \(Y[8]\)[t] + 
                Dy\ \(Y[9]\)[t] - dy\ \(Y[14]\)[t] - 7\ Dy\ \(Y[14]\)[t] + 
                Dy\ \(Y[17]\)[t] + Dy\ \(Y[23]\)[t] + Dy\ \(Y[27]\)[t] + 
                Dy\ \(Y[33]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[15]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[15] - dy\ \(Y[15]\)[t] - 
                5\ Dy\ \(Y[15]\)[t] + Dy\ \(Y[20]\)[t] + Dy\ \(Y[21]\)[t] + 
                Dy\ \(Y[29]\)[t] + Dy\ \(Y[34]\)[t] + Dy\ \(Y[35]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[16]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[16] + Dy\ \(Y[12]\)[t] - 
                dy\ \(Y[16]\)[t] - 2\ Dy\ \(Y[16]\)[t] + Dy\ \(Y[30]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[17]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[17] + Dy\ \(Y[8]\)[t] + Dy\ \(Y[13]\)[t] + 
                Dy\ \(Y[14]\)[t] - dy\ \(Y[17]\)[t] - 7\ Dy\ \(Y[17]\)[t] + 
                Dy\ \(Y[23]\)[t] + Dy\ \(Y[39]\)[t] + Dy\ \(Y[53]\)[t] + 
                Dy\ \(Y[54]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[18]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[18] + Dy\ \(Y[9]\)[t] + Dy\ \(Y[10]\)[t] - 
                dy\ \(Y[18]\)[t] - 5\ Dy\ \(Y[18]\)[t] + Dy\ \(Y[27]\)[t] + 
                Dy\ \(Y[28]\)[t] + Dy\ \(Y[31]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[19]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[19] + Dy\ \(Y[10]\)[t] - 
                dy\ \(Y[19]\)[t] - 6\ Dy\ \(Y[19]\)[t] + Dy\ \(Y[20]\)[t] + 
                Dy\ \(Y[28]\)[t] + Dy\ \(Y[32]\)[t] + Dy\ \(Y[38]\)[t] + 
                Dy\ \(Y[40]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[20]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[20] + Dy\ \(Y[15]\)[t] + 
                Dy\ \(Y[19]\)[t] - dy\ \(Y[20]\)[t] - 4\ Dy\ \(Y[20]\)[t] + 
                Dy\ \(Y[34]\)[t] + Dy\ \(Y[40]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[21]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[21] + Dy\ \(Y[15]\)[t] - 
                dy\ \(Y[21]\)[t] - 4\ Dy\ \(Y[21]\)[t] + Dy\ \(Y[29]\)[t] + 
                Dy\ \(Y[36]\)[t] + Dy\ \(Y[47]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[22]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[22] + Dy\ \(Y[6]\)[t] + Dy\ \(Y[11]\)[t] + 
                Dy\ \(Y[12]\)[t] - dy\ \(Y[22]\)[t] - 6\ Dy\ \(Y[22]\)[t] + 
                Dy\ \(Y[24]\)[t] + Dy\ \(Y[37]\)[t] + Dy\ \(Y[43]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[23]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[23] + Dy\ \(Y[14]\)[t] + 
                Dy\ \(Y[17]\)[t] - dy\ \(Y[23]\)[t] - 5\ Dy\ \(Y[23]\)[t] + 
                Dy\ \(Y[33]\)[t] + Dy\ \(Y[45]\)[t] + Dy\ \(Y[54]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[24]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[24] + Dy\ \(Y[11]\)[t] + 
                Dy\ \(Y[22]\)[t] - dy\ \(Y[24]\)[t] - 4\ Dy\ \(Y[24]\)[t] + 
                Dy\ \(Y[25]\)[t] + Dy\ \(Y[37]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[25]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[25] + Dy\ \(Y[11]\)[t] + 
                Dy\ \(Y[24]\)[t] - dy\ \(Y[25]\)[t] - 5\ Dy\ \(Y[25]\)[t] + 
                Dy\ \(Y[26]\)[t] + Dy\ \(Y[37]\)[t] + Dy\ \(Y[39]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[26]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[26] + Dy\ \(Y[11]\)[t] + 
                Dy\ \(Y[13]\)[t] + Dy\ \(Y[25]\)[t] - dy\ \(Y[26]\)[t] - 
                4\ Dy\ \(Y[26]\)[t] + Dy\ \(Y[39]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[27]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[27] + Dy\ \(Y[9]\)[t] + Dy\ \(Y[14]\)[t] + 
                Dy\ \(Y[18]\)[t] - dy\ \(Y[27]\)[t] - 5\ Dy\ \(Y[27]\)[t] + 
                Dy\ \(Y[31]\)[t] + Dy\ \(Y[33]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[28]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[28] + Dy\ \(Y[10]\)[t] + 
                Dy\ \(Y[18]\)[t] + Dy\ \(Y[19]\)[t] - dy\ \(Y[28]\)[t] - 
                6\ Dy\ \(Y[28]\)[t] + Dy\ \(Y[31]\)[t] + Dy\ \(Y[32]\)[t] + 
                Dy\ \(Y[44]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[29]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[29] + Dy\ \(Y[15]\)[t] + 
                Dy\ \(Y[21]\)[t] - dy\ \(Y[29]\)[t] - 6\ Dy\ \(Y[29]\)[t] + 
                Dy\ \(Y[35]\)[t] + Dy\ \(Y[47]\)[t] + Dy\ \(Y[49]\)[t] + 
                Dy\ \(Y[57]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[30]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[30] + Dy\ \(Y[12]\)[t] + 
                Dy\ \(Y[16]\)[t] - dy\ \(Y[30]\)[t] - 4\ Dy\ \(Y[30]\)[t] + 
                Dy\ \(Y[43]\)[t] + Dy\ \(Y[50]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[31]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[31] + Dy\ \(Y[18]\)[t] + 
                Dy\ \(Y[27]\)[t] + Dy\ \(Y[28]\)[t] - dy\ \(Y[31]\)[t] - 
                6\ Dy\ \(Y[31]\)[t] + Dy\ \(Y[33]\)[t] + Dy\ \(Y[44]\)[t] + 
                Dy\ \(Y[46]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[32]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[32] + Dy\ \(Y[19]\)[t] + 
                Dy\ \(Y[28]\)[t] - dy\ \(Y[32]\)[t] - 4\ Dy\ \(Y[32]\)[t] + 
                Dy\ \(Y[38]\)[t] + Dy\ \(Y[44]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[33]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[33] + Dy\ \(Y[14]\)[t] + 
                Dy\ \(Y[23]\)[t] + Dy\ \(Y[27]\)[t] + Dy\ \(Y[31]\)[t] - 
                dy\ \(Y[33]\)[t] - 6\ Dy\ \(Y[33]\)[t] + Dy\ \(Y[45]\)[t] + 
                Dy\ \(Y[46]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[34]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[34] + Dy\ \(Y[15]\)[t] + 
                Dy\ \(Y[20]\)[t] - dy\ \(Y[34]\)[t] - 7\ Dy\ \(Y[34]\)[t] + 
                Dy\ \(Y[35]\)[t] + Dy\ \(Y[40]\)[t] + Dy\ \(Y[41]\)[t] + 
                Dy\ \(Y[51]\)[t] + Dy\ \(Y[52]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[35]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[35] + Dy\ \(Y[15]\)[t] + 
                Dy\ \(Y[29]\)[t] + Dy\ \(Y[34]\)[t] - dy\ \(Y[35]\)[t] - 
                6\ Dy\ \(Y[35]\)[t] + Dy\ \(Y[41]\)[t] + Dy\ \(Y[57]\)[t] + 
                Dy\ \(Y[60]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[36]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[36] + Dy\ \(Y[21]\)[t] - 
                dy\ \(Y[36]\)[t] - 4\ Dy\ \(Y[36]\)[t] + Dy\ \(Y[42]\)[t] + 
                Dy\ \(Y[47]\)[t] + Dy\ \(Y[48]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[37]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[37] + Dy\ \(Y[22]\)[t] + 
                Dy\ \(Y[24]\)[t] + Dy\ \(Y[25]\)[t] - dy\ \(Y[37]\)[t] - 
                6\ Dy\ \(Y[37]\)[t] + Dy\ \(Y[39]\)[t] + Dy\ \(Y[43]\)[t] + 
                Dy\ \(Y[59]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[38]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[38] + Dy\ \(Y[19]\)[t] + 
                Dy\ \(Y[32]\)[t] - dy\ \(Y[38]\)[t] - 6\ Dy\ \(Y[38]\)[t] + 
                Dy\ \(Y[40]\)[t] + Dy\ \(Y[44]\)[t] + Dy\ \(Y[56]\)[t] + 
                Dy\ \(Y[67]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[39]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[39] + Dy\ \(Y[13]\)[t] + 
                Dy\ \(Y[17]\)[t] + Dy\ \(Y[25]\)[t] + Dy\ \(Y[26]\)[t] + 
                Dy\ \(Y[37]\)[t] - dy\ \(Y[39]\)[t] - 8\ Dy\ \(Y[39]\)[t] + 
                Dy\ \(Y[53]\)[t] + Dy\ \(Y[59]\)[t] + Dy\ \(Y[65]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[40]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[40] + Dy\ \(Y[19]\)[t] + 
                Dy\ \(Y[20]\)[t] + Dy\ \(Y[34]\)[t] + Dy\ \(Y[38]\)[t] - 
                dy\ \(Y[40]\)[t] - 6\ Dy\ \(Y[40]\)[t] + Dy\ \(Y[51]\)[t] + 
                Dy\ \(Y[56]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[41]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[41] + Dy\ \(Y[34]\)[t] + 
                Dy\ \(Y[35]\)[t] - dy\ \(Y[41]\)[t] - 4\ Dy\ \(Y[41]\)[t] + 
                Dy\ \(Y[52]\)[t] + Dy\ \(Y[60]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[42]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[42] + Dy\ \(Y[36]\)[t] - 
                dy\ \(Y[42]\)[t] - 3\ Dy\ \(Y[42]\)[t] + Dy\ \(Y[48]\)[t] + 
                Dy\ \(Y[58]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[43]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[43] + Dy\ \(Y[22]\)[t] + 
                Dy\ \(Y[30]\)[t] + Dy\ \(Y[37]\)[t] - dy\ \(Y[43]\)[t] - 
                7\ Dy\ \(Y[43]\)[t] + Dy\ \(Y[50]\)[t] + Dy\ \(Y[59]\)[t] + 
                Dy\ \(Y[61]\)[t] + Dy\ \(Y[64]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[44]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[44] + Dy\ \(Y[28]\)[t] + 
                Dy\ \(Y[31]\)[t] + Dy\ \(Y[32]\)[t] + Dy\ \(Y[38]\)[t] - 
                dy\ \(Y[44]\)[t] - 8\ Dy\ \(Y[44]\)[t] + Dy\ \(Y[46]\)[t] + 
                Dy\ \(Y[55]\)[t] + Dy\ \(Y[66]\)[t] + Dy\ \(Y[67]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[45]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[45] + Dy\ \(Y[23]\)[t] + 
                Dy\ \(Y[33]\)[t] - dy\ \(Y[45]\)[t] - 5\ Dy\ \(Y[45]\)[t] + 
                Dy\ \(Y[46]\)[t] + Dy\ \(Y[54]\)[t] + Dy\ \(Y[75]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[46]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[46] + Dy\ \(Y[31]\)[t] + 
                Dy\ \(Y[33]\)[t] + Dy\ \(Y[44]\)[t] + Dy\ \(Y[45]\)[t] - 
                dy\ \(Y[46]\)[t] - 7\ Dy\ \(Y[46]\)[t] + Dy\ \(Y[55]\)[t] + 
                Dy\ \(Y[68]\)[t] + Dy\ \(Y[69]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[47]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[47] + Dy\ \(Y[21]\)[t] + 
                Dy\ \(Y[29]\)[t] + Dy\ \(Y[36]\)[t] - dy\ \(Y[47]\)[t] - 
                6\ Dy\ \(Y[47]\)[t] + Dy\ \(Y[48]\)[t] + Dy\ \(Y[49]\)[t] + 
                Dy\ \(Y[63]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[48]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[48] + Dy\ \(Y[36]\)[t] + 
                Dy\ \(Y[42]\)[t] + Dy\ \(Y[47]\)[t] - dy\ \(Y[48]\)[t] - 
                7\ Dy\ \(Y[48]\)[t] + Dy\ \(Y[58]\)[t] + Dy\ \(Y[63]\)[t] + 
                Dy\ \(Y[73]\)[t] + Dy\ \(Y[77]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[49]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[49] + Dy\ \(Y[29]\)[t] + 
                Dy\ \(Y[47]\)[t] - dy\ \(Y[49]\)[t] - 5\ Dy\ \(Y[49]\)[t] + 
                Dy\ \(Y[57]\)[t] + Dy\ \(Y[63]\)[t] + Dy\ \(Y[76]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[50]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[50] + Dy\ \(Y[30]\)[t] + 
                Dy\ \(Y[43]\)[t] - dy\ \(Y[50]\)[t] - 4\ Dy\ \(Y[50]\)[t] + 
                Dy\ \(Y[61]\)[t] + Dy\ \(Y[82]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[51]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[51] + Dy\ \(Y[34]\)[t] + 
                Dy\ \(Y[40]\)[t] - dy\ \(Y[51]\)[t] - 7\ Dy\ \(Y[51]\)[t] + 
                Dy\ \(Y[52]\)[t] + Dy\ \(Y[56]\)[t] + Dy\ \(Y[71]\)[t] + 
                Dy\ \(Y[72]\)[t] + Dy\ \(Y[84]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[52]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[52] + Dy\ \(Y[34]\)[t] + 
                Dy\ \(Y[41]\)[t] + Dy\ \(Y[51]\)[t] - dy\ \(Y[52]\)[t] - 
                5\ Dy\ \(Y[52]\)[t] + Dy\ \(Y[60]\)[t] + Dy\ \(Y[72]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[53]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[53] + Dy\ \(Y[17]\)[t] + 
                Dy\ \(Y[39]\)[t] - dy\ \(Y[53]\)[t] - 6\ Dy\ \(Y[53]\)[t] + 
                Dy\ \(Y[54]\)[t] + Dy\ \(Y[65]\)[t] + Dy\ \(Y[70]\)[t] + 
                Dy\ \(Y[74]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[54]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[54] + Dy\ \(Y[17]\)[t] + 
                Dy\ \(Y[23]\)[t] + Dy\ \(Y[45]\)[t] + Dy\ \(Y[53]\)[t] - 
                dy\ \(Y[54]\)[t] - 6\ Dy\ \(Y[54]\)[t] + Dy\ \(Y[74]\)[t] + 
                Dy\ \(Y[75]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[55]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[55] + Dy\ \(Y[44]\)[t] + 
                Dy\ \(Y[46]\)[t] - dy\ \(Y[55]\)[t] - 5\ Dy\ \(Y[55]\)[t] + 
                Dy\ \(Y[66]\)[t] + Dy\ \(Y[69]\)[t] + Dy\ \(Y[86]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[56]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[56] + Dy\ \(Y[38]\)[t] + 
                Dy\ \(Y[40]\)[t] + Dy\ \(Y[51]\)[t] - dy\ \(Y[56]\)[t] - 
                6\ Dy\ \(Y[56]\)[t] + Dy\ \(Y[62]\)[t] + Dy\ \(Y[67]\)[t] + 
                Dy\ \(Y[71]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[57]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[57] + Dy\ \(Y[29]\)[t] + 
                Dy\ \(Y[35]\)[t] + Dy\ \(Y[49]\)[t] - dy\ \(Y[57]\)[t] - 
                7\ Dy\ \(Y[57]\)[t] + Dy\ \(Y[60]\)[t] + Dy\ \(Y[76]\)[t] + 
                Dy\ \(Y[81]\)[t] + Dy\ \(Y[85]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[58]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[58] + Dy\ \(Y[42]\)[t] + 
                Dy\ \(Y[48]\)[t] - dy\ \(Y[58]\)[t] - 4\ Dy\ \(Y[58]\)[t] + 
                Dy\ \(Y[77]\)[t] + Dy\ \(Y[78]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[59]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[59] + Dy\ \(Y[37]\)[t] + 
                Dy\ \(Y[39]\)[t] + Dy\ \(Y[43]\)[t] - dy\ \(Y[59]\)[t] - 
                7\ Dy\ \(Y[59]\)[t] + Dy\ \(Y[64]\)[t] + Dy\ \(Y[65]\)[t] + 
                Dy\ \(Y[83]\)[t] + Dy\ \(Y[87]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[60]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[60] + Dy\ \(Y[35]\)[t] + 
                Dy\ \(Y[41]\)[t] + Dy\ \(Y[52]\)[t] + Dy\ \(Y[57]\)[t] - 
                dy\ \(Y[60]\)[t] - 7\ Dy\ \(Y[60]\)[t] + Dy\ \(Y[72]\)[t] + 
                Dy\ \(Y[80]\)[t] + Dy\ \(Y[85]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[61]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[61] + Dy\ \(Y[43]\)[t] + 
                Dy\ \(Y[50]\)[t] - dy\ \(Y[61]\)[t] - 6\ Dy\ \(Y[61]\)[t] + 
                Dy\ \(Y[64]\)[t] + Dy\ \(Y[82]\)[t] + Dy\ \(Y[89]\)[t] + 
                Dy\ \(Y[96]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[62]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[62] + Dy\ \(Y[56]\)[t] - 
                dy\ \(Y[62]\)[t] - 4\ Dy\ \(Y[62]\)[t] + Dy\ \(Y[67]\)[t] + 
                Dy\ \(Y[71]\)[t] + Dy\ \(Y[79]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[63]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[63] + Dy\ \(Y[47]\)[t] + 
                Dy\ \(Y[48]\)[t] + Dy\ \(Y[49]\)[t] - dy\ \(Y[63]\)[t] - 
                5\ Dy\ \(Y[63]\)[t] + Dy\ \(Y[73]\)[t] + Dy\ \(Y[76]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[64]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[64] + Dy\ \(Y[43]\)[t] + 
                Dy\ \(Y[59]\)[t] + Dy\ \(Y[61]\)[t] - dy\ \(Y[64]\)[t] - 
                5\ Dy\ \(Y[64]\)[t] + Dy\ \(Y[83]\)[t] + Dy\ \(Y[96]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[65]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[65] + Dy\ \(Y[39]\)[t] + 
                Dy\ \(Y[53]\)[t] + Dy\ \(Y[59]\)[t] - dy\ \(Y[65]\)[t] - 
                7\ Dy\ \(Y[65]\)[t] + Dy\ \(Y[70]\)[t] + Dy\ \(Y[87]\)[t] + 
                Dy\ \(Y[97]\)[t] + Dy\ \(Y[100]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[66]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[66] + Dy\ \(Y[44]\)[t] + 
                Dy\ \(Y[55]\)[t] - dy\ \(Y[66]\)[t] - 6\ Dy\ \(Y[66]\)[t] + 
                Dy\ \(Y[67]\)[t] + Dy\ \(Y[79]\)[t] + Dy\ \(Y[86]\)[t] + 
                Dy\ \(Y[91]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[67]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[67] + Dy\ \(Y[38]\)[t] + 
                Dy\ \(Y[44]\)[t] + Dy\ \(Y[56]\)[t] + Dy\ \(Y[62]\)[t] + 
                Dy\ \(Y[66]\)[t] - dy\ \(Y[67]\)[t] - 6\ Dy\ \(Y[67]\)[t] + 
                Dy\ \(Y[79]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[68]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[68] + Dy\ \(Y[46]\)[t] - 
                dy\ \(Y[68]\)[t] - 4\ Dy\ \(Y[68]\)[t] + Dy\ \(Y[69]\)[t] + 
                Dy\ \(Y[75]\)[t] + Dy\ \(Y[94]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[69]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[69] + Dy\ \(Y[46]\)[t] + 
                Dy\ \(Y[55]\)[t] + Dy\ \(Y[68]\)[t] - dy\ \(Y[69]\)[t] - 
                6\ Dy\ \(Y[69]\)[t] + Dy\ \(Y[86]\)[t] + Dy\ \(Y[94]\)[t] + 
                Dy\ \(Y[98]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[70]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[70] + Dy\ \(Y[53]\)[t] + 
                Dy\ \(Y[65]\)[t] - dy\ \(Y[70]\)[t] - 5\ Dy\ \(Y[70]\)[t] + 
                Dy\ \(Y[74]\)[t] + Dy\ \(Y[93]\)[t] + Dy\ \(Y[97]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[71]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[71] + Dy\ \(Y[51]\)[t] + 
                Dy\ \(Y[56]\)[t] + Dy\ \(Y[62]\)[t] - dy\ \(Y[71]\)[t] - 
                5\ Dy\ \(Y[71]\)[t] + Dy\ \(Y[79]\)[t] + Dy\ \(Y[84]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[72]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[72] + Dy\ \(Y[51]\)[t] + 
                Dy\ \(Y[52]\)[t] + Dy\ \(Y[60]\)[t] - dy\ \(Y[72]\)[t] - 
                6\ Dy\ \(Y[72]\)[t] + Dy\ \(Y[80]\)[t] + Dy\ \(Y[84]\)[t] + 
                Dy\ \(Y[102]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[73]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[73] + Dy\ \(Y[48]\)[t] + 
                Dy\ \(Y[63]\)[t] - dy\ \(Y[73]\)[t] - 5\ Dy\ \(Y[73]\)[t] + 
                Dy\ \(Y[76]\)[t] + Dy\ \(Y[77]\)[t] + Dy\ \(Y[92]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[74]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[74] + Dy\ \(Y[53]\)[t] + 
                Dy\ \(Y[54]\)[t] + Dy\ \(Y[70]\)[t] - dy\ \(Y[74]\)[t] - 
                6\ Dy\ \(Y[74]\)[t] + Dy\ \(Y[75]\)[t] + Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[93]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[75]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[75] + Dy\ \(Y[45]\)[t] + 
                Dy\ \(Y[54]\)[t] + Dy\ \(Y[68]\)[t] + Dy\ \(Y[74]\)[t] - 
                dy\ \(Y[75]\)[t] - 6\ Dy\ \(Y[75]\)[t] + Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[94]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[76]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[76] + Dy\ \(Y[49]\)[t] + 
                Dy\ \(Y[57]\)[t] + Dy\ \(Y[63]\)[t] + Dy\ \(Y[73]\)[t] - 
                dy\ \(Y[76]\)[t] - 7\ Dy\ \(Y[76]\)[t] + Dy\ \(Y[81]\)[t] + 
                Dy\ \(Y[92]\)[t] + Dy\ \(Y[95]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[77]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[77] + Dy\ \(Y[48]\)[t] + 
                Dy\ \(Y[58]\)[t] + Dy\ \(Y[73]\)[t] - dy\ \(Y[77]\)[t] - 
                7\ Dy\ \(Y[77]\)[t] + Dy\ \(Y[78]\)[t] + Dy\ \(Y[92]\)[t] + 
                Dy\ \(Y[103]\)[t] + Dy\ \(Y[107]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[78]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[78] + Dy\ \(Y[58]\)[t] + 
                Dy\ \(Y[77]\)[t] - dy\ \(Y[78]\)[t] - 3\ Dy\ \(Y[78]\)[t] + 
                Dy\ \(Y[107]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[79]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[79] + Dy\ \(Y[62]\)[t] + 
                Dy\ \(Y[66]\)[t] + Dy\ \(Y[67]\)[t] + Dy\ \(Y[71]\)[t] - 
                dy\ \(Y[79]\)[t] - 8\ Dy\ \(Y[79]\)[t] + Dy\ \(Y[84]\)[t] + 
                Dy\ \(Y[91]\)[t] + Dy\ \(Y[99]\)[t] + Dy\ \(Y[101]\)[t]\)}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[80]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[80] + Dy\ \(Y[60]\)[t] + 
                Dy\ \(Y[72]\)[t] - dy\ \(Y[80]\)[t] - 6\ Dy\ \(Y[80]\)[t] + 
                Dy\ \(Y[85]\)[t] + Dy\ \(Y[88]\)[t] + Dy\ \(Y[102]\)[t] + 
                Dy\ \(Y[110]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[81]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[81] + Dy\ \(Y[57]\)[t] + 
                Dy\ \(Y[76]\)[t] - dy\ \(Y[81]\)[t] - 4\ Dy\ \(Y[81]\)[t] + 
                Dy\ \(Y[85]\)[t] + Dy\ \(Y[95]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[82]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[82] + Dy\ \(Y[50]\)[t] + 
                Dy\ \(Y[61]\)[t] - dy\ \(Y[82]\)[t] - 4\ Dy\ \(Y[82]\)[t] + 
                Dy\ \(Y[89]\)[t] + Dy\ \(Y[113]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[83]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[83] + Dy\ \(Y[59]\)[t] + 
                Dy\ \(Y[64]\)[t] - dy\ \(Y[83]\)[t] - 6\ Dy\ \(Y[83]\)[t] + 
                Dy\ \(Y[87]\)[t] + Dy\ \(Y[96]\)[t] + Dy\ \(Y[100]\)[t] + 
                Dy\ \(Y[123]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[84]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[84] + Dy\ \(Y[51]\)[t] + 
                Dy\ \(Y[71]\)[t] + Dy\ \(Y[72]\)[t] + Dy\ \(Y[79]\)[t] - 
                dy\ \(Y[84]\)[t] - 7\ Dy\ \(Y[84]\)[t] + Dy\ \(Y[101]\)[t] + 
                Dy\ \(Y[102]\)[t] + Dy\ \(Y[109]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[85]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[85] + Dy\ \(Y[57]\)[t] + 
                Dy\ \(Y[60]\)[t] + Dy\ \(Y[80]\)[t] + Dy\ \(Y[81]\)[t] - 
                dy\ \(Y[85]\)[t] - 6\ Dy\ \(Y[85]\)[t] + Dy\ \(Y[88]\)[t] + 
                Dy\ \(Y[95]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[86]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[86] + Dy\ \(Y[55]\)[t] + 
                Dy\ \(Y[66]\)[t] + Dy\ \(Y[69]\)[t] - dy\ \(Y[86]\)[t] - 
                6\ Dy\ \(Y[86]\)[t] + Dy\ \(Y[91]\)[t] + Dy\ \(Y[98]\)[t] + 
                Dy\ \(Y[106]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[87]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[87] + Dy\ \(Y[59]\)[t] + 
                Dy\ \(Y[65]\)[t] + Dy\ \(Y[83]\)[t] - dy\ \(Y[87]\)[t] - 
                4\ Dy\ \(Y[87]\)[t] + Dy\ \(Y[100]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[88]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[88] + Dy\ \(Y[80]\)[t] + 
                Dy\ \(Y[85]\)[t] - dy\ \(Y[88]\)[t] - 6\ Dy\ \(Y[88]\)[t] + 
                Dy\ \(Y[95]\)[t] + Dy\ \(Y[110]\)[t] + Dy\ \(Y[112]\)[t] + 
                Dy\ \(Y[120]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[89]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[89] + Dy\ \(Y[61]\)[t] + 
                Dy\ \(Y[82]\)[t] - dy\ \(Y[89]\)[t] - 4\ Dy\ \(Y[89]\)[t] + 
                Dy\ \(Y[96]\)[t] + Dy\ \(Y[113]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[90]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[90] + Dy\ \(Y[74]\)[t] + 
                Dy\ \(Y[75]\)[t] - dy\ \(Y[90]\)[t] - 6\ Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[93]\)[t] + Dy\ \(Y[105]\)[t] + Dy\ \(Y[108]\)[t] + 
                Dy\ \(Y[116]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[91]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[91] + Dy\ \(Y[66]\)[t] + 
                Dy\ \(Y[79]\)[t] + Dy\ \(Y[86]\)[t] - dy\ \(Y[91]\)[t] - 
                6\ Dy\ \(Y[91]\)[t] + Dy\ \(Y[99]\)[t] + Dy\ \(Y[106]\)[t] + 
                Dy\ \(Y[118]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[92]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[92] + Dy\ \(Y[73]\)[t] + 
                Dy\ \(Y[76]\)[t] + Dy\ \(Y[77]\)[t] - dy\ \(Y[92]\)[t] - 
                6\ Dy\ \(Y[92]\)[t] + Dy\ \(Y[95]\)[t] + Dy\ \(Y[103]\)[t] + 
                Dy\ \(Y[111]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[93]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[93] + Dy\ \(Y[70]\)[t] + 
                Dy\ \(Y[74]\)[t] + Dy\ \(Y[90]\)[t] - dy\ \(Y[93]\)[t] - 
                7\ Dy\ \(Y[93]\)[t] + Dy\ \(Y[97]\)[t] + Dy\ \(Y[104]\)[t] + 
                Dy\ \(Y[105]\)[t] + Dy\ \(Y[115]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[94]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[94] + Dy\ \(Y[68]\)[t] + 
                Dy\ \(Y[69]\)[t] + Dy\ \(Y[75]\)[t] - dy\ \(Y[94]\)[t] - 
                6\ Dy\ \(Y[94]\)[t] + Dy\ \(Y[98]\)[t] + Dy\ \(Y[108]\)[t] + 
                Dy\ \(Y[117]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[95]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[95] + Dy\ \(Y[76]\)[t] + 
                Dy\ \(Y[81]\)[t] + Dy\ \(Y[85]\)[t] + Dy\ \(Y[88]\)[t] + 
                Dy\ \(Y[92]\)[t] - dy\ \(Y[95]\)[t] - 8\ Dy\ \(Y[95]\)[t] + 
                Dy\ \(Y[111]\)[t] + Dy\ \(Y[120]\)[t] + Dy\ \(Y[121]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[96]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[96] + Dy\ \(Y[61]\)[t] + 
                Dy\ \(Y[64]\)[t] + Dy\ \(Y[83]\)[t] + Dy\ \(Y[89]\)[t] - 
                dy\ \(Y[96]\)[t] - 7\ Dy\ \(Y[96]\)[t] + Dy\ \(Y[113]\)[t] + 
                Dy\ \(Y[123]\)[t] + Dy\ \(Y[127]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[97]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[97] + Dy\ \(Y[65]\)[t] + 
                Dy\ \(Y[70]\)[t] + Dy\ \(Y[93]\)[t] - dy\ \(Y[97]\)[t] - 
                6\ Dy\ \(Y[97]\)[t] + Dy\ \(Y[100]\)[t] + Dy\ \(Y[104]\)[t] + 
                Dy\ \(Y[124]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[98]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[98] + Dy\ \(Y[69]\)[t] + 
                Dy\ \(Y[86]\)[t] + Dy\ \(Y[94]\)[t] - dy\ \(Y[98]\)[t] - 
                6\ Dy\ \(Y[98]\)[t] + Dy\ \(Y[106]\)[t] + Dy\ \(Y[117]\)[t] + 
                Dy\ \(Y[125]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[99]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[99] + Dy\ \(Y[79]\)[t] + 
                Dy\ \(Y[91]\)[t] - dy\ \(Y[99]\)[t] - 5\ Dy\ \(Y[99]\)[t] + 
                Dy\ \(Y[101]\)[t] + Dy\ \(Y[118]\)[t] + Dy\ \(Y[119]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[100]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[100] + Dy\ \(Y[65]\)[t] + 
                Dy\ \(Y[83]\)[t] + Dy\ \(Y[87]\)[t] + Dy\ \(Y[97]\)[t] - 
                dy\ \(Y[100]\)[t] - 8\ Dy\ \(Y[100]\)[t] + 
                Dy\ \(Y[114]\)[t] + Dy\ \(Y[123]\)[t] + Dy\ \(Y[124]\)[t] + 
                Dy\ \(Y[132]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[101]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[101] + Dy\ \(Y[79]\)[t] + 
                Dy\ \(Y[84]\)[t] + Dy\ \(Y[99]\)[t] - dy\ \(Y[101]\)[t] - 
                6\ Dy\ \(Y[101]\)[t] + Dy\ \(Y[109]\)[t] + 
                Dy\ \(Y[119]\)[t] + Dy\ \(Y[131]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[102]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[102] + Dy\ \(Y[72]\)[t] + 
                Dy\ \(Y[80]\)[t] + Dy\ \(Y[84]\)[t] - dy\ \(Y[102]\)[t] - 
                6\ Dy\ \(Y[102]\)[t] + Dy\ \(Y[109]\)[t] + 
                Dy\ \(Y[110]\)[t] + Dy\ \(Y[129]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[103]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[103] + Dy\ \(Y[77]\)[t] + 
                Dy\ \(Y[92]\)[t] - dy\ \(Y[103]\)[t] - 6\ Dy\ \(Y[103]\)[t] + 
                Dy\ \(Y[107]\)[t] + Dy\ \(Y[111]\)[t] + Dy\ \(Y[136]\)[t] + 
                Dy\ \(Y[137]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[104]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[104] + Dy\ \(Y[93]\)[t] + 
                Dy\ \(Y[97]\)[t] - dy\ \(Y[104]\)[t] - 6\ Dy\ \(Y[104]\)[t] + 
                Dy\ \(Y[115]\)[t] + Dy\ \(Y[124]\)[t] + Dy\ \(Y[128]\)[t] + 
                Dy\ \(Y[130]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[105]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[105] + Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[93]\)[t] - dy\ \(Y[105]\)[t] - 4\ Dy\ \(Y[105]\)[t] + 
                Dy\ \(Y[115]\)[t] + Dy\ \(Y[116]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[106]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[106] + Dy\ \(Y[86]\)[t] + 
                Dy\ \(Y[91]\)[t] + Dy\ \(Y[98]\)[t] - dy\ \(Y[106]\)[t] - 
                5\ Dy\ \(Y[106]\)[t] + Dy\ \(Y[118]\)[t] + 
                Dy\ \(Y[125]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[107]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[107] + Dy\ \(Y[77]\)[t] + 
                Dy\ \(Y[78]\)[t] + Dy\ \(Y[103]\)[t] - dy\ \(Y[107]\)[t] - 
                5\ Dy\ \(Y[107]\)[t] + Dy\ \(Y[122]\)[t] + 
                Dy\ \(Y[137]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[108]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[108] + Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[94]\)[t] - dy\ \(Y[108]\)[t] - 4\ Dy\ \(Y[108]\)[t] + 
                Dy\ \(Y[116]\)[t] + Dy\ \(Y[117]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[109]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[109] + Dy\ \(Y[84]\)[t] + 
                Dy\ \(Y[101]\)[t] + Dy\ \(Y[102]\)[t] - dy\ \(Y[109]\)[t] - 
                5\ Dy\ \(Y[109]\)[t] + Dy\ \(Y[129]\)[t] + 
                Dy\ \(Y[131]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[110]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[110] + Dy\ \(Y[80]\)[t] + 
                Dy\ \(Y[88]\)[t] + Dy\ \(Y[102]\)[t] - dy\ \(Y[110]\)[t] - 
                5\ Dy\ \(Y[110]\)[t] + Dy\ \(Y[112]\)[t] + 
                Dy\ \(Y[129]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[111]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[111] + Dy\ \(Y[92]\)[t] + 
                Dy\ \(Y[95]\)[t] + Dy\ \(Y[103]\)[t] - dy\ \(Y[111]\)[t] - 
                5\ Dy\ \(Y[111]\)[t] + Dy\ \(Y[121]\)[t] + 
                Dy\ \(Y[136]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[112]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[112] + Dy\ \(Y[88]\)[t] + 
                Dy\ \(Y[110]\)[t] - dy\ \(Y[112]\)[t] - 
                6\ Dy\ \(Y[112]\)[t] + Dy\ \(Y[120]\)[t] + 
                Dy\ \(Y[129]\)[t] + Dy\ \(Y[144]\)[t] + Dy\ \(Y[149]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[113]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[113] + Dy\ \(Y[82]\)[t] + 
                Dy\ \(Y[89]\)[t] + Dy\ \(Y[96]\)[t] - dy\ \(Y[113]\)[t] - 
                5\ Dy\ \(Y[113]\)[t] + Dy\ \(Y[127]\)[t] + 
                Dy\ \(Y[134]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[114]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[114] + Dy\ \(Y[100]\)[t] - 
                dy\ \(Y[114]\)[t] - 4\ Dy\ \(Y[114]\)[t] + 
                Dy\ \(Y[124]\)[t] + Dy\ \(Y[132]\)[t] + Dy\ \(Y[145]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[115]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[115] + Dy\ \(Y[93]\)[t] + 
                Dy\ \(Y[104]\)[t] + Dy\ \(Y[105]\)[t] - dy\ \(Y[115]\)[t] - 
                6\ Dy\ \(Y[115]\)[t] + Dy\ \(Y[116]\)[t] + 
                Dy\ \(Y[130]\)[t] + Dy\ \(Y[142]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[116]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[116] + Dy\ \(Y[90]\)[t] + 
                Dy\ \(Y[105]\)[t] + Dy\ \(Y[108]\)[t] + Dy\ \(Y[115]\)[t] - 
                dy\ \(Y[116]\)[t] - 6\ Dy\ \(Y[116]\)[t] + 
                Dy\ \(Y[117]\)[t] + Dy\ \(Y[143]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[117]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[117] + Dy\ \(Y[94]\)[t] + 
                Dy\ \(Y[98]\)[t] + Dy\ \(Y[108]\)[t] + Dy\ \(Y[116]\)[t] - 
                dy\ \(Y[117]\)[t] - 7\ Dy\ \(Y[117]\)[t] + 
                Dy\ \(Y[125]\)[t] + Dy\ \(Y[143]\)[t] + Dy\ \(Y[154]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[118]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[118] + Dy\ \(Y[91]\)[t] + 
                Dy\ \(Y[99]\)[t] + Dy\ \(Y[106]\)[t] - dy\ \(Y[118]\)[t] - 
                6\ Dy\ \(Y[118]\)[t] + Dy\ \(Y[119]\)[t] + 
                Dy\ \(Y[125]\)[t] + Dy\ \(Y[135]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[119]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[119] + Dy\ \(Y[99]\)[t] + 
                Dy\ \(Y[101]\)[t] + Dy\ \(Y[118]\)[t] - dy\ \(Y[119]\)[t] - 
                5\ Dy\ \(Y[119]\)[t] + Dy\ \(Y[131]\)[t] + 
                Dy\ \(Y[135]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[120]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[120] + Dy\ \(Y[88]\)[t] + 
                Dy\ \(Y[95]\)[t] + Dy\ \(Y[112]\)[t] - dy\ \(Y[120]\)[t] - 
                6\ Dy\ \(Y[120]\)[t] + Dy\ \(Y[121]\)[t] + 
                Dy\ \(Y[126]\)[t] + Dy\ \(Y[149]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[121]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[121] + Dy\ \(Y[95]\)[t] + 
                Dy\ \(Y[111]\)[t] + Dy\ \(Y[120]\)[t] - dy\ \(Y[121]\)[t] - 
                7\ Dy\ \(Y[121]\)[t] + Dy\ \(Y[126]\)[t] + 
                Dy\ \(Y[136]\)[t] + Dy\ \(Y[138]\)[t] + Dy\ \(Y[139]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[122]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[122] + Dy\ \(Y[107]\)[t] - 
                dy\ \(Y[122]\)[t] - 3\ Dy\ \(Y[122]\)[t] + 
                Dy\ \(Y[137]\)[t] + Dy\ \(Y[150]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[123]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[123] + Dy\ \(Y[83]\)[t] + 
                Dy\ \(Y[96]\)[t] + Dy\ \(Y[100]\)[t] - dy\ \(Y[123]\)[t] - 
                6\ Dy\ \(Y[123]\)[t] + Dy\ \(Y[127]\)[t] + 
                Dy\ \(Y[132]\)[t] + Dy\ \(Y[141]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[124]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[124] + Dy\ \(Y[97]\)[t] + 
                Dy\ \(Y[100]\)[t] + Dy\ \(Y[104]\)[t] + Dy\ \(Y[114]\)[t] - 
                dy\ \(Y[124]\)[t] - 7\ Dy\ \(Y[124]\)[t] + 
                Dy\ \(Y[128]\)[t] + Dy\ \(Y[140]\)[t] + Dy\ \(Y[145]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[125]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[125] + Dy\ \(Y[98]\)[t] + 
                Dy\ \(Y[106]\)[t] + Dy\ \(Y[117]\)[t] + Dy\ \(Y[118]\)[t] - 
                dy\ \(Y[125]\)[t] - 8\ Dy\ \(Y[125]\)[t] + 
                Dy\ \(Y[135]\)[t] + Dy\ \(Y[154]\)[t] + Dy\ \(Y[155]\)[t] + 
                Dy\ \(Y[162]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[126]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[126] + Dy\ \(Y[120]\)[t] + 
                Dy\ \(Y[121]\)[t] - dy\ \(Y[126]\)[t] - 
                4\ Dy\ \(Y[126]\)[t] + Dy\ \(Y[138]\)[t] + 
                Dy\ \(Y[149]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[127]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[127] + Dy\ \(Y[96]\)[t] + 
                Dy\ \(Y[113]\)[t] + Dy\ \(Y[123]\)[t] - dy\ \(Y[127]\)[t] - 
                5\ Dy\ \(Y[127]\)[t] + Dy\ \(Y[134]\)[t] + 
                Dy\ \(Y[141]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[128]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[128] + Dy\ \(Y[104]\)[t] + 
                Dy\ \(Y[124]\)[t] - dy\ \(Y[128]\)[t] - 
                4\ Dy\ \(Y[128]\)[t] + Dy\ \(Y[130]\)[t] + 
                Dy\ \(Y[140]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[129]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[129] + Dy\ \(Y[102]\)[t] + 
                Dy\ \(Y[109]\)[t] + Dy\ \(Y[110]\)[t] + Dy\ \(Y[112]\)[t] - 
                dy\ \(Y[129]\)[t] - 7\ Dy\ \(Y[129]\)[t] + 
                Dy\ \(Y[131]\)[t] + Dy\ \(Y[133]\)[t] + Dy\ \(Y[144]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[130]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[130] + Dy\ \(Y[104]\)[t] + 
                Dy\ \(Y[115]\)[t] + Dy\ \(Y[128]\)[t] - dy\ \(Y[130]\)[t] - 
                7\ Dy\ \(Y[130]\)[t] + Dy\ \(Y[140]\)[t] + 
                Dy\ \(Y[142]\)[t] + Dy\ \(Y[146]\)[t] + Dy\ \(Y[156]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[131]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[131] + Dy\ \(Y[101]\)[t] + 
                Dy\ \(Y[109]\)[t] + Dy\ \(Y[119]\)[t] + Dy\ \(Y[129]\)[t] - 
                dy\ \(Y[131]\)[t] - 9\ Dy\ \(Y[131]\)[t] + 
                Dy\ \(Y[133]\)[t] + Dy\ \(Y[135]\)[t] + Dy\ \(Y[147]\)[t] + 
                Dy\ \(Y[148]\)[t] + Dy\ \(Y[158]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[132]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[132] + Dy\ \(Y[100]\)[t] + 
                Dy\ \(Y[114]\)[t] + Dy\ \(Y[123]\)[t] - dy\ \(Y[132]\)[t] - 
                6\ Dy\ \(Y[132]\)[t] + Dy\ \(Y[141]\)[t] + 
                Dy\ \(Y[145]\)[t] + Dy\ \(Y[164]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[133]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[133] + Dy\ \(Y[129]\)[t] + 
                Dy\ \(Y[131]\)[t] - dy\ \(Y[133]\)[t] - 
                4\ Dy\ \(Y[133]\)[t] + Dy\ \(Y[144]\)[t] + 
                Dy\ \(Y[148]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[134]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[134] + Dy\ \(Y[113]\)[t] + 
                Dy\ \(Y[127]\)[t] - dy\ \(Y[134]\)[t] - 
                5\ Dy\ \(Y[134]\)[t] + Dy\ \(Y[141]\)[t] + 
                Dy\ \(Y[152]\)[t] + Dy\ \(Y[153]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[135]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[135] + Dy\ \(Y[118]\)[t] + 
                Dy\ \(Y[119]\)[t] + Dy\ \(Y[125]\)[t] + Dy\ \(Y[131]\)[t] - 
                dy\ \(Y[135]\)[t] - 6\ Dy\ \(Y[135]\)[t] + 
                Dy\ \(Y[147]\)[t] + Dy\ \(Y[155]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[136]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[136] + Dy\ \(Y[103]\)[t] + 
                Dy\ \(Y[111]\)[t] + Dy\ \(Y[121]\)[t] - dy\ \(Y[136]\)[t] - 
                7\ Dy\ \(Y[136]\)[t] + Dy\ \(Y[137]\)[t] + 
                Dy\ \(Y[139]\)[t] + Dy\ \(Y[157]\)[t] + Dy\ \(Y[159]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[137]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[137] + Dy\ \(Y[103]\)[t] + 
                Dy\ \(Y[107]\)[t] + Dy\ \(Y[122]\)[t] + Dy\ \(Y[136]\)[t] - 
                dy\ \(Y[137]\)[t] - 7\ Dy\ \(Y[137]\)[t] + 
                Dy\ \(Y[150]\)[t] + Dy\ \(Y[159]\)[t] + Dy\ \(Y[171]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[138]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[138] + Dy\ \(Y[121]\)[t] + 
                Dy\ \(Y[126]\)[t] - dy\ \(Y[138]\)[t] - 
                7\ Dy\ \(Y[138]\)[t] + Dy\ \(Y[139]\)[t] + 
                Dy\ \(Y[149]\)[t] + Dy\ \(Y[157]\)[t] + Dy\ \(Y[163]\)[t] + 
                Dy\ \(Y[170]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[139]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[139] + Dy\ \(Y[121]\)[t] + 
                Dy\ \(Y[136]\)[t] + Dy\ \(Y[138]\)[t] - dy\ \(Y[139]\)[t] - 
                4\ Dy\ \(Y[139]\)[t] + Dy\ \(Y[157]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[140]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[140] + Dy\ \(Y[124]\)[t] + 
                Dy\ \(Y[128]\)[t] + Dy\ \(Y[130]\)[t] - dy\ \(Y[140]\)[t] - 
                5\ Dy\ \(Y[140]\)[t] + Dy\ \(Y[145]\)[t] + 
                Dy\ \(Y[156]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[141]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[141] + Dy\ \(Y[123]\)[t] + 
                Dy\ \(Y[127]\)[t] + Dy\ \(Y[132]\)[t] + Dy\ \(Y[134]\)[t] - 
                dy\ \(Y[141]\)[t] - 6\ Dy\ \(Y[141]\)[t] + 
                Dy\ \(Y[153]\)[t] + Dy\ \(Y[164]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[142]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[142] + Dy\ \(Y[115]\)[t] + 
                Dy\ \(Y[130]\)[t] - dy\ \(Y[142]\)[t] - 
                5\ Dy\ \(Y[142]\)[t] + Dy\ \(Y[143]\)[t] + 
                Dy\ \(Y[146]\)[t] + Dy\ \(Y[151]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[143]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[143] + Dy\ \(Y[116]\)[t] + 
                Dy\ \(Y[117]\)[t] + Dy\ \(Y[142]\)[t] - dy\ \(Y[143]\)[t] - 
                5\ Dy\ \(Y[143]\)[t] + Dy\ \(Y[151]\)[t] + 
                Dy\ \(Y[154]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[144]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[144] + Dy\ \(Y[112]\)[t] + 
                Dy\ \(Y[129]\)[t] + Dy\ \(Y[133]\)[t] - dy\ \(Y[144]\)[t] - 
                7\ Dy\ \(Y[144]\)[t] + Dy\ \(Y[148]\)[t] + 
                Dy\ \(Y[149]\)[t] + Dy\ \(Y[165]\)[t] + Dy\ \(Y[169]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[145]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[145] + Dy\ \(Y[114]\)[t] + 
                Dy\ \(Y[124]\)[t] + Dy\ \(Y[132]\)[t] + Dy\ \(Y[140]\)[t] - 
                dy\ \(Y[145]\)[t] - 8\ Dy\ \(Y[145]\)[t] + 
                Dy\ \(Y[156]\)[t] + Dy\ \(Y[160]\)[t] + Dy\ \(Y[164]\)[t] + 
                Dy\ \(Y[188]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[146]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[146] + Dy\ \(Y[130]\)[t] + 
                Dy\ \(Y[142]\)[t] - dy\ \(Y[146]\)[t] - 
                5\ Dy\ \(Y[146]\)[t] + Dy\ \(Y[151]\)[t] + 
                Dy\ \(Y[156]\)[t] + Dy\ \(Y[161]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[147]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[147] + Dy\ \(Y[131]\)[t] + 
                Dy\ \(Y[135]\)[t] - dy\ \(Y[147]\)[t] - 
                5\ Dy\ \(Y[147]\)[t] + Dy\ \(Y[155]\)[t] + 
                Dy\ \(Y[158]\)[t] + Dy\ \(Y[167]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[148]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[148] + Dy\ \(Y[131]\)[t] + 
                Dy\ \(Y[133]\)[t] + Dy\ \(Y[144]\)[t] - dy\ \(Y[148]\)[t] - 
                6\ Dy\ \(Y[148]\)[t] + Dy\ \(Y[158]\)[t] + 
                Dy\ \(Y[168]\)[t] + Dy\ \(Y[169]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[149]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[149] + Dy\ \(Y[112]\)[t] + 
                Dy\ \(Y[120]\)[t] + Dy\ \(Y[126]\)[t] + Dy\ \(Y[138]\)[t] + 
                Dy\ \(Y[144]\)[t] - dy\ \(Y[149]\)[t] - 
                7\ Dy\ \(Y[149]\)[t] + Dy\ \(Y[163]\)[t] + 
                Dy\ \(Y[165]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[150]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[150] + Dy\ \(Y[122]\)[t] + 
                Dy\ \(Y[137]\)[t] - dy\ \(Y[150]\)[t] - 
                3\ Dy\ \(Y[150]\)[t] + Dy\ \(Y[171]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[151]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[151] + Dy\ \(Y[142]\)[t] + 
                Dy\ \(Y[143]\)[t] + Dy\ \(Y[146]\)[t] - dy\ \(Y[151]\)[t] - 
                7\ Dy\ \(Y[151]\)[t] + Dy\ \(Y[154]\)[t] + 
                Dy\ \(Y[161]\)[t] + Dy\ \(Y[166]\)[t] + Dy\ \(Y[175]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[152]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[152] + Dy\ \(Y[134]\)[t] - 
                dy\ \(Y[152]\)[t] - 4\ Dy\ \(Y[152]\)[t] + 
                Dy\ \(Y[153]\)[t] + Dy\ \(Y[172]\)[t] + Dy\ \(Y[178]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[153]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[153] + Dy\ \(Y[134]\)[t] + 
                Dy\ \(Y[141]\)[t] + Dy\ \(Y[152]\)[t] - dy\ \(Y[153]\)[t] - 
                6\ Dy\ \(Y[153]\)[t] + Dy\ \(Y[164]\)[t] + 
                Dy\ \(Y[172]\)[t] + Dy\ \(Y[176]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[154]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[154] + Dy\ \(Y[117]\)[t] + 
                Dy\ \(Y[125]\)[t] + Dy\ \(Y[143]\)[t] + Dy\ \(Y[151]\)[t] - 
                dy\ \(Y[154]\)[t] - 6\ Dy\ \(Y[154]\)[t] + 
                Dy\ \(Y[162]\)[t] + Dy\ \(Y[166]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[155]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[155] + Dy\ \(Y[125]\)[t] + 
                Dy\ \(Y[135]\)[t] + Dy\ \(Y[147]\)[t] - dy\ \(Y[155]\)[t] - 
                6\ Dy\ \(Y[155]\)[t] + Dy\ \(Y[162]\)[t] + 
                Dy\ \(Y[167]\)[t] + Dy\ \(Y[173]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[156]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[156] + Dy\ \(Y[130]\)[t] + 
                Dy\ \(Y[140]\)[t] + Dy\ \(Y[145]\)[t] + Dy\ \(Y[146]\)[t] - 
                dy\ \(Y[156]\)[t] - 6\ Dy\ \(Y[156]\)[t] + 
                Dy\ \(Y[160]\)[t] + Dy\ \(Y[161]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[157]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[157] + Dy\ \(Y[136]\)[t] + 
                Dy\ \(Y[138]\)[t] + Dy\ \(Y[139]\)[t] - dy\ \(Y[157]\)[t] - 
                5\ Dy\ \(Y[157]\)[t] + Dy\ \(Y[159]\)[t] + 
                Dy\ \(Y[170]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[158]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[158] + Dy\ \(Y[131]\)[t] + 
                Dy\ \(Y[147]\)[t] + Dy\ \(Y[148]\)[t] - dy\ \(Y[158]\)[t] - 
                6\ Dy\ \(Y[158]\)[t] + Dy\ \(Y[167]\)[t] + 
                Dy\ \(Y[168]\)[t] + Dy\ \(Y[179]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[159]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[159] + Dy\ \(Y[136]\)[t] + 
                Dy\ \(Y[137]\)[t] + Dy\ \(Y[157]\)[t] - dy\ \(Y[159]\)[t] - 
                7\ Dy\ \(Y[159]\)[t] + Dy\ \(Y[170]\)[t] + 
                Dy\ \(Y[171]\)[t] + Dy\ \(Y[181]\)[t] + Dy\ \(Y[182]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[160]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[160] + Dy\ \(Y[145]\)[t] + 
                Dy\ \(Y[156]\)[t] - dy\ \(Y[160]\)[t] - 
                5\ Dy\ \(Y[160]\)[t] + Dy\ \(Y[161]\)[t] + 
                Dy\ \(Y[186]\)[t] + Dy\ \(Y[188]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[161]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[161] + Dy\ \(Y[146]\)[t] + 
                Dy\ \(Y[151]\)[t] + Dy\ \(Y[156]\)[t] + Dy\ \(Y[160]\)[t] - 
                dy\ \(Y[161]\)[t] - 7\ Dy\ \(Y[161]\)[t] + 
                Dy\ \(Y[175]\)[t] + Dy\ \(Y[186]\)[t] + Dy\ \(Y[190]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[162]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[162] + Dy\ \(Y[125]\)[t] + 
                Dy\ \(Y[154]\)[t] + Dy\ \(Y[155]\)[t] - dy\ \(Y[162]\)[t] - 
                7\ Dy\ \(Y[162]\)[t] + Dy\ \(Y[166]\)[t] + 
                Dy\ \(Y[173]\)[t] + Dy\ \(Y[183]\)[t] + Dy\ \(Y[184]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[163]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[163] + Dy\ \(Y[138]\)[t] + 
                Dy\ \(Y[149]\)[t] - dy\ \(Y[163]\)[t] - 
                5\ Dy\ \(Y[163]\)[t] + Dy\ \(Y[165]\)[t] + 
                Dy\ \(Y[170]\)[t] + Dy\ \(Y[180]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[164]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[164] + Dy\ \(Y[132]\)[t] + 
                Dy\ \(Y[141]\)[t] + Dy\ \(Y[145]\)[t] + Dy\ \(Y[153]\)[t] - 
                dy\ \(Y[164]\)[t] - 7\ Dy\ \(Y[164]\)[t] + 
                Dy\ \(Y[176]\)[t] + Dy\ \(Y[188]\)[t] + Dy\ \(Y[201]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[165]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[165] + Dy\ \(Y[144]\)[t] + 
                Dy\ \(Y[149]\)[t] + Dy\ \(Y[163]\)[t] - dy\ \(Y[165]\)[t] - 
                6\ Dy\ \(Y[165]\)[t] + Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[177]\)[t] + Dy\ \(Y[180]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[166]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[166] + Dy\ \(Y[151]\)[t] + 
                Dy\ \(Y[154]\)[t] + Dy\ \(Y[162]\)[t] - dy\ \(Y[166]\)[t] - 
                5\ Dy\ \(Y[166]\)[t] + Dy\ \(Y[175]\)[t] + 
                Dy\ \(Y[183]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[167]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[167] + Dy\ \(Y[147]\)[t] + 
                Dy\ \(Y[155]\)[t] + Dy\ \(Y[158]\)[t] - dy\ \(Y[167]\)[t] - 
                6\ Dy\ \(Y[167]\)[t] + Dy\ \(Y[173]\)[t] + 
                Dy\ \(Y[174]\)[t] + Dy\ \(Y[179]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[168]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[168] + Dy\ \(Y[148]\)[t] + 
                Dy\ \(Y[158]\)[t] - dy\ \(Y[168]\)[t] - 
                4\ Dy\ \(Y[168]\)[t] + Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[179]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[169]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[169] + Dy\ \(Y[144]\)[t] + 
                Dy\ \(Y[148]\)[t] + Dy\ \(Y[165]\)[t] + Dy\ \(Y[168]\)[t] - 
                dy\ \(Y[169]\)[t] - 8\ Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[177]\)[t] + Dy\ \(Y[179]\)[t] + Dy\ \(Y[192]\)[t] + 
                Dy\ \(Y[193]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[170]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[170] + Dy\ \(Y[138]\)[t] + 
                Dy\ \(Y[157]\)[t] + Dy\ \(Y[159]\)[t] + Dy\ \(Y[163]\)[t] - 
                dy\ \(Y[170]\)[t] - 6\ Dy\ \(Y[170]\)[t] + 
                Dy\ \(Y[180]\)[t] + Dy\ \(Y[181]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[171]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[171] + Dy\ \(Y[137]\)[t] + 
                Dy\ \(Y[150]\)[t] + Dy\ \(Y[159]\)[t] - dy\ \(Y[171]\)[t] - 
                4\ Dy\ \(Y[171]\)[t] + Dy\ \(Y[182]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[172]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[172] + Dy\ \(Y[152]\)[t] + 
                Dy\ \(Y[153]\)[t] - dy\ \(Y[172]\)[t] - 
                5\ Dy\ \(Y[172]\)[t] + Dy\ \(Y[176]\)[t] + 
                Dy\ \(Y[178]\)[t] + Dy\ \(Y[185]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[173]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[173] + Dy\ \(Y[155]\)[t] + 
                Dy\ \(Y[162]\)[t] + Dy\ \(Y[167]\)[t] - dy\ \(Y[173]\)[t] - 
                6\ Dy\ \(Y[173]\)[t] + Dy\ \(Y[174]\)[t] + 
                Dy\ \(Y[184]\)[t] + Dy\ \(Y[189]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[174]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[174] + Dy\ \(Y[167]\)[t] + 
                Dy\ \(Y[173]\)[t] - dy\ \(Y[174]\)[t] - 
                5\ Dy\ \(Y[174]\)[t] + Dy\ \(Y[179]\)[t] + 
                Dy\ \(Y[187]\)[t] + Dy\ \(Y[189]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[175]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[175] + Dy\ \(Y[151]\)[t] + 
                Dy\ \(Y[161]\)[t] + Dy\ \(Y[166]\)[t] - dy\ \(Y[175]\)[t] - 
                6\ Dy\ \(Y[175]\)[t] + Dy\ \(Y[183]\)[t] + 
                Dy\ \(Y[190]\)[t] + Dy\ \(Y[199]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[176]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[176] + Dy\ \(Y[153]\)[t] + 
                Dy\ \(Y[164]\)[t] + Dy\ \(Y[172]\)[t] - dy\ \(Y[176]\)[t] - 
                6\ Dy\ \(Y[176]\)[t] + Dy\ \(Y[185]\)[t] + 
                Dy\ \(Y[197]\)[t] + Dy\ \(Y[201]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[177]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[177] + Dy\ \(Y[165]\)[t] + 
                Dy\ \(Y[169]\)[t] - dy\ \(Y[177]\)[t] - 
                5\ Dy\ \(Y[177]\)[t] + Dy\ \(Y[180]\)[t] + 
                Dy\ \(Y[193]\)[t] + Dy\ \(Y[194]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[178]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[178] + Dy\ \(Y[152]\)[t] + 
                Dy\ \(Y[172]\)[t] - dy\ \(Y[178]\)[t] - 
                4\ Dy\ \(Y[178]\)[t] + Dy\ \(Y[185]\)[t] + 
                Dy\ \(Y[203]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[179]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[179] + Dy\ \(Y[158]\)[t] + 
                Dy\ \(Y[167]\)[t] + Dy\ \(Y[168]\)[t] + Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[174]\)[t] - dy\ \(Y[179]\)[t] - 
                8\ Dy\ \(Y[179]\)[t] + Dy\ \(Y[187]\)[t] + 
                Dy\ \(Y[191]\)[t] + Dy\ \(Y[192]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[180]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[180] + Dy\ \(Y[163]\)[t] + 
                Dy\ \(Y[165]\)[t] + Dy\ \(Y[170]\)[t] + Dy\ \(Y[177]\)[t] - 
                dy\ \(Y[180]\)[t] - 8\ Dy\ \(Y[180]\)[t] + 
                Dy\ \(Y[181]\)[t] + Dy\ \(Y[194]\)[t] + Dy\ \(Y[196]\)[t] + 
                Dy\ \(Y[204]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[181]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[181] + Dy\ \(Y[159]\)[t] + 
                Dy\ \(Y[170]\)[t] + Dy\ \(Y[180]\)[t] - dy\ \(Y[181]\)[t] - 
                6\ Dy\ \(Y[181]\)[t] + Dy\ \(Y[182]\)[t] + 
                Dy\ \(Y[196]\)[t] + Dy\ \(Y[200]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[182]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[182] + Dy\ \(Y[159]\)[t] + 
                Dy\ \(Y[171]\)[t] + Dy\ \(Y[181]\)[t] - dy\ \(Y[182]\)[t] - 
                4\ Dy\ \(Y[182]\)[t] + Dy\ \(Y[200]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[183]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[183] + Dy\ \(Y[162]\)[t] + 
                Dy\ \(Y[166]\)[t] + Dy\ \(Y[175]\)[t] - dy\ \(Y[183]\)[t] - 
                6\ Dy\ \(Y[183]\)[t] + Dy\ \(Y[184]\)[t] + 
                Dy\ \(Y[195]\)[t] + Dy\ \(Y[199]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[184]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[184] + Dy\ \(Y[162]\)[t] + 
                Dy\ \(Y[173]\)[t] + Dy\ \(Y[183]\)[t] - dy\ \(Y[184]\)[t] - 
                6\ Dy\ \(Y[184]\)[t] + Dy\ \(Y[189]\)[t] + 
                Dy\ \(Y[195]\)[t] + Dy\ \(Y[202]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[185]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[185] + Dy\ \(Y[172]\)[t] + 
                Dy\ \(Y[176]\)[t] + Dy\ \(Y[178]\)[t] - dy\ \(Y[185]\)[t] - 
                6\ Dy\ \(Y[185]\)[t] + Dy\ \(Y[197]\)[t] + 
                Dy\ \(Y[203]\)[t] + Dy\ \(Y[208]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[186]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[186] + Dy\ \(Y[160]\)[t] + 
                Dy\ \(Y[161]\)[t] - dy\ \(Y[186]\)[t] - 
                5\ Dy\ \(Y[186]\)[t] + Dy\ \(Y[188]\)[t] + 
                Dy\ \(Y[190]\)[t] + Dy\ \(Y[198]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[187]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[187] + Dy\ \(Y[174]\)[t] + 
                Dy\ \(Y[179]\)[t] - dy\ \(Y[187]\)[t] - 
                5\ Dy\ \(Y[187]\)[t] + Dy\ \(Y[189]\)[t] + 
                Dy\ \(Y[191]\)[t] + Dy\ \(Y[205]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[188]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[188] + Dy\ \(Y[145]\)[t] + 
                Dy\ \(Y[160]\)[t] + Dy\ \(Y[164]\)[t] + Dy\ \(Y[186]\)[t] - 
                dy\ \(Y[188]\)[t] - 7\ Dy\ \(Y[188]\)[t] + 
                Dy\ \(Y[198]\)[t] + Dy\ \(Y[201]\)[t] + Dy\ \(Y[218]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[189]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[189] + Dy\ \(Y[173]\)[t] + 
                Dy\ \(Y[174]\)[t] + Dy\ \(Y[184]\)[t] + Dy\ \(Y[187]\)[t] - 
                dy\ \(Y[189]\)[t] - 6\ Dy\ \(Y[189]\)[t] + 
                Dy\ \(Y[202]\)[t] + Dy\ \(Y[205]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[190]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[190] + Dy\ \(Y[161]\)[t] + 
                Dy\ \(Y[175]\)[t] + Dy\ \(Y[186]\)[t] - dy\ \(Y[190]\)[t] - 
                7\ Dy\ \(Y[190]\)[t] + Dy\ \(Y[198]\)[t] + 
                Dy\ \(Y[199]\)[t] + Dy\ \(Y[207]\)[t] + Dy\ \(Y[215]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[191]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[191] + Dy\ \(Y[179]\)[t] + 
                Dy\ \(Y[187]\)[t] - dy\ \(Y[191]\)[t] - 
                6\ Dy\ \(Y[191]\)[t] + Dy\ \(Y[192]\)[t] + 
                Dy\ \(Y[205]\)[t] + Dy\ \(Y[206]\)[t] + Dy\ \(Y[216]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[192]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[192] + Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[179]\)[t] + Dy\ \(Y[191]\)[t] - dy\ \(Y[192]\)[t] - 
                5\ Dy\ \(Y[192]\)[t] + Dy\ \(Y[193]\)[t] + 
                Dy\ \(Y[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[193]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[193] + Dy\ \(Y[169]\)[t] + 
                Dy\ \(Y[177]\)[t] + Dy\ \(Y[192]\)[t] - dy\ \(Y[193]\)[t] - 
                5\ Dy\ \(Y[193]\)[t] + Dy\ \(Y[194]\)[t] + 
                Dy\ \(Y[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[194]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[194] + Dy\ \(Y[177]\)[t] + 
                Dy\ \(Y[180]\)[t] + Dy\ \(Y[193]\)[t] - dy\ \(Y[194]\)[t] - 
                5\ Dy\ \(Y[194]\)[t] + Dy\ \(Y[204]\)[t] + 
                Dy\ \(Y[206]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[195]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[195] + Dy\ \(Y[183]\)[t] + 
                Dy\ \(Y[184]\)[t] - dy\ \(Y[195]\)[t] - 
                6\ Dy\ \(Y[195]\)[t] + Dy\ \(Y[199]\)[t] + 
                Dy\ \(Y[202]\)[t] + Dy\ \(Y[213]\)[t] + Dy\ \(Y[222]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[196]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[196] + Dy\ \(Y[180]\)[t] + 
                Dy\ \(Y[181]\)[t] - dy\ \(Y[196]\)[t] - 
                6\ Dy\ \(Y[196]\)[t] + Dy\ \(Y[200]\)[t] + 
                Dy\ \(Y[204]\)[t] + Dy\ \(Y[211]\)[t] + Dy\ \(Y[214]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[197]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[197] + Dy\ \(Y[176]\)[t] + 
                Dy\ \(Y[185]\)[t] - dy\ \(Y[197]\)[t] - 
                5\ Dy\ \(Y[197]\)[t] + Dy\ \(Y[201]\)[t] + 
                Dy\ \(Y[208]\)[t] + Dy\ \(Y[209]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[198]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[198] + Dy\ \(Y[186]\)[t] + 
                Dy\ \(Y[188]\)[t] + Dy\ \(Y[190]\)[t] - dy\ \(Y[198]\)[t] - 
                5\ Dy\ \(Y[198]\)[t] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[218]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[199]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[199] + Dy\ \(Y[175]\)[t] + 
                Dy\ \(Y[183]\)[t] + Dy\ \(Y[190]\)[t] + Dy\ \(Y[195]\)[t] - 
                dy\ \(Y[199]\)[t] - 7\ Dy\ \(Y[199]\)[t] + 
                Dy\ \(Y[207]\)[t] + Dy\ \(Y[212]\)[t] + Dy\ \(Y[222]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[200]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[200] + Dy\ \(Y[181]\)[t] + 
                Dy\ \(Y[182]\)[t] + Dy\ \(Y[196]\)[t] - dy\ \(Y[200]\)[t] - 
                4\ Dy\ \(Y[200]\)[t] + Dy\ \(Y[211]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[201]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[201] + Dy\ \(Y[164]\)[t] + 
                Dy\ \(Y[176]\)[t] + Dy\ \(Y[188]\)[t] + Dy\ \(Y[197]\)[t] - 
                dy\ \(Y[201]\)[t] - 7\ Dy\ \(Y[201]\)[t] + 
                Dy\ \(Y[209]\)[t] + Dy\ \(Y[218]\)[t] + Dy\ \(Y[220]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[202]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[202] + Dy\ \(Y[184]\)[t] + 
                Dy\ \(Y[189]\)[t] + Dy\ \(Y[195]\)[t] - dy\ \(Y[202]\)[t] - 
                6\ Dy\ \(Y[202]\)[t] + Dy\ \(Y[205]\)[t] + 
                Dy\ \(Y[210]\)[t] + Dy\ \(Y[213]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[203]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[203] + Dy\ \(Y[178]\)[t] + 
                Dy\ \(Y[185]\)[t] - dy\ \(Y[203]\)[t] - 
                4\ Dy\ \(Y[203]\)[t] + Dy\ \(Y[208]\)[t] + 
                Dy\ \(Y[219]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[204]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[204] + Dy\ \(Y[180]\)[t] + 
                Dy\ \(Y[194]\)[t] + Dy\ \(Y[196]\)[t] - dy\ \(Y[204]\)[t] - 
                6\ Dy\ \(Y[204]\)[t] + Dy\ \(Y[206]\)[t] + 
                Dy\ \(Y[214]\)[t] + Dy\ \(Y[217]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[205]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[205] + Dy\ \(Y[187]\)[t] + 
                Dy\ \(Y[189]\)[t] + Dy\ \(Y[191]\)[t] + Dy\ \(Y[202]\)[t] - 
                dy\ \(Y[205]\)[t] - 7\ Dy\ \(Y[205]\)[t] + 
                Dy\ \(Y[210]\)[t] + Dy\ \(Y[216]\)[t] + Dy\ \(Y[225]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[206]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[206] + Dy\ \(Y[191]\)[t] + 
                Dy\ \(Y[192]\)[t] + Dy\ \(Y[193]\)[t] + Dy\ \(Y[194]\)[t] + 
                Dy\ \(Y[204]\)[t] - dy\ \(Y[206]\)[t] - 
                8\ Dy\ \(Y[206]\)[t] + Dy\ \(Y[216]\)[t] + 
                Dy\ \(Y[217]\)[t] + Dy\ \(Y[221]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[207]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[207] + Dy\ \(Y[190]\)[t] + 
                Dy\ \(Y[199]\)[t] - dy\ \(Y[207]\)[t] - 
                4\ Dy\ \(Y[207]\)[t] + Dy\ \(Y[212]\)[t] + 
                Dy\ \(Y[215]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[208]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[208] + Dy\ \(Y[185]\)[t] + 
                Dy\ \(Y[197]\)[t] + Dy\ \(Y[203]\)[t] - dy\ \(Y[208]\)[t] - 
                6\ Dy\ \(Y[208]\)[t] + Dy\ \(Y[209]\)[t] + 
                Dy\ \(Y[219]\)[t] + Dy\ \(Y[226]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[209]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[209] + Dy\ \(Y[197]\)[t] + 
                Dy\ \(Y[201]\)[t] + Dy\ \(Y[208]\)[t] - dy\ \(Y[209]\)[t] - 
                6\ Dy\ \(Y[209]\)[t] + Dy\ \(Y[220]\)[t] + 
                Dy\ \(Y[226]\)[t] + Dy\ \(Y[227]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[210]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[210] + Dy\ \(Y[202]\)[t] + 
                Dy\ \(Y[205]\)[t] - dy\ \(Y[210]\)[t] - 
                5\ Dy\ \(Y[210]\)[t] + Dy\ \(Y[213]\)[t] + 
                Dy\ \(Y[224]\)[t] + Dy\ \(Y[225]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[211]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[211] + Dy\ \(Y[196]\)[t] + 
                Dy\ \(Y[200]\)[t] - dy\ \(Y[211]\)[t] - 
                3\ Dy\ \(Y[211]\)[t] + Dy\ \(Y[214]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[212]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[212] + Dy\ \(Y[199]\)[t] + 
                Dy\ \(Y[207]\)[t] - dy\ \(Y[212]\)[t] - 
                6\ Dy\ \(Y[212]\)[t] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[222]\)[t] + Dy\ \(Y[223]\)[t] + Dy\ \(Y[230]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[213]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[213] + Dy\ \(Y[195]\)[t] + 
                Dy\ \(Y[202]\)[t] + Dy\ \(Y[210]\)[t] - dy\ \(Y[213]\)[t] - 
                5\ Dy\ \(Y[213]\)[t] + Dy\ \(Y[222]\)[t] + 
                Dy\ \(Y[224]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[214]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[214] + Dy\ \(Y[196]\)[t] + 
                Dy\ \(Y[204]\)[t] + Dy\ \(Y[211]\)[t] - dy\ \(Y[214]\)[t] - 
                4\ Dy\ \(Y[214]\)[t] + Dy\ \(Y[217]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[215]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[215] + Dy\ \(Y[190]\)[t] + 
                Dy\ \(Y[198]\)[t] + Dy\ \(Y[207]\)[t] + Dy\ \(Y[212]\)[t] - 
                dy\ \(Y[215]\)[t] - 10\ Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[218]\)[t] + Dy\ \(Y[228]\)[t] + Dy\ \(Y[230]\)[t] + 
                Dy\ \(Y[232]\)[t] + Dy\ \(Y[233]\)[t] + Dy\ \(Y[235]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[216]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[216] + Dy\ \(Y[191]\)[t] + 
                Dy\ \(Y[205]\)[t] + Dy\ \(Y[206]\)[t] - dy\ \(Y[216]\)[t] - 
                6\ Dy\ \(Y[216]\)[t] + Dy\ \(Y[221]\)[t] + 
                Dy\ \(Y[225]\)[t] + Dy\ \(Y[234]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[217]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[217] + Dy\ \(Y[204]\)[t] + 
                Dy\ \(Y[206]\)[t] + Dy\ \(Y[214]\)[t] - dy\ \(Y[217]\)[t] - 
                4\ Dy\ \(Y[217]\)[t] + Dy\ \(Y[221]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[218]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[218] + Dy\ \(Y[188]\)[t] + 
                Dy\ \(Y[198]\)[t] + Dy\ \(Y[201]\)[t] + Dy\ \(Y[215]\)[t] - 
                dy\ \(Y[218]\)[t] - 7\ Dy\ \(Y[218]\)[t] + 
                Dy\ \(Y[220]\)[t] + Dy\ \(Y[228]\)[t] + Dy\ \(Y[229]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[219]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[219] + Dy\ \(Y[203]\)[t] + 
                Dy\ \(Y[208]\)[t] - dy\ \(Y[219]\)[t] - 
                4\ Dy\ \(Y[219]\)[t] + Dy\ \(Y[226]\)[t] + 
                Dy\ \(Y[237]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[220]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[220] + Dy\ \(Y[201]\)[t] + 
                Dy\ \(Y[209]\)[t] + Dy\ \(Y[218]\)[t] - dy\ \(Y[220]\)[t] - 
                5\ Dy\ \(Y[220]\)[t] + Dy\ \(Y[227]\)[t] + 
                Dy\ \(Y[229]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[221]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[221] + Dy\ \(Y[206]\)[t] + 
                Dy\ \(Y[216]\)[t] + Dy\ \(Y[217]\)[t] - dy\ \(Y[221]\)[t] - 
                3\ Dy\ \(Y[221]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[222]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[222] + Dy\ \(Y[195]\)[t] + 
                Dy\ \(Y[199]\)[t] + Dy\ \(Y[212]\)[t] + Dy\ \(Y[213]\)[t] - 
                dy\ \(Y[222]\)[t] - 7\ Dy\ \(Y[222]\)[t] + 
                Dy\ \(Y[223]\)[t] + Dy\ \(Y[224]\)[t] + Dy\ \(Y[231]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[223]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[223] + Dy\ \(Y[212]\)[t] + 
                Dy\ \(Y[222]\)[t] - dy\ \(Y[223]\)[t] - 
                6\ Dy\ \(Y[223]\)[t] + Dy\ \(Y[230]\)[t] + 
                Dy\ \(Y[231]\)[t] + Dy\ \(Y[236]\)[t] + Dy\ \(Y[238]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[224]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[224] + Dy\ \(Y[210]\)[t] + 
                Dy\ \(Y[213]\)[t] + Dy\ \(Y[222]\)[t] - dy\ \(Y[224]\)[t] - 
                5\ Dy\ \(Y[224]\)[t] + Dy\ \(Y[225]\)[t] + 
                Dy\ \(Y[231]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[225]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[225] + Dy\ \(Y[205]\)[t] + 
                Dy\ \(Y[210]\)[t] + Dy\ \(Y[216]\)[t] + Dy\ \(Y[224]\)[t] - 
                dy\ \(Y[225]\)[t] - 6\ Dy\ \(Y[225]\)[t] + 
                Dy\ \(Y[231]\)[t] + Dy\ \(Y[234]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[226]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[226] + Dy\ \(Y[208]\)[t] + 
                Dy\ \(Y[209]\)[t] + Dy\ \(Y[219]\)[t] - dy\ \(Y[226]\)[t] - 
                6\ Dy\ \(Y[226]\)[t] + Dy\ \(Y[227]\)[t] + 
                Dy\ \(Y[237]\)[t] + Dy\ \(Y[239]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[227]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[227] + Dy\ \(Y[209]\)[t] + 
                Dy\ \(Y[220]\)[t] + Dy\ \(Y[226]\)[t] - dy\ \(Y[227]\)[t] - 
                5\ Dy\ \(Y[227]\)[t] + Dy\ \(Y[229]\)[t] + 
                Dy\ \(Y[239]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[228]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[228] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[218]\)[t] - dy\ \(Y[228]\)[t] - 
                5\ Dy\ \(Y[228]\)[t] + Dy\ \(Y[229]\)[t] + 
                Dy\ \(Y[235]\)[t] + Dy\ \(Y[240]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[229]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[229] + Dy\ \(Y[218]\)[t] + 
                Dy\ \(Y[220]\)[t] + Dy\ \(Y[227]\)[t] + Dy\ \(Y[228]\)[t] - 
                dy\ \(Y[229]\)[t] - 7\ Dy\ \(Y[229]\)[t] + 
                Dy\ \(Y[239]\)[t] + Dy\ \(Y[240]\)[t] + Dy\ \(Y[242]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[230]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[230] + Dy\ \(Y[212]\)[t] + 
                Dy\ \(Y[215]\)[t] + Dy\ \(Y[223]\)[t] - dy\ \(Y[230]\)[t] - 
                6\ Dy\ \(Y[230]\)[t] + Dy\ \(Y[232]\)[t] + 
                Dy\ \(Y[236]\)[t] + Dy\ \(Y[245]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[231]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[231] + Dy\ \(Y[222]\)[t] + 
                Dy\ \(Y[223]\)[t] + Dy\ \(Y[224]\)[t] + Dy\ \(Y[225]\)[t] - 
                dy\ \(Y[231]\)[t] - 7\ Dy\ \(Y[231]\)[t] + 
                Dy\ \(Y[234]\)[t] + Dy\ \(Y[238]\)[t] + Dy\ \(Y[244]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[232]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[232] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[230]\)[t] - dy\ \(Y[232]\)[t] - 
                4\ Dy\ \(Y[232]\)[t] + Dy\ \(Y[233]\)[t] + 
                Dy\ \(Y[245]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[233]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[233] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[232]\)[t] - dy\ \(Y[233]\)[t] - 
                5\ Dy\ \(Y[233]\)[t] + Dy\ \(Y[235]\)[t] + 
                Dy\ \(Y[241]\)[t] + Dy\ \(Y[245]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[234]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[234] + Dy\ \(Y[216]\)[t] + 
                Dy\ \(Y[225]\)[t] + Dy\ \(Y[231]\)[t] - dy\ \(Y[234]\)[t] - 
                4\ Dy\ \(Y[234]\)[t] + Dy\ \(Y[244]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[235]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[235] + Dy\ \(Y[215]\)[t] + 
                Dy\ \(Y[228]\)[t] + Dy\ \(Y[233]\)[t] - dy\ \(Y[235]\)[t] - 
                6\ Dy\ \(Y[235]\)[t] + Dy\ \(Y[240]\)[t] + 
                Dy\ \(Y[241]\)[t] + Dy\ \(Y[243]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[236]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[236] + Dy\ \(Y[223]\)[t] + 
                Dy\ \(Y[230]\)[t] - dy\ \(Y[236]\)[t] - 
                5\ Dy\ \(Y[236]\)[t] + Dy\ \(Y[238]\)[t] + 
                Dy\ \(Y[245]\)[t] + Dy\ \(Y[248]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[237]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[237] + Dy\ \(Y[219]\)[t] + 
                Dy\ \(Y[226]\)[t] - dy\ \(Y[237]\)[t] - 
                4\ Dy\ \(Y[237]\)[t] + Dy\ \(Y[239]\)[t] + 
                Dy\ \(Y[249]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[238]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[238] + Dy\ \(Y[223]\)[t] + 
                Dy\ \(Y[231]\)[t] + Dy\ \(Y[236]\)[t] - dy\ \(Y[238]\)[t] - 
                6\ Dy\ \(Y[238]\)[t] + Dy\ \(Y[244]\)[t] + 
                Dy\ \(Y[246]\)[t] + Dy\ \(Y[248]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[239]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[239] + Dy\ \(Y[226]\)[t] + 
                Dy\ \(Y[227]\)[t] + Dy\ \(Y[229]\)[t] + Dy\ \(Y[237]\)[t] - 
                dy\ \(Y[239]\)[t] - 7\ Dy\ \(Y[239]\)[t] + 
                Dy\ \(Y[242]\)[t] + Dy\ \(Y[249]\)[t] + Dy\ \(Y[250]\)[t]\)}],
             ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[240]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[240] + Dy\ \(Y[228]\)[t] + 
                Dy\ \(Y[229]\)[t] + Dy\ \(Y[235]\)[t] - dy\ \(Y[240]\)[t] - 
                6\ Dy\ \(Y[240]\)[t] + Dy\ \(Y[242]\)[t] + 
                Dy\ \(Y[243]\)[t] + Dy\ \(Y[247]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[241]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[241] + Dy\ \(Y[233]\)[t] + 
                Dy\ \(Y[235]\)[t] - dy\ \(Y[241]\)[t] - 
                7\ Dy\ \(Y[241]\)[t] + Dy\ \(Y[243]\)[t] + 
                Dy\ \(Y[245]\)[t] + Dy\ \(Y[247]\)[t] + Dy\ \(Y[251]\)[t] + 
                Dy\ \(Y[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[242]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[242] + Dy\ \(Y[229]\)[t] + 
                Dy\ \(Y[239]\)[t] + Dy\ \(Y[240]\)[t] - dy\ \(Y[242]\)[t] - 
                6\ Dy\ \(Y[242]\)[t] + Dy\ \(Y[247]\)[t] + 
                Dy\ \(Y[250]\)[t] + Dy\ \(Y[252]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[243]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[243] + Dy\ \(Y[235]\)[t] + 
                Dy\ \(Y[240]\)[t] + Dy\ \(Y[241]\)[t] - dy\ \(Y[243]\)[t] - 
                4\ Dy\ \(Y[243]\)[t] + Dy\ \(Y[247]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[244]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[244] + Dy\ \(Y[231]\)[t] + 
                Dy\ \(Y[234]\)[t] + Dy\ \(Y[238]\)[t] - dy\ \(Y[244]\)[t] - 
                4\ Dy\ \(Y[244]\)[t] + Dy\ \(Y[246]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[245]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[245] + Dy\ \(Y[230]\)[t] + 
                Dy\ \(Y[232]\)[t] + Dy\ \(Y[233]\)[t] + Dy\ \(Y[236]\)[t] + 
                Dy\ \(Y[241]\)[t] - dy\ \(Y[245]\)[t] - 
                7\ Dy\ \(Y[245]\)[t] + Dy\ \(Y[248]\)[t] + 
                Dy\ \(Y[251]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[246]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[246] + Dy\ \(Y[238]\)[t] + 
                Dy\ \(Y[244]\)[t] - dy\ \(Y[246]\)[t] - 
                3\ Dy\ \(Y[246]\)[t] + Dy\ \(Y[248]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[247]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[247] + Dy\ \(Y[240]\)[t] + 
                Dy\ \(Y[241]\)[t] + Dy\ \(Y[242]\)[t] + Dy\ \(Y[243]\)[t] - 
                dy\ \(Y[247]\)[t] - 6\ Dy\ \(Y[247]\)[t] + 
                Dy\ \(Y[252]\)[t] + Dy\ \(Y[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[248]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[248] + Dy\ \(Y[236]\)[t] + 
                Dy\ \(Y[238]\)[t] + Dy\ \(Y[245]\)[t] + Dy\ \(Y[246]\)[t] - 
                dy\ \(Y[248]\)[t] - 4\ Dy\ \(Y[248]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[249]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[249] + Dy\ \(Y[237]\)[t] + 
                Dy\ \(Y[239]\)[t] - dy\ \(Y[249]\)[t] - 
                3\ Dy\ \(Y[249]\)[t] + Dy\ \(Y[250]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[250]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[250] + Dy\ \(Y[239]\)[t] + 
                Dy\ \(Y[242]\)[t] + Dy\ \(Y[249]\)[t] - dy\ \(Y[250]\)[t] - 
                4\ Dy\ \(Y[250]\)[t] + Dy\ \(Y[252]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[251]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[251] + Dy\ \(Y[241]\)[t] + 
                Dy\ \(Y[245]\)[t] - dy\ \(Y[251]\)[t] - 
                3\ Dy\ \(Y[251]\)[t] + Dy\ \(Y[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[252]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[252] + Dy\ \(Y[242]\)[t] + 
                Dy\ \(Y[247]\)[t] + Dy\ \(Y[250]\)[t] - dy\ \(Y[252]\)[t] - 
                4\ Dy\ \(Y[252]\)[t] + Dy\ \(Y[253]\)[t]\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox[\(Y[253]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], 
              "\[Equal]", \(ky\ L1[253] + Dy\ \(Y[241]\)[t] + 
                Dy\ \(Y[247]\)[t] + Dy\ \(Y[251]\)[t] + Dy\ \(Y[252]\)[t] - 
                dy\ \(Y[253]\)[t] - 4\ Dy\ \(Y[253]\)[t]\)}]}], "}"}], 
        ",", \({A[1], A[2], A[3], A[4], A[5], A[6], A[7], A[8], A[9], A[10], 
          A[11], A[12], A[13], A[14], A[15], A[16], A[17], A[18], A[19], 
          A[20], A[21], A[22], A[23], A[24], A[25], A[26], A[27], A[28], 
          A[29], A[30], A[31], A[32], A[33], A[34], A[35], A[36], A[37], 
          A[38], A[39], A[40], A[41], A[42], A[43], A[44], A[45], A[46], 
          A[47], A[48], A[49], A[50], A[51], A[52], A[53], A[54], A[55], 
          A[56], A[57], A[58], A[59], A[60], A[61], A[62], A[63], A[64], 
          A[65], A[66], A[67], A[68], A[69], A[70], A[71], A[72], A[73], 
          A[74], A[75], A[76], A[77], A[78], A[79], A[80], A[81], A[82], 
          A[83], A[84], A[85], A[86], A[87], A[88], A[89], A[90], A[91], 
          A[92], A[93], A[94], A[95], A[96], A[97], A[98], A[99], A[100], 
          A[101], A[102], A[103], A[104], A[105], A[106], A[107], A[108], 
          A[109], A[110], A[111], A[112], A[113], A[114], A[115], A[116], 
          A[117], A[118], A[119], A[120], A[121], A[122], A[123], A[124], 
          A[125], A[126], A[127], A[128], A[129], A[130], A[131], A[132], 
          A[133], A[134], A[135], A[136], A[137], A[138], A[139], A[140], 
          A[141], A[142], A[143], A[144], A[145], A[146], A[147], A[148], 
          A[149], A[150], A[151], A[152], A[153], A[154], A[155], A[156], 
          A[157], A[158], A[159], A[160], A[161], A[162], A[163], A[164], 
          A[165], A[166], A[167], A[168], A[169], A[170], A[171], A[172], 
          A[173], A[174], A[175], A[176], A[177], A[178], A[179], A[180], 
          A[181], A[182], A[183], A[184], A[185], A[186], A[187], A[188], 
          A[189], A[190], A[191], A[192], A[193], A[194], A[195], A[196], 
          A[197], A[198], A[199], A[200], A[201], A[202], A[203], A[204], 
          A[205], A[206], A[207], A[208], A[209], A[210], A[211], A[212], 
          A[213], A[214], A[215], A[216], A[217], A[218], A[219], A[220], 
          A[221], A[222], A[223], A[224], A[225], A[226], A[227], A[228], 
          A[229], A[230], A[231], A[232], A[233], A[234], A[235], A[236], 
          A[237], A[238], A[239], A[240], A[241], A[242], A[243], A[244], 
          A[245], A[246], A[247], A[248], A[249], A[250], A[251], A[252], 
          A[253], B[1], B[2], B[3], B[4], B[5], B[6], B[7], B[8], B[9], 
          B[10], B[11], B[12], B[13], B[14], B[15], B[16], B[17], B[18], 
          B[19], B[20], B[21], B[22], B[23], B[24], B[25], B[26], B[27], 
          B[28], B[29], B[30], B[31], B[32], B[33], B[34], B[35], B[36], 
          B[37], B[38], B[39], B[40], B[41], B[42], B[43], B[44], B[45], 
          B[46], B[47], B[48], B[49], B[50], B[51], B[52], B[53], B[54], 
          B[55], B[56], B[57], B[58], B[59], B[60], B[61], B[62], B[63], 
          B[64], B[65], B[66], B[67], B[68], B[69], B[70], B[71], B[72], 
          B[73], B[74], B[75], B[76], B[77], B[78], B[79], B[80], B[81], 
          B[82], B[83], B[84], B[85], B[86], B[87], B[88], B[89], B[90], 
          B[91], B[92], B[93], B[94], B[95], B[96], B[97], B[98], B[99], 
          B[100], B[101], B[102], B[103], B[104], B[105], B[106], B[107], 
          B[108], B[109], B[110], B[111], B[112], B[113], B[114], B[115], 
          B[116], B[117], B[118], B[119], B[120], B[121], B[122], B[123], 
          B[124], B[125], B[126], B[127], B[128], B[129], B[130], B[131], 
          B[132], B[133], B[134], B[135], B[136], B[137], B[138], B[139], 
          B[140], B[141], B[142], B[143], B[144], B[145], B[146], B[147], 
          B[148], B[149], B[150], B[151], B[152], B[153], B[154], B[155], 
          B[156], B[157], B[158], B[159], B[160], B[161], B[162], B[163], 
          B[164], B[165], B[166], B[167], B[168], B[169], B[170], B[171], 
          B[172], B[173], B[174], B[175], B[176], B[177], B[178], B[179], 
          B[180], B[181], B[182], B[183], B[184], B[185], B[186], B[187], 
          B[188], B[189], B[190], B[191], B[192], B[193], B[194], B[195], 
          B[196], B[197], B[198], B[199], B[200], B[201], B[202], B[203], 
          B[204], B[205], B[206], B[207], B[208], B[209], B[210], B[211], 
          B[212], B[213], B[214], B[215], B[216], B[217], B[218], B[219], 
          B[220], B[221], B[222], B[223], B[224], B[225], B[226], B[227], 
          B[228], B[229], B[230], B[231], B[232], B[233], B[234], B[235], 
          B[236], B[237], B[238], B[239], B[240], B[241], B[242], B[243], 
          B[244], B[245], B[246], B[247], B[248], B[249], B[250], B[251], 
          B[252], B[253], W[1], W[2], W[3], W[4], W[5], W[6], W[7], W[8], 
          W[9], W[10], W[11], W[12], W[13], W[14], W[15], W[16], W[17], 
          W[18], W[19], W[20], W[21], W[22], W[23], W[24], W[25], W[26], 
          W[27], W[28], W[29], W[30], W[31], W[32], W[33], W[34], W[35], 
          W[36], W[37], W[38], W[39], W[40], W[41], W[42], W[43], W[44], 
          W[45], W[46], W[47], W[48], W[49], W[50], W[51], W[52], W[53], 
          W[54], W[55], W[56], W[57], W[58], W[59], W[60], W[61], W[62], 
          W[63], W[64], W[65], W[66], W[67], W[68], W[69], W[70], W[71], 
          W[72], W[73], W[74], W[75], W[76], W[77], W[78], W[79], W[80], 
          W[81], W[82], W[83], W[84], W[85], W[86], W[87], W[88], W[89], 
          W[90], W[91], W[92], W[93], W[94], W[95], W[96], W[97], W[98], 
          W[99], W[100], W[101], W[102], W[103], W[104], W[105], W[106], 
          W[107], W[108], W[109], W[110], W[111], W[112], W[113], W[114], 
          W[115], W[116], W[117], W[118], W[119], W[120], W[121], W[122], 
          W[123], W[124], W[125], W[126], W[127], W[128], W[129], W[130], 
          W[131], W[132], W[133], W[134], W[135], W[136], W[137], W[138], 
          W[139], W[140], W[141], W[142], W[143], W[144], W[145], W[146], 
          W[147], W[148], W[149], W[150], W[151], W[152], W[153], W[154], 
          W[155], W[156], W[157], W[158], W[159], W[160], W[161], W[162], 
          W[163], W[164], W[165], W[166], W[167], W[168], W[169], W[170], 
          W[171], W[172], W[173], W[174], W[175], W[176], W[177], W[178], 
          W[179], W[180], W[181], W[182], W[183], W[184], W[185], W[186], 
          W[187], W[188], W[189], W[190], W[191], W[192], W[193], W[194], 
          W[195], W[196], W[197], W[198], W[199], W[200], W[201], W[202], 
          W[203], W[204], W[205], W[206], W[207], W[208], W[209], W[210], 
          W[211], W[212], W[213], W[214], W[215], W[216], W[217], W[218], 
          W[219], W[220], W[221], W[222], W[223], W[224], W[225], W[226], 
          W[227], W[228], W[229], W[230], W[231], W[232], W[233], W[234], 
          W[235], W[236], W[237], W[238], W[239], W[240], W[241], W[242], 
          W[243], W[244], W[245], W[246], W[247], W[248], W[249], W[250], 
          W[251], W[252], W[253], Y[1], Y[2], Y[3], Y[4], Y[5], Y[6], Y[7], 
          Y[8], Y[9], Y[10], Y[11], Y[12], Y[13], Y[14], Y[15], Y[16], Y[17], 
          Y[18], Y[19], Y[20], Y[21], Y[22], Y[23], Y[24], Y[25], Y[26], 
          Y[27], Y[28], Y[29], Y[30], Y[31], Y[32], Y[33], Y[34], Y[35], 
          Y[36], Y[37], Y[38], Y[39], Y[40], Y[41], Y[42], Y[43], Y[44], 
          Y[45], Y[46], Y[47], Y[48], Y[49], Y[50], Y[51], Y[52], Y[53], 
          Y[54], Y[55], Y[56], Y[57], Y[58], Y[59], Y[60], Y[61], Y[62], 
          Y[63], Y[64], Y[65], Y[66], Y[67], Y[68], Y[69], Y[70], Y[71], 
          Y[72], Y[73], Y[74], Y[75], Y[76], Y[77], Y[78], Y[79], Y[80], 
          Y[81], Y[82], Y[83], Y[84], Y[85], Y[86], Y[87], Y[88], Y[89], 
          Y[90], Y[91], Y[92], Y[93], Y[94], Y[95], Y[96], Y[97], Y[98], 
          Y[99], Y[100], Y[101], Y[102], Y[103], Y[104], Y[105], Y[106], 
          Y[107], Y[108], Y[109], Y[110], Y[111], Y[112], Y[113], Y[114], 
          Y[115], Y[116], Y[117], Y[118], Y[119], Y[120], Y[121], Y[122], 
          Y[123], Y[124], Y[125], Y[126], Y[127], Y[128], Y[129], Y[130], 
          Y[131], Y[132], Y[133], Y[134], Y[135], Y[136], Y[137], Y[138], 
          Y[139], Y[140], Y[141], Y[142], Y[143], Y[144], Y[145], Y[146], 
          Y[147], Y[148], Y[149], Y[150], Y[151], Y[152], Y[153], Y[154], 
          Y[155], Y[156], Y[157], Y[158], Y[159], Y[160], Y[161], Y[162], 
          Y[163], Y[164], Y[165], Y[166], Y[167], Y[168], Y[169], Y[170], 
          Y[171], Y[172], Y[173], Y[174], Y[175], Y[176], Y[177], Y[178], 
          Y[179], Y[180], Y[181], Y[182], Y[183], Y[184], Y[185], Y[186], 
          Y[187], Y[188], Y[189], Y[190], Y[191], Y[192], Y[193], Y[194], 
          Y[195], Y[196], Y[197], Y[198], Y[199], Y[200], Y[201], Y[202], 
          Y[203], Y[204], Y[205], Y[206], Y[207], Y[208], Y[209], Y[210], 
          Y[211], Y[212], Y[213], Y[214], Y[215], Y[216], Y[217], Y[218], 
          Y[219], Y[220], Y[221], Y[222], Y[223], Y[224], Y[225], Y[226], 
          Y[227], Y[228], Y[229], Y[230], Y[231], Y[232], Y[233], Y[234], 
          Y[235], Y[236], Y[237], Y[238], Y[239], Y[240], Y[241], Y[242], 
          Y[243], Y[244], Y[245], Y[246], Y[247], Y[248], Y[249], Y[250], 
          Y[251], Y[252], Y[253]}\)}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sc\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 6, 10, 12, 15, 16, 19, 20, 21, 30, 36, 42, 50, 58, 78, 82, 
      107, 113, 122, 134, 150, 152, 171, 178, 182, 200, 203, 211, 214, 216, 
      217, 219, 221, 234, 237, 244, 245, 246, 248, 249, 250, 251, 252, 
      253}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length /@ istn\)], "Input"],

Cell[BoxData[
    \({1012, 1012}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L1[i_] := \ \ If[MemberQ[sc, i], 1, 0];\)\), "\[IndentingNewLine]", 
    \(\({cpu, sim} = 
        Timing[run[
            istn /. rates, {0, 500}, \ \ initialConditions \[Rule] \ 
              myic[n]]];\)\), "\[IndentingNewLine]", 
    \(\(Print[cpu];\)\)}], "Input"],

Cell[BoxData[
    \(26.791301999999995`\ Second\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(runPlot[sim, \ W /@ \((Range[n])\), {0, 150}, \ 
      PlotRange \[Rule] \ All, \ ImageSize \[Rule] \ 600, 
      holdLegend \[Rule] \ True]; 
    runPlot[sim, \ W /@ \((Range[n])\), {0, 500}, \ 
      PlotRange \[Rule] \ All, \ ImageSize \[Rule] \ 600, \ 
      holdLegend \[Rule] \ True];\), "\[IndentingNewLine]", 
    \(\(runPlot[sim, \ A /@ \((Range[n])\), {0, 500}, \ 
        PlotRange \[Rule] \ All, \ ImageSize \[Rule] \ 600, \ 
        holdLegend \[Rule] \ True];\)\), "\[IndentingNewLine]", 
    \(\(runPlot[sim, \ B /@ \((Range[n])\), {0, 500}, \ 
        PlotRange \[Rule] \ All, \ ImageSize \[Rule] \ 600, \ 
        holdLegend \[Rule] \ True];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 600 370.82 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.0147149 0.620773 [
[.15079 .00221 -6 -9 ]
[.15079 .00221 6 0 ]
[.27778 .00221 -6 -9 ]
[.27778 .00221 6 0 ]
[.40476 .00221 -6 -9 ]
[.40476 .00221 6 0 ]
[.53175 .00221 -6 -9 ]
[.53175 .00221 6 0 ]
[.65873 .00221 -9 -9 ]
[.65873 .00221 9 0 ]
[.78571 .00221 -9 -9 ]
[.78571 .00221 9 0 ]
[.9127 .00221 -9 -9 ]
[.9127 .00221 9 0 ]
[.01131 .13887 -18 -4.5 ]
[.01131 .13887 0 4.5 ]
[.01131 .26302 -18 -4.5 ]
[.01131 .26302 0 4.5 ]
[.01131 .38718 -18 -4.5 ]
[.01131 .38718 0 4.5 ]
[.01131 .51133 -18 -4.5 ]
[.01131 .51133 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01471 m
.15079 .02096 L
s
[(20)] .15079 .00221 0 1 Mshowa
.27778 .01471 m
.27778 .02096 L
s
[(40)] .27778 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(60)] .40476 .00221 0 1 Mshowa
.53175 .01471 m
.53175 .02096 L
s
[(80)] .53175 .00221 0 1 Mshowa
.65873 .01471 m
.65873 .02096 L
s
[(100)] .65873 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(120)] .78571 .00221 0 1 Mshowa
.9127 .01471 m
.9127 .02096 L
s
[(140)] .9127 .00221 0 1 Mshowa
.125 Mabswid
.05556 .01471 m
.05556 .01846 L
s
.0873 .01471 m
.0873 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.18254 .01471 m
.18254 .01846 L
s
.21429 .01471 m
.21429 .01846 L
s
.24603 .01471 m
.24603 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.34127 .01471 m
.34127 .01846 L
s
.37302 .01471 m
.37302 .01846 L
s
.43651 .01471 m
.43651 .01846 L
s
.46825 .01471 m
.46825 .01846 L
s
.5 .01471 m
.5 .01846 L
s
.56349 .01471 m
.56349 .01846 L
s
.59524 .01471 m
.59524 .01846 L
s
.62698 .01471 m
.62698 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.72222 .01471 m
.72222 .01846 L
s
.75397 .01471 m
.75397 .01846 L
s
.81746 .01471 m
.81746 .01846 L
s
.84921 .01471 m
.84921 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.94444 .01471 m
.94444 .01846 L
s
.97619 .01471 m
.97619 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13887 m
.03006 .13887 L
s
[(0.2)] .01131 .13887 1 0 Mshowa
.02381 .26302 m
.03006 .26302 L
s
[(0.4)] .01131 .26302 1 0 Mshowa
.02381 .38718 m
.03006 .38718 L
s
[(0.6)] .01131 .38718 1 0 Mshowa
.02381 .51133 m
.03006 .51133 L
s
[(0.8)] .01131 .51133 1 0 Mshowa
.125 Mabswid
.02381 .04575 m
.02756 .04575 L
s
.02381 .07679 m
.02756 .07679 L
s
.02381 .10783 m
.02756 .10783 L
s
.02381 .16991 m
.02756 .16991 L
s
.02381 .20095 m
.02756 .20095 L
s
.02381 .23199 m
.02756 .23199 L
s
.02381 .29406 m
.02756 .29406 L
s
.02381 .3251 m
.02756 .3251 L
s
.02381 .35614 m
.02756 .35614 L
s
.02381 .41822 m
.02756 .41822 L
s
.02381 .44926 m
.02756 .44926 L
s
.02381 .48029 m
.02756 .48029 L
s
.02381 .54237 m
.02756 .54237 L
s
.02381 .57341 m
.02756 .57341 L
s
.02381 .60445 m
.02756 .60445 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02138 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02122 L
.04262 .0209 L
.06244 .01954 L
.08259 .01839 L
.10458 .01745 L
.12517 .01679 L
.14429 .01634 L
.16481 .01598 L
.18342 .01574 L
.20266 .01555 L
.22348 .0154 L
.24342 .0153 L
.26449 .01522 L
.28413 .01516 L
.30246 .01512 L
.32281 .01509 L
.34137 .01507 L
.36045 .01505 L
.38121 .01504 L
.40099 .01503 L
.4111 .01503 L
.422 .01502 L
.43215 .01502 L
.44147 .01502 L
.45975 .01502 L
.46955 .01501 L
.47867 .01501 L
.48868 .01501 L
.49428 .01501 L
.49937 .01501 L
.50935 .01501 L
.51856 .01501 L
.5293 .01501 L
.53935 .01501 L
.5484 .01501 L
.55812 .01501 L
.57876 .01501 L
.62003 .01501 L
Mistroke
.64066 .01501 L
.65979 .01501 L
.6795 .01501 L
.69804 .01501 L
.7186 .015 L
.73722 .015 L
.74701 .015 L
.75734 .015 L
.76701 .015 L
.77582 .015 L
.78533 .015 L
.7955 .015 L
.81385 .015 L
.83458 .015 L
.85374 .015 L
.87237 .015 L
.89213 .015 L
.92993 .015 L
.97018 .015 L
.97619 .015 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01858 L
.10458 .01761 L
.12517 .01694 L
.14429 .01647 L
.16481 .01609 L
.18342 .01584 L
.20266 .01565 L
.22348 .01549 L
.24342 .01538 L
.26449 .01529 L
.28413 .01523 L
.30246 .01519 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .01511 L
.40099 .0151 L
.41097 .01509 L
.422 .01509 L
.44134 .01509 L
.45222 .01509 L
.4622 .01508 L
.46694 .01508 L
.472 .01508 L
.47638 .01508 L
.48112 .01508 L
.4867 .01508 L
.48926 .01508 L
.49197 .01508 L
.49441 .01508 L
.4971 .01508 L
.49954 .01508 L
.50182 .01508 L
.50307 .01508 L
.50441 .01508 L
Mistroke
.50566 .01508 L
.5068 .01508 L
.5075 .01508 L
.50815 .01508 L
.50885 .01508 L
.5096 .01508 L
.51085 .01508 L
.51157 .01508 L
.51223 .01508 L
.51351 .01508 L
.51473 .01508 L
.517 .01508 L
.51948 .01508 L
.52073 .01508 L
.52144 .01508 L
.52211 .01508 L
.52327 .01508 L
.52433 .01508 L
.5255 .01508 L
.52673 .01508 L
.52779 .01508 L
.52877 .01508 L
.52984 .01508 L
.53099 .01508 L
.5336 .01508 L
.53606 .01508 L
.53826 .01508 L
.54065 .01508 L
.54555 .01508 L
.55014 .01508 L
.56056 .01508 L
.57072 .01508 L
.58162 .01508 L
.62295 .01508 L
.64362 .01508 L
.66276 .01507 L
.6825 .01507 L
.70106 .01507 L
.7197 .01507 L
.72973 .01507 L
.74029 .01507 L
.74991 .01507 L
.76045 .01507 L
.76996 .01507 L
.77895 .01507 L
.7892 .01507 L
.79853 .01507 L
.81947 .01507 L
.83777 .01507 L
.85791 .01507 L
Mistroke
.87776 .01507 L
.8988 .01507 L
.9391 .01507 L
.97619 .01507 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02139 L
.04262 .02109 L
.06244 .01976 L
.08259 .01859 L
.10458 .01762 L
.12517 .01695 L
.14429 .01648 L
.16481 .01611 L
.18342 .01585 L
.20266 .01566 L
.22348 .0155 L
.24342 .01539 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01517 L
.34137 .01514 L
.36045 .01513 L
.38121 .01511 L
.40099 .0151 L
.4111 .0151 L
.422 .0151 L
.43215 .01509 L
.44147 .01509 L
.4503 .01509 L
.45975 .01509 L
.46955 .01509 L
.47867 .01509 L
.48425 .01509 L
.48952 .01509 L
.49424 .01509 L
.49691 .01509 L
.49937 .01509 L
.50181 .01509 L
.50404 .01509 L
.50528 .01509 L
.50662 .01509 L
.50789 .01509 L
Mistroke
.50906 .01509 L
.51025 .01509 L
.51137 .01509 L
.51237 .01509 L
.51346 .01509 L
.51464 .01509 L
.51589 .01509 L
.51813 .01509 L
.5194 .01509 L
.52059 .01509 L
.52126 .01509 L
.52197 .01509 L
.52323 .01509 L
.52443 .01509 L
.5257 .01509 L
.52678 .01509 L
.52798 .01509 L
.52938 .01509 L
.53066 .01509 L
.53207 .01509 L
.53355 .01509 L
.53605 .01509 L
.53877 .01509 L
.54408 .01509 L
.54907 .01509 L
.55842 .01509 L
.56849 .01508 L
.57939 .01508 L
.62036 .01508 L
.65981 .01508 L
.67965 .01508 L
.69775 .01508 L
.71724 .01508 L
.72809 .01508 L
.73814 .01508 L
.75721 .01508 L
.76726 .01508 L
.77796 .01508 L
.78731 .01507 L
.7974 .01507 L
.81568 .01507 L
.8353 .01507 L
.85678 .01507 L
.87729 .01507 L
.89638 .01507 L
.93539 .01507 L
.97619 .01507 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .0214 L
.04262 .02111 L
.06244 .01978 L
.08259 .01863 L
.10458 .01767 L
.12517 .017 L
.14429 .01654 L
.16481 .01616 L
.18342 .01591 L
.20266 .01571 L
.22348 .01555 L
.24342 .01544 L
.26449 .01536 L
.28413 .0153 L
.30246 .01526 L
.32281 .01522 L
.34137 .0152 L
.36045 .01518 L
.38121 .01517 L
.40099 .01516 L
.41097 .01516 L
.422 .01515 L
.43142 .01515 L
.44134 .01515 L
.45222 .01515 L
.45745 .01515 L
.4622 .01515 L
.46678 .01515 L
.47174 .01515 L
.47447 .01515 L
.47699 .01515 L
.47955 .01515 L
.48194 .01515 L
.48399 .01515 L
.48504 .01515 L
.48619 .01515 L
.48744 .01515 L
.48863 .01515 L
Mistroke
.48979 .01515 L
.49086 .01515 L
.4921 .01515 L
.49326 .01515 L
.49431 .01515 L
.49544 .01515 L
.49797 .01515 L
.50031 .01515 L
.51019 .01515 L
.52077 .01515 L
.5259 .01515 L
.52842 .01515 L
.53075 .01515 L
.53287 .01515 L
.53394 .01515 L
.53511 .01515 L
.53629 .01515 L
.53756 .01515 L
.53875 .01515 L
.53985 .01515 L
.54101 .01515 L
.54207 .01515 L
.54329 .01515 L
.54444 .01515 L
.54649 .01515 L
.54871 .01515 L
.55374 .01515 L
.55838 .01515 L
.56785 .01515 L
.57787 .01515 L
.61581 .01514 L
.6562 .01514 L
.67482 .01514 L
.69508 .01514 L
.71629 .01513 L
.72585 .01513 L
.73641 .01513 L
.75616 .01513 L
.76698 .01513 L
.77716 .01513 L
.78697 .01513 L
.79732 .01513 L
.81581 .01513 L
.83575 .01513 L
.85389 .01513 L
.87348 .01513 L
.89442 .01513 L
.93437 .01513 L
.9728 .01513 L
.97619 .01513 L
Mistroke
Mfstroke
1 .119 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03559 L
.03072 .04325 L
.03279 .04835 L
.03405 .05064 L
.03521 .05226 L
.03649 .05358 L
.03713 .05408 L
.03784 .05454 L
.03903 .05509 L
.04031 .05544 L
.04151 .05558 L
.04262 .05559 L
.04384 .05549 L
.04514 .05529 L
.04636 .05502 L
.04748 .05472 L
.05278 .0529 L
.06244 .0489 L
.08269 .04089 L
.10458 .03407 L
.12545 .02922 L
.14465 .0259 L
.16347 .02343 L
.18413 .02142 L
.20364 .02002 L
.22456 .01892 L
.2458 .01811 L
.26592 .01755 L
.28583 .01714 L
.30425 .01686 L
.32291 .01664 L
.34352 .01647 L
.36286 .01635 L
.38372 .01626 L
.40376 .01619 L
.41384 .01617 L
.42486 .01615 L
.43495 .01613 L
.44447 .01612 L
.45545 .01611 L
.46019 .0161 L
.46542 .0161 L
.47011 .0161 L
.47514 .01609 L
.48046 .01609 L
.48284 .01609 L
.48543 .01609 L
.488 .01609 L
Mistroke
.49038 .01609 L
.49265 .01609 L
.49392 .01609 L
.49507 .01609 L
.49621 .01609 L
.49726 .01609 L
.4984 .01609 L
.49961 .01609 L
.50067 .01609 L
.50165 .01609 L
.50273 .01609 L
.50389 .01609 L
.51352 .01609 L
.52373 .01609 L
.5263 .01609 L
.52907 .01609 L
.53065 .01609 L
.53134 .01609 L
.5321 .01609 L
.53277 .01609 L
.53349 .01609 L
.53424 .01609 L
.53494 .01609 L
.53564 .01609 L
.53628 .01609 L
.53699 .01609 L
.53774 .01609 L
.53899 .01609 L
.53971 .01609 L
.54037 .01609 L
.54275 .01609 L
.54408 .01609 L
.5453 .01609 L
.55039 .01609 L
.5551 .01609 L
.56028 .01609 L
.56578 .01609 L
.5852 .01608 L
.62291 .01606 L
.64386 .01605 L
.66309 .01604 L
.6831 .01603 L
.70174 .01602 L
.72064 .01602 L
.73128 .01602 L
.74133 .01601 L
.75113 .01601 L
.76176 .01601 L
.77136 .01601 L
.78035 .01601 L
Mistroke
.78979 .01601 L
.8002 .01601 L
.82123 .01601 L
.83978 .01601 L
.86002 .01601 L
.88117 .01601 L
.90127 .01601 L
.94193 .016 L
.97619 .016 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02085 L
.02846 .02124 L
.02954 .02144 L
.03053 .02155 L
.03163 .02162 L
.03279 .02166 L
.03395 .02166 L
.0352 .02164 L
.03638 .02161 L
.03746 .02157 L
.04262 .0213 L
.06244 .02 L
.08259 .01882 L
.10458 .01783 L
.12517 .01713 L
.14429 .01664 L
.16481 .01625 L
.18342 .01598 L
.20266 .01577 L
.22348 .0156 L
.24342 .01548 L
.26449 .01539 L
.28413 .01533 L
.30246 .01528 L
.32281 .01525 L
.34137 .01522 L
.36045 .0152 L
.38121 .01519 L
.40099 .01518 L
.41097 .01517 L
.422 .01517 L
.43142 .01517 L
.44134 .01517 L
.45222 .01516 L
.4622 .01516 L
.47174 .01516 L
.47709 .01516 L
.47961 .01516 L
.48194 .01516 L
.4841 .01516 L
.48647 .01516 L
.48886 .01516 L
.49018 .01516 L
.49139 .01516 L
.49245 .01516 L
.49361 .01516 L
.49483 .01516 L
Mistroke
.496 .01516 L
.49708 .01516 L
.49823 .01516 L
.49932 .01516 L
.50031 .01516 L
.50151 .01516 L
.50264 .01516 L
.5052 .01516 L
.51036 .01516 L
.51959 .01516 L
.52476 .01516 L
.5273 .01516 L
.52965 .01516 L
.53094 .01516 L
.53236 .01516 L
.53304 .01516 L
.53378 .01516 L
.53456 .01516 L
.53529 .01516 L
.5366 .01516 L
.53725 .01516 L
.53797 .01516 L
.53924 .01516 L
.54043 .01516 L
.54171 .01516 L
.54306 .01516 L
.54549 .01516 L
.54811 .01516 L
.55098 .01516 L
.55612 .01516 L
.56092 .01516 L
.5699 .01516 L
.57952 .01516 L
.62085 .01515 L
.66067 .01515 L
.67886 .01515 L
.69896 .01515 L
.71871 .01515 L
.72966 .01515 L
.73971 .01515 L
.75904 .01515 L
.76919 .01515 L
.77988 .01515 L
.78941 .01515 L
.7996 .01515 L
.81796 .01515 L
.83785 .01515 L
.85942 .01515 L
.89937 .01515 L
.94026 .01515 L
Mistroke
.97619 .01514 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04857 L
.03416 .05114 L
.03543 .05295 L
.03665 .05424 L
.03793 .05522 L
.03908 .05583 L
.04016 .0562 L
.04135 .05644 L
.04262 .05653 L
.04393 .05649 L
.04516 .05634 L
.04586 .05622 L
.0465 .05609 L
.04793 .05574 L
.05297 .05407 L
.06244 .05018 L
.08269 .04205 L
.10458 .03501 L
.12545 .02998 L
.14465 .02651 L
.16347 .02393 L
.18413 .02182 L
.20364 .02034 L
.22456 .01918 L
.2458 .01831 L
.26592 .01772 L
.28583 .01729 L
.30425 .01699 L
.32291 .01676 L
.34352 .01657 L
.36286 .01645 L
.38372 .01635 L
.40376 .01628 L
.41384 .01625 L
.42486 .01623 L
.43495 .01621 L
.44447 .0162 L
.45545 .01618 L
.46019 .01618 L
.46542 .01618 L
.47011 .01617 L
.47514 .01617 L
.48046 .01617 L
.48284 .01617 L
.48543 .01617 L
.488 .01617 L
Mistroke
.49038 .01616 L
.49265 .01616 L
.49392 .01616 L
.49507 .01616 L
.49621 .01616 L
.49726 .01616 L
.4984 .01616 L
.49961 .01616 L
.50067 .01616 L
.50165 .01616 L
.50273 .01616 L
.50389 .01616 L
.51352 .01617 L
.52373 .01617 L
.5263 .01617 L
.52907 .01617 L
.53065 .01617 L
.5321 .01617 L
.53349 .01617 L
.53418 .01617 L
.53494 .01617 L
.53564 .01617 L
.5363 .01617 L
.53754 .01617 L
.53823 .01617 L
.53887 .01617 L
.53957 .01617 L
.54031 .01617 L
.54154 .01617 L
.54269 .01617 L
.5453 .01617 L
.54777 .01617 L
.55046 .01617 L
.55536 .01616 L
.56013 .01616 L
.56455 .01616 L
.5852 .01615 L
.62443 .01613 L
.66215 .01611 L
.68147 .0161 L
.70232 .01609 L
.72234 .01609 L
.73253 .01609 L
.74343 .01608 L
.75375 .01608 L
.76314 .01608 L
.77206 .01608 L
.7815 .01608 L
.79147 .01608 L
.80066 .01608 L
Mistroke
.82145 .01608 L
.85931 .01608 L
.87873 .01607 L
.89962 .01607 L
.94086 .01607 L
.97619 .01607 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.02605 .02534 L
.02846 .03502 L
.02962 .0388 L
.03072 .04177 L
.0317 .04394 L
.03279 .04586 L
.03398 .04746 L
.03524 .0487 L
.03641 .04949 L
.0375 .04999 L
.03879 .05035 L
.03997 .05051 L
.04062 .05054 L
.04132 .05053 L
.04262 .05044 L
.04326 .05036 L
.04396 .05024 L
.04523 .04999 L
.04759 .04939 L
.0529 .04769 L
.06244 .04422 L
.08293 .03726 L
.10458 .03149 L
.12413 .02756 L
.14558 .02435 L
.16509 .0222 L
.18601 .02049 L
.20725 .01923 L
.22737 .01835 L
.24728 .01772 L
.2657 .01728 L
.28436 .01694 L
.30496 .01666 L
.32431 .01648 L
.34517 .01633 L
.36521 .01622 L
.38631 .01614 L
.40605 .01609 L
.42442 .01606 L
.43494 .01604 L
.44487 .01603 L
.45379 .01602 L
.46346 .01601 L
.46802 .01601 L
.47293 .01601 L
.4783 .01601 L
.48334 .01601 L
.48604 .01601 L
.48746 .01601 L
Mistroke
.48898 .01601 L
.49044 .01601 L
.49176 .01601 L
.49239 .01601 L
.49308 .01601 L
.49433 .01601 L
.49555 .01601 L
.49624 .01601 L
.49688 .01601 L
.49818 .01601 L
.49891 .01601 L
.49957 .01601 L
.50204 .01601 L
.50438 .01601 L
.52264 .01601 L
.52764 .01601 L
.53026 .01601 L
.53302 .01601 L
.53545 .01601 L
.53683 .01601 L
.53811 .01601 L
.53929 .01601 L
.54036 .01601 L
.5416 .01601 L
.54276 .01601 L
.54391 .01601 L
.54517 .01601 L
.54648 .01601 L
.54771 .01601 L
.54991 .01601 L
.55228 .01601 L
.55766 .01601 L
.56257 .01601 L
.57337 .016 L
.5836 .016 L
.62189 .01598 L
.66264 .01596 L
.68287 .01595 L
.70188 .01595 L
.72002 .01594 L
.7396 .01594 L
.74915 .01594 L
.75961 .01594 L
.77053 .01594 L
.7807 .01594 L
.79121 .01594 L
.80114 .01594 L
.81972 .01593 L
.85815 .01593 L
.878 .01593 L
Mistroke
.89904 .01593 L
.93689 .01593 L
.97619 .01593 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03564 L
.03053 .0429 L
.03279 .04888 L
.03416 .05161 L
.03543 .05357 L
.03665 .05501 L
.03793 .05616 L
.03908 .0569 L
.04016 .0574 L
.04135 .05776 L
.04262 .05797 L
.04393 .05803 L
.04516 .05797 L
.04586 .0579 L
.0465 .0578 L
.04793 .05753 L
.05052 .05685 L
.05297 .05605 L
.06244 .0523 L
.08439 .04342 L
.10458 .03675 L
.12333 .03194 L
.14313 .02805 L
.16277 .02515 L
.1811 .0231 L
.20145 .02139 L
.22001 .02023 L
.2391 .01932 L
.25986 .0186 L
.27963 .01809 L
.30064 .01769 L
.32011 .01742 L
.33839 .01723 L
.35857 .01708 L
.37708 .01698 L
.396 .0169 L
.40672 .01687 L
.4167 .01684 L
.42722 .01682 L
.43716 .0168 L
.44608 .01679 L
.45107 .01679 L
.45575 .01679 L
.46031 .01678 L
.46521 .01678 L
.468 .01678 L
.46938 .01678 L
.47065 .01678 L
Mistroke
.4719 .01678 L
.47303 .01678 L
.47428 .01678 L
.47497 .01678 L
.47562 .01678 L
.47685 .01678 L
.47754 .01678 L
.47819 .01678 L
.47949 .01678 L
.48023 .01678 L
.48089 .01678 L
.48209 .01678 L
.48338 .01678 L
.48574 .01678 L
.48849 .01678 L
.49142 .01678 L
.49666 .01678 L
.5164 .0168 L
.52503 .0168 L
.5296 .01681 L
.53447 .01681 L
.53704 .01681 L
.53937 .01681 L
.54171 .01681 L
.54276 .01681 L
.54392 .01681 L
.54512 .01681 L
.5464 .01681 L
.54758 .01681 L
.54869 .01681 L
.54999 .01681 L
.55118 .01681 L
.55184 .01681 L
.55255 .01681 L
.55385 .01681 L
.55635 .01681 L
.5591 .01681 L
.56469 .01681 L
.56986 .0168 L
.57472 .0168 L
.59488 .01678 L
.61338 .01676 L
.65297 .01673 L
.69105 .0167 L
.71063 .01668 L
.73157 .01668 L
.7418 .01667 L
.7529 .01667 L
.76248 .01667 L
.77304 .01667 L
Mistroke
.78329 .01666 L
.79289 .01666 L
.81393 .01666 L
.85272 .01666 L
.87387 .01666 L
.89396 .01666 L
.93218 .01665 L
.97284 .01665 L
.97619 .01665 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02086 L
.02846 .02124 L
.02954 .02145 L
.03053 .02156 L
.03163 .02163 L
.03279 .02167 L
.03395 .02167 L
.0352 .02166 L
.03638 .02163 L
.03746 .02159 L
.04011 .02147 L
.04262 .02133 L
.06244 .02007 L
.08429 .01884 L
.10458 .01796 L
.12307 .01734 L
.14277 .01684 L
.16418 .01643 L
.18435 .01614 L
.20443 .01593 L
.22291 .01579 L
.24173 .01567 L
.26239 .01558 L
.2819 .01552 L
.30282 .01547 L
.32406 .01543 L
.34418 .0154 L
.36409 .01538 L
.38251 .01537 L
.40117 .01536 L
.4118 .01536 L
.42177 .01536 L
.43161 .01535 L
.43697 .01535 L
.44196 .01535 L
.44659 .01535 L
.45079 .01535 L
.45547 .01535 L
.45804 .01535 L
.46046 .01535 L
.46161 .01535 L
.46285 .01535 L
.46402 .01535 L
.46509 .01535 L
.46634 .01535 L
.46705 .01535 L
.4677 .01535 L
Mistroke
.4689 .01535 L
.47018 .01535 L
.47088 .01535 L
.47152 .01535 L
.47297 .01535 L
.47424 .01535 L
.47558 .01535 L
.47792 .01535 L
.48048 .01535 L
.48509 .01535 L
.49002 .01535 L
.49893 .01535 L
.51878 .01536 L
.52924 .01536 L
.53452 .01536 L
.53756 .01536 L
.54034 .01536 L
.54285 .01536 L
.5455 .01536 L
.54687 .01536 L
.54815 .01536 L
.54888 .01536 L
.54955 .01536 L
.55032 .01536 L
.55104 .01536 L
.55226 .01536 L
.55355 .01536 L
.55465 .01536 L
.55586 .01536 L
.55716 .01536 L
.55856 .01536 L
.56108 .01536 L
.56354 .01536 L
.56622 .01536 L
.5711 .01536 L
.58024 .01536 L
.59999 .01535 L
.62099 .01535 L
.65871 .01534 L
.67966 .01534 L
.69888 .01534 L
.7177 .01534 L
.73753 .01534 L
.74706 .01534 L
.75725 .01533 L
.77561 .01533 L
.78584 .01533 L
.79693 .01533 L
.80741 .01533 L
.81707 .01533 L
Mistroke
.83741 .01533 L
.85645 .01533 L
.87469 .01533 L
.8943 .01533 L
.93554 .01533 L
.97527 .01533 L
.97619 .01533 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.02846 .03631 L
.03279 .05261 L
.03527 .05975 L
.03754 .06482 L
.03879 .06708 L
.04015 .06912 L
.04142 .07068 L
.04262 .07187 L
.04386 .07286 L
.045 .07355 L
.04626 .07413 L
.04696 .07437 L
.04762 .07454 L
.04894 .07477 L
.05016 .07484 L
.05086 .07484 L
.0515 .0748 L
.05223 .07473 L
.05293 .07463 L
.05408 .07441 L
.05531 .07411 L
.0575 .07342 L
.06244 .07139 L
.08424 .05985 L
.10458 .04986 L
.12408 .04215 L
.14255 .03641 L
.1629 .03157 L
.18146 .02821 L
.20137 .02547 L
.21979 .02356 L
.23845 .02208 L
.25906 .02086 L
.2784 .02001 L
.29926 .01933 L
.3193 .01885 L
.3404 .01849 L
.36014 .01824 L
.37851 .01807 L
.38903 .01799 L
.39896 .01793 L
.41755 .01784 L
.42727 .01781 L
.43757 .01778 L
.44635 .01776 L
.45602 .01774 L
.46123 .01774 L
.4638 .01773 L
.46618 .01773 L
Mistroke
.46851 .01773 L
.47062 .01773 L
.47297 .01773 L
.47426 .01773 L
.47547 .01773 L
.47668 .01773 L
.47737 .01773 L
.47801 .01773 L
.47931 .01773 L
.48004 .01773 L
.4807 .01773 L
.48188 .01773 L
.48317 .01773 L
.48551 .01773 L
.48825 .01773 L
.49115 .01773 L
.49636 .01774 L
.50575 .01775 L
.51587 .01776 L
.52535 .01777 L
.53416 .01778 L
.5388 .01778 L
.5414 .01779 L
.54376 .01779 L
.54511 .01779 L
.54635 .01779 L
.54705 .01779 L
.54771 .01779 L
.5484 .01779 L
.54915 .01779 L
.55044 .01779 L
.55161 .01779 L
.55226 .01779 L
.55296 .01779 L
.55424 .01779 L
.55554 .01779 L
.55677 .01779 L
.55955 .01779 L
.56227 .01778 L
.5652 .01778 L
.57535 .01777 L
.58491 .01776 L
.59537 .01774 L
.61646 .0177 L
.65699 .01763 L
.6757 .0176 L
.696 .01758 L
.71732 .01756 L
.73747 .01754 L
.75732 .01754 L
Mistroke
.76733 .01753 L
.77836 .01753 L
.79778 .01752 L
.80869 .01752 L
.81866 .01752 L
.85839 .01752 L
.8966 .01751 L
.93727 .0175 L
.97619 .0175 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02137 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02121 L
.04262 .0209 L
.06244 .01954 L
.08259 .01838 L
.10458 .01743 L
.12517 .01677 L
.14429 .01632 L
.16481 .01595 L
.18342 .01571 L
.20266 .01552 L
.22348 .01537 L
.24342 .01526 L
.26449 .01518 L
.28413 .01512 L
.30246 .01508 L
.32281 .01505 L
.34137 .01503 L
.36045 .01501 L
.38121 .015 L
.40099 .01499 L
.4111 .01499 L
.422 .01499 L
.43215 .01498 L
.44147 .01498 L
.45975 .01498 L
.46955 .01498 L
.47867 .01498 L
.48868 .01498 L
.49937 .01497 L
.50961 .01497 L
.52072 .01497 L
.54087 .01497 L
.58179 .01497 L
.62119 .01497 L
.65908 .01497 L
.67852 .01497 L
.69942 .01497 L
.72059 .01497 L
Mistroke
.73033 .01497 L
.74069 .01497 L
.75111 .01497 L
.76054 .01497 L
.76949 .01497 L
.77894 .01497 L
.78899 .01497 L
.79822 .01497 L
.81906 .01497 L
.83896 .01497 L
.85708 .01497 L
.87663 .01497 L
.89756 .01497 L
.93746 .01497 L
.97584 .01497 L
.97619 .01497 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.03279 .05613 L
.03793 .07563 L
.04262 .08909 L
.04517 .09451 L
.04758 .09842 L
.05012 .10138 L
.05156 .10257 L
.05288 .10339 L
.05402 .1039 L
.05509 .10423 L
.05626 .10445 L
.05752 .10452 L
.05884 .10444 L
.06009 .10422 L
.06122 .10394 L
.06244 .10353 L
.0653 .10227 L
.06799 .10076 L
.07302 .09739 L
.08429 .08864 L
.10458 .07306 L
.12296 .06115 L
.14313 .05077 L
.16307 .0429 L
.18413 .03663 L
.20364 .03228 L
.22456 .0288 L
.2458 .02619 L
.26592 .02438 L
.28583 .02304 L
.30425 .02212 L
.32291 .02141 L
.34352 .02083 L
.36286 .02043 L
.37282 .02027 L
.38372 .02013 L
.40376 .01992 L
.41469 .01983 L
.42486 .01977 L
.43538 .01972 L
.44055 .0197 L
.44532 .01969 L
.44956 .01968 L
.45423 .01967 L
.45893 .01966 L
.4615 .01966 L
.4639 .01966 L
.46515 .01966 L
.46584 .01966 L
Mistroke
.46649 .01966 L
.46774 .01966 L
.46888 .01966 L
.46954 .01966 L
.47024 .01966 L
.47149 .01966 L
.47219 .01966 L
.47284 .01966 L
.47431 .01966 L
.47559 .01966 L
.47681 .01966 L
.47908 .01966 L
.48153 .01966 L
.48419 .01967 L
.48887 .01968 L
.49383 .01969 L
.50273 .01972 L
.52246 .01979 L
.5311 .01982 L
.53566 .01983 L
.54053 .01984 L
.5431 .01985 L
.54543 .01985 L
.54777 .01985 L
.54998 .01985 L
.55119 .01986 L
.55246 .01986 L
.55355 .01986 L
.55475 .01986 L
.55604 .01986 L
.55676 .01986 L
.55742 .01986 L
.5587 .01986 L
.55992 .01986 L
.56111 .01985 L
.56243 .01985 L
.5651 .01985 L
.56991 .01984 L
.57552 .01983 L
.58079 .01982 L
.60094 .01975 L
.61944 .01968 L
.65903 .01952 L
.69711 .01941 L
.7167 .01937 L
.73764 .01934 L
.74786 .01932 L
.75896 .01931 L
.76855 .01931 L
.7791 .0193 L
Mistroke
.78936 .01929 L
.79895 .01929 L
.80909 .01929 L
.81999 .01929 L
.86123 .01928 L
.90096 .01927 L
.93918 .01926 L
.97619 .01925 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.03279 .05601 L
.03793 .0751 L
.04262 .08788 L
.04517 .09284 L
.04758 .09629 L
.0489 .09773 L
.05012 .09878 L
.05146 .09967 L
.05214 .10002 L
.05288 .10034 L
.05412 .10071 L
.05526 .10089 L
.05657 .10094 L
.05782 .10084 L
.05897 .10063 L
.06003 .10036 L
.06244 .09949 L
.06509 .09821 L
.06795 .09655 L
.07314 .09304 L
.08284 .08573 L
.10458 .06981 L
.12413 .05799 L
.14558 .0479 L
.166 .04065 L
.18507 .03552 L
.20542 .03139 L
.22398 .02854 L
.24306 .02632 L
.26382 .02453 L
.2836 .02326 L
.30461 .02227 L
.32408 .02159 L
.34236 .02112 L
.36254 .02074 L
.38104 .02048 L
.39997 .02029 L
.41069 .02021 L
.42067 .02016 L
.43119 .02011 L
.43636 .02009 L
.44113 .02008 L
.44546 .02007 L
.45005 .02006 L
.45242 .02006 L
.45465 .02006 L
.4559 .02006 L
.45709 .02006 L
.45775 .02006 L
Mistroke
.45846 .02005 L
.45971 .02005 L
.46036 .02005 L
.46105 .02005 L
.46228 .02005 L
.4636 .02005 L
.46435 .02005 L
.46504 .02005 L
.46631 .02006 L
.46747 .02006 L
.47006 .02006 L
.47237 .02006 L
.47487 .02007 L
.47943 .02007 L
.48472 .02009 L
.49033 .02011 L
.50041 .02015 L
.52014 .02025 L
.52878 .02029 L
.53821 .02032 L
.54311 .02034 L
.54546 .02034 L
.54766 .02034 L
.54887 .02035 L
.55018 .02035 L
.55127 .02035 L
.55247 .02035 L
.55377 .02035 L
.55448 .02035 L
.55514 .02035 L
.55633 .02035 L
.5576 .02035 L
.55827 .02035 L
.55899 .02035 L
.56028 .02035 L
.561 .02035 L
.56167 .02035 L
.5632 .02035 L
.56576 .02035 L
.56851 .02034 L
.5737 .02033 L
.57847 .02032 L
.59737 .02025 L
.61806 .02016 L
.65859 .01998 L
.6976 .01984 L
.71892 .01979 L
.73907 .01976 L
.74877 .01974 L
.75906 .01973 L
Mistroke
.7775 .01971 L
.78692 .01971 L
.79705 .0197 L
.81536 .0197 L
.83651 .01969 L
.8566 .01969 L
.89481 .01968 L
.93548 .01967 L
.97463 .01965 L
.97619 .01965 L
Mfstroke
1 .356 0 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02086 L
.02846 .02124 L
.02954 .02144 L
.03053 .02156 L
.03163 .02163 L
.03279 .02166 L
.03395 .02166 L
.0352 .02165 L
.03638 .02162 L
.03746 .02158 L
.04262 .02131 L
.06244 .02003 L
.08259 .01889 L
.10458 .01792 L
.12517 .01724 L
.14429 .01676 L
.16481 .01638 L
.18342 .01612 L
.20266 .01591 L
.22348 .01575 L
.24342 .01563 L
.26449 .01554 L
.28413 .01548 L
.30246 .01544 L
.32281 .0154 L
.34137 .01538 L
.36045 .01536 L
.38121 .01534 L
.40099 .01533 L
.41097 .01533 L
.422 .01533 L
.43209 .01532 L
.44134 .01532 L
.44619 .01532 L
.4515 .01532 L
.45418 .01532 L
.45704 .01532 L
.4595 .01532 L
.4622 .01532 L
.46479 .01532 L
.4662 .01532 L
.46688 .01532 L
.46753 .01532 L
.46877 .01532 L
.4699 .01532 L
.47111 .01532 L
.4718 .01532 L
Mistroke
.47244 .01532 L
.47314 .01532 L
.4739 .01532 L
.47526 .01532 L
.4766 .01532 L
.47782 .01532 L
.48061 .01532 L
.48354 .01532 L
.48852 .01532 L
.49316 .01532 L
.5037 .01532 L
.52237 .01533 L
.53221 .01533 L
.5376 .01533 L
.54266 .01533 L
.5454 .01533 L
.54792 .01533 L
.55071 .01533 L
.55218 .01533 L
.55372 .01533 L
.55494 .01533 L
.55625 .01533 L
.55748 .01533 L
.5586 .01533 L
.55992 .01533 L
.56066 .01533 L
.56135 .01533 L
.56261 .01533 L
.56394 .01533 L
.56633 .01533 L
.5689 .01533 L
.57353 .01533 L
.57904 .01533 L
.58407 .01533 L
.60313 .01532 L
.62388 .01532 L
.66463 .01531 L
.68486 .01531 L
.70387 .01531 L
.72223 .01531 L
.74159 .01531 L
.75121 .01531 L
.76174 .01531 L
.77125 .01531 L
.78024 .0153 L
.7905 .0153 L
.79983 .0153 L
.80505 .0153 L
.80987 .0153 L
.81516 .0153 L
Mistroke
.81783 .0153 L
.82077 .0153 L
.82326 .0153 L
.82457 .0153 L
.82597 .0153 L
.82732 .0153 L
.82854 .0153 L
.82976 .0153 L
.83092 .0153 L
.83204 .0153 L
.83324 .0153 L
.83426 .0153 L
.83537 .0153 L
.83658 .0153 L
.83787 .0153 L
.83908 .0153 L
.84019 .0153 L
.84533 .0153 L
.85092 .0153 L
.85616 .0153 L
.86108 .0153 L
.86328 .0153 L
.86561 .0153 L
.86682 .0153 L
.86815 .0153 L
.86936 .0153 L
.87049 .0153 L
.87114 .0153 L
.87184 .0153 L
.87312 .0153 L
.87436 .0153 L
.87551 .0153 L
.87675 .0153 L
.87745 .0153 L
.87811 .0153 L
.87943 .0153 L
.88087 .0153 L
.88358 .0153 L
.88616 .0153 L
.891 .0153 L
.89665 .0153 L
.90188 .0153 L
.91248 .0153 L
.92246 .0153 L
.94108 .0153 L
.97619 .0153 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.02499 .01855 L
.02605 .01996 L
.02729 .02068 L
.02846 .02099 L
.02954 .02114 L
.03053 .02121 L
.03163 .02124 L
.03279 .02124 L
.03395 .02121 L
.0352 .02117 L
.03746 .02105 L
.04262 .02071 L
.06244 .01933 L
.08405 .01812 L
.10458 .01726 L
.12429 .01664 L
.1458 .01615 L
.16548 .01582 L
.18645 .01556 L
.20786 .01537 L
.22803 .01524 L
.24811 .01515 L
.26658 .01508 L
.28541 .01503 L
.30607 .01499 L
.32558 .01497 L
.34649 .01494 L
.36773 .01493 L
.38786 .01492 L
.40776 .01491 L
.42618 .0149 L
.44485 .0149 L
.4556 .0149 L
.46545 .0149 L
.4848 .0149 L
.49496 .01489 L
.50565 .01489 L
.54376 .01489 L
.58432 .01489 L
.62337 .01489 L
.64328 .01489 L
.66487 .01489 L
.68567 .01489 L
.70485 .01489 L
.72361 .01489 L
.73428 .01489 L
.74425 .01489 L
.75466 .01489 L
.76454 .01489 L
Mistroke
.77341 .01489 L
.78308 .01489 L
.79342 .01489 L
.80279 .01489 L
.82377 .01489 L
.84306 .01489 L
.85392 .01489 L
.86389 .01489 L
.90343 .01489 L
.94146 .01489 L
.97619 .01489 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.03279 .05651 L
.04262 .09359 L
.04758 .10712 L
.0503 .11292 L
.05288 .11734 L
.05528 .12058 L
.05655 .12196 L
.05789 .1232 L
.05902 .12407 L
.06026 .12485 L
.06139 .12542 L
.06244 .12582 L
.0631 .12602 L
.06379 .12618 L
.06504 .12637 L
.06581 .12642 L
.06653 .12642 L
.06718 .12639 L
.06788 .12632 L
.06919 .1261 L
.06985 .12594 L
.07057 .12575 L
.07305 .12485 L
.07547 .12369 L
.07806 .12219 L
.08274 .11898 L
.10458 .10052 L
.12439 .08424 L
.14594 .06949 L
.16664 .05837 L
.18579 .05037 L
.20445 .04429 L
.22505 .03916 L
.2444 .03551 L
.26526 .03254 L
.2853 .03042 L
.3064 .02877 L
.32614 .02762 L
.3445 .02683 L
.36496 .02619 L
.38355 .02577 L
.39353 .0256 L
.40273 .02547 L
.41284 .02536 L
.41842 .02531 L
.42353 .02527 L
.42805 .02525 L
.43297 .02522 L
.43567 .02521 L
Mistroke
.43817 .02521 L
.44056 .0252 L
.4419 .0252 L
.44311 .0252 L
.44426 .0252 L
.44547 .02519 L
.44651 .02519 L
.44764 .02519 L
.44887 .02519 L
.45018 .0252 L
.45141 .0252 L
.45254 .0252 L
.45473 .0252 L
.4571 .02521 L
.46142 .02522 L
.46628 .02525 L
.47084 .02528 L
.47627 .02532 L
.48123 .02537 L
.49135 .0255 L
.50225 .02568 L
.52282 .0261 L
.53284 .02628 L
.54193 .02642 L
.54649 .02647 L
.54889 .02649 L
.55143 .02651 L
.55365 .02652 L
.5561 .02654 L
.55717 .02654 L
.55832 .02654 L
.55932 .02655 L
.56039 .02655 L
.56171 .02655 L
.56292 .02655 L
.56423 .02655 L
.56498 .02655 L
.56568 .02655 L
.56694 .02655 L
.56809 .02655 L
.56936 .02655 L
.57069 .02654 L
.57301 .02653 L
.57518 .02652 L
.58009 .02649 L
.58513 .02645 L
.5906 .0264 L
.60052 .02629 L
.6191 .02604 L
.65999 .02546 L
Mistroke
.68032 .02522 L
.69936 .02504 L
.71877 .02488 L
.73722 .02477 L
.74691 .02473 L
.75748 .02468 L
.76702 .02465 L
.77601 .02463 L
.78097 .02462 L
.78634 .02461 L
.79569 .0246 L
.80101 .02459 L
.80391 .02459 L
.80662 .02459 L
.80913 .02459 L
.81141 .02459 L
.81395 .02459 L
.81535 .02459 L
.81667 .02459 L
.81781 .02459 L
.81904 .02459 L
.8202 .02459 L
.82127 .02459 L
.82245 .02459 L
.82374 .02459 L
.82439 .02459 L
.82508 .02459 L
.82634 .02459 L
.8291 .02459 L
.83171 .02459 L
.8366 .02459 L
.8412 .02459 L
.84544 .0246 L
.85502 .0246 L
.87539 .02463 L
.89444 .02465 L
.90382 .02466 L
.91272 .02466 L
.91763 .02467 L
.92298 .02467 L
.92534 .02467 L
.92785 .02467 L
.93 .02467 L
.93235 .02467 L
.93371 .02467 L
.93497 .02467 L
.93631 .02467 L
.93705 .02467 L
.93773 .02467 L
.93895 .02467 L
Mistroke
.94027 .02467 L
.94152 .02467 L
.94267 .02467 L
.94331 .02467 L
.944 .02467 L
.94525 .02467 L
.94808 .02467 L
.95108 .02467 L
.95382 .02467 L
.95877 .02467 L
.96417 .02466 L
.97401 .02466 L
.97619 .02465 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.02846 .03628 L
.03279 .05239 L
.03527 .0593 L
.03754 .06407 L
.03879 .06615 L
.04015 .06799 L
.04142 .06937 L
.04262 .07039 L
.04376 .07115 L
.045 .07176 L
.0457 .07202 L
.04637 .07221 L
.04762 .07246 L
.04894 .07256 L
.05016 .07254 L
.05086 .07248 L
.0515 .0724 L
.05223 .07228 L
.05293 .07215 L
.05531 .07152 L
.0575 .07077 L
.06244 .06868 L
.08253 .05844 L
.10458 .04822 L
.125 .04075 L
.14407 .03535 L
.16442 .03095 L
.18298 .02791 L
.20206 .02553 L
.22282 .02359 L
.2426 .02222 L
.2636 .02114 L
.28307 .0204 L
.30135 .01988 L
.32154 .01945 L
.34004 .01916 L
.35897 .01894 L
.36981 .01884 L
.37967 .01877 L
.39928 .01865 L
.41005 .01861 L
.42023 .01857 L
.42995 .01855 L
.43527 .01854 L
.44024 .01853 L
.44448 .01852 L
.44903 .01852 L
.45162 .01852 L
.45289 .01852 L
Mistroke
.45408 .01852 L
.45524 .01852 L
.45629 .01852 L
.45745 .01852 L
.45869 .01852 L
.4599 .01852 L
.46103 .01852 L
.46226 .01852 L
.46358 .01852 L
.46425 .01852 L
.46497 .01852 L
.46628 .01852 L
.46874 .01852 L
.47107 .01852 L
.47354 .01852 L
.47798 .01853 L
.48309 .01854 L
.48789 .01854 L
.49881 .01857 L
.51733 .01862 L
.52781 .01865 L
.53292 .01866 L
.53755 .01867 L
.53995 .01868 L
.54255 .01868 L
.5448 .01868 L
.54727 .01868 L
.54862 .01868 L
.54989 .01868 L
.55123 .01869 L
.55198 .01869 L
.55266 .01869 L
.55388 .01869 L
.55457 .01869 L
.55521 .01869 L
.55638 .01869 L
.55763 .01869 L
.55893 .01868 L
.56012 .01868 L
.5628 .01868 L
.56517 .01868 L
.56766 .01868 L
.57295 .01867 L
.57874 .01866 L
.59833 .01862 L
.61927 .01856 L
.66074 .01845 L
.68151 .01841 L
.70069 .01838 L
.71935 .01835 L
Mistroke
.73912 .01833 L
.74854 .01832 L
.75867 .01832 L
.77698 .01831 L
.78709 .01831 L
.79813 .0183 L
.81822 .0183 L
.83955 .01829 L
.85889 .01829 L
.89804 .01828 L
.93812 .01827 L
.97619 .01826 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.02499 .01859 L
.02605 .02009 L
.02729 .02092 L
.02846 .02133 L
.02954 .02155 L
.03053 .02168 L
.03163 .02176 L
.03279 .02181 L
.03395 .02183 L
.0352 .02183 L
.03638 .02181 L
.03746 .02178 L
.04011 .02167 L
.04262 .02155 L
.06244 .02034 L
.08429 .01912 L
.10458 .01824 L
.12307 .01761 L
.14277 .01709 L
.16418 .01667 L
.18435 .01638 L
.20443 .01616 L
.22291 .01601 L
.24173 .01589 L
.26239 .0158 L
.2819 .01573 L
.30282 .01568 L
.32406 .01564 L
.34418 .01561 L
.36409 .01559 L
.38251 .01558 L
.40117 .01557 L
.4118 .01557 L
.42177 .01556 L
.43161 .01556 L
.43655 .01556 L
.43938 .01556 L
.44196 .01556 L
.44418 .01556 L
.44659 .01556 L
.44792 .01556 L
.44914 .01556 L
.45031 .01556 L
.45154 .01556 L
.4526 .01556 L
.45374 .01556 L
.45481 .01556 L
.45579 .01556 L
.45694 .01556 L
Mistroke
.45819 .01556 L
.45937 .01556 L
.46046 .01556 L
.46312 .01556 L
.46555 .01556 L
.47106 .01556 L
.47591 .01556 L
.48102 .01556 L
.48991 .01556 L
.49964 .01557 L
.52083 .01557 L
.53086 .01558 L
.54012 .01558 L
.54478 .01558 L
.54715 .01558 L
.54972 .01558 L
.55105 .01558 L
.55228 .01558 L
.55352 .01558 L
.55467 .01558 L
.55595 .01558 L
.55662 .01558 L
.55734 .01558 L
.55809 .01558 L
.55881 .01558 L
.55945 .01558 L
.56014 .01558 L
.56132 .01558 L
.56242 .01558 L
.56363 .01558 L
.56493 .01558 L
.56758 .01558 L
.57 .01558 L
.57466 .01558 L
.57908 .01558 L
.58872 .01558 L
.59897 .01558 L
.61738 .01557 L
.6551 .01556 L
.67604 .01555 L
.69527 .01555 L
.71528 .01555 L
.73392 .01554 L
.75282 .01554 L
.76282 .01554 L
.77351 .01554 L
.78374 .01554 L
.79484 .01554 L
.80531 .01554 L
.81498 .01554 L
Mistroke
.83531 .01554 L
.85435 .01554 L
.87259 .01554 L
.89221 .01554 L
.93345 .01554 L
.97318 .01553 L
.97619 .01553 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02135 L
.03053 .02145 L
.03163 .0215 L
.03279 .02152 L
.03395 .02152 L
.0352 .02149 L
.03638 .02145 L
.03746 .02141 L
.04262 .02112 L
.06244 .01983 L
.08259 .0187 L
.10458 .01776 L
.12517 .0171 L
.14429 .01665 L
.16481 .01628 L
.18342 .01604 L
.20266 .01584 L
.22348 .01569 L
.24342 .01558 L
.26449 .01549 L
.28413 .01544 L
.30246 .0154 L
.32281 .01536 L
.34137 .01534 L
.36045 .01532 L
.37032 .01532 L
.38121 .01531 L
.40099 .0153 L
.41182 .0153 L
.422 .0153 L
.43183 .01529 L
.43719 .01529 L
.44218 .01529 L
.44681 .01529 L
.45102 .01529 L
.45569 .01529 L
.45826 .01529 L
.46068 .01529 L
.46184 .01529 L
.46307 .01529 L
.46415 .01529 L
.46531 .01529 L
.46602 .01529 L
.46668 .01529 L
.46797 .01529 L
Mistroke
.46915 .01529 L
.4704 .01529 L
.4711 .01529 L
.47174 .01529 L
.47319 .01529 L
.47446 .01529 L
.47581 .01529 L
.47814 .01529 L
.4807 .01529 L
.48531 .01529 L
.49025 .01529 L
.49915 .01529 L
.519 .0153 L
.52946 .0153 L
.53519 .0153 L
.54056 .0153 L
.54531 .0153 L
.54798 .0153 L
.55043 .0153 L
.55165 .0153 L
.55296 .0153 L
.55371 .0153 L
.55439 .0153 L
.55504 .0153 L
.55573 .0153 L
.55644 .0153 L
.5571 .0153 L
.55781 .0153 L
.55859 .0153 L
.55927 .0153 L
.55999 .0153 L
.5613 .0153 L
.56258 .0153 L
.56376 .0153 L
.56644 .0153 L
.56881 .0153 L
.57132 .0153 L
.58046 .0153 L
.58981 .0153 L
.59991 .0153 L
.61818 .01529 L
.65929 .01529 L
.67979 .01528 L
.69888 .01528 L
.71846 .01528 L
.73695 .01528 L
.74675 .01528 L
.75739 .01528 L
.77597 .01528 L
.78542 .01528 L
Mistroke
.79582 .01528 L
.80668 .01528 L
.81685 .01528 L
.82724 .01528 L
.83712 .01528 L
.85565 .01528 L
.86524 .01528 L
.87547 .01528 L
.89386 .01528 L
.91529 .01527 L
.93546 .01527 L
.97403 .01527 L
.97619 .01527 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .0214 L
.04262 .02111 L
.06244 .01979 L
.08259 .01863 L
.10458 .01767 L
.12517 .017 L
.14429 .01654 L
.16481 .01616 L
.18342 .01591 L
.20266 .01571 L
.22348 .01555 L
.24342 .01544 L
.26449 .01535 L
.28413 .01529 L
.30246 .01525 L
.32281 .01522 L
.34137 .0152 L
.36045 .01518 L
.38121 .01516 L
.40099 .01515 L
.41097 .01515 L
.422 .01515 L
.43142 .01515 L
.44134 .01514 L
.45222 .01514 L
.45745 .01514 L
.4622 .01514 L
.46678 .01514 L
.47174 .01514 L
.47447 .01514 L
.47699 .01514 L
.47955 .01514 L
.48194 .01514 L
.48399 .01514 L
.48619 .01514 L
.48744 .01514 L
.48863 .01514 L
.4897 .01514 L
Mistroke
.49086 .01514 L
.49211 .01514 L
.49324 .01514 L
.49454 .01514 L
.49576 .01514 L
.4969 .01514 L
.49795 .01514 L
.50031 .01514 L
.50277 .01514 L
.50502 .01514 L
.51007 .01514 L
.51917 .01514 L
.52438 .01514 L
.52992 .01514 L
.53464 .01514 L
.53733 .01514 L
.53853 .01514 L
.53985 .01514 L
.54106 .01514 L
.54219 .01514 L
.54338 .01514 L
.54465 .01514 L
.54584 .01514 L
.54696 .01514 L
.54797 .01514 L
.54906 .01514 L
.55025 .01514 L
.55156 .01514 L
.55422 .01514 L
.55667 .01514 L
.55897 .01514 L
.56421 .01514 L
.56899 .01514 L
.57974 .01514 L
.61956 .01514 L
.65785 .01513 L
.67722 .01513 L
.6986 .01513 L
.71883 .01513 L
.73784 .01513 L
.74765 .01513 L
.758 .01513 L
.76683 .01513 L
.77649 .01513 L
.78177 .01513 L
.78675 .01513 L
.79123 .01513 L
.79608 .01513 L
.7986 .01513 L
.80137 .01513 L
Mistroke
.80276 .01513 L
.80426 .01513 L
.80568 .01513 L
.80697 .01513 L
.80825 .01513 L
.80944 .01513 L
.81074 .01513 L
.81147 .01513 L
.81213 .01513 L
.81334 .01513 L
.81465 .01513 L
.81588 .01513 L
.81702 .01513 L
.81948 .01513 L
.82173 .01513 L
.82677 .01513 L
.83586 .01513 L
.85653 .01513 L
.87724 .01513 L
.88635 .01513 L
.89118 .01513 L
.8964 .01513 L
.89883 .01513 L
.9014 .01513 L
.90378 .01513 L
.90599 .01513 L
.90807 .01513 L
.90923 .01513 L
.91029 .01513 L
.91145 .01513 L
.91271 .01513 L
.9139 .01513 L
.91499 .01513 L
.91613 .01513 L
.91736 .01513 L
.91851 .01513 L
.91957 .01513 L
.92214 .01513 L
.92459 .01513 L
.92945 .01513 L
.93474 .01513 L
.9451 .01513 L
.95447 .01513 L
.97546 .01513 L
.97619 .01513 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03563 L
.03053 .04286 L
.03279 .04878 L
.03416 .05145 L
.03543 .05336 L
.03665 .05476 L
.03793 .05585 L
.03908 .05655 L
.04016 .057 L
.04135 .05732 L
.04262 .05749 L
.04393 .05751 L
.04516 .05742 L
.04586 .05733 L
.0465 .05722 L
.04793 .05692 L
.05052 .05619 L
.05297 .05536 L
.06244 .05154 L
.08439 .04264 L
.10458 .03602 L
.12333 .03125 L
.14313 .02741 L
.16277 .02454 L
.1811 .02252 L
.20145 .02084 L
.22001 .01969 L
.2391 .0188 L
.25986 .01808 L
.27963 .01758 L
.30064 .01719 L
.32011 .01693 L
.33839 .01674 L
.35857 .01659 L
.37708 .01649 L
.396 .01641 L
.40685 .01637 L
.4167 .01635 L
.43631 .01631 L
.44709 .01629 L
.45726 .01628 L
.46698 .01627 L
.47188 .01627 L
.47727 .01627 L
.48187 .01627 L
.4844 .01627 L
.48681 .01627 L
.48904 .01627 L
Mistroke
.49022 .01626 L
.49147 .01626 L
.49263 .01626 L
.49368 .01626 L
.49473 .01626 L
.49573 .01626 L
.49689 .01626 L
.49814 .01626 L
.49932 .01626 L
.5004 .01626 L
.50166 .01626 L
.50303 .01626 L
.50552 .01626 L
.50812 .01627 L
.51089 .01627 L
.51585 .01627 L
.52055 .01627 L
.52549 .01627 L
.52771 .01627 L
.53007 .01627 L
.53227 .01627 L
.53433 .01627 L
.53546 .01627 L
.53668 .01627 L
.5378 .01627 L
.53882 .01627 L
.53996 .01627 L
.54121 .01627 L
.54251 .01627 L
.54373 .01627 L
.54504 .01627 L
.54628 .01627 L
.54861 .01627 L
.55111 .01627 L
.55384 .01627 L
.55844 .01627 L
.56334 .01626 L
.57213 .01626 L
.59158 .01625 L
.60985 .01624 L
.64851 .01621 L
.66813 .0162 L
.68961 .01619 L
.71012 .01618 L
.72921 .01618 L
.73971 .01618 L
.74964 .01618 L
.76822 .01617 L
.77792 .01617 L
.78821 .01617 L
Mistroke
.80665 .01617 L
.84451 .01617 L
.88482 .01617 L
.92361 .01616 L
.96485 .01616 L
.97619 .01616 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.03279 .05689 L
.04262 .09804 L
.05288 .13284 L
.05747 .14505 L
.06244 .15575 L
.06529 .16066 L
.06792 .16443 L
.07039 .16731 L
.0731 .16978 L
.07428 .17063 L
.07553 .17141 L
.07662 .17197 L
.07781 .17246 L
.0785 .17269 L
.07915 .17288 L
.08042 .17314 L
.08157 .17328 L
.0828 .17332 L
.08352 .1733 L
.08427 .17323 L
.08492 .17315 L
.08563 .17303 L
.08721 .17265 L
.08868 .17218 L
.09136 .17102 L
.09422 .16943 L
.10458 .16139 L
.14594 .1193 L
.16664 .101 L
.18579 .08708 L
.20556 .07556 L
.22412 .06699 L
.24278 .0602 L
.26338 .05442 L
.28356 .05012 L
.30207 .04713 L
.32099 .04479 L
.34169 .0429 L
.3613 .04161 L
.37228 .04107 L
.38225 .04067 L
.39224 .04035 L
.40144 .04013 L
.40625 .04004 L
.41154 .03996 L
.41421 .03992 L
.41707 .03989 L
.41978 .03987 L
.42224 .03985 L
Mistroke
.42346 .03985 L
.42478 .03984 L
.42551 .03984 L
.42618 .03984 L
.42749 .03984 L
.42862 .03983 L
.42987 .03983 L
.43116 .03983 L
.43237 .03984 L
.43306 .03984 L
.4338 .03984 L
.43516 .03985 L
.4377 .03986 L
.43914 .03987 L
.44067 .03988 L
.44341 .03991 L
.44835 .03998 L
.45297 .04006 L
.45805 .04017 L
.46351 .04033 L
.47311 .04069 L
.48359 .04124 L
.49454 .042 L
.50471 .04289 L
.52348 .04477 L
.53336 .04568 L
.5438 .04642 L
.54911 .04668 L
.55212 .0468 L
.55494 .04689 L
.55752 .04695 L
.55988 .04698 L
.56119 .047 L
.56188 .04701 L
.56261 .04701 L
.56324 .04701 L
.56395 .04702 L
.56519 .04702 L
.56646 .04702 L
.5671 .04702 L
.5678 .04701 L
.56904 .047 L
.57019 .04699 L
.5728 .04696 L
.57558 .0469 L
.5807 .04677 L
.58535 .04661 L
.60451 .04569 L
.6253 .04445 L
.66619 .04208 L
Mistroke
.68652 .04112 L
.70556 .04038 L
.7238 .03982 L
.74341 .03936 L
.75353 .03917 L
.76456 .03901 L
.77511 .03888 L
.78466 .0388 L
.7948 .03873 L
.80435 .03868 L
.8096 .03866 L
.81443 .03864 L
.81973 .03863 L
.82532 .03862 L
.82787 .03861 L
.83029 .03861 L
.83248 .03861 L
.83481 .03861 L
.83601 .0386 L
.83734 .0386 L
.83856 .0386 L
.83968 .0386 L
.841 .0386 L
.84169 .0386 L
.84241 .0386 L
.84364 .0386 L
.84433 .0386 L
.84498 .0386 L
.84613 .0386 L
.84737 .0386 L
.84854 .0386 L
.84963 .0386 L
.85385 .03861 L
.85604 .03861 L
.85845 .03861 L
.86332 .03862 L
.87349 .03863 L
.88278 .03865 L
.90368 .0387 L
.9129 .03872 L
.92271 .03874 L
.92837 .03875 L
.93348 .03876 L
.93595 .03876 L
.93862 .03876 L
.94114 .03876 L
.94233 .03876 L
.94346 .03876 L
.94444 .03876 L
.9455 .03876 L
Mistroke
.94647 .03876 L
.94736 .03876 L
.94833 .03876 L
.94939 .03876 L
.9505 .03876 L
.95154 .03876 L
.95251 .03876 L
.95344 .03876 L
.95517 .03876 L
.95704 .03876 L
.95908 .03876 L
.96337 .03876 L
.96795 .03875 L
.97619 .03874 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.03279 .05649 L
.03793 .07727 L
.04262 .09301 L
.04758 .1057 L
.0503 .11084 L
.05288 .11453 L
.05404 .11583 L
.05527 .11699 L
.05633 .11782 L
.05747 .11853 L
.05869 .11912 L
.05984 .1195 L
.06053 .11966 L
.0612 .11976 L
.06244 .11983 L
.0631 .11981 L
.06381 .11975 L
.0651 .11952 L
.06635 .11918 L
.0675 .11877 L
.07012 .11756 L
.07289 .1159 L
.08259 .10831 L
.10458 .08849 L
.12444 .07264 L
.14255 .06092 L
.16206 .05096 L
.18298 .04284 L
.20206 .03724 L
.22282 .03265 L
.2426 .02939 L
.2636 .02683 L
.28307 .02506 L
.30135 .02381 L
.32154 .02278 L
.34004 .02208 L
.35897 .02154 L
.37967 .02111 L
.39928 .02082 L
.41025 .0207 L
.42023 .02061 L
.42955 .02054 L
.43941 .02049 L
.44456 .02046 L
.45023 .02044 L
.45539 .02043 L
.46021 .02042 L
.46279 .02041 L
.46519 .02041 L
Mistroke
.46654 .02041 L
.46782 .02041 L
.46852 .02041 L
.46929 .02041 L
.46997 .02041 L
.47062 .02041 L
.47181 .02041 L
.47312 .02041 L
.4744 .02041 L
.47511 .02041 L
.47576 .02041 L
.47693 .02041 L
.4782 .02041 L
.4805 .02041 L
.48272 .02041 L
.48517 .02042 L
.49013 .02043 L
.49903 .02045 L
.52005 .02053 L
.52924 .02057 L
.5341 .02058 L
.53677 .02059 L
.53929 .0206 L
.54175 .0206 L
.54442 .02061 L
.5456 .02061 L
.54684 .02061 L
.54801 .02061 L
.54908 .02061 L
.55016 .02061 L
.55132 .02061 L
.55239 .02061 L
.55341 .02061 L
.55459 .02061 L
.55569 .02061 L
.55689 .02061 L
.55817 .02061 L
.56051 .02061 L
.56304 .0206 L
.56761 .02059 L
.57304 .02058 L
.57803 .02056 L
.59693 .02049 L
.61762 .02038 L
.65815 .02019 L
.67686 .02012 L
.69716 .02006 L
.71848 .02001 L
.73863 .01997 L
.75848 .01995 L
Mistroke
.76849 .01994 L
.77951 .01993 L
.79894 .01992 L
.81982 .01991 L
.86106 .0199 L
.90079 .01988 L
.93901 .01986 L
.97619 .01984 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.03279 .05675 L
.04262 .09634 L
.04758 .11245 L
.05288 .12614 L
.05546 .13137 L
.05789 .13546 L
.06024 .13864 L
.06244 .14095 L
.06487 .14278 L
.06616 .14348 L
.06754 .14402 L
.06824 .14421 L
.06899 .14437 L
.0697 .14447 L
.07037 .14451 L
.07162 .1445 L
.07232 .14443 L
.07295 .14433 L
.0742 .14405 L
.07535 .14369 L
.07794 .14257 L
.08023 .14126 L
.08265 .1396 L
.10458 .11839 L
.14255 .08224 L
.16206 .06834 L
.18298 .05678 L
.20422 .04791 L
.22434 .0416 L
.24425 .03688 L
.26267 .03357 L
.28133 .03101 L
.30193 .02888 L
.32128 .0274 L
.34214 .02622 L
.36218 .0254 L
.37238 .02507 L
.38328 .02478 L
.39362 .02455 L
.40302 .02438 L
.41194 .02424 L
.42138 .02413 L
.43137 .02403 L
.44057 .02397 L
.44569 .02394 L
.45047 .02392 L
.45322 .02392 L
.45572 .02391 L
.45711 .02391 L
Mistroke
.45784 .02391 L
.45862 .02391 L
.45937 .02391 L
.46004 .02391 L
.46137 .02391 L
.46257 .02391 L
.4637 .02391 L
.46493 .02391 L
.46626 .02391 L
.46764 .02391 L
.46896 .02391 L
.47142 .02392 L
.47372 .02392 L
.47584 .02393 L
.48065 .02395 L
.48546 .02398 L
.49076 .02402 L
.50148 .02412 L
.5225 .02435 L
.53169 .02445 L
.53655 .02449 L
.54174 .02452 L
.54438 .02454 L
.54687 .02455 L
.54911 .02456 L
.55026 .02456 L
.55153 .02456 L
.55264 .02456 L
.55383 .02457 L
.55509 .02457 L
.55626 .02457 L
.55743 .02457 L
.55854 .02457 L
.55954 .02457 L
.56062 .02457 L
.56185 .02456 L
.563 .02456 L
.56562 .02456 L
.56818 .02455 L
.57093 .02454 L
.58048 .02448 L
.59004 .0244 L
.6005 .0243 L
.62159 .02407 L
.66212 .02366 L
.68083 .02351 L
.70113 .02338 L
.72245 .02327 L
.73204 .02323 L
.74259 .0232 L
Mistroke
.76245 .02314 L
.77331 .02312 L
.78348 .02311 L
.79387 .0231 L
.80374 .02309 L
.82227 .02307 L
.86049 .02305 L
.90115 .02302 L
.9403 .02299 L
.97619 .02296 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.03279 .05675 L
.04262 .09636 L
.04758 .11252 L
.05288 .1263 L
.05546 .1316 L
.05789 .13576 L
.06024 .13901 L
.06244 .14141 L
.06487 .14334 L
.06616 .14408 L
.06754 .14468 L
.06824 .14491 L
.06899 .14509 L
.0697 .14522 L
.07037 .1453 L
.07162 .14533 L
.07232 .14529 L
.07295 .14522 L
.0742 .14499 L
.07535 .14467 L
.07661 .14422 L
.07794 .14364 L
.08265 .14082 L
.08806 .13649 L
.0931 .13177 L
.10458 .11994 L
.14349 .08291 L
.16473 .06795 L
.18485 .057 L
.20476 .0487 L
.22318 .0428 L
.24184 .03818 L
.26245 .03433 L
.28179 .03162 L
.30265 .02945 L
.32269 .0279 L
.34379 .02671 L
.36353 .0259 L
.3819 .02536 L
.39242 .02511 L
.40235 .02492 L
.41121 .02479 L
.42094 .02466 L
.43066 .02457 L
.43598 .02453 L
.44096 .0245 L
.4456 .02448 L
.44985 .02446 L
.4522 .02446 L
Mistroke
.45344 .02446 L
.45475 .02445 L
.45602 .02445 L
.45717 .02445 L
.45832 .02445 L
.45941 .02445 L
.46058 .02445 L
.46183 .02445 L
.463 .02445 L
.46408 .02445 L
.46534 .02445 L
.46671 .02446 L
.4692 .02446 L
.4718 .02447 L
.47457 .02448 L
.47953 .02451 L
.48832 .02457 L
.49801 .02466 L
.51902 .02493 L
.52822 .02504 L
.53308 .0251 L
.53827 .02514 L
.5434 .02518 L
.54806 .0252 L
.5503 .02521 L
.55149 .02522 L
.55274 .02522 L
.55383 .02522 L
.55503 .02522 L
.55613 .02522 L
.55715 .02522 L
.55838 .02522 L
.55908 .02522 L
.55972 .02522 L
.5609 .02522 L
.56216 .02522 L
.56328 .02522 L
.56433 .02522 L
.56673 .02521 L
.56931 .0252 L
.57167 .02519 L
.57701 .02515 L
.58679 .02508 L
.59591 .02499 L
.6166 .02475 L
.65561 .0243 L
.6755 .02411 L
.69708 .02394 L
.71785 .02382 L
.73703 .02373 L
Mistroke
.75577 .02367 L
.76642 .02365 L
.7764 .02363 L
.78679 .02361 L
.79666 .0236 L
.81519 .02358 L
.8534 .02356 L
.89407 .02353 L
.93322 .0235 L
.97482 .02347 L
.97619 .02346 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.03279 .05648 L
.03793 .07721 L
.04262 .09285 L
.04758 .10536 L
.0503 .11038 L
.05288 .11397 L
.05404 .11523 L
.05527 .11635 L
.05633 .11715 L
.05747 .11783 L
.05869 .11839 L
.05984 .11875 L
.06053 .1189 L
.0612 .119 L
.06244 .11906 L
.0631 .11904 L
.06381 .11897 L
.0651 .11875 L
.06635 .11842 L
.0675 .11803 L
.07012 .11685 L
.07289 .11527 L
.08259 .10799 L
.10458 .08895 L
.14255 .06231 L
.16206 .05262 L
.18298 .0447 L
.20422 .03868 L
.22434 .03443 L
.24425 .03128 L
.26267 .02908 L
.28133 .02738 L
.30193 .02598 L
.32128 .02501 L
.34214 .02424 L
.36218 .0237 L
.37238 .02349 L
.38328 .02331 L
.39362 .02317 L
.40302 .02306 L
.41194 .02298 L
.42138 .02291 L
.42614 .02288 L
.43137 .02286 L
.43612 .02284 L
.44057 .02283 L
.44326 .02282 L
.44458 .02282 L
.44581 .02282 L
Mistroke
.44701 .02282 L
.4481 .02282 L
.44931 .02282 L
.4506 .02281 L
.45127 .02281 L
.45199 .02281 L
.45326 .02281 L
.45397 .02281 L
.45464 .02282 L
.45537 .02282 L
.45615 .02282 L
.45755 .02282 L
.45888 .02282 L
.46137 .02282 L
.46374 .02283 L
.46597 .02283 L
.47105 .02285 L
.47599 .02287 L
.48132 .0229 L
.49094 .02298 L
.49975 .02306 L
.52031 .02328 L
.53033 .02338 L
.53942 .02345 L
.54399 .02347 L
.54656 .02348 L
.54893 .02349 L
.551 .0235 L
.55218 .0235 L
.55328 .0235 L
.55444 .0235 L
.5555 .0235 L
.55673 .0235 L
.55789 .0235 L
.55901 .0235 L
.56026 .0235 L
.56156 .0235 L
.56278 .0235 L
.56496 .02349 L
.56732 .02349 L
.57267 .02347 L
.57759 .02344 L
.59649 .02331 L
.61718 .02314 L
.65771 .02279 L
.69672 .02254 L
.71804 .02244 L
.73818 .02237 L
.74789 .02234 L
.75817 .02232 L
Mistroke
.77662 .02229 L
.78604 .02228 L
.79617 .02227 L
.81447 .02225 L
.85572 .02223 L
.89545 .0222 L
.93366 .02217 L
.97432 .02214 L
.97619 .02214 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.02605 .02543 L
.02846 .03568 L
.03053 .04303 L
.03279 .04922 L
.03416 .05213 L
.03543 .05428 L
.03662 .05589 L
.03793 .05727 L
.03911 .05822 L
.04021 .05889 L
.04137 .05942 L
.04262 .0598 L
.04393 .06003 L
.04516 .06012 L
.04586 .06013 L
.0465 .0601 L
.04723 .06005 L
.04793 .05997 L
.04919 .05978 L
.05035 .05955 L
.05297 .05889 L
.06244 .05554 L
.08253 .0475 L
.10458 .0399 L
.125 .03442 L
.14407 .03047 L
.16442 .02726 L
.18298 .02504 L
.20206 .0233 L
.22282 .02188 L
.2426 .02088 L
.2636 .02009 L
.28307 .01955 L
.30135 .01917 L
.32154 .01886 L
.34004 .01865 L
.35897 .01849 L
.36981 .01841 L
.37967 .01836 L
.39928 .01828 L
.41005 .01824 L
.42023 .01822 L
.42995 .0182 L
.43485 .0182 L
.43767 .01819 L
.44024 .01819 L
.44244 .01819 L
.44484 .01819 L
.44615 .01819 L
Mistroke
.44737 .01819 L
.44861 .01819 L
.44977 .01819 L
.45086 .01819 L
.45204 .01819 L
.45311 .01819 L
.45409 .01819 L
.45516 .01819 L
.45633 .01819 L
.45755 .01819 L
.45869 .01819 L
.45996 .01819 L
.4613 .01819 L
.46372 .01819 L
.46631 .01819 L
.46917 .01819 L
.47429 .0182 L
.47908 .01821 L
.48803 .01822 L
.49765 .01825 L
.51734 .01831 L
.52774 .01834 L
.53346 .01835 L
.53885 .01836 L
.54402 .01837 L
.54694 .01837 L
.54963 .01838 L
.55189 .01838 L
.55318 .01838 L
.55438 .01838 L
.55565 .01838 L
.55681 .01838 L
.55745 .01838 L
.55815 .01838 L
.55941 .01838 L
.56059 .01838 L
.5617 .01838 L
.56291 .01838 L
.56422 .01838 L
.56689 .01838 L
.56933 .01837 L
.57381 .01837 L
.57852 .01836 L
.58805 .01835 L
.59824 .01833 L
.6166 .01828 L
.65806 .01818 L
.67884 .01814 L
.69801 .01811 L
.71786 .01808 L
Mistroke
.73645 .01806 L
.75519 .01805 L
.76513 .01804 L
.77582 .01804 L
.78593 .01803 L
.79697 .01803 L
.81706 .01803 L
.85773 .01802 L
.89688 .01801 L
.93848 .018 L
.97619 .01799 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03564 L
.03053 .0429 L
.03279 .04889 L
.03416 .05162 L
.03543 .0536 L
.03665 .05505 L
.03793 .05621 L
.03908 .05696 L
.04016 .05747 L
.04135 .05784 L
.04262 .05806 L
.04393 .05814 L
.04516 .05809 L
.04586 .05802 L
.0465 .05794 L
.04793 .05768 L
.05052 .05701 L
.05297 .05623 L
.06244 .05253 L
.08439 .04368 L
.10458 .03701 L
.12333 .03218 L
.14313 .02826 L
.16277 .02534 L
.1811 .02326 L
.20145 .02153 L
.22001 .02035 L
.2391 .01943 L
.25986 .01869 L
.27963 .01817 L
.30064 .01776 L
.32011 .01748 L
.33839 .01729 L
.35857 .01713 L
.37708 .01702 L
.396 .01694 L
.40672 .01691 L
.4167 .01688 L
.42722 .01686 L
.43716 .01684 L
.44608 .01683 L
.45107 .01683 L
.45575 .01682 L
.46031 .01682 L
.46521 .01682 L
.468 .01682 L
.46938 .01681 L
.47065 .01681 L
Mistroke
.4719 .01681 L
.47303 .01681 L
.47428 .01681 L
.47497 .01681 L
.47562 .01681 L
.47685 .01681 L
.47754 .01681 L
.47819 .01681 L
.47949 .01681 L
.48023 .01681 L
.48089 .01681 L
.48209 .01681 L
.48338 .01681 L
.48574 .01681 L
.48849 .01682 L
.49142 .01682 L
.49666 .01682 L
.50606 .01683 L
.51617 .01684 L
.52566 .01684 L
.53447 .01685 L
.53911 .01685 L
.54406 .01686 L
.54689 .01686 L
.54828 .01686 L
.54956 .01686 L
.5507 .01686 L
.55195 .01686 L
.55321 .01686 L
.5539 .01686 L
.55455 .01686 L
.55586 .01686 L
.5566 .01686 L
.55728 .01686 L
.55854 .01686 L
.55917 .01686 L
.55987 .01686 L
.56108 .01686 L
.56238 .01686 L
.56473 .01686 L
.56751 .01686 L
.57043 .01685 L
.57566 .01685 L
.58519 .01685 L
.59538 .01684 L
.61374 .01682 L
.6552 .01677 L
.67598 .01675 L
.69515 .01674 L
.715 .01673 L
Mistroke
.73358 .01672 L
.75232 .01671 L
.76227 .01671 L
.77296 .01671 L
.78307 .0167 L
.78841 .0167 L
.79411 .0167 L
.79957 .0167 L
.80453 .0167 L
.80692 .0167 L
.80951 .0167 L
.81196 .0167 L
.8142 .0167 L
.81658 .0167 L
.81788 .0167 L
.81912 .0167 L
.82027 .0167 L
.82132 .0167 L
.82248 .0167 L
.82371 .0167 L
.82495 .0167 L
.82564 .0167 L
.82628 .0167 L
.82745 .0167 L
.82868 .0167 L
.83129 .0167 L
.83415 .0167 L
.83943 .0167 L
.84507 .0167 L
.85522 .0167 L
.87515 .0167 L
.88061 .0167 L
.88639 .0167 L
.88876 .0167 L
.89132 .0167 L
.89278 .0167 L
.89412 .0167 L
.8955 .0167 L
.89674 .0167 L
.89801 .0167 L
.89921 .0167 L
.90047 .0167 L
.90119 .0167 L
.90184 .0167 L
.90294 .0167 L
.90414 .0167 L
.90539 .0167 L
.90656 .0167 L
.90927 .0167 L
.91173 .0167 L
Mistroke
.91458 .0167 L
.91727 .0167 L
.9266 .0167 L
.93187 .0167 L
.93674 .0167 L
.95546 .0167 L
.97608 .0167 L
.97619 .0167 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02107 L
.02954 .02124 L
.03053 .02132 L
.03163 .02136 L
.03279 .02137 L
.03395 .02135 L
.0352 .02131 L
.03638 .02126 L
.03746 .02121 L
.04262 .02089 L
.06244 .01953 L
.08259 .01837 L
.10458 .01742 L
.12517 .01676 L
.14429 .0163 L
.16481 .01594 L
.18342 .0157 L
.20266 .01551 L
.22348 .01536 L
.24342 .01525 L
.26449 .01517 L
.28413 .01511 L
.30246 .01508 L
.32281 .01504 L
.34137 .01502 L
.36045 .01501 L
.38121 .01499 L
.40099 .01498 L
.422 .01498 L
.43137 .01497 L
.44147 .01497 L
.45975 .01497 L
.46932 .01497 L
.47979 .01497 L
.49072 .01497 L
.50089 .01497 L
.51141 .01497 L
.52134 .01497 L
.53993 .01496 L
.5784 .01496 L
.61932 .01496 L
.63967 .01496 L
.65872 .01496 L
.67816 .01496 L
.69661 .01496 L
.71689 .01496 L
Mistroke
.73543 .01496 L
.74504 .01496 L
.75528 .01496 L
.76487 .01496 L
.77368 .01496 L
.78399 .01496 L
.79513 .01496 L
.81531 .01496 L
.83577 .01496 L
.85485 .01496 L
.89287 .01496 L
.93183 .01496 L
.97325 .01496 L
.97619 .01496 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.03279 .05651 L
.04262 .09357 L
.04758 .10709 L
.0503 .11289 L
.05288 .11732 L
.05528 .12058 L
.05655 .12198 L
.05789 .12324 L
.05902 .12413 L
.06026 .12494 L
.06139 .12552 L
.06244 .12595 L
.06315 .12618 L
.06379 .12634 L
.0645 .12648 L
.06525 .12658 L
.06591 .12664 L
.06662 .12665 L
.06792 .12658 L
.06919 .1264 L
.06982 .12628 L
.07053 .12611 L
.07293 .12532 L
.07574 .12405 L
.07876 .12235 L
.0842 .11865 L
.10458 .1018 L
.12439 .08585 L
.14594 .07133 L
.16488 .06117 L
.18579 .05241 L
.20556 .04607 L
.22657 .04096 L
.24592 .0374 L
.26677 .03452 L
.28681 .03245 L
.30791 .03084 L
.32765 .02974 L
.34602 .02898 L
.35654 .02863 L
.36648 .02836 L
.38506 .02797 L
.39479 .02783 L
.40508 .0277 L
.41387 .02763 L
.41886 .02759 L
.42353 .02757 L
.42611 .02756 L
.42851 .02755 L
Mistroke
.43114 .02755 L
.43261 .02755 L
.43326 .02754 L
.43394 .02754 L
.43521 .02754 L
.43639 .02754 L
.43765 .02754 L
.43836 .02754 L
.43903 .02754 L
.44024 .02754 L
.44134 .02755 L
.44261 .02755 L
.44382 .02755 L
.44606 .02756 L
.44844 .02756 L
.4527 .02758 L
.45729 .02761 L
.46236 .02765 L
.47247 .02777 L
.48174 .02792 L
.49191 .02813 L
.50261 .02841 L
.52262 .02901 L
.53133 .02924 L
.54077 .02944 L
.54604 .02951 L
.54835 .02954 L
.55089 .02956 L
.55328 .02958 L
.55552 .02959 L
.55676 .0296 L
.55788 .0296 L
.55919 .02961 L
.56042 .02961 L
.56162 .02961 L
.5623 .02961 L
.56295 .02961 L
.56424 .02961 L
.56496 .0296 L
.56563 .0296 L
.56798 .02959 L
.57046 .02958 L
.57316 .02956 L
.57567 .02954 L
.58138 .02948 L
.59189 .02934 L
.60182 .02917 L
.6204 .02881 L
.65883 .02808 L
.67829 .02777 L
Mistroke
.69972 .02748 L
.72005 .02727 L
.73909 .02712 L
.74948 .02706 L
.75935 .02701 L
.77788 .02693 L
.78748 .0269 L
.7977 .02688 L
.81609 .02685 L
.8577 .0268 L
.89778 .02675 L
.93635 .0267 L
.97619 .02666 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.02846 .0363 L
.03279 .05251 L
.03527 .05955 L
.03754 .06451 L
.03879 .06669 L
.04015 .06866 L
.04142 .07016 L
.04262 .0713 L
.04386 .07223 L
.045 .07289 L
.04626 .07344 L
.04696 .07366 L
.04762 .07382 L
.04894 .07403 L
.05016 .0741 L
.05086 .07409 L
.0515 .07405 L
.05223 .07398 L
.05293 .07388 L
.05408 .07367 L
.05531 .07339 L
.0575 .07274 L
.06244 .07083 L
.08424 .05999 L
.10458 .05057 L
.12408 .04326 L
.14255 .03781 L
.1629 .03317 L
.18146 .02995 L
.20137 .02732 L
.21979 .02547 L
.23845 .02403 L
.25906 .02285 L
.2784 .02202 L
.29926 .02136 L
.3193 .02089 L
.3404 .02054 L
.36014 .0203 L
.37851 .02014 L
.38903 .02007 L
.39896 .02002 L
.40788 .01998 L
.41755 .01995 L
.42212 .01993 L
.42702 .01992 L
.42983 .01992 L
.4324 .01991 L
.43483 .01991 L
.43743 .01991 L
Mistroke
.43884 .01991 L
.44011 .01991 L
.4414 .01991 L
.44259 .01991 L
.44327 .01991 L
.44399 .01991 L
.44471 .01991 L
.44549 .01991 L
.44618 .01991 L
.44691 .01991 L
.44822 .01991 L
.44954 .01991 L
.45029 .01991 L
.45098 .01991 L
.45222 .01991 L
.45359 .01991 L
.45596 .01991 L
.45847 .01991 L
.4634 .01992 L
.46859 .01993 L
.47786 .01996 L
.48783 .02 L
.49873 .02006 L
.52002 .0202 L
.53008 .02026 L
.53934 .0203 L
.54404 .02032 L
.549 .02033 L
.55158 .02033 L
.55399 .02034 L
.55537 .02034 L
.55663 .02034 L
.55733 .02034 L
.55808 .02034 L
.5588 .02034 L
.55946 .02034 L
.56055 .02034 L
.56172 .02034 L
.56282 .02034 L
.56383 .02034 L
.56496 .02034 L
.56618 .02034 L
.56866 .02034 L
.57111 .02033 L
.57372 .02033 L
.57844 .02032 L
.58866 .02029 L
.59976 .02024 L
.6199 .02015 L
.66079 .01997 L
Mistroke
.68112 .01989 L
.70016 .01983 L
.71957 .01978 L
.73802 .01974 L
.74771 .01972 L
.75828 .01971 L
.77681 .01969 L
.78714 .01968 L
.79649 .01968 L
.81747 .01967 L
.85756 .01966 L
.89613 .01964 L
.93715 .01961 L
.97619 .01959 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.03279 .05688 L
.04262 .09778 L
.04758 .11542 L
.05288 .13151 L
.05785 .14368 L
.06244 .15232 L
.06508 .15616 L
.06788 .15938 L
.07069 .16176 L
.07229 .16276 L
.07379 .16348 L
.07445 .16373 L
.07517 .16396 L
.07648 .16427 L
.07776 .16443 L
.07895 .16447 L
.07968 .16444 L
.08036 .16438 L
.08164 .16418 L
.08236 .16403 L
.08302 .16385 L
.08451 .16337 L
.08691 .16234 L
.08916 .16112 L
.09427 .15761 L
.10458 .14845 L
.14349 .10937 L
.1633 .09281 L
.18485 .07833 L
.20555 .06752 L
.22469 .05975 L
.24336 .05385 L
.26396 .04885 L
.28331 .0453 L
.30416 .04242 L
.3242 .04038 L
.3453 .03881 L
.35485 .03827 L
.36505 .03777 L
.38341 .0371 L
.39366 .03683 L
.39905 .03672 L
.40476 .03662 L
.40975 .03654 L
.41524 .03648 L
.41765 .03646 L
.42024 .03644 L
.42268 .03643 L
.42491 .03642 L
Mistroke
.4262 .03641 L
.42742 .03641 L
.42851 .03641 L
.42969 .03641 L
.43098 .03641 L
.43163 .03641 L
.43234 .03641 L
.43361 .03641 L
.43478 .03641 L
.43597 .03641 L
.43709 .03642 L
.4392 .03643 L
.44147 .03644 L
.44393 .03646 L
.44916 .03652 L
.45471 .0366 L
.45945 .03669 L
.46467 .03681 L
.47479 .03712 L
.48406 .03751 L
.49423 .03806 L
.50493 .03878 L
.52493 .04029 L
.53365 .04086 L
.54309 .04134 L
.54565 .04144 L
.54835 .04152 L
.55086 .04159 L
.5532 .04164 L
.55539 .04168 L
.55774 .04171 L
.55908 .04173 L
.56035 .04173 L
.56149 .04174 L
.56274 .04174 L
.56403 .04174 L
.56524 .04174 L
.56594 .04174 L
.56657 .04173 L
.56801 .04172 L
.56932 .04171 L
.57074 .0417 L
.57362 .04165 L
.57884 .04155 L
.5837 .04142 L
.60413 .04066 L
.62271 .0398 L
.66266 .03802 L
.7011 .03672 L
.72095 .03623 L
Mistroke
.74198 .03585 L
.7514 .03571 L
.76153 .03559 L
.77984 .03543 L
.78995 .03536 L
.80099 .03531 L
.81141 .03527 L
.82108 .03524 L
.84162 .03519 L
.86023 .03516 L
.87949 .03514 L
.89034 .03513 L
.90032 .03512 L
.93983 .0351 L
.97619 .03507 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.02605 .02543 L
.02846 .03567 L
.03053 .04299 L
.03279 .04912 L
.03416 .05197 L
.03543 .05407 L
.03665 .05566 L
.03793 .05696 L
.03908 .05784 L
.04016 .05846 L
.04135 .05896 L
.04262 .0593 L
.04393 .05949 L
.04516 .05955 L
.04586 .05953 L
.0465 .05949 L
.04723 .05942 L
.04793 .05933 L
.04919 .05912 L
.05035 .05887 L
.05297 .05816 L
.06244 .05476 L
.08253 .04678 L
.10458 .03933 L
.125 .03398 L
.14407 .03014 L
.16442 .02703 L
.18298 .02487 L
.20206 .02318 L
.22282 .0218 L
.2426 .02082 L
.2636 .02005 L
.28307 .01953 L
.30135 .01915 L
.32154 .01885 L
.34004 .01864 L
.35897 .01848 L
.36981 .01841 L
.37967 .01835 L
.39928 .01827 L
.41005 .01824 L
.42023 .01822 L
.42995 .0182 L
.43485 .0182 L
.43767 .01819 L
.44024 .01819 L
.44244 .01819 L
.44484 .01819 L
.44615 .01819 L
Mistroke
.44737 .01819 L
.44861 .01819 L
.44977 .01819 L
.45086 .01819 L
.45204 .01819 L
.45311 .01819 L
.45409 .01819 L
.45516 .01819 L
.45633 .01819 L
.45755 .01819 L
.45869 .01819 L
.4613 .01819 L
.46372 .01819 L
.46636 .01819 L
.46917 .01819 L
.47389 .0182 L
.47908 .01821 L
.48867 .01823 L
.49765 .01825 L
.51617 .01831 L
.52665 .01835 L
.53639 .01838 L
.54139 .01839 L
.54611 .0184 L
.54872 .01841 L
.55154 .01841 L
.55409 .01841 L
.55647 .01842 L
.55902 .01842 L
.56037 .01842 L
.56182 .01842 L
.56254 .01842 L
.56333 .01842 L
.56408 .01842 L
.56477 .01842 L
.56608 .01842 L
.56674 .01842 L
.56746 .01842 L
.56877 .01842 L
.56997 .01842 L
.57129 .01842 L
.57268 .01842 L
.57502 .01842 L
.57759 .01841 L
.58286 .01841 L
.58784 .0184 L
.59717 .01838 L
.61811 .01834 L
.65655 .01824 L
.67601 .01819 L
Mistroke
.69743 .01815 L
.718 .01812 L
.73681 .01809 L
.75623 .01807 L
.76706 .01807 L
.77711 .01806 L
.78708 .01805 L
.79611 .01805 L
.80615 .01805 L
.81684 .01805 L
.82688 .01804 L
.8361 .01804 L
.85693 .01804 L
.86679 .01804 L
.87736 .01804 L
.89644 .01803 L
.91631 .01803 L
.93443 .01802 L
.97429 .01801 L
.97619 .01801 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.02846 .0363 L
.03279 .05252 L
.03527 .05957 L
.03754 .06453 L
.03879 .06673 L
.04015 .06871 L
.04142 .07023 L
.04262 .07137 L
.04386 .07232 L
.045 .07299 L
.04626 .07354 L
.04696 .07377 L
.04762 .07394 L
.04894 .07416 L
.05016 .07424 L
.05086 .07423 L
.0515 .0742 L
.05223 .07413 L
.05293 .07404 L
.05408 .07384 L
.05531 .07356 L
.0575 .07292 L
.06244 .07102 L
.10458 .05063 L
.12444 .04309 L
.14255 .03767 L
.16206 .03312 L
.18298 .02942 L
.20206 .02688 L
.22282 .0248 L
.2426 .02332 L
.2636 .02215 L
.28307 .02134 L
.30135 .02077 L
.32154 .0203 L
.34004 .01998 L
.35897 .01973 L
.36981 .01963 L
.37967 .01954 L
.39928 .01942 L
.41005 .01937 L
.42023 .01933 L
.42995 .0193 L
.43485 .01929 L
.44024 .01928 L
.44484 .01928 L
.44742 .01928 L
.44864 .01928 L
.44977 .01928 L
Mistroke
.45092 .01927 L
.45196 .01927 L
.45312 .01927 L
.45435 .01927 L
.45542 .01927 L
.45659 .01927 L
.45768 .01927 L
.45869 .01927 L
.45996 .01928 L
.46116 .01928 L
.46341 .01928 L
.46583 .01928 L
.46845 .01928 L
.47318 .01929 L
.47756 .0193 L
.48759 .01933 L
.49823 .01937 L
.51797 .01946 L
.53604 .01955 L
.54548 .01958 L
.55023 .01959 L
.5529 .0196 L
.55542 .0196 L
.55674 .0196 L
.55816 .01961 L
.55935 .01961 L
.56065 .01961 L
.56207 .01961 L
.56284 .01961 L
.56356 .01961 L
.56485 .01961 L
.56558 .01961 L
.56624 .01961 L
.56752 .01961 L
.56871 .01961 L
.57001 .01961 L
.5714 .01961 L
.57372 .0196 L
.57629 .0196 L
.5812 .01959 L
.58637 .01958 L
.59561 .01956 L
.61646 .01949 L
.65454 .01934 L
.67576 .01927 L
.69507 .01921 L
.71536 .01916 L
.73408 .01912 L
.75324 .0191 L
.76398 .01908 L
Mistroke
.77403 .01907 L
.78382 .01907 L
.79277 .01906 L
.80271 .01906 L
.80789 .01905 L
.8134 .01905 L
.81857 .01905 L
.82325 .01905 L
.82802 .01905 L
.8324 .01905 L
.83753 .01905 L
.84308 .01905 L
.84797 .01905 L
.85313 .01905 L
.86262 .01905 L
.86784 .01905 L
.87278 .01905 L
.87738 .01905 L
.88238 .01905 L
.89112 .01904 L
.90053 .01904 L
.91091 .01904 L
.92175 .01904 L
.93192 .01903 L
.97063 .01902 L
.97619 .01901 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01857 L
.10458 .0176 L
.12517 .01693 L
.14429 .01646 L
.16481 .01608 L
.18342 .01583 L
.20266 .01563 L
.22348 .01547 L
.24342 .01536 L
.26449 .01528 L
.28413 .01522 L
.30246 .01518 L
.32281 .01514 L
.34137 .01512 L
.36045 .0151 L
.38121 .01509 L
.40099 .01508 L
.4111 .01507 L
.422 .01507 L
.43215 .01507 L
.44147 .01507 L
.4503 .01506 L
.45975 .01506 L
.46955 .01506 L
.47867 .01506 L
.48425 .01506 L
.48952 .01506 L
.49424 .01506 L
.49937 .01506 L
.50173 .01506 L
.50426 .01506 L
.50884 .01506 L
.51163 .01506 L
.51428 .01506 L
.51925 .01506 L
Mistroke
.52412 .01506 L
.52931 .01506 L
.5323 .01506 L
.53501 .01506 L
.54029 .01506 L
.54518 .01506 L
.55034 .01506 L
.55957 .01506 L
.56951 .01506 L
.58041 .01506 L
.62088 .01506 L
.65984 .01505 L
.68113 .01505 L
.70126 .01505 L
.72121 .01505 L
.73964 .01505 L
.74929 .01505 L
.75834 .01505 L
.76827 .01505 L
.77385 .01505 L
.77896 .01505 L
.78371 .01505 L
.78633 .01505 L
.78879 .01505 L
.79109 .01505 L
.7923 .01505 L
.79358 .01505 L
.79465 .01505 L
.79584 .01505 L
.79691 .01505 L
.79792 .01505 L
.7992 .01505 L
.79993 .01505 L
.8006 .01505 L
.80184 .01505 L
.80315 .01505 L
.80431 .01505 L
.80541 .01505 L
.80791 .01505 L
.8106 .01505 L
.81307 .01505 L
.81863 .01505 L
.82842 .01505 L
.83754 .01505 L
.85823 .01505 L
.87694 .01505 L
.89724 .01505 L
.90262 .01505 L
.90833 .01505 L
.91361 .01505 L
Mistroke
.9162 .01505 L
.91856 .01505 L
.92077 .01505 L
.92318 .01505 L
.9245 .01505 L
.92573 .01505 L
.92689 .01505 L
.92815 .01505 L
.92887 .01505 L
.92953 .01505 L
.93083 .01505 L
.93201 .01505 L
.93326 .01505 L
.93391 .01505 L
.9346 .01505 L
.93586 .01505 L
.93735 .01505 L
.93871 .01505 L
.94086 .01505 L
.94323 .01505 L
.94804 .01505 L
.95249 .01505 L
.95666 .01505 L
.96606 .01505 L
.97619 .01505 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.03279 .05637 L
.03793 .07677 L
.04262 .09185 L
.04758 .10356 L
.0503 .10812 L
.05156 .10978 L
.05288 .11126 L
.05402 .11232 L
.05527 .11326 L
.0564 .11394 L
.05747 .11443 L
.05872 .11482 L
.05987 .11504 L
.06119 .11512 L
.06244 .11506 L
.0631 .11497 L
.06381 .11484 L
.0651 .11451 L
.06635 .11408 L
.0675 .11361 L
.07289 .11057 L
.08259 .10309 L
.10458 .08427 L
.125 .06902 L
.14407 .0576 L
.16239 .04896 L
.18204 .04178 L
.20328 .03595 L
.2234 .03183 L
.24331 .02879 L
.26173 .02666 L
.28039 .02501 L
.301 .02366 L
.32034 .02272 L
.3412 .02197 L
.36124 .02145 L
.37144 .02124 L
.38234 .02106 L
.39268 .02091 L
.40208 .0208 L
.42045 .02063 L
.43043 .02056 L
.43963 .02052 L
.44485 .0205 L
.44973 .02048 L
.45483 .02047 L
.45753 .02046 L
.46043 .02046 L
.46298 .02046 L
Mistroke
.4644 .02046 L
.46569 .02046 L
.46689 .02046 L
.4682 .02045 L
.46943 .02045 L
.47056 .02045 L
.4712 .02045 L
.47189 .02046 L
.47312 .02046 L
.47388 .02046 L
.47459 .02046 L
.47593 .02046 L
.47865 .02046 L
.4816 .02047 L
.48667 .02048 L
.49205 .02049 L
.50171 .02053 L
.52144 .02062 L
.53008 .02066 L
.53464 .02068 L
.53951 .02069 L
.54208 .0207 L
.54441 .0207 L
.54678 .02071 L
.54896 .02071 L
.55013 .02071 L
.55141 .02071 L
.55271 .02071 L
.55341 .02071 L
.55407 .02072 L
.55529 .02072 L
.5564 .02072 L
.55768 .02072 L
.55889 .02072 L
.56009 .02071 L
.56141 .02071 L
.56279 .02071 L
.56408 .02071 L
.56889 .0207 L
.57161 .0207 L
.57412 .02069 L
.57976 .02067 L
.59866 .0206 L
.61936 .02049 L
.65988 .02029 L
.6786 .02022 L
.6989 .02015 L
.72022 .0201 L
.74036 .02006 L
.76022 .02003 L
Mistroke
.77023 .02002 L
.78125 .02001 L
.7914 .02001 L
.80067 .02 L
.82156 .02 L
.86129 .01999 L
.8995 .01998 L
.94016 .01997 L
.97619 .01995 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.02846 .03632 L
.03279 .05275 L
.03527 .06008 L
.03754 .0654 L
.04015 .07008 L
.04132 .07172 L
.04262 .07324 L
.04502 .07536 L
.04633 .07618 L
.04756 .07677 L
.04871 .07718 L
.04976 .07745 L
.05097 .07764 L
.05212 .07773 L
.05336 .07773 L
.05468 .07763 L
.05593 .07746 L
.05706 .07725 L
.05983 .07654 L
.06244 .07566 L
.10458 .05562 L
.12296 .04823 L
.14313 .04174 L
.16307 .03677 L
.18413 .03278 L
.20364 .02998 L
.22456 .02772 L
.2458 .02602 L
.26592 .02483 L
.28583 .02394 L
.30425 .02333 L
.32291 .02286 L
.34352 .02248 L
.36286 .02222 L
.37374 .02211 L
.38372 .02203 L
.39287 .02197 L
.40264 .02192 L
.40826 .02189 L
.41337 .02188 L
.4185 .02186 L
.421 .02186 L
.42334 .02185 L
.42576 .02185 L
.42797 .02185 L
.43043 .02184 L
.43178 .02184 L
.43306 .02184 L
.4343 .02184 L
Mistroke
.43562 .02184 L
.43686 .02184 L
.43799 .02184 L
.43868 .02184 L
.43932 .02184 L
.44075 .02184 L
.44202 .02184 L
.44336 .02184 L
.44556 .02185 L
.44791 .02185 L
.45216 .02186 L
.45721 .02187 L
.46181 .02189 L
.47175 .02194 L
.48093 .022 L
.49101 .02209 L
.50171 .02221 L
.52144 .02246 L
.53008 .02256 L
.53951 .02265 L
.54441 .02269 L
.54896 .02272 L
.55143 .02273 L
.55377 .02274 L
.55645 .02274 L
.55889 .02275 L
.5601 .02275 L
.56143 .02275 L
.5621 .02275 L
.56282 .02275 L
.56411 .02275 L
.5654 .02275 L
.56662 .02275 L
.56772 .02275 L
.56892 .02275 L
.57021 .02275 L
.57165 .02274 L
.57455 .02274 L
.57976 .02272 L
.58467 .0227 L
.58984 .02267 L
.59909 .02261 L
.61994 .02246 L
.65801 .02215 L
.67924 .02201 L
.69854 .02189 L
.71883 .0218 L
.73755 .02173 L
.75671 .02167 L
.76745 .02165 L
Mistroke
.7775 .02163 L
.79624 .02161 L
.80618 .0216 L
.81687 .02159 L
.85812 .02156 L
.89785 .02153 L
.93606 .02149 L
.97619 .02145 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.03279 .05686 L
.04262 .09753 L
.04758 .11481 L
.05288 .13025 L
.05789 .14162 L
.06244 .14918 L
.06507 .15236 L
.0665 .15375 L
.06785 .15483 L
.06908 .15566 L
.07022 .15627 L
.07148 .15679 L
.07217 .15702 L
.07283 .15719 L
.07354 .15732 L
.07418 .15741 L
.07493 .15746 L
.07563 .15747 L
.07687 .15739 L
.07757 .15729 L
.07822 .15716 L
.07958 .15681 L
.08108 .15627 L
.0841 .1548 L
.08922 .15131 L
.09469 .14658 L
.10458 .13656 L
.12439 .11526 L
.14594 .09454 L
.16488 .07962 L
.18579 .06656 L
.20556 .05702 L
.22657 .04929 L
.24592 .04388 L
.26677 .03948 L
.28681 .03631 L
.30791 .03384 L
.32765 .03213 L
.34602 .03094 L
.36648 .02997 L
.38506 .02934 L
.39505 .02908 L
.40425 .02888 L
.41435 .02872 L
.41994 .02864 L
.42505 .02859 L
.42956 .02854 L
.43448 .02851 L
.43718 .02849 L
Mistroke
.43968 .02848 L
.44208 .02847 L
.4434 .02847 L
.44462 .02847 L
.44578 .02847 L
.447 .02847 L
.44823 .02846 L
.44892 .02846 L
.44957 .02846 L
.45075 .02846 L
.45182 .02847 L
.45306 .02847 L
.45423 .02847 L
.4564 .02847 L
.4584 .02848 L
.4606 .02849 L
.46293 .0285 L
.46784 .02854 L
.47233 .02858 L
.48244 .02872 L
.49136 .02889 L
.50074 .02911 L
.52074 .0297 L
.52946 .02995 L
.5389 .03018 L
.54416 .03028 L
.54901 .03036 L
.55365 .03041 L
.55598 .03042 L
.55855 .03044 L
.55995 .03044 L
.56064 .03045 L
.56128 .03045 L
.56248 .03045 L
.56378 .03045 L
.56507 .03045 L
.5658 .03045 L
.56649 .03045 L
.56722 .03045 L
.56788 .03045 L
.56938 .03044 L
.57174 .03043 L
.57432 .03041 L
.57951 .03037 L
.58479 .0303 L
.58977 .03023 L
.5991 .03007 L
.62004 .02965 L
.65847 .02884 L
.67793 .02849 L
Mistroke
.69936 .02817 L
.71969 .02794 L
.73873 .02777 L
.74912 .0277 L
.75899 .02765 L
.76871 .0276 L
.77752 .02757 L
.78712 .02755 L
.79238 .02754 L
.79734 .02753 L
.79958 .02753 L
.80195 .02753 L
.80399 .02753 L
.80618 .02753 L
.80741 .02752 L
.80854 .02752 L
.80967 .02752 L
.81074 .02752 L
.81198 .02752 L
.81313 .02752 L
.81439 .02752 L
.81503 .02752 L
.81574 .02752 L
.81695 .02752 L
.81809 .02752 L
.81933 .02752 L
.82066 .02753 L
.82337 .02753 L
.82584 .02753 L
.8306 .02753 L
.8351 .02754 L
.84511 .02755 L
.85596 .02757 L
.87546 .02761 L
.8858 .02764 L
.8969 .02766 L
.90236 .02767 L
.90755 .02767 L
.91259 .02768 L
.91727 .02768 L
.92169 .02769 L
.92415 .02769 L
.92639 .02769 L
.92767 .02769 L
.92885 .02769 L
.93014 .02769 L
.93079 .02769 L
.93151 .02769 L
.93271 .02769 L
.934 .02769 L
Mistroke
.93521 .02769 L
.93632 .02769 L
.93861 .02769 L
.94114 .02769 L
.94378 .02769 L
.94626 .02768 L
.95544 .02767 L
.96066 .02767 L
.96543 .02766 L
.97619 .02764 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03566 L
.03053 .04295 L
.03279 .04902 L
.03416 .05183 L
.03543 .05388 L
.03665 .05542 L
.03793 .05666 L
.03908 .0575 L
.04016 .05808 L
.04135 .05853 L
.04262 .05884 L
.04393 .05899 L
.04516 .05901 L
.04586 .05898 L
.0465 .05893 L
.04723 .05885 L
.04793 .05874 L
.05035 .05824 L
.05297 .0575 L
.06244 .05405 L
.08293 .04598 L
.10458 .03881 L
.12413 .03378 L
.14558 .02959 L
.16509 .02672 L
.18601 .02442 L
.20725 .0227 L
.22737 .0215 L
.24728 .02061 L
.2657 .02 L
.28436 .01952 L
.30496 .01913 L
.32431 .01886 L
.34517 .01865 L
.36521 .0185 L
.37528 .01845 L
.38631 .0184 L
.39639 .01836 L
.40592 .01833 L
.41689 .0183 L
.42164 .0183 L
.42687 .01829 L
.43155 .01828 L
.43659 .01828 L
.43937 .01828 L
.44191 .01827 L
.44313 .01827 L
.44446 .01827 L
Mistroke
.44572 .01827 L
.44688 .01827 L
.44804 .01827 L
.4493 .01827 L
.45048 .01827 L
.45157 .01827 L
.45256 .01827 L
.45364 .01827 L
.45477 .01827 L
.45582 .01827 L
.45822 .01827 L
.46041 .01828 L
.46533 .01828 L
.47016 .01828 L
.47527 .01829 L
.48446 .01831 L
.49434 .01834 L
.50523 .01838 L
.52625 .01845 L
.53544 .01848 L
.5403 .0185 L
.54549 .01851 L
.54813 .01851 L
.55062 .01852 L
.55304 .01852 L
.55528 .01852 L
.5574 .01852 L
.55848 .01852 L
.55964 .01852 L
.56081 .01852 L
.5619 .01852 L
.56319 .01853 L
.56437 .01853 L
.5656 .01853 L
.56691 .01852 L
.56802 .01852 L
.56925 .01852 L
.57199 .01852 L
.57456 .01852 L
.57921 .01852 L
.58423 .01851 L
.59378 .01849 L
.60424 .01847 L
.62533 .01841 L
.66586 .01831 L
.70488 .01823 L
.7262 .0182 L
.74634 .01817 L
.75605 .01817 L
.76633 .01816 L
Mistroke
.78478 .01815 L
.7942 .01814 L
.80433 .01814 L
.82263 .01813 L
.84236 .01813 L
.86388 .01813 L
.88448 .01812 L
.9036 .01812 L
.94275 .0181 L
.97619 .01809 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.03279 .0565 L
.04262 .09342 L
.04758 .10673 L
.05035 .11247 L
.05288 .11665 L
.05524 .11969 L
.05648 .12098 L
.0578 .12214 L
.05895 .12297 L
.06021 .12371 L
.06137 .12424 L
.06244 .1246 L
.0631 .12477 L
.06379 .12491 L
.06504 .12504 L
.06581 .12507 L
.06653 .12505 L
.06718 .12499 L
.06788 .12491 L
.06919 .12466 L
.06985 .12449 L
.07057 .12428 L
.07305 .12335 L
.07806 .12068 L
.08274 .11752 L
.10458 .09964 L
.14349 .07127 L
.16473 .06 L
.18485 .05174 L
.20476 .04545 L
.22318 .04096 L
.24184 .03743 L
.26245 .03447 L
.28179 .03238 L
.30265 .03069 L
.32269 .02949 L
.34379 .02857 L
.36353 .02795 L
.3819 .02754 L
.39242 .02737 L
.40235 .02724 L
.41127 .02715 L
.41627 .02711 L
.42094 .02708 L
.4255 .02706 L
.42785 .02705 L
.43041 .02704 L
.43185 .02704 L
.4332 .02704 L
Mistroke
.43459 .02703 L
.43585 .02703 L
.43709 .02703 L
.43825 .02703 L
.43949 .02703 L
.44018 .02703 L
.44082 .02703 L
.44204 .02703 L
.44335 .02703 L
.44458 .02703 L
.4457 .02704 L
.44845 .02704 L
.45106 .02705 L
.45624 .02708 L
.46186 .02712 L
.46672 .02716 L
.47129 .02721 L
.48167 .02736 L
.4918 .02756 L
.5027 .02784 L
.52238 .02844 L
.53279 .02874 L
.5385 .02888 L
.54389 .02899 L
.54906 .02908 L
.55179 .02912 L
.55467 .02915 L
.5571 .02917 L
.55976 .02919 L
.56093 .0292 L
.56219 .0292 L
.56329 .02921 L
.56445 .02921 L
.56573 .02922 L
.56691 .02922 L
.56818 .02922 L
.5689 .02922 L
.56958 .02922 L
.5708 .02922 L
.57192 .02921 L
.57315 .02921 L
.57445 .02921 L
.5767 .02919 L
.5788 .02918 L
.58356 .02914 L
.5886 .02909 L
.59407 .02903 L
.604 .02888 L
.62258 .02855 L
.66346 .02777 L
Mistroke
.6838 .02744 L
.70283 .02717 L
.72225 .02695 L
.74069 .02678 L
.76095 .02663 L
.77948 .02654 L
.78908 .0265 L
.7993 .02647 L
.80895 .02645 L
.81769 .02644 L
.82773 .02642 L
.83695 .02641 L
.85778 .0264 L
.86765 .02639 L
.87822 .02638 L
.89729 .02636 L
.9075 .02634 L
.91716 .02633 L
.93528 .02629 L
.97363 .0262 L
.97619 .02619 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02137 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02122 L
.04262 .0209 L
.06244 .01954 L
.08259 .01838 L
.10458 .01743 L
.12517 .01678 L
.14429 .01632 L
.16481 .01596 L
.18342 .01572 L
.20266 .01553 L
.22348 .01538 L
.24342 .01527 L
.26449 .01519 L
.28413 .01513 L
.30246 .01509 L
.32281 .01506 L
.34137 .01504 L
.36045 .01502 L
.38121 .01501 L
.40099 .015 L
.4111 .015 L
.422 .015 L
.43215 .01499 L
.44147 .01499 L
.45975 .01499 L
.46955 .01499 L
.47867 .01499 L
.48868 .01499 L
.49937 .01498 L
.50961 .01498 L
.52072 .01498 L
.54087 .01498 L
.56074 .01498 L
.58179 .01498 L
.61967 .01498 L
.64075 .01498 L
.66001 .01498 L
.68016 .01498 L
Mistroke
.69884 .01498 L
.71786 .01498 L
.72855 .01498 L
.7386 .01498 L
.74848 .01498 L
.75916 .01498 L
.76388 .01498 L
.76886 .01498 L
.77345 .01498 L
.77778 .01498 L
.78016 .01498 L
.78275 .01498 L
.78491 .01498 L
.78728 .01498 L
.78852 .01498 L
.78985 .01498 L
.79058 .01498 L
.79125 .01498 L
.79257 .01498 L
.79371 .01498 L
.79495 .01498 L
.79625 .01498 L
.79746 .01498 L
.79861 .01498 L
.79985 .01498 L
.80211 .01498 L
.80431 .01498 L
.80633 .01498 L
.81094 .01498 L
.8158 .01498 L
.82527 .01498 L
.83542 .01498 L
.85374 .01498 L
.87353 .01498 L
.89507 .01498 L
.90509 .01498 L
.91058 .01498 L
.91574 .01498 L
.92049 .01498 L
.92484 .01498 L
.92967 .01498 L
.93221 .01498 L
.93349 .01498 L
.93489 .01498 L
.93622 .01498 L
.93745 .01498 L
.93863 .01498 L
.93988 .01498 L
.94099 .01498 L
.94204 .01498 L
Mistroke
.94318 .01498 L
.94441 .01498 L
.94572 .01498 L
.94714 .01498 L
.94974 .01498 L
.95226 .01498 L
.9546 .01498 L
.96349 .01498 L
.96846 .01498 L
.97296 .01498 L
.97619 .01498 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03563 L
.03053 .04285 L
.03279 .04877 L
.03416 .05143 L
.03543 .05333 L
.03665 .05472 L
.03793 .05579 L
.03908 .05648 L
.04016 .05692 L
.04135 .05723 L
.04262 .05738 L
.04393 .0574 L
.04516 .05729 L
.04586 .0572 L
.0465 .05709 L
.04793 .05677 L
.05052 .05603 L
.05297 .05519 L
.06244 .05133 L
.08439 .04243 L
.10458 .03582 L
.12333 .03108 L
.14313 .02726 L
.16277 .02442 L
.1811 .02242 L
.20145 .02075 L
.22001 .01962 L
.2391 .01874 L
.25986 .01803 L
.27963 .01754 L
.30064 .01715 L
.32011 .01689 L
.33839 .01671 L
.35857 .01656 L
.37708 .01645 L
.396 .01638 L
.40685 .01634 L
.4167 .01632 L
.43631 .01628 L
.44709 .01626 L
.45726 .01625 L
.46698 .01625 L
.47188 .01624 L
.47727 .01624 L
.48187 .01624 L
.48445 .01624 L
.48681 .01624 L
.489 .01624 L
Mistroke
.49015 .01624 L
.49138 .01624 L
.49257 .01624 L
.49364 .01624 L
.49471 .01624 L
.49573 .01624 L
.49689 .01624 L
.49814 .01624 L
.49932 .01624 L
.5004 .01624 L
.50166 .01624 L
.50303 .01624 L
.50552 .01624 L
.51089 .01624 L
.51585 .01624 L
.52475 .01624 L
.52942 .01624 L
.53433 .01624 L
.53674 .01624 L
.5381 .01624 L
.53937 .01624 L
.54054 .01624 L
.5416 .01624 L
.54283 .01624 L
.54398 .01624 L
.54508 .01624 L
.54625 .01624 L
.54724 .01624 L
.54833 .01624 L
.55076 .01624 L
.55303 .01624 L
.5557 .01624 L
.55823 .01624 L
.56298 .01624 L
.57365 .01623 L
.58329 .01623 L
.59353 .01622 L
.61195 .01621 L
.64966 .01619 L
.67061 .01618 L
.68984 .01617 L
.70985 .01616 L
.72849 .01616 L
.74739 .01615 L
.75739 .01615 L
.76808 .01615 L
.77831 .01615 L
.7894 .01615 L
.79988 .01615 L
.80955 .01615 L
Mistroke
.84892 .01614 L
.88677 .01614 L
.92708 .01614 L
.96587 .01614 L
.97619 .01614 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.03279 .05642 L
.04262 .09289 L
.04758 .10608 L
.0503 .11176 L
.05288 .11616 L
.05528 .11945 L
.05789 .12222 L
.06026 .12408 L
.06244 .1253 L
.06371 .12581 L
.06487 .12616 L
.0655 .1263 L
.0662 .12643 L
.06747 .12657 L
.06865 .1266 L
.06991 .12654 L
.0711 .1264 L
.07218 .12621 L
.07356 .12588 L
.07483 .12551 L
.0777 .12442 L
.0829 .12179 L
.10458 .10647 L
.125 .09134 L
.14407 .07898 L
.16357 .06852 L
.18204 .06054 L
.20239 .0536 L
.22095 .04867 L
.24086 .04456 L
.25928 .04163 L
.27794 .03934 L
.29854 .03742 L
.31789 .03608 L
.33875 .03502 L
.35879 .0343 L
.36886 .03403 L
.37989 .0338 L
.39016 .03363 L
.3995 .03352 L
.40467 .03347 L
.40739 .03345 L
.41027 .03344 L
.41279 .03343 L
.41413 .03342 L
.41557 .03342 L
.41688 .03341 L
.41809 .03341 L
.4193 .03341 L
Mistroke
.42045 .03341 L
.4217 .03341 L
.4224 .03341 L
.42305 .03341 L
.42424 .03341 L
.42549 .03341 L
.42662 .03341 L
.42767 .03341 L
.43006 .03342 L
.43265 .03343 L
.435 .03345 L
.44029 .03349 L
.44482 .03353 L
.44975 .03359 L
.45869 .03375 L
.46812 .03397 L
.47851 .03431 L
.48935 .03479 L
.49953 .03536 L
.51804 .03662 L
.52853 .03733 L
.53827 .03787 L
.54327 .03809 L
.54798 .03826 L
.55059 .03833 L
.55342 .03839 L
.55598 .03844 L
.55835 .03847 L
.55957 .03849 L
.56087 .0385 L
.56211 .03851 L
.56324 .03851 L
.56456 .03851 L
.5653 .03852 L
.56599 .03852 L
.56726 .03851 L
.5679 .03851 L
.56861 .03851 L
.57001 .0385 L
.5713 .03849 L
.5742 .03846 L
.57676 .03843 L
.57946 .03838 L
.58899 .03817 L
.59918 .03786 L
.61753 .03719 L
.659 .0356 L
.67978 .03492 L
.69895 .03439 L
.7188 .03395 L
Mistroke
.73738 .03362 L
.75612 .03337 L
.7667 .03326 L
.77675 .03318 L
.78645 .03311 L
.79702 .03305 L
.81555 .03298 L
.83523 .03292 L
.85621 .03286 L
.89781 .03276 L
.9187 .03272 L
.9379 .03268 L
.97619 .03263 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.04262 .09881 L
.0522 .13452 L
.06244 .1662 L
.0679 .18002 L
.07286 .19069 L
.0779 .19965 L
.08255 .20627 L
.08798 .21204 L
.09084 .21428 L
.09388 .21608 L
.09514 .21667 L
.09651 .21719 L
.09768 .21756 L
.09897 .21788 L
.09975 .21802 L
.10047 .21813 L
.10116 .21821 L
.1019 .21826 L
.10262 .21829 L
.10331 .21829 L
.10458 .21824 L
.10574 .21812 L
.10699 .21793 L
.10816 .21769 L
.10923 .21742 L
.11186 .21656 L
.11434 .21552 L
.11928 .21286 L
.12466 .20921 L
.14313 .19291 L
.18391 .1529 L
.20417 .13587 L
.22318 .12242 L
.26093 .10249 L
.28111 .09495 L
.29962 .08956 L
.31854 .08531 L
.32939 .08335 L
.33924 .08185 L
.35885 .07955 L
.36963 .07864 L
.3798 .07798 L
.38952 .07754 L
.39442 .07738 L
.39724 .07731 L
.39982 .07726 L
.40217 .07722 L
.40441 .0772 L
.40564 .07719 L
Mistroke
.40677 .07718 L
.40802 .07718 L
.40872 .07718 L
.40935 .07718 L
.4105 .07718 L
.41156 .07718 L
.41272 .07719 L
.41394 .0772 L
.41601 .07722 L
.41827 .07726 L
.42079 .07731 L
.42353 .07739 L
.4285 .07756 L
.43334 .07779 L
.43782 .07806 L
.44797 .07887 L
.4531 .07941 L
.45874 .08013 L
.46886 .08178 L
.47813 .08383 L
.4883 .08681 L
.499 .09094 L
.51901 .1011 L
.52772 .10576 L
.53716 .11019 L
.54243 .11221 L
.54727 .11375 L
.55191 .11489 L
.55681 .11577 L
.5593 .11609 L
.56067 .11623 L
.56197 .11634 L
.56318 .11642 L
.5645 .11649 L
.56569 .11653 L
.5668 .11655 L
.5681 .11656 L
.56933 .11655 L
.57003 .11654 L
.57067 .11652 L
.57138 .1165 L
.57212 .11647 L
.57352 .1164 L
.57482 .11631 L
.57777 .11606 L
.58281 .11545 L
.58828 .11456 L
.59821 .1125 L
.61679 .10766 L
.65767 .09637 L
Mistroke
.67801 .09158 L
.69704 .08782 L
.71646 .08474 L
.7349 .08246 L
.74459 .0815 L
.75516 .08062 L
.76471 .07998 L
.77369 .07949 L
.78402 .07906 L
.79338 .07879 L
.79863 .07867 L
.80346 .0786 L
.80599 .07857 L
.80876 .07854 L
.81016 .07853 L
.81165 .07852 L
.81307 .07851 L
.81436 .07851 L
.81554 .07851 L
.81664 .0785 L
.81786 .0785 L
.81917 .0785 L
.82047 .07851 L
.82112 .07851 L
.82184 .07851 L
.8231 .07851 L
.82428 .07852 L
.82661 .07853 L
.82872 .07855 L
.83346 .0786 L
.83858 .07867 L
.84414 .07877 L
.85422 .07901 L
.87411 .07964 L
.89516 .08046 L
.91497 .08123 L
.93307 .08183 L
.94238 .08208 L
.95253 .08229 L
.9581 .08238 L
.96325 .08245 L
.96818 .08249 L
.97094 .08251 L
.97343 .08253 L
.97476 .08253 L
.97619 .08254 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.04262 .09834 L
.0522 .13245 L
.06244 .16078 L
.0679 .1722 L
.07286 .18043 L
.07784 .18671 L
.08255 .19095 L
.08522 .19266 L
.08668 .19341 L
.08805 .19399 L
.08931 .19442 L
.09046 .19474 L
.09174 .19501 L
.09244 .19512 L
.09312 .1952 L
.09384 .19526 L
.09449 .19529 L
.09525 .1953 L
.09596 .19529 L
.09723 .19521 L
.09794 .19513 L
.0986 .19504 L
.09998 .19478 L
.10151 .19442 L
.10458 .19342 L
.10982 .19101 L
.11478 .18805 L
.12409 .18123 L
.145 .16295 L
.18333 .13038 L
.20272 .11691 L
.22412 .10468 L
.2446 .09534 L
.26338 .08855 L
.28273 .08303 L
.30359 .07847 L
.32251 .07536 L
.33335 .07395 L
.34321 .07288 L
.35262 .07203 L
.36282 .07127 L
.3736 .07066 L
.37885 .07043 L
.38377 .07025 L
.38872 .0701 L
.39324 .07 L
.39581 .06996 L
.39825 .06993 L
.3995 .06992 L
Mistroke
.40083 .0699 L
.4016 .0699 L
.40229 .0699 L
.40294 .06989 L
.40365 .06989 L
.40497 .06989 L
.40569 .06989 L
.40636 .06989 L
.40757 .06989 L
.40886 .0699 L
.40958 .0699 L
.41037 .06991 L
.41181 .06992 L
.41449 .06995 L
.41706 .06999 L
.41979 .07005 L
.42469 .07019 L
.42959 .07037 L
.43408 .07058 L
.4442 .07122 L
.45312 .07201 L
.46249 .07313 L
.47206 .07467 L
.48227 .07687 L
.49191 .07961 L
.50065 .08274 L
.5215 .09207 L
.53064 .09612 L
.53549 .09802 L
.54069 .09979 L
.54575 .10121 L
.55037 .10223 L
.55259 .10263 L
.55501 .10299 L
.55728 .10327 L
.55941 .10347 L
.56178 .10364 L
.56303 .1037 L
.56368 .10373 L
.56439 .10375 L
.56509 .10377 L
.56574 .10378 L
.56642 .10379 L
.56715 .1038 L
.56784 .1038 L
.56848 .10379 L
.56969 .10377 L
.57084 .10374 L
.57206 .10369 L
.57425 .10358 L
Mistroke
.57661 .10341 L
.57921 .10318 L
.58441 .10257 L
.58935 .10185 L
.59863 .10018 L
.61951 .09558 L
.65773 .08679 L
.67906 .08261 L
.69839 .07944 L
.71879 .07677 L
.73754 .07486 L
.7568 .0734 L
.76693 .07282 L
.77763 .07233 L
.78711 .07199 L
.79728 .07172 L
.80221 .07162 L
.80687 .07153 L
.81562 .07142 L
.82021 .07137 L
.82528 .07133 L
.82783 .07132 L
.83058 .07131 L
.83184 .0713 L
.83317 .0713 L
.83441 .0713 L
.83554 .0713 L
.83668 .07129 L
.83775 .07129 L
.83888 .07129 L
.8401 .07129 L
.84118 .07129 L
.84231 .0713 L
.84328 .0713 L
.84435 .0713 L
.84674 .07131 L
.84932 .07132 L
.85397 .07134 L
.85923 .07138 L
.86411 .07143 L
.87516 .07157 L
.8849 .07174 L
.89526 .07195 L
.93692 .073 L
.97619 .07387 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04857 L
.03416 .05114 L
.03543 .05294 L
.03665 .05423 L
.03793 .05521 L
.03908 .05581 L
.04016 .05619 L
.04135 .05642 L
.04262 .05651 L
.04393 .05646 L
.04516 .05631 L
.04586 .05619 L
.0465 .05606 L
.04793 .05571 L
.05297 .05403 L
.06244 .05014 L
.08269 .042 L
.10458 .03496 L
.12545 .02993 L
.14465 .02646 L
.16347 .02388 L
.18413 .02178 L
.20364 .0203 L
.22456 .01914 L
.2458 .01828 L
.26592 .01769 L
.28583 .01725 L
.30425 .01696 L
.32291 .01673 L
.34352 .01654 L
.36286 .01642 L
.38372 .01632 L
.40376 .01625 L
.41384 .01622 L
.42486 .0162 L
.43495 .01618 L
.44447 .01617 L
.45545 .01615 L
.46542 .01615 L
.47514 .01614 L
.48004 .01614 L
.48286 .01614 L
.48543 .01614 L
.48763 .01614 L
.49003 .01613 L
.49134 .01613 L
Mistroke
.49256 .01613 L
.4938 .01613 L
.49497 .01613 L
.49606 .01613 L
.49723 .01613 L
.4983 .01613 L
.49929 .01613 L
.50035 .01613 L
.50152 .01613 L
.50275 .01613 L
.50389 .01613 L
.50515 .01613 L
.5065 .01613 L
.50891 .01613 L
.51436 .01613 L
.52428 .01614 L
.52853 .01614 L
.53076 .01614 L
.53311 .01614 L
.53436 .01614 L
.53573 .01614 L
.53698 .01614 L
.53813 .01614 L
.53933 .01614 L
.54041 .01614 L
.54167 .01614 L
.54285 .01614 L
.544 .01614 L
.54525 .01614 L
.54749 .01614 L
.55016 .01614 L
.55259 .01614 L
.55788 .01614 L
.5629 .01613 L
.57174 .01613 L
.58136 .01613 L
.62211 .0161 L
.66135 .01608 L
.69907 .01607 L
.71839 .01606 L
.72834 .01606 L
.73924 .01606 L
.74891 .01606 L
.75925 .01606 L
.77018 .01605 L
.78035 .01605 L
.78566 .01605 L
.79057 .01605 L
.79596 .01605 L
.79868 .01605 L
Mistroke
.80021 .01605 L
.80167 .01605 L
.80292 .01605 L
.80428 .01605 L
.80553 .01605 L
.80668 .01605 L
.80738 .01605 L
.80805 .01605 L
.80929 .01605 L
.80999 .01605 L
.81063 .01605 L
.81133 .01605 L
.81207 .01605 L
.81323 .01605 L
.81447 .01605 L
.81671 .01605 L
.81938 .01605 L
.82181 .01605 L
.82662 .01605 L
.83173 .01605 L
.84091 .01605 L
.86168 .01605 L
.88138 .01606 L
.89001 .01606 L
.89945 .01606 L
.90433 .01606 L
.90888 .01606 L
.91135 .01606 L
.91368 .01606 L
.91497 .01606 L
.91637 .01606 L
.91754 .01606 L
.91881 .01606 L
.92011 .01606 L
.92132 .01606 L
.92206 .01606 L
.92276 .01606 L
.92408 .01606 L
.92475 .01606 L
.92547 .01606 L
.92675 .01606 L
.92754 .01606 L
.92828 .01606 L
.92966 .01606 L
.93217 .01606 L
.93448 .01606 L
.93967 .01606 L
.94403 .01606 L
.94869 .01606 L
.9571 .01606 L
Mistroke
.97619 .01605 L
Mfstroke
.862 1 0 r
.02381 .01472 m
.02605 .02534 L
.02846 .03498 L
.02962 .03871 L
.03072 .04161 L
.0317 .0437 L
.03279 .04552 L
.03398 .04701 L
.03524 .04813 L
.03641 .04881 L
.0375 .04923 L
.03879 .04949 L
.03997 .04957 L
.04062 .04956 L
.04132 .04952 L
.04262 .04936 L
.04326 .04925 L
.04396 .04911 L
.04523 .04882 L
.04759 .04815 L
.0529 .04637 L
.06244 .04287 L
.08293 .03603 L
.10458 .03044 L
.12413 .02666 L
.14558 .02358 L
.16509 .02153 L
.18601 .0199 L
.20725 .0187 L
.22737 .01788 L
.24728 .01727 L
.2657 .01686 L
.28436 .01654 L
.30496 .01628 L
.32431 .0161 L
.34517 .01596 L
.36521 .01586 L
.38631 .01579 L
.40605 .01574 L
.42442 .01571 L
.43494 .01569 L
.44487 .01568 L
.46346 .01566 L
.47318 .01566 L
.48347 .01565 L
.49226 .01565 L
.49726 .01565 L
.50193 .01565 L
.50691 .01565 L
.51233 .01564 L
Mistroke
.52221 .01564 L
.53177 .01564 L
.54075 .01564 L
.5511 .01564 L
.56046 .01564 L
.58145 .01563 L
.62005 .01562 L
.63964 .01561 L
.66111 .01561 L
.6818 .0156 L
.70065 .0156 L
.7202 .0156 L
.73107 .0156 L
.74112 .0156 L
.75022 .0156 L
.76025 .0156 L
.77033 .0156 L
.77585 .0156 L
.78102 .01559 L
.78573 .01559 L
.79088 .01559 L
.79348 .01559 L
.79491 .01559 L
.79625 .01559 L
.79751 .01559 L
.79887 .01559 L
.80011 .01559 L
.80124 .01559 L
.80231 .01559 L
.80346 .01559 L
.80454 .01559 L
.80553 .01559 L
.80669 .01559 L
.80795 .01559 L
.80914 .01559 L
.81024 .01559 L
.81486 .01559 L
.81719 .01559 L
.81976 .01559 L
.82984 .01559 L
.83908 .0156 L
.85993 .0156 L
.88043 .0156 L
.89043 .0156 L
.89952 .0156 L
.90899 .0156 L
.91333 .0156 L
.91792 .0156 L
.92026 .0156 L
.92283 .0156 L
Mistroke
.9252 .0156 L
.92736 .0156 L
.92867 .0156 L
.92991 .0156 L
.93122 .0156 L
.93196 .0156 L
.93265 .0156 L
.93391 .0156 L
.93505 .0156 L
.93636 .0156 L
.9376 .0156 L
.93876 .0156 L
.94001 .0156 L
.94226 .0156 L
.94494 .0156 L
.94737 .0156 L
.95267 .0156 L
.95769 .0156 L
.96655 .0156 L
.97617 .0156 L
.97619 .0156 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.03279 .05635 L
.03793 .0766 L
.04262 .09131 L
.045 .09719 L
.04758 .10232 L
.04899 .10459 L
.0503 .10636 L
.05164 .10785 L
.05288 .10898 L
.05404 .10981 L
.05509 .1104 L
.05626 .11089 L
.05752 .11121 L
.05873 .11136 L
.06005 .11135 L
.06129 .11119 L
.06244 .11093 L
.06382 .1105 L
.06509 .10999 L
.06795 .10852 L
.07314 .10505 L
.08284 .09712 L
.10458 .07882 L
.125 .06436 L
.14407 .05369 L
.16239 .0457 L
.18204 .03911 L
.20328 .03378 L
.2234 .03003 L
.24331 .02727 L
.26173 .02535 L
.28039 .02387 L
.301 .02265 L
.32034 .0218 L
.3412 .02113 L
.36124 .02066 L
.38234 .02031 L
.39188 .02019 L
.40208 .02008 L
.42045 .01993 L
.43069 .01987 L
.43608 .01984 L
.44179 .01982 L
.44679 .0198 L
.45228 .01978 L
.45727 .01977 L
.46195 .01977 L
.46453 .01976 L
.46576 .01976 L
Mistroke
.46692 .01976 L
.46759 .01976 L
.4683 .01976 L
.46955 .01976 L
.47026 .01976 L
.47101 .01976 L
.47165 .01976 L
.47235 .01976 L
.47364 .01976 L
.47482 .01976 L
.47547 .01976 L
.47618 .01976 L
.47747 .01976 L
.47994 .01976 L
.48223 .01977 L
.48651 .01977 L
.49123 .01978 L
.50077 .01981 L
.52178 .01989 L
.53098 .01992 L
.53584 .01993 L
.54102 .01995 L
.54367 .01995 L
.54616 .01995 L
.54858 .01996 L
.55081 .01996 L
.55294 .01996 L
.55401 .01996 L
.55518 .01996 L
.55636 .01996 L
.55762 .01996 L
.55882 .01996 L
.55991 .01996 L
.56114 .01996 L
.56244 .01996 L
.56479 .01996 L
.56731 .01996 L
.5701 .01995 L
.57508 .01994 L
.57976 .01993 L
.59992 .01987 L
.61842 .0198 L
.65801 .01964 L
.69609 .01952 L
.71567 .01947 L
.73662 .01944 L
.74684 .01942 L
.75794 .01941 L
.76753 .0194 L
.77808 .01939 L
Mistroke
.78302 .01939 L
.78833 .01939 L
.79292 .01939 L
.79793 .01939 L
.80086 .01939 L
.80357 .01938 L
.80638 .01938 L
.80892 .01938 L
.81143 .01938 L
.81379 .01938 L
.81508 .01938 L
.81628 .01938 L
.81759 .01938 L
.81824 .01938 L
.81897 .01938 L
.82027 .01938 L
.82148 .01938 L
.82211 .01938 L
.82281 .01938 L
.82353 .01938 L
.82422 .01938 L
.82546 .01938 L
.82661 .01938 L
.82918 .01938 L
.83135 .01938 L
.83372 .01938 L
.83849 .01938 L
.84933 .01939 L
.85941 .01939 L
.87816 .01939 L
.88803 .01939 L
.89343 .01939 L
.89848 .0194 L
.90125 .0194 L
.90377 .0194 L
.90658 .0194 L
.90813 .0194 L
.90959 .0194 L
.91083 .0194 L
.91214 .0194 L
.91338 .0194 L
.9145 .0194 L
.91519 .0194 L
.91582 .0194 L
.91652 .0194 L
.91725 .0194 L
.91849 .0194 L
.91984 .0194 L
.92248 .0194 L
.92488 .0194 L
Mistroke
.93027 .0194 L
.93527 .01939 L
.94 .01939 L
.94913 .01939 L
.95881 .01939 L
.97619 .01938 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02109 L
.06244 .01975 L
.08259 .01859 L
.10458 .01762 L
.12517 .01694 L
.14429 .01647 L
.16481 .0161 L
.18342 .01584 L
.20266 .01564 L
.22348 .01548 L
.24342 .01537 L
.26449 .01528 L
.28413 .01522 L
.30246 .01518 L
.32281 .01515 L
.34137 .01513 L
.36045 .01511 L
.38121 .01509 L
.40099 .01508 L
.4111 .01508 L
.422 .01508 L
.43215 .01508 L
.44147 .01507 L
.4503 .01507 L
.45975 .01507 L
.46955 .01507 L
.47867 .01507 L
.48425 .01507 L
.48952 .01507 L
.49424 .01507 L
.49672 .01507 L
.49937 .01507 L
.50193 .01507 L
.50426 .01507 L
.50884 .01507 L
.51139 .01507 L
.51418 .01507 L
Mistroke
.51925 .01507 L
.52453 .01507 L
.52744 .01507 L
.53017 .01507 L
.53272 .01507 L
.53548 .01507 L
.54029 .01507 L
.54522 .01507 L
.54982 .01507 L
.56027 .01507 L
.57045 .01507 L
.58134 .01507 L
.62276 .01506 L
.64349 .01506 L
.66266 .01506 L
.68246 .01506 L
.70104 .01506 L
.71974 .01506 L
.72979 .01506 L
.74036 .01506 L
.75002 .01506 L
.76058 .01506 L
.7791 .01506 L
.7894 .01506 L
.79874 .01506 L
.81971 .01506 L
.85974 .01506 L
.89826 .01506 L
.93923 .01506 L
.97619 .01506 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.03279 .05641 L
.04262 .09274 L
.04758 .10577 L
.0503 .11134 L
.05288 .11562 L
.05528 .11881 L
.05789 .12146 L
.05904 .12239 L
.06026 .12323 L
.0613 .12383 L
.06244 .12437 L
.06378 .12486 L
.06505 .12519 L
.06628 .12539 L
.06743 .12549 L
.06813 .12551 L
.06879 .12549 L
.07003 .1254 L
.07072 .12531 L
.07136 .12521 L
.0728 .1249 L
.07505 .12424 L
.07751 .12329 L
.0825 .12081 L
.10458 .10554 L
.12572 .09028 L
.145 .07816 L
.18391 .05995 L
.203 .05364 L
.22376 .04831 L
.24353 .04441 L
.26454 .04125 L
.28401 .03904 L
.30229 .03745 L
.32247 .03613 L
.34098 .03523 L
.3599 .03456 L
.37063 .03428 L
.3806 .03407 L
.39113 .03389 L
.39629 .03383 L
.40106 .03378 L
.40531 .03374 L
.40998 .03371 L
.41241 .0337 L
.41468 .03369 L
.41707 .03369 L
.41842 .03368 L
.41965 .03368 L
Mistroke
.42094 .03368 L
.42216 .03368 L
.42325 .03368 L
.42443 .03368 L
.42572 .03368 L
.42637 .03368 L
.42708 .03369 L
.42952 .03369 L
.43181 .0337 L
.43425 .03371 L
.43867 .03374 L
.44425 .0338 L
.44952 .03387 L
.45423 .03394 L
.45941 .03404 L
.46909 .03429 L
.47936 .03464 L
.48887 .03508 L
.49779 .0356 L
.5163 .03695 L
.52679 .03777 L
.53653 .03845 L
.54624 .03897 L
.55168 .03919 L
.55661 .03934 L
.55933 .0394 L
.56183 .03944 L
.56457 .03948 L
.56596 .03949 L
.56674 .03949 L
.56748 .0395 L
.56812 .0395 L
.56881 .0395 L
.57003 .03951 L
.57072 .03951 L
.57145 .03951 L
.57277 .0395 L
.57399 .0395 L
.57512 .03949 L
.57637 .03948 L
.57772 .03947 L
.58011 .03944 L
.58267 .0394 L
.58728 .03932 L
.59774 .03905 L
.61883 .03829 L
.66029 .03659 L
.68107 .03582 L
.70024 .03521 L
.72009 .03468 L
Mistroke
.73868 .03427 L
.75742 .03395 L
.768 .03381 L
.77805 .03369 L
.78774 .0336 L
.79831 .03351 L
.81684 .0334 L
.83653 .03331 L
.85751 .03322 L
.89911 .03304 L
.9392 .03281 L
.97619 .0326 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.03279 .05663 L
.04262 .09508 L
.04758 .11012 L
.05288 .12252 L
.05546 .12717 L
.05789 .13078 L
.06024 .13358 L
.06244 .13562 L
.06487 .13729 L
.06616 .13794 L
.06754 .13847 L
.06824 .13867 L
.06899 .13885 L
.0697 .13898 L
.07037 .13907 L
.07162 .13914 L
.07232 .13913 L
.07295 .1391 L
.0742 .13896 L
.07535 .13875 L
.07661 .13844 L
.07794 .13803 L
.08265 .13595 L
.08806 .13266 L
.0931 .12899 L
.10458 .11956 L
.14349 .08829 L
.16473 .07495 L
.18485 .06491 L
.20476 .05712 L
.22318 .05147 L
.24184 .04698 L
.26245 .04317 L
.28179 .04045 L
.30265 .03825 L
.32269 .03667 L
.34379 .03546 L
.35333 .03504 L
.36353 .03466 L
.3819 .03414 L
.39214 .03393 L
.39753 .03384 L
.40324 .03376 L
.40824 .03371 L
.41373 .03366 L
.41614 .03365 L
.41872 .03363 L
.42116 .03362 L
.42339 .03361 L
Mistroke
.42469 .03361 L
.4259 .03361 L
.427 .03361 L
.42818 .03361 L
.42947 .03361 L
.43012 .03361 L
.43083 .03361 L
.43209 .03361 L
.43327 .03361 L
.43445 .03362 L
.43558 .03362 L
.43769 .03363 L
.43995 .03364 L
.44242 .03366 L
.44765 .0337 L
.4532 .03377 L
.45793 .03385 L
.46316 .03395 L
.47327 .03421 L
.48254 .03453 L
.49271 .035 L
.50341 .03562 L
.52342 .03703 L
.53213 .03763 L
.54157 .03817 L
.54684 .03841 L
.55169 .03859 L
.55632 .03872 L
.55866 .03877 L
.56122 .03881 L
.56262 .03883 L
.56395 .03885 L
.56516 .03886 L
.56645 .03887 L
.56711 .03887 L
.56784 .03888 L
.56913 .03888 L
.56986 .03888 L
.57064 .03888 L
.57138 .03888 L
.57206 .03888 L
.57328 .03888 L
.57441 .03887 L
.57566 .03886 L
.57699 .03885 L
.57971 .03882 L
.58218 .03879 L
.58702 .0387 L
.59215 .03859 L
.60135 .03833 L
Mistroke
.62213 .03757 L
.65999 .03607 L
.68104 .03531 L
.7003 .03472 L
.72042 .0342 L
.73909 .03382 L
.75809 .03351 L
.76876 .03338 L
.77882 .03327 L
.78869 .03318 L
.79935 .0331 L
.81797 .033 L
.82748 .03296 L
.83792 .03293 L
.85899 .03287 L
.88015 .03282 L
.89943 .03275 L
.93836 .03257 L
.97619 .03237 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.04262 .0986 L
.0522 .13356 L
.06244 .16361 L
.0679 .17622 L
.07286 .18561 L
.07784 .19307 L
.08255 .19835 L
.08522 .20061 L
.08805 .20247 L
.09046 .20364 L
.09183 .20414 L
.09312 .2045 L
.09382 .20466 L
.09459 .2048 L
.09532 .2049 L
.096 .20496 L
.09728 .20502 L
.09799 .20502 L
.09864 .20499 L
.0994 .20493 L
.10011 .20485 L
.10088 .20473 L
.1017 .20458 L
.10307 .20425 L
.10458 .2038 L
.10709 .20283 L
.10982 .20152 L
.11478 .19851 L
.12409 .19118 L
.145 .17057 L
.18579 .13066 L
.20604 .11465 L
.22505 .10226 L
.24344 .09249 L
.2628 .08424 L
.28299 .07752 L
.30149 .07273 L
.32123 .06882 L
.3396 .06607 L
.35012 .06483 L
.36006 .06385 L
.36891 .06313 L
.37864 .06248 L
.38837 .06198 L
.39333 .06177 L
.39866 .06159 L
.40364 .06146 L
.40819 .06138 L
.41038 .06135 L
Mistroke
.41154 .06133 L
.41277 .06132 L
.41395 .06131 L
.41502 .0613 L
.4161 .0613 L
.41711 .0613 L
.41828 .06129 L
.41953 .06129 L
.42071 .0613 L
.42178 .0613 L
.42304 .06131 L
.42441 .06132 L
.4269 .06134 L
.4295 .06138 L
.43227 .06144 L
.43723 .06157 L
.44177 .06173 L
.44602 .06192 L
.45571 .0625 L
.46042 .06287 L
.46557 .06335 L
.47594 .06462 L
.48553 .06621 L
.49445 .06814 L
.51495 .07433 L
.53355 .08078 L
.54289 .08345 L
.548 .08462 L
.55277 .0855 L
.55794 .08622 L
.56067 .0865 L
.56208 .08662 L
.56361 .08673 L
.565 .08681 L
.56629 .08688 L
.56752 .08692 L
.56882 .08696 L
.56999 .08698 L
.57109 .08699 L
.57229 .087 L
.57358 .08699 L
.57484 .08697 L
.57598 .08694 L
.57729 .0869 L
.57853 .08684 L
.58074 .08673 L
.58314 .08657 L
.58858 .08611 L
.5936 .08555 L
.61469 .08235 L
Mistroke
.65406 .07524 L
.69192 .0695 L
.71134 .06728 L
.73223 .06544 L
.74234 .06476 L
.75338 .06415 L
.7638 .06372 L
.76884 .06355 L
.77347 .06343 L
.77855 .06333 L
.78123 .06329 L
.78405 .06326 L
.78523 .06324 L
.7865 .06323 L
.7877 .06323 L
.7888 .06322 L
.79008 .06322 L
.7908 .06322 L
.79147 .06322 L
.7927 .06322 L
.79401 .06322 L
.79515 .06322 L
.79621 .06323 L
.79736 .06324 L
.79857 .06325 L
.80062 .06327 L
.80286 .0633 L
.80792 .06339 L
.81262 .0635 L
.81768 .06366 L
.82315 .06388 L
.83309 .06437 L
.85168 .06564 L
.87118 .06729 L
.89262 .06914 L
.90245 .06989 L
.913 .07057 L
.91811 .07084 L
.92295 .07106 L
.92764 .07124 L
.93205 .07138 L
.93447 .07144 L
.9371 .0715 L
.93928 .07153 L
.94167 .07157 L
.94427 .0716 L
.94568 .07161 L
.94701 .07162 L
.94824 .07162 L
.94937 .07162 L
Mistroke
.95068 .07162 L
.95191 .07162 L
.95297 .07162 L
.95413 .07161 L
.95535 .0716 L
.95649 .07159 L
.95853 .07157 L
.96073 .07155 L
.96573 .07146 L
.97031 .07135 L
.97619 .07119 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.04262 .09863 L
.0522 .13374 L
.06244 .16426 L
.0679 .17729 L
.07286 .18717 L
.0779 .19531 L
.08255 .20116 L
.08514 .20375 L
.08798 .20608 L
.09084 .20789 L
.09243 .20868 L
.09388 .20927 L
.09515 .20969 L
.09654 .21005 L
.0973 .2102 L
.09801 .21031 L
.09868 .21039 L
.0994 .21046 L
.10007 .21049 L
.1008 .21051 L
.10212 .21047 L
.1034 .21035 L
.10458 .21018 L
.10584 .20993 L
.10704 .20963 L
.10928 .20893 L
.11432 .2067 L
.11867 .20416 L
.1234 .20086 L
.14407 .18252 L
.18485 .14355 L
.2051 .12728 L
.22412 .11448 L
.26187 .09559 L
.28205 .08847 L
.30055 .08337 L
.31948 .07934 L
.34018 .07607 L
.35979 .07388 L
.37077 .07298 L
.38074 .07236 L
.38559 .07212 L
.39072 .07191 L
.3951 .07176 L
.39992 .07164 L
.40263 .07159 L
.4051 .07156 L
.40647 .07154 L
.40719 .07154 L
Mistroke
.40796 .07153 L
.4087 .07152 L
.40936 .07152 L
.41067 .07152 L
.41197 .07152 L
.41316 .07152 L
.41447 .07152 L
.41513 .07152 L
.41585 .07153 L
.41707 .07154 L
.41837 .07155 L
.42072 .07159 L
.42329 .07163 L
.42602 .0717 L
.43092 .07186 L
.43619 .07208 L
.442 .07241 L
.44701 .07277 L
.45239 .07323 L
.46213 .07433 L
.47173 .07581 L
.48221 .07803 L
.49316 .08118 L
.50333 .08502 L
.5221 .09386 L
.53198 .09854 L
.54242 .10267 L
.54773 .10429 L
.55054 .10501 L
.55356 .10566 L
.55633 .10616 L
.55886 .10653 L
.5614 .10682 L
.56381 .10703 L
.56496 .1071 L
.56624 .10717 L
.56688 .10719 L
.56757 .10722 L
.56882 .10725 L
.57 .10726 L
.57124 .10726 L
.5723 .10724 L
.57346 .10721 L
.57417 .10719 L
.57484 .10716 L
.57609 .1071 L
.57891 .10691 L
.58134 .1067 L
.58397 .10642 L
.59342 .10503 L
Mistroke
.60383 .10298 L
.62486 .09796 L
.66517 .0882 L
.70396 .08102 L
.72511 .07825 L
.73484 .07723 L
.7452 .07631 L
.7556 .07557 L
.76502 .07503 L
.76958 .07482 L
.7745 .07463 L
.7788 .07449 L
.78342 .07437 L
.78599 .07432 L
.78834 .07428 L
.79072 .07425 L
.79293 .07423 L
.79418 .07422 L
.7955 .07421 L
.79619 .07421 L
.79683 .0742 L
.79753 .0742 L
.79829 .0742 L
.79958 .0742 L
.80023 .0742 L
.80094 .0742 L
.8022 .07421 L
.80337 .07421 L
.80469 .07422 L
.80612 .07424 L
.80871 .07427 L
.81123 .0743 L
.81356 .07435 L
.81885 .07447 L
.82444 .07465 L
.83389 .07504 L
.84403 .07558 L
.86235 .07684 L
.88211 .07845 L
.90364 .08017 L
.91365 .08087 L
.92429 .0815 L
.93433 .08196 L
.93876 .08212 L
.94342 .08227 L
.94734 .08237 L
.95164 .08245 L
.95352 .08248 L
.95554 .08251 L
.95743 .08253 L
Mistroke
.95918 .08254 L
.96024 .08255 L
.96137 .08255 L
.96251 .08256 L
.96376 .08256 L
.96483 .08256 L
.96599 .08256 L
.96708 .08256 L
.96809 .08255 L
.96911 .08255 L
.97007 .08254 L
.97224 .08253 L
.97415 .08251 L
.97619 .08249 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.04262 .09859 L
.0522 .13364 L
.06244 .16429 L
.0679 .17759 L
.07286 .1879 L
.08255 .20335 L
.08798 .20947 L
.09084 .21203 L
.09388 .21427 L
.09652 .21584 L
.09944 .2172 L
.10072 .21768 L
.10209 .21811 L
.10337 .21845 L
.10458 .2187 L
.10591 .21892 L
.10712 .21906 L
.10841 .21915 L
.10915 .21918 L
.10982 .21918 L
.11095 .21916 L
.11219 .21909 L
.11348 .21897 L
.11468 .21881 L
.11611 .21856 L
.11747 .21828 L
.12001 .21762 L
.12571 .2156 L
.13534 .21083 L
.1458 .20429 L
.18659 .17471 L
.22585 .14987 L
.2636 .13263 L
.28295 .12616 L
.30381 .12075 L
.32385 .11687 L
.33392 .11536 L
.34495 .11401 L
.35522 .11303 L
.36456 .11237 L
.36973 .11209 L
.37245 .11196 L
.37533 .11185 L
.37785 .11177 L
.38063 .1117 L
.38184 .11168 L
.38315 .11166 L
.38436 .11164 L
.38551 .11163 L
Mistroke
.38615 .11162 L
.38684 .11161 L
.38805 .11161 L
.38874 .1116 L
.38947 .1116 L
.39076 .1116 L
.39197 .11161 L
.39309 .11162 L
.39432 .11163 L
.39564 .11165 L
.39861 .1117 L
.40142 .11178 L
.40668 .11198 L
.41169 .11224 L
.41632 .11255 L
.42136 .11297 L
.42678 .11352 L
.43644 .1148 L
.44549 .11641 L
.45625 .11898 L
.4661 .12216 L
.47593 .12639 L
.48506 .13158 L
.49509 .13899 L
.50578 .14902 L
.52573 .17091 L
.53623 .18126 L
.54197 .1859 L
.54733 .18945 L
.55212 .19194 L
.55726 .19391 L
.56019 .19472 L
.56163 .19503 L
.56297 .19528 L
.56415 .19546 L
.56546 .19562 L
.56677 .19574 L
.56749 .19578 L
.56817 .19582 L
.56929 .19585 L
.57052 .19586 L
.57179 .19583 L
.57299 .19578 L
.5741 .1957 L
.57512 .1956 L
.5774 .19532 L
.57986 .19492 L
.58252 .19436 L
.58736 .19308 L
.59681 .18972 L
Mistroke
.60721 .18507 L
.62825 .17414 L
.66856 .15345 L
.70735 .13823 L
.7285 .13223 L
.74859 .12792 L
.75819 .12629 L
.76841 .12485 L
.78681 .12291 L
.7971 .12215 L
.80823 .12153 L
.81874 .12111 L
.82841 .12083 L
.83311 .12073 L
.83815 .12064 L
.8406 .12061 L
.84291 .12058 L
.84497 .12056 L
.84725 .12054 L
.84845 .12053 L
.84974 .12053 L
.85046 .12052 L
.85111 .12052 L
.85239 .12052 L
.8535 .12052 L
.85471 .12052 L
.85597 .12052 L
.85715 .12052 L
.85782 .12052 L
.85855 .12052 L
.85988 .12053 L
.86117 .12053 L
.86236 .12054 L
.86506 .12056 L
.86792 .1206 L
.87285 .12067 L
.87736 .12076 L
.8875 .12103 L
.8969 .12138 L
.90582 .12177 L
.94409 .12401 L
.97619 .12599 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.03279 .05652 L
.04262 .09387 L
.04758 .10786 L
.0503 .11404 L
.05288 .11893 L
.05528 .12267 L
.05789 .12592 L
.06026 .12819 L
.06244 .12977 L
.06371 .13047 L
.06487 .13098 L
.0655 .13122 L
.0662 .13144 L
.06747 .13174 L
.06865 .13192 L
.06991 .132 L
.0711 .13199 L
.07218 .1319 L
.07285 .13182 L
.07356 .1317 L
.07483 .13143 L
.0762 .13106 L
.0777 .13056 L
.0829 .12821 L
.09411 .12104 L
.10458 .11316 L
.14349 .08512 L
.16473 .07319 L
.18485 .06419 L
.20307 .05772 L
.22318 .05211 L
.24295 .04785 L
.26396 .04441 L
.28331 .04201 L
.30416 .04007 L
.3242 .03869 L
.33441 .03814 L
.3453 .03764 L
.35565 .03725 L
.36505 .03696 L
.37397 .03673 L
.38341 .03654 L
.38817 .03646 L
.39339 .03639 L
.3982 .03633 L
.4026 .03629 L
.40778 .03626 L
.41063 .03624 L
.41194 .03624 L
Mistroke
.41334 .03624 L
.41465 .03623 L
.41584 .03623 L
.41703 .03623 L
.41815 .03623 L
.41947 .03623 L
.42067 .03623 L
.4213 .03623 L
.422 .03623 L
.42339 .03623 L
.4247 .03624 L
.42591 .03624 L
.42865 .03626 L
.43107 .03627 L
.43363 .03629 L
.43806 .03633 L
.44294 .03639 L
.44814 .03648 L
.45374 .03659 L
.46387 .03686 L
.47347 .03721 L
.48395 .03773 L
.49489 .03845 L
.50506 .03928 L
.52384 .04103 L
.53372 .04188 L
.54416 .04257 L
.54947 .04282 L
.55228 .04293 L
.55529 .04302 L
.55807 .04309 L
.56059 .04313 L
.56181 .04315 L
.56314 .04316 L
.56439 .04317 L
.56555 .04318 L
.5667 .04318 L
.56794 .04318 L
.56911 .04318 L
.57019 .04318 L
.57138 .04317 L
.57269 .04316 L
.57405 .04315 L
.57532 .04313 L
.58034 .04305 L
.58315 .04298 L
.58571 .04291 L
.60487 .0422 L
.62566 .04119 L
.66655 .0392 L
Mistroke
.68688 .03836 L
.70592 .0377 L
.72533 .03715 L
.74377 .03673 L
.76404 .03639 L
.78256 .03616 L
.79216 .03607 L
.80239 .03599 L
.82078 .03588 L
.86238 .03568 L
.90247 .03544 L
.94104 .03518 L
.97619 .03496 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.03279 .05652 L
.04262 .09374 L
.04758 .10747 L
.0503 .11341 L
.05288 .118 L
.05528 .1214 L
.05789 .12422 L
.05904 .12518 L
.06026 .12604 L
.0613 .12664 L
.06244 .12716 L
.06314 .12741 L
.06378 .1276 L
.06505 .12787 L
.0662 .128 L
.06743 .12801 L
.06813 .12797 L
.06888 .12788 L
.06959 .12776 L
.07025 .12763 L
.07149 .1273 L
.0728 .12686 L
.07742 .12464 L
.0825 .12133 L
.10458 .10265 L
.12572 .08501 L
.145 .0715 L
.16521 .06015 L
.18391 .05191 L
.203 .04534 L
.22376 .03988 L
.24242 .03615 L
.26302 .03302 L
.28237 .03081 L
.30323 .02903 L
.32327 .02777 L
.34437 .02679 L
.36411 .02613 L
.38248 .02569 L
.393 .0255 L
.40293 .02535 L
.41178 .02524 L
.42152 .02515 L
.42621 .02512 L
.43124 .02509 L
.43402 .02508 L
.43656 .02507 L
.43914 .02506 L
.44153 .02505 L
Mistroke
.44373 .02505 L
.44495 .02504 L
.44606 .02504 L
.44729 .02504 L
.44861 .02504 L
.44985 .02504 L
.451 .02504 L
.45208 .02504 L
.45309 .02504 L
.45419 .02504 L
.45537 .02504 L
.45779 .02505 L
.45999 .02505 L
.46481 .02507 L
.46724 .02508 L
.46993 .0251 L
.47911 .02517 L
.48427 .02522 L
.48983 .02529 L
.49988 .02544 L
.51957 .02582 L
.52998 .02603 L
.53569 .02613 L
.54108 .02621 L
.54625 .02628 L
.54898 .02631 L
.55186 .02633 L
.55429 .02635 L
.55695 .02637 L
.55938 .02638 L
.56164 .02639 L
.56283 .02639 L
.56412 .02639 L
.56534 .02639 L
.56646 .0264 L
.56748 .0264 L
.5686 .0264 L
.56976 .02639 L
.57086 .02639 L
.57207 .02639 L
.57334 .02639 L
.57562 .02638 L
.57807 .02637 L
.58075 .02636 L
.58603 .02632 L
.59101 .02628 L
.60034 .02618 L
.62128 .02591 L
.65972 .02538 L
.67918 .02514 L
Mistroke
.7006 .02491 L
.72117 .02474 L
.73997 .02462 L
.7594 .02452 L
.77011 .02448 L
.78028 .02445 L
.78988 .02442 L
.8001 .02441 L
.80975 .02439 L
.81849 .02438 L
.82337 .02438 L
.82853 .02438 L
.83293 .02437 L
.83775 .02437 L
.84048 .02437 L
.84296 .02437 L
.84433 .02437 L
.84582 .02437 L
.84723 .02437 L
.84853 .02437 L
.84972 .02437 L
.85085 .02437 L
.85208 .02437 L
.85277 .02437 L
.8534 .02437 L
.85461 .02437 L
.85593 .02437 L
.85659 .02437 L
.8573 .02437 L
.85858 .02437 L
.86883 .02437 L
.87164 .02437 L
.87318 .02437 L
.87461 .02437 L
.87584 .02437 L
.87715 .02437 L
.8779 .02437 L
.87861 .02437 L
.87925 .02437 L
.87994 .02437 L
.8806 .02437 L
.88131 .02437 L
.8826 .02437 L
.88386 .02437 L
.88501 .02437 L
.88763 .02437 L
.88896 .02437 L
.8904 .02437 L
.89283 .02437 L
.89542 .02437 L
Mistroke
.9001 .02437 L
.90541 .02437 L
.91031 .02437 L
.92139 .02436 L
.93117 .02435 L
.94153 .02434 L
.97619 .02429 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02002 L
.02729 .02079 L
.02846 .02115 L
.02954 .02134 L
.03053 .02143 L
.03163 .02148 L
.03279 .0215 L
.03395 .02149 L
.0352 .02146 L
.03638 .02142 L
.03746 .02137 L
.04262 .02107 L
.06244 .01971 L
.08259 .01854 L
.10458 .01756 L
.12517 .01689 L
.14429 .01642 L
.16481 .01604 L
.18342 .01579 L
.20266 .01559 L
.22348 .01543 L
.24342 .01532 L
.26449 .01523 L
.28413 .01518 L
.30246 .01514 L
.32281 .0151 L
.34137 .01508 L
.36045 .01506 L
.38121 .01505 L
.40099 .01504 L
.4111 .01503 L
.422 .01503 L
.43215 .01503 L
.44147 .01503 L
.45975 .01502 L
.46955 .01502 L
.47867 .01502 L
.48868 .01502 L
.49424 .01502 L
.49937 .01502 L
.50961 .01502 L
.52072 .01502 L
.53113 .01502 L
.54087 .01502 L
.55963 .01502 L
.58027 .01502 L
.6191 .01502 L
.63884 .01501 L
Mistroke
.66037 .01501 L
.68124 .01501 L
.70013 .01501 L
.71984 .01501 L
.73066 .01501 L
.74083 .01501 L
.75062 .01501 L
.76095 .01501 L
.76977 .01501 L
.77477 .01501 L
.77943 .01501 L
.78187 .01501 L
.78446 .01501 L
.78729 .01501 L
.78855 .01501 L
.78991 .01501 L
.79118 .01501 L
.79235 .01501 L
.79346 .01501 L
.79463 .01501 L
.79591 .01501 L
.79711 .01501 L
.79842 .01501 L
.79916 .01501 L
.79983 .01501 L
.80221 .01501 L
.80441 .01501 L
.80938 .01501 L
.81376 .01501 L
.81839 .01501 L
.82786 .01501 L
.83801 .01501 L
.85633 .01501 L
.87612 .01501 L
.88656 .01501 L
.89766 .01501 L
.90748 .01501 L
.9127 .01501 L
.91833 .01501 L
.92348 .01501 L
.9282 .01501 L
.93054 .01501 L
.93272 .01501 L
.93499 .01501 L
.93619 .01501 L
.93748 .01501 L
.93862 .01501 L
.93989 .01501 L
.94121 .01501 L
.94244 .01501 L
Mistroke
.94359 .01501 L
.94465 .01501 L
.94587 .01501 L
.94702 .01501 L
.94959 .01501 L
.95198 .01501 L
.95738 .01501 L
.96216 .01501 L
.96649 .01501 L
.97619 .01501 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.03279 .05663 L
.04262 .0949 L
.04758 .10961 L
.0503 .11618 L
.05288 .12137 L
.05528 .12532 L
.05789 .12869 L
.06026 .13097 L
.06244 .13246 L
.06371 .13307 L
.06487 .13348 L
.0655 .13365 L
.0662 .13379 L
.06747 .13394 L
.06865 .13395 L
.06991 .13383 L
.0711 .13361 L
.07218 .13334 L
.07356 .13287 L
.07483 .13234 L
.0777 .13086 L
.0829 .12733 L
.10458 .10767 L
.125 .08919 L
.14407 .07463 L
.16357 .06266 L
.18204 .05372 L
.20239 .0461 L
.22095 .04078 L
.24086 .03641 L
.25928 .03333 L
.27794 .03094 L
.29854 .02895 L
.31789 .02757 L
.33875 .02646 L
.35879 .02569 L
.36899 .02539 L
.37989 .02511 L
.39023 .0249 L
.39963 .02474 L
.40855 .02461 L
.418 .0245 L
.42275 .02446 L
.42798 .02442 L
.43279 .02439 L
.43718 .02436 L
.44236 .02434 L
.44521 .02433 L
.44792 .02433 L
Mistroke
.44913 .02432 L
.45042 .02432 L
.45163 .02432 L
.45273 .02432 L
.45403 .02432 L
.45476 .02432 L
.45544 .02432 L
.45667 .02432 L
.45798 .02432 L
.4592 .02432 L
.46053 .02432 L
.46295 .02433 L
.46531 .02433 L
.46748 .02434 L
.47242 .02436 L
.47765 .02439 L
.48638 .02446 L
.496 .02457 L
.51701 .02488 L
.52621 .02503 L
.53626 .02517 L
.54099 .02523 L
.54605 .02527 L
.55081 .02531 L
.55514 .02533 L
.5577 .02534 L
.55891 .02535 L
.56005 .02535 L
.56128 .02535 L
.56193 .02535 L
.56263 .02535 L
.56336 .02535 L
.56406 .02536 L
.56536 .02536 L
.56652 .02535 L
.56776 .02535 L
.56881 .02535 L
.56997 .02535 L
.57256 .02534 L
.575 .02534 L
.57968 .02531 L
.58481 .02528 L
.59515 .0252 L
.61365 .025 L
.65418 .02451 L
.69319 .02412 L
.71451 .02397 L
.73466 .02386 L
.74436 .02382 L
.75465 .02378 L
Mistroke
.76428 .02375 L
.77309 .02373 L
.78251 .02372 L
.78771 .02371 L
.79264 .0237 L
.79718 .0237 L
.8014 .0237 L
.80382 .0237 L
.80602 .02369 L
.80724 .02369 L
.80856 .02369 L
.8098 .02369 L
.81095 .02369 L
.81221 .02369 L
.81341 .02369 L
.81448 .02369 L
.81565 .02369 L
.81692 .02369 L
.81756 .02369 L
.81827 .02369 L
.82069 .02369 L
.82295 .02369 L
.82538 .0237 L
.82979 .0237 L
.83504 .0237 L
.84057 .02371 L
.85045 .02372 L
.88858 .02377 L
.89868 .02378 L
.90821 .02379 L
.91348 .02379 L
.91625 .0238 L
.91919 .0238 L
.92166 .0238 L
.92438 .0238 L
.92557 .0238 L
.92685 .0238 L
.92806 .0238 L
.92916 .0238 L
.93046 .0238 L
.93168 .0238 L
.93277 .0238 L
.93395 .0238 L
.93524 .0238 L
.93589 .0238 L
.93661 .0238 L
.93904 .0238 L
.94133 .0238 L
.94378 .0238 L
.9482 .0238 L
Mistroke
.95378 .02379 L
.95906 .02379 L
.96894 .02378 L
.97619 .02377 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.03279 .05676 L
.04262 .09658 L
.04758 .11316 L
.05288 .12782 L
.05789 .13862 L
.06244 .14592 L
.06507 .14909 L
.06785 .15168 L
.07022 .15331 L
.07157 .15402 L
.07283 .15454 L
.07353 .15477 L
.07428 .15498 L
.07495 .15513 L
.07567 .15525 L
.07637 .15534 L
.07701 .15539 L
.07826 .15541 L
.07901 .15537 L
.07971 .15531 L
.08047 .1552 L
.08127 .15506 L
.08262 .15474 L
.0841 .15428 L
.08678 .15321 L
.08922 .15198 L
.09469 .14852 L
.10458 .14062 L
.14443 .10485 L
.18275 .07833 L
.20253 .06839 L
.22354 .06013 L
.24301 .05422 L
.26129 .04988 L
.28147 .04618 L
.29997 .04359 L
.3189 .04156 L
.3396 .03991 L
.35921 .03878 L
.37019 .03829 L
.38016 .03794 L
.38948 .03767 L
.39934 .03745 L
.4045 .03736 L
.41017 .03728 L
.41532 .03723 L
.41766 .03721 L
.42014 .03719 L
.42273 .03717 L
Mistroke
.42388 .03717 L
.42512 .03717 L
.42589 .03716 L
.42659 .03716 L
.42725 .03716 L
.42797 .03716 L
.42922 .03716 L
.42991 .03716 L
.43055 .03716 L
.43183 .03716 L
.43305 .03716 L
.43414 .03716 L
.43532 .03717 L
.43798 .03718 L
.44043 .0372 L
.44471 .03723 L
.44942 .03729 L
.45435 .03737 L
.45897 .03747 L
.46882 .03774 L
.47378 .03792 L
.47919 .03815 L
.49771 .03927 L
.50801 .04012 L
.51735 .04101 L
.52827 .04206 L
.53832 .04293 L
.54766 .04357 L
.55237 .04381 L
.55754 .04402 L
.56026 .0441 L
.56273 .04416 L
.5641 .04419 L
.56559 .04421 L
.56688 .04423 L
.5683 .04424 L
.5696 .04425 L
.57083 .04426 L
.57212 .04426 L
.57285 .04426 L
.57352 .04426 L
.57464 .04425 L
.57587 .04425 L
.57716 .04424 L
.57835 .04422 L
.58097 .04419 L
.58339 .04415 L
.58886 .04402 L
.59879 .04369 L
.61737 .04284 L
Mistroke
.65674 .04073 L
.69459 .03895 L
.71565 .03817 L
.7349 .03759 L
.75479 .03713 L
.77369 .0368 L
.78329 .03666 L
.79351 .03655 L
.8119 .03639 L
.8222 .03633 L
.83333 .03628 L
.85351 .03621 L
.87307 .03616 L
.89453 .03609 L
.91497 .036 L
.93404 .0359 L
.97297 .03564 L
.97619 .03562 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04856 L
.03416 .05112 L
.03543 .05292 L
.03665 .0542 L
.03793 .05518 L
.03908 .05577 L
.04016 .05614 L
.04135 .05637 L
.04262 .05645 L
.04393 .0564 L
.04516 .05624 L
.04586 .05611 L
.0465 .05598 L
.04793 .05562 L
.05297 .05393 L
.06244 .05002 L
.08269 .04187 L
.10458 .03484 L
.12545 .02982 L
.14465 .02636 L
.16347 .0238 L
.18413 .0217 L
.20364 .02023 L
.22456 .01907 L
.2458 .01822 L
.26592 .01763 L
.28583 .0172 L
.30425 .0169 L
.32291 .01668 L
.34352 .01649 L
.36286 .01637 L
.38372 .01627 L
.40376 .0162 L
.41384 .01617 L
.42486 .01615 L
.44447 .01612 L
.45545 .0161 L
.46542 .0161 L
.47027 .01609 L
.4754 .01609 L
.47984 .01609 L
.4846 .01609 L
.48728 .01609 L
.48972 .01608 L
.4922 .01608 L
.49451 .01608 L
Mistroke
.49718 .01608 L
.49859 .01608 L
.49932 .01608 L
.5001 .01608 L
.50084 .01608 L
.50153 .01608 L
.50219 .01608 L
.50288 .01608 L
.50408 .01608 L
.5054 .01608 L
.50671 .01608 L
.50792 .01608 L
.50925 .01608 L
.51066 .01608 L
.51563 .01608 L
.52495 .01608 L
.52742 .01608 L
.53009 .01608 L
.53131 .01609 L
.5326 .01609 L
.5337 .01609 L
.5349 .01609 L
.53565 .01609 L
.53635 .01609 L
.53766 .01609 L
.53839 .01609 L
.53907 .01609 L
.53981 .01609 L
.54059 .01609 L
.54189 .01609 L
.54311 .01609 L
.54445 .01608 L
.54588 .01608 L
.54843 .01608 L
.55115 .01608 L
.55603 .01608 L
.56129 .01608 L
.56709 .01608 L
.58721 .01607 L
.62738 .01605 L
.66603 .01603 L
.68605 .01602 L
.70714 .01602 L
.72686 .01601 L
.74522 .01601 L
.75572 .01601 L
.76565 .01601 L
.78423 .016 L
.79393 .016 L
.80422 .016 L
Mistroke
.82266 .016 L
.86052 .016 L
.90083 .016 L
.93962 .016 L
.97619 .01599 L
Mfstroke
.53 1 0 r
.02381 .01472 m
.04262 .09853 L
.0522 .13326 L
.06244 .16288 L
.0679 .17525 L
.07286 .18446 L
.07784 .19182 L
.08255 .19712 L
.08522 .19944 L
.08805 .20142 L
.09046 .20272 L
.09312 .20378 L
.0946 .20421 L
.09597 .2045 L
.09672 .20463 L
.09754 .20473 L
.09831 .2048 L
.09903 .20484 L
.09976 .20486 L
.10044 .20485 L
.10172 .20479 L
.10243 .20473 L
.10309 .20466 L
.10458 .20442 L
.10584 .20416 L
.10704 .20387 L
.10928 .20318 L
.11432 .2011 L
.1234 .19586 L
.14407 .17993 L
.1824 .1485 L
.20178 .13488 L
.22318 .12227 L
.26245 .10528 L
.28179 .09937 L
.30265 .09446 L
.32269 .09095 L
.33289 .08954 L
.34379 .08831 L
.35413 .08736 L
.36353 .08669 L
.36806 .08642 L
.37298 .08617 L
.37728 .086 L
.3819 .08584 L
.38445 .08577 L
.38679 .08572 L
.38916 .08568 L
.39136 .08565 L
.3926 .08564 L
Mistroke
.39392 .08562 L
.39467 .08562 L
.39538 .08562 L
.39601 .08561 L
.3967 .08561 L
.39799 .08561 L
.39864 .08561 L
.39934 .08561 L
.4006 .08562 L
.40177 .08563 L
.40308 .08564 L
.40451 .08566 L
.40709 .0857 L
.40961 .08575 L
.41194 .08581 L
.41721 .086 L
.42282 .08626 L
.43221 .08689 L
.43749 .08735 L
.44233 .08785 L
.45124 .08901 L
.46062 .09063 L
.47019 .09283 L
.4804 .09599 L
.49004 .09994 L
.49878 .10452 L
.51962 .11862 L
.52877 .12504 L
.53881 .13108 L
.54348 .13335 L
.54849 .13534 L
.55322 .13679 L
.55754 .13776 L
.56006 .13817 L
.5624 .13846 L
.56362 .13857 L
.56497 .13867 L
.56564 .13871 L
.56638 .13874 L
.5677 .13878 L
.56887 .1388 L
.57014 .13879 L
.57079 .13878 L
.57148 .13876 L
.57272 .13871 L
.57396 .13864 L
.57514 .13855 L
.57733 .13835 L
.58195 .13774 L
.58704 .13683 L
Mistroke
.59732 .13436 L
.61577 .1286 L
.65607 .11476 L
.69487 .10378 L
.71601 .09924 L
.73611 .09583 L
.75593 .09324 L
.77432 .09144 L
.79486 .08998 L
.81347 .08904 L
.85356 .08754 L
.89213 .08606 L
.93315 .08436 L
.97266 .08293 L
.97619 .08282 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.03279 .05621 L
.03793 .0759 L
.04262 .08952 L
.04517 .09495 L
.04758 .09881 L
.0489 .10043 L
.05012 .10164 L
.05146 .10266 L
.0522 .1031 L
.05288 .10342 L
.05401 .10383 L
.05523 .10407 L
.05636 .10415 L
.05743 .10409 L
.05868 .10389 L
.05983 .10358 L
.0611 .10314 L
.06244 .10255 L
.06791 .09928 L
.07382 .0948 L
.08454 .08586 L
.10458 .07008 L
.12413 .05752 L
.14558 .04693 L
.166 .0394 L
.18507 .0341 L
.20542 .02986 L
.22398 .02697 L
.24306 .02471 L
.26382 .02289 L
.2836 .02162 L
.30461 .02062 L
.32408 .01995 L
.34236 .01947 L
.36254 .01908 L
.38104 .01882 L
.39997 .01862 L
.41069 .01854 L
.42067 .01847 L
.43119 .01842 L
.44113 .01838 L
.45005 .01835 L
.45504 .01833 L
.45971 .01832 L
.46466 .01831 L
.46918 .01831 L
.4742 .0183 L
.47696 .0183 L
.47834 .0183 L
Mistroke
.47959 .0183 L
.48089 .0183 L
.48212 .0183 L
.48341 .0183 L
.48414 .0183 L
.48481 .0183 L
.48594 .0183 L
.48717 .0183 L
.48846 .0183 L
.48966 .0183 L
.49108 .0183 L
.49243 .0183 L
.49496 .0183 L
.49768 .0183 L
.50063 .0183 L
.52006 .01833 L
.53037 .01834 L
.53616 .01835 L
.53891 .01835 L
.54147 .01835 L
.54375 .01835 L
.54503 .01835 L
.54619 .01835 L
.54747 .01835 L
.54819 .01835 L
.54885 .01835 L
.55007 .01835 L
.55136 .01835 L
.55259 .01835 L
.55329 .01835 L
.55392 .01835 L
.55632 .01835 L
.55765 .01835 L
.55911 .01835 L
.56176 .01835 L
.56655 .01834 L
.57164 .01834 L
.58079 .01832 L
.60023 .01828 L
.6185 .01824 L
.65716 .01815 L
.67678 .01812 L
.69827 .01809 L
.71877 .01806 L
.73786 .01805 L
.74836 .01804 L
.75829 .01803 L
.76714 .01803 L
.77687 .01803 L
.78658 .01802 L
Mistroke
.79189 .01802 L
.79686 .01802 L
.79924 .01802 L
.8015 .01802 L
.80356 .01802 L
.80575 .01802 L
.80699 .01802 L
.80812 .01802 L
.80925 .01802 L
.81032 .01802 L
.81157 .01802 L
.81272 .01802 L
.81398 .01802 L
.81461 .01802 L
.81531 .01802 L
.81661 .01802 L
.81782 .01802 L
.82055 .01802 L
.82296 .01802 L
.82552 .01802 L
.83483 .01802 L
.84478 .01802 L
.85575 .01803 L
.87674 .01803 L
.88593 .01803 L
.89597 .01803 L
.9007 .01803 L
.90575 .01803 L
.91011 .01803 L
.91483 .01803 L
.91762 .01803 L
.91884 .01803 L
.92018 .01803 L
.92145 .01803 L
.92264 .01803 L
.92389 .01803 L
.92459 .01803 L
.92523 .01803 L
.92644 .01803 L
.92755 .01803 L
.92878 .01803 L
.93008 .01803 L
.93133 .01803 L
.9325 .01803 L
.93468 .01803 L
.93936 .01803 L
.94448 .01803 L
.94983 .01803 L
.95481 .01803 L
.9733 .01803 L
Mistroke
.97619 .01803 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.03279 .05622 L
.03793 .07599 L
.04262 .0898 L
.04517 .0954 L
.04758 .09946 L
.05012 .10253 L
.05156 .10375 L
.05288 .10459 L
.05402 .10511 L
.05509 .10544 L
.05626 .10564 L
.05752 .10569 L
.05884 .10558 L
.06009 .10533 L
.06122 .10501 L
.06244 .10456 L
.0653 .10319 L
.06799 .10157 L
.07302 .09799 L
.08429 .08882 L
.10458 .07277 L
.12296 .06064 L
.14313 .05015 L
.16307 .04224 L
.18413 .03597 L
.20364 .03164 L
.22456 .02817 L
.2458 .0256 L
.26592 .0238 L
.28583 .02249 L
.30425 .02157 L
.32291 .02088 L
.34352 .02031 L
.36286 .01992 L
.38372 .01961 L
.40376 .0194 L
.41384 .01933 L
.42486 .01926 L
.43513 .01921 L
.44447 .01917 L
.44964 .01916 L
.45525 .01914 L
.45782 .01914 L
.46054 .01913 L
.46287 .01913 L
.46542 .01913 L
.46673 .01913 L
.46795 .01913 L
.46921 .01913 L
Mistroke
.47035 .01912 L
.47147 .01912 L
.47253 .01912 L
.47365 .01912 L
.47486 .01912 L
.47608 .01912 L
.47678 .01912 L
.47743 .01912 L
.47874 .01912 L
.47947 .01912 L
.48014 .01912 L
.48263 .01913 L
.48499 .01913 L
.48956 .01913 L
.49377 .01914 L
.50331 .01916 L
.5236 .01922 L
.53353 .01925 L
.53788 .01925 L
.54262 .01926 L
.54485 .01927 L
.54722 .01927 L
.54947 .01927 L
.5515 .01927 L
.5527 .01927 L
.5538 .01927 L
.55502 .01927 L
.5563 .01927 L
.55742 .01927 L
.55846 .01927 L
.5596 .01927 L
.56083 .01927 L
.56214 .01927 L
.56335 .01927 L
.56609 .01927 L
.56851 .01927 L
.57108 .01926 L
.58043 .01925 L
.58978 .01923 L
.59987 .0192 L
.61815 .01914 L
.65925 .019 L
.67976 .01895 L
.69885 .01891 L
.71842 .01887 L
.73692 .01884 L
.74672 .01883 L
.75735 .01882 L
.77593 .01881 L
.78538 .01881 L
Mistroke
.79579 .0188 L
.80665 .0188 L
.81682 .0188 L
.82721 .0188 L
.83708 .0188 L
.85561 .01879 L
.86521 .01879 L
.87543 .01879 L
.89383 .01879 L
.90412 .01879 L
.91525 .01879 L
.92576 .01879 L
.93543 .01879 L
.95427 .01878 L
.97494 .01878 L
.97619 .01878 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.04262 .09865 L
.0522 .13373 L
.06244 .16389 L
.0679 .1765 L
.07286 .18582 L
.07784 .19313 L
.08255 .19819 L
.08522 .2003 L
.08668 .20124 L
.08805 .20197 L
.08931 .20254 L
.09046 .20296 L
.09174 .20333 L
.09246 .20349 L
.09312 .2036 L
.09382 .2037 L
.09457 .20377 L
.09527 .20381 L
.09593 .20382 L
.09669 .20379 L
.0974 .20375 L
.09817 .20366 L
.09899 .20354 L
.10037 .20325 L
.10166 .20291 L
.10458 .20183 L
.10718 .20057 L
.10959 .19918 L
.11503 .19534 L
.12493 .18654 L
.14349 .16694 L
.18275 .12688 L
.22051 .09848 L
.23985 .08783 L
.26071 .07879 L
.28075 .07208 L
.30185 .06668 L
.32159 .06289 L
.33996 .06022 L
.35048 .05901 L
.36041 .05805 L
.379 .05669 L
.38872 .05617 L
.39404 .05594 L
.39902 .05577 L
.40361 .05563 L
.4078 .05553 L
.41246 .05544 L
.41503 .05541 L
Mistroke
.41747 .05538 L
.41872 .05537 L
.42007 .05536 L
.42134 .05536 L
.42251 .05536 L
.42357 .05535 L
.42474 .05535 L
.42595 .05536 L
.42708 .05536 L
.42772 .05536 L
.42841 .05537 L
.42967 .05538 L
.43202 .0554 L
.43477 .05544 L
.43731 .05548 L
.44156 .05558 L
.44624 .05572 L
.45113 .05592 L
.45571 .05614 L
.46557 .05678 L
.47052 .0572 L
.47594 .05775 L
.48553 .05898 L
.49445 .06048 L
.51495 .06531 L
.53355 .07042 L
.54289 .07258 L
.548 .07354 L
.55277 .07428 L
.55794 .07489 L
.56067 .07514 L
.56361 .07535 L
.56489 .07542 L
.56629 .07549 L
.56752 .07554 L
.56882 .07558 L
.57 .07561 L
.5713 .07563 L
.57248 .07564 L
.57358 .07564 L
.57476 .07564 L
.57601 .07562 L
.57719 .0756 L
.57827 .07558 L
.58091 .07549 L
.5834 .07538 L
.58836 .07508 L
.59374 .07464 L
.61224 .07254 L
.65313 .06674 L
Mistroke
.67346 .06408 L
.6925 .06195 L
.71191 .06017 L
.73035 .05886 L
.74004 .05832 L
.75061 .05784 L
.75527 .05767 L
.76023 .05752 L
.76456 .0574 L
.76914 .05731 L
.7717 .05726 L
.77451 .05723 L
.77574 .05721 L
.77706 .0572 L
.7783 .05719 L
.77944 .05718 L
.78012 .05718 L
.78087 .05718 L
.78163 .05717 L
.78243 .05717 L
.78313 .05717 L
.78389 .05717 L
.78461 .05717 L
.78526 .05717 L
.7865 .05718 L
.7872 .05718 L
.78785 .05718 L
.78917 .05719 L
.79057 .0572 L
.79318 .05723 L
.79601 .05727 L
.80114 .05738 L
.80614 .05753 L
.81075 .0577 L
.82045 .05817 L
.82952 .05874 L
.85017 .0605 L
.88901 .06434 L
.89915 .06515 L
.90451 .06551 L
.9102 .06585 L
.91568 .06611 L
.92064 .0663 L
.92304 .06638 L
.92562 .06645 L
.92808 .0665 L
.93031 .06654 L
.93269 .06657 L
.93401 .06659 L
.93525 .0666 L
Mistroke
.93639 .0666 L
.93745 .06661 L
.93862 .06661 L
.93985 .06661 L
.94109 .06661 L
.94178 .06661 L
.94242 .0666 L
.94365 .0666 L
.94482 .06659 L
.94744 .06656 L
.9503 .06651 L
.95559 .0664 L
.96123 .06624 L
.97138 .06585 L
.97619 .06563 L
Mfstroke
.435 1 0 r
.02381 .01472 m
.04262 .09852 L
.0522 .13336 L
.06244 .16355 L
.0679 .17653 L
.07286 .18651 L
.0779 .19495 L
.08255 .20128 L
.08798 .20702 L
.09079 .20935 L
.09388 .21144 L
.09638 .21279 L
.09907 .21393 L
.10056 .21442 L
.10192 .21479 L
.10329 .21509 L
.10458 .21531 L
.10578 .21546 L
.10708 .21556 L
.10826 .2156 L
.10934 .2156 L
.11052 .21555 L
.11182 .21545 L
.11247 .21538 L
.11316 .2153 L
.11442 .2151 L
.11688 .21461 L
.11921 .214 L
.12357 .21253 L
.13349 .20789 L
.14429 .20143 L
.18507 .17291 L
.22434 .1489 L
.26209 .13218 L
.28143 .1259 L
.30229 .12062 L
.32233 .11684 L
.33241 .11536 L
.34343 .11404 L
.35371 .11309 L
.36304 .11243 L
.36821 .11216 L
.37094 .11204 L
.37382 .11193 L
.37634 .11185 L
.37911 .11178 L
.38033 .11176 L
.38163 .11174 L
.38285 .11172 L
.38399 .1117 L
Mistroke
.38463 .1117 L
.38533 .11169 L
.38654 .11169 L
.38723 .11168 L
.38795 .11168 L
.38925 .11168 L
.39045 .11169 L
.39157 .1117 L
.3928 .11171 L
.39412 .11173 L
.39709 .11178 L
.3999 .11185 L
.40517 .11205 L
.41017 .1123 L
.4148 .1126 L
.41984 .11301 L
.42527 .11355 L
.43492 .11479 L
.44397 .11635 L
.45473 .11885 L
.46459 .12193 L
.47442 .12604 L
.48355 .13108 L
.49357 .13832 L
.50426 .14823 L
.52421 .17054 L
.53471 .18148 L
.54045 .18651 L
.54581 .19043 L
.55101 .19347 L
.55574 .19558 L
.55845 .1965 L
.56101 .1972 L
.56371 .19775 L
.56524 .19798 L
.56666 .19815 L
.56775 .19824 L
.56893 .19831 L
.57005 .19835 L
.57107 .19836 L
.57221 .19835 L
.57345 .1983 L
.57475 .19822 L
.57596 .19811 L
.57846 .19781 L
.58074 .19743 L
.58585 .19627 L
.59069 .19484 L
.59581 .193 L
.60501 .18909 L
Mistroke
.6258 .17854 L
.66365 .15875 L
.68471 .14928 L
.70396 .14199 L
.72408 .13577 L
.74275 .13123 L
.76175 .12769 L
.77243 .12614 L
.78248 .12493 L
.79235 .12396 L
.80302 .12311 L
.82163 .12199 L
.84158 .12112 L
.85175 .12077 L
.86265 .12044 L
.87294 .12018 L
.88231 .12 L
.88682 .11993 L
.89173 .11987 L
.89636 .11983 L
.89845 .11981 L
.90064 .1198 L
.9018 .11979 L
.90306 .11979 L
.90423 .11979 L
.90528 .11978 L
.90654 .11978 L
.90722 .11978 L
.90787 .11978 L
.90903 .11978 L
.91028 .11978 L
.91137 .11978 L
.91257 .11978 L
.91382 .11978 L
.91499 .11979 L
.91708 .11979 L
.91932 .11981 L
.92485 .11984 L
.93009 .11989 L
.93993 .12002 L
.95875 .12034 L
.97619 .12068 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.03279 .05677 L
.04262 .09677 L
.04758 .11365 L
.05288 .1289 L
.05785 .14046 L
.06244 .14884 L
.06788 .15609 L
.07075 .15883 L
.07379 .16101 L
.07505 .16172 L
.07642 .16235 L
.0776 .16279 L
.07889 .16317 L
.07967 .16335 L
.08039 .16348 L
.08108 .16358 L
.08182 .16366 L
.08255 .16371 L
.08323 .16372 L
.08451 .16369 L
.08567 .1636 L
.08695 .16342 L
.08828 .16316 L
.08953 .16285 L
.09176 .16215 L
.09415 .16121 L
.09961 .15845 L
.10458 .15536 L
.14443 .12399 L
.18275 .09781 L
.20253 .08754 L
.22354 .07881 L
.24323 .07239 L
.26129 .06773 L
.28063 .06381 L
.30149 .0606 L
.32041 .05842 L
.33126 .05743 L
.34111 .05668 L
.36073 .05554 L
.3715 .0551 L
.37635 .05494 L
.38168 .0548 L
.38636 .05469 L
.3914 .0546 L
.39418 .05456 L
.39671 .05454 L
.39927 .05451 L
.40054 .0545 L
Mistroke
.40169 .0545 L
.40276 .05449 L
.40391 .05449 L
.40513 .05449 L
.40627 .05449 L
.40735 .05449 L
.40848 .05449 L
.40945 .05449 L
.41052 .05449 L
.41178 .0545 L
.41292 .0545 L
.4155 .05453 L
.41788 .05455 L
.42014 .05458 L
.42475 .05466 L
.42982 .05477 L
.43512 .05493 L
.44009 .05511 L
.44897 .05554 L
.45852 .05617 L
.46812 .05702 L
.4786 .05827 L
.48955 .06004 L
.49972 .0622 L
.51849 .06723 L
.52837 .06995 L
.53881 .07238 L
.54412 .07334 L
.54995 .07416 L
.5525 .07444 L
.55525 .07469 L
.55784 .07488 L
.5602 .07501 L
.56145 .07506 L
.56277 .07511 L
.5639 .07514 L
.56516 .07516 L
.56585 .07517 L
.56649 .07518 L
.5672 .07518 L
.56794 .07518 L
.56918 .07518 L
.56989 .07517 L
.57055 .07516 L
.57183 .07514 L
.57303 .07511 L
.57529 .07503 L
.57772 .07492 L
.58036 .07478 L
.58981 .07403 L
Mistroke
.60022 .07291 L
.62125 .07013 L
.66156 .0646 L
.70035 .06039 L
.7215 .05868 L
.74159 .05742 L
.76141 .05648 L
.77981 .05585 L
.79038 .05556 L
.80034 .05535 L
.81896 .05503 L
.85753 .05451 L
.89855 .05394 L
.93806 .0534 L
.97605 .05298 L
.97619 .05298 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.04262 .09891 L
.06244 .16891 L
.07216 .19591 L
.08255 .21958 L
.09396 .2397 L
.09948 .24737 L
.10458 .25334 L
.10944 .2581 L
.1148 .26234 L
.12018 .26562 L
.12316 .26705 L
.12589 .26813 L
.12828 .2689 L
.13089 .26957 L
.13233 .26987 L
.13366 .27009 L
.13501 .27028 L
.13628 .27042 L
.13747 .27051 L
.13876 .27058 L
.13992 .27061 L
.141 .27061 L
.14216 .27059 L
.14344 .27053 L
.14409 .27049 L
.14478 .27044 L
.14603 .27032 L
.14859 .26999 L
.15131 .26952 L
.1562 .26839 L
.16146 .26681 L
.16727 .2647 L
.18739 .25528 L
.22759 .23321 L
.26628 .21459 L
.28632 .20701 L
.30742 .20067 L
.31696 .19836 L
.32716 .19626 L
.33671 .19464 L
.34553 .19343 L
.35577 .19238 L
.36116 .19198 L
.36391 .19182 L
.36687 .19167 L
.36946 .19157 L
.37183 .19151 L
.37297 .19148 L
.37421 .19146 L
Mistroke
.37538 .19144 L
.37647 .19143 L
.37713 .19143 L
.37785 .19142 L
.37915 .19143 L
.38042 .19143 L
.38158 .19145 L
.38284 .19146 L
.38423 .19149 L
.38702 .19157 L
.38954 .19168 L
.39228 .19182 L
.39725 .19216 L
.4021 .19259 L
.40657 .1931 L
.41673 .19464 L
.4275 .19695 L
.43689 .19966 L
.44701 .20348 L
.45656 .20818 L
.4653 .21367 L
.47513 .22156 L
.48426 .23094 L
.50498 .26042 L
.52375 .29278 L
.53363 .30844 L
.54408 .32212 L
.54938 .32767 L
.55521 .33262 L
.56051 .33606 L
.56546 .33838 L
.56807 .33927 L
.57055 .33991 L
.57163 .34012 L
.57277 .34031 L
.57403 .34047 L
.57519 .34058 L
.57642 .34064 L
.57711 .34066 L
.57775 .34067 L
.57892 .34065 L
.58015 .34058 L
.5808 .34053 L
.5815 .34047 L
.58276 .34031 L
.58426 .34007 L
.58563 .33981 L
.59046 .3385 L
.59559 .33655 L
.60479 .33182 L
Mistroke
.62558 .31703 L
.66343 .2852 L
.68449 .26885 L
.70374 .25599 L
.72386 .24506 L
.74253 .2373 L
.75173 .23432 L
.76153 .23176 L
.76713 .23058 L
.7724 .22966 L
.7771 .22898 L
.78226 .22841 L
.7847 .2282 L
.78731 .22802 L
.78978 .22788 L
.79203 .22779 L
.79335 .22775 L
.79457 .22773 L
.79521 .22772 L
.79591 .22771 L
.79664 .2277 L
.79733 .2277 L
.79859 .22771 L
.79975 .22772 L
.80102 .22774 L
.80165 .22776 L
.80235 .22778 L
.80478 .22787 L
.80698 .22798 L
.81193 .22834 L
.81651 .2288 L
.82083 .22935 L
.83056 .23101 L
.84086 .23342 L
.85932 .23948 L
.8789 .24819 L
.89722 .25788 L
.93607 .27911 L
.97619 .29534 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.04262 .0989 L
.06244 .16862 L
.07216 .19527 L
.08255 .21843 L
.09396 .23787 L
.09948 .2452 L
.10458 .25087 L
.10944 .25534 L
.1148 .2593 L
.12018 .26232 L
.12316 .26362 L
.12589 .26459 L
.12828 .26528 L
.13089 .26587 L
.13233 .26612 L
.13366 .26631 L
.13493 .26645 L
.13563 .26652 L
.13628 .26656 L
.13755 .26664 L
.13821 .26666 L
.13891 .26668 L
.1401 .26668 L
.14139 .26665 L
.14255 .2666 L
.14379 .26652 L
.14496 .26642 L
.14603 .2663 L
.14831 .266 L
.15083 .26556 L
.15594 .26441 L
.16511 .26154 L
.18587 .25251 L
.22607 .23177 L
.26476 .21423 L
.2848 .20708 L
.3059 .2011 L
.31545 .19893 L
.32564 .19695 L
.3352 .19543 L
.34401 .19431 L
.35425 .19335 L
.35965 .19299 L
.3624 .19284 L
.36536 .19272 L
.36795 .19263 L
.37031 .19257 L
.37145 .19256 L
.37269 .19254 L
Mistroke
.37386 .19253 L
.37495 .19252 L
.37562 .19252 L
.37633 .19253 L
.37763 .19253 L
.3789 .19255 L
.38006 .19256 L
.38133 .19259 L
.38271 .19262 L
.38551 .19271 L
.38803 .19282 L
.39076 .19297 L
.39574 .19333 L
.40058 .19378 L
.40506 .19429 L
.41521 .19583 L
.42598 .19813 L
.43538 .20081 L
.44549 .20457 L
.45504 .20918 L
.46379 .21454 L
.47362 .22226 L
.48275 .23141 L
.50346 .26043 L
.52224 .29291 L
.53212 .30888 L
.54256 .32299 L
.54787 .32878 L
.55369 .33399 L
.55899 .33767 L
.56395 .34022 L
.56656 .34122 L
.56903 .34196 L
.57125 .34246 L
.57251 .34267 L
.57367 .34283 L
.57491 .34295 L
.57608 .34302 L
.57735 .34305 L
.57807 .34305 L
.57873 .34303 L
.57998 .34297 L
.58069 .34292 L
.58135 .34286 L
.58268 .3427 L
.58411 .34247 L
.58669 .34194 L
.58943 .34121 L
.59434 .33948 L
.59962 .33709 L
Mistroke
.60543 .33391 L
.62558 .31977 L
.66588 .28662 L
.70468 .25928 L
.72582 .24806 L
.73555 .24386 L
.74592 .24004 L
.75632 .2369 L
.76574 .23465 L
.77029 .23376 L
.77521 .23295 L
.77952 .23236 L
.78413 .23186 L
.78671 .23163 L
.78905 .23146 L
.79144 .23133 L
.79365 .23123 L
.79489 .23119 L
.79622 .23115 L
.7969 .23114 L
.79754 .23113 L
.79825 .23112 L
.79901 .23111 L
.8003 .23111 L
.80095 .23111 L
.80166 .23112 L
.80292 .23114 L
.80409 .23116 L
.8054 .2312 L
.80683 .23125 L
.80943 .23137 L
.81195 .23152 L
.81428 .2317 L
.81956 .23221 L
.82516 .23293 L
.8346 .23458 L
.84474 .23697 L
.86306 .24298 L
.88425 .25246 L
.90436 .2632 L
.94262 .2842 L
.97619 .29883 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.04262 .09891 L
.06244 .16876 L
.07286 .19707 L
.08255 .21816 L
.0932 .23554 L
.09916 .24274 L
.10458 .24781 L
.10941 .25119 L
.11185 .25252 L
.11454 .25369 L
.11682 .25447 L
.11808 .25482 L
.11928 .25509 L
.12039 .2553 L
.1216 .25547 L
.1227 .25558 L
.12373 .25565 L
.12503 .25569 L
.12577 .25569 L
.12644 .25567 L
.12769 .2556 L
.129 .25548 L
.13018 .25533 L
.13128 .25515 L
.13379 .25461 L
.13649 .25385 L
.13896 .253 L
.14451 .25061 L
.15442 .24494 L
.16359 .23852 L
.18435 .22179 L
.22362 .18988 L
.26137 .16529 L
.28072 .1556 L
.30158 .14723 L
.32162 .14104 L
.33182 .13851 L
.34271 .13625 L
.35306 .13449 L
.36246 .13322 L
.3719 .13223 L
.37651 .13185 L
.38082 .13156 L
.38545 .13132 L
.38791 .13122 L
.39054 .13113 L
.39186 .1311 L
.3933 .13107 L
.39466 .13105 L
Mistroke
.39592 .13103 L
.39717 .13102 L
.3983 .13102 L
.39961 .13102 L
.40084 .13103 L
.40191 .13104 L
.40309 .13105 L
.40431 .13108 L
.40546 .1311 L
.40751 .13116 L
.40971 .13124 L
.41472 .1315 L
.41929 .13182 L
.42411 .13226 L
.42923 .13284 L
.43841 .13425 L
.44829 .13636 L
.45919 .1396 L
.46931 .14377 L
.47857 .1489 L
.48875 .15643 L
.49944 .16698 L
.5376 .21872 L
.54772 .22999 L
.55725 .2378 L
.56253 .24087 L
.56531 .24214 L
.56824 .24322 L
.57072 .24393 L
.57203 .24424 L
.57344 .24451 L
.57473 .24471 L
.57591 .24485 L
.57709 .24496 L
.57822 .24503 L
.57935 .24507 L
.58058 .24507 L
.58173 .24504 L
.5828 .24498 L
.58397 .24488 L
.58526 .24474 L
.58785 .24435 L
.59042 .24382 L
.59316 .24312 L
.5981 .24151 L
.60774 .23731 L
.61651 .23256 L
.65646 .20656 L
.6949 .18406 L
.71475 .17528 L
Mistroke
.72489 .17167 L
.73578 .16847 L
.74102 .16721 L
.746 .16617 L
.75084 .16532 L
.75533 .16469 L
.75957 .16423 L
.76194 .16403 L
.76409 .16389 L
.76532 .16383 L
.76645 .16379 L
.76769 .16375 L
.76901 .16373 L
.77015 .16372 L
.77122 .16373 L
.77239 .16374 L
.77364 .16378 L
.77486 .16382 L
.7762 .16389 L
.77893 .16409 L
.78145 .16434 L
.78382 .16465 L
.78915 .16558 L
.79489 .16699 L
.80001 .16864 L
.8054 .1708 L
.81502 .17583 L
.82457 .18236 L
.83478 .19097 L
.85315 .20979 L
.87308 .23192 L
.88357 .24279 L
.89467 .25289 L
.90458 .26032 L
.90984 .26356 L
.91548 .26649 L
.92067 .26866 L
.9254 .2702 L
.92767 .2708 L
.93015 .27135 L
.93251 .27176 L
.93467 .27206 L
.93592 .27219 L
.93723 .27231 L
.93856 .27239 L
.93931 .27242 L
.94 .27245 L
.94127 .27247 L
.94243 .27247 L
.94307 .27246 L
Mistroke
.94376 .27244 L
.94502 .27239 L
.94615 .27232 L
.94739 .27222 L
.94989 .27196 L
.95222 .27163 L
.95439 .27125 L
.95967 .27008 L
.96451 .2687 L
.97539 .26468 L
.97619 .26434 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.04262 .09833 L
.0522 .13239 L
.06244 .16064 L
.0679 .17205 L
.07286 .1803 L
.07784 .18665 L
.08255 .19101 L
.08522 .19281 L
.08805 .19426 L
.09046 .19513 L
.09183 .19548 L
.09312 .19573 L
.09382 .19583 L
.09459 .19591 L
.09532 .19596 L
.096 .19599 L
.09728 .19599 L
.09799 .19595 L
.09864 .1959 L
.0994 .19583 L
.10011 .19573 L
.1017 .19546 L
.1031 .19514 L
.10458 .19472 L
.10954 .19286 L
.11406 .1906 L
.12422 .18409 L
.14255 .16963 L
.1824 .13787 L
.22073 .11428 L
.2405 .10515 L
.26151 .09741 L
.28098 .09179 L
.29926 .08766 L
.31944 .08417 L
.33795 .08182 L
.3471 .08091 L
.35687 .08012 L
.36759 .07944 L
.37757 .07899 L
.3829 .07881 L
.38781 .07869 L
.39038 .07864 L
.39321 .07861 L
.39463 .07859 L
.39541 .07858 L
.39616 .07858 L
.39685 .07858 L
.3976 .07857 L
Mistroke
.39892 .07857 L
.39957 .07857 L
.40029 .07857 L
.40157 .07857 L
.40283 .07857 L
.40398 .07858 L
.40523 .07859 L
.40661 .07861 L
.40937 .07865 L
.4118 .07869 L
.41439 .07875 L
.41907 .0789 L
.42437 .07912 L
.42927 .07938 L
.43454 .07972 L
.44035 .08019 L
.45012 .08122 L
.46048 .08272 L
.4706 .08472 L
.47987 .08716 L
.49004 .09074 L
.50074 .0957 L
.52074 .10779 L
.52946 .11323 L
.5389 .11834 L
.54416 .12067 L
.54901 .12242 L
.55365 .12374 L
.55855 .12477 L
.56104 .12514 L
.56241 .12531 L
.56371 .12545 L
.56492 .12555 L
.56623 .12564 L
.56743 .1257 L
.56854 .12574 L
.56984 .12576 L
.57106 .12577 L
.57176 .12576 L
.57241 .12575 L
.57311 .12574 L
.57386 .12571 L
.57525 .12565 L
.57656 .12557 L
.57951 .12533 L
.58213 .12505 L
.58455 .12473 L
.59002 .12383 L
.59994 .1217 L
.61852 .11662 L
Mistroke
.65789 .10483 L
.69575 .09533 L
.71517 .09153 L
.73606 .08825 L
.75721 .0857 L
.7773 .08389 L
.79712 .08261 L
.81551 .08174 L
.85466 .08039 L
.89627 .07893 L
.93635 .07742 L
.97492 .07612 L
.97619 .07608 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.04262 .09832 L
.0522 .13234 L
.06244 .16045 L
.0679 .17173 L
.07286 .17982 L
.07784 .18596 L
.08255 .19008 L
.08522 .19174 L
.08668 .19246 L
.08805 .19302 L
.08931 .19343 L
.09046 .19374 L
.09174 .19399 L
.09244 .19409 L
.09312 .19416 L
.09384 .19422 L
.09449 .19424 L
.09525 .19425 L
.09596 .19423 L
.09723 .19414 L
.09794 .19406 L
.0986 .19396 L
.09998 .19371 L
.10151 .19334 L
.10458 .19234 L
.10982 .18995 L
.11478 .18703 L
.12409 .18031 L
.145 .16227 L
.18333 .12988 L
.20272 .11634 L
.22412 .10397 L
.2446 .09447 L
.26338 .08749 L
.28273 .08179 L
.30359 .07705 L
.32251 .07379 L
.33335 .07229 L
.34321 .07115 L
.36282 .0694 L
.3736 .06872 L
.37844 .06847 L
.38377 .06824 L
.38846 .06807 L
.39349 .06793 L
.39627 .06786 L
.39881 .06781 L
.40136 .06778 L
.40263 .06776 L
Mistroke
.40378 .06775 L
.40485 .06774 L
.406 .06773 L
.40722 .06772 L
.40837 .06772 L
.40944 .06772 L
.41058 .06772 L
.41155 .06772 L
.41261 .06772 L
.41387 .06773 L
.41502 .06774 L
.41634 .06775 L
.41759 .06776 L
.41982 .0678 L
.42224 .06784 L
.4271 .06796 L
.43166 .06811 L
.43666 .06833 L
.44205 .06863 L
.4474 .06899 L
.45302 .06946 L
.46307 .07055 L
.47264 .07198 L
.48285 .07405 L
.49249 .07668 L
.50123 .07972 L
.52207 .08923 L
.53122 .09366 L
.54127 .09795 L
.54594 .09962 L
.55094 .10112 L
.55527 .10218 L
.55999 .10307 L
.56275 .10347 L
.5653 .10377 L
.56774 .10398 L
.56898 .10407 L
.57034 .10414 L
.57156 .10419 L
.57268 .10422 L
.57391 .10425 L
.57521 .10426 L
.57634 .10425 L
.57739 .10424 L
.57855 .10421 L
.57978 .10417 L
.58101 .10412 L
.58237 .10404 L
.5851 .10385 L
.59001 .10338 L
Mistroke
.59574 .10264 L
.60111 .1018 L
.62125 .09773 L
.66004 .08862 L
.70129 .08024 L
.72189 .07698 L
.74101 .07452 L
.75951 .07263 L
.77923 .07108 L
.78952 .07044 L
.80065 .06987 L
.82083 .06907 L
.84078 .06849 L
.86185 .068 L
.89984 .0671 L
.94029 .06598 L
.97619 .06494 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.03279 .05609 L
.03793 .0754 L
.04262 .08836 L
.04517 .09336 L
.04758 .0968 L
.0489 .09819 L
.05012 .09919 L
.05146 .10001 L
.05214 .10031 L
.05288 .10057 L
.05412 .10085 L
.05526 .10094 L
.05657 .10087 L
.05782 .10065 L
.05897 .10034 L
.06003 .09997 L
.06244 .09888 L
.06795 .09544 L
.07314 .09153 L
.08284 .08366 L
.10458 .06712 L
.12296 .05578 L
.14313 .04609 L
.16307 .03885 L
.18413 .03314 L
.20364 .02922 L
.22456 .0261 L
.2458 .02379 L
.26592 .02219 L
.28583 .02101 L
.30425 .0202 L
.32291 .01958 L
.34352 .01908 L
.36286 .01873 L
.38372 .01846 L
.40376 .01827 L
.41384 .0182 L
.42486 .01814 L
.43495 .01809 L
.44447 .01805 L
.44974 .01804 L
.45545 .01802 L
.4606 .01801 L
.46542 .018 L
.47036 .01799 L
.47488 .01799 L
.47746 .01799 L
.4799 .01798 L
.48248 .01798 L
Mistroke
.48394 .01798 L
.48465 .01798 L
.48529 .01798 L
.48593 .01798 L
.48662 .01798 L
.48732 .01798 L
.48805 .01798 L
.4887 .01798 L
.48939 .01798 L
.49064 .01798 L
.49195 .01798 L
.49318 .01798 L
.49429 .01798 L
.49549 .01798 L
.49822 .01798 L
.50113 .01799 L
.50634 .01799 L
.51596 .018 L
.52607 .01801 L
.53025 .01801 L
.53471 .01802 L
.53727 .01802 L
.5396 .01802 L
.54194 .01802 L
.54414 .01802 L
.54526 .01802 L
.5465 .01802 L
.54778 .01802 L
.54899 .01802 L
.55011 .01802 L
.55114 .01802 L
.55232 .01802 L
.55345 .01802 L
.55466 .01802 L
.55595 .01802 L
.55827 .01802 L
.56077 .01802 L
.56353 .01802 L
.5687 .01801 L
.57429 .01801 L
.5844 .01799 L
.6255 .01791 L
.6651 .01784 L
.68504 .01781 L
.70317 .01778 L
.72276 .01777 L
.73365 .01776 L
.7437 .01775 L
.75282 .01775 L
.76286 .01774 L
Mistroke
.77296 .01774 L
.77844 .01774 L
.78365 .01774 L
.7885 .01773 L
.7938 .01773 L
.79613 .01773 L
.79861 .01773 L
.80093 .01773 L
.80307 .01773 L
.80579 .01773 L
.80721 .01773 L
.80794 .01773 L
.80872 .01773 L
.81003 .01773 L
.81125 .01773 L
.812 .01773 L
.8127 .01773 L
.81334 .01773 L
.81403 .01773 L
.81522 .01773 L
.81653 .01773 L
.8179 .01773 L
.81919 .01773 L
.82148 .01773 L
.82396 .01773 L
.82892 .01773 L
.83354 .01773 L
.84401 .01774 L
.86512 .01774 L
.88387 .01774 L
.89374 .01774 L
.90418 .01774 L
.90948 .01774 L
.91229 .01774 L
.9153 .01774 L
.91807 .01774 L
.92059 .01774 L
.92181 .01774 L
.92313 .01774 L
.92438 .01775 L
.92554 .01775 L
.92681 .01775 L
.92753 .01775 L
.92819 .01775 L
.92939 .01775 L
.93067 .01775 L
.93182 .01775 L
.93288 .01774 L
.93406 .01774 L
.93531 .01774 L
Mistroke
.93811 .01774 L
.94075 .01774 L
.9457 .01774 L
.95339 .01774 L
.96155 .01774 L
.97619 .01774 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.04262 .09891 L
.06244 .16886 L
.07216 .1957 L
.08255 .219 L
.08852 .22991 L
.09396 .23833 L
.09911 .24504 L
.10458 .25084 L
.10932 .25484 L
.11454 .25822 L
.11682 .25937 L
.11928 .2604 L
.12159 .26118 L
.12373 .26174 L
.12512 .26203 L
.12639 .26224 L
.12779 .26242 L
.12856 .26249 L
.12929 .26254 L
.12993 .26257 L
.13061 .2626 L
.13183 .26261 L
.13314 .26257 L
.13389 .26253 L
.13458 .26248 L
.13587 .26236 L
.13709 .2622 L
.13937 .26182 L
.14183 .26127 L
.14451 .26053 L
.15391 .25689 L
.16428 .25138 L
.18529 .23737 L
.22549 .20845 L
.26418 .1853 L
.28422 .176 L
.30532 .1682 L
.32506 .16261 L
.34343 .1588 L
.35395 .15717 L
.36389 .15601 L
.37281 .15526 L
.37784 .15496 L
.38022 .15485 L
.38248 .15476 L
.38364 .15473 L
.38492 .15469 L
.38609 .15467 L
.38715 .15465 L
Mistroke
.38841 .15463 L
.3891 .15462 L
.38975 .15462 L
.39092 .15462 L
.39217 .15462 L
.39327 .15462 L
.39447 .15463 L
.39573 .15465 L
.3969 .15467 L
.39899 .15473 L
.40124 .15481 L
.4039 .15492 L
.40679 .15509 L
.41204 .15548 L
.41715 .15598 L
.42188 .15657 L
.43153 .15816 L
.44058 .1602 L
.45051 .16321 L
.4612 .16762 L
.47079 .17295 L
.48128 .18073 L
.49222 .19169 L
.50239 .2048 L
.52116 .23451 L
.54149 .26498 L
.5469 .27133 L
.55262 .27698 L
.55792 .28121 L
.56287 .28427 L
.56751 .28638 L
.57011 .28725 L
.57248 .28786 L
.57374 .28812 L
.57508 .28834 L
.57577 .28843 L
.57654 .28851 L
.57725 .28858 L
.5779 .28862 L
.57917 .28868 L
.57984 .28869 L
.58055 .28869 L
.58174 .28865 L
.58304 .28857 L
.58435 .28845 L
.58557 .2883 L
.58831 .28782 L
.59073 .28726 L
.5933 .28653 L
.60262 .2828 L
Mistroke
.61259 .27735 L
.62357 .27013 L
.66387 .24016 L
.70266 .21566 L
.71278 .21071 L
.72381 .20609 L
.73436 .20246 L
.74391 .19989 L
.74878 .19886 L
.75405 .19796 L
.75647 .19763 L
.75902 .19734 L
.76142 .19712 L
.7636 .19697 L
.76488 .19691 L
.7661 .19686 L
.76738 .19682 L
.7681 .19681 L
.76877 .19681 L
.76989 .19681 L
.77111 .19682 L
.7724 .19686 L
.7736 .19691 L
.77494 .19699 L
.77636 .19709 L
.77888 .19733 L
.7816 .19768 L
.78457 .19818 L
.78987 .19936 L
.79486 .20085 L
.8042 .2047 L
.81426 .21049 L
.82516 .21872 L
.86609 .26248 L
.88647 .28496 L
.89642 .29448 L
.90552 .30199 L
.91427 .30802 L
.9238 .31318 L
.92902 .31538 L
.93387 .31702 L
.9385 .31824 L
.9409 .31874 L
.94342 .31918 L
.94544 .31946 L
.94766 .31969 L
.94863 .31977 L
.94967 .31984 L
.95065 .3199 L
.95154 .31993 L
Mistroke
.95267 .31996 L
.9537 .31998 L
.95484 .31997 L
.95605 .31995 L
.9571 .31992 L
.95808 .31987 L
.95915 .31981 L
.96031 .31972 L
.96234 .31953 L
.96456 .31927 L
.9686 .31864 L
.97619 .31698 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.04262 .09892 L
.06244 .16905 L
.07216 .19613 L
.08255 .21983 L
.09396 .23978 L
.09948 .24729 L
.10458 .25304 L
.10944 .25753 L
.1148 .26142 L
.12018 .26429 L
.12313 .26545 L
.12589 .26628 L
.12713 .26659 L
.12848 .26687 L
.12968 .26707 L
.13095 .26724 L
.13221 .26737 L
.13336 .26745 L
.13451 .2675 L
.13559 .26751 L
.13686 .26749 L
.1375 .26747 L
.1382 .26743 L
.13944 .26733 L
.1406 .26721 L
.14322 .26684 L
.14603 .26628 L
.15131 .26484 L
.1562 .26311 L
.16727 .25803 L
.18739 .24618 L
.22665 .22072 L
.2644 .19986 L
.28538 .19081 L
.30461 .18416 L
.32345 .17911 L
.33305 .17707 L
.34329 .17528 L
.35364 .17386 L
.36304 .17291 L
.36757 .17257 L
.36996 .17242 L
.37248 .17228 L
.37469 .17218 L
.37712 .17209 L
.37933 .17203 L
.38042 .17201 L
.3814 .17199 L
.38265 .17197 L
Mistroke
.38334 .17196 L
.38399 .17196 L
.38514 .17196 L
.38638 .17196 L
.38704 .17196 L
.38776 .17197 L
.38851 .17197 L
.38921 .17198 L
.39047 .17201 L
.39181 .17204 L
.39447 .17212 L
.39698 .17222 L
.40169 .17249 L
.40631 .17285 L
.41057 .17328 L
.42023 .17459 L
.42988 .17644 L
.43893 .17878 L
.44886 .18216 L
.45954 .18705 L
.46914 .19288 L
.47962 .20129 L
.49057 .21297 L
.50074 .22678 L
.51951 .25763 L
.53983 .28901 L
.54525 .29554 L
.55097 .30136 L
.55627 .30571 L
.56122 .30887 L
.56586 .31104 L
.56846 .31195 L
.57083 .31258 L
.57218 .31286 L
.57342 .31306 L
.57479 .31324 L
.57548 .3133 L
.57625 .31336 L
.57752 .31341 L
.57824 .31342 L
.5789 .31342 L
.58011 .31338 L
.58138 .3133 L
.58262 .31318 L
.58395 .313 L
.58638 .31257 L
.58874 .31201 L
.59091 .31138 L
.59586 .30957 L
.6011 .30715 L
Mistroke
.61946 .29563 L
.65732 .2657 L
.67837 .24985 L
.69762 .23728 L
.71774 .22659 L
.73641 .2191 L
.74561 .2163 L
.75541 .214 L
.76102 .21302 L
.76376 .21263 L
.76629 .21232 L
.76855 .21209 L
.77102 .21189 L
.77351 .21174 L
.77487 .21168 L
.77614 .21164 L
.77741 .21161 L
.77804 .2116 L
.77875 .2116 L
.77999 .2116 L
.78116 .21162 L
.78182 .21163 L
.78252 .21165 L
.78378 .2117 L
.78513 .21177 L
.78661 .21186 L
.78909 .21207 L
.79174 .21236 L
.79651 .21306 L
.80152 .21404 L
.80624 .21521 L
.81507 .21806 L
.8248 .2222 L
.8351 .22771 L
.85356 .24022 L
.89147 .2713 L
.91256 .28725 L
.93183 .29874 L
.94136 .3031 L
.95176 .3068 L
.95651 .30813 L
.96157 .30931 L
.96626 .31018 L
.97067 .31082 L
.97332 .31112 L
.97619 .31138 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.03279 .05685 L
.04262 .09705 L
.04758 .11357 L
.05288 .12761 L
.05546 .13293 L
.05789 .13704 L
.06007 .13999 L
.06244 .14243 L
.0637 .14341 L
.06506 .14424 L
.06634 .14482 L
.06751 .14518 L
.06821 .14533 L
.06887 .14542 L
.06959 .14547 L
.07036 .14546 L
.0711 .14541 L
.07179 .14531 L
.07308 .14502 L
.07373 .14483 L
.07445 .14457 L
.0759 .14395 L
.07849 .14251 L
.08435 .13806 L
.10458 .11718 L
.12572 .09544 L
.145 .07891 L
.16521 .06516 L
.18391 .05526 L
.203 .04744 L
.22376 .04099 L
.24242 .03661 L
.26302 .03296 L
.28237 .0304 L
.30323 .02835 L
.32327 .02689 L
.34437 .02577 L
.36411 .02501 L
.38248 .0245 L
.393 .02427 L
.40293 .02409 L
.41178 .02396 L
.42152 .02384 L
.43124 .02375 L
.4362 .02371 L
.44153 .02368 L
.44652 .02366 L
.45107 .02364 L
.45326 .02364 L
Mistroke
.45441 .02363 L
.45564 .02363 L
.45683 .02363 L
.4579 .02363 L
.45897 .02363 L
.45999 .02363 L
.46115 .02363 L
.4624 .02363 L
.46358 .02363 L
.46466 .02363 L
.46592 .02363 L
.46729 .02363 L
.46858 .02363 L
.46978 .02363 L
.47216 .02364 L
.47479 .02365 L
.48011 .02367 L
.4847 .0237 L
.48965 .02373 L
.49859 .02381 L
.51828 .02404 L
.52868 .02416 L
.5344 .02423 L
.53978 .02428 L
.54496 .02432 L
.54768 .02433 L
.55056 .02435 L
.55299 .02436 L
.55566 .02437 L
.55683 .02437 L
.55808 .02438 L
.55927 .02438 L
.56035 .02438 L
.56153 .02438 L
.56279 .02438 L
.56386 .02438 L
.56505 .02438 L
.56631 .02438 L
.56703 .02438 L
.56768 .02438 L
.57016 .02437 L
.57232 .02437 L
.57469 .02436 L
.57946 .02434 L
.58473 .02431 L
.58972 .02427 L
.59905 .0242 L
.61999 .024 L
.65842 .0236 L
.67788 .02343 L
Mistroke
.69931 .02327 L
.71987 .02315 L
.73868 .02306 L
.7581 .023 L
.76881 .02297 L
.77899 .02295 L
.78858 .02294 L
.79385 .02293 L
.79881 .02292 L
.80344 .02292 L
.80846 .02292 L
.81301 .02291 L
.8172 .02291 L
.81966 .02291 L
.8219 .02291 L
.82314 .02291 L
.82449 .02291 L
.82566 .02291 L
.82694 .02291 L
.82813 .02291 L
.82924 .02291 L
.83041 .02291 L
.83167 .02291 L
.83278 .02291 L
.83395 .02291 L
.83495 .02291 L
.83604 .02291 L
.83875 .02291 L
.84122 .02291 L
.84675 .02291 L
.85671 .02292 L
.87752 .02292 L
.88666 .02293 L
.89151 .02293 L
.89671 .02293 L
.8993 .02293 L
.90176 .02293 L
.90397 .02293 L
.90521 .02293 L
.90637 .02293 L
.90756 .02293 L
.90867 .02293 L
.90967 .02293 L
.91075 .02293 L
.91193 .02293 L
.91318 .02293 L
.91424 .02293 L
.91541 .02293 L
.918 .02293 L
.92036 .02293 L
Mistroke
.92308 .02293 L
.92565 .02293 L
.93023 .02293 L
.93519 .02293 L
.94463 .02292 L
.95502 .02291 L
.97605 .02289 L
.97619 .02289 L
Mfstroke
.174 1 0 r
.02381 .01472 m
.02605 .02534 L
.02846 .035 L
.02962 .03875 L
.03072 .04169 L
.0317 .04382 L
.03279 .04569 L
.03398 .04724 L
.03524 .04841 L
.03641 .04914 L
.0375 .0496 L
.03879 .04991 L
.03997 .05002 L
.04062 .05003 L
.04132 .05001 L
.04262 .04988 L
.04326 .04978 L
.04396 .04965 L
.04523 .04937 L
.04759 .04874 L
.0529 .04698 L
.06244 .04348 L
.08293 .03656 L
.10458 .03086 L
.12413 .027 L
.14558 .02385 L
.16509 .02174 L
.18601 .02008 L
.20725 .01884 L
.22737 .01799 L
.24728 .01737 L
.2657 .01694 L
.28436 .01662 L
.30496 .01635 L
.32431 .01616 L
.34517 .01602 L
.36521 .01592 L
.38631 .01584 L
.40605 .01579 L
.42442 .01575 L
.43494 .01574 L
.44487 .01573 L
.46346 .01571 L
.47318 .0157 L
.48347 .0157 L
.49226 .0157 L
.49726 .0157 L
.50193 .01569 L
.50691 .01569 L
.51233 .01569 L
Mistroke
.52221 .01569 L
.53177 .01569 L
.54075 .01569 L
.54572 .01569 L
.5511 .01569 L
.56046 .01569 L
.58145 .01568 L
.6225 .01567 L
.66204 .01566 L
.68195 .01565 L
.70007 .01565 L
.71962 .01565 L
.73049 .01564 L
.74054 .01564 L
.74964 .01564 L
.75967 .01564 L
.76975 .01564 L
.77496 .01564 L
.78044 .01564 L
.78528 .01564 L
.78783 .01564 L
.79056 .01564 L
.79308 .01564 L
.79536 .01564 L
.79766 .01564 L
.79983 .01564 L
.80104 .01564 L
.80236 .01564 L
.80303 .01564 L
.80375 .01564 L
.80504 .01564 L
.80633 .01564 L
.80756 .01564 L
.80865 .01564 L
.80985 .01564 L
.81115 .01564 L
.81258 .01564 L
.81548 .01564 L
.8207 .01564 L
.8256 .01564 L
.83077 .01564 L
.84002 .01564 L
.86087 .01564 L
.88081 .01564 L
.89894 .01564 L
.90902 .01564 L
.91364 .01564 L
.91853 .01564 L
.92102 .01564 L
.92376 .01564 L
Mistroke
.92627 .01564 L
.92858 .01564 L
.92997 .01564 L
.93129 .01564 L
.93196 .01564 L
.93268 .01564 L
.93347 .01564 L
.9342 .01564 L
.93489 .01564 L
.93563 .01564 L
.93633 .01564 L
.93697 .01564 L
.93819 .01564 L
.93947 .01564 L
.94065 .01564 L
.94194 .01564 L
.94427 .01564 L
.94864 .01564 L
.95375 .01564 L
.95847 .01564 L
.96706 .01564 L
.97619 .01564 L
Mfstroke
.15 1 0 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02133 L
.03163 .02137 L
.03279 .02138 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02122 L
.04262 .0209 L
.06244 .01955 L
.08259 .0184 L
.10458 .01745 L
.12517 .01679 L
.14429 .01633 L
.16481 .01597 L
.18342 .01573 L
.20266 .01554 L
.22348 .01538 L
.24342 .01528 L
.26449 .01519 L
.28413 .01514 L
.30246 .0151 L
.32281 .01507 L
.34137 .01505 L
.36045 .01503 L
.38121 .01502 L
.40099 .01501 L
.4111 .015 L
.422 .015 L
.43215 .015 L
.44147 .01499 L
.45975 .01499 L
.46955 .01499 L
.47867 .01499 L
.48868 .01499 L
.49937 .01499 L
.50961 .01499 L
.52072 .01499 L
.54087 .01499 L
.56074 .01499 L
.58179 .01499 L
.61967 .01498 L
.64075 .01498 L
.66001 .01498 L
.68016 .01498 L
Mistroke
.69884 .01498 L
.71786 .01498 L
.72855 .01498 L
.7386 .01498 L
.74848 .01498 L
.75916 .01498 L
.76388 .01498 L
.76886 .01498 L
.77345 .01498 L
.77778 .01498 L
.78016 .01498 L
.78275 .01498 L
.78491 .01498 L
.78728 .01498 L
.78985 .01498 L
.79125 .01498 L
.79257 .01498 L
.7938 .01498 L
.79493 .01498 L
.79616 .01498 L
.79746 .01498 L
.79861 .01498 L
.79966 .01498 L
.80086 .01498 L
.802 .01498 L
.80403 .01498 L
.80623 .01498 L
.81121 .01498 L
.8158 .01498 L
.82552 .01498 L
.83461 .01498 L
.85526 .01498 L
.89414 .01498 L
.90429 .01498 L
.90965 .01498 L
.91535 .01498 L
.92031 .01498 L
.92579 .01498 L
.92819 .01498 L
.93078 .01498 L
.93323 .01498 L
.93547 .01498 L
.9366 .01498 L
.93783 .01498 L
.93914 .01498 L
.94037 .01498 L
.94152 .01498 L
.94274 .01498 L
.94378 .01498 L
.94493 .01498 L
Mistroke
.94562 .01498 L
.94628 .01498 L
.94751 .01498 L
.94884 .01498 L
.95028 .01498 L
.95288 .01498 L
.9553 .01498 L
.9606 .01498 L
.96541 .01498 L
.97619 .01498 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.04262 .09878 L
.06244 .16652 L
.07286 .19228 L
.08255 .21026 L
.08813 .21813 L
.0932 .22385 L
.09905 .22889 L
.1019 .23078 L
.10458 .23224 L
.10699 .23331 L
.10919 .23409 L
.11164 .23476 L
.11299 .23504 L
.11428 .23525 L
.11551 .23541 L
.11682 .23552 L
.11806 .23558 L
.11919 .23559 L
.11988 .23559 L
.12052 .23557 L
.12121 .23554 L
.12195 .23549 L
.12319 .23537 L
.12455 .23521 L
.12696 .2348 L
.12916 .23432 L
.13409 .23289 L
.14299 .22929 L
.16208 .21864 L
.18284 .2051 L
.22362 .17969 L
.24387 .16919 L
.26289 .16089 L
.28128 .15425 L
.30064 .14865 L
.32082 .1442 L
.33933 .14127 L
.34887 .14015 L
.35412 .13965 L
.35907 .13925 L
.36368 .13894 L
.36869 .13867 L
.3709 .13858 L
.37324 .13849 L
.37525 .13843 L
.37743 .13838 L
.37875 .13835 L
.37996 .13833 L
.38113 .13832 L
Mistroke
.38237 .13831 L
.38358 .1383 L
.38473 .1383 L
.38576 .1383 L
.38687 .13831 L
.3881 .13832 L
.38879 .13833 L
.38944 .13834 L
.39215 .13839 L
.3945 .13845 L
.39701 .13854 L
.40193 .13878 L
.40659 .13908 L
.41532 .13986 L
.41993 .1404 L
.425 .1411 L
.43527 .14294 L
.44478 .14523 L
.4537 .14804 L
.46356 .15209 L
.47393 .1578 L
.48278 .16421 L
.49244 .17325 L
.51209 .19848 L
.53306 .22858 L
.54332 .24039 L
.54873 .24529 L
.55444 .24942 L
.55944 .25214 L
.56229 .25332 L
.56494 .2542 L
.56738 .25481 L
.5696 .25522 L
.57083 .25539 L
.57148 .25546 L
.57217 .25552 L
.57344 .2556 L
.57461 .25564 L
.57574 .25564 L
.57698 .25561 L
.57828 .25553 L
.57948 .25542 L
.58062 .25529 L
.58165 .25514 L
.58396 .25474 L
.58645 .25417 L
.58915 .25342 L
.59405 .25174 L
.60356 .24746 L
.61232 .24262 L
Mistroke
.65169 .2166 L
.68955 .19321 L
.7106 .18263 L
.72986 .17464 L
.74998 .16796 L
.76865 .16316 L
.78765 .1595 L
.80838 .15661 L
.82892 .15449 L
.84753 .15287 L
.88761 .14971 L
.92618 .14716 L
.94614 .14613 L
.96721 .14527 L
.97619 .14496 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.04262 .09879 L
.06244 .16655 L
.07286 .19211 L
.08255 .20952 L
.08813 .21682 L
.0932 .22184 L
.096 .22399 L
.09905 .22585 L
.10192 .22716 L
.10329 .22765 L
.10458 .22802 L
.10574 .22829 L
.10701 .22852 L
.10817 .22867 L
.10924 .22875 L
.11051 .22879 L
.11166 .22877 L
.1123 .22873 L
.11299 .22868 L
.11425 .22853 L
.11534 .22836 L
.11654 .22812 L
.11897 .22749 L
.12331 .22591 L
.12845 .22335 L
.13397 .21994 L
.14393 .21246 L
.18529 .1746 L
.22514 .14229 L
.26347 .11996 L
.28324 .11155 L
.30425 .10457 L
.32372 .09962 L
.342 .09611 L
.35183 .09463 L
.36218 .09334 L
.37188 .09238 L
.38069 .09171 L
.38527 .09142 L
.39023 .09118 L
.39296 .09106 L
.39548 .09097 L
.39803 .0909 L
.40043 .09084 L
.40248 .09081 L
.40353 .09079 L
.40468 .09078 L
.40593 .09077 L
.40712 .09076 L
Mistroke
.40828 .09075 L
.40935 .09075 L
.41059 .09076 L
.41175 .09076 L
.4128 .09077 L
.41392 .09078 L
.41516 .0908 L
.41646 .09083 L
.4188 .09088 L
.42135 .09095 L
.42377 .09104 L
.4283 .09125 L
.43317 .09154 L
.43847 .09196 L
.44801 .09297 L
.45682 .09428 L
.46647 .09624 L
.47552 .09871 L
.48545 .10237 L
.49614 .10775 L
.50573 .11405 L
.51622 .12245 L
.53733 .14074 L
.54744 .14798 L
.55698 .15302 L
.56226 .155 L
.56523 .15586 L
.56797 .1565 L
.57028 .15692 L
.57282 .15727 L
.5741 .15741 L
.57547 .15751 L
.57676 .15759 L
.57794 .15763 L
.57912 .15765 L
.58022 .15764 L
.58143 .15762 L
.58274 .15757 L
.58403 .15749 L
.5854 .15738 L
.58784 .15712 L
.59221 .15647 L
.597 .15549 L
.60775 .1525 L
.61776 .14897 L
.65677 .13247 L
.69823 .11628 L
.71901 .10983 L
.73818 .10495 L
.75803 .10094 L
Mistroke
.77662 .09803 L
.79536 .09582 L
.80594 .09485 L
.81599 .09408 L
.83625 .09289 L
.85478 .09208 L
.89299 .09066 L
.93366 .08891 L
.97281 .08703 L
.97619 .08687 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.04262 .09854 L
.0522 .1331 L
.06244 .16176 L
.0679 .17301 L
.07286 .18073 L
.07525 .18359 L
.07784 .18609 L
.08029 .18789 L
.08255 .18908 L
.08382 .18956 L
.08452 .18977 L
.08518 .18993 L
.08647 .19015 L
.08764 .19024 L
.08831 .19025 L
.08903 .19022 L
.09032 .19009 L
.09111 .18995 L
.09185 .18978 L
.09325 .18938 L
.09608 .18821 L
.09869 .18678 L
.10458 .18245 L
.11432 .17297 L
.1234 .16268 L
.14407 .13831 L
.18298 .09972 L
.20422 .08423 L
.22434 .07276 L
.24425 .06394 L
.26267 .0576 L
.28133 .05259 L
.30193 .04838 L
.32128 .0454 L
.34214 .04302 L
.36218 .04137 L
.37225 .04072 L
.38328 .04015 L
.39336 .03972 L
.40289 .0394 L
.40815 .03926 L
.41386 .03913 L
.41902 .03903 L
.42384 .03896 L
.4284 .03891 L
.43096 .03889 L
.4333 .03888 L
.43463 .03887 L
.43586 .03886 L
Mistroke
.43655 .03886 L
.43721 .03886 L
.43796 .03886 L
.43864 .03886 L
.43991 .03886 L
.44108 .03886 L
.44236 .03886 L
.44301 .03886 L
.44371 .03887 L
.44513 .03887 L
.44647 .03888 L
.44897 .0389 L
.45167 .03892 L
.4546 .03896 L
.45988 .03904 L
.46476 .03915 L
.47441 .03944 L
.48346 .03982 L
.49339 .04038 L
.50407 .04117 L
.52376 .04296 L
.53417 .0439 L
.53988 .04435 L
.54527 .04471 L
.55044 .045 L
.55317 .04512 L
.55605 .04523 L
.55848 .04531 L
.56114 .04538 L
.56357 .04543 L
.56474 .04544 L
.56583 .04546 L
.56702 .04547 L
.56831 .04548 L
.56944 .04548 L
.57065 .04548 L
.57173 .04548 L
.57274 .04548 L
.57385 .04547 L
.57505 .04546 L
.57625 .04545 L
.57756 .04543 L
.58021 .04539 L
.58494 .04528 L
.59022 .04512 L
.5952 .04493 L
.60453 .04451 L
.62547 .04336 L
.66391 .04116 L
.68337 .04019 L
Mistroke
.70479 .0393 L
.72536 .03862 L
.74416 .03814 L
.76359 .03776 L
.7743 .0376 L
.78447 .03747 L
.79407 .03738 L
.80429 .0373 L
.81394 .03724 L
.82268 .03721 L
.82756 .03719 L
.83272 .03718 L
.83712 .03717 L
.84194 .03716 L
.84714 .03716 L
.85006 .03716 L
.85272 .03715 L
.85519 .03715 L
.8565 .03715 L
.85788 .03715 L
.85909 .03715 L
.86042 .03715 L
.86277 .03715 L
.86399 .03715 L
.86512 .03715 L
.86636 .03715 L
.86769 .03715 L
.87041 .03715 L
.87287 .03715 L
.87516 .03715 L
.87645 .03715 L
.87764 .03715 L
.87982 .03715 L
.88092 .03715 L
.88213 .03715 L
.88485 .03715 L
.88733 .03715 L
.89019 .03715 L
.89291 .03715 L
.89774 .03714 L
.90299 .03714 L
.90833 .03713 L
.91335 .03712 L
.92272 .0371 L
.93281 .03707 L
.94371 .03702 L
.97619 .03685 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .0214 L
.04262 .0211 L
.06244 .01978 L
.08259 .01863 L
.10458 .01766 L
.12517 .01699 L
.14429 .01652 L
.16481 .01614 L
.18342 .01589 L
.20266 .01569 L
.22348 .01553 L
.24342 .01541 L
.26449 .01533 L
.28413 .01527 L
.30246 .01523 L
.32281 .01519 L
.34137 .01517 L
.36045 .01515 L
.38121 .01514 L
.40099 .01513 L
.41097 .01512 L
.422 .01512 L
.44134 .01511 L
.45222 .01511 L
.4622 .01511 L
.46694 .01511 L
.472 .01511 L
.47638 .01511 L
.48112 .01511 L
.48403 .01511 L
.4867 .01511 L
.48921 .01511 L
.49197 .01511 L
.49444 .01511 L
.49675 .01511 L
.49803 .01511 L
.4992 .01511 L
.49984 .01511 L
Mistroke
.50054 .01511 L
.50182 .01511 L
.50247 .01511 L
.50316 .01511 L
.50438 .01511 L
.50571 .01511 L
.50645 .01511 L
.50715 .01511 L
.50957 .01511 L
.51217 .01511 L
.52153 .01511 L
.52424 .01511 L
.52718 .01511 L
.52853 .01511 L
.52995 .01511 L
.53117 .01511 L
.53183 .01511 L
.53252 .01511 L
.53382 .01511 L
.535 .01511 L
.53628 .01511 L
.53701 .01511 L
.53768 .01511 L
.53891 .01511 L
.54002 .01511 L
.54131 .01511 L
.54252 .01511 L
.54492 .01511 L
.54717 .01511 L
.55227 .01511 L
.55724 .01511 L
.56257 .01511 L
.58104 .01511 L
.62237 .0151 L
.66218 .0151 L
.68038 .0151 L
.70048 .0151 L
.72023 .0151 L
.73118 .0151 L
.74123 .0151 L
.76055 .0151 L
.7707 .0151 L
.7814 .0151 L
.80112 .0151 L
.81947 .0151 L
.85849 .0151 L
.89995 .0151 L
.9399 .0151 L
.97619 .0151 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.03279 .05674 L
.04262 .0961 L
.04758 .11193 L
.05288 .12519 L
.05546 .13018 L
.05789 .13405 L
.06024 .13702 L
.06244 .13916 L
.06371 .14012 L
.06487 .14083 L
.06616 .14145 L
.06688 .14172 L
.06754 .14193 L
.06819 .14208 L
.06887 .1422 L
.06963 .14229 L
.07032 .14232 L
.07097 .14232 L
.07167 .14227 L
.07295 .14209 L
.07412 .14182 L
.07541 .14142 L
.078 .14031 L
.08265 .1375 L
.09399 .12788 L
.10458 .11743 L
.14349 .08226 L
.16473 .06798 L
.18485 .05749 L
.20476 .0495 L
.22318 .0438 L
.24184 .03933 L
.26245 .03558 L
.28179 .03294 L
.30265 .03081 L
.32269 .0293 L
.34379 .02813 L
.36353 .02734 L
.3819 .0268 L
.39242 .02657 L
.40235 .02639 L
.41121 .02626 L
.42094 .02615 L
.43066 .02607 L
.43598 .02604 L
.43853 .02603 L
.44096 .02602 L
.44318 .02601 L
.44435 .02601 L
Mistroke
.4456 .02601 L
.44676 .026 L
.44781 .026 L
.44886 .026 L
.44985 .026 L
.45102 .026 L
.45225 .026 L
.4533 .026 L
.45445 .026 L
.45569 .026 L
.45701 .02601 L
.45941 .02601 L
.46198 .02602 L
.46471 .02603 L
.46961 .02606 L
.47488 .0261 L
.48069 .02615 L
.49108 .02629 L
.50082 .02646 L
.51934 .02687 L
.52982 .0271 L
.53956 .02729 L
.54456 .02737 L
.54928 .02743 L
.55189 .02745 L
.55471 .02748 L
.55726 .0275 L
.55964 .02751 L
.56219 .02752 L
.56354 .02752 L
.56429 .02753 L
.56498 .02753 L
.56571 .02753 L
.5665 .02753 L
.5672 .02753 L
.56794 .02753 L
.56922 .02753 L
.56995 .02753 L
.57063 .02753 L
.57187 .02752 L
.57317 .02752 L
.5755 .02751 L
.57801 .0275 L
.58075 .02748 L
.58603 .02745 L
.59101 .0274 L
.60034 .02729 L
.62128 .02699 L
.65972 .02639 L
.67918 .02612 L
Mistroke
.7006 .02587 L
.72093 .02569 L
.73997 .02556 L
.75036 .0255 L
.76024 .02546 L
.7691 .02543 L
.77877 .02541 L
.78408 .0254 L
.78909 .02539 L
.79359 .02538 L
.79612 .02538 L
.79845 .02538 L
.79967 .02538 L
.80097 .02538 L
.8022 .02538 L
.80332 .02538 L
.80463 .02538 L
.80537 .02538 L
.80606 .02538 L
.80732 .02538 L
.80795 .02538 L
.80866 .02538 L
.81005 .02538 L
.81133 .02538 L
.81421 .02538 L
.81676 .02538 L
.81943 .02539 L
.82444 .02539 L
.82898 .0254 L
.83919 .02542 L
.85756 .02547 L
.87838 .02554 L
.88751 .02557 L
.89756 .0256 L
.90658 .02563 L
.91626 .02564 L
.9216 .02565 L
.92649 .02566 L
.92883 .02566 L
.93007 .02566 L
.93139 .02566 L
.93266 .02566 L
.93381 .02566 L
.93496 .02566 L
.93605 .02566 L
.93722 .02566 L
.93847 .02566 L
.93965 .02566 L
.94072 .02566 L
.94199 .02566 L
Mistroke
.94336 .02566 L
.94585 .02566 L
.94845 .02566 L
.95122 .02565 L
.95618 .02565 L
.96498 .02563 L
.97467 .02561 L
.97619 .02561 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.04262 .09859 L
.0522 .13369 L
.06244 .16449 L
.07286 .18841 L
.08255 .20433 L
.08848 .21129 L
.0914 .214 L
.09409 .21612 L
.09912 .21916 L
.10177 .22031 L
.10311 .22078 L
.10458 .22121 L
.10589 .22153 L
.1071 .22176 L
.10826 .22194 L
.10949 .22208 L
.11071 .22216 L
.11185 .22219 L
.11288 .22219 L
.11399 .22215 L
.11521 .22206 L
.11591 .22199 L
.11655 .22191 L
.11926 .22147 L
.1216 .22093 L
.12411 .22022 L
.13369 .21634 L
.14241 .21158 L
.18226 .18379 L
.22059 .15836 L
.23997 .14778 L
.26137 .13807 L
.28186 .13059 L
.30064 .12515 L
.31999 .12081 L
.33079 .11889 L
.34084 .11741 L
.35076 .11621 L
.35977 .11535 L
.36977 .11463 L
.37527 .11434 L
.37796 .11423 L
.38047 .11414 L
.38288 .11407 L
.38509 .11401 L
.38755 .11397 L
.3889 .11395 L
.39019 .11394 L
.39142 .11394 L
Mistroke
.39274 .11393 L
.39399 .11393 L
.39511 .11394 L
.3958 .11394 L
.39644 .11395 L
.39788 .11397 L
.39914 .11398 L
.40048 .11401 L
.40268 .11406 L
.40503 .11413 L
.40928 .1143 L
.41433 .11458 L
.41893 .11491 L
.42887 .11587 L
.43805 .11714 L
.44813 .11904 L
.45883 .12181 L
.46822 .12511 L
.47834 .12987 L
.48789 .1359 L
.49663 .14304 L
.5172 .16592 L
.52722 .17846 L
.53631 .18899 L
.54517 .19759 L
.55477 .20451 L
.56005 .20719 L
.56237 .20811 L
.56491 .20897 L
.56715 .20957 L
.56956 .21008 L
.57088 .2103 L
.5721 .21046 L
.57331 .21059 L
.57447 .21068 L
.5756 .21074 L
.57683 .21077 L
.57799 .21077 L
.57905 .21075 L
.58022 .21069 L
.58151 .2106 L
.58286 .21047 L
.58411 .21032 L
.5867 .20992 L
.58906 .20945 L
.59435 .2081 L
.60382 .20476 L
.61277 .20079 L
.6512 .17974 L
.69209 .15824 L
Mistroke
.71242 .14944 L
.73146 .14254 L
.75087 .1368 L
.76931 .13248 L
.78958 .12886 L
.8081 .12639 L
.82793 .12438 L
.84632 .12284 L
.88547 .11983 L
.92707 .1166 L
.96716 .11376 L
.97619 .1132 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.04262 .09854 L
.0522 .13325 L
.06244 .16268 L
.0679 .17477 L
.07286 .18355 L
.07784 .19028 L
.08008 .19264 L
.08255 .19478 L
.08522 .19657 L
.08668 .19732 L
.08805 .1979 L
.08932 .19832 L
.09049 .19861 L
.09113 .19873 L
.09184 .19884 L
.09312 .19895 L
.09389 .19897 L
.09462 .19895 L
.09528 .19892 L
.09599 .19885 L
.09677 .19874 L
.09759 .19859 L
.09906 .19825 L
.10169 .19736 L
.10458 .19604 L
.10982 .19283 L
.11478 .189 L
.12409 .18038 L
.145 .15795 L
.18333 .11955 L
.20272 .10415 L
.22412 .09042 L
.2446 .08008 L
.26338 .07263 L
.28273 .06661 L
.30359 .06164 L
.32251 .05823 L
.34321 .05545 L
.36282 .05354 L
.3738 .05274 L
.38377 .05215 L
.39375 .05169 L
.40296 .05137 L
.40777 .05124 L
.41306 .05113 L
.41572 .05109 L
.41858 .05106 L
.41997 .05104 L
.42128 .05103 L
Mistroke
.42257 .05102 L
.42375 .05102 L
.425 .05101 L
.42566 .05101 L
.42635 .05101 L
.42752 .05101 L
.4288 .05101 L
.42994 .05101 L
.43116 .05101 L
.43231 .05102 L
.43336 .05103 L
.43588 .05105 L
.43862 .05108 L
.44121 .05113 L
.4436 .05117 L
.44784 .05128 L
.45253 .05143 L
.462 .05185 L
.46693 .05214 L
.47212 .05251 L
.48138 .05335 L
.49136 .05456 L
.50225 .05631 L
.52354 .06084 L
.54287 .06487 L
.55253 .0663 L
.55798 .06687 L
.56057 .06708 L
.56299 .06724 L
.56529 .06737 L
.56738 .06746 L
.5685 .0675 L
.56971 .06753 L
.571 .06756 L
.57221 .06757 L
.57338 .06758 L
.57467 .06759 L
.57531 .06759 L
.57601 .06759 L
.57728 .06757 L
.57847 .06756 L
.57972 .06753 L
.58196 .06747 L
.58453 .06738 L
.58695 .06727 L
.59149 .067 L
.60168 .0662 L
.62004 .06424 L
.65847 .0595 L
.67793 .05729 L
Mistroke
.69936 .05518 L
.71992 .05352 L
.73873 .0523 L
.75815 .05132 L
.76899 .05088 L
.77904 .05053 L
.79804 .05003 L
.80807 .04984 L
.81877 .04968 L
.82906 .04956 L
.84019 .04946 L
.8507 .04939 L
.86037 .04933 L
.88081 .04924 L
.89988 .04913 L
.91822 .04899 L
.93787 .0488 L
.97619 .04832 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.04262 .09891 L
.06244 .16882 L
.08255 .21942 L
.09396 .23968 L
.10458 .2537 L
.10961 .25887 L
.11508 .26351 L
.11989 .26682 L
.125 .26961 L
.12959 .27153 L
.13203 .27234 L
.13466 .27306 L
.13706 .27358 L
.13926 .27396 L
.14032 .27411 L
.14147 .27424 L
.14249 .27434 L
.14357 .27442 L
.14421 .27446 L
.1449 .2745 L
.14612 .27454 L
.14681 .27455 L
.14755 .27456 L
.14825 .27455 L
.14889 .27454 L
.15012 .27451 L
.15081 .27447 L
.15146 .27444 L
.15389 .27425 L
.15605 .27401 L
.15843 .27368 L
.16325 .2728 L
.16845 .27158 L
.17406 .26998 L
.18422 .26653 L
.22536 .24916 L
.26498 .23336 L
.28495 .22697 L
.30309 .22225 L
.3227 .21838 L
.33348 .2168 L
.33832 .21622 L
.34365 .21567 L
.34834 .21527 L
.35337 .21492 L
.35615 .21477 L
.35869 .21465 L
.36127 .21456 L
.36253 .21452 L
Mistroke
.36367 .21449 L
.36472 .21447 L
.36586 .21445 L
.36706 .21443 L
.36819 .21442 L
.36945 .21442 L
.37077 .21442 L
.3719 .21442 L
.37313 .21444 L
.37431 .21445 L
.37538 .21447 L
.37778 .21453 L
.38001 .21461 L
.38212 .2147 L
.38672 .21496 L
.3918 .21536 L
.3971 .21589 L
.40207 .21652 L
.41094 .21795 L
.4205 .22001 L
.4301 .22272 L
.44058 .22657 L
.45152 .23186 L
.46169 .23827 L
.47224 .24692 L
.48219 .25743 L
.50079 .28409 L
.51914 .31633 L
.52957 .33389 L
.53931 .34804 L
.54891 .3591 L
.55385 .36357 L
.55922 .36747 L
.56216 .36919 L
.56487 .37052 L
.56742 .37155 L
.57023 .37245 L
.57144 .37276 L
.57274 .37304 L
.57387 .37325 L
.5751 .37343 L
.57642 .37358 L
.57713 .37363 L
.5778 .37368 L
.579 .37372 L
.58028 .37372 L
.58151 .37369 L
.58221 .37365 L
.58286 .3736 L
.58418 .37347 L
Mistroke
.5856 .37328 L
.58816 .37282 L
.5905 .37226 L
.59619 .37042 L
.6016 .36809 L
.61123 .36278 L
.62174 .35568 L
.66241 .32286 L
.70156 .29371 L
.72155 .28191 L
.74316 .27189 L
.75332 .26819 L
.76404 .26497 L
.7732 .26277 L
.78325 .26093 L
.78849 .26019 L
.79346 .25963 L
.79792 .25923 L
.80277 .25891 L
.80528 .25879 L
.80804 .25869 L
.80943 .25866 L
.81016 .25864 L
.81093 .25863 L
.81161 .25862 L
.81235 .25861 L
.81364 .2586 L
.81496 .2586 L
.81616 .25861 L
.81682 .25861 L
.81754 .25862 L
.81885 .25864 L
.82007 .25867 L
.82137 .2587 L
.82369 .25878 L
.82623 .2589 L
.82863 .25904 L
.83314 .25936 L
.83799 .25981 L
.84328 .26043 L
.85279 .26188 L
.8616 .26362 L
.88218 .26916 L
.9008 .27574 L
.94094 .29235 L
.97619 .30573 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.04262 .09856 L
.0522 .13322 L
.06244 .16223 L
.0679 .17382 L
.07286 .18194 L
.07525 .18504 L
.07784 .18782 L
.08029 .1899 L
.08255 .19136 L
.08382 .192 L
.08518 .19254 L
.08647 .19293 L
.08764 .19317 L
.08835 .19327 L
.08902 .19333 L
.08974 .19337 L
.09051 .19336 L
.09125 .19332 L
.09195 .19325 L
.09325 .19304 L
.0939 .19289 L
.09462 .19271 L
.09608 .19224 L
.09869 .19112 L
.10174 .18942 L
.10458 .18748 L
.11503 .17823 L
.12493 .16757 L
.14349 .14627 L
.18182 .10778 L
.20159 .09266 L
.2226 .07991 L
.24207 .07068 L
.26035 .06386 L
.28053 .05803 L
.29904 .05392 L
.31796 .05069 L
.33866 .04805 L
.35827 .04623 L
.36925 .04544 L
.37922 .04486 L
.38854 .04441 L
.39841 .04404 L
.40356 .04388 L
.40923 .04374 L
.414 .04364 L
.41921 .04355 L
.42191 .04352 L
.42442 .0435 L
Mistroke
.42682 .04348 L
.42815 .04347 L
.42937 .04346 L
.43057 .04346 L
.43167 .04346 L
.43288 .04346 L
.43415 .04346 L
.43526 .04346 L
.4363 .04346 L
.43744 .04346 L
.43865 .04347 L
.44005 .04348 L
.44135 .04348 L
.44427 .04351 L
.44685 .04354 L
.44959 .04359 L
.45432 .04368 L
.45954 .04382 L
.46448 .04398 L
.46966 .04419 L
.47893 .04469 L
.4889 .04541 L
.4998 .04645 L
.52109 .04917 L
.54041 .0516 L
.55008 .05247 L
.55552 .05281 L
.55812 .05294 L
.56054 .05304 L
.56284 .05311 L
.56493 .05316 L
.56613 .05319 L
.56726 .0532 L
.56846 .05322 L
.56976 .05323 L
.57093 .05323 L
.57221 .05323 L
.57286 .05323 L
.57356 .05323 L
.57482 .05322 L
.57601 .0532 L
.57727 .05319 L
.57951 .05314 L
.58208 .05308 L
.5845 .053 L
.58904 .05283 L
.59923 .0523 L
.61759 .05103 L
.65602 .04804 L
.67548 .04668 L
Mistroke
.69691 .04542 L
.71747 .04445 L
.73628 .04378 L
.7557 .04327 L
.76641 .04307 L
.77175 .04299 L
.77659 .04293 L
.7812 .04289 L
.78618 .04285 L
.78893 .04283 L
.79145 .04282 L
.79386 .04281 L
.79519 .0428 L
.79641 .0428 L
.79753 .0428 L
.7986 .0428 L
.79972 .0428 L
.80094 .0428 L
.80201 .0428 L
.80314 .0428 L
.80411 .0428 L
.80518 .0428 L
.80642 .0428 L
.80757 .04281 L
.81014 .04281 L
.81241 .04282 L
.8148 .04284 L
.81981 .04288 L
.82435 .04292 L
.83456 .04305 L
.84401 .04321 L
.85293 .04339 L
.89141 .04428 L
.90169 .04449 L
.9113 .04465 L
.92133 .04477 L
.92664 .04482 L
.92963 .04484 L
.93235 .04485 L
.93486 .04486 L
.93605 .04487 L
.93714 .04487 L
.9384 .04487 L
.93906 .04487 L
.93976 .04487 L
.94094 .04487 L
.94223 .04487 L
.94343 .04487 L
.94452 .04487 L
.94578 .04487 L
Mistroke
.94697 .04487 L
.94909 .04486 L
.95139 .04485 L
.95388 .04484 L
.95662 .04482 L
.96217 .04478 L
.97213 .04467 L
.97619 .04462 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.04262 .09889 L
.06244 .16815 L
.07286 .19544 L
.08255 .21489 L
.08813 .22345 L
.0932 .22962 L
.096 .23238 L
.09905 .23488 L
.10171 .23665 L
.10458 .23813 L
.10588 .23866 L
.10712 .23909 L
.10833 .23944 L
.10945 .2397 L
.11051 .23989 L
.11164 .24003 L
.11289 .24013 L
.11402 .24015 L
.11467 .24014 L
.11536 .24012 L
.11659 .24001 L
.11728 .23993 L
.11792 .23984 L
.11937 .23957 L
.12181 .23893 L
.12442 .23802 L
.13007 .23532 L
.13542 .23196 L
.14545 .22403 L
.18378 .18559 L
.22456 .14815 L
.24481 .13353 L
.26382 .12225 L
.28221 .11338 L
.30158 .10593 L
.32176 .09992 L
.34026 .09575 L
.34981 .09403 L
.36 .0925 L
.36956 .09132 L
.37837 .09044 L
.38861 .08966 L
.39401 .08935 L
.39676 .08923 L
.39972 .08911 L
.40231 .08902 L
.40467 .08896 L
.40705 .08891 L
.40931 .08887 L
Mistroke
.41058 .08886 L
.41129 .08885 L
.41193 .08885 L
.41319 .08884 L
.41436 .08884 L
.41503 .08884 L
.41574 .08884 L
.41701 .08885 L
.41772 .08886 L
.41837 .08886 L
.41987 .08888 L
.42114 .0889 L
.42248 .08893 L
.42489 .089 L
.42749 .08908 L
.43035 .0892 L
.43546 .08948 L
.44026 .08982 L
.4492 .09069 L
.45423 .09134 L
.45883 .09204 L
.46866 .09397 L
.47779 .09643 L
.48781 .10008 L
.49851 .1054 L
.50877 .11208 L
.51989 .12085 L
.5295 .12901 L
.54006 .13749 L
.54966 .14391 L
.55495 .14673 L
.55997 .14889 L
.5627 .14985 L
.56566 .15072 L
.56813 .15132 L
.57086 .15184 L
.57342 .15221 L
.57482 .15236 L
.57614 .15246 L
.57736 .15254 L
.57849 .15259 L
.57972 .15261 L
.58103 .15261 L
.58226 .15259 L
.58295 .15257 L
.58359 .15254 L
.58477 .15247 L
.58602 .15238 L
.58818 .15216 L
.59056 .15186 L
Mistroke
.59582 .15093 L
.60074 .14979 L
.6191 .14382 L
.65789 .1275 L
.69914 .1117 L
.71975 .1055 L
.73887 .10082 L
.75737 .09721 L
.77708 .09425 L
.78738 .09302 L
.79851 .09192 L
.80813 .09112 L
.81868 .09041 L
.83864 .08939 L
.84954 .08898 L
.85971 .08864 L
.89863 .0875 L
.94002 .08602 L
.97619 .08447 L
Mfstroke
0 1 .111 r
.02381 .01472 m
.02605 .02542 L
.02846 .0356 L
.03072 .04329 L
.03279 .04845 L
.03405 .05078 L
.03521 .05244 L
.03649 .0538 L
.03713 .05433 L
.03784 .0548 L
.03903 .05539 L
.04031 .05577 L
.04151 .05595 L
.04262 .05598 L
.04384 .0559 L
.04514 .05571 L
.04636 .05546 L
.04748 .05517 L
.05278 .05338 L
.06244 .04937 L
.08269 .04129 L
.10458 .03437 L
.12545 .02945 L
.14465 .02606 L
.16347 .02355 L
.18413 .0215 L
.20364 .02007 L
.22456 .01894 L
.2458 .0181 L
.26592 .01753 L
.28583 .01711 L
.30425 .01682 L
.32291 .0166 L
.34352 .01642 L
.36286 .0163 L
.38372 .0162 L
.40376 .01614 L
.41384 .01611 L
.42486 .01609 L
.44447 .01606 L
.45545 .01604 L
.46542 .01604 L
.47027 .01603 L
.4754 .01603 L
.47984 .01603 L
.4846 .01603 L
.48728 .01602 L
.48972 .01602 L
.4922 .01602 L
.49451 .01602 L
Mistroke
.49718 .01602 L
.49859 .01602 L
.5001 .01602 L
.50153 .01602 L
.50223 .01602 L
.50288 .01602 L
.50409 .01602 L
.5054 .01602 L
.50667 .01602 L
.50787 .01602 L
.50895 .01602 L
.51012 .01602 L
.51139 .01602 L
.51274 .01602 L
.51516 .01602 L
.52426 .01602 L
.52671 .01602 L
.52799 .01602 L
.52934 .01602 L
.53053 .01602 L
.53182 .01602 L
.533 .01602 L
.5341 .01602 L
.53478 .01602 L
.53551 .01602 L
.53621 .01602 L
.53685 .01602 L
.53806 .01602 L
.53934 .01602 L
.54072 .01602 L
.54201 .01602 L
.54494 .01602 L
.54753 .01602 L
.54994 .01602 L
.55538 .01602 L
.56017 .01602 L
.56527 .01602 L
.58382 .01601 L
.62154 .01599 L
.66171 .01597 L
.68016 .01597 L
.70036 .01596 L
.72038 .01595 L
.73142 .01595 L
.74147 .01595 L
.76106 .01595 L
.77182 .01595 L
.782 .01595 L
.80199 .01595 L
.82043 .01595 L
Mistroke
.8598 .01594 L
.89766 .01594 L
.93797 .01594 L
.97619 .01594 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.04262 .09894 L
.06244 .1697 L
.08255 .22358 L
.09396 .24699 L
.10458 .26464 L
.11508 .2785 L
.125 .28866 L
.1339 .29561 L
.1389 .29869 L
.14357 .30109 L
.1485 .30314 L
.15301 .30463 L
.15802 .30586 L
.16078 .30638 L
.16341 .30676 L
.16593 .30703 L
.16734 .30714 L
.16862 .30723 L
.16982 .30728 L
.17112 .30732 L
.17234 .30734 L
.17346 .30735 L
.17478 .30733 L
.17601 .3073 L
.17671 .30728 L
.17736 .30725 L
.1788 .30717 L
.1817 .30695 L
.18444 .30667 L
.18903 .30604 L
.19409 .30517 L
.20435 .30287 L
.22277 .29757 L
.26297 .28431 L
.30166 .2735 L
.3217 .26948 L
.33178 .26794 L
.33745 .26723 L
.3428 .26666 L
.34773 .26623 L
.35307 .26586 L
.35543 .26573 L
.35793 .26561 L
.36027 .26553 L
.36241 .26547 L
.36368 .26544 L
.36489 .26542 L
.36617 .26541 L
.36689 .26541 L
Mistroke
.36756 .2654 L
.36879 .2654 L
.3699 .26541 L
.37118 .26542 L
.37239 .26544 L
.37372 .26546 L
.37514 .2655 L
.37766 .26559 L
.38038 .26571 L
.38336 .26589 L
.38862 .2663 L
.39359 .26681 L
.40291 .26812 L
.41294 .27009 L
.42384 .27302 L
.43326 .27632 L
.44365 .281 L
.4545 .28732 L
.46467 .29495 L
.47453 .30432 L
.48489 .31665 L
.50341 .34516 L
.52342 .38028 L
.54157 .40784 L
.55169 .41957 L
.56122 .42799 L
.56646 .43153 L
.57129 .43414 L
.57658 .43632 L
.57925 .43715 L
.58218 .43788 L
.58469 .43834 L
.5861 .43854 L
.58741 .43869 L
.58856 .43879 L
.58982 .43887 L
.59114 .43892 L
.59237 .43893 L
.59351 .43891 L
.59471 .43887 L
.59573 .43882 L
.59685 .43873 L
.59805 .43862 L
.59934 .43846 L
.60167 .43812 L
.60437 .4376 L
.6073 .43692 L
.61262 .43537 L
.62258 .43152 L
.64243 .42128 L
Mistroke
.66346 .40864 L
.68324 .39693 L
.70132 .38755 L
.71061 .38354 L
.72074 .37998 L
.7263 .37844 L
.73145 .3773 L
.73399 .37686 L
.73638 .37651 L
.7377 .37635 L
.73913 .3762 L
.74044 .37609 L
.74163 .37601 L
.74285 .37595 L
.744 .37591 L
.74522 .37589 L
.74591 .37588 L
.74655 .37589 L
.74761 .37591 L
.74878 .37595 L
.75 .37602 L
.75114 .37611 L
.75376 .37639 L
.75617 .37675 L
.7588 .37727 L
.76158 .37795 L
.76679 .37966 L
.77164 .38177 L
.77697 .38471 L
.78265 .3886 L
.7929 .39763 L
.80401 .41009 L
.82417 .43739 L
.84367 .46499 L
.86511 .49205 L
.88548 .51258 L
.90453 .52695 L
.91495 .53295 L
.92483 .53753 L
.9337 .54079 L
.94337 .54349 L
.94767 .54442 L
.95172 .54517 L
.95539 .54573 L
.95927 .54621 L
.96351 .54661 L
.96539 .54675 L
.96741 .54687 L
.96958 .54698 L
.97055 .54701 L
Mistroke
.9716 .54704 L
.97283 .54707 L
.974 .54709 L
.97514 .5471 L
.97619 .54711 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.04262 .09892 L
.06244 .16904 L
.08255 .22039 L
.09396 .24138 L
.10458 .25624 L
.10961 .26186 L
.11508 .26701 L
.11989 .2708 L
.125 .2741 L
.12959 .27649 L
.13466 .27855 L
.13926 .27993 L
.14135 .28042 L
.14357 .28084 L
.14615 .28123 L
.14729 .28136 L
.14854 .28148 L
.1493 .28154 L
.15 .28159 L
.15066 .28163 L
.15138 .28166 L
.15263 .2817 L
.15331 .28172 L
.15395 .28172 L
.15523 .28171 L
.15644 .28169 L
.15753 .28165 L
.15871 .28158 L
.16 .28149 L
.16137 .28138 L
.16382 .28112 L
.16836 .28046 L
.17263 .27965 L
.18234 .27726 L
.20253 .27062 L
.22103 .26357 L
.26066 .24884 L
.28062 .24261 L
.29876 .23792 L
.31838 .23399 L
.32915 .23236 L
.33933 .23118 L
.34435 .23072 L
.34905 .23037 L
.35395 .23009 L
.35655 .22997 L
.35934 .22987 L
.36171 .22981 L
.36304 .22979 L
Mistroke
.36429 .22977 L
.36548 .22976 L
.36656 .22975 L
.36781 .22975 L
.36898 .22976 L
.37006 .22977 L
.37119 .22978 L
.37216 .2298 L
.37322 .22982 L
.37558 .22988 L
.37779 .22996 L
.38281 .23022 L
.38565 .23041 L
.38827 .23062 L
.39299 .23107 L
.39818 .23169 L
.40719 .2331 L
.41675 .2351 L
.42687 .23789 L
.43614 .24117 L
.44631 .24577 L
.45701 .25204 L
.46658 .25925 L
.47679 .26905 L
.49517 .29337 L
.51512 .32779 L
.52562 .34614 L
.53672 .36332 L
.54665 .37576 L
.55191 .38108 L
.55756 .38576 L
.56275 .38915 L
.56748 .39149 L
.56976 .39237 L
.57224 .39315 L
.57458 .39373 L
.57675 .39412 L
.57793 .39428 L
.57916 .39441 L
.58022 .39449 L
.58138 .39454 L
.58262 .39456 L
.58332 .39455 L
.58396 .39453 L
.5852 .39447 L
.58636 .39438 L
.58746 .39426 L
.58862 .39411 L
.59069 .39376 L
.59293 .39328 L
Mistroke
.59539 .39264 L
.60052 .39091 L
.60603 .38855 L
.61599 .38317 L
.65723 .35257 L
.69696 .32229 L
.73517 .29959 L
.75486 .29108 L
.77584 .28443 L
.78613 .28203 L
.79726 .27999 L
.80778 .27853 L
.81744 .27751 L
.82214 .27711 L
.82719 .27676 L
.83154 .2765 L
.83628 .27628 L
.83916 .27617 L
.84183 .27609 L
.84438 .27603 L
.84567 .27601 L
.84709 .27599 L
.84837 .27597 L
.84954 .27596 L
.85082 .27596 L
.85147 .27596 L
.85218 .27596 L
.85337 .27596 L
.85465 .27597 L
.85585 .27598 L
.85695 .276 L
.85926 .27604 L
.8618 .2761 L
.86446 .27619 L
.86694 .27629 L
.87138 .27652 L
.87615 .27683 L
.88702 .27781 L
.89695 .27901 L
.91599 .28205 L
.93673 .28614 L
.97619 .29438 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.03279 .05636 L
.03793 .07671 L
.04262 .09163 L
.045 .09768 L
.04758 .10304 L
.0503 .10735 L
.05153 .10886 L
.05288 .11023 L
.05404 .11119 L
.0553 .112 L
.05662 .11262 L
.05785 .113 L
.05908 .11321 L
.06025 .11326 L
.0613 .1132 L
.06244 .11302 L
.06316 .11285 L
.06382 .11267 L
.0653 .11215 L
.06799 .11087 L
.07302 .10764 L
.08429 .09841 L
.10458 .08101 L
.125 .06607 L
.14407 .05502 L
.16239 .04671 L
.18204 .03985 L
.20328 .0343 L
.2234 .0304 L
.24331 .02752 L
.26173 .02551 L
.28039 .02396 L
.301 .02269 L
.32034 .02181 L
.3412 .02111 L
.36124 .02062 L
.38234 .02025 L
.39188 .02012 L
.40208 .02 L
.42045 .01984 L
.43069 .01977 L
.44179 .01972 L
.44689 .0197 L
.45228 .01968 L
.45688 .01967 L
.46195 .01966 L
.46444 .01966 L
.46716 .01966 L
.4684 .01966 L
Mistroke
.46973 .01965 L
.47098 .01965 L
.47211 .01965 L
.47331 .01965 L
.47441 .01965 L
.47562 .01965 L
.47689 .01965 L
.478 .01965 L
.47904 .01965 L
.48018 .01965 L
.48139 .01966 L
.48409 .01966 L
.48701 .01966 L
.49233 .01967 L
.4975 .01968 L
.50229 .0197 L
.52258 .01977 L
.53251 .0198 L
.53686 .01981 L
.5416 .01982 L
.5462 .01983 L
.5484 .01984 L
.55048 .01984 L
.55161 .01984 L
.55284 .01984 L
.55387 .01984 L
.55499 .01984 L
.55621 .01984 L
.5575 .01984 L
.55869 .01984 L
.55981 .01984 L
.56102 .01984 L
.56235 .01984 L
.56359 .01984 L
.56475 .01984 L
.56694 .01984 L
.56926 .01984 L
.57408 .01983 L
.57941 .01982 L
.58948 .01979 L
.59873 .01976 L
.61958 .01968 L
.65917 .01953 L
.69725 .01941 L
.71683 .01937 L
.73777 .01933 L
.748 .01932 L
.75909 .0193 L
.76868 .01929 L
.77924 .01929 L
Mistroke
.78418 .01928 L
.78949 .01928 L
.79408 .01928 L
.79909 .01928 L
.80473 .01928 L
.80732 .01928 L
.81008 .01928 L
.81281 .01928 L
.81529 .01927 L
.81649 .01927 L
.81778 .01927 L
.819 .01927 L
.82013 .01927 L
.82139 .01927 L
.82259 .01927 L
.82366 .01927 L
.82483 .01927 L
.8261 .01927 L
.82674 .01927 L
.82745 .01927 L
.82987 .01927 L
.83213 .01927 L
.83456 .01928 L
.83897 .01928 L
.84975 .01928 L
.85963 .01928 L
.88018 .01928 L
.89019 .01929 L
.89928 .01929 L
.90383 .01929 L
.90623 .01929 L
.90876 .01929 L
.91098 .01929 L
.91342 .01929 L
.91449 .01929 L
.91564 .01929 L
.91673 .01929 L
.91772 .01929 L
.91893 .01929 L
.92023 .01929 L
.92145 .01929 L
.92255 .01929 L
.92386 .01929 L
.92459 .01929 L
.92527 .01929 L
.92782 .01929 L
.93005 .01929 L
.93249 .01929 L
.93741 .01929 L
.94245 .01929 L
Mistroke
.94721 .01929 L
.95614 .01928 L
.97619 .01928 L
Mfstroke
0 1 .206 r
.02381 .01472 m
.04262 .09894 L
.06244 .16961 L
.08255 .22292 L
.09396 .2456 L
.10458 .26226 L
.11508 .27484 L
.12023 .27972 L
.125 .28353 L
.1339 .28896 L
.1386 .29102 L
.14115 .29192 L
.14357 .29265 L
.14592 .29323 L
.14849 .29373 L
.15082 .29408 L
.15298 .29432 L
.15431 .29442 L
.15555 .29449 L
.15667 .29453 L
.15788 .29454 L
.15851 .29454 L
.15921 .29454 L
.15993 .29452 L
.1606 .2945 L
.16181 .29444 L
.16311 .29436 L
.16546 .29414 L
.16802 .29382 L
.17268 .29302 L
.17721 .29201 L
.18141 .29088 L
.20007 .28422 L
.22067 .27503 L
.26088 .25654 L
.29956 .2422 L
.31961 .2368 L
.32981 .23463 L
.3407 .23274 L
.35105 .23137 L
.35594 .23087 L
.36045 .2305 L
.36498 .2302 L
.36737 .23008 L
.36989 .22998 L
.37095 .22994 L
.37209 .22991 L
.37307 .22989 L
.37414 .22987 L
.37539 .22985 L
Mistroke
.37658 .22984 L
.37774 .22984 L
.37881 .22984 L
.3801 .22985 L
.38075 .22985 L
.38147 .22986 L
.38273 .22989 L
.38391 .22991 L
.38656 .23 L
.38941 .23013 L
.39209 .23029 L
.39463 .23048 L
.39938 .23091 L
.4083 .23206 L
.41334 .23291 L
.418 .23385 L
.42765 .2363 L
.4367 .23932 L
.44663 .2436 L
.45731 .24966 L
.46691 .25673 L
.47739 .26673 L
.48834 .28026 L
.49851 .29586 L
.51728 .33007 L
.5376 .36578 L
.54874 .38126 L
.55899 .39219 L
.56879 .39962 L
.57373 .40229 L
.57633 .40341 L
.57915 .40443 L
.58187 .40521 L
.58438 .40577 L
.58679 .40616 L
.588 .4063 L
.58865 .40637 L
.58934 .40642 L
.59054 .40649 L
.59165 .40653 L
.59284 .40654 L
.59414 .40652 L
.59526 .40647 L
.59647 .40639 L
.5976 .40629 L
.59864 .40617 L
.60132 .40578 L
.60379 .4053 L
.60939 .40384 L
.61432 .40216 L
Mistroke
.61955 .40003 L
.6574 .3781 L
.67845 .36471 L
.69771 .35394 L
.70722 .34954 L
.7176 .34566 L
.72235 .34426 L
.7274 .34306 L
.72986 .3426 L
.73217 .34224 L
.73425 .34198 L
.7365 .34177 L
.73774 .34169 L
.73888 .34163 L
.74018 .3416 L
.74142 .34159 L
.74256 .34161 L
.74362 .34164 L
.74478 .34171 L
.74601 .3418 L
.74725 .34192 L
.74857 .34209 L
.75098 .34248 L
.75383 .3431 L
.75645 .34384 L
.76136 .34565 L
.76672 .34837 L
.77232 .3521 L
.77752 .35647 L
.78806 .36808 L
.798 .38227 L
.81659 .41413 L
.85507 .47687 L
.87496 .50033 L
.88499 .50955 L
.89601 .51777 L
.90618 .52368 L
.91547 .52776 L
.92061 .52951 L
.9262 .53102 L
.92876 .53158 L
.93148 .53209 L
.93381 .53245 L
.93637 .53278 L
.93888 .53303 L
.94015 .53312 L
.94152 .53321 L
.9428 .53327 L
.94396 .53331 L
.94513 .53334 L
Mistroke
.94624 .53335 L
.94753 .53334 L
.94818 .53333 L
.9489 .53332 L
.95016 .53328 L
.95135 .53323 L
.95274 .53315 L
.95402 .53306 L
.95689 .53281 L
.96162 .53221 L
.96678 .53133 L
.97619 .52914 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.04262 .09894 L
.06244 .16962 L
.08255 .22313 L
.09396 .24614 L
.10458 .2633 L
.11508 .2766 L
.125 .28619 L
.1339 .29263 L
.1389 .29542 L
.14357 .29757 L
.1485 .29936 L
.15301 .30062 L
.15802 .30163 L
.16078 .30202 L
.16216 .30217 L
.16341 .30229 L
.16462 .30238 L
.16593 .30246 L
.16665 .30249 L
.16732 .30252 L
.16862 .30256 L
.16975 .30257 L
.17098 .30257 L
.17226 .30255 L
.17346 .30251 L
.17415 .30248 L
.17489 .30245 L
.17623 .30237 L
.17876 .30217 L
.18171 .30187 L
.18444 .30152 L
.19407 .29984 L
.2031 .29774 L
.22371 .29177 L
.26239 .27944 L
.28204 .27385 L
.30353 .26878 L
.31346 .26688 L
.32406 .26519 L
.33407 .26392 L
.34316 .26305 L
.34801 .26271 L
.35066 .26256 L
.35314 .26244 L
.35543 .26234 L
.35752 .26228 L
.35985 .26222 L
.36113 .2622 L
.36234 .26219 L
Mistroke
.36365 .26218 L
.36484 .26218 L
.3655 .26218 L
.36621 .26218 L
.36751 .26219 L
.36872 .26221 L
.37 .26223 L
.37229 .26229 L
.37497 .26238 L
.37747 .26249 L
.38314 .26286 L
.38816 .2633 L
.39362 .26391 L
.40353 .26542 L
.41318 .26743 L
.4221 .26984 L
.43175 .27315 L
.4408 .27706 L
.45073 .28244 L
.46142 .28985 L
.47101 .29827 L
.4815 .30982 L
.50261 .341 L
.5239 .37752 L
.54322 .40513 L
.55289 .41515 L
.55797 .41931 L
.56335 .42288 L
.56805 .42532 L
.57055 .42637 L
.57323 .4273 L
.57568 .42799 L
.57793 .42848 L
.57901 .42868 L
.58018 .42885 L
.58122 .42898 L
.58232 .42909 L
.58353 .42918 L
.58465 .42922 L
.58585 .42925 L
.58716 .42923 L
.5883 .42919 L
.58951 .42911 L
.59066 .42901 L
.59171 .4289 L
.59426 .42852 L
.59704 .42797 L
.60207 .42662 L
.60737 .42474 L
.61299 .4223 L
Mistroke
.62307 .41696 L
.66093 .39089 L
.68198 .37582 L
.70123 .36344 L
.72135 .35282 L
.73115 .3487 L
.74003 .34564 L
.74922 .34322 L
.75427 .34224 L
.75903 .34156 L
.76155 .3413 L
.76293 .34118 L
.76421 .3411 L
.76531 .34104 L
.76649 .34099 L
.7678 .34095 L
.76899 .34094 L
.76965 .34094 L
.77036 .34095 L
.77164 .34097 L
.77234 .341 L
.77301 .34103 L
.77452 .34111 L
.77583 .34121 L
.77704 .34132 L
.77975 .34163 L
.78224 .34201 L
.7845 .34242 L
.78957 .34362 L
.79426 .34507 L
.79869 .34674 L
.80863 .3516 L
.8194 .35864 L
.83929 .3762 L
.86034 .39958 L
.89824 .44336 L
.91934 .46376 L
.9386 .47861 L
.95789 .48984 L
.97619 .49747 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.03279 .0569 L
.04262 .09835 L
.053 .13467 L
.06244 .15919 L
.06786 .16914 L
.07035 .17269 L
.07298 .17577 L
.07579 .17831 L
.07839 .17999 L
.07983 .18066 L
.08118 .18113 L
.08196 .18133 L
.08266 .18148 L
.08348 .18159 L
.08426 .18166 L
.08554 .18166 L
.0867 .18157 L
.08734 .18148 L
.08804 .18135 L
.0893 .18104 L
.09048 .18065 L
.09173 .18016 L
.09397 .17907 L
.09903 .17577 L
.10458 .17107 L
.145 .12635 L
.18391 .09075 L
.20515 .07671 L
.22527 .06637 L
.24518 .05846 L
.2636 .05278 L
.28227 .04832 L
.30287 .04456 L
.32222 .04192 L
.34307 .0398 L
.36311 .03833 L
.37319 .03775 L
.38421 .03724 L
.3943 .03686 L
.40382 .03657 L
.40909 .03644 L
.4148 .03632 L
.41995 .03624 L
.42477 .03617 L
.42934 .03612 L
.4319 .0361 L
.43424 .03609 L
.43548 .03608 L
.43679 .03608 L
Mistroke
.43755 .03607 L
.43824 .03607 L
.43894 .03607 L
.43958 .03607 L
.44083 .03607 L
.4415 .03607 L
.44219 .03607 L
.44336 .03607 L
.44465 .03607 L
.44533 .03607 L
.44606 .03607 L
.4474 .03608 L
.44991 .03609 L
.45284 .03611 L
.45554 .03614 L
.46047 .0362 L
.46569 .03629 L
.47509 .03653 L
.48037 .0367 L
.4852 .03689 L
.5035 .03788 L
.52406 .03944 L
.53408 .04021 L
.54317 .04081 L
.54773 .04105 L
.55267 .04128 L
.55734 .04144 L
.56163 .04155 L
.56399 .04159 L
.5662 .04163 L
.56746 .04164 L
.56861 .04165 L
.56925 .04165 L
.56995 .04166 L
.57121 .04166 L
.57242 .04167 L
.57311 .04167 L
.57376 .04166 L
.57506 .04166 L
.57579 .04166 L
.57647 .04165 L
.5776 .04164 L
.57884 .04163 L
.58133 .0416 L
.58386 .04156 L
.58661 .04151 L
.59159 .04139 L
.60092 .04109 L
.62186 .0402 L
.66275 .03822 L
Mistroke
.68308 .03735 L
.70212 .03665 L
.72153 .03606 L
.73997 .03562 L
.76024 .03524 L
.77877 .03499 L
.78836 .03489 L
.79859 .03481 L
.80823 .03474 L
.81698 .0347 L
.82186 .03468 L
.82701 .03466 L
.83624 .03464 L
.84138 .03463 L
.84617 .03462 L
.85143 .03462 L
.85706 .03461 L
.87689 .0346 L
.88232 .0346 L
.88809 .0346 L
.89301 .03459 L
.89845 .03459 L
.90835 .03457 L
.91391 .03456 L
.91901 .03455 L
.93831 .0345 L
.95641 .03443 L
.97619 .03433 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.02846 .03628 L
.03279 .05236 L
.03527 .05922 L
.03754 .06392 L
.03879 .06593 L
.04015 .06771 L
.04143 .06902 L
.04262 .06996 L
.04376 .07065 L
.04498 .07118 L
.04614 .07151 L
.0472 .07169 L
.04843 .07177 L
.04913 .07175 L
.04978 .07171 L
.05097 .07155 L
.05224 .0713 L
.05357 .07096 L
.055 .07051 L
.05759 .06952 L
.06244 .0673 L
.08293 .05651 L
.10458 .04647 L
.12413 .03935 L
.14558 .03341 L
.16509 .02936 L
.18601 .02612 L
.20725 .02369 L
.22737 .022 L
.24728 .02076 L
.2657 .0199 L
.28436 .01924 L
.30496 .01869 L
.32431 .01832 L
.34517 .01802 L
.36521 .01781 L
.38631 .01766 L
.39585 .0176 L
.40605 .01755 L
.42442 .01749 L
.43466 .01746 L
.44005 .01745 L
.44576 .01744 L
.45075 .01743 L
.45625 .01742 L
.46124 .01742 L
.46591 .01741 L
.4685 .01741 L
.47089 .01741 L
Mistroke
.47227 .01741 L
.47352 .01741 L
.47422 .01741 L
.47496 .01741 L
.47567 .01741 L
.47632 .01741 L
.47752 .01741 L
.47883 .01741 L
.4801 .01741 L
.48082 .01741 L
.48147 .01741 L
.48263 .01741 L
.4839 .01741 L
.4862 .01741 L
.48842 .01741 L
.49088 .01741 L
.49584 .01742 L
.50474 .01742 L
.52575 .01745 L
.53495 .01746 L
.54015 .01746 L
.54264 .01747 L
.54499 .01747 L
.54729 .01747 L
.5485 .01747 L
.54978 .01747 L
.55086 .01747 L
.55205 .01747 L
.55312 .01747 L
.55413 .01747 L
.55539 .01747 L
.55659 .01747 L
.55766 .01747 L
.55883 .01747 L
.5601 .01747 L
.56145 .01747 L
.56388 .01747 L
.56622 .01747 L
.56874 .01747 L
.57331 .01746 L
.58373 .01745 L
.59329 .01744 L
.60375 .01743 L
.62484 .0174 L
.66537 .01734 L
.70438 .01729 L
.7257 .01728 L
.73548 .01727 L
.74585 .01726 L
.75536 .01726 L
Mistroke
.76584 .01726 L
.77529 .01725 L
.78428 .01725 L
.79443 .01725 L
.80371 .01725 L
.81369 .01725 L
.8193 .01725 L
.82459 .01725 L
.82955 .01725 L
.83492 .01725 L
.83938 .01724 L
.84428 .01724 L
.84959 .01724 L
.8525 .01724 L
.8552 .01724 L
.85774 .01724 L
.86006 .01724 L
.86134 .01724 L
.86273 .01724 L
.86404 .01724 L
.86525 .01724 L
.86643 .01724 L
.86767 .01724 L
.86873 .01724 L
.86989 .01724 L
.87115 .01724 L
.87248 .01724 L
.87489 .01724 L
.88393 .01724 L
.8866 .01724 L
.8881 .01724 L
.88882 .01724 L
.88949 .01724 L
.8907 .01724 L
.89135 .01724 L
.89204 .01724 L
.89276 .01724 L
.89345 .01724 L
.89473 .01724 L
.89591 .01724 L
.89717 .01724 L
.89835 .01724 L
.89943 .01724 L
.90206 .01724 L
.90454 .01724 L
.90696 .01724 L
.90922 .01724 L
.91434 .01724 L
.91933 .01724 L
.92467 .01724 L
Mistroke
.93435 .01724 L
.94316 .01724 L
.959 .01724 L
.97619 .01724 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.04262 .09891 L
.06244 .16859 L
.07286 .1967 L
.08255 .21757 L
.0932 .23472 L
.09916 .24183 L
.10458 .24683 L
.10941 .25019 L
.11185 .25151 L
.11454 .25269 L
.11682 .25348 L
.11808 .25383 L
.11928 .25411 L
.12039 .25433 L
.1216 .25452 L
.1227 .25464 L
.12373 .25473 L
.12503 .25478 L
.12577 .25479 L
.12644 .25478 L
.12769 .25474 L
.129 .25464 L
.13018 .2545 L
.13128 .25435 L
.13379 .25387 L
.13649 .25317 L
.13896 .25239 L
.14451 .25015 L
.15442 .24481 L
.16359 .23872 L
.18435 .22272 L
.22362 .19189 L
.26137 .16789 L
.28072 .15837 L
.30158 .15012 L
.32162 .144 L
.33182 .14151 L
.34271 .13927 L
.35306 .13753 L
.36246 .13628 L
.3719 .13531 L
.37651 .13494 L
.38082 .13466 L
.38545 .13443 L
.38791 .13434 L
.39054 .13426 L
.39186 .13423 L
.3933 .13421 L
.39396 .1342 L
Mistroke
.39466 .13419 L
.39592 .13418 L
.39656 .13418 L
.39725 .13418 L
.3985 .13418 L
.39972 .13418 L
.40084 .13419 L
.40191 .13421 L
.40305 .13423 L
.40512 .13428 L
.40758 .13436 L
.40982 .13445 L
.41468 .13472 L
.41929 .13507 L
.42389 .13551 L
.42897 .13612 L
.43924 .13779 L
.44875 .13996 L
.45767 .14269 L
.46753 .14672 L
.47789 .15251 L
.48674 .15911 L
.49641 .16851 L
.51606 .19489 L
.53702 .2265 L
.54729 .23923 L
.5527 .24468 L
.55841 .24943 L
.56341 .25272 L
.56606 .25414 L
.56891 .25542 L
.57152 .25638 L
.57391 .25708 L
.5763 .25762 L
.57857 .25799 L
.57971 .25812 L
.58093 .25822 L
.58209 .25829 L
.58315 .25832 L
.58433 .25832 L
.58562 .25828 L
.58627 .25825 L
.58696 .2582 L
.58821 .2581 L
.58954 .25794 L
.59097 .25773 L
.59358 .25725 L
.59846 .256 L
.60311 .25444 L
.60804 .25244 L
Mistroke
.61687 .24814 L
.65473 .22468 L
.67578 .21166 L
.69503 .20129 L
.70455 .1969 L
.71493 .19276 L
.72466 .18955 L
.73383 .18719 L
.73879 .18621 L
.7414 .18578 L
.74415 .1854 L
.74648 .18514 L
.74771 .18503 L
.74903 .18492 L
.75024 .18484 L
.75135 .18479 L
.75246 .18474 L
.75351 .18472 L
.75472 .1847 L
.7554 .1847 L
.75605 .18471 L
.75734 .18473 L
.75807 .18476 L
.75874 .18479 L
.75986 .18485 L
.76109 .18494 L
.76356 .18519 L
.7663 .18558 L
.76923 .18614 L
.77449 .18754 L
.77708 .18844 L
.77983 .18956 L
.78474 .19205 L
.79004 .19547 L
.79585 .20024 L
.80627 .21169 L
.81601 .22584 L
.85485 .3008 L
.87462 .33569 L
.88505 .35044 L
.89615 .36285 L
.90174 .36777 L
.90699 .37157 L
.9121 .37452 L
.9168 .37659 L
.92127 .378 L
.92353 .3785 L
.9248 .37873 L
.926 .3789 L
.9273 .37905 L
Mistroke
.92848 .37915 L
.92975 .37921 L
.93047 .37923 L
.93114 .37924 L
.93224 .37922 L
.93346 .37917 L
.93474 .37908 L
.93593 .37896 L
.93717 .3788 L
.9385 .37859 L
.94089 .37811 L
.94373 .37737 L
.9463 .37656 L
.95617 .3722 L
.9657 .36635 L
.97469 .35962 L
.97619 .3584 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.04262 .09894 L
.06244 .16965 L
.08255 .22337 L
.09396 .24666 L
.10458 .26423 L
.11508 .27809 L
.125 .28833 L
.1339 .29544 L
.1389 .29864 L
.14357 .30119 L
.15301 .3051 L
.15802 .30657 L
.16341 .30775 L
.1661 .30819 L
.16904 .30856 L
.17038 .3087 L
.17182 .30882 L
.17316 .30892 L
.17439 .30899 L
.1757 .30905 L
.17638 .30907 L
.17711 .30909 L
.17832 .30911 L
.17902 .30911 L
.17966 .30911 L
.18087 .3091 L
.18197 .30908 L
.18324 .30905 L
.18444 .309 L
.18681 .30887 L
.18903 .30871 L
.19409 .30821 L
.19903 .30756 L
.20435 .30671 L
.22277 .30288 L
.26391 .29245 L
.28444 .28767 L
.30353 .28397 L
.32196 .28127 L
.33227 .28018 L
.33673 .2798 L
.34164 .27947 L
.34649 .27921 L
.34914 .27911 L
.35162 .27903 L
.35281 .279 L
.35394 .27898 L
.35497 .27896 L
.35606 .27894 L
Mistroke
.35724 .27893 L
.35834 .27893 L
.35964 .27892 L
.36083 .27893 L
.36213 .27894 L
.36279 .27895 L
.36351 .27896 L
.36479 .27898 L
.36598 .27901 L
.36866 .27909 L
.37154 .2792 L
.37682 .2795 L
.38162 .27988 L
.38645 .28036 L
.39156 .28098 L
.40075 .28243 L
.41063 .28451 L
.42152 .28753 L
.43164 .29116 L
.44091 .29533 L
.45108 .30106 L
.46178 .30871 L
.47135 .3173 L
.48156 .32865 L
.49994 .35502 L
.51989 .38829 L
.53039 .40461 L
.54149 .41929 L
.55142 .42966 L
.55668 .43403 L
.56233 .43787 L
.56752 .44064 L
.57225 .44255 L
.57453 .44327 L
.57701 .4439 L
.57935 .44437 L
.58152 .44469 L
.5827 .44482 L
.58393 .44493 L
.58499 .44499 L
.58614 .44503 L
.58739 .44504 L
.58809 .44504 L
.58873 .44502 L
.58996 .44497 L
.59113 .44489 L
.59223 .4448 L
.59338 .44467 L
.59546 .44438 L
.5977 .44399 L
Mistroke
.60016 .44345 L
.60529 .44202 L
.6108 .44006 L
.62076 .43556 L
.662 .40948 L
.70173 .38351 L
.72177 .37293 L
.73994 .36556 L
.75008 .36252 L
.75473 .36142 L
.75963 .36046 L
.76213 .36005 L
.76488 .35968 L
.76741 .3594 L
.76971 .3592 L
.77101 .35911 L
.77243 .35903 L
.77321 .359 L
.77393 .35897 L
.77462 .35895 L
.77535 .35894 L
.77664 .35892 L
.77785 .35893 L
.77854 .35894 L
.77918 .35895 L
.77987 .35897 L
.78061 .359 L
.78184 .35906 L
.78318 .35914 L
.78561 .35935 L
.78798 .35962 L
.79016 .35992 L
.79512 .36084 L
.80036 .36214 L
.80911 .36511 L
.81873 .36958 L
.82891 .37569 L
.8382 .38248 L
.85909 .40126 L
.89888 .44228 L
.93714 .4756 L
.95606 .48784 L
.97619 .49784 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.04262 .09894 L
.06244 .16946 L
.08255 .22234 L
.09396 .24475 L
.10458 .26124 L
.11508 .27381 L
.125 .28271 L
.1339 .28854 L
.13893 .29103 L
.14357 .29287 L
.14823 .29431 L
.1508 .29493 L
.15324 .29543 L
.1555 .29581 L
.15797 .29613 L
.15906 .29624 L
.16021 .29635 L
.16123 .29642 L
.1623 .29649 L
.16296 .29652 L
.16369 .29655 L
.16497 .29658 L
.1657 .2966 L
.16647 .2966 L
.1672 .2966 L
.16787 .29659 L
.16916 .29656 L
.16989 .29654 L
.17056 .29651 L
.17188 .29645 L
.17312 .29637 L
.17538 .29618 L
.17787 .29592 L
.18292 .29523 L
.19276 .29334 L
.20311 .29075 L
.22161 .28518 L
.25972 .27284 L
.28097 .26672 L
.30028 .26209 L
.30992 .26017 L
.32036 .2584 L
.33016 .25706 L
.33933 .25608 L
.34427 .25567 L
.34879 .25537 L
.35381 .25511 L
.35658 .25501 L
.35795 .25498 L
Mistroke
.3592 .25495 L
.36051 .25492 L
.36173 .2549 L
.36303 .25489 L
.36376 .25489 L
.36443 .25489 L
.36555 .25489 L
.36678 .25489 L
.36807 .25491 L
.36927 .25492 L
.37069 .25495 L
.37204 .25499 L
.37457 .25507 L
.37729 .25519 L
.38024 .25536 L
.38511 .25571 L
.38967 .25614 L
.39509 .25678 L
.40006 .2575 L
.41018 .25939 L
.42108 .26214 L
.43091 .2654 L
.44004 .26922 L
.45006 .27451 L
.46076 .28174 L
.47102 .29065 L
.48214 .30298 L
.50231 .33305 L
.52183 .3672 L
.53218 .38393 L
.54328 .39909 L
.55394 .41033 L
.56367 .41762 L
.56836 .42014 L
.57083 .42122 L
.57346 .42219 L
.57574 .42288 L
.57827 .42349 L
.57938 .42371 L
.58057 .4239 L
.58168 .42406 L
.58273 .42418 L
.58398 .42429 L
.58512 .42435 L
.58635 .42439 L
.58704 .4244 L
.58768 .4244 L
.58874 .42437 L
.58992 .42432 L
.59114 .42423 L
Mistroke
.59229 .42412 L
.59492 .42377 L
.59733 .42333 L
.60275 .42196 L
.60792 .42021 L
.61356 .41785 L
.62384 .41256 L
.6645 .3845 L
.70365 .35609 L
.72364 .34341 L
.74526 .33181 L
.76614 .3229 L
.78534 .31668 L
.80418 .31219 L
.82485 .30853 L
.84601 .30558 L
.86529 .30342 L
.87487 .30256 L
.88529 .3018 L
.89006 .30153 L
.89513 .30128 L
.89956 .3011 L
.90422 .30096 L
.90656 .30091 L
.90912 .30086 L
.91024 .30085 L
.91144 .30083 L
.91257 .30082 L
.9136 .30081 L
.91491 .3008 L
.9156 .3008 L
.91633 .3008 L
.91755 .30079 L
.91825 .30079 L
.9189 .3008 L
.92011 .3008 L
.92122 .30081 L
.9225 .30081 L
.92371 .30083 L
.92591 .30085 L
.92825 .30089 L
.93246 .30098 L
.93746 .30111 L
.94199 .30127 L
.95844 .302 L
.97619 .30299 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.04262 .09838 L
.0522 .13253 L
.06244 .16071 L
.0679 .17189 L
.07286 .17976 L
.07525 .18279 L
.07784 .18553 L
.08027 .18761 L
.08255 .18915 L
.0852 .19045 L
.0866 .19095 L
.08811 .19133 L
.08887 .19147 L
.08969 .19158 L
.09047 .19165 L
.09119 .19168 L
.09191 .19168 L
.09255 .19166 L
.0933 .1916 L
.09401 .19152 L
.09529 .1913 L
.09665 .19099 L
.09909 .1902 L
.1017 .18908 L
.10458 .18755 L
.11478 .18011 L
.12409 .17154 L
.145 .15009 L
.18485 .11313 L
.22318 .08797 L
.24295 .07863 L
.26396 .0709 L
.28343 .06537 L
.30171 .06133 L
.32189 .05791 L
.3404 .05557 L
.35932 .05379 L
.37005 .05303 L
.38002 .05245 L
.39055 .05198 L
.39571 .05179 L
.40048 .05165 L
.40473 .05154 L
.4094 .05145 L
.4141 .05138 L
.41667 .05135 L
.41907 .05133 L
.42032 .05132 L
.42101 .05132 L
Mistroke
.42165 .05132 L
.42291 .05132 L
.42405 .05131 L
.42471 .05131 L
.42541 .05131 L
.42666 .05132 L
.42735 .05132 L
.428 .05132 L
.42948 .05133 L
.43076 .05134 L
.43197 .05135 L
.43425 .05137 L
.4367 .05141 L
.43936 .05145 L
.44403 .05156 L
.44899 .05171 L
.45789 .05208 L
.4628 .05235 L
.46729 .05265 L
.4774 .05351 L
.48632 .05453 L
.4957 .05593 L
.51548 .06008 L
.53386 .06459 L
.54441 .0668 L
.54958 .06767 L
.55435 .06833 L
.55869 .06882 L
.56328 .0692 L
.56567 .06936 L
.56789 .06947 L
.57033 .06956 L
.5717 .0696 L
.57295 .06962 L
.57413 .06964 L
.57523 .06965 L
.57644 .06965 L
.57775 .06965 L
.57905 .06964 L
.5797 .06963 L
.58041 .06962 L
.58169 .06959 L
.58285 .06956 L
.58514 .06949 L
.5876 .06939 L
.59201 .06915 L
.60268 .06834 L
.61277 .06735 L
.6512 .06278 L
.67066 .06054 L
Mistroke
.69209 .05841 L
.71265 .05675 L
.73146 .05561 L
.74142 .05514 L
.75088 .05481 L
.75606 .05467 L
.76087 .05457 L
.76364 .05452 L
.76614 .05449 L
.76754 .05448 L
.76904 .05446 L
.76973 .05446 L
.77046 .05446 L
.77177 .05445 L
.77299 .05445 L
.77368 .05445 L
.77431 .05445 L
.77549 .05445 L
.77673 .05446 L
.77784 .05446 L
.77888 .05447 L
.78125 .0545 L
.78381 .05453 L
.78615 .05458 L
.79142 .05472 L
.79569 .05488 L
.80035 .05509 L
.80976 .05569 L
.82004 .05659 L
.82938 .05763 L
.85034 .06065 L
.87116 .06404 L
.88029 .06544 L
.89034 .06681 L
.89936 .06784 L
.90904 .06869 L
.91438 .06904 L
.91926 .06928 L
.92161 .06938 L
.92417 .06946 L
.92659 .06952 L
.92883 .06956 L
.93012 .06958 L
.93083 .06958 L
.93148 .06959 L
.93265 .0696 L
.93393 .0696 L
.93464 .0696 L
.93532 .0696 L
.93659 .0696 L
Mistroke
.93729 .06959 L
.93795 .06959 L
.93943 .06957 L
.94062 .06955 L
.94173 .06953 L
.94427 .06948 L
.9494 .06932 L
.95409 .06913 L
.95837 .06892 L
.96803 .06833 L
.97619 .06773 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.04262 .09892 L
.06244 .16912 L
.08255 .22076 L
.09396 .24195 L
.10458 .25701 L
.10961 .2627 L
.11508 .26793 L
.11989 .27176 L
.125 .27508 L
.12959 .27748 L
.13466 .27951 L
.13687 .28021 L
.13926 .28085 L
.14152 .28134 L
.14357 .2817 L
.14611 .28203 L
.1475 .28217 L
.14881 .28226 L
.15003 .28232 L
.15115 .28235 L
.15238 .28237 L
.15368 .28236 L
.15499 .28232 L
.15573 .28229 L
.1564 .28225 L
.15894 .28206 L
.16036 .28191 L
.1619 .28172 L
.16471 .28129 L
.16977 .2803 L
.17514 .27897 L
.1848 .27596 L
.22255 .26025 L
.26275 .24314 L
.28123 .23651 L
.30144 .23049 L
.32148 .2259 L
.33241 .22398 L
.34258 .22258 L
.34763 .22203 L
.3531 .22153 L
.35827 .22116 L
.36073 .22102 L
.36304 .22091 L
.36528 .22082 L
.36733 .22076 L
.36843 .22073 L
.36961 .22071 L
.37087 .22069 L
Mistroke
.37206 .22067 L
.37333 .22067 L
.37447 .22067 L
.37578 .22067 L
.37702 .22068 L
.37818 .2207 L
.37924 .22072 L
.38162 .22078 L
.38409 .22087 L
.38634 .22098 L
.39138 .2213 L
.39606 .2217 L
.40049 .22218 L
.4104 .22364 L
.41599 .22472 L
.42116 .22589 L
.43017 .22841 L
.43987 .23191 L
.45051 .23693 L
.46048 .24307 L
.47008 .25066 L
.48056 .26133 L
.50167 .29184 L
.52297 .33054 L
.54229 .36149 L
.55195 .37304 L
.55703 .3779 L
.56241 .38213 L
.56712 .38508 L
.56961 .38636 L
.57229 .38753 L
.57475 .38842 L
.57699 .38908 L
.57925 .3896 L
.58138 .38997 L
.58252 .39011 L
.58375 .39024 L
.5849 .39032 L
.58596 .39036 L
.58714 .39038 L
.58843 .39036 L
.58908 .39033 L
.58977 .3903 L
.59102 .3902 L
.59235 .39006 L
.59378 .38987 L
.59639 .38941 L
.60127 .38818 L
.60592 .38661 L
.61085 .38455 L
Mistroke
.61968 .38 L
.65754 .35286 L
.69784 .32078 L
.73664 .29467 L
.75779 .2836 L
.77788 .27529 L
.7977 .26901 L
.81609 .26451 L
.85524 .25704 L
.89685 .25021 L
.91773 .24725 L
.93693 .24493 L
.9755 .24151 L
.97619 .24147 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.04262 .0989 L
.06244 .16845 L
.07286 .19649 L
.08255 .21739 L
.0932 .23479 L
.09916 .24215 L
.10458 .24748 L
.10941 .25118 L
.11206 .25282 L
.11454 .25411 L
.11891 .25587 L
.12123 .25653 L
.12373 .25706 L
.12511 .25727 L
.12639 .25741 L
.12712 .25747 L
.12779 .25751 L
.12856 .25754 L
.12929 .25756 L
.12993 .25756 L
.13061 .25755 L
.13183 .2575 L
.13314 .25741 L
.13389 .25733 L
.13458 .25725 L
.13709 .25687 L
.13937 .2564 L
.14451 .25494 L
.14932 .25313 L
.15442 .25081 L
.16359 .24579 L
.18435 .23192 L
.22211 .20473 L
.26231 .18036 L
.28079 .17159 L
.301 .16377 L
.32104 .15773 L
.33209 .15508 L
.34214 .15307 L
.35155 .15153 L
.36175 .1502 L
.36735 .14963 L
.37252 .14919 L
.37746 .14887 L
.38015 .14872 L
.3827 .14861 L
.38506 .14853 L
.3863 .14849 L
.38763 .14846 L
Mistroke
.38885 .14844 L
.38997 .14842 L
.39108 .14841 L
.39213 .1484 L
.39337 .1484 L
.39467 .1484 L
.39579 .14841 L
.39701 .14842 L
.39832 .14845 L
.39973 .14848 L
.40227 .14855 L
.40463 .14864 L
.4072 .14877 L
.41186 .14907 L
.41639 .14946 L
.42058 .1499 L
.43024 .15129 L
.43929 .1531 L
.44921 .1558 L
.4599 .15979 L
.4695 .16463 L
.47998 .17176 L
.49093 .18189 L
.50109 .19425 L
.51987 .2235 L
.54019 .2557 L
.55133 .26936 L
.55621 .27409 L
.56158 .27837 L
.56665 .28153 L
.57138 .28372 L
.57399 .28463 L
.57638 .28528 L
.5777 .28557 L
.57913 .28583 L
.58049 .28602 L
.58174 .28615 L
.58292 .28623 L
.58415 .28628 L
.58521 .28629 L
.58637 .28627 L
.58761 .28621 L
.58831 .28615 L
.58895 .2861 L
.5902 .28596 L
.59135 .2858 L
.59358 .28541 L
.596 .28486 L
.60038 .28356 L
.60514 .28176 L
Mistroke
.61038 .27934 L
.62098 .27333 L
.66128 .24319 L
.70008 .21383 L
.7198 .20114 L
.74132 .18954 L
.76216 .18056 L
.78105 .1742 L
.80074 .16916 L
.82171 .1652 L
.84098 .16243 L
.8618 .15992 L
.90282 .15521 L
.94233 .15049 L
.97619 .14667 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.02846 .03626 L
.03279 .05212 L
.03527 .05868 L
.03754 .06303 L
.03879 .06482 L
.04015 .06635 L
.04143 .06743 L
.04262 .06816 L
.04376 .06866 L
.04498 .06899 L
.04614 .06915 L
.0472 .06918 L
.04843 .0691 L
.04913 .06901 L
.04978 .06889 L
.05097 .06862 L
.05224 .06826 L
.05759 .06613 L
.06244 .06375 L
.08269 .05313 L
.10458 .04342 L
.12545 .03635 L
.14465 .03143 L
.16347 .02776 L
.18413 .02474 L
.20364 .02263 L
.22456 .02095 L
.2458 .01971 L
.26592 .01886 L
.28583 .01823 L
.30425 .0178 L
.32291 .01747 L
.34352 .0172 L
.36286 .01701 L
.38372 .01687 L
.40376 .01677 L
.41384 .01673 L
.42486 .01669 L
.43495 .01667 L
.44447 .01665 L
.45545 .01663 L
.46019 .01662 L
.46542 .01662 L
.47011 .01661 L
.47514 .01661 L
.48046 .01661 L
.48284 .01661 L
.48543 .01661 L
.488 .0166 L
Mistroke
.48925 .0166 L
.49038 .0166 L
.49147 .0166 L
.49265 .0166 L
.4939 .0166 L
.49507 .0166 L
.49614 .0166 L
.49731 .0166 L
.49853 .0166 L
.49967 .0166 L
.50073 .0166 L
.5017 .0166 L
.50389 .0166 L
.50618 .0166 L
.50871 .0166 L
.51382 .01661 L
.52301 .01661 L
.52817 .01661 L
.53373 .01661 L
.53629 .01661 L
.53898 .01661 L
.54009 .01661 L
.54127 .01661 L
.54257 .01661 L
.54378 .01661 L
.54502 .01661 L
.54572 .01661 L
.54638 .01661 L
.54707 .01661 L
.54771 .01661 L
.54844 .01661 L
.54913 .01661 L
.55035 .01661 L
.55149 .01661 L
.55405 .01661 L
.55661 .01661 L
.55944 .01661 L
.56517 .01661 L
.57017 .01661 L
.57557 .0166 L
.58533 .0166 L
.62644 .01656 L
.66603 .01653 L
.68597 .01652 L
.70411 .01651 L
.7237 .0165 L
.73459 .01649 L
.74464 .01649 L
.75376 .01649 L
.7638 .01649 L
Mistroke
.77389 .01649 L
.77938 .01648 L
.78459 .01648 L
.78944 .01648 L
.79473 .01648 L
.79706 .01648 L
.79955 .01648 L
.80187 .01648 L
.80401 .01648 L
.80672 .01648 L
.80815 .01648 L
.80887 .01648 L
.80965 .01648 L
.81096 .01648 L
.81219 .01648 L
.81293 .01648 L
.81364 .01648 L
.81428 .01648 L
.81497 .01648 L
.81616 .01648 L
.81747 .01648 L
.81884 .01648 L
.82012 .01648 L
.82242 .01648 L
.82489 .01648 L
.82986 .01648 L
.83448 .01648 L
.84495 .01648 L
.86605 .01649 L
.8848 .01649 L
.89467 .01649 L
.90512 .01649 L
.91041 .01649 L
.91322 .01649 L
.91624 .01649 L
.919 .01649 L
.92153 .01649 L
.92275 .01649 L
.92407 .01649 L
.92532 .01649 L
.92648 .01649 L
.92775 .01649 L
.92847 .01649 L
.92912 .01649 L
.93033 .01649 L
.93161 .01649 L
.93275 .01649 L
.93382 .01649 L
.93625 .01649 L
.93887 .01649 L
Mistroke
.94127 .01649 L
.94664 .01649 L
.954 .01649 L
.96081 .01649 L
.97619 .01649 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.04262 .09894 L
.06244 .16963 L
.08255 .22309 L
.09396 .246 L
.10458 .26296 L
.11508 .27594 L
.125 .28508 L
.1339 .29098 L
.13893 .29344 L
.14357 .2952 L
.14823 .29651 L
.15085 .29706 L
.15324 .29745 L
.15546 .29772 L
.15672 .29784 L
.15788 .29792 L
.159 .29798 L
.16002 .29802 L
.16119 .29804 L
.1623 .29804 L
.16349 .29802 L
.16481 .29798 L
.16547 .29795 L
.16618 .29791 L
.16746 .29782 L
.16994 .29758 L
.17221 .29729 L
.17771 .29635 L
.18292 .29517 L
.19258 .29235 L
.20283 .28867 L
.22125 .28099 L
.259 .26432 L
.27998 .25604 L
.29921 .24957 L
.31805 .24446 L
.32765 .24235 L
.33789 .24048 L
.34824 .239 L
.35764 .23802 L
.36217 .23768 L
.36456 .23753 L
.36708 .2374 L
.36929 .23731 L
.37047 .23727 L
.37172 .23723 L
.37288 .2372 L
.37393 .23718 L
.375 .23716 L
Mistroke
.376 .23715 L
.37725 .23715 L
.37796 .23715 L
.3786 .23715 L
.37979 .23716 L
.38105 .23717 L
.38217 .23719 L
.38323 .23722 L
.38561 .23729 L
.3882 .2374 L
.39056 .23753 L
.39585 .23792 L
.40038 .23837 L
.4053 .23899 L
.41425 .24049 L
.42367 .24266 L
.43406 .24588 L
.44491 .25039 L
.45508 .25597 L
.46494 .26299 L
.4753 .27255 L
.49382 .29672 L
.53198 .36616 L
.55163 .39519 L
.56262 .40664 L
.5726 .41404 L
.57746 .41668 L
.5826 .41883 L
.58699 .42018 L
.58949 .42075 L
.59182 .42117 L
.59311 .42135 L
.59451 .42152 L
.59584 .42164 L
.59707 .42172 L
.59817 .42177 L
.59939 .42179 L
.60066 .4218 L
.60186 .42177 L
.60317 .42172 L
.60384 .42168 L
.60456 .42163 L
.60704 .4214 L
.60844 .42123 L
.60993 .42101 L
.61263 .42055 L
.61795 .41936 L
.62286 .41798 L
.63395 .41404 L
.6541 .40508 L
Mistroke
.67443 .39545 L
.68437 .39109 L
.69347 .38755 L
.70219 .38471 L
.7068 .38347 L
.71171 .38239 L
.71444 .38191 L
.71692 .38155 L
.71812 .38141 L
.71942 .38128 L
.72063 .38117 L
.72177 .38109 L
.72292 .38103 L
.72419 .38099 L
.72542 .38097 L
.72674 .38098 L
.72797 .38101 L
.72914 .38106 L
.73018 .38113 L
.73132 .38123 L
.73366 .3815 L
.73618 .38191 L
.73855 .38242 L
.74073 .38299 L
.74579 .38475 L
.75111 .3873 L
.75631 .39057 L
.76115 .39437 L
.77212 .40593 L
.78266 .42087 L
.7926 .43761 L
.81119 .47096 L
.82952 .50061 L
.84967 .52648 L
.86957 .54508 L
.88044 .55263 L
.89061 .55821 L
.90103 .56256 L
.90616 .56423 L
.91092 .56552 L
.91557 .56655 L
.91979 .56729 L
.92447 .56791 L
.92704 .56816 L
.92946 .56834 L
.93063 .56841 L
.93188 .56847 L
.93306 .56851 L
.93413 .56854 L
.9354 .56856 L
Mistroke
.93611 .56857 L
.93677 .56857 L
.93797 .56856 L
.93926 .56854 L
.94048 .56851 L
.94179 .56846 L
.94417 .56834 L
.947 .56813 L
.94959 .56788 L
.95412 .56733 L
.95907 .56656 L
.96808 .5647 L
.97619 .56258 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.04262 .09894 L
.06244 .1698 L
.08255 .22433 L
.09409 .24884 L
.10458 .2674 L
.12415 .29372 L
.13491 .3042 L
.14509 .31188 L
.15478 .31741 L
.16009 .31979 L
.16506 .32163 L
.16964 .32302 L
.17384 .32405 L
.17849 .32496 L
.18112 .32536 L
.1835 .32567 L
.18579 .3259 L
.18827 .3261 L
.18963 .32619 L
.19088 .32625 L
.19208 .3263 L
.19335 .32634 L
.19444 .32636 L
.1956 .32638 L
.1967 .32638 L
.19771 .32638 L
.19888 .32636 L
.20016 .32633 L
.20137 .3263 L
.20249 .32625 L
.20495 .32613 L
.20726 .32598 L
.21254 .32551 L
.21767 .32493 L
.22321 .32417 L
.26435 .31624 L
.28488 .31206 L
.30398 .30868 L
.3224 .30614 L
.33271 .3051 L
.33718 .30475 L
.34208 .30442 L
.34693 .30418 L
.34958 .30408 L
.35207 .30401 L
.35325 .30398 L
.35438 .30396 L
.35541 .30394 L
.3565 .30393 L
Mistroke
.35769 .30392 L
.35878 .30392 L
.36009 .30392 L
.36127 .30392 L
.36257 .30393 L
.36323 .30394 L
.36395 .30395 L
.36642 .30401 L
.36781 .30405 L
.3693 .3041 L
.37198 .30421 L
.37726 .30452 L
.38207 .30491 L
.39201 .30604 L
.40119 .30751 L
.41127 .30968 L
.42196 .31272 L
.43136 .31612 L
.44147 .32072 L
.45977 .33227 L
.46936 .3405 L
.47985 .35163 L
.50096 .38123 L
.52225 .41596 L
.54157 .44318 L
.55123 .45372 L
.5617 .4626 L
.5665 .46582 L
.57157 .46867 L
.57624 .4708 L
.58067 .47242 L
.58304 .47313 L
.58562 .47379 L
.58776 .47425 L
.59013 .47467 L
.59269 .47501 L
.59409 .47516 L
.5954 .47526 L
.59663 .47534 L
.59775 .47539 L
.59898 .47543 L
.60028 .47545 L
.60143 .47544 L
.60247 .47542 L
.60368 .47538 L
.60481 .47532 L
.60684 .47518 L
.60903 .47498 L
.61145 .47469 L
.61401 .47431 L
Mistroke
.61861 .47347 L
.62803 .47119 L
.63816 .46809 L
.65646 .46145 L
.67619 .45397 L
.68661 .45033 L
.69771 .44697 L
.70328 .44555 L
.70852 .44441 L
.71362 .44352 L
.71586 .4432 L
.71831 .4429 L
.72047 .44269 L
.72278 .44253 L
.72406 .44246 L
.72522 .44241 L
.72639 .44238 L
.7275 .44237 L
.7287 .44237 L
.72998 .44239 L
.73106 .44242 L
.73226 .44248 L
.73355 .44256 L
.73493 .44267 L
.73744 .44295 L
.73984 .4433 L
.7424 .44377 L
.74702 .44489 L
.75251 .44671 L
.75749 .44886 L
.76835 .45534 L
.7786 .4638 L
.81708 .50828 L
.83658 .52998 L
.85802 .54915 L
.86784 .5562 L
.87839 .56261 L
.89744 .57146 L
.90758 .57489 L
.91863 .57774 L
.92369 .57877 L
.92907 .57968 L
.93411 .58038 L
.93874 .5809 L
.94326 .58129 L
.94802 .5816 L
.9505 .58172 L
.9528 .5818 L
.9541 .58184 L
.95533 .58187 L
Mistroke
.95601 .58188 L
.95675 .58189 L
.95804 .58191 L
.95917 .58191 L
.96022 .58192 L
.96138 .58191 L
.96262 .5819 L
.96392 .58189 L
.96516 .58187 L
.96748 .58181 L
.96964 .58175 L
.97164 .58167 L
.97619 .58145 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.04262 .09894 L
.06244 .16968 L
.08255 .22352 L
.09396 .24695 L
.10458 .2647 L
.11508 .27878 L
.125 .28926 L
.1339 .29661 L
.14357 .30265 L
.15301 .30685 L
.15838 .30859 L
.16341 .30984 L
.16612 .31037 L
.1687 .31079 L
.17104 .3111 L
.17354 .31136 L
.17496 .31148 L
.17624 .31157 L
.17755 .31164 L
.17875 .3117 L
.17942 .31172 L
.18016 .31174 L
.1809 .31176 L
.18168 .31177 L
.18237 .31177 L
.18311 .31177 L
.1838 .31177 L
.18444 .31176 L
.18562 .31174 L
.18672 .31171 L
.18794 .31167 L
.18925 .31161 L
.19191 .31144 L
.19435 .31125 L
.19882 .3108 L
.20352 .3102 L
.22428 .30643 L
.26239 .29757 L
.28364 .29294 L
.30295 .28942 L
.31259 .28799 L
.32304 .28671 L
.32783 .28623 L
.3329 .28579 L
.33757 .28545 L
.342 .2852 L
.34436 .28508 L
.34693 .28498 L
.34927 .28491 L
Mistroke
.35144 .28486 L
.35276 .28483 L
.35401 .28482 L
.35513 .28481 L
.35635 .2848 L
.35698 .2848 L
.35767 .2848 L
.3584 .2848 L
.35907 .28481 L
.36028 .28482 L
.36157 .28483 L
.3628 .28485 L
.36393 .28488 L
.3665 .28495 L
.36876 .28504 L
.37116 .28515 L
.37531 .2854 L
.37989 .28576 L
.38482 .28624 L
.39001 .28686 L
.39927 .28831 L
.40925 .29038 L
.42014 .29336 L
.43044 .297 L
.43979 .30114 L
.45071 .30724 L
.46076 .31434 L
.47998 .3332 L
.49009 .34641 L
.50079 .36266 L
.52063 .39534 L
.53873 .42137 L
.54873 .4324 L
.55821 .44034 L
.56341 .44365 L
.56822 .44609 L
.57351 .44809 L
.57617 .44884 L
.57912 .44948 L
.58146 .44984 L
.58279 .45 L
.58403 .45011 L
.58534 .45019 L
.58653 .45023 L
.58718 .45024 L
.5879 .45024 L
.5892 .45022 L
.59031 .45018 L
.59153 .4501 L
.59281 .44999 L
Mistroke
.59401 .44986 L
.59614 .44956 L
.59844 .44916 L
.60403 .44781 L
.60933 .4461 L
.61929 .44193 L
.63911 .43085 L
.6575 .41871 L
.69665 .39243 L
.71664 .38073 L
.73826 .37034 L
.74841 .36641 L
.75914 .36299 L
.7683 .36067 L
.77834 .35881 L
.78359 .35812 L
.78617 .35786 L
.78856 .35765 L
.79068 .35751 L
.79302 .35738 L
.79423 .35733 L
.79537 .35729 L
.79657 .35726 L
.79787 .35725 L
.79918 .35724 L
.80041 .35724 L
.80111 .35725 L
.80175 .35726 L
.80249 .35727 L
.80319 .35729 L
.80458 .35733 L
.80587 .35739 L
.80878 .35755 L
.8111 .35773 L
.81364 .35797 L
.81879 .3586 L
.82401 .35944 L
.82896 .36044 L
.83825 .36286 L
.84825 .36628 L
.85915 .37098 L
.89986 .39581 L
.93907 .42299 L
.97619 .44404 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02085 L
.02846 .02124 L
.02954 .02144 L
.03053 .02154 L
.03163 .02161 L
.03279 .02164 L
.03395 .02164 L
.0352 .02162 L
.03638 .02159 L
.03746 .02154 L
.04262 .02127 L
.06244 .01993 L
.08259 .01874 L
.10458 .01773 L
.12517 .01703 L
.14429 .01654 L
.16481 .01615 L
.18342 .01588 L
.20266 .01568 L
.22348 .01551 L
.24342 .01539 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .0151 L
.40099 .01509 L
.4111 .01509 L
.422 .01508 L
.43215 .01508 L
.44147 .01508 L
.45975 .01508 L
.46955 .01507 L
.47867 .01507 L
.48868 .01507 L
.49428 .01507 L
.49937 .01507 L
.50422 .01507 L
.50935 .01507 L
.51373 .01507 L
.51856 .01507 L
.52413 .01507 L
.52942 .01507 L
.53458 .01507 L
.53935 .01507 L
Mistroke
.54866 .01507 L
.55357 .01507 L
.5588 .01507 L
.57969 .01507 L
.62133 .01507 L
.64223 .01507 L
.66145 .01507 L
.68142 .01506 L
.70005 .01506 L
.71891 .01506 L
.72954 .01506 L
.73959 .01506 L
.74936 .01506 L
.75998 .01506 L
.76466 .01506 L
.76963 .01506 L
.77398 .01506 L
.77855 .01506 L
.78345 .01506 L
.78794 .01506 L
.79045 .01506 L
.79278 .01506 L
.79412 .01506 L
.79533 .01506 L
.79601 .01506 L
.79674 .01506 L
.79742 .01506 L
.79806 .01506 L
.79912 .01506 L
.80025 .01506 L
.80132 .01506 L
.8023 .01506 L
.80344 .01506 L
.80469 .01506 L
.80695 .01506 L
.80932 .01506 L
.81183 .01506 L
.81635 .01506 L
.82571 .01506 L
.8358 .01506 L
.85407 .01506 L
.87369 .01506 L
.88408 .01506 L
.89518 .01506 L
.90591 .01506 L
.91568 .01506 L
.92039 .01506 L
.92287 .01506 L
.9255 .01506 L
.92779 .01506 L
Mistroke
.93032 .01506 L
.93143 .01506 L
.93262 .01506 L
.93373 .01506 L
.93477 .01506 L
.93541 .01506 L
.9361 .01506 L
.93731 .01506 L
.938 .01506 L
.93872 .01506 L
.94002 .01506 L
.94122 .01506 L
.94234 .01506 L
.94357 .01506 L
.94488 .01506 L
.94785 .01506 L
.95066 .01506 L
.95592 .01506 L
.96092 .01506 L
.96555 .01506 L
.97601 .01506 L
.97619 .01506 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.04262 .09894 L
.06244 .1698 L
.08255 .22435 L
.09409 .2489 L
.10458 .26753 L
.12415 .29412 L
.13491 .30484 L
.14509 .3128 L
.15478 .31866 L
.16506 .32326 L
.17384 .32607 L
.17883 .32726 L
.1835 .32813 L
.18847 .32882 L
.19127 .32912 L
.19388 .32933 L
.19639 .32948 L
.19866 .32958 L
.19992 .32962 L
.20058 .32964 L
.20128 .32965 L
.20257 .32967 L
.20375 .32968 L
.2049 .32967 L
.20595 .32966 L
.20717 .32964 L
.20832 .32962 L
.21036 .32955 L
.21258 .32945 L
.21762 .32915 L
.22227 .32876 L
.2319 .32771 L
.24094 .32649 L
.26154 .32326 L
.30023 .31734 L
.31061 .31609 L
.32027 .31513 L
.33035 .31436 L
.33567 .31405 L
.33844 .31393 L
.34137 .31382 L
.34391 .31374 L
.34525 .31371 L
.3467 .31368 L
.34802 .31366 L
.34924 .31365 L
.35045 .31364 L
.35161 .31363 L
.35231 .31363 L
Mistroke
.35295 .31363 L
.35368 .31363 L
.35437 .31364 L
.3556 .31365 L
.35629 .31365 L
.35692 .31366 L
.35974 .31372 L
.36116 .31376 L
.36271 .31381 L
.36775 .31403 L
.37057 .31419 L
.37314 .31436 L
.38287 .31526 L
.38769 .31586 L
.39281 .3166 L
.40199 .31827 L
.41187 .32058 L
.42276 .32387 L
.44215 .33216 L
.45304 .33862 L
.46302 .34604 L
.48198 .36518 L
.5027 .39419 L
.52399 .42729 L
.54331 .45218 L
.55297 .4615 L
.55806 .4655 L
.56343 .46908 L
.56814 .47168 L
.57331 .47397 L
.57801 .47558 L
.58241 .47669 L
.585 .47718 L
.5874 .47752 L
.58865 .47766 L
.59004 .47779 L
.59073 .47784 L
.59148 .47789 L
.59219 .47792 L
.59284 .47795 L
.59404 .47797 L
.59535 .47798 L
.59663 .47796 L
.59735 .47794 L
.598 .47791 L
.59917 .47785 L
.60043 .47777 L
.60273 .47755 L
.60496 .47728 L
.60742 .4769 L
Mistroke
.61238 .47593 L
.62128 .47355 L
.64071 .46627 L
.66159 .45669 L
.68131 .44744 L
.70283 .43853 L
.71281 .43518 L
.71829 .43362 L
.72344 .43236 L
.72826 .43139 L
.7308 .43096 L
.73347 .43057 L
.73573 .4303 L
.73821 .43006 L
.7393 .42998 L
.74046 .42991 L
.74154 .42985 L
.74256 .42981 L
.74378 .42978 L
.74443 .42977 L
.74513 .42976 L
.74582 .42977 L
.74655 .42977 L
.74785 .4298 L
.74906 .42985 L
.75019 .42991 L
.75143 .43 L
.75275 .43011 L
.75573 .43046 L
.75855 .4309 L
.76382 .43205 L
.76884 .43356 L
.77348 .43533 L
.78394 .44074 L
.79365 .44751 L
.80272 .45525 L
.82337 .47653 L
.86221 .51899 L
.88197 .53699 L
.90351 .55251 L
.92415 .56356 L
.93401 .56765 L
.94329 .57088 L
.95159 .57332 L
.96056 .57551 L
.97619 .57839 L
Mfstroke
0 1 .585 r
.02381 .01472 m
.04262 .09893 L
.06244 .16923 L
.08255 .22115 L
.09396 .24252 L
.10458 .25766 L
.10961 .26336 L
.11508 .26855 L
.11989 .27232 L
.125 .27554 L
.12959 .2778 L
.13203 .27877 L
.13466 .27964 L
.13706 .2803 L
.13926 .28078 L
.14147 .28116 L
.14357 .28142 L
.14482 .28153 L
.14547 .28157 L
.14616 .28161 L
.14743 .28166 L
.1486 .28167 L
.14972 .28167 L
.15077 .28164 L
.15192 .28158 L
.15316 .2815 L
.15447 .28138 L
.1559 .28123 L
.1585 .28086 L
.16338 .2799 L
.16801 .2787 L
.17293 .27716 L
.18177 .27381 L
.21952 .25496 L
.25972 .23445 L
.29841 .21913 L
.31845 .2134 L
.32865 .21108 L
.33955 .20904 L
.34989 .20752 L
.35929 .2065 L
.36382 .20613 L
.36621 .20597 L
.36874 .20583 L
.37095 .20572 L
.37338 .20563 L
.37444 .20559 L
.37559 .20556 L
.37665 .20554 L
.37766 .20552 L
Mistroke
.3783 .20551 L
.37899 .2055 L
.3802 .20549 L
.38089 .20549 L
.38161 .20549 L
.38291 .2055 L
.38412 .20551 L
.38524 .20552 L
.38647 .20555 L
.38779 .20558 L
.39076 .20568 L
.39357 .20582 L
.39883 .20618 L
.40384 .20665 L
.40846 .2072 L
.41893 .2089 L
.42858 .21113 L
.43763 .21389 L
.44756 .21785 L
.45825 .2235 L
.46785 .23017 L
.47833 .23969 L
.48927 .25273 L
.49944 .26798 L
.51822 .30194 L
.53854 .33773 L
.54967 .35311 L
.55456 .35862 L
.55993 .36376 L
.56465 .36751 L
.56973 .37073 L
.57253 .37217 L
.57508 .37327 L
.57746 .37412 L
.58009 .37488 L
.58128 .37516 L
.58256 .37541 L
.58367 .3756 L
.58489 .37577 L
.58618 .3759 L
.58689 .37596 L
.58755 .376 L
.58873 .37604 L
.58999 .37605 L
.59117 .37603 L
.59245 .37596 L
.59367 .37587 L
.59479 .37575 L
.59691 .37545 L
.59915 .37503 L
Mistroke
.60425 .37369 L
.60903 .372 L
.6199 .36677 L
.64017 .35322 L
.65869 .33823 L
.69842 .30433 L
.73664 .2761 L
.75797 .26368 L
.7773 .25467 L
.79747 .24736 L
.81645 .24207 L
.85502 .234 L
.89604 .22647 L
.93555 .21954 L
.97354 .21385 L
.97619 .2135 L
Mfstroke
0 1 .609 r
.02381 .01472 m
.04262 .09893 L
.06244 .16932 L
.08255 .22101 L
.09396 .2417 L
.09905 .24901 L
.10458 .25564 L
.11004 .2609 L
.11508 .26469 L
.11989 .2674 L
.12232 .26845 L
.125 .26937 L
.12741 .26999 L
.12962 .27039 L
.13084 .27055 L
.13153 .27062 L
.13217 .27067 L
.13334 .27073 L
.13459 .27076 L
.13575 .27074 L
.13701 .27068 L
.1382 .27058 L
.1393 .27045 L
.14138 .27014 L
.14357 .26969 L
.14853 .26827 L
.15305 .26653 L
.16321 .26135 L
.18154 .24889 L
.22139 .21736 L
.25972 .19063 L
.2791 .17982 L
.3005 .1701 L
.32075 .16293 L
.33977 .15785 L
.3496 .15581 L
.35995 .15407 L
.36879 .15291 L
.37343 .15242 L
.37846 .15199 L
.38374 .15163 L
.38616 .1515 L
.38873 .15139 L
.39104 .15132 L
.39227 .15128 L
.39359 .15126 L
.3948 .15124 L
.3959 .15122 L
.39701 .15122 L
.39807 .15121 L
Mistroke
.39939 .15122 L
.40059 .15123 L
.40125 .15124 L
.40197 .15125 L
.40327 .15127 L
.40449 .1513 L
.40578 .15134 L
.40809 .15143 L
.41079 .15156 L
.4133 .15171 L
.41902 .15218 L
.42404 .15273 L
.42949 .15348 L
.43941 .15535 L
.44906 .15789 L
.45798 .16104 L
.46763 .16557 L
.47668 .17121 L
.48661 .1794 L
.4973 .19114 L
.51738 .2215 L
.53849 .2568 L
.54806 .27018 L
.55331 .27636 L
.55827 .28136 L
.5629 .28528 L
.5679 .28871 L
.57246 .29111 L
.57665 .29273 L
.5791 .29343 L
.58134 .29391 L
.58257 .29411 L
.58392 .29428 L
.58519 .29439 L
.58637 .29446 L
.58745 .29449 L
.58846 .29449 L
.58957 .29445 L
.59077 .29438 L
.59196 .29427 L
.59321 .29412 L
.59545 .29376 L
.59792 .29323 L
.60056 .29251 L
.60531 .29085 L
.6161 .28557 L
.62633 .27903 L
.63742 .27072 L
.65757 .25386 L
.69846 .21979 L
Mistroke
.71879 .20534 L
.73783 .1939 L
.75724 .18436 L
.77568 .17718 L
.79594 .17116 L
.81447 .16709 L
.83429 .16387 L
.85269 .16157 L
.89184 .15743 L
.93344 .1528 L
.97352 .14816 L
.97619 .14786 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.03279 .05673 L
.04262 .09587 L
.04758 .11135 L
.0503 .11837 L
.05288 .12399 L
.05528 .12832 L
.05789 .13205 L
.06026 .1346 L
.06244 .1363 L
.06371 .13701 L
.06487 .13749 L
.0655 .1377 L
.0662 .13787 L
.06747 .13806 L
.06865 .1381 L
.06991 .13801 L
.0711 .1378 L
.07218 .13751 L
.07356 .13703 L
.07483 .13648 L
.0777 .1349 L
.0829 .13112 L
.10458 .11005 L
.125 .09045 L
.14407 .07514 L
.16357 .06264 L
.18204 .05335 L
.20239 .04547 L
.22095 .03998 L
.24086 .0355 L
.25928 .03234 L
.27794 .0299 L
.29854 .02787 L
.31789 .02646 L
.33875 .02533 L
.35879 .02455 L
.36899 .02423 L
.37989 .02395 L
.39023 .02373 L
.39963 .02356 L
.418 .02331 L
.42798 .02321 L
.43718 .02315 L
.44199 .02312 L
.44728 .0231 L
.44995 .02309 L
.45281 .02308 L
.45551 .02307 L
.45798 .02307 L
Mistroke
.45927 .02307 L
.46049 .02307 L
.46158 .02307 L
.46276 .02307 L
.46405 .02307 L
.4647 .02307 L
.46541 .02307 L
.46667 .02307 L
.46785 .02307 L
.46904 .02307 L
.47016 .02307 L
.47227 .02308 L
.47454 .02308 L
.477 .02309 L
.48223 .02311 L
.48778 .02314 L
.49774 .02322 L
.51725 .02342 L
.53554 .02363 L
.5454 .02371 L
.55035 .02374 L
.55319 .02375 L
.55576 .02376 L
.55815 .02377 L
.56041 .02377 L
.56165 .02377 L
.56279 .02377 L
.56404 .02378 L
.56467 .02378 L
.56536 .02378 L
.56652 .02378 L
.56759 .02378 L
.56881 .02377 L
.56997 .02377 L
.57203 .02377 L
.57428 .02376 L
.57661 .02376 L
.57912 .02375 L
.58366 .02373 L
.59403 .02366 L
.61503 .02349 L
.65614 .0231 L
.67664 .02292 L
.69573 .02278 L
.71531 .02267 L
.73381 .02258 L
.75424 .02251 L
.77282 .02246 L
.78252 .02244 L
.79281 .02243 L
Mistroke
.80159 .02242 L
.80658 .02242 L
.81125 .02241 L
.81622 .02241 L
.81903 .02241 L
.82164 .02241 L
.82415 .02241 L
.82642 .02241 L
.82768 .02241 L
.82905 .02241 L
.83033 .02241 L
.83152 .02241 L
.83259 .02241 L
.83374 .02241 L
.83482 .02241 L
.83581 .02241 L
.83697 .02241 L
.83823 .02241 L
.84053 .02241 L
.84293 .02241 L
.84547 .02241 L
.85004 .02241 L
.85942 .02241 L
.86953 .02242 L
.88782 .02242 L
.89245 .02242 L
.8974 .02242 L
.90024 .02242 L
.90282 .02243 L
.90407 .02243 L
.90542 .02243 L
.9066 .02243 L
.90787 .02243 L
.90918 .02243 L
.91041 .02243 L
.91116 .02243 L
.91187 .02243 L
.91251 .02243 L
.91321 .02243 L
.91395 .02243 L
.91463 .02243 L
.91541 .02243 L
.91614 .02243 L
.91744 .02243 L
.91885 .02243 L
.92142 .02243 L
.92413 .02242 L
.92898 .02242 L
.93396 .02242 L
.93849 .02242 L
Mistroke
.94867 .02241 L
.96702 .0224 L
.97619 .02239 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.04262 .09893 L
.06244 .16922 L
.07216 .1964 L
.08255 .22009 L
.08852 .23117 L
.09396 .23967 L
.09911 .24636 L
.10458 .25205 L
.10932 .25584 L
.11183 .25744 L
.11454 .25886 L
.11701 .25989 L
.11928 .26062 L
.12037 .26089 L
.12156 .26114 L
.12268 .26133 L
.12373 .26146 L
.12503 .26157 L
.12577 .2616 L
.12644 .26162 L
.12769 .2616 L
.129 .26153 L
.13018 .26142 L
.13128 .26128 L
.13249 .26107 L
.13379 .26081 L
.13667 .26004 L
.1394 .25911 L
.14451 .25685 L
.15416 .2511 L
.16442 .24337 L
.18284 .22713 L
.22059 .19279 L
.24156 .17612 L
.26079 .16307 L
.29948 .14327 L
.3184 .1364 L
.3391 .13071 L
.35872 .12686 L
.36969 .12531 L
.37967 .12426 L
.38451 .12386 L
.38965 .12353 L
.39403 .12332 L
.39652 .12323 L
.39885 .12317 L
.40014 .12314 L
.40154 .12312 L
.40218 .12311 L
Mistroke
.40286 .1231 L
.40409 .12309 L
.40538 .12309 L
.4066 .12309 L
.4077 .12309 L
.40888 .1231 L
.41018 .12312 L
.41161 .12315 L
.4131 .12319 L
.41449 .12323 L
.41698 .12333 L
.41965 .12346 L
.42495 .1238 L
.42985 .12424 L
.43522 .12485 L
.44093 .12567 L
.4505 .12751 L
.46106 .13038 L
.47118 .13421 L
.48045 .13896 L
.49062 .146 L
.50132 .15594 L
.53948 .2062 L
.54959 .21765 L
.55913 .22583 L
.5644 .22917 L
.56718 .23058 L
.57012 .23183 L
.57259 .23269 L
.57531 .23342 L
.5765 .23368 L
.57778 .23392 L
.57897 .23409 L
.58009 .23423 L
.5813 .23434 L
.58195 .23438 L
.58265 .23441 L
.58334 .23444 L
.58406 .23445 L
.58536 .23443 L
.58657 .23438 L
.58769 .23431 L
.58893 .23419 L
.59025 .23403 L
.59322 .23354 L
.59604 .2329 L
.6013 .23132 L
.61095 .22729 L
.62142 .22161 L
.66231 .19376 L
Mistroke
.70168 .16834 L
.73953 .15013 L
.75895 .14331 L
.77984 .13769 L
.80099 .13353 L
.82108 .13074 L
.8409 .12876 L
.8593 .12734 L
.89845 .1247 L
.94005 .12159 L
.97619 .11872 L
Mfstroke
0 1 .68 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02086 L
.02846 .02124 L
.02954 .02145 L
.03053 .02156 L
.03163 .02163 L
.03279 .02166 L
.03395 .02167 L
.0352 .02165 L
.03638 .02162 L
.03746 .02158 L
.04262 .02132 L
.06244 .02004 L
.08259 .01888 L
.10458 .0179 L
.12517 .01721 L
.14429 .01673 L
.16481 .01633 L
.18342 .01606 L
.20266 .01586 L
.22348 .01569 L
.24342 .01557 L
.26449 .01547 L
.28413 .01541 L
.30246 .01536 L
.32281 .01533 L
.34137 .0153 L
.36045 .01528 L
.38121 .01527 L
.40099 .01526 L
.41097 .01525 L
.422 .01525 L
.43142 .01525 L
.44134 .01525 L
.44654 .01524 L
.45222 .01524 L
.45701 .01524 L
.4622 .01524 L
.46495 .01524 L
.46748 .01524 L
.46986 .01524 L
.47247 .01524 L
.47482 .01524 L
.47701 .01524 L
.47822 .01524 L
.47932 .01524 L
.4806 .01524 L
.48181 .01524 L
Mistroke
.48313 .01524 L
.48433 .01524 L
.48499 .01524 L
.48571 .01524 L
.48701 .01524 L
.48823 .01524 L
.48952 .01524 L
.49183 .01524 L
.49453 .01524 L
.49705 .01524 L
.50276 .01524 L
.52143 .01524 L
.53128 .01524 L
.53624 .01524 L
.5391 .01524 L
.54172 .01524 L
.54447 .01524 L
.54591 .01524 L
.54665 .01524 L
.54743 .01524 L
.54812 .01524 L
.54875 .01524 L
.54999 .01524 L
.55068 .01524 L
.55142 .01524 L
.55213 .01524 L
.55278 .01524 L
.554 .01524 L
.55515 .01524 L
.5564 .01524 L
.55775 .01524 L
.56049 .01524 L
.563 .01524 L
.56795 .01524 L
.57334 .01524 L
.58313 .01524 L
.62388 .01524 L
.66312 .01523 L
.70084 .01523 L
.72016 .01523 L
.74101 .01523 L
.76102 .01523 L
.77109 .01523 L
.78211 .01523 L
.8017 .01523 L
.82264 .01523 L
.86411 .01523 L
.90406 .01523 L
.94249 .01522 L
.97619 .01522 L
Mistroke
Mfstroke
0 1 .704 r
.02381 .01472 m
.04262 .09878 L
.06244 .16632 L
.07286 .19146 L
.08255 .20821 L
.08813 .21502 L
.0932 .21953 L
.096 .22138 L
.09748 .22218 L
.09905 .22289 L
.10042 .22341 L
.10192 .22387 L
.1033 .2242 L
.10458 .22442 L
.10583 .22456 L
.10652 .2246 L
.10715 .22463 L
.10838 .22463 L
.10954 .22457 L
.1102 .22451 L
.1109 .22443 L
.11214 .22423 L
.11349 .22396 L
.11496 .22358 L
.11742 .22279 L
.12006 .22171 L
.12483 .21927 L
.13452 .21268 L
.14335 .20532 L
.1832 .16741 L
.22153 .13591 L
.24091 .12343 L
.26231 .11225 L
.28279 .1038 L
.30158 .0977 L
.32092 .09282 L
.34178 .0889 L
.3607 .08636 L
.37143 .08531 L
.3814 .08455 L
.38645 .08425 L
.39193 .08399 L
.39709 .0838 L
.39956 .08373 L
.40186 .08367 L
.40393 .08364 L
.40616 .0836 L
.40743 .08359 L
.40863 .08358 L
.40971 .08358 L
Mistroke
.41089 .08357 L
.41215 .08357 L
.41329 .08358 L
.41461 .08358 L
.41585 .0836 L
.417 .08361 L
.41806 .08362 L
.42045 .08367 L
.42291 .08373 L
.42516 .0838 L
.43021 .084 L
.43489 .08425 L
.43931 .08456 L
.44922 .08548 L
.45482 .08617 L
.45999 .08695 L
.46964 .08881 L
.47869 .09118 L
.48862 .09469 L
.49931 .09983 L
.5089 .10581 L
.51939 .11361 L
.53045 .12244 L
.5405 .12992 L
.54993 .13574 L
.5549 .1382 L
.56015 .14032 L
.56282 .14121 L
.56576 .14203 L
.56847 .14265 L
.57094 .14311 L
.57347 .14348 L
.57478 .14363 L
.5762 .14376 L
.57751 .14386 L
.57872 .14392 L
.57988 .14396 L
.58111 .14399 L
.58224 .14399 L
.58349 .14398 L
.58478 .14394 L
.58599 .14388 L
.58712 .14382 L
.58815 .14374 L
.59047 .14353 L
.59295 .14323 L
.59565 .14284 L
.60056 .14196 L
.61006 .13971 L
.61883 .13717 L
Mistroke
.6582 .12363 L
.69606 .11187 L
.71548 .10727 L
.72631 .1052 L
.73636 .10363 L
.74648 .1024 L
.75182 .10191 L
.75456 .10171 L
.75751 .10152 L
.76034 .10138 L
.76158 .10133 L
.76294 .10128 L
.76414 .10125 L
.76543 .10122 L
.76614 .10121 L
.76679 .1012 L
.76805 .10119 L
.76928 .10119 L
.7704 .1012 L
.77164 .10121 L
.77296 .10124 L
.7741 .10127 L
.77517 .1013 L
.77761 .10141 L
.78004 .10156 L
.78231 .10174 L
.78745 .10227 L
.79246 .10301 L
.7978 .10405 L
.80751 .10671 L
.81631 .11014 L
.82631 .11534 L
.83551 .12147 L
.85632 .13946 L
.87669 .15972 L
.88665 .16905 L
.89574 .17658 L
.90449 .18263 L
.91402 .18766 L
.91925 .18968 L
.92179 .19048 L
.92409 .19109 L
.92632 .19159 L
.92872 .19202 L
.93004 .19221 L
.93126 .19236 L
.9324 .19247 L
.93365 .19257 L
.93492 .19264 L
.93612 .19268 L
Mistroke
.93729 .1927 L
.93837 .1927 L
.93953 .19267 L
.94082 .19261 L
.94146 .19257 L
.94216 .19252 L
.94342 .19242 L
.94585 .19214 L
.94817 .19179 L
.95252 .19092 L
.95765 .18959 L
.96241 .18806 L
.97321 .18376 L
.97619 .1824 L
Mfstroke
0 1 .727 r
.02381 .01472 m
.04262 .09894 L
.06244 .16979 L
.08255 .22426 L
.09409 .24867 L
.10458 .2671 L
.12415 .29304 L
.13491 .30324 L
.14509 .31061 L
.15478 .31582 L
.15968 .31785 L
.16506 .31966 L
.16965 .32087 L
.17458 .32188 L
.17697 .32226 L
.17924 .32256 L
.18129 .32278 L
.1835 .32298 L
.18485 .32307 L
.18609 .32314 L
.18728 .32319 L
.18853 .32323 L
.18965 .32325 L
.1907 .32327 L
.19185 .32327 L
.19309 .32326 L
.1944 .32323 L
.19515 .32321 L
.19583 .32319 L
.19843 .32308 L
.2008 .32293 L
.20331 .32273 L
.20782 .32227 L
.21205 .32173 L
.2217 .32017 L
.26038 .3115 L
.28003 .30686 L
.30152 .30239 L
.31145 .30064 L
.32205 .29906 L
.33199 .29786 L
.34115 .29702 L
.34612 .29668 L
.35139 .2964 L
.35412 .2963 L
.35668 .29623 L
.35814 .2962 L
.35948 .29618 L
.36022 .29617 L
.36103 .29616 L
Mistroke
.36179 .29615 L
.36249 .29615 L
.36376 .29615 L
.36448 .29616 L
.36513 .29616 L
.36634 .29617 L
.36762 .29619 L
.36876 .29621 L
.36983 .29624 L
.37225 .29632 L
.37488 .29643 L
.37727 .29655 L
.38264 .29693 L
.38747 .29737 L
.39258 .29797 L
.40177 .29938 L
.41165 .30144 L
.42254 .30447 L
.43266 .30814 L
.44193 .31238 L
.4521 .31822 L
.4628 .32603 L
.48258 .34639 L
.50096 .37317 L
.51973 .4048 L
.54006 .43541 L
.55119 .44841 L
.56144 .45774 L
.57124 .46436 L
.57618 .4669 L
.58161 .46913 L
.58684 .47075 L
.58941 .47138 L
.59179 .47186 L
.59391 .47221 L
.59625 .47251 L
.59859 .47274 L
.59988 .47283 L
.60109 .4729 L
.60231 .47295 L
.603 .47296 L
.60365 .47298 L
.60495 .47298 L
.60567 .47298 L
.60634 .47297 L
.60752 .47294 L
.60881 .47289 L
.61003 .47282 L
.61115 .47274 L
.61366 .47253 L
Mistroke
.61642 .47222 L
.622 .47139 L
.63214 .46929 L
.64142 .46688 L
.66231 .46064 L
.67228 .45766 L
.68291 .45475 L
.6921 .45262 L
.69693 .4517 L
.70203 .45091 L
.7046 .45059 L
.70741 .4503 L
.70865 .4502 L
.70997 .4501 L
.71121 .45003 L
.71236 .44998 L
.71361 .44993 L
.71427 .44992 L
.71497 .44991 L
.71615 .4499 L
.71744 .44991 L
.7186 .44993 L
.71984 .44998 L
.72101 .45004 L
.72208 .45011 L
.72427 .4503 L
.72631 .45054 L
.72873 .4509 L
.73093 .4513 L
.73544 .45236 L
.74025 .45388 L
.7451 .45585 L
.75024 .45847 L
.75945 .46463 L
.76935 .47348 L
.78025 .48569 L
.80134 .51304 L
.82061 .53637 L
.84054 .55562 L
.85945 .56917 L
.86907 .5745 L
.87931 .57915 L
.88891 .58264 L
.89772 .58519 L
.90804 .58746 L
.91346 .58837 L
.91918 .58914 L
.92417 .58966 L
.92882 .59002 L
.93149 .59018 L
Mistroke
.93392 .5903 L
.93526 .59035 L
.93672 .5904 L
.9381 .59043 L
.93937 .59046 L
.94046 .59048 L
.94149 .59049 L
.94257 .5905 L
.94376 .5905 L
.94479 .59049 L
.94589 .59049 L
.94693 .59048 L
.94787 .59046 L
.95019 .59041 L
.9527 .59034 L
.95724 .59014 L
.96204 .58987 L
.96711 .5895 L
.97619 .58866 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.04262 .09894 L
.06244 .16981 L
.08255 .22445 L
.09409 .24911 L
.10458 .2679 L
.12415 .29492 L
.13491 .30594 L
.14509 .3142 L
.15478 .32036 L
.16506 .32528 L
.17384 .32835 L
.17883 .32968 L
.1835 .33068 L
.18847 .3315 L
.19109 .33184 L
.19388 .33214 L
.19657 .33237 L
.199 .33253 L
.20017 .33259 L
.20145 .33264 L
.20264 .33268 L
.20375 .33271 L
.20483 .33273 L
.20599 .33275 L
.20727 .33275 L
.20844 .33275 L
.20966 .33273 L
.21035 .33272 L
.21099 .33271 L
.2134 .33264 L
.21544 .33256 L
.2177 .33245 L
.22227 .33214 L
.22719 .33172 L
.23237 .33118 L
.24162 .33003 L
.26248 .32691 L
.30059 .32121 L
.31067 .32 L
.3202 .31905 L
.32546 .31861 L
.33117 .31821 L
.33633 .31792 L
.33885 .3178 L
.34115 .31771 L
.34333 .31764 L
.34571 .31758 L
.34701 .31755 L
.34822 .31753 L
Mistroke
.34938 .31751 L
.35061 .3175 L
.35132 .3175 L
.35196 .3175 L
.35268 .31749 L
.35343 .31749 L
.35469 .3175 L
.35541 .3175 L
.35608 .31751 L
.35733 .31752 L
.35846 .31754 L
.36102 .3176 L
.36372 .31768 L
.36621 .31778 L
.37184 .3181 L
.3768 .31847 L
.38207 .31898 L
.39146 .32018 L
.40158 .32195 L
.41112 .32413 L
.41987 .32664 L
.43883 .33417 L
.44957 .34007 L
.45954 .34693 L
.48004 .36648 L
.49864 .39153 L
.51948 .4241 L
.53868 .45069 L
.54836 .46126 L
.5574 .46919 L
.56683 .47551 L
.57183 .47808 L
.5772 .48029 L
.58247 .48194 L
.58735 .48303 L
.5899 .48344 L
.59271 .48378 L
.59412 .48391 L
.59487 .48396 L
.59565 .48401 L
.59634 .48405 L
.59709 .48408 L
.59841 .48412 L
.59906 .48413 L
.59977 .48413 L
.60105 .48412 L
.60229 .4841 L
.60344 .48405 L
.60469 .48399 L
.60606 .4839 L
Mistroke
.60883 .48365 L
.61124 .48337 L
.61383 .483 L
.61852 .48217 L
.62864 .4798 L
.63967 .47652 L
.65977 .46952 L
.6811 .462 L
.70043 .45635 L
.71012 .4543 L
.71558 .45345 L
.71818 .45313 L
.7206 .45289 L
.72272 .45273 L
.72381 .45266 L
.725 .4526 L
.7263 .45256 L
.72753 .45253 L
.72873 .45252 L
.72983 .45252 L
.73099 .45254 L
.73208 .45257 L
.73327 .45263 L
.73456 .4527 L
.73718 .45293 L
.73958 .45321 L
.74207 .45359 L
.74433 .45401 L
.7494 .45525 L
.75409 .45678 L
.75852 .45858 L
.76846 .46402 L
.77923 .47219 L
.79912 .49266 L
.82017 .51723 L
.83998 .53827 L
.85807 .55404 L
.87754 .56717 L
.88838 .57291 L
.89843 .57734 L
.91747 .58369 L
.92752 .58611 L
.93821 .58809 L
.94762 .58939 L
.95257 .58993 L
.95779 .5904 L
.96236 .59073 L
.96738 .59102 L
.97194 .59121 L
.97619 .59135 L
Mistroke
Mfstroke
0 1 .775 r
.02381 .01472 m
.04262 .09894 L
.06244 .16979 L
.08255 .2243 L
.09409 .24878 L
.10458 .26733 L
.12415 .29371 L
.13491 .30428 L
.14509 .3121 L
.15478 .31781 L
.16009 .32031 L
.16506 .32227 L
.17384 .32495 L
.17849 .326 L
.1835 .32687 L
.18604 .32722 L
.18874 .32753 L
.19108 .32774 L
.19361 .32792 L
.19516 .32801 L
.19659 .32807 L
.19795 .32811 L
.19864 .32813 L
.19939 .32815 L
.2007 .32816 L
.20144 .32817 L
.2021 .32817 L
.2034 .32817 L
.20464 .32815 L
.20579 .32813 L
.20706 .32809 L
.20964 .328 L
.21202 .32787 L
.21426 .32773 L
.2193 .32733 L
.22473 .32678 L
.24477 .32401 L
.26587 .32049 L
.28583 .31721 L
.30398 .31463 L
.31339 .31353 L
.32359 .31255 L
.32919 .31212 L
.33436 .3118 L
.3393 .31156 L
.3418 .31146 L
.34454 .31138 L
.34703 .31132 L
.34844 .3113 L
.34975 .31129 L
Mistroke
.35101 .31128 L
.35215 .31127 L
.35346 .31127 L
.3547 .31127 L
.35583 .31128 L
.35702 .3113 L
.35804 .31131 L
.35916 .31133 L
.36166 .3114 L
.36398 .31147 L
.36926 .31172 L
.37407 .31204 L
.37962 .31252 L
.38488 .31309 L
.39456 .31447 L
.40483 .31644 L
.41359 .31861 L
.42326 .32159 L
.44264 .32997 L
.45354 .3365 L
.46351 .34401 L
.48248 .36338 L
.50319 .39271 L
.52448 .426 L
.5438 .45091 L
.55347 .46018 L
.55855 .46416 L
.56393 .46771 L
.56863 .47027 L
.5738 .47254 L
.57851 .47411 L
.5829 .47519 L
.58549 .47566 L
.5879 .47599 L
.58915 .47612 L
.59053 .47623 L
.59123 .47628 L
.59198 .47632 L
.59268 .47635 L
.59333 .47637 L
.59453 .47639 L
.59563 .47639 L
.59685 .47637 L
.59815 .47632 L
.59881 .47629 L
.59952 .47624 L
.60081 .47615 L
.60323 .47591 L
.60546 .47562 L
.60791 .47523 L
Mistroke
.61287 .47423 L
.62178 .47182 L
.6412 .46449 L
.66208 .45493 L
.68181 .44572 L
.70333 .43685 L
.7133 .43352 L
.71878 .43197 L
.72394 .43071 L
.72876 .42974 L
.73129 .42932 L
.73397 .42894 L
.73622 .42867 L
.7387 .42844 L
.73979 .42836 L
.74095 .42829 L
.74205 .42824 L
.74306 .42821 L
.74424 .42818 L
.74535 .42817 L
.74656 .42818 L
.74787 .42821 L
.74917 .42826 L
.74982 .4283 L
.75054 .42834 L
.75298 .42855 L
.75528 .42882 L
.75773 .4292 L
.76216 .43012 L
.76776 .43176 L
.77304 .43384 L
.78292 .43923 L
.79265 .44655 L
.80295 .45635 L
.82141 .4777 L
.85932 .52287 L
.88041 .54291 L
.89968 .55713 L
.91961 .56812 L
.93852 .57562 L
.94799 .57849 L
.95807 .581 L
.97619 .58433 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.04262 .09894 L
.06244 .16973 L
.08255 .22382 L
.09409 .24777 L
.10458 .26563 L
.11396 .27872 L
.12415 .29019 L
.13491 .29954 L
.14509 .30611 L
.15453 .31049 L
.1599 .31234 L
.16493 .31369 L
.16764 .31428 L
.17022 .31475 L
.17256 .31511 L
.17506 .31543 L
.17776 .31569 L
.18027 .31587 L
.1818 .31595 L
.18256 .31598 L
.18325 .316 L
.18455 .31604 L
.18523 .31605 L
.18596 .31605 L
.18717 .31606 L
.18786 .31605 L
.1885 .31605 L
.18967 .31602 L
.19091 .31599 L
.19202 .31595 L
.19306 .3159 L
.19543 .31576 L
.20032 .31537 L
.20559 .31478 L
.21516 .31336 L
.22393 .31176 L
.26355 .303 L
.28352 .29873 L
.30166 .29543 L
.32127 .29271 L
.32644 .29216 L
.33205 .29165 L
.3373 .29125 L
.34222 .29096 L
.34678 .29076 L
.34934 .29068 L
.35169 .29062 L
.35301 .2906 L
.35424 .29058 L
Mistroke
.35495 .29057 L
.35559 .29057 L
.35633 .29056 L
.35703 .29056 L
.3583 .29056 L
.35946 .29057 L
.36074 .29058 L
.36139 .29059 L
.3621 .2906 L
.36351 .29062 L
.36485 .29066 L
.36736 .29073 L
.37005 .29084 L
.37299 .291 L
.37826 .29136 L
.38314 .2918 L
.39279 .29298 L
.40184 .29451 L
.41177 .29672 L
.42246 .29983 L
.43205 .30338 L
.44254 .30827 L
.45348 .31478 L
.46365 .32244 L
.48415 .34405 L
.50275 .3714 L
.52359 .40549 L
.53273 .419 L
.54278 .43173 L
.55181 .44098 L
.5615 .44851 L
.56686 .45163 L
.57174 .45385 L
.57409 .45472 L
.57665 .45553 L
.57907 .45615 L
.5813 .45661 L
.58363 .45698 L
.58485 .45713 L
.58614 .45725 L
.58726 .45733 L
.58831 .45739 L
.58946 .45742 L
.59068 .45743 L
.59138 .45743 L
.59202 .45741 L
.59273 .45739 L
.59348 .45735 L
.59473 .45727 L
.59611 .45715 L
Mistroke
.59866 .45685 L
.60105 .45646 L
.60634 .45531 L
.61117 .45392 L
.62205 .44975 L
.64105 .43993 L
.66178 .42708 L
.70244 .40093 L
.74159 .38017 L
.75189 .37594 L
.76302 .37205 L
.77264 .36928 L
.7832 .36689 L
.78818 .366 L
.79352 .36521 L
.79856 .36462 L
.80315 .36421 L
.80584 .36402 L
.80833 .36389 L
.80974 .36383 L
.81107 .36378 L
.81245 .36374 L
.81318 .36373 L
.81397 .36371 L
.81522 .3637 L
.81592 .3637 L
.81658 .36369 L
.81727 .3637 L
.8179 .3637 L
.81863 .36371 L
.81932 .36371 L
.82054 .36374 L
.82167 .36377 L
.82422 .36386 L
.82666 .36398 L
.8289 .36412 L
.83392 .36455 L
.83858 .36509 L
.843 .36572 L
.85288 .36756 L
.86364 .37025 L
.88337 .37687 L
.90436 .38571 L
.94601 .4047 L
.97619 .41659 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.04262 .09894 L
.06244 .16972 L
.08255 .22376 L
.09396 .24738 L
.10458 .26534 L
.11508 .27962 L
.125 .29029 L
.1339 .29776 L
.14357 .30389 L
.15301 .30812 L
.15838 .30985 L
.16341 .31107 L
.16612 .31158 L
.1687 .31198 L
.17101 .31226 L
.17354 .31249 L
.17498 .31259 L
.17628 .31266 L
.177 .3127 L
.17778 .31272 L
.17851 .31274 L
.17919 .31276 L
.18041 .31277 L
.1811 .31277 L
.18174 .31277 L
.18304 .31275 L
.18377 .31274 L
.18444 .31272 L
.18562 .31267 L
.18672 .31262 L
.18925 .31246 L
.1917 .31225 L
.19435 .31198 L
.20352 .31069 L
.21435 .30858 L
.22428 .30626 L
.26391 .29567 L
.30202 .28679 L
.32163 .28354 L
.3326 .28221 L
.34258 .28134 L
.34743 .28103 L
.35008 .2809 L
.35256 .2808 L
.35467 .28073 L
.35694 .28067 L
.35823 .28064 L
.35946 .28063 L
.36056 .28062 L
Mistroke
.36176 .28061 L
.36244 .28061 L
.36318 .28061 L
.36387 .28061 L
.36451 .28062 L
.36571 .28063 L
.36699 .28065 L
.36836 .28067 L
.36964 .28071 L
.37255 .2808 L
.37508 .28092 L
.37739 .28104 L
.38256 .28141 L
.38738 .28186 L
.3925 .28246 L
.40168 .28387 L
.41156 .28592 L
.42246 .28894 L
.43258 .29259 L
.44184 .29679 L
.45202 .30259 L
.46271 .31036 L
.47228 .3191 L
.48249 .33066 L
.50087 .35749 L
.52082 .39123 L
.53132 .4078 L
.54242 .42281 L
.55236 .43356 L
.55762 .43817 L
.56327 .4423 L
.56845 .44536 L
.57319 .44756 L
.57547 .44843 L
.57795 .44923 L
.5803 .44987 L
.58246 .45034 L
.58479 .45074 L
.58598 .4509 L
.5873 .45104 L
.58844 .45114 L
.58951 .45121 L
.59064 .45125 L
.59184 .45128 L
.59254 .45128 L
.59318 .45127 L
.59389 .45125 L
.59463 .45122 L
.59589 .45115 L
.59727 .45105 L
Mistroke
.5985 .45092 L
.59982 .45076 L
.60221 .4504 L
.60783 .44919 L
.61318 .44763 L
.62321 .44377 L
.64303 .43338 L
.66142 .42171 L
.70057 .3951 L
.72056 .38237 L
.74217 .37024 L
.76129 .36131 L
.78226 .35365 L
.80221 .34831 L
.82328 .34427 L
.84281 .34156 L
.85375 .3404 L
.86373 .33958 L
.86854 .33927 L
.87365 .33901 L
.87801 .33884 L
.8805 .33876 L
.88283 .3387 L
.88537 .33866 L
.88664 .33864 L
.88738 .33863 L
.88804 .33863 L
.88924 .33862 L
.89052 .33862 L
.8917 .33862 L
.89282 .33862 L
.89413 .33863 L
.89479 .33863 L
.89551 .33864 L
.89799 .33868 L
.89939 .33871 L
.90088 .33874 L
.90359 .33882 L
.90885 .33902 L
.91373 .33926 L
.92478 .33999 L
.94489 .3418 L
.97619 .34523 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.04262 .09888 L
.06244 .16773 L
.07286 .19428 L
.08255 .21253 L
.08813 .22015 L
.0932 .22531 L
.096 .22746 L
.09748 .2284 L
.09905 .22925 L
.10042 .22988 L
.10192 .23044 L
.1033 .23084 L
.10458 .23113 L
.10583 .23131 L
.10652 .23138 L
.10715 .23143 L
.10838 .23145 L
.10954 .23141 L
.1102 .23135 L
.1109 .23127 L
.11214 .23107 L
.11349 .23078 L
.11496 .23037 L
.11742 .22948 L
.12006 .22826 L
.12483 .22546 L
.13452 .2178 L
.14335 .20918 L
.1832 .16499 L
.22153 .1291 L
.2413 .11489 L
.26231 .10278 L
.282 .09384 L
.30006 .08736 L
.31941 .08195 L
.34026 .07756 L
.35919 .07466 L
.36991 .0734 L
.37989 .07246 L
.39041 .07169 L
.39558 .07139 L
.40034 .07116 L
.40459 .07099 L
.40926 .07084 L
.41153 .07079 L
.41396 .07074 L
.4153 .07072 L
.41653 .0707 L
.41768 .07069 L
Mistroke
.41893 .07068 L
.42022 .07067 L
.42144 .07067 L
.42262 .07067 L
.42371 .07067 L
.42489 .07067 L
.42619 .07068 L
.42684 .07068 L
.42754 .07069 L
.4288 .07071 L
.43126 .07075 L
.43359 .0708 L
.43796 .07092 L
.44312 .07114 L
.44789 .0714 L
.45313 .07176 L
.45869 .07225 L
.46809 .07334 L
.4782 .075 L
.48775 .07714 L
.4965 .07972 L
.51546 .0876 L
.53617 .09813 L
.54629 .10259 L
.55582 .10576 L
.5611 .10703 L
.56388 .10755 L
.56681 .10799 L
.56929 .10829 L
.5706 .10841 L
.572 .10852 L
.5733 .10861 L
.57448 .10867 L
.57566 .10871 L
.57679 .10874 L
.57792 .10875 L
.57915 .10875 L
.5803 .10873 L
.58136 .10871 L
.58254 .10867 L
.58383 .10861 L
.58642 .10844 L
.58899 .10822 L
.59173 .10792 L
.59667 .10725 L
.60631 .1055 L
.61508 .10353 L
.65503 .09281 L
.69347 .08342 L
.71293 .07965 L
Mistroke
.73435 .0763 L
.75469 .07383 L
.77372 .07209 L
.78411 .07134 L
.79399 .07074 L
.81252 .06989 L
.82211 .06957 L
.83234 .06929 L
.85073 .06893 L
.86102 .06878 L
.87215 .06863 L
.89233 .06838 L
.91189 .06809 L
.93335 .06768 L
.97286 .06673 L
.97619 .06664 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.03279 .05689 L
.04262 .0982 L
.053 .13402 L
.05753 .14655 L
.06244 .15779 L
.06526 .16309 L
.06786 .16725 L
.07051 .17077 L
.07298 .17342 L
.07559 .17557 L
.07697 .17646 L
.07846 .17722 L
.0792 .17753 L
.08001 .17782 L
.08072 .17802 L
.08149 .1782 L
.08224 .17832 L
.08292 .1784 L
.08361 .17845 L
.08426 .17846 L
.08544 .1784 L
.08673 .17823 L
.08738 .1781 L
.08808 .17793 L
.08934 .17755 L
.09179 .17657 L
.09402 .1754 L
.09944 .17166 L
.10458 .1672 L
.14291 .12518 L
.16229 .10586 L
.18369 .08827 L
.20418 .07495 L
.22296 .06535 L
.2423 .0576 L
.26316 .05119 L
.28208 .04676 L
.30279 .04309 L
.3224 .04048 L
.34335 .03841 L
.35359 .03762 L
.36469 .0369 L
.37429 .03638 L
.38484 .03591 L
.39443 .03555 L
.40472 .03525 L
.4104 .03511 L
.41559 .03501 L
.42052 .03492 L
Mistroke
.42576 .03485 L
.42843 .03482 L
.43094 .0348 L
.43339 .03478 L
.43563 .03476 L
.43777 .03475 L
.43885 .03475 L
.44003 .03475 L
.44122 .03474 L
.44249 .03474 L
.44369 .03474 L
.44479 .03474 L
.44607 .03474 L
.44672 .03474 L
.44744 .03474 L
.44871 .03475 L
.44989 .03475 L
.45257 .03477 L
.45544 .03479 L
.45801 .03481 L
.4607 .03484 L
.46552 .03491 L
.47054 .035 L
.47509 .03511 L
.4853 .03543 L
.49476 .03583 L
.50368 .03631 L
.52204 .03752 L
.53246 .03823 L
.5422 .03882 L
.55181 .03925 L
.5572 .03943 L
.55958 .03949 L
.56212 .03954 L
.5648 .03958 L
.566 .0396 L
.56729 .03961 L
.56867 .03962 L
.56997 .03963 L
.57072 .03963 L
.57151 .03963 L
.57219 .03963 L
.57293 .03963 L
.57362 .03963 L
.57427 .03963 L
.57549 .03963 L
.57681 .03962 L
.57823 .03961 L
.5808 .03958 L
.58317 .03955 L
Mistroke
.58784 .03947 L
.59285 .03935 L
.60191 .03908 L
.62254 .03827 L
.66379 .03646 L
.6844 .03567 L
.70352 .03504 L
.7232 .03452 L
.74173 .03412 L
.76227 .0338 L
.78088 .03358 L
.79065 .0335 L
.80097 .03343 L
.80978 .03339 L
.81945 .03335 L
.8247 .03333 L
.82967 .03332 L
.83418 .03331 L
.83897 .0333 L
.84145 .0333 L
.84418 .0333 L
.849 .0333 L
.8517 .03329 L
.85462 .03329 L
.85737 .03329 L
.85989 .03329 L
.86235 .03329 L
.86373 .03329 L
.86501 .03329 L
.86612 .03329 L
.86735 .03329 L
.86863 .03329 L
.86983 .03329 L
.87123 .03329 L
.87251 .03329 L
.87389 .03329 L
.87539 .03329 L
.87673 .03329 L
.87798 .03329 L
.87917 .03329 L
.88044 .03329 L
.88173 .03329 L
.88292 .03329 L
.8856 .03329 L
.88797 .03329 L
.89046 .03329 L
.89479 .03329 L
.89725 .03328 L
.89954 .03328 L
.90449 .03328 L
Mistroke
.90918 .03327 L
.91796 .03326 L
.92741 .03324 L
.93767 .03322 L
.95636 .03316 L
.97619 .03307 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02107 L
.02954 .02124 L
.03053 .02132 L
.03163 .02136 L
.03279 .02137 L
.03395 .02135 L
.0352 .02131 L
.03638 .02126 L
.03746 .02121 L
.04262 .02089 L
.06244 .01953 L
.08259 .01837 L
.10458 .01741 L
.12517 .01676 L
.14429 .0163 L
.16481 .01594 L
.18342 .0157 L
.20266 .01551 L
.22348 .01536 L
.24342 .01525 L
.26449 .01517 L
.28413 .01511 L
.30246 .01507 L
.32281 .01504 L
.34137 .01502 L
.36045 .015 L
.38121 .01499 L
.40099 .01498 L
.422 .01497 L
.44147 .01497 L
.45975 .01497 L
.46958 .01496 L
.47993 .01496 L
.48962 .01496 L
.49843 .01496 L
.50798 .01496 L
.51818 .01496 L
.53654 .01496 L
.57652 .01496 L
.61499 .01496 L
.63448 .01496 L
.65591 .01496 L
.6765 .01496 L
.69531 .01496 L
.71476 .01496 L
.7256 .01496 L
Mistroke
.73565 .01495 L
.74564 .01495 L
.75468 .01495 L
.76472 .01495 L
.77023 .01495 L
.77541 .01495 L
.78008 .01495 L
.78273 .01495 L
.7852 .01495 L
.78781 .01495 L
.78905 .01495 L
.79019 .01495 L
.79151 .01495 L
.7922 .01495 L
.79293 .01495 L
.79417 .01495 L
.79487 .01495 L
.79553 .01495 L
.79661 .01495 L
.7978 .01495 L
.79903 .01495 L
.80018 .01495 L
.80224 .01495 L
.80443 .01495 L
.80946 .01495 L
.81402 .01495 L
.82402 .01495 L
.83324 .01495 L
.85405 .01495 L
.87445 .01495 L
.89351 .01496 L
.9029 .01496 L
.91181 .01496 L
.91672 .01496 L
.92208 .01496 L
.92694 .01496 L
.92913 .01496 L
.93144 .01496 L
.9326 .01496 L
.93386 .01496 L
.93501 .01496 L
.93607 .01496 L
.93732 .01496 L
.938 .01496 L
.93865 .01496 L
.9398 .01496 L
.94106 .01496 L
.94214 .01496 L
.94334 .01496 L
.94458 .01496 L
Mistroke
.94575 .01496 L
.94784 .01496 L
.95009 .01496 L
.95272 .01496 L
.9556 .01496 L
.96084 .01496 L
.97068 .01496 L
.97619 .01496 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.03279 .05638 L
.03793 .07681 L
.04262 .092 L
.04758 .10396 L
.0503 .10871 L
.05288 .11209 L
.05404 .11328 L
.05527 .11433 L
.05633 .11508 L
.05747 .11573 L
.05869 .11625 L
.05984 .1166 L
.06053 .11675 L
.0612 .11684 L
.06244 .11691 L
.0631 .1169 L
.06381 .11684 L
.0651 .11665 L
.06635 .11635 L
.0675 .11599 L
.07012 .11492 L
.07289 .11345 L
.08259 .10665 L
.10458 .08852 L
.14255 .06256 L
.16206 .05299 L
.18298 .04509 L
.20422 .03906 L
.22434 .03477 L
.24425 .03158 L
.26267 .02933 L
.28133 .02758 L
.30193 .02614 L
.32128 .02513 L
.34214 .02433 L
.36218 .02378 L
.37238 .02355 L
.38328 .02336 L
.39362 .02321 L
.40302 .02309 L
.41194 .023 L
.42138 .02293 L
.42614 .0229 L
.43137 .02287 L
.43618 .02285 L
.44057 .02284 L
.44323 .02283 L
.44575 .02283 L
.44841 .02282 L
Mistroke
.44992 .02282 L
.45059 .02282 L
.45131 .02282 L
.45263 .02282 L
.45387 .02282 L
.45507 .02282 L
.45618 .02282 L
.45739 .02282 L
.45871 .02282 L
.46008 .02282 L
.46137 .02282 L
.46398 .02283 L
.46639 .02283 L
.47184 .02285 L
.47666 .02287 L
.48176 .0229 L
.49059 .02297 L
.50033 .02307 L
.52134 .02334 L
.53054 .02346 L
.54058 .02357 L
.54532 .02362 L
.55037 .02365 L
.55514 .02368 L
.55724 .02369 L
.55947 .0237 L
.56068 .0237 L
.56202 .0237 L
.56325 .02371 L
.56437 .02371 L
.5657 .02371 L
.56643 .02371 L
.56712 .02371 L
.56835 .02371 L
.56904 .02371 L
.56969 .02371 L
.57083 .02371 L
.57191 .02371 L
.57308 .02371 L
.57436 .02371 L
.57695 .0237 L
.57932 .0237 L
.58405 .02368 L
.58911 .02366 L
.59822 .0236 L
.61891 .02343 L
.66038 .02305 L
.68116 .02288 L
.70033 .02275 L
.72018 .02263 L
Mistroke
.73876 .02256 L
.7575 .0225 L
.76744 .02248 L
.77299 .02247 L
.77813 .02246 L
.78303 .02245 L
.78554 .02245 L
.78825 .02245 L
.7898 .02245 L
.79123 .02245 L
.79257 .02245 L
.79404 .02245 L
.79536 .02245 L
.79659 .02245 L
.79789 .02245 L
.79862 .02245 L
.79928 .02245 L
.80053 .02245 L
.80116 .02245 L
.80185 .02245 L
.80308 .02245 L
.80423 .02245 L
.80682 .02245 L
.80961 .02245 L
.8147 .02246 L
.81938 .02246 L
.82919 .02248 L
.83832 .02249 L
.85902 .02255 L
.87777 .02261 L
.89809 .02267 L
.9092 .02269 L
.91408 .0227 L
.91945 .02271 L
.92451 .02272 L
.92924 .02272 L
.93185 .02272 L
.93424 .02272 L
.93556 .02273 L
.93699 .02273 L
.93765 .02273 L
.93835 .02273 L
.93961 .02273 L
.9407 .02273 L
.94191 .02273 L
.94316 .02273 L
.94433 .02273 L
.94543 .02273 L
.94643 .02273 L
.94867 .02273 L
Mistroke
.95108 .02272 L
.9537 .02272 L
.95846 .02272 L
.96293 .02271 L
.96768 .02271 L
.97619 .02269 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.04262 .0989 L
.06244 .16847 L
.07286 .1965 L
.08255 .21734 L
.0932 .23455 L
.09916 .24177 L
.10458 .24691 L
.10941 .25044 L
.11206 .25197 L
.11454 .25315 L
.11682 .25405 L
.11891 .2547 L
.12123 .25526 L
.12251 .25549 L
.12373 .25566 L
.12503 .25579 L
.12622 .25587 L
.12688 .25589 L
.12759 .2559 L
.12888 .25589 L
.13009 .25583 L
.13137 .25573 L
.13246 .2556 L
.13366 .25544 L
.13637 .25493 L
.13927 .25419 L
.14451 .25242 L
.15468 .24762 L
.16575 .24088 L
.18587 .22637 L
.22665 .1961 L
.24691 .18303 L
.26592 .17249 L
.28431 .16393 L
.30367 .1566 L
.32385 .15065 L
.34236 .14659 L
.3519 .14498 L
.3621 .14361 L
.36705 .14307 L
.37172 .14264 L
.37624 .1423 L
.38047 .14204 L
.38509 .14182 L
.38755 .14174 L
.39019 .14167 L
.39151 .14165 L
.3922 .14164 L
.39295 .14163 L
Mistroke
.39366 .14163 L
.3943 .14162 L
.39556 .14162 L
.39678 .14162 L
.3981 .14163 L
.39934 .14164 L
.40048 .14166 L
.4027 .14171 L
.40476 .14177 L
.40703 .14186 L
.40946 .14197 L
.41442 .14229 L
.41893 .14268 L
.42375 .14319 L
.42887 .14388 L
.43805 .14548 L
.44794 .14788 L
.45883 .15154 L
.46895 .15623 L
.47821 .16201 L
.48839 .17052 L
.49908 .1825 L
.53725 .24282 L
.54736 .25679 L
.55689 .26715 L
.56217 .27161 L
.56789 .27542 L
.57041 .27677 L
.57308 .278 L
.57786 .27966 L
.5804 .28029 L
.58165 .28053 L
.58281 .28072 L
.58383 .28086 L
.58497 .28098 L
.58611 .28108 L
.58732 .28114 L
.58863 .28117 L
.58984 .28116 L
.59116 .28112 L
.59183 .28108 L
.59255 .28103 L
.59379 .28092 L
.5951 .28076 L
.59747 .2804 L
.59984 .27994 L
.60241 .27932 L
.60707 .27793 L
.6158 .27451 L
.63565 .26408 L
Mistroke
.65668 .25125 L
.69454 .22996 L
.7045 .22555 L
.71396 .22204 L
.71918 .22042 L
.72487 .21895 L
.73005 .2179 L
.73238 .21753 L
.73485 .21721 L
.73611 .21708 L
.73749 .21695 L
.73875 .21687 L
.73993 .2168 L
.74064 .21678 L
.74132 .21676 L
.74258 .21674 L
.74329 .21674 L
.74394 .21675 L
.74466 .21676 L
.74542 .21679 L
.7466 .21685 L
.74787 .21694 L
.74906 .21706 L
.75016 .21718 L
.75271 .21757 L
.75538 .21812 L
.75999 .21946 L
.76428 .2212 L
.76898 .22374 L
.774 .22731 L
.77933 .23222 L
.78425 .23792 L
.79536 .25533 L
.80515 .27575 L
.81551 .30104 L
.85342 .39371 L
.87288 .42901 L
.88381 .44408 L
.89378 .4549 L
.89857 .45912 L
.90366 .46294 L
.90807 .46569 L
.91282 .4681 L
.91574 .46929 L
.91843 .4702 L
.92095 .4709 L
.92228 .4712 L
.92371 .47148 L
.92501 .47169 L
.92619 .47184 L
Mistroke
.92738 .47197 L
.9285 .47206 L
.92976 .47212 L
.93093 .47214 L
.93221 .47213 L
.93285 .47212 L
.93356 .47208 L
.93485 .472 L
.93604 .47189 L
.93736 .47173 L
.93875 .47151 L
.94134 .47101 L
.94369 .47042 L
.94846 .46888 L
.95296 .467 L
.96299 .46142 L
.97384 .4534 L
.97619 .45142 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.04262 .09894 L
.06244 .16974 L
.08255 .22394 L
.09409 .24801 L
.10458 .26601 L
.11396 .27926 L
.12415 .2909 L
.13491 .30044 L
.14509 .30718 L
.15453 .31171 L
.1599 .31363 L
.16493 .31504 L
.17022 .31616 L
.17506 .31689 L
.17773 .31718 L
.17914 .3173 L
.18064 .3174 L
.18209 .31749 L
.1834 .31754 L
.18471 .31758 L
.18596 .31761 L
.18712 .31761 L
.18836 .31761 L
.18954 .3176 L
.19061 .31758 L
.19187 .31754 L
.19323 .31748 L
.19572 .31735 L
.19832 .31716 L
.20108 .31691 L
.20603 .31635 L
.21481 .31505 L
.22451 .31327 L
.26471 .30418 L
.28319 .30013 L
.3034 .29634 L
.31309 .29485 L
.32344 .29353 L
.32916 .29292 L
.33437 .29246 L
.33931 .29209 L
.34454 .29179 L
.34683 .29168 L
.34929 .29159 L
.3507 .29155 L
.35199 .29151 L
.3533 .29148 L
.35452 .29146 L
.35561 .29145 L
Mistroke
.35678 .29143 L
.35807 .29143 L
.35924 .29143 L
.36035 .29143 L
.36155 .29144 L
.36268 .29145 L
.36372 .29147 L
.36493 .29149 L
.36622 .29152 L
.36855 .29159 L
.37132 .29171 L
.37384 .29184 L
.37933 .29221 L
.38452 .29269 L
.3942 .2939 L
.40447 .29571 L
.41324 .29775 L
.4229 .30059 L
.43302 .30437 L
.44229 .30871 L
.4531 .31508 L
.46316 .32257 L
.48212 .34203 L
.50283 .37216 L
.52161 .40315 L
.54193 .43179 L
.55306 .44332 L
.55795 .44736 L
.56332 .45108 L
.56804 .45376 L
.57312 .45603 L
.57592 .45703 L
.57847 .45779 L
.58085 .45837 L
.58348 .45886 L
.58467 .45904 L
.58595 .45921 L
.58706 .45932 L
.58828 .45942 L
.58957 .45949 L
.59028 .45952 L
.59094 .45953 L
.59212 .45954 L
.59338 .45953 L
.59456 .45948 L
.59584 .45941 L
.59706 .45932 L
.59818 .45921 L
.6003 .45895 L
.60254 .4586 L
Mistroke
.60764 .45753 L
.61242 .45621 L
.62329 .45224 L
.64355 .44216 L
.66208 .43126 L
.70181 .40769 L
.72186 .39772 L
.74003 .39069 L
.7449 .38921 L
.75017 .38783 L
.75472 .38683 L
.75971 .38596 L
.76228 .38561 L
.76503 .3853 L
.76655 .38517 L
.76793 .38507 L
.76932 .38499 L
.77064 .38494 L
.77185 .38491 L
.77314 .3849 L
.77424 .3849 L
.77546 .38492 L
.77676 .38496 L
.77749 .385 L
.77816 .38504 L
.77946 .38512 L
.78069 .38523 L
.78318 .3855 L
.78544 .38582 L
.7905 .38681 L
.79488 .38797 L
.79963 .38958 L
.8104 .39461 L
.82033 .40102 L
.83911 .41755 L
.85976 .44039 L
.90012 .48586 L
.92005 .50427 L
.93896 .51842 L
.95678 .52893 L
.97619 .53769 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.04262 .09887 L
.06244 .16753 L
.07286 .19369 L
.07784 .20358 L
.08255 .2113 L
.08813 .21841 L
.0932 .22302 L
.09603 .22486 L
.09865 .2261 L
.10002 .22658 L
.10153 .22697 L
.10229 .22712 L
.1031 .22725 L
.10388 .22733 L
.10458 .22738 L
.10587 .22739 L
.10708 .22733 L
.10817 .2272 L
.10934 .227 L
.11063 .22671 L
.11199 .22631 L
.11442 .22539 L
.11878 .22314 L
.12357 .21989 L
.13428 .21033 L
.14429 .19956 L
.1832 .15465 L
.20301 .13474 L
.22456 .11667 L
.2435 .10379 L
.2644 .09246 L
.28418 .08409 L
.30519 .07724 L
.32453 .07245 L
.34539 .0686 L
.36543 .06594 L
.37551 .06493 L
.38653 .06404 L
.3968 .06341 L
.40614 .063 L
.41131 .06283 L
.41403 .06276 L
.41692 .0627 L
.41944 .06266 L
.42077 .06265 L
.42221 .06263 L
.42353 .06262 L
.42473 .06261 L
.42594 .06261 L
Mistroke
.42709 .06261 L
.42834 .06261 L
.42904 .06261 L
.42969 .06261 L
.43088 .06262 L
.43213 .06263 L
.43326 .06264 L
.43431 .06265 L
.4367 .06269 L
.43929 .06274 L
.44164 .0628 L
.44693 .06298 L
.45147 .06319 L
.45639 .06347 L
.46533 .06416 L
.47476 .06519 L
.48515 .06677 L
.496 .06905 L
.50617 .07186 L
.52468 .07841 L
.53517 .08229 L
.54491 .08546 L
.55462 .08788 L
.56006 .08884 L
.56499 .08947 L
.5677 .08972 L
.57021 .0899 L
.57151 .08996 L
.57295 .09002 L
.57368 .09004 L
.57445 .09006 L
.57519 .09007 L
.57585 .09008 L
.57716 .09009 L
.57837 .09008 L
.579 .09007 L
.5797 .09006 L
.58043 .09004 L
.58111 .09002 L
.58351 .08993 L
.58486 .08985 L
.5861 .08978 L
.59083 .0894 L
.59589 .08885 L
.605 .08757 L
.62569 .08371 L
.66716 .07516 L
.68794 .07144 L
.70711 .06854 L
.72696 .0661 L
Mistroke
.74554 .0643 L
.76428 .06289 L
.77486 .06227 L
.78491 .06177 L
.7946 .06137 L
.80517 .06101 L
.81472 .06076 L
.8237 .06057 L
.83403 .0604 L
.84339 .06029 L
.85347 .06019 L
.86437 .06012 L
.88393 .06 L
.89429 .05993 L
.90539 .05984 L
.92583 .05962 L
.9449 .05935 L
.97619 .05879 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03564 L
.03053 .0429 L
.03279 .0489 L
.03416 .05164 L
.03543 .05362 L
.03665 .05508 L
.03793 .05624 L
.03908 .05701 L
.04016 .05752 L
.04135 .0579 L
.04262 .05813 L
.04393 .05821 L
.04516 .05817 L
.04586 .05811 L
.0465 .05802 L
.04793 .05777 L
.05052 .05712 L
.05297 .05635 L
.06244 .05267 L
.08439 .04383 L
.10458 .03715 L
.12333 .0323 L
.14313 .02837 L
.16277 .02543 L
.1811 .02334 L
.20145 .0216 L
.22001 .0204 L
.2391 .01947 L
.25986 .01873 L
.27963 .0182 L
.30064 .01779 L
.32011 .01751 L
.33839 .01731 L
.35857 .01715 L
.37708 .01704 L
.396 .01696 L
.40672 .01693 L
.4167 .0169 L
.42722 .01688 L
.43716 .01686 L
.44608 .01685 L
.45107 .01684 L
.45575 .01684 L
.46031 .01683 L
.46521 .01683 L
.468 .01683 L
.46938 .01683 L
.47065 .01683 L
Mistroke
.4719 .01683 L
.47303 .01683 L
.47428 .01683 L
.47497 .01683 L
.47562 .01683 L
.47685 .01683 L
.47754 .01683 L
.47819 .01683 L
.47949 .01683 L
.48023 .01683 L
.48089 .01683 L
.48209 .01683 L
.48338 .01683 L
.48574 .01683 L
.48849 .01683 L
.49142 .01683 L
.49666 .01683 L
.50606 .01684 L
.51617 .01685 L
.52566 .01686 L
.53447 .01687 L
.5395 .01687 L
.54406 .01687 L
.5465 .01687 L
.54914 .01687 L
.55059 .01687 L
.55192 .01687 L
.55319 .01688 L
.55389 .01688 L
.55455 .01688 L
.55587 .01688 L
.55707 .01688 L
.55821 .01688 L
.55944 .01688 L
.56008 .01688 L
.56079 .01688 L
.56153 .01688 L
.56223 .01688 L
.56481 .01687 L
.56613 .01687 L
.56753 .01687 L
.57003 .01687 L
.57566 .01687 L
.58519 .01686 L
.59538 .01686 L
.61374 .01684 L
.6552 .01679 L
.67598 .01677 L
.69515 .01676 L
.715 .01674 L
Mistroke
.73358 .01674 L
.75232 .01673 L
.76227 .01673 L
.77296 .01672 L
.78307 .01672 L
.79411 .01672 L
.80453 .01672 L
.8142 .01672 L
.81928 .01672 L
.82478 .01672 L
.82997 .01672 L
.83243 .01672 L
.83474 .01672 L
.837 .01672 L
.83905 .01672 L
.84134 .01672 L
.8426 .01672 L
.84379 .01672 L
.84494 .01672 L
.84617 .01672 L
.84722 .01672 L
.84837 .01672 L
.84961 .01672 L
.8503 .01672 L
.85094 .01672 L
.85211 .01672 L
.85335 .01672 L
.85593 .01672 L
.85836 .01672 L
.8629 .01672 L
.87311 .01672 L
.89148 .01672 L
.90121 .01672 L
.90653 .01672 L
.90913 .01672 L
.91151 .01672 L
.91354 .01672 L
.91575 .01672 L
.91696 .01672 L
.91808 .01672 L
.91916 .01672 L
.9203 .01672 L
.92156 .01672 L
.92226 .01672 L
.92291 .01672 L
.92411 .01672 L
.92537 .01672 L
.92651 .01672 L
.92756 .01672 L
.92996 .01672 L
Mistroke
.93258 .01672 L
.93499 .01672 L
.94045 .01672 L
.94527 .01672 L
.95037 .01672 L
.95921 .01672 L
.96894 .01672 L
.97619 .01672 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16966 L
.08255 .22334 L
.09396 .2465 L
.10458 .2638 L
.11508 .27721 L
.125 .28683 L
.1339 .2932 L
.13893 .29594 L
.14357 .29796 L
.14823 .29954 L
.1508 .30022 L
.15324 .30076 L
.1555 .30117 L
.15797 .30151 L
.15906 .30162 L
.16021 .30173 L
.16123 .3018 L
.1623 .30186 L
.16296 .30189 L
.16369 .30192 L
.16497 .30194 L
.1657 .30194 L
.16647 .30194 L
.1672 .30192 L
.16787 .30191 L
.16916 .30186 L
.16989 .30182 L
.17056 .30178 L
.17312 .30157 L
.17538 .30131 L
.17787 .30097 L
.18292 .30007 L
.19302 .29757 L
.20227 .29464 L
.22313 .28661 L
.26275 .27003 L
.30086 .25668 L
.32047 .25159 L
.33137 .24936 L
.34142 .24769 L
.35166 .24639 L
.35706 .24587 L
.35981 .24565 L
.36277 .24545 L
.36536 .24531 L
.36772 .2452 L
.3701 .24511 L
.37129 .24508 L
Mistroke
.37236 .24505 L
.37363 .24503 L
.37433 .24502 L
.37498 .24501 L
.37615 .24501 L
.37741 .245 L
.37808 .24501 L
.37881 .24501 L
.37957 .24502 L
.38028 .24503 L
.38155 .24505 L
.38292 .24508 L
.38549 .24517 L
.38822 .24529 L
.39312 .24561 L
.39839 .24609 L
.4042 .2468 L
.41459 .24857 L
.42433 .25092 L
.43419 .25408 L
.44455 .25847 L
.4534 .26329 L
.46307 .26998 L
.47337 .27918 L
.48272 .2898 L
.50368 .32242 L
.52453 .36184 L
.54372 .39402 L
.5534 .40676 L
.56244 .41631 L
.57187 .4239 L
.57687 .42701 L
.58224 .42969 L
.58751 .4317 L
.59239 .43306 L
.59494 .43359 L
.59775 .43404 L
.59917 .43422 L
.60069 .43437 L
.60213 .43448 L
.60345 .43455 L
.60462 .43459 L
.60587 .43461 L
.60705 .43462 L
.60813 .4346 L
.60939 .43456 L
.6101 .43453 L
.61076 .4345 L
.61325 .43432 L
.61563 .43408 L
Mistroke
.61826 .43374 L
.62357 .43284 L
.63371 .43047 L
.64299 .42774 L
.66387 .42069 L
.67385 .41733 L
.68448 .41409 L
.69367 .41176 L
.6985 .41077 L
.7036 .40995 L
.70617 .40964 L
.70752 .4095 L
.70898 .40937 L
.71032 .40927 L
.71154 .40921 L
.71277 .40916 L
.71393 .40913 L
.7151 .40912 L
.71635 .40912 L
.71741 .40915 L
.71858 .40919 L
.71984 .40927 L
.7212 .40937 L
.72365 .40963 L
.72585 .40995 L
.72827 .4104 L
.73313 .41164 L
.73763 .41323 L
.74181 .41512 L
.74687 .41799 L
.75235 .4219 L
.76229 .43128 L
.77196 .44332 L
.78088 .45659 L
.80125 .49001 L
.8203 .51838 L
.83858 .54008 L
.85821 .55746 L
.86835 .5643 L
.8794 .57029 L
.88984 .57469 L
.89951 .57777 L
.90461 .57904 L
.91011 .58015 L
.91531 .58096 L
.91778 .58127 L
.92008 .58152 L
.92235 .58172 L
.92441 .58187 L
.9267 .582 L
Mistroke
.92796 .58206 L
.92915 .5821 L
.93031 .58213 L
.93153 .58215 L
.93258 .58216 L
.93373 .58217 L
.93497 .58216 L
.93566 .58215 L
.9363 .58214 L
.93753 .58211 L
.93871 .58207 L
.94125 .58197 L
.94364 .58182 L
.94811 .58146 L
.95293 .58094 L
.95814 .58022 L
.96754 .57853 L
.97619 .57656 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16949 L
.08255 .22209 L
.09396 .24385 L
.10458 .2592 L
.10961 .26492 L
.11508 .27005 L
.11989 .27371 L
.125 .27673 L
.12959 .27875 L
.13221 .27963 L
.13466 .28027 L
.1369 .28071 L
.13895 .28101 L
.14008 .28112 L
.14132 .28122 L
.14249 .28127 L
.14357 .28129 L
.14486 .28128 L
.14551 .28126 L
.14622 .28122 L
.14747 .28114 L
.14865 .28103 L
.15004 .28087 L
.1513 .28068 L
.15414 .28016 L
.15925 .27885 L
.1641 .27722 L
.17301 .2734 L
.1827 .26829 L
.22348 .24202 L
.26275 .21803 L
.3005 .20064 L
.31985 .19417 L
.32981 .19147 L
.3407 .18899 L
.35039 .1872 L
.36075 .18571 L
.36647 .18507 L
.37168 .18461 L
.37419 .18443 L
.37691 .18426 L
.37929 .18413 L
.38184 .18403 L
.38316 .18399 L
.3844 .18395 L
.38561 .18393 L
.38673 .18391 L
.38779 .18389 L
Mistroke
.38892 .18388 L
.39018 .18388 L
.39131 .18389 L
.39196 .18389 L
.39265 .1839 L
.39389 .18392 L
.39522 .18394 L
.39667 .18398 L
.39929 .18408 L
.40172 .1842 L
.40704 .18456 L
.41188 .18502 L
.41747 .18571 L
.42276 .18655 L
.43244 .18856 L
.44271 .19153 L
.45148 .1949 L
.46115 .19976 L
.47126 .2065 L
.48053 .21462 L
.4907 .22618 L
.5014 .24169 L
.53956 .30965 L
.54967 .3241 L
.55921 .3347 L
.56449 .33925 L
.5702 .34312 L
.57272 .34449 L
.57539 .34572 L
.57768 .3466 L
.58017 .34738 L
.58149 .34772 L
.58271 .34799 L
.58386 .3482 L
.58512 .34839 L
.58625 .34853 L
.58731 .34862 L
.58843 .34869 L
.58964 .34872 L
.59087 .34872 L
.59156 .3487 L
.59221 .34867 L
.59353 .34858 L
.59426 .34851 L
.59493 .34844 L
.59743 .34807 L
.59979 .34759 L
.60436 .34632 L
.60858 .34478 L
.61811 .34014 L
Mistroke
.63685 .3274 L
.65748 .31002 L
.69779 .27416 L
.73658 .24503 L
.75773 .23277 L
.77783 .22355 L
.79765 .21658 L
.81604 .21167 L
.85519 .2043 L
.89679 .19795 L
.93688 .19188 L
.97545 .1865 L
.97619 .1864 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16973 L
.08255 .22381 L
.09396 .24748 L
.10458 .26549 L
.11508 .27981 L
.125 .29047 L
.1339 .2979 L
.1389 .30126 L
.14357 .30392 L
.1485 .30624 L
.15301 .30797 L
.15802 .30947 L
.16082 .31013 L
.16341 .31063 L
.16611 .31105 L
.16856 .31134 L
.16987 .31146 L
.17129 .31156 L
.17207 .31161 L
.17278 .31165 L
.17346 .31168 L
.17419 .3117 L
.17542 .31173 L
.17657 .31174 L
.17727 .31174 L
.17793 .31173 L
.17917 .3117 L
.18048 .31166 L
.1817 .3116 L
.18444 .31142 L
.18686 .31119 L
.18907 .31094 L
.19407 .31021 L
.2031 .30844 L
.22371 .30279 L
.26333 .28956 L
.30144 .27834 L
.32105 .27404 L
.33203 .27217 L
.342 .27084 L
.34685 .27032 L
.35198 .26987 L
.35636 .26956 L
.36118 .26931 L
.36389 .26921 L
.36517 .26917 L
.36636 .26914 L
.36773 .26912 L
Mistroke
.36845 .26911 L
.36922 .2691 L
.36995 .26909 L
.37064 .26909 L
.37193 .26909 L
.37315 .26909 L
.37445 .26911 L
.37555 .26912 L
.37676 .26915 L
.37807 .26918 L
.37946 .26923 L
.38198 .26933 L
.38455 .26947 L
.38728 .26965 L
.39218 .27006 L
.39745 .27065 L
.40326 .27147 L
.41365 .27346 L
.42339 .276 L
.43325 .27937 L
.44362 .28397 L
.45247 .28897 L
.46213 .29582 L
.47244 .30511 L
.48178 .3157 L
.50275 .34758 L
.52359 .38535 L
.54278 .416 L
.55246 .42818 L
.5615 .43735 L
.57094 .44473 L
.5813 .45046 L
.5863 .45242 L
.58893 .45326 L
.59173 .45402 L
.59417 .45456 L
.59687 .45506 L
.59932 .45541 L
.60042 .45553 L
.60163 .45565 L
.60272 .45574 L
.60389 .45582 L
.60513 .45588 L
.60628 .45592 L
.60743 .45595 L
.60852 .45596 L
.60949 .45595 L
.61055 .45593 L
.61171 .4559 L
.61298 .45584 L
Mistroke
.61431 .45576 L
.61556 .45567 L
.62018 .45521 L
.62515 .4545 L
.63057 .45352 L
.64044 .45129 L
.65897 .44625 L
.66996 .44319 L
.6803 .44054 L
.69037 .43841 L
.69479 .43767 L
.69713 .43733 L
.69963 .43702 L
.70211 .43676 L
.70437 .43658 L
.70545 .43651 L
.70664 .43644 L
.70775 .4364 L
.70878 .43637 L
.70993 .43635 L
.71101 .43634 L
.71219 .43635 L
.71347 .43638 L
.71473 .43642 L
.71537 .43646 L
.71607 .4365 L
.71844 .43669 L
.71982 .43683 L
.72112 .43699 L
.72354 .43736 L
.72898 .43854 L
.73369 .43998 L
.73878 .44203 L
.74826 .44738 L
.75364 .45141 L
.75867 .45587 L
.77972 .48138 L
.81857 .53537 L
.83976 .55698 L
.8495 .56476 L
.85986 .5717 L
.87029 .57742 L
.87972 .58162 L
.88868 .58483 L
.89813 .58748 L
.90293 .58855 L
.90819 .58955 L
.91302 .59029 L
.91743 .59084 L
.92264 .59133 L
Mistroke
.9255 .59154 L
.92821 .59169 L
.93072 .59179 L
.93191 .59183 L
.93303 .59186 L
.93424 .59189 L
.93488 .5919 L
.93557 .59191 L
.93629 .59191 L
.93698 .59192 L
.93827 .59192 L
.9395 .59191 L
.9402 .59191 L
.94084 .5919 L
.94201 .59188 L
.94326 .59186 L
.94541 .59179 L
.94778 .5917 L
.95303 .59142 L
.95793 .59106 L
.96674 .5902 L
.97619 .58901 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16951 L
.08255 .2225 L
.09396 .24492 L
.10458 .2613 L
.11508 .2736 L
.12023 .27834 L
.125 .28203 L
.1339 .28725 L
.1386 .2892 L
.14115 .29005 L
.14357 .29073 L
.14592 .29127 L
.14849 .29173 L
.14962 .29189 L
.15082 .29203 L
.15195 .29215 L
.15298 .29223 L
.1543 .29231 L
.15499 .29234 L
.15572 .29236 L
.15695 .29238 L
.15764 .29238 L
.15829 .29237 L
.15951 .29234 L
.16062 .29229 L
.1619 .29222 L
.16311 .29212 L
.16532 .29189 L
.16766 .29158 L
.17187 .29084 L
.17641 .28982 L
.18141 .28846 L
.20075 .28142 L
.22161 .27205 L
.26275 .25333 L
.28328 .24534 L
.30238 .23915 L
.3208 .2344 L
.33104 .23231 L
.34048 .23073 L
.35073 .22941 L
.35612 .22888 L
.36183 .22844 L
.36422 .22829 L
.36679 .22816 L
.36921 .22807 L
.37143 .228 L
.37277 .22797 L
Mistroke
.37402 .22795 L
.37473 .22794 L
.37538 .22793 L
.37613 .22792 L
.37684 .22792 L
.37813 .22792 L
.37931 .22793 L
.38061 .22794 L
.38126 .22795 L
.38198 .22797 L
.3845 .22803 L
.38592 .22808 L
.38724 .22814 L
.39221 .22842 L
.39673 .22878 L
.40153 .22928 L
.41148 .23073 L
.41715 .23182 L
.42246 .23305 L
.43232 .23592 L
.44268 .23991 L
.45153 .2443 L
.4612 .25041 L
.4715 .25884 L
.48085 .26862 L
.50181 .29923 L
.52265 .33753 L
.5318 .35365 L
.54184 .36924 L
.55088 .3808 L
.56057 .39037 L
.56592 .3944 L
.5708 .39732 L
.57571 .39955 L
.57811 .40039 L
.58036 .40105 L
.58257 .40155 L
.58494 .40196 L
.58623 .40212 L
.58693 .40219 L
.58758 .40224 L
.58874 .40232 L
.59 .40236 L
.59064 .40237 L
.59133 .40237 L
.59259 .40233 L
.59382 .40227 L
.59495 .40218 L
.59618 .40206 L
.59752 .40188 L
Mistroke
.60025 .40141 L
.60483 .40031 L
.60976 .3987 L
.61866 .39483 L
.63981 .38185 L
.6599 .36648 L
.69812 .3353 L
.73878 .3064 L
.75759 .29585 L
.77793 .2867 L
.79936 .27946 L
.81953 .27445 L
.83949 .27068 L
.86056 .26753 L
.88044 .26515 L
.89855 .26345 L
.91807 .2621 L
.92882 .26156 L
.93899 .26116 L
.94837 .26089 L
.9535 .26077 L
.95832 .26067 L
.96682 .26054 L
.97133 .26049 L
.97619 .26045 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.03279 .05676 L
.04262 .09657 L
.04758 .11314 L
.05288 .12777 L
.05789 .13852 L
.06244 .14576 L
.06507 .14888 L
.06785 .15142 L
.07022 .153 L
.07157 .15367 L
.07283 .15416 L
.07353 .15437 L
.07428 .15456 L
.075 .1547 L
.07567 .1548 L
.07692 .1549 L
.07763 .1549 L
.07826 .15488 L
.07901 .15483 L
.07971 .15474 L
.08047 .15462 L
.08127 .15445 L
.08262 .15409 L
.0841 .15359 L
.08678 .15244 L
.08922 .15114 L
.09469 .14752 L
.10458 .13937 L
.14443 .10294 L
.18275 .07619 L
.20253 .06622 L
.22354 .05796 L
.24301 .05206 L
.26129 .04773 L
.28147 .04405 L
.29997 .04147 L
.3189 .03945 L
.3396 .0378 L
.35921 .03667 L
.37019 .03618 L
.38016 .03582 L
.38948 .03554 L
.39934 .03531 L
.4045 .03521 L
.41017 .03512 L
.41494 .03506 L
.42014 .03501 L
.42285 .03499 L
.42536 .03498 L
Mistroke
.42775 .03496 L
.42909 .03496 L
.4303 .03496 L
.4315 .03495 L
.4326 .03495 L
.43381 .03495 L
.43509 .03495 L
.4362 .03495 L
.43724 .03495 L
.43837 .03495 L
.43959 .03496 L
.44099 .03496 L
.44228 .03497 L
.44521 .03499 L
.44779 .03501 L
.45052 .03503 L
.45526 .03509 L
.46048 .03517 L
.46541 .03528 L
.4706 .03541 L
.47987 .03571 L
.48984 .03616 L
.50074 .03681 L
.52203 .03849 L
.54135 .04003 L
.55101 .0406 L
.55646 .04084 L
.56147 .04101 L
.56587 .04111 L
.56836 .04116 L
.5707 .04118 L
.57196 .0412 L
.57316 .04121 L
.57423 .04121 L
.5754 .04121 L
.57667 .04122 L
.57731 .04122 L
.57802 .04122 L
.57927 .04121 L
.58045 .04121 L
.58162 .0412 L
.58287 .04119 L
.58513 .04116 L
.58782 .04112 L
.59026 .04108 L
.60061 .04082 L
.61012 .04051 L
.6191 .04016 L
.65754 .03847 L
.677 .03766 L
Mistroke
.69842 .0369 L
.71899 .03631 L
.73779 .03591 L
.74775 .03574 L
.75722 .03563 L
.7624 .03558 L
.76721 .03555 L
.76997 .03553 L
.77248 .03552 L
.77387 .03552 L
.77538 .03551 L
.77607 .03551 L
.7768 .03551 L
.7781 .03551 L
.77932 .03551 L
.78001 .03551 L
.78065 .03551 L
.78182 .03551 L
.78307 .03551 L
.78418 .03551 L
.78522 .03552 L
.78759 .03552 L
.79014 .03554 L
.79248 .03555 L
.79775 .0356 L
.80202 .03565 L
.80669 .03572 L
.81609 .03591 L
.82638 .0362 L
.83572 .03653 L
.85667 .03748 L
.87749 .03855 L
.89668 .03944 L
.90634 .0398 L
.91538 .04006 L
.9203 .04017 L
.9248 .04025 L
.9298 .04032 L
.93255 .04035 L
.93381 .04036 L
.93516 .04037 L
.93652 .04037 L
.93777 .04038 L
.93896 .04038 L
.94021 .04039 L
.94134 .04039 L
.94239 .04039 L
.94355 .04039 L
.94478 .04039 L
.9461 .04039 L
Mistroke
.94685 .04038 L
.94754 .04038 L
.95014 .04037 L
.95251 .04035 L
.95502 .04033 L
.95954 .04028 L
.96378 .04022 L
.97343 .04005 L
.97619 .03999 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16955 L
.08255 .22249 L
.09396 .24469 L
.10458 .26064 L
.10961 .2667 L
.11508 .27225 L
.11989 .2763 L
.125 .27978 L
.12959 .28223 L
.13203 .28329 L
.13466 .28424 L
.13706 .28496 L
.13926 .28548 L
.14147 .28589 L
.14357 .28617 L
.14482 .28629 L
.14552 .28634 L
.14616 .28638 L
.14735 .28643 L
.1486 .28645 L
.14972 .28644 L
.15077 .2864 L
.15192 .28634 L
.15316 .28625 L
.15447 .28612 L
.1559 .28594 L
.1585 .28552 L
.16338 .28444 L
.16801 .28309 L
.17293 .28136 L
.18177 .27758 L
.21952 .25628 L
.25972 .23308 L
.29841 .21572 L
.31845 .20916 L
.32865 .20647 L
.33955 .20407 L
.34989 .20225 L
.35929 .20097 L
.36382 .20048 L
.36874 .20005 L
.37338 .19973 L
.37557 .19962 L
.37766 .19953 L
.37882 .19948 L
.3801 .19944 L
.38127 .19941 L
.38233 .19939 L
Mistroke
.38359 .19937 L
.38428 .19936 L
.38493 .19936 L
.38609 .19935 L
.38735 .19935 L
.38845 .19936 L
.38965 .19937 L
.3909 .19939 L
.39208 .19942 L
.39417 .19948 L
.39642 .19958 L
.39908 .19972 L
.40197 .19991 L
.40722 .20038 L
.41233 .20098 L
.41706 .20168 L
.42671 .20356 L
.43576 .20596 L
.44569 .20947 L
.45638 .21455 L
.46597 .2206 L
.47646 .22931 L
.4874 .2414 L
.49757 .25581 L
.53667 .32639 L
.54694 .34192 L
.55234 .3488 L
.55805 .35504 L
.56305 .35962 L
.56855 .36371 L
.57355 .36658 L
.57822 .36858 L
.58081 .36942 L
.58321 .37002 L
.58585 .3705 L
.58718 .37067 L
.5879 .37074 L
.58865 .3708 L
.58993 .37088 L
.5911 .37091 L
.59237 .3709 L
.59308 .37088 L
.59375 .37085 L
.59496 .37077 L
.59607 .37067 L
.59734 .37052 L
.59854 .37034 L
.60079 .36992 L
.60317 .36936 L
.60744 .36808 L
Mistroke
.61709 .364 L
.62651 .35865 L
.63664 .35174 L
.65495 .33715 L
.69619 .30103 L
.73592 .27031 L
.77413 .24884 L
.79382 .241 L
.8148 .23464 L
.8564 .22563 L
.89649 .21826 L
.93506 .21145 L
.97608 .20521 L
.97619 .20519 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.02499 .01858 L
.02605 .02006 L
.02729 .02086 L
.02846 .02124 L
.02954 .02145 L
.03053 .02156 L
.03163 .02163 L
.03279 .02166 L
.03395 .02167 L
.0352 .02165 L
.03638 .02162 L
.03746 .02158 L
.04262 .02132 L
.06244 .02005 L
.08259 .0189 L
.10458 .01792 L
.12517 .01724 L
.14429 .01676 L
.16481 .01637 L
.18342 .0161 L
.20266 .01589 L
.22348 .01572 L
.24342 .0156 L
.26449 .01551 L
.28413 .01545 L
.30246 .0154 L
.32281 .01536 L
.34137 .01534 L
.36045 .01532 L
.38121 .0153 L
.40099 .01529 L
.41097 .01529 L
.422 .01529 L
.43142 .01528 L
.44134 .01528 L
.44654 .01528 L
.45222 .01528 L
.45701 .01528 L
.4622 .01528 L
.46495 .01528 L
.46748 .01528 L
.46991 .01528 L
.47114 .01528 L
.47247 .01528 L
.47367 .01528 L
.47477 .01528 L
.47587 .01528 L
.47692 .01528 L
.47813 .01528 L
Mistroke
.47926 .01528 L
.48049 .01528 L
.48181 .01528 L
.48323 .01528 L
.48453 .01528 L
.48747 .01528 L
.49007 .01528 L
.4928 .01528 L
.50276 .01528 L
.52266 .01528 L
.53135 .01528 L
.53593 .01528 L
.54078 .01528 L
.54327 .01528 L
.546 .01528 L
.54849 .01528 L
.55083 .01528 L
.55199 .01528 L
.55322 .01528 L
.55426 .01528 L
.5554 .01528 L
.55664 .01528 L
.55796 .01528 L
.5592 .01528 L
.56033 .01528 L
.56164 .01528 L
.56302 .01528 L
.5655 .01528 L
.56817 .01528 L
.5711 .01528 L
.57635 .01528 L
.58126 .01528 L
.60159 .01528 L
.62014 .01528 L
.65995 .01527 L
.69825 .01527 L
.718 .01527 L
.739 .01527 L
.74835 .01527 L
.75844 .01526 L
.77671 .01526 L
.78627 .01526 L
.79673 .01526 L
.80765 .01526 L
.81782 .01526 L
.82833 .01526 L
.83825 .01526 L
.8471 .01526 L
.85684 .01526 L
.86654 .01526 L
Mistroke
.87682 .01526 L
.89527 .01526 L
.90523 .01526 L
.91469 .01526 L
.91991 .01526 L
.9256 .01526 L
.93558 .01526 L
.94589 .01526 L
.95524 .01526 L
.97619 .01526 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16974 L
.08255 .2239 L
.09409 .24792 L
.10458 .26582 L
.11396 .27895 L
.12415 .29041 L
.13491 .29971 L
.14509 .30616 L
.15453 .31037 L
.1599 .3121 L
.16493 .31333 L
.16764 .31384 L
.17022 .31425 L
.17256 .31454 L
.17506 .31478 L
.17647 .31488 L
.17776 .31496 L
.17905 .31501 L
.18027 .31505 L
.18096 .31507 L
.18169 .31508 L
.183 .31509 L
.18373 .31508 L
.18441 .31508 L
.18515 .31506 L
.18596 .31504 L
.18717 .315 L
.18852 .31494 L
.19124 .31477 L
.19376 .31456 L
.19613 .31433 L
.20145 .31365 L
.2072 .31274 L
.22732 .30841 L
.26846 .29757 L
.28898 .29262 L
.30808 .28879 L
.32651 .28601 L
.33181 .2854 L
.33682 .2849 L
.34166 .2845 L
.34619 .2842 L
.35082 .28396 L
.35327 .28386 L
.35591 .28378 L
.35723 .28375 L
.35867 .28372 L
.35933 .28371 L
Mistroke
.36003 .2837 L
.36129 .28369 L
.36193 .28369 L
.36262 .28369 L
.36387 .28369 L
.36508 .2837 L
.3662 .28371 L
.36727 .28373 L
.36842 .28375 L
.37049 .28381 L
.37294 .28389 L
.37518 .284 L
.38005 .28429 L
.38465 .28466 L
.39433 .28577 L
.39922 .28652 L
.4046 .28748 L
.41359 .28949 L
.42304 .2922 L
.43316 .2959 L
.44242 .30017 L
.4524 .30593 L
.46329 .31393 L
.48294 .33431 L
.49393 .34959 L
.50391 .36553 L
.52475 .40055 L
.53389 .41441 L
.54394 .42748 L
.55297 .437 L
.56266 .4448 L
.56801 .44806 L
.5729 .45041 L
.5778 .45221 L
.5802 .45289 L
.58246 .45341 L
.58466 .45381 L
.58704 .45414 L
.58832 .45427 L
.58902 .45432 L
.58967 .45437 L
.59083 .45443 L
.5921 .45446 L
.59274 .45447 L
.59343 .45446 L
.59469 .45444 L
.59592 .45439 L
.59705 .45431 L
.59827 .45421 L
.59962 .45407 L
Mistroke
.60234 .4537 L
.60692 .45281 L
.61185 .45151 L
.62076 .44841 L
.6419 .43796 L
.662 .42554 L
.70021 .40024 L
.72155 .38721 L
.74088 .37698 L
.76104 .36838 L
.78003 .36252 L
.7898 .36039 L
.79514 .35948 L
.80012 .35879 L
.80437 .35833 L
.80893 .35796 L
.81153 .35781 L
.81281 .35775 L
.81399 .3577 L
.81504 .35767 L
.8162 .35764 L
.81736 .35762 L
.8186 .35761 L
.81982 .3576 L
.82095 .35761 L
.82219 .35762 L
.82289 .35764 L
.82352 .35765 L
.8248 .35769 L
.82619 .35774 L
.8287 .35787 L
.83104 .35803 L
.83352 .35823 L
.83796 .35871 L
.84309 .35943 L
.8479 .36027 L
.85882 .36278 L
.86924 .36594 L
.87912 .36958 L
.89767 .37777 L
.93593 .39729 L
.97619 .41596 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.03279 .05601 L
.03793 .07512 L
.04262 .08793 L
.04517 .09291 L
.04758 .09639 L
.0489 .09783 L
.05012 .0989 L
.05146 .0998 L
.05214 .10015 L
.05288 .10046 L
.05412 .10084 L
.05526 .10102 L
.05657 .10107 L
.05782 .10096 L
.05897 .10076 L
.06003 .10048 L
.06244 .0996 L
.06509 .0983 L
.06795 .0966 L
.07314 .09303 L
.08284 .0856 L
.10458 .06942 L
.12413 .05742 L
.14558 .04719 L
.166 .03984 L
.18507 .03465 L
.20542 .03046 L
.22398 .02759 L
.24306 .02534 L
.26382 .02352 L
.2836 .02224 L
.30461 .02123 L
.32408 .02055 L
.34236 .02007 L
.36254 .01967 L
.38104 .01941 L
.39997 .01921 L
.41069 .01913 L
.42067 .01906 L
.43119 .01901 L
.44113 .01897 L
.45005 .01894 L
.45508 .01893 L
.45971 .01892 L
.46439 .01891 L
.46701 .01891 L
.46825 .01891 L
.46941 .01891 L
.47058 .01891 L
Mistroke
.47163 .01891 L
.47281 .01891 L
.47406 .01891 L
.47515 .01891 L
.47634 .01891 L
.47745 .01891 L
.47848 .01891 L
.47967 .01891 L
.48096 .01891 L
.48327 .01891 L
.48602 .01891 L
.48852 .01891 L
.49397 .01892 L
.49912 .01893 L
.51737 .01898 L
.52776 .01901 L
.5375 .01903 L
.54215 .01904 L
.54704 .01905 L
.5496 .01905 L
.5524 .01905 L
.55363 .01906 L
.55495 .01906 L
.55619 .01906 L
.55731 .01906 L
.55863 .01906 L
.55929 .01906 L
.56002 .01906 L
.5613 .01906 L
.56251 .01906 L
.56324 .01906 L
.56393 .01906 L
.56522 .01906 L
.56661 .01906 L
.56813 .01906 L
.5707 .01905 L
.57343 .01905 L
.57833 .01904 L
.58769 .01903 L
.59778 .019 L
.61605 .01895 L
.65716 .01882 L
.67766 .01876 L
.69675 .01872 L
.71633 .01868 L
.73483 .01865 L
.74463 .01864 L
.75526 .01863 L
.77384 .01862 L
.78329 .01861 L
Mistroke
.79369 .01861 L
.79893 .01861 L
.80455 .01861 L
.80728 .01861 L
.80987 .0186 L
.8122 .0186 L
.81473 .0186 L
.81732 .0186 L
.81851 .0186 L
.81976 .0186 L
.82089 .0186 L
.82214 .0186 L
.82327 .0186 L
.82432 .0186 L
.82496 .0186 L
.82565 .0186 L
.82691 .0186 L
.82813 .0186 L
.82926 .0186 L
.83048 .0186 L
.83182 .0186 L
.83455 .0186 L
.83911 .0186 L
.84404 .0186 L
.85294 .01861 L
.8726 .01861 L
.883 .01861 L
.88871 .01861 L
.8941 .01861 L
.89927 .01861 L
.90199 .01861 L
.90486 .01861 L
.90729 .01861 L
.90857 .01861 L
.90995 .01861 L
.91122 .01861 L
.91238 .01861 L
.91354 .01861 L
.91464 .01861 L
.91585 .01861 L
.91694 .01861 L
.9182 .01861 L
.91939 .01861 L
.92049 .01861 L
.9215 .01861 L
.92378 .01861 L
.9261 .01861 L
.92863 .01861 L
.93374 .01861 L
.93901 .01861 L
Mistroke
.94399 .01861 L
.95331 .01861 L
.97424 .0186 L
.97619 .0186 L
Mfstroke
0 .751 1 r
.02381 .01472 m
.02605 .02526 L
.02729 .03032 L
.02846 .03437 L
.02954 .03745 L
.03072 .04004 L
.0318 .0418 L
.03279 .04299 L
.03396 .04398 L
.03506 .04458 L
.03626 .04498 L
.03756 .04518 L
.03821 .04521 L
.03891 .0452 L
.0402 .0451 L
.04145 .04492 L
.04262 .04469 L
.04765 .04335 L
.05221 .0419 L
.06244 .03854 L
.08269 .03269 L
.10458 .02786 L
.12545 .02448 L
.14465 .02218 L
.16347 .02048 L
.18413 .01909 L
.20364 .01813 L
.22456 .01738 L
.2458 .01682 L
.26592 .01644 L
.28583 .01616 L
.30425 .01597 L
.32291 .01582 L
.34352 .0157 L
.36286 .01562 L
.38372 .01556 L
.40376 .01552 L
.41396 .0155 L
.42486 .01548 L
.4352 .01547 L
.4446 .01546 L
.46297 .01545 L
.47295 .01544 L
.48215 .01544 L
.49225 .01543 L
.50295 .01543 L
.51239 .01543 L
.52252 .01543 L
.54084 .01543 L
.56201 .01542 L
Mistroke
.58211 .01542 L
.62036 .01541 L
.64172 .01541 L
.66106 .0154 L
.68147 .0154 L
.70024 .0154 L
.71952 .0154 L
.7303 .01539 L
.74036 .01539 L
.75023 .01539 L
.75922 .01539 L
.7692 .01539 L
.77439 .01539 L
.7799 .01539 L
.78462 .01539 L
.78983 .01539 L
.79212 .01539 L
.79457 .01539 L
.79688 .01539 L
.79902 .01539 L
.80034 .01539 L
.80154 .01539 L
.80288 .01539 L
.80361 .01539 L
.8043 .01539 L
.80498 .01539 L
.80569 .01539 L
.80697 .01539 L
.80769 .01539 L
.80835 .01539 L
.80908 .01539 L
.80986 .01539 L
.81114 .01539 L
.81253 .01539 L
.81506 .01539 L
.81752 .01539 L
.81979 .01539 L
.8294 .01539 L
.83843 .01539 L
.85903 .01539 L
.87748 .01539 L
.88794 .01539 L
.89768 .01539 L
.90736 .01539 L
.91277 .01539 L
.9177 .01539 L
.9204 .01539 L
.9229 .01539 L
.92564 .01539 L
.92702 .01539 L
Mistroke
.9278 .01539 L
.92854 .01539 L
.92918 .01539 L
.92988 .01539 L
.93109 .01539 L
.93178 .01539 L
.93252 .01539 L
.93384 .01539 L
.93448 .01539 L
.93517 .01539 L
.93643 .01539 L
.93879 .01539 L
.94096 .01539 L
.94328 .01539 L
.94746 .01539 L
.95244 .01539 L
.95698 .01539 L
.96685 .01539 L
.97619 .01539 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.03279 .0569 L
.04262 .09828 L
.053 .13433 L
.05753 .14698 L
.06244 .15834 L
.06526 .16371 L
.06786 .16791 L
.07051 .17147 L
.07298 .17414 L
.07559 .17631 L
.07697 .1772 L
.07846 .17796 L
.0792 .17826 L
.08001 .17855 L
.08072 .17875 L
.08149 .17892 L
.08224 .17904 L
.08292 .17911 L
.08361 .17915 L
.08426 .17915 L
.08544 .17908 L
.08673 .1789 L
.08738 .17876 L
.08808 .17858 L
.08934 .17819 L
.09179 .17716 L
.09402 .17595 L
.09944 .17212 L
.10458 .16757 L
.14291 .1251 L
.16229 .1057 L
.18369 .08808 L
.20418 .07476 L
.22296 .06517 L
.2423 .05744 L
.26316 .05105 L
.28208 .04664 L
.30279 .04298 L
.3224 .04038 L
.34335 .03833 L
.35359 .03754 L
.36469 .03683 L
.37429 .03631 L
.38484 .03583 L
.39443 .03548 L
.40472 .03518 L
.4104 .03505 L
.41559 .03494 L
.42052 .03486 L
Mistroke
.42576 .03479 L
.42843 .03476 L
.43094 .03473 L
.43339 .03471 L
.43563 .0347 L
.43777 .03469 L
.43885 .03469 L
.44003 .03468 L
.44122 .03468 L
.44249 .03468 L
.44369 .03468 L
.44479 .03468 L
.44607 .03468 L
.44672 .03468 L
.44744 .03468 L
.44871 .03469 L
.44989 .03469 L
.45257 .0347 L
.45544 .03472 L
.45801 .03475 L
.4607 .03478 L
.46552 .03485 L
.47054 .03494 L
.47509 .03505 L
.4853 .03536 L
.49476 .03576 L
.50368 .03623 L
.52204 .03742 L
.53246 .03812 L
.5422 .03868 L
.54713 .03891 L
.55181 .0391 L
.55439 .03918 L
.5572 .03926 L
.55973 .03932 L
.56212 .03936 L
.56463 .0394 L
.56597 .03941 L
.56742 .03943 L
.56885 .03944 L
.56957 .03944 L
.57035 .03944 L
.57103 .03944 L
.57175 .03944 L
.57305 .03944 L
.57436 .03944 L
.5751 .03944 L
.57578 .03943 L
.57703 .03942 L
.57835 .03941 L
Mistroke
.58065 .03939 L
.58317 .03935 L
.58838 .03926 L
.59332 .03914 L
.6026 .03885 L
.62348 .03804 L
.66169 .0364 L
.68303 .03559 L
.70236 .03497 L
.72275 .03444 L
.74151 .03405 L
.76077 .03375 L
.77154 .03362 L
.7816 .03352 L
.79145 .03344 L
.80043 .03338 L
.81041 .03333 L
.8156 .03331 L
.8211 .03329 L
.82582 .03328 L
.83103 .03327 L
.83581 .03326 L
.8402 .03325 L
.84536 .03325 L
.85092 .03324 L
.85581 .03324 L
.86097 .03324 L
.87125 .03323 L
.8763 .03323 L
.88095 .03323 L
.88518 .03323 L
.88966 .03323 L
.89415 .03322 L
.8991 .03322 L
.90924 .03321 L
.91872 .03319 L
.92883 .03316 L
.93968 .03313 L
.97619 .03298 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.03279 .05689 L
.04262 .09806 L
.04758 .11608 L
.05288 .13279 L
.05785 .14575 L
.06244 .15522 L
.06503 .15947 L
.06788 .16327 L
.07075 .16617 L
.07232 .16738 L
.07379 .16829 L
.07517 .16895 L
.07648 .16941 L
.07766 .16968 L
.07895 .16985 L
.07968 .16988 L
.08035 .16987 L
.08111 .16982 L
.08183 .16972 L
.08312 .16947 L
.08384 .16927 L
.08451 .16906 L
.08691 .16807 L
.08916 .16685 L
.09427 .16318 L
.10458 .15324 L
.14349 .10993 L
.1633 .09162 L
.18485 .07573 L
.20555 .06393 L
.22469 .0555 L
.24336 .04912 L
.26396 .04374 L
.28331 .03992 L
.30416 .03683 L
.3242 .03462 L
.3453 .03292 L
.36505 .03176 L
.38341 .03097 L
.39394 .03063 L
.40387 .03037 L
.41272 .03018 L
.42246 .03002 L
.42714 .02996 L
.43218 .0299 L
.43496 .02988 L
.4375 .02986 L
.44008 .02984 L
.44247 .02983 L
Mistroke
.44466 .02982 L
.44579 .02982 L
.447 .02982 L
.4477 .02982 L
.44834 .02981 L
.44959 .02981 L
.45073 .02981 L
.45194 .02981 L
.45301 .02981 L
.45416 .02981 L
.45524 .02982 L
.45622 .02982 L
.45864 .02982 L
.46092 .02983 L
.4633 .02985 L
.46553 .02986 L
.4706 .02991 L
.47555 .02997 L
.48087 .03005 L
.4905 .03024 L
.49931 .03047 L
.51987 .03118 L
.52989 .03155 L
.53898 .03185 L
.54355 .03197 L
.54849 .03208 L
.55315 .03217 L
.55744 .03223 L
.5598 .03225 L
.56201 .03227 L
.56325 .03228 L
.56443 .03228 L
.56507 .03228 L
.56578 .03229 L
.56702 .03229 L
.56823 .03229 L
.56892 .03229 L
.56957 .03229 L
.57087 .03229 L
.5716 .03229 L
.57228 .03229 L
.57341 .03228 L
.57465 .03228 L
.57714 .03226 L
.57967 .03224 L
.58242 .03221 L
.5874 .03215 L
.59673 .03199 L
.61767 .03151 L
.65856 .03045 L
Mistroke
.67889 .02998 L
.69793 .02961 L
.71734 .0293 L
.73578 .02906 L
.75605 .02887 L
.77458 .02875 L
.78417 .0287 L
.7944 .02866 L
.80404 .02863 L
.81279 .02861 L
.81767 .0286 L
.82282 .0286 L
.82722 .02859 L
.82972 .02859 L
.83205 .02859 L
.83334 .02859 L
.83475 .02859 L
.83599 .02859 L
.83731 .02859 L
.83849 .02859 L
.8398 .02859 L
.84099 .02859 L
.8421 .02859 L
.84342 .02859 L
.84408 .02859 L
.84481 .02859 L
.84609 .02859 L
.84729 .02859 L
.84999 .02859 L
.85287 .02859 L
.85821 .02859 L
.86313 .02859 L
.87424 .0286 L
.87926 .0286 L
.88465 .02861 L
.88931 .02861 L
.89195 .02861 L
.89439 .02861 L
.89683 .02861 L
.8982 .02861 L
.89943 .02861 L
.90061 .02861 L
.90189 .02861 L
.9031 .02861 L
.90421 .02861 L
.90528 .02861 L
.90629 .02861 L
.90739 .02861 L
.90857 .02861 L
.91098 .02861 L
Mistroke
.91317 .02861 L
.91582 .02861 L
.91826 .02861 L
.92378 .0286 L
.92865 .0286 L
.93382 .02859 L
.94322 .02858 L
.95334 .02856 L
.97164 .02852 L
.97619 .02851 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .16924 L
.08255 .22121 L
.09396 .24264 L
.10458 .25785 L
.10961 .26358 L
.11508 .2688 L
.11989 .27259 L
.125 .27583 L
.12959 .2781 L
.13203 .27908 L
.13466 .27996 L
.13706 .28062 L
.13926 .2811 L
.14147 .28147 L
.14357 .28173 L
.14482 .28183 L
.14552 .28188 L
.14616 .28191 L
.14735 .28195 L
.1486 .28197 L
.14972 .28196 L
.15077 .28192 L
.15192 .28186 L
.15316 .28177 L
.15447 .28165 L
.1559 .28148 L
.1585 .2811 L
.16338 .2801 L
.16801 .27885 L
.17293 .27725 L
.18177 .27378 L
.21952 .25418 L
.25972 .23272 L
.29841 .21654 L
.31845 .21042 L
.32865 .2079 L
.33955 .20567 L
.34989 .20398 L
.35929 .20282 L
.36382 .20238 L
.36874 .202 L
.37099 .20186 L
.37338 .20173 L
.37542 .20164 L
.37766 .20156 L
.37897 .20153 L
.38018 .2015 L
.38135 .20148 L
Mistroke
.38259 .20146 L
.3838 .20146 L
.38495 .20146 L
.38598 .20146 L
.38709 .20147 L
.38832 .20149 L
.38901 .2015 L
.38966 .20151 L
.39237 .20159 L
.39472 .20169 L
.39723 .20182 L
.40215 .20217 L
.40681 .20262 L
.41554 .20379 L
.42015 .20459 L
.42522 .20565 L
.43549 .2084 L
.445 .21182 L
.45392 .21598 L
.46378 .22197 L
.47415 .23032 L
.483 .23956 L
.49266 .25234 L
.51396 .28995 L
.53328 .32745 L
.54294 .34384 L
.5534 .3586 L
.56328 .36942 L
.57237 .37673 L
.57706 .37955 L
.58209 .38193 L
.58453 .38284 L
.58684 .38357 L
.5889 .38412 L
.59118 .38461 L
.59366 .38502 L
.59503 .38519 L
.59631 .38531 L
.5975 .3854 L
.5986 .38545 L
.5998 .38548 L
.60106 .38549 L
.60235 .38546 L
.60307 .38544 L
.60373 .38541 L
.605 .38532 L
.6062 .38522 L
.6089 .38491 L
.61183 .38444 L
.61671 .3834 L
Mistroke
.62128 .38217 L
.63168 .37856 L
.65272 .36915 L
.67127 .3601 L
.69151 .35123 L
.70248 .34747 L
.70782 .34603 L
.71266 .345 L
.71507 .34459 L
.71767 .34424 L
.71886 .34411 L
.72013 .34399 L
.72131 .3439 L
.72239 .34384 L
.72362 .34379 L
.72494 .34377 L
.72617 .34378 L
.72733 .3438 L
.72798 .34383 L
.72868 .34387 L
.72993 .34396 L
.73127 .34409 L
.73275 .34427 L
.7351 .34466 L
.73768 .34522 L
.74036 .34598 L
.74286 .34684 L
.74733 .34882 L
.75211 .35159 L
.75774 .35585 L
.76305 .36096 L
.77298 .37365 L
.78271 .39005 L
.793 .41064 L
.81146 .44979 L
.83127 .48712 L
.84937 .51415 L
.86883 .53584 L
.87955 .54486 L
.88973 .55169 L
.89935 .55675 L
.90463 .55898 L
.90959 .56075 L
.91423 .56214 L
.91925 .56334 L
.92381 .56419 L
.92799 .56476 L
.93046 .56501 L
.93271 .56519 L
.93396 .56526 L
Mistroke
.93531 .56533 L
.93659 .56537 L
.93776 .56539 L
.93885 .5654 L
.93987 .5654 L
.94098 .56539 L
.94218 .56537 L
.94344 .56532 L
.94463 .56527 L
.94687 .56513 L
.94935 .56493 L
.952 .56465 L
.95676 .56399 L
.96242 .56296 L
.96755 .56179 L
.97619 .55937 L
Mfstroke
0 .656 1 r
.02381 .01472 m
.02846 .0363 L
.03279 .05251 L
.03527 .05955 L
.03754 .0645 L
.03879 .06668 L
.04015 .06864 L
.04142 .07013 L
.04262 .07126 L
.04376 .07212 L
.045 .07284 L
.0457 .07315 L
.04637 .0734 L
.04762 .07374 L
.04894 .07393 L
.05016 .07399 L
.05086 .07397 L
.0515 .07392 L
.05223 .07384 L
.05293 .07374 L
.05408 .07352 L
.05531 .07322 L
.0575 .07254 L
.06244 .07056 L
.08424 .05947 L
.10458 .04987 L
.12408 .04243 L
.14255 .03688 L
.1629 .03216 L
.18146 .02888 L
.20137 .0262 L
.21979 .02431 L
.23845 .02286 L
.25906 .02165 L
.2784 .0208 L
.29926 .02012 L
.3193 .01964 L
.3404 .01928 L
.36014 .01903 L
.37851 .01885 L
.38903 .01878 L
.39896 .01872 L
.41755 .01863 L
.42727 .0186 L
.43259 .01859 L
.43757 .01858 L
.44216 .01857 L
.44635 .01856 L
.45101 .01856 L
.45358 .01856 L
Mistroke
.45602 .01855 L
.45727 .01855 L
.45862 .01855 L
.45989 .01855 L
.46106 .01855 L
.46212 .01855 L
.46329 .01855 L
.4645 .01855 L
.46563 .01855 L
.46627 .01855 L
.46696 .01855 L
.46822 .01855 L
.46944 .01855 L
.47057 .01855 L
.47314 .01856 L
.47586 .01856 L
.48038 .01856 L
.48462 .01857 L
.49426 .01859 L
.50412 .01862 L
.51449 .01865 L
.533 .01872 L
.54257 .01874 L
.54793 .01875 L
.55278 .01876 L
.55499 .01877 L
.55733 .01877 L
.55855 .01877 L
.55989 .01877 L
.56112 .01877 L
.56225 .01877 L
.56339 .01877 L
.56447 .01877 L
.56561 .01877 L
.56686 .01877 L
.56794 .01877 L
.56909 .01877 L
.57008 .01877 L
.57116 .01877 L
.57238 .01877 L
.57351 .01877 L
.57607 .01877 L
.57857 .01877 L
.58124 .01876 L
.59049 .01875 L
.60141 .01873 L
.61134 .0187 L
.65128 .01859 L
.68972 .01849 L
.70957 .01846 L
Mistroke
.73061 .01842 L
.74003 .01841 L
.75016 .0184 L
.75965 .01839 L
.76846 .01839 L
.77858 .01838 L
.78392 .01838 L
.78665 .01838 L
.78961 .01838 L
.79244 .01838 L
.79504 .01838 L
.79753 .01838 L
.79878 .01838 L
.80015 .01838 L
.8014 .01838 L
.80254 .01838 L
.80385 .01838 L
.80509 .01838 L
.80624 .01838 L
.8073 .01838 L
.80847 .01838 L
.8097 .01838 L
.81209 .01838 L
.8146 .01838 L
.81908 .01838 L
.82391 .01838 L
.82919 .01838 L
.83867 .01839 L
.84748 .01839 L
.88654 .01842 L
.90647 .01844 L
.91193 .01844 L
.9177 .01844 L
.9227 .01844 L
.92806 .01844 L
.9307 .01845 L
.9332 .01845 L
.93564 .01845 L
.9379 .01845 L
.939 .01845 L
.94004 .01845 L
.94123 .01845 L
.94231 .01845 L
.94351 .01845 L
.94462 .01845 L
.94583 .01845 L
.94711 .01845 L
.94842 .01845 L
.94961 .01845 L
.95229 .01845 L
Mistroke
.95476 .01845 L
.95711 .01845 L
.96236 .01844 L
.96806 .01844 L
.97619 .01844 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .1698 L
.08255 .22439 L
.09409 .24897 L
.10458 .26764 L
.12415 .29428 L
.13491 .30499 L
.14509 .31289 L
.15478 .31866 L
.16009 .32115 L
.16506 .32311 L
.17384 .32573 L
.17849 .32674 L
.1835 .32754 L
.18604 .32785 L
.18874 .32812 L
.19006 .32822 L
.19129 .3283 L
.1924 .32836 L
.19361 .32842 L
.19495 .32846 L
.19568 .32848 L
.19637 .3285 L
.19759 .32851 L
.19891 .32852 L
.19964 .32851 L
.20045 .32851 L
.2012 .32849 L
.2019 .32848 L
.20323 .32844 L
.20464 .32839 L
.20701 .32827 L
.20956 .32811 L
.21419 .32771 L
.21969 .3271 L
.22473 .32642 L
.26435 .31892 L
.30246 .31156 L
.32207 .30875 L
.33305 .30761 L
.3378 .30722 L
.34302 .30687 L
.34787 .30662 L
.35052 .30652 L
.353 .30644 L
.35419 .30642 L
.35532 .30639 L
.35635 .30638 L
.35744 .30636 L
Mistroke
.35862 .30635 L
.35972 .30635 L
.36102 .30635 L
.36221 .30635 L
.36351 .30637 L
.36417 .30637 L
.36489 .30639 L
.36736 .30644 L
.36875 .30648 L
.37024 .30653 L
.37292 .30665 L
.3782 .30696 L
.383 .30734 L
.38783 .30784 L
.39294 .30848 L
.40213 .30998 L
.41201 .31213 L
.4229 .31526 L
.43302 .31902 L
.44229 .32333 L
.4531 .32968 L
.46316 .33715 L
.48212 .35654 L
.50283 .38655 L
.52161 .41754 L
.54193 .44676 L
.55306 .45904 L
.56332 .46783 L
.57312 .47409 L
.57805 .47652 L
.58348 .47866 L
.58871 .48026 L
.59367 .48139 L
.59812 .4821 L
.60064 .48239 L
.60297 .48259 L
.60416 .48267 L
.60545 .48274 L
.60666 .48278 L
.60778 .48281 L
.60902 .48283 L
.60972 .48283 L
.61037 .48283 L
.61169 .48281 L
.61243 .4828 L
.6131 .48278 L
.61448 .48273 L
.61575 .48266 L
.61864 .48248 L
.62118 .48226 L
Mistroke
.62387 .48198 L
.63329 .48067 L
.64342 .47886 L
.66173 .47516 L
.67184 .4732 L
.67718 .47228 L
.68288 .47142 L
.68834 .47073 L
.6933 .47026 L
.69569 .47009 L
.69695 .47001 L
.69828 .46995 L
.69945 .4699 L
.70072 .46986 L
.70189 .46984 L
.70297 .46983 L
.70423 .46983 L
.70487 .46984 L
.70557 .46985 L
.70682 .46988 L
.70798 .46992 L
.70935 .46999 L
.71061 .47006 L
.71343 .4703 L
.71574 .47056 L
.71826 .47091 L
.72334 .47187 L
.72799 .47306 L
.73296 .4747 L
.7419 .47872 L
.75215 .48524 L
.76326 .4948 L
.78342 .51765 L
.80292 .54118 L
.82436 .56267 L
.84473 .57775 L
.86378 .58777 L
.8742 .59186 L
.88408 .59496 L
.89295 .59718 L
.90262 .59906 L
.90796 .59988 L
.91298 .60052 L
.91754 .60101 L
.92235 .60143 L
.92761 .60178 L
.93244 .60202 L
.93513 .60212 L
.93764 .60219 L
.93906 .60222 L
Mistroke
.94039 .60224 L
.94194 .60227 L
.94267 .60227 L
.94334 .60228 L
.94432 .60229 L
.94538 .60229 L
.94635 .60229 L
.94728 .60229 L
.94836 .60229 L
.94936 .60229 L
.95046 .60228 L
.95163 .60226 L
.954 .60223 L
.95624 .60219 L
.96042 .60208 L
.96799 .60181 L
.97619 .60142 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16981 L
.08255 .22446 L
.09409 .24915 L
.10458 .26798 L
.12415 .29512 L
.13491 .30623 L
.14509 .31459 L
.15478 .32085 L
.16506 .32588 L
.17384 .32904 L
.17883 .33043 L
.1835 .33148 L
.18847 .33235 L
.19109 .33272 L
.19388 .33305 L
.19657 .3333 L
.199 .33348 L
.20017 .33355 L
.20145 .33362 L
.20264 .33367 L
.20375 .33371 L
.20483 .33374 L
.20599 .33376 L
.20727 .33378 L
.20844 .33378 L
.20966 .33378 L
.21035 .33378 L
.21099 .33377 L
.21216 .33375 L
.2134 .33372 L
.21557 .33365 L
.21762 .33356 L
.22227 .33329 L
.22697 .33292 L
.23211 .33242 L
.24246 .33119 L
.26096 .32851 L
.28221 .32523 L
.30152 .32254 L
.31116 .32141 L
.32161 .32039 L
.3264 .32001 L
.33147 .31966 L
.33614 .3194 L
.34057 .31921 L
.34293 .31913 L
.3455 .31906 L
.34663 .31903 L
Mistroke
.34784 .31901 L
.34897 .319 L
.35 .31898 L
.35132 .31897 L
.35201 .31897 L
.35275 .31897 L
.35398 .31897 L
.35467 .31897 L
.35532 .31898 L
.35654 .31899 L
.35765 .319 L
.35893 .31903 L
.36014 .31905 L
.36236 .31911 L
.3647 .3192 L
.36892 .31939 L
.37346 .31968 L
.37846 .32009 L
.38857 .32124 L
.39784 .3227 L
.40801 .32482 L
.41871 .32774 L
.42828 .33105 L
.43849 .33546 L
.45687 .34639 L
.46714 .35467 L
.47826 .36588 L
.49842 .39263 L
.51794 .4232 L
.52829 .43862 L
.53939 .45313 L
.55006 .46459 L
.55979 .4728 L
.56447 .47601 L
.56957 .47897 L
.57885 .48305 L
.58369 .48456 L
.58823 .48561 L
.59083 .48607 L
.59322 .48641 L
.59584 .48668 L
.59716 .48678 L
.59785 .48683 L
.5986 .48687 L
.59933 .48691 L
.60001 .48693 L
.60066 .48695 L
.60135 .48696 L
.60254 .48698 L
.60385 .48697 L
Mistroke
.60458 .48696 L
.60525 .48694 L
.60602 .48692 L
.60675 .48689 L
.60805 .48682 L
.60947 .48673 L
.61201 .48651 L
.61472 .48622 L
.6196 .48553 L
.62989 .48352 L
.64102 .48072 L
.6612 .47484 L
.68076 .46924 L
.69112 .46672 L
.69682 .46554 L
.70222 .4646 L
.70735 .46389 L
.71024 .46358 L
.71292 .46335 L
.71516 .46321 L
.71644 .46315 L
.71764 .4631 L
.7189 .46307 L
.72006 .46306 L
.72133 .46306 L
.72196 .46306 L
.72266 .46308 L
.72395 .46311 L
.72516 .46316 L
.72626 .46322 L
.72744 .4633 L
.73009 .46355 L
.73254 .46385 L
.73701 .46461 L
.74173 .46574 L
.74667 .4673 L
.75118 .4691 L
.76132 .47458 L
.77072 .48159 L
.77964 .48997 L
.8179 .53492 L
.83928 .55671 L
.85862 .57189 L
.87882 .58356 L
.89782 .59132 L
.90762 .59433 L
.91795 .5969 L
.92763 .5988 L
.93644 .60018 L
.94596 .60133 L
Mistroke
.95614 .60225 L
.96066 .60257 L
.96557 .60286 L
.97449 .60326 L
.97619 .60332 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.04262 .09888 L
.06244 .168 L
.07286 .19523 L
.08255 .21479 L
.08802 .22338 L
.0932 .22995 L
.09605 .23295 L
.09916 .23572 L
.10177 .23767 L
.10458 .23939 L
.10712 .24063 L
.10945 .24151 L
.11057 .24184 L
.11179 .24215 L
.11294 .24238 L
.11402 .24255 L
.11468 .24263 L
.11539 .2427 L
.11663 .24277 L
.11733 .24279 L
.11808 .24278 L
.11871 .24276 L
.11941 .24273 L
.12066 .24262 L
.12136 .24253 L
.122 .24244 L
.12442 .24197 L
.1271 .24124 L
.12959 .24037 L
.13522 .23782 L
.14545 .23147 L
.18471 .1974 L
.22246 .1652 L
.24344 .1505 L
.26267 .13928 L
.28271 .12974 L
.30135 .12266 L
.32028 .11701 L
.33093 .11444 L
.34098 .11238 L
.35079 .11068 L
.36144 .10918 L
.37111 .10811 L
.38002 .10735 L
.3847 .10704 L
.38972 .10677 L
.39215 .10667 L
.39446 .10659 L
.39673 .10652 L
Mistroke
.39879 .10647 L
.39998 .10645 L
.40127 .10643 L
.40198 .10642 L
.40263 .10641 L
.40391 .1064 L
.40501 .1064 L
.40622 .1064 L
.40748 .1064 L
.40866 .10641 L
.40933 .10642 L
.41006 .10643 L
.41138 .10645 L
.41386 .1065 L
.41675 .10659 L
.41943 .10669 L
.42407 .10693 L
.42908 .10728 L
.43813 .10816 L
.44337 .10885 L
.44889 .10972 L
.45874 .11177 L
.46832 .1145 L
.47853 .11848 L
.48816 .12359 L
.49691 .12968 L
.51613 .1483 L
.53694 .17184 L
.54723 .18153 L
.55685 .18829 L
.56169 .19078 L
.56689 .19278 L
.56985 .19361 L
.57265 .1942 L
.57517 .19458 L
.57659 .19474 L
.57791 .19484 L
.57908 .1949 L
.58032 .19493 L
.58138 .19493 L
.58253 .19491 L
.58378 .19485 L
.58448 .19481 L
.58512 .19476 L
.58752 .19452 L
.58975 .19421 L
.59216 .19378 L
.59655 .19277 L
.60726 .18929 L
.61714 .1851 L
Mistroke
.65652 .16438 L
.69437 .14527 L
.71542 .13649 L
.73468 .12981 L
.7548 .12416 L
.77347 .12005 L
.79247 .11686 L
.8132 .1143 L
.83374 .11245 L
.85235 .11113 L
.89243 .10862 L
.93101 .10609 L
.97203 .10346 L
.97619 .10321 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.04262 .09858 L
.0522 .1336 L
.06244 .16407 L
.0679 .17718 L
.07286 .18723 L
.0779 .19565 L
.08255 .20187 L
.08798 .20735 L
.09084 .20951 L
.09388 .21129 L
.09514 .21188 L
.09651 .21242 L
.09768 .21282 L
.09897 .21317 L
.09975 .21335 L
.10047 .21348 L
.10122 .2136 L
.1019 .21368 L
.1032 .21378 L
.10391 .2138 L
.10458 .21381 L
.10574 .21377 L
.10699 .21367 L
.10816 .21352 L
.10923 .21333 L
.11186 .21271 L
.11434 .21191 L
.11928 .20977 L
.12466 .20674 L
.14313 .19257 L
.18391 .15571 L
.22318 .12616 L
.26093 .10615 L
.28028 .0987 L
.30113 .09241 L
.32117 .0878 L
.34227 .08422 L
.35182 .08297 L
.36201 .08186 L
.37157 .08102 L
.38038 .08041 L
.38526 .08014 L
.39062 .0799 L
.39602 .07971 L
.39897 .07963 L
.40173 .07957 L
.40297 .07955 L
.40433 .07953 L
.40553 .07951 L
Mistroke
.4068 .0795 L
.40807 .07949 L
.40921 .07949 L
.41036 .07949 L
.41144 .07949 L
.41271 .07949 L
.41335 .07949 L
.41406 .0795 L
.4153 .07951 L
.41646 .07952 L
.41908 .07956 L
.42188 .07962 L
.42445 .07969 L
.42718 .07978 L
.43208 .07999 L
.43735 .08029 L
.44316 .08072 L
.44816 .08118 L
.45355 .08178 L
.46329 .0832 L
.47289 .08513 L
.48337 .08805 L
.49432 .09232 L
.50448 .09769 L
.52326 .11091 L
.54358 .12573 L
.54899 .12891 L
.55472 .13176 L
.56002 .13389 L
.56497 .13545 L
.5696 .13653 L
.5722 .13699 L
.57458 .13732 L
.57717 .13758 L
.57864 .13769 L
.57934 .13773 L
.57999 .13776 L
.58118 .1378 L
.58248 .13783 L
.58376 .13784 L
.58447 .13783 L
.58513 .13782 L
.58641 .13779 L
.58761 .13774 L
.58869 .13768 L
.58986 .1376 L
.59249 .13737 L
.59492 .1371 L
.59934 .13648 L
.60403 .13565 L
Mistroke
.62472 .13052 L
.66258 .11888 L
.68363 .1129 L
.70289 .1083 L
.7124 .1064 L
.72278 .10467 L
.73258 .10337 L
.73732 .10289 L
.74168 .10252 L
.7441 .10236 L
.74676 .10221 L
.74943 .1021 L
.75089 .10206 L
.75155 .10204 L
.75226 .10203 L
.75355 .10201 L
.75477 .102 L
.75596 .102 L
.75706 .10201 L
.75825 .10203 L
.75956 .10206 L
.76093 .10211 L
.76222 .10216 L
.76449 .1023 L
.76689 .10248 L
.77117 .10294 L
.77356 .10328 L
.77579 .10365 L
.78083 .10473 L
.78588 .10617 L
.79136 .10823 L
.79653 .11073 L
.8013 .11359 L
.81033 .12068 L
.81989 .13084 L
.83948 .1598 L
.8578 .19229 L
.87639 .2232 L
.8862 .23668 L
.89664 .24816 L
.90242 .25313 L
.90764 .25678 L
.91289 .25963 L
.91783 .26158 L
.92029 .26229 L
.92287 .26287 L
.92508 .26322 L
.92633 .26336 L
.9275 .26345 L
.92815 .26349 L
Mistroke
.92886 .26352 L
.93014 .26354 L
.93139 .26352 L
.93254 .26347 L
.93379 .26338 L
.93516 .26323 L
.9366 .26304 L
.93794 .26282 L
.94283 .26167 L
.9456 .26081 L
.94818 .25988 L
.95791 .25533 L
.97619 .24338 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16974 L
.08255 .22387 L
.09409 .24785 L
.10458 .26569 L
.11396 .27872 L
.12415 .29002 L
.13491 .29907 L
.14017 .30251 L
.14509 .3052 L
.15002 .30742 L
.15453 .30905 L
.15954 .31045 L
.16233 .31106 L
.16493 .31152 L
.16742 .31187 L
.17008 .31214 L
.1716 .31226 L
.17235 .3123 L
.17303 .31234 L
.17432 .31239 L
.17499 .31241 L
.17571 .31242 L
.17693 .31243 L
.17823 .31243 L
.17947 .3124 L
.18059 .31236 L
.18191 .3123 L
.18335 .31222 L
.18596 .31201 L
.18829 .31176 L
.1908 .31145 L
.19535 .31075 L
.20573 .3086 L
.22674 .30262 L
.26788 .28887 L
.2884 .2826 L
.3075 .27767 L
.32593 .27395 L
.33624 .27236 L
.34561 .27124 L
.35046 .27078 L
.35559 .2704 L
.35997 .27016 L
.36246 .27005 L
.36479 .26998 L
.36608 .26994 L
.36748 .26992 L
.36812 .26991 L
Mistroke
.36881 .2699 L
.37003 .26989 L
.37133 .26988 L
.37255 .26989 L
.37364 .26989 L
.37482 .26991 L
.37612 .26993 L
.37755 .26997 L
.38043 .27006 L
.3831 .27019 L
.38559 .27033 L
.39061 .27072 L
.39607 .27129 L
.40598 .27274 L
.41564 .27473 L
.42455 .27717 L
.4342 .28057 L
.44325 .28462 L
.45318 .29026 L
.46387 .29807 L
.47347 .30702 L
.48395 .31933 L
.50506 .35247 L
.52636 .39093 L
.54568 .42056 L
.55534 .43195 L
.5658 .44156 L
.5706 .44506 L
.57568 .44818 L
.58035 .45054 L
.58477 .45236 L
.58972 .45395 L
.59424 .45502 L
.59676 .45546 L
.5991 .45579 L
.60166 .45605 L
.60296 .45614 L
.60364 .45618 L
.60439 .45622 L
.60554 .45626 L
.60676 .45629 L
.60788 .4563 L
.60893 .45629 L
.61017 .45627 L
.6113 .45623 L
.6126 .45617 L
.61384 .45609 L
.61605 .45591 L
.61809 .45571 L
.62271 .45509 L
Mistroke
.62738 .4543 L
.63239 .45327 L
.64145 .45106 L
.66208 .44511 L
.68181 .43961 L
.68721 .43834 L
.69297 .43716 L
.69837 .43626 L
.70333 .43564 L
.70584 .43542 L
.70712 .43532 L
.70849 .43525 L
.70921 .43521 L
.70986 .43519 L
.71115 .43515 L
.71186 .43514 L
.71264 .43513 L
.71338 .43513 L
.71406 .43514 L
.71526 .43516 L
.71639 .4352 L
.71763 .43526 L
.71896 .43536 L
.72168 .43562 L
.72417 .43596 L
.72857 .4368 L
.73106 .43742 L
.73337 .43811 L
.74306 .44216 L
.74811 .44512 L
.75359 .44908 L
.76353 .45836 L
.78212 .48247 L
.80162 .51173 L
.82306 .53997 L
.84343 .56038 L
.86248 .57424 L
.8729 .58 L
.88279 .58445 L
.89252 .58796 L
.90133 .59049 L
.91095 .59262 L
.91587 .59348 L
.92119 .59425 L
.92613 .59483 L
.93067 .59526 L
.93501 .59558 L
.93959 .59582 L
.94206 .59592 L
.94438 .59599 L
Mistroke
.94647 .59604 L
.94765 .59606 L
.94874 .59607 L
.94991 .59608 L
.95101 .59608 L
.95221 .59609 L
.9535 .59608 L
.95414 .59608 L
.95485 .59607 L
.95613 .59606 L
.95738 .59604 L
.95854 .59602 L
.96084 .59597 L
.96302 .5959 L
.96708 .59575 L
.97619 .59528 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .16946 L
.08255 .2224 L
.09396 .24488 L
.10458 .26141 L
.11508 .27399 L
.125 .28282 L
.1339 .28849 L
.13893 .29086 L
.14357 .29256 L
.14823 .29383 L
.15085 .29436 L
.15324 .29475 L
.15546 .29502 L
.15672 .29513 L
.15788 .29522 L
.159 .29528 L
.16002 .29533 L
.16119 .29535 L
.1623 .29536 L
.16349 .29536 L
.16481 .29532 L
.16547 .2953 L
.16618 .29527 L
.16746 .29519 L
.16994 .29498 L
.17221 .29473 L
.17771 .2939 L
.18292 .29283 L
.19258 .29029 L
.20283 .28696 L
.22125 .28 L
.259 .26499 L
.27998 .25758 L
.29921 .25185 L
.31805 .24738 L
.32765 .24558 L
.33789 .24401 L
.34321 .24334 L
.34824 .24281 L
.35313 .24238 L
.35764 .24207 L
.36192 .24185 L
.36407 .24176 L
.36645 .24169 L
.36769 .24166 L
.36883 .24164 L
.37014 .24162 L
.37138 .24161 L
Mistroke
.37253 .24161 L
.37359 .24161 L
.37476 .24162 L
.376 .24163 L
.37725 .24166 L
.37862 .24169 L
.38138 .24177 L
.38393 .24188 L
.38631 .24202 L
.39169 .24241 L
.39745 .24299 L
.40288 .2437 L
.40802 .24452 L
.41764 .2465 L
.42732 .24916 L
.43759 .25287 L
.44635 .25691 L
.45602 .26254 L
.46614 .27009 L
.4754 .27886 L
.49627 .30672 L
.51684 .34316 L
.53595 .37587 L
.54545 .38906 L
.55441 .39905 L
.55937 .40353 L
.56474 .40753 L
.56926 .41023 L
.57411 .41249 L
.57668 .41342 L
.57902 .41411 L
.58137 .41467 L
.5836 .41507 L
.58486 .41524 L
.58619 .41538 L
.58733 .41547 L
.58859 .41553 L
.5893 .41555 L
.58994 .41555 L
.59065 .41555 L
.59139 .41554 L
.59265 .41548 L
.59336 .41544 L
.59403 .41539 L
.59534 .41526 L
.59677 .41508 L
.59936 .41466 L
.6042 .41353 L
.60986 .4117 L
.61508 .40958 L
Mistroke
.63382 .39927 L
.65445 .38473 L
.69476 .35375 L
.73355 .32763 L
.7547 .3165 L
.7748 .30829 L
.78439 .30517 L
.79462 .3024 L
.81301 .29865 L
.82331 .29715 L
.82872 .29652 L
.83444 .29597 L
.83945 .29558 L
.8421 .29542 L
.84495 .29527 L
.84756 .29516 L
.84995 .29508 L
.85109 .29505 L
.85234 .29502 L
.85352 .29501 L
.85461 .29499 L
.85579 .29499 L
.85703 .29498 L
.85809 .29499 L
.85925 .295 L
.8605 .29501 L
.8612 .29502 L
.86184 .29504 L
.86425 .2951 L
.86648 .29518 L
.8689 .2953 L
.87329 .29557 L
.8785 .296 L
.88402 .2966 L
.8939 .29801 L
.90334 .29975 L
.91349 .30201 L
.93181 .30692 L
.9731 .31983 L
.97619 .3208 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.04262 .0989 L
.06244 .16855 L
.07286 .19671 L
.08255 .21772 L
.0932 .2352 L
.09916 .24259 L
.10458 .24791 L
.10941 .2516 L
.11206 .25322 L
.11454 .25449 L
.11891 .2562 L
.12123 .25684 L
.12244 .2571 L
.12373 .25733 L
.12511 .25752 L
.12639 .25764 L
.12717 .2577 L
.12791 .25773 L
.12857 .25774 L
.12929 .25775 L
.12993 .25774 L
.13063 .25772 L
.13136 .25768 L
.13205 .25763 L
.13327 .25752 L
.13458 .25735 L
.13725 .25689 L
.13977 .2563 L
.14451 .25484 L
.15416 .25064 L
.16442 .24479 L
.18284 .23216 L
.22059 .2045 L
.26079 .17972 L
.27927 .17081 L
.29948 .16286 L
.31952 .15672 L
.33058 .15402 L
.34062 .15196 L
.35003 .15037 L
.36023 .149 L
.36584 .1484 L
.37101 .14795 L
.37595 .14759 L
.37863 .14744 L
.38118 .14731 L
.38354 .14722 L
.38611 .14714 L
.38724 .14711 L
Mistroke
.38845 .14709 L
.38959 .14707 L
.39062 .14705 L
.39193 .14704 L
.39313 .14704 L
.39445 .14704 L
.39511 .14704 L
.39584 .14705 L
.39707 .14706 L
.39838 .14708 L
.39963 .14711 L
.40076 .14714 L
.4031 .14722 L
.40527 .14731 L
.41017 .14758 L
.41449 .14791 L
.41907 .14836 L
.42846 .1496 L
.43374 .15053 L
.43858 .15153 L
.4475 .15384 L
.45687 .15706 L
.46644 .16143 L
.47665 .16769 L
.48629 .1756 L
.49503 .18483 L
.51426 .21223 L
.53507 .24569 L
.54536 .25953 L
.55498 .2695 L
.55982 .27334 L
.56501 .27659 L
.56797 .27803 L
.57078 .27915 L
.5733 .27994 L
.57473 .28031 L
.57604 .28059 L
.57715 .28079 L
.57836 .28097 L
.57959 .28111 L
.58088 .28121 L
.58201 .28126 L
.58323 .28128 L
.58438 .28127 L
.58542 .28123 L
.58607 .28119 L
.58675 .28113 L
.58798 .28101 L
.5893 .28084 L
.59075 .2806 L
Mistroke
.59335 .28007 L
.59579 .27944 L
.60107 .2777 L
.60591 .27569 L
.61679 .27 L
.65652 .24205 L
.69473 .21469 L
.71606 .20166 L
.73539 .19166 L
.75579 .18302 L
.77454 .17673 L
.7938 .17174 L
.81463 .1677 L
.85414 .16225 L
.89213 .15786 L
.93257 .15351 L
.9715 .1501 L
.97619 .14976 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.04262 .09884 L
.06244 .1668 L
.06747 .17996 L
.07286 .19204 L
.07751 .20077 L
.08255 .20848 L
.08564 .21228 L
.08848 .21519 L
.09115 .21742 L
.09409 .21933 L
.09535 .21998 L
.09672 .22057 L
.09789 .22099 L
.09918 .22135 L
.09993 .22152 L
.10063 .22165 L
.10129 .22174 L
.102 .22182 L
.1027 .22187 L
.10335 .22189 L
.10458 .22186 L
.10574 .22177 L
.10699 .2216 L
.10816 .22137 L
.10923 .2211 L
.11186 .22024 L
.11434 .21916 L
.11928 .21634 L
.12466 .21241 L
.14313 .19448 L
.18391 .14984 L
.20417 .13085 L
.22318 .11587 L
.26093 .09375 L
.28111 .08538 L
.29962 .07939 L
.31854 .07462 L
.33924 .0707 L
.35885 .06799 L
.36983 .06684 L
.3798 .066 L
.38978 .06534 L
.39899 .06488 L
.4038 .0647 L
.40909 .06455 L
.41175 .06448 L
.41461 .06443 L
.416 .06441 L
.41732 .0644 L
Mistroke
.4186 .06438 L
.41978 .06437 L
.42103 .06437 L
.42169 .06436 L
.42238 .06436 L
.42355 .06436 L
.42483 .06436 L
.42597 .06437 L
.42719 .06437 L
.42835 .06438 L
.4294 .06439 L
.43192 .06443 L
.43465 .06448 L
.43724 .06454 L
.43963 .06461 L
.44388 .06476 L
.44856 .06498 L
.45803 .06559 L
.46296 .06602 L
.46815 .06656 L
.47741 .0678 L
.48739 .06963 L
.49828 .07234 L
.51793 .07927 L
.5389 .08771 L
.54917 .091 L
.55495 .09241 L
.56028 .09341 L
.56495 .09405 L
.56761 .09431 L
.57008 .0945 L
.57143 .09457 L
.5727 .09463 L
.57384 .09467 L
.57508 .0947 L
.57573 .09471 L
.57643 .09471 L
.57717 .09472 L
.57787 .09471 L
.57911 .0947 L
.57981 .09469 L
.58045 .09467 L
.58172 .09464 L
.58292 .09459 L
.58518 .09447 L
.5876 .0943 L
.59023 .09408 L
.59935 .09301 L
.61011 .09127 L
.62004 .08935 L
Mistroke
.65941 .08088 L
.69727 .07376 L
.71832 .07067 L
.73757 .0684 L
.75746 .06656 L
.77636 .06523 L
.78596 .0647 L
.79619 .06423 L
.81458 .06358 L
.82487 .06331 L
.836 .06308 L
.85618 .06277 L
.8972 .06226 L
.93671 .06159 L
.9747 .06076 L
.97619 .06073 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02073 L
.02846 .02107 L
.02954 .02124 L
.03053 .02132 L
.03163 .02136 L
.03279 .02137 L
.03395 .02135 L
.0352 .02131 L
.03638 .02126 L
.03746 .02121 L
.04262 .02089 L
.06244 .01952 L
.08259 .01836 L
.10458 .0174 L
.12517 .01675 L
.14429 .01629 L
.16481 .01593 L
.18342 .01569 L
.20266 .0155 L
.22348 .01535 L
.24342 .01524 L
.26449 .01516 L
.28413 .01511 L
.30246 .01507 L
.32281 .01504 L
.34137 .01501 L
.36045 .015 L
.38121 .01498 L
.40099 .01498 L
.422 .01497 L
.44147 .01496 L
.45975 .01496 L
.46958 .01496 L
.47993 .01496 L
.48962 .01496 L
.49843 .01496 L
.50798 .01496 L
.51818 .01496 L
.53654 .01496 L
.57652 .01495 L
.61499 .01495 L
.63448 .01495 L
.65591 .01495 L
.6765 .01495 L
.69531 .01495 L
.71476 .01495 L
.7256 .01495 L
Mistroke
.73565 .01495 L
.74564 .01495 L
.75468 .01495 L
.76472 .01495 L
.77023 .01495 L
.77541 .01495 L
.78008 .01495 L
.78276 .01495 L
.7852 .01495 L
.78778 .01495 L
.7892 .01495 L
.79055 .01495 L
.79179 .01495 L
.79294 .01495 L
.79419 .01495 L
.79483 .01495 L
.79553 .01495 L
.7967 .01495 L
.79793 .01495 L
.79898 .01495 L
.80012 .01495 L
.80137 .01495 L
.80269 .01495 L
.80507 .01495 L
.80976 .01495 L
.81402 .01495 L
.82402 .01495 L
.83324 .01495 L
.85405 .01495 L
.87445 .01495 L
.89351 .01495 L
.9029 .01495 L
.91181 .01495 L
.91672 .01495 L
.92208 .01495 L
.92443 .01495 L
.92694 .01495 L
.92909 .01495 L
.93144 .01495 L
.93267 .01495 L
.93382 .01495 L
.93503 .01495 L
.93632 .01495 L
.93753 .01495 L
.93867 .01495 L
.93969 .01495 L
.9408 .01495 L
.94201 .01495 L
.94335 .01495 L
.94474 .01495 L
Mistroke
.94605 .01495 L
.94853 .01495 L
.95089 .01495 L
.95549 .01495 L
.9597 .01495 L
.96916 .01495 L
.97619 .01495 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16972 L
.08255 .22376 L
.09396 .24738 L
.10458 .26532 L
.11508 .27955 L
.125 .29012 L
.1339 .29746 L
.1389 .30076 L
.14357 .30338 L
.1485 .30566 L
.15301 .30734 L
.15802 .3088 L
.16082 .30944 L
.16341 .30992 L
.1659 .3103 L
.16856 .3106 L
.17008 .31073 L
.17152 .31083 L
.1728 .31089 L
.17352 .31092 L
.17419 .31094 L
.17542 .31096 L
.17657 .31096 L
.17783 .31095 L
.17853 .31094 L
.17917 .31092 L
.18047 .31087 L
.18188 .3108 L
.18444 .31062 L
.18677 .3104 L
.18929 .31011 L
.19384 .30945 L
.20421 .3074 L
.22522 .30162 L
.26636 .28826 L
.28689 .28216 L
.30599 .27737 L
.32441 .27376 L
.33472 .27221 L
.34409 .27113 L
.34894 .27069 L
.35408 .27033 L
.35846 .27009 L
.36095 .26999 L
.36328 .26992 L
.36456 .26989 L
.36524 .26988 L
.36597 .26987 L
Mistroke
.36666 .26986 L
.36729 .26985 L
.36852 .26984 L
.3697 .26984 L
.37098 .26984 L
.37219 .26985 L
.3733 .26987 L
.3746 .26989 L
.37581 .26992 L
.37855 .27001 L
.38122 .27013 L
.38408 .2703 L
.38938 .2707 L
.39428 .27121 L
.39955 .27189 L
.40536 .27282 L
.41512 .27486 L
.42549 .27776 L
.43561 .28149 L
.44487 .28584 L
.45505 .2919 L
.46574 .30011 L
.47531 .30944 L
.48553 .32185 L
.50391 .35066 L
.52386 .38629 L
.53435 .40354 L
.54546 .41911 L
.55539 .43032 L
.56065 .43519 L
.5663 .4396 L
.57149 .44295 L
.57622 .44544 L
.58098 .44742 L
.58549 .44886 L
.58769 .44941 L
.59007 .44989 L
.59268 .45031 L
.59513 .45058 L
.59637 .45068 L
.59773 .45076 L
.59842 .45079 L
.59915 .45082 L
.60047 .45084 L
.60179 .45083 L
.60304 .4508 L
.60416 .45075 L
.60537 .45068 L
.60759 .4505 L
.61002 .45022 L
Mistroke
.61495 .44943 L
.61951 .44847 L
.62379 .44737 L
.64405 .44037 L
.66258 .43256 L
.68319 .42397 L
.69322 .4203 L
.70231 .41748 L
.70689 .41629 L
.71184 .41521 L
.71651 .41441 L
.71858 .41413 L
.72081 .41389 L
.72204 .41378 L
.72317 .41369 L
.72432 .41363 L
.72538 .41358 L
.72661 .41354 L
.72726 .41353 L
.72796 .41353 L
.72912 .41353 L
.7304 .41356 L
.73171 .41362 L
.73291 .4137 L
.73423 .41381 L
.73562 .41396 L
.73796 .41428 L
.74052 .41475 L
.74306 .41534 L
.74581 .41613 L
.7508 .41797 L
.75567 .42035 L
.76015 .42308 L
.77033 .43147 L
.7811 .4438 L
.81901 .50244 L
.8401 .53139 L
.85937 .55193 L
.8793 .56777 L
.89821 .57861 L
.90783 .58284 L
.91807 .58655 L
.93648 .59146 L
.94632 .59333 L
.95694 .59487 L
.96698 .59594 L
.97619 .59666 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .0214 L
.04262 .02111 L
.06244 .01979 L
.08259 .01864 L
.10458 .01768 L
.12517 .01701 L
.14429 .01654 L
.16481 .01617 L
.18342 .01591 L
.20266 .01571 L
.22348 .01556 L
.24342 .01544 L
.26449 .01536 L
.28413 .0153 L
.30246 .01526 L
.32281 .01522 L
.34137 .0152 L
.36045 .01518 L
.38121 .01517 L
.40099 .01516 L
.41097 .01515 L
.422 .01515 L
.43142 .01515 L
.44134 .01515 L
.45222 .01514 L
.45745 .01514 L
.4622 .01514 L
.46678 .01514 L
.47174 .01514 L
.47447 .01514 L
.47699 .01514 L
.47955 .01514 L
.48194 .01514 L
.48399 .01514 L
.48619 .01514 L
.48744 .01514 L
.48863 .01514 L
.4897 .01514 L
Mistroke
.49086 .01514 L
.49211 .01514 L
.49324 .01514 L
.49454 .01514 L
.49576 .01514 L
.4969 .01514 L
.49795 .01514 L
.50031 .01514 L
.50502 .01514 L
.51007 .01514 L
.51917 .01514 L
.52438 .01514 L
.52992 .01514 L
.53504 .01514 L
.53755 .01514 L
.53985 .01514 L
.54218 .01514 L
.54341 .01514 L
.5447 .01514 L
.54534 .01514 L
.54602 .01514 L
.54725 .01514 L
.54801 .01514 L
.54872 .01514 L
.54936 .01514 L
.55005 .01514 L
.55074 .01514 L
.55138 .01514 L
.55285 .01514 L
.55428 .01514 L
.55582 .01514 L
.55859 .01514 L
.56113 .01514 L
.56608 .01514 L
.57146 .01514 L
.58126 .01514 L
.60101 .01514 L
.62201 .01514 L
.65973 .01513 L
.68068 .01513 L
.6999 .01513 L
.71872 .01513 L
.73855 .01513 L
.74808 .01513 L
.75827 .01513 L
.77663 .01513 L
.78686 .01513 L
.79795 .01513 L
.8181 .01513 L
.85898 .01513 L
Mistroke
.89835 .01513 L
.93621 .01513 L
.97619 .01513 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03564 L
.03053 .0429 L
.03279 .04889 L
.03416 .05161 L
.03543 .05358 L
.03665 .05503 L
.03793 .05618 L
.03908 .05693 L
.04016 .05743 L
.04135 .0578 L
.04262 .05801 L
.04393 .05808 L
.04516 .05802 L
.04586 .05795 L
.0465 .05786 L
.04793 .0576 L
.05052 .05692 L
.05297 .05613 L
.06244 .0524 L
.08439 .04352 L
.10458 .03684 L
.12333 .03201 L
.14313 .02811 L
.16277 .02519 L
.1811 .02312 L
.20145 .0214 L
.22001 .02022 L
.2391 .0193 L
.25986 .01856 L
.27963 .01804 L
.30064 .01764 L
.32011 .01736 L
.33839 .01717 L
.35857 .01701 L
.37708 .01691 L
.396 .01683 L
.40685 .01679 L
.4167 .01676 L
.42611 .01674 L
.43631 .01673 L
.44709 .01671 L
.45234 .01671 L
.45726 .0167 L
.46221 .0167 L
.46673 .0167 L
.4693 .01669 L
.47175 .01669 L
.47432 .01669 L
Mistroke
.47578 .01669 L
.47649 .01669 L
.47714 .01669 L
.47777 .01669 L
.47846 .01669 L
.47916 .01669 L
.47989 .01669 L
.48054 .01669 L
.48123 .01669 L
.48249 .01669 L
.48379 .01669 L
.48502 .01669 L
.48613 .01669 L
.48733 .01669 L
.49007 .01669 L
.49297 .01669 L
.49818 .0167 L
.50758 .0167 L
.51769 .01671 L
.52717 .01672 L
.53598 .01672 L
.54101 .01673 L
.54558 .01673 L
.54819 .01673 L
.55065 .01673 L
.55191 .01673 L
.55325 .01673 L
.55395 .01673 L
.55471 .01673 L
.55541 .01673 L
.55606 .01673 L
.55674 .01673 L
.55748 .01673 L
.55813 .01673 L
.55882 .01673 L
.56001 .01673 L
.56133 .01673 L
.56206 .01673 L
.56273 .01673 L
.56424 .01673 L
.56557 .01673 L
.56698 .01673 L
.57185 .01673 L
.57461 .01673 L
.57718 .01673 L
.58768 .01672 L
.59761 .01671 L
.61619 .0167 L
.65462 .01666 L
.67408 .01664 L
Mistroke
.69551 .01663 L
.71607 .01661 L
.73488 .0166 L
.7543 .0166 L
.76501 .0166 L
.77519 .01659 L
.78478 .01659 L
.79005 .01659 L
.79501 .01659 L
.79964 .01659 L
.80466 .01659 L
.80687 .01659 L
.80921 .01659 L
.81122 .01659 L
.8134 .01659 L
.81472 .01659 L
.81595 .01659 L
.81712 .01659 L
.81836 .01659 L
.81947 .01659 L
.82051 .01659 L
.82166 .01659 L
.82289 .01659 L
.82412 .01659 L
.82547 .01659 L
.82688 .01659 L
.82819 .01659 L
.83069 .01659 L
.83305 .01659 L
.8377 .01659 L
.84192 .01659 L
.85139 .01659 L
.88988 .01659 L
.90016 .0166 L
.90977 .0166 L
.9146 .0166 L
.91979 .0166 L
.92275 .0166 L
.92555 .0166 L
.92677 .0166 L
.92807 .0166 L
.92882 .0166 L
.9295 .0166 L
.93082 .0166 L
.93203 .0166 L
.93315 .0166 L
.93439 .0166 L
.93508 .0166 L
.93571 .0166 L
.93699 .0166 L
Mistroke
.9377 .0166 L
.93837 .0166 L
.94088 .0166 L
.94301 .0166 L
.94536 .0166 L
.95012 .0166 L
.9553 .0166 L
.96087 .0166 L
.97095 .01659 L
.97619 .01659 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16977 L
.08255 .22412 L
.09409 .24839 L
.10458 .26663 L
.12415 .29215 L
.13491 .30209 L
.14509 .30922 L
.15478 .31422 L
.15968 .31615 L
.16506 .31786 L
.16965 .319 L
.17458 .31993 L
.17697 .32027 L
.17924 .32054 L
.18129 .32074 L
.1835 .32091 L
.18485 .32099 L
.18609 .32104 L
.18728 .32108 L
.18853 .32111 L
.18965 .32113 L
.1907 .32113 L
.19185 .32112 L
.19309 .3211 L
.1944 .32107 L
.19583 .32102 L
.19843 .32089 L
.20097 .32071 L
.20331 .32052 L
.21222 .31948 L
.2217 .31796 L
.25945 .3098 L
.28042 .30509 L
.29965 .30131 L
.3185 .29837 L
.32797 .29724 L
.3333 .29672 L
.33834 .2963 L
.34327 .29597 L
.34586 .29583 L
.34861 .29571 L
.35092 .29562 L
.35347 .29555 L
.35458 .29552 L
.35578 .2955 L
.35691 .29549 L
.35795 .29547 L
.35924 .29547 L
Mistroke
.35996 .29546 L
.36062 .29546 L
.36189 .29547 L
.36309 .29548 L
.36377 .29549 L
.36449 .2955 L
.36578 .29552 L
.36717 .29555 L
.36869 .2956 L
.37124 .29569 L
.37397 .29582 L
.3789 .29613 L
.3842 .29659 L
.3891 .29712 L
.40018 .29876 L
.40995 .30077 L
.42031 .30358 L
.42971 .30683 L
.43982 .31124 L
.45811 .32235 L
.46771 .3303 L
.47819 .34111 L
.49931 .3703 L
.5206 .40554 L
.53992 .43378 L
.54958 .44478 L
.56004 .45406 L
.56484 .45741 L
.56992 .46035 L
.57459 .46255 L
.57902 .46419 L
.58139 .4649 L
.58396 .46554 L
.58611 .46599 L
.58848 .46637 L
.59103 .46668 L
.59243 .4668 L
.59375 .46688 L
.59497 .46693 L
.5961 .46696 L
.59733 .46696 L
.59863 .46694 L
.59978 .4669 L
.60082 .46685 L
.60202 .46677 L
.60316 .46668 L
.60518 .46647 L
.60738 .46618 L
.61236 .4653 L
.61696 .46424 L
Mistroke
.62663 .46135 L
.6357 .45799 L
.65633 .44886 L
.69512 .43104 L
.70523 .42717 L
.71627 .42364 L
.72131 .42233 L
.72669 .42118 L
.7293 .42072 L
.73176 .42034 L
.73398 .42006 L
.73636 .41983 L
.73762 .41973 L
.73877 .41965 L
.73993 .41959 L
.74102 .41955 L
.7423 .41953 L
.74347 .41952 L
.74476 .41954 L
.74542 .41955 L
.74614 .41958 L
.74747 .41965 L
.7487 .41973 L
.75004 .41985 L
.75146 .42 L
.75385 .42034 L
.75646 .42081 L
.76109 .42196 L
.76603 .42363 L
.7707 .42569 L
.77493 .42798 L
.78493 .43513 L
.79413 .44394 L
.81494 .47032 L
.85436 .52463 L
.87417 .54622 L
.89227 .56167 L
.91173 .57426 L
.92257 .57974 L
.93263 .58399 L
.95166 .5902 L
.96171 .59268 L
.97241 .59482 L
.97619 .59548 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .16945 L
.08255 .22237 L
.09396 .24484 L
.10458 .26138 L
.11508 .27398 L
.125 .28286 L
.1339 .28861 L
.13893 .29103 L
.14357 .29279 L
.14823 .29412 L
.15085 .29469 L
.15324 .29511 L
.15546 .29542 L
.15663 .29555 L
.15788 .29567 L
.15908 .29575 L
.16017 .29581 L
.16127 .29586 L
.1623 .29589 L
.16349 .2959 L
.16481 .29589 L
.16547 .29588 L
.16618 .29586 L
.16746 .29581 L
.16873 .29574 L
.16994 .29565 L
.17221 .29545 L
.17487 .29514 L
.17734 .29478 L
.18292 .29377 L
.19255 .29145 L
.20159 .28876 L
.22219 .28147 L
.26088 .26693 L
.28053 .26039 L
.30202 .25442 L
.31194 .25215 L
.32254 .25007 L
.33248 .24848 L
.34164 .24731 L
.34652 .24682 L
.35188 .24637 L
.35728 .24603 L
.36023 .24589 L
.36299 .24579 L
.36423 .24575 L
.36559 .24572 L
.36687 .2457 L
Mistroke
.36806 .24568 L
.36924 .24568 L
.37031 .24567 L
.37154 .24567 L
.3727 .24568 L
.37397 .24569 L
.37461 .2457 L
.37532 .24572 L
.37772 .24578 L
.37907 .24582 L
.38052 .24588 L
.38314 .246 L
.38844 .24635 L
.39334 .24679 L
.39872 .24742 L
.40442 .24825 L
.414 .25008 L
.42455 .25281 L
.43467 .25628 L
.44394 .26035 L
.45411 .26606 L
.46481 .27383 L
.47438 .28273 L
.48459 .29468 L
.50297 .32298 L
.52292 .35886 L
.53342 .37633 L
.54452 .39191 L
.55445 .40281 L
.55971 .40736 L
.56536 .41131 L
.57055 .41412 L
.57528 .41602 L
.57756 .41672 L
.58004 .41732 L
.58118 .41755 L
.58238 .41775 L
.58351 .41791 L
.58455 .41803 L
.58569 .41813 L
.58693 .41821 L
.58814 .41825 L
.58943 .41825 L
.59064 .41822 L
.59178 .41817 L
.5928 .4181 L
.59391 .41799 L
.59646 .41766 L
.59916 .41717 L
.604 .41595 L
Mistroke
.60849 .41447 L
.6127 .41281 L
.62227 .40815 L
.66106 .38182 L
.70231 .35163 L
.72291 .33871 L
.74204 .32881 L
.76054 .32147 L
.77088 .31842 L
.78025 .31635 L
.78513 .31554 L
.78779 .31517 L
.79028 .31489 L
.79258 .31467 L
.79468 .3145 L
.79701 .31436 L
.7983 .3143 L
.79951 .31426 L
.80071 .31423 L
.80202 .31421 L
.80269 .31421 L
.8034 .31421 L
.80469 .31422 L
.80591 .31425 L
.80719 .31429 L
.80829 .31433 L
.80949 .31439 L
.81221 .31458 L
.81511 .31486 L
.82033 .31557 L
.82567 .31658 L
.83059 .31778 L
.8417 .3215 L
.85149 .32603 L
.86185 .33213 L
.88144 .34707 L
.89976 .36406 L
.9386 .40253 L
.97619 .43403 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .16926 L
.08255 .22133 L
.09396 .24284 L
.10458 .25812 L
.10961 .26388 L
.11508 .26912 L
.11989 .27292 L
.125 .27617 L
.12959 .27844 L
.13203 .27941 L
.13466 .28028 L
.13706 .28093 L
.13926 .2814 L
.14147 .28176 L
.14257 .2819 L
.14357 .282 L
.14482 .2821 L
.14547 .28214 L
.14616 .28217 L
.14732 .2822 L
.1486 .28221 L
.14974 .28218 L
.15096 .28213 L
.15211 .28206 L
.15316 .28197 L
.15567 .28168 L
.15841 .28125 L
.16338 .28018 L
.16801 .27887 L
.17293 .2772 L
.18177 .27359 L
.21952 .25338 L
.25972 .23138 L
.29841 .21485 L
.31845 .2086 L
.32865 .20603 L
.33955 .20375 L
.34989 .20202 L
.35929 .20081 L
.36382 .20035 L
.36874 .19995 L
.37099 .1998 L
.37338 .19967 L
.37542 .19957 L
.37766 .19948 L
.37897 .19944 L
.38018 .19941 L
.38135 .19939 L
Mistroke
.38259 .19937 L
.3838 .19936 L
.38495 .19935 L
.38598 .19935 L
.38709 .19936 L
.38832 .19937 L
.38901 .19938 L
.38966 .19939 L
.39097 .19942 L
.39237 .19946 L
.39492 .19955 L
.39723 .19967 L
.40174 .19997 L
.40664 .20041 L
.41127 .20095 L
.41554 .20156 L
.42519 .20338 L
.43424 .2057 L
.44417 .20911 L
.45486 .21405 L
.46446 .21993 L
.47494 .22845 L
.48588 .24034 L
.49605 .25468 L
.53515 .32782 L
.54542 .34467 L
.55654 .35941 L
.56164 .36488 L
.56703 .36977 L
.57209 .37355 L
.5767 .37634 L
.58156 .37865 L
.58616 .38028 L
.58869 .38095 L
.59102 .38143 L
.59359 .38182 L
.59488 .38197 L
.59557 .38203 L
.59631 .38208 L
.59747 .38215 L
.59868 .38219 L
.59981 .3822 L
.60086 .38219 L
.6021 .38215 L
.60323 .38208 L
.60453 .38199 L
.60576 .38186 L
.60798 .38158 L
.61002 .38126 L
.61464 .38028 L
Mistroke
.6193 .37901 L
.62432 .37735 L
.63338 .37373 L
.65401 .36354 L
.67374 .353 L
.68415 .34774 L
.69526 .3427 L
.70607 .33865 L
.71117 .33712 L
.71586 .33596 L
.72059 .33508 L
.72308 .33474 L
.72435 .3346 L
.72571 .33448 L
.72691 .3344 L
.728 .33435 L
.72909 .33431 L
.73013 .3343 L
.73134 .33431 L
.73246 .33435 L
.73368 .33441 L
.73498 .33451 L
.73612 .33463 L
.73737 .33479 L
.73988 .33521 L
.7422 .33574 L
.74436 .33634 L
.74925 .33818 L
.75447 .34092 L
.7594 .34437 L
.76405 .34846 L
.77275 .35859 L
.78249 .37393 L
.79278 .39416 L
.81124 .43479 L
.83105 .47512 L
.84915 .50494 L
.86861 .52926 L
.87933 .53956 L
.88951 .54754 L
.89913 .55362 L
.90937 .55868 L
.91903 .56225 L
.92777 .56456 L
.93267 .56551 L
.93534 .56593 L
.93783 .56626 L
.94014 .56651 L
.94224 .5667 L
.94458 .56686 L
Mistroke
.94586 .56693 L
.94707 .56698 L
.94827 .56702 L
.94959 .56705 L
.95026 .56706 L
.95097 .56707 L
.95227 .56707 L
.95355 .56706 L
.95477 .56703 L
.95587 .567 L
.95706 .56696 L
.95978 .56682 L
.96269 .56661 L
.96791 .56608 L
.97217 .56552 L
.97619 .56488 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.03279 .05661 L
.04262 .09446 L
.04758 .10857 L
.0503 .11466 L
.05288 .11931 L
.05528 .12271 L
.05655 .12415 L
.05789 .12543 L
.05902 .12631 L
.06026 .1271 L
.06139 .12765 L
.06244 .12804 L
.0631 .12821 L
.06379 .12835 L
.06504 .12848 L
.06581 .12849 L
.06653 .12844 L
.06718 .12837 L
.06788 .12825 L
.06919 .12793 L
.07057 .12747 L
.07305 .12635 L
.07767 .12347 L
.08274 .1195 L
.10458 .09916 L
.12572 .08082 L
.145 .06715 L
.16498 .05598 L
.18391 .04779 L
.20382 .04118 L
.22224 .03651 L
.24091 .03287 L
.26151 .02984 L
.28086 .02772 L
.30171 .02601 L
.32175 .0248 L
.34285 .02387 L
.36259 .02324 L
.38096 .02281 L
.39148 .02261 L
.40142 .02246 L
.42001 .02225 L
.42973 .02217 L
.43504 .02214 L
.44002 .02211 L
.44461 .02209 L
.44881 .02207 L
.45347 .02206 L
.45603 .02205 L
Mistroke
.45847 .02205 L
.45972 .02205 L
.46107 .02205 L
.46234 .02205 L
.46352 .02205 L
.46458 .02205 L
.46574 .02205 L
.46695 .02205 L
.46808 .02205 L
.46872 .02205 L
.46941 .02205 L
.47067 .02205 L
.47303 .02205 L
.47578 .02206 L
.47832 .02207 L
.48256 .02208 L
.48724 .0221 L
.49672 .02215 L
.5161 .02231 L
.52608 .0224 L
.53697 .02248 L
.54201 .02252 L
.54738 .02255 L
.54999 .02256 L
.55245 .02256 L
.55464 .02257 L
.55705 .02258 L
.55838 .02258 L
.55962 .02258 L
.56093 .02258 L
.56166 .02258 L
.56233 .02258 L
.56352 .02258 L
.56482 .02258 L
.56605 .02258 L
.56719 .02258 L
.56849 .02258 L
.56972 .02258 L
.57251 .02257 L
.57523 .02257 L
.57816 .02256 L
.58772 .02252 L
.59818 .02246 L
.61927 .02231 L
.6598 .022 L
.69881 .02176 L
.72013 .02166 L
.74028 .02159 L
.74998 .02157 L
.76027 .02154 L
Mistroke
.77871 .02151 L
.78813 .0215 L
.79333 .0215 L
.79826 .02149 L
.80284 .02149 L
.80782 .02149 L
.81236 .02148 L
.81657 .02148 L
.81922 .02148 L
.82165 .02148 L
.82432 .02148 L
.82567 .02148 L
.82715 .02148 L
.82845 .02148 L
.82963 .02148 L
.83029 .02148 L
.831 .02148 L
.8323 .02148 L
.83351 .02148 L
.8348 .02148 L
.83589 .02148 L
.83711 .02148 L
.83952 .02148 L
.84173 .02148 L
.84671 .02148 L
.85572 .02148 L
.87626 .02149 L
.88627 .02149 L
.891 .02149 L
.89536 .02149 L
.89753 .02149 L
.89992 .02149 L
.90107 .02149 L
.90231 .02149 L
.90362 .02149 L
.90485 .02149 L
.906 .02149 L
.90725 .02149 L
.90843 .02149 L
.90953 .02149 L
.91061 .02149 L
.9116 .02149 L
.9138 .02149 L
.91504 .02149 L
.91634 .02149 L
.91868 .02149 L
.92395 .02149 L
.9285 .02149 L
.93349 .02149 L
.94373 .02148 L
Mistroke
.95305 .02148 L
.97399 .02146 L
.97619 .02146 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.04262 .09884 L
.06244 .16787 L
.07286 .19551 L
.08255 .21607 L
.0932 .23322 L
.09916 .24054 L
.10458 .24588 L
.10941 .24965 L
.11454 .25272 L
.11891 .25463 L
.1214 .25544 L
.12373 .25604 L
.12501 .2563 L
.12641 .25653 L
.12773 .2567 L
.12896 .25682 L
.13017 .25689 L
.13127 .25693 L
.13254 .25694 L
.13374 .25691 L
.13505 .25685 L
.13571 .2568 L
.13643 .25674 L
.13891 .25643 L
.14031 .25621 L
.14181 .25592 L
.14451 .2553 L
.14979 .25374 L
.15468 .25191 L
.16575 .24674 L
.18587 .23495 L
.22514 .20995 L
.26289 .18949 L
.28386 .18057 L
.30309 .17398 L
.32194 .16893 L
.33153 .16687 L
.34178 .16504 L
.35212 .16357 L
.36152 .16255 L
.36605 .16217 L
.37097 .16184 L
.37322 .16171 L
.37561 .1616 L
.37766 .16152 L
.37989 .16145 L
.3812 .16142 L
.38242 .16139 L
.38358 .16137 L
Mistroke
.38482 .16136 L
.38604 .16135 L
.38718 .16135 L
.38821 .16135 L
.38932 .16135 L
.39055 .16136 L
.39125 .16137 L
.39189 .16138 L
.39331 .16141 L
.39461 .16145 L
.39695 .16152 L
.39946 .16163 L
.40397 .16188 L
.40887 .16226 L
.41777 .16325 L
.42264 .16395 L
.4272 .16474 L
.43759 .16705 L
.44771 .17012 L
.45861 .17462 L
.4682 .17994 L
.47869 .1877 L
.48963 .19863 L
.4998 .21184 L
.51857 .24264 L
.5389 .27589 L
.55003 .28978 L
.55492 .29455 L
.56028 .29882 L
.56535 .30194 L
.57008 .30408 L
.5727 .30495 L
.57508 .30556 L
.5764 .30583 L
.57784 .30606 L
.57849 .30614 L
.57919 .30622 L
.58045 .30632 L
.58158 .30638 L
.58282 .3064 L
.58412 .30638 L
.58533 .30633 L
.58646 .30624 L
.58749 .30613 L
.5898 .3058 L
.59229 .30531 L
.59499 .30463 L
.59989 .30301 L
.6094 .29871 L
.61817 .29366 L
Mistroke
.65754 .26463 L
.69539 .23658 L
.71645 .22332 L
.7357 .21307 L
.75582 .20432 L
.77449 .19794 L
.79349 .19297 L
.81422 .18897 L
.83476 .18597 L
.85337 .18375 L
.87425 .18166 L
.89346 .18011 L
.91222 .17899 L
.92166 .17859 L
.92699 .17842 L
.93203 .17828 L
.93692 .17817 L
.9395 .17813 L
.94224 .17809 L
.94454 .17807 L
.94708 .17804 L
.94819 .17804 L
.94939 .17803 L
.95043 .17802 L
.95155 .17802 L
.95287 .17802 L
.95409 .17801 L
.95484 .17801 L
.95555 .17801 L
.95687 .17801 L
.95755 .17802 L
.95827 .17802 L
.95956 .17802 L
.96094 .17803 L
.96247 .17804 L
.96496 .17806 L
.96764 .17808 L
.97247 .17814 L
.97619 .1782 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03562 L
.03053 .04281 L
.03279 .04867 L
.03416 .05128 L
.03543 .05314 L
.03665 .05447 L
.03793 .0555 L
.03908 .05614 L
.04016 .05655 L
.04135 .05682 L
.04262 .05694 L
.04393 .05692 L
.04516 .05679 L
.04586 .05668 L
.0465 .05656 L
.04793 .05623 L
.05297 .05459 L
.06244 .0507 L
.08269 .04248 L
.10458 .03533 L
.12545 .03021 L
.14465 .02667 L
.16347 .02405 L
.18413 .02189 L
.20364 .02039 L
.22456 .0192 L
.2458 .01832 L
.26592 .01771 L
.28583 .01726 L
.30425 .01696 L
.32291 .01673 L
.34352 .01654 L
.36286 .01641 L
.38372 .0163 L
.40376 .01623 L
.41384 .01621 L
.42486 .01618 L
.44447 .01615 L
.45545 .01613 L
.46542 .01613 L
.47027 .01612 L
.4754 .01612 L
.47984 .01612 L
.4846 .01612 L
.48728 .01611 L
.48972 .01611 L
.4922 .01611 L
.49451 .01611 L
Mistroke
.49591 .01611 L
.49718 .01611 L
.49859 .01611 L
.49937 .01611 L
.5001 .01611 L
.50074 .01611 L
.50142 .01611 L
.50265 .01611 L
.50396 .01611 L
.50471 .01611 L
.5054 .01611 L
.50667 .01611 L
.50801 .01611 L
.51042 .01611 L
.51302 .01611 L
.51588 .01611 L
.52579 .01611 L
.53041 .01612 L
.53283 .01612 L
.53415 .01612 L
.53538 .01612 L
.53655 .01612 L
.53762 .01612 L
.5388 .01612 L
.54007 .01612 L
.54113 .01612 L
.54228 .01612 L
.54336 .01612 L
.54436 .01612 L
.54562 .01612 L
.54681 .01612 L
.54905 .01612 L
.55146 .01612 L
.55408 .01611 L
.5588 .01611 L
.56316 .01611 L
.57317 .01611 L
.58382 .01611 L
.62154 .01608 L
.66171 .01606 L
.70036 .01605 L
.72038 .01604 L
.73057 .01604 L
.74147 .01604 L
.7518 .01604 L
.76119 .01604 L
.7701 .01603 L
.77955 .01603 L
.78429 .01603 L
.78951 .01603 L
Mistroke
.79426 .01603 L
.79871 .01603 L
.80139 .01603 L
.80394 .01603 L
.80623 .01603 L
.80751 .01603 L
.80872 .01603 L
.80941 .01603 L
.81014 .01603 L
.81143 .01603 L
.81216 .01603 L
.81293 .01603 L
.81359 .01603 L
.81431 .01603 L
.81561 .01603 L
.81633 .01603 L
.81699 .01603 L
.81828 .01603 L
.81949 .01603 L
.82187 .01603 L
.82409 .01603 L
.82916 .01603 L
.8341 .01603 L
.83942 .01603 L
.85784 .01603 L
.87751 .01603 L
.8879 .01603 L
.89361 .01603 L
.899 .01603 L
.90417 .01603 L
.90708 .01603 L
.90977 .01603 L
.91203 .01603 L
.91332 .01603 L
.91452 .01603 L
.91579 .01603 L
.91694 .01603 L
.91758 .01603 L
.91828 .01603 L
.91955 .01603 L
.92085 .01603 L
.92207 .01603 L
.92435 .01603 L
.92681 .01603 L
.92946 .01603 L
.93425 .01603 L
.93865 .01603 L
.94792 .01603 L
.95656 .01603 L
.97619 .01603 L
Mistroke
Mfstroke
0 .206 1 r
.02381 .01472 m
.04262 .09891 L
.06244 .1687 L
.07286 .197 L
.08255 .21811 L
.0932 .2356 L
.09916 .24291 L
.10458 .2481 L
.10941 .25161 L
.11206 .25311 L
.11454 .25426 L
.11682 .25511 L
.11891 .25571 L
.12002 .25597 L
.12123 .2562 L
.12251 .25639 L
.12373 .25651 L
.1244 .25656 L
.12514 .2566 L
.12583 .25662 L
.12646 .25662 L
.12767 .25659 L
.12894 .25651 L
.1296 .25645 L
.13031 .25638 L
.13159 .2562 L
.1345 .25563 L
.13719 .25491 L
.13974 .25406 L
.14451 .2521 L
.15416 .24683 L
.16442 .23982 L
.18284 .22516 L
.22059 .1941 L
.24156 .17895 L
.26079 .16703 L
.29948 .14887 L
.3184 .14257 L
.32925 .13963 L
.3391 .13737 L
.34851 .13554 L
.35872 .13392 L
.36949 .13259 L
.37475 .13208 L
.37967 .13169 L
.38423 .1314 L
.38913 .13116 L
.39192 .13106 L
.3933 .13102 L
.39457 .131 L
Mistroke
.39582 .13097 L
.39695 .13096 L
.3982 .13094 L
.39889 .13094 L
.39954 .13093 L
.40076 .13093 L
.40146 .13093 L
.40211 .13094 L
.40341 .13095 L
.40415 .13096 L
.40481 .13097 L
.40601 .13099 L
.4073 .13102 L
.40966 .13109 L
.41241 .1312 L
.41534 .13135 L
.42058 .13171 L
.42549 .13216 L
.42998 .13267 L
.44009 .13424 L
.44901 .13618 L
.45839 .13893 L
.46796 .14272 L
.47817 .14823 L
.4878 .1553 L
.49655 .1637 L
.51577 .18931 L
.53658 .22187 L
.54688 .23581 L
.5565 .2462 L
.56174 .25066 L
.56653 .25397 L
.57185 .25683 L
.57478 .25804 L
.57755 .25897 L
.57991 .25959 L
.58213 .26003 L
.5834 .26023 L
.58457 .26038 L
.58584 .2605 L
.58649 .26054 L
.58719 .26058 L
.58788 .26061 L
.58853 .26063 L
.58975 .26063 L
.59107 .26059 L
.59181 .26056 L
.5925 .26051 L
.59364 .26042 L
.5949 .26028 L
Mistroke
.59744 .25991 L
.59983 .25945 L
.60202 .25894 L
.60695 .2575 L
.61585 .25401 L
.63485 .24389 L
.65558 .23083 L
.67691 .21733 L
.69624 .20633 L
.71641 .19694 L
.72546 .1936 L
.7306 .19198 L
.73539 .19067 L
.74051 .18951 L
.74517 .18866 L
.74755 .18832 L
.75015 .18802 L
.75157 .18789 L
.75289 .18779 L
.75415 .18771 L
.7548 .18768 L
.75549 .18766 L
.75663 .18763 L
.75767 .18762 L
.75879 .18762 L
.76002 .18765 L
.76109 .18769 L
.76222 .18775 L
.7633 .18783 L
.76427 .18792 L
.76667 .1882 L
.76926 .18862 L
.77171 .18914 L
.77396 .18973 L
.77864 .19133 L
.78367 .19368 L
.78841 .19658 L
.79274 .1999 L
.79781 .2047 L
.80334 .21117 L
.81339 .22655 L
.83311 .26943 L
.8541 .32416 L
.87413 .37292 L
.88466 .39488 L
.89576 .41476 L
.90574 .4297 L
.91668 .4429 L
.92663 .45213 L
.9359 .45847 L
Mistroke
.94093 .46103 L
.94358 .46213 L
.94639 .46313 L
.94884 .46386 L
.95154 .4645 L
.954 .46495 L
.95631 .46525 L
.95745 .46535 L
.9587 .46544 L
.95988 .46549 L
.96098 .46551 L
.96206 .46551 L
.96305 .46549 L
.96418 .46544 L
.96525 .46537 L
.96642 .46526 L
.96766 .46513 L
.96988 .4648 L
.97226 .46435 L
.97488 .46374 L
.97619 .46339 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .1693 L
.08255 .22127 L
.09396 .24249 L
.09905 .25016 L
.10458 .25728 L
.11004 .26313 L
.11508 .26755 L
.1198 .27088 L
.125 .2737 L
.12724 .27465 L
.12965 .27551 L
.13174 .27612 L
.13401 .27664 L
.13534 .27688 L
.13657 .27707 L
.13775 .27721 L
.13901 .27732 L
.14024 .27739 L
.1414 .27743 L
.14244 .27743 L
.14357 .27741 L
.14481 .27735 L
.14595 .27727 L
.14725 .27715 L
.14849 .277 L
.15069 .27665 L
.15308 .27617 L
.1585 .27472 L
.16351 .27298 L
.17373 .26843 L
.18458 .26251 L
.22233 .23829 L
.26253 .21424 L
.30122 .197 L
.32126 .19061 L
.33146 .188 L
.34236 .18569 L
.3527 .18393 L
.3621 .1827 L
.36663 .18223 L
.37155 .18182 L
.37619 .18151 L
.38047 .18131 L
.38172 .18127 L
.38291 .18123 L
.38399 .1812 L
.38514 .18118 L
.38639 .18116 L
Mistroke
.38754 .18115 L
.38825 .18114 L
.38892 .18114 L
.39016 .18114 L
.39127 .18115 L
.39243 .18116 L
.39343 .18117 L
.39452 .1812 L
.39696 .18126 L
.39923 .18135 L
.40191 .18149 L
.40445 .18165 L
.4092 .18204 L
.41431 .18259 L
.41987 .18336 L
.42929 .18512 L
.43968 .18783 L
.45053 .19175 L
.4607 .19674 L
.47056 .20321 L
.48093 .21228 L
.48977 .22235 L
.49944 .23615 L
.52073 .27468 L
.54006 .30962 L
.54972 .32378 L
.56018 .33573 L
.56498 .34 L
.57006 .3437 L
.57439 .34621 L
.57915 .34831 L
.58166 .34915 L
.58438 .34987 L
.58563 .35014 L
.58696 .35037 L
.5881 .35054 L
.58934 .35068 L
.59053 .35078 L
.59162 .35084 L
.59266 .35088 L
.59376 .35089 L
.59497 .35087 L
.59609 .35082 L
.59732 .35073 L
.59864 .3506 L
.60004 .35043 L
.60134 .35023 L
.60427 .34966 L
.60959 .34824 L
.61442 .34655 L
Mistroke
.61955 .3444 L
.63909 .33365 L
.6574 .32158 L
.69619 .29675 L
.70631 .29151 L
.71734 .28676 L
.72239 .285 L
.72776 .28343 L
.73038 .2828 L
.73284 .2823 L
.73506 .28191 L
.73744 .28158 L
.7387 .28144 L
.73985 .28134 L
.741 .28125 L
.7421 .2812 L
.74337 .28116 L
.74455 .28114 L
.74584 .28116 L
.74649 .28118 L
.74721 .28122 L
.74786 .28126 L
.74855 .28131 L
.74977 .28142 L
.75109 .28158 L
.75253 .2818 L
.75512 .28232 L
.75753 .28295 L
.76221 .28463 L
.76647 .28674 L
.77137 .28997 L
.77601 .29388 L
.78574 .30531 L
.79064 .31284 L
.79604 .32251 L
.81449 .36387 L
.83559 .41532 L
.85485 .4564 L
.87478 .48992 L
.8937 .5136 L
.90332 .52295 L
.91356 .53115 L
.92315 .53736 L
.93196 .54192 L
.94228 .54602 L
.94771 .54768 L
.95343 .5491 L
.95842 .55008 L
.96306 .55079 L
.96816 .55135 L
Mistroke
.97102 .55157 L
.97226 .55165 L
.97362 .55172 L
.97619 .55181 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.04262 .09893 L
.06244 .16934 L
.08255 .22172 L
.09396 .24357 L
.10458 .25931 L
.11508 .27093 L
.12023 .27534 L
.125 .27872 L
.12924 .28119 L
.1339 .28339 L
.1386 .28507 L
.14117 .28578 L
.14357 .28633 L
.14615 .28678 L
.14854 .28708 L
.14991 .28721 L
.15116 .2873 L
.15185 .28733 L
.1526 .28736 L
.1533 .28738 L
.15395 .28739 L
.15514 .2874 L
.15624 .28738 L
.15745 .28734 L
.15875 .28727 L
.16011 .28717 L
.1614 .28706 L
.16382 .28678 L
.16843 .28604 L
.17269 .28514 L
.18234 .28245 L
.20101 .27542 L
.22161 .26626 L
.26181 .24855 L
.3005 .23524 L
.32054 .23034 L
.33062 .22842 L
.34164 .22674 L
.34693 .2261 L
.35192 .22559 L
.35645 .2252 L
.36125 .22488 L
.36374 .22475 L
.36648 .22464 L
.36768 .2246 L
.36897 .22456 L
.37018 .22453 L
.3713 .22451 L
.37204 .2245 L
Mistroke
.3727 .22449 L
.37344 .22448 L
.37423 .22448 L
.37491 .22447 L
.37565 .22447 L
.37636 .22447 L
.377 .22448 L
.37821 .22449 L
.37889 .2245 L
.37953 .22451 L
.38082 .22454 L
.3822 .22457 L
.38477 .22466 L
.3875 .22479 L
.3924 .2251 L
.39767 .22557 L
.40348 .22626 L
.41387 .22795 L
.42362 .23018 L
.43347 .23317 L
.44384 .2373 L
.45269 .24184 L
.46236 .24815 L
.47266 .25683 L
.482 .2669 L
.50297 .29817 L
.52381 .33637 L
.53296 .35205 L
.543 .36692 L
.55268 .37836 L
.56173 .38631 L
.56672 .38957 L
.57128 .39187 L
.57379 .39288 L
.57653 .39377 L
.57912 .39442 L
.58152 .39485 L
.5827 .39501 L
.58393 .39514 L
.58499 .39522 L
.58614 .39527 L
.58739 .3953 L
.58809 .39529 L
.58873 .39528 L
.58996 .39523 L
.59113 .39514 L
.59223 .39504 L
.59338 .3949 L
.59546 .39458 L
.5977 .39413 L
Mistroke
.60016 .39353 L
.60529 .39191 L
.6108 .38969 L
.62076 .38461 L
.662 .35558 L
.70173 .32726 L
.72177 .31585 L
.73994 .30798 L
.74481 .30633 L
.75008 .30479 L
.75463 .30368 L
.75963 .3027 L
.76219 .3023 L
.76494 .30196 L
.76646 .30181 L
.76785 .30169 L
.76924 .3016 L
.77056 .30154 L
.77177 .3015 L
.77306 .30148 L
.77416 .30148 L
.77537 .3015 L
.77667 .30154 L
.7774 .30157 L
.77807 .30161 L
.77938 .30171 L
.78061 .30182 L
.78309 .30211 L
.78535 .30246 L
.79042 .30356 L
.7948 .30488 L
.79954 .30673 L
.80478 .3093 L
.81032 .3127 L
.82025 .32068 L
.8297 .33066 L
.83984 .34395 L
.85816 .37344 L
.89945 .44602 L
.9201 .47643 L
.93923 .49922 L
.95714 .5161 L
.97619 .52999 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.03279 .05688 L
.04262 .09792 L
.04758 .11576 L
.05288 .13216 L
.05785 .14473 L
.06244 .15379 L
.06503 .1578 L
.06788 .16134 L
.07075 .164 L
.07232 .16509 L
.07379 .16589 L
.07445 .16618 L
.07517 .16645 L
.07648 .16683 L
.07776 .16705 L
.07895 .16713 L
.07968 .16713 L
.08036 .16709 L
.08164 .16693 L
.08236 .16679 L
.08302 .16662 L
.08451 .16616 L
.08691 .16513 L
.08916 .16389 L
.09427 .16026 L
.10458 .15061 L
.14349 .10906 L
.1633 .09147 L
.18485 .07615 L
.20555 .06474 L
.22469 .05656 L
.24336 .05036 L
.26396 .04511 L
.28331 .04138 L
.30416 .03835 L
.3242 .0362 L
.3453 .03453 L
.36505 .0334 L
.38341 .03264 L
.39394 .03232 L
.40387 .03207 L
.41279 .0319 L
.41778 .03182 L
.42246 .03176 L
.4274 .0317 L
.43192 .03167 L
.4345 .03165 L
.43694 .03164 L
.43952 .03163 L
Mistroke
.44098 .03162 L
.44169 .03162 L
.44233 .03162 L
.44298 .03162 L
.44366 .03162 L
.44434 .03162 L
.44509 .03162 L
.44574 .03162 L
.44643 .03162 L
.44768 .03162 L
.44898 .03162 L
.45022 .03163 L
.45253 .03163 L
.45384 .03164 L
.45523 .03165 L
.45773 .03166 L
.46338 .03171 L
.46828 .03177 L
.47277 .03185 L
.48289 .03206 L
.4918 .03232 L
.50118 .03267 L
.52119 .03362 L
.53934 .03446 L
.5442 .03464 L
.54945 .0348 L
.55442 .03491 L
.55899 .03499 L
.5615 .03503 L
.56384 .03505 L
.56519 .03506 L
.56642 .03507 L
.5671 .03507 L
.56784 .03507 L
.56853 .03507 L
.56918 .03508 L
.57046 .03508 L
.57166 .03508 L
.57298 .03507 L
.57372 .03507 L
.5744 .03507 L
.57569 .03506 L
.5771 .03506 L
.57995 .03503 L
.58248 .035 L
.58523 .03497 L
.59021 .03489 L
.59954 .03469 L
.62048 .0341 L
.66137 .03282 L
Mistroke
.6817 .03225 L
.70074 .03179 L
.72015 .03141 L
.73859 .03112 L
.75886 .03088 L
.77739 .03072 L
.78698 .03065 L
.79721 .0306 L
.80686 .03056 L
.8156 .03053 L
.82563 .03051 L
.83486 .03049 L
.83969 .03048 L
.84499 .03048 L
.85569 .03047 L
.86655 .03046 L
.87685 .03045 L
.88608 .03045 L
.89613 .03043 L
.90594 .03042 L
.91635 .0304 L
.93506 .03035 L
.97283 .03022 L
.97619 .0302 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.03279 .05651 L
.04262 .0936 L
.04758 .10715 L
.0503 .11296 L
.05288 .1174 L
.05528 .12066 L
.05655 .12205 L
.05789 .1233 L
.05902 .12418 L
.06026 .12497 L
.06139 .12555 L
.06244 .12596 L
.06309 .12616 L
.06379 .12633 L
.06455 .12647 L
.06525 .12655 L
.06591 .12659 L
.06662 .12659 L
.06792 .12649 L
.06919 .12629 L
.06982 .12614 L
.07053 .12596 L
.07293 .12511 L
.07574 .12377 L
.07876 .12199 L
.0842 .11813 L
.10458 .10076 L
.12439 .08444 L
.14594 .06964 L
.16664 .05846 L
.18579 .0504 L
.20445 .04428 L
.22505 .03911 L
.2444 .03542 L
.26526 .03242 L
.2853 .03027 L
.3064 .02859 L
.32614 .02743 L
.3445 .02662 L
.36496 .02596 L
.38355 .02553 L
.39353 .02535 L
.40273 .02522 L
.41284 .0251 L
.41842 .02505 L
.42353 .02501 L
.42805 .02498 L
.43297 .02496 L
.43567 .02494 L
Mistroke
.43817 .02493 L
.44071 .02493 L
.44311 .02492 L
.44419 .02492 L
.44534 .02492 L
.4466 .02492 L
.44776 .02492 L
.4488 .02492 L
.44977 .02492 L
.45084 .02492 L
.45198 .02492 L
.45319 .02492 L
.45452 .02492 L
.45576 .02492 L
.45692 .02492 L
.4591 .02493 L
.46142 .02494 L
.46632 .02496 L
.47081 .02498 L
.47574 .02502 L
.48093 .02507 L
.48967 .02517 L
.49922 .02532 L
.52051 .02576 L
.53983 .02617 L
.5495 .02632 L
.55494 .02638 L
.55754 .0264 L
.55996 .02642 L
.56226 .02644 L
.56435 .02645 L
.56668 .02646 L
.56796 .02646 L
.56918 .02646 L
.57036 .02647 L
.5716 .02647 L
.57267 .02647 L
.57385 .02647 L
.57511 .02647 L
.57582 .02647 L
.57647 .02646 L
.57767 .02646 L
.57893 .02646 L
.5815 .02645 L
.58392 .02644 L
.58846 .02642 L
.59335 .02638 L
.59865 .02634 L
.61701 .02613 L
.65789 .02557 L
Mistroke
.67823 .02532 L
.69727 .02511 L
.71668 .02494 L
.73512 .02481 L
.74481 .02476 L
.75538 .02472 L
.76004 .0247 L
.76499 .02469 L
.76967 .02468 L
.77391 .02467 L
.77624 .02467 L
.77879 .02467 L
.78008 .02466 L
.78079 .02466 L
.78146 .02466 L
.78276 .02466 L
.78395 .02466 L
.78506 .02466 L
.78624 .02466 L
.78725 .02466 L
.78837 .02466 L
.78956 .02467 L
.79085 .02467 L
.79317 .02467 L
.7957 .02467 L
.79847 .02468 L
.80404 .02469 L
.8092 .02471 L
.814 .02473 L
.82453 .02479 L
.83447 .02487 L
.85306 .02504 L
.89155 .02545 L
.90183 .02554 L
.91144 .02561 L
.92147 .02567 L
.92678 .02569 L
.92955 .0257 L
.93249 .02571 L
.93525 .02571 L
.93775 .02572 L
.94027 .02572 L
.94139 .02572 L
.94263 .02572 L
.94398 .02573 L
.94471 .02573 L
.9454 .02573 L
.94663 .02573 L
.94794 .02573 L
.94868 .02573 L
Mistroke
.94949 .02573 L
.95024 .02573 L
.95095 .02573 L
.95227 .02572 L
.95368 .02572 L
.95606 .02572 L
.95862 .02572 L
.96325 .02571 L
.96875 .02569 L
.97379 .02568 L
.97619 .02567 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.03279 .0569 L
.04262 .09825 L
.053 .13425 L
.06244 .15836 L
.06786 .16811 L
.07035 .1716 L
.07298 .17462 L
.07579 .17713 L
.07839 .17882 L
.07983 .1795 L
.08118 .18 L
.08196 .18021 L
.08266 .18037 L
.08348 .18051 L
.08426 .18059 L
.08554 .18064 L
.0867 .18059 L
.08734 .18053 L
.08804 .18043 L
.0893 .18017 L
.09048 .17985 L
.09173 .17942 L
.09397 .17846 L
.09903 .17547 L
.10458 .17116 L
.145 .12895 L
.18391 .09444 L
.20515 .08063 L
.22527 .0704 L
.24518 .06252 L
.2636 .05684 L
.28227 .05235 L
.30287 .04857 L
.32222 .0459 L
.34307 .04377 L
.36311 .0423 L
.37319 .04173 L
.38421 .04123 L
.39449 .04086 L
.40382 .0406 L
.40899 .04049 L
.4146 .04039 L
.41717 .04035 L
.41989 .04032 L
.42223 .04029 L
.42477 .04027 L
.42609 .04026 L
.4273 .04026 L
.42856 .04025 L
Mistroke
.4297 .04025 L
.43083 .04024 L
.43189 .04024 L
.433 .04024 L
.43421 .04024 L
.43544 .04024 L
.43613 .04024 L
.43678 .04024 L
.43809 .04025 L
.43949 .04025 L
.44203 .04027 L
.44435 .04029 L
.44886 .04034 L
.45376 .04042 L
.45839 .04052 L
.46266 .04063 L
.47231 .04097 L
.48136 .04141 L
.49129 .04206 L
.50198 .04298 L
.52167 .04515 L
.53207 .04633 L
.54317 .0474 L
.54872 .04783 L
.55395 .04814 L
.55865 .04836 L
.5613 .04845 L
.56374 .04851 L
.56603 .04856 L
.56712 .04858 L
.56816 .04859 L
.56939 .04861 L
.57051 .04862 L
.57172 .04862 L
.57303 .04862 L
.5742 .04862 L
.5755 .04861 L
.57615 .04861 L
.57685 .0486 L
.57813 .04859 L
.58059 .04855 L
.58285 .04851 L
.58758 .04839 L
.59264 .04822 L
.60175 .04781 L
.62244 .04663 L
.66391 .04398 L
.68468 .04281 L
.70386 .04187 L
.7237 .04107 L
Mistroke
.74229 .04047 L
.76103 .04 L
.77161 .03978 L
.78166 .03961 L
.79135 .03948 L
.80192 .03935 L
.82045 .0392 L
.83078 .03913 L
.84014 .03908 L
.86112 .039 L
.882 .03891 L
.9012 .03881 L
.93977 .03855 L
.97619 .03825 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.04262 .09894 L
.06244 .16964 L
.08255 .22316 L
.09396 .24613 L
.10458 .26318 L
.11508 .27628 L
.125 .28556 L
.1339 .29161 L
.13893 .29417 L
.14357 .29603 L
.14823 .29744 L
.15085 .29805 L
.15324 .2985 L
.15546 .29883 L
.15663 .29896 L
.15788 .29909 L
.15908 .29918 L
.16017 .29925 L
.16127 .29929 L
.1623 .29932 L
.16349 .29934 L
.16481 .29933 L
.16547 .29931 L
.16618 .29929 L
.16746 .29924 L
.16873 .29916 L
.16994 .29907 L
.17221 .29885 L
.17487 .29852 L
.17734 .29814 L
.18292 .29705 L
.19255 .29455 L
.20159 .29164 L
.22219 .28375 L
.26088 .26796 L
.28053 .26082 L
.30202 .25427 L
.31194 .25175 L
.32254 .24943 L
.33248 .24763 L
.34164 .24628 L
.35188 .24516 L
.35728 .24472 L
.36003 .24455 L
.36299 .24439 L
.36558 .24429 L
.36795 .24421 L
.36908 .24419 L
.37032 .24416 L
Mistroke
.3715 .24415 L
.37258 .24414 L
.37325 .24413 L
.37397 .24413 L
.37527 .24414 L
.37653 .24415 L
.3777 .24416 L
.37896 .24418 L
.38034 .24422 L
.38314 .24431 L
.38566 .24443 L
.3884 .24459 L
.39337 .24498 L
.39821 .24547 L
.40269 .24605 L
.41284 .24778 L
.42362 .25037 L
.43301 .25339 L
.44313 .2576 L
.45267 .26271 L
.46142 .26861 L
.48038 .28679 L
.49112 .30116 L
.50109 .31725 L
.51987 .35152 L
.54019 .38542 L
.55133 .39962 L
.55621 .40469 L
.56158 .40944 L
.56631 .41292 L
.57138 .41594 L
.57418 .4173 L
.57674 .41836 L
.57911 .4192 L
.58174 .41995 L
.58422 .42051 L
.58654 .4209 L
.58782 .42106 L
.58899 .42118 L
.59028 .42128 L
.59093 .42131 L
.59164 .42134 L
.59284 .42136 L
.59393 .42135 L
.59519 .42131 L
.59638 .42125 L
.59749 .42116 L
.5985 .42106 L
.6008 .42077 L
.60328 .42035 L
Mistroke
.6056 .41986 L
.61088 .41843 L
.62156 .41437 L
.64182 .40358 L
.66035 .39182 L
.68095 .37848 L
.70008 .36719 L
.71858 .3583 L
.72892 .35454 L
.73339 .35324 L
.73829 .35206 L
.74317 .35119 L
.74584 .35084 L
.74711 .35071 L
.74832 .3506 L
.74944 .35052 L
.75065 .35046 L
.75176 .35042 L
.75278 .35041 L
.75388 .3504 L
.75509 .35043 L
.75636 .35048 L
.75755 .35055 L
.75877 .35065 L
.7601 .35078 L
.76278 .35116 L
.76526 .35164 L
.76757 .3522 L
.7728 .3539 L
.77837 .35644 L
.78371 .35966 L
.78863 .36336 L
.79974 .37452 L
.80953 .38762 L
.81989 .40436 L
.8578 .4741 L
.87889 .50759 L
.89816 .53196 L
.91809 .55131 L
.937 .56501 L
.95686 .57552 L
.97527 .58253 L
.97619 .58282 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.04262 .09882 L
.06244 .16759 L
.07286 .19485 L
.08255 .21491 L
.0932 .23139 L
.09916 .23831 L
.10458 .24328 L
.10941 .24673 L
.11206 .24826 L
.11454 .24947 L
.11891 .25111 L
.12123 .25175 L
.12373 .25225 L
.12511 .25246 L
.12639 .2526 L
.12712 .25266 L
.12779 .25271 L
.12856 .25275 L
.12929 .25277 L
.12993 .25278 L
.13061 .25278 L
.13183 .25275 L
.13314 .25269 L
.13389 .25263 L
.13458 .25257 L
.13709 .25226 L
.13937 .25187 L
.14451 .25064 L
.14932 .2491 L
.15442 .24712 L
.16359 .24281 L
.18435 .23087 L
.22211 .20738 L
.26231 .1862 L
.28079 .17858 L
.301 .17179 L
.32104 .16661 L
.33209 .16437 L
.34214 .16271 L
.35222 .16138 L
.36175 .16044 L
.36698 .16005 L
.3718 .15978 L
.37432 .15967 L
.37709 .15957 L
.37849 .15953 L
.37999 .15949 L
.3814 .15947 L
.3827 .15945 L
Mistroke
.38399 .15944 L
.38521 .15943 L
.3863 .15943 L
.38748 .15944 L
.38877 .15945 L
.38942 .15946 L
.39013 .15947 L
.39141 .15949 L
.39257 .15952 L
.39486 .15958 L
.3973 .15968 L
.40172 .15991 L
.40683 .16028 L
.41238 .16081 L
.42246 .16216 L
.43188 .16394 L
.44227 .16662 L
.45312 .17044 L
.46329 .17528 L
.47315 .18154 L
.48351 .19031 L
.49236 .20001 L
.50203 .21317 L
.52332 .2485 L
.54264 .27778 L
.55231 .28836 L
.55775 .29288 L
.56277 .29612 L
.56716 .29825 L
.56966 .29918 L
.57199 .29986 L
.57325 .30016 L
.57445 .3004 L
.57554 .30058 L
.5767 .30074 L
.57795 .30086 L
.57911 .30094 L
.58036 .30098 L
.58107 .30098 L
.58174 .30097 L
.58291 .30093 L
.58417 .30084 L
.58535 .30072 L
.58643 .30059 L
.58907 .30014 L
.59156 .29957 L
.59652 .29806 L
.6019 .29589 L
.6204 .28538 L
.66128 .25485 L
Mistroke
.70065 .22737 L
.73851 .20763 L
.75793 .20032 L
.77882 .19449 L
.78893 .19236 L
.79997 .19049 L
.81039 .18912 L
.82006 .18814 L
.82514 .18773 L
.83064 .18736 L
.83583 .18709 L
.8383 .18699 L
.8406 .18691 L
.84286 .18685 L
.84492 .1868 L
.84601 .18678 L
.8472 .18676 L
.84846 .18675 L
.84965 .18674 L
.8508 .18673 L
.85206 .18673 L
.85338 .18673 L
.85462 .18674 L
.85577 .18676 L
.85683 .18677 L
.85921 .18682 L
.8617 .18688 L
.86396 .18696 L
.86902 .1872 L
.87372 .1875 L
.87815 .18785 L
.88809 .18889 L
.89886 .19041 L
.91875 .19425 L
.93979 .19947 L
.97619 .20986 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.04262 .0988 L
.06244 .16695 L
.07286 .19314 L
.08255 .21151 L
.08813 .21954 L
.0932 .22533 L
.096 .22794 L
.09905 .23032 L
.10171 .23204 L
.10458 .23352 L
.10712 .23452 L
.10945 .23521 L
.11057 .23546 L
.11179 .23568 L
.11295 .23583 L
.11402 .23593 L
.11467 .23597 L
.11538 .236 L
.11666 .236 L
.11791 .23595 L
.11905 .23586 L
.1203 .23572 L
.12166 .2355 L
.12442 .23491 L
.12716 .23411 L
.12967 .23322 L
.13529 .2307 L
.14545 .22471 L
.18529 .1932 L
.22362 .16404 L
.24301 .15192 L
.2644 .14081 L
.28489 .13228 L
.30367 .12608 L
.32302 .12113 L
.33382 .11893 L
.34387 .11722 L
.35379 .11583 L
.3628 .11481 L
.3728 .11395 L
.3783 .11359 L
.3835 .11332 L
.38813 .11315 L
.39076 .11308 L
.39322 .11303 L
.39455 .11301 L
.39581 .113 L
.39694 .11299 L
.39818 .11298 L
Mistroke
.39888 .11298 L
.39952 .11298 L
.40025 .11298 L
.40095 .11299 L
.40218 .11299 L
.40287 .113 L
.40351 .11301 L
.40573 .11305 L
.40779 .11309 L
.41006 .11316 L
.41249 .11325 L
.41745 .1135 L
.42196 .1138 L
.42679 .1142 L
.4319 .11474 L
.44109 .116 L
.45097 .11788 L
.46186 .12076 L
.47198 .12447 L
.48125 .12904 L
.49142 .13574 L
.50212 .1451 L
.52212 .16805 L
.54028 .18873 L
.54513 .1932 L
.55039 .19735 L
.55493 .20031 L
.55993 .20289 L
.56523 .20488 L
.56813 .20565 L
.56952 .20594 L
.57084 .20617 L
.57205 .20635 L
.57338 .20651 L
.57458 .20661 L
.57569 .20668 L
.57689 .20672 L
.57757 .20673 L
.57821 .20673 L
.5795 .2067 L
.58022 .20667 L
.58089 .20664 L
.58216 .20654 L
.58337 .20643 L
.58562 .20613 L
.58805 .20572 L
.59068 .20516 L
.59979 .20244 L
.61055 .19802 L
.62048 .19315 L
Mistroke
.65985 .17138 L
.69771 .15263 L
.71876 .14425 L
.73802 .13797 L
.75814 .13272 L
.77681 .12894 L
.79581 .12602 L
.81654 .12366 L
.85569 .12042 L
.89729 .11734 L
.93737 .11464 L
.97594 .11268 L
.97619 .11267 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.03279 .05689 L
.04262 .09824 L
.053 .13436 L
.06244 .15898 L
.06786 .16931 L
.07298 .17658 L
.07579 .17958 L
.07839 .18176 L
.08124 .18354 L
.08268 .18421 L
.08426 .18478 L
.08491 .18496 L
.08561 .18513 L
.0869 .18535 L
.08815 .18547 L
.08931 .1855 L
.09002 .18547 L
.09069 .18542 L
.09194 .18527 L
.09265 .18515 L
.09329 .18501 L
.09475 .18464 L
.09703 .18385 L
.09953 .18274 L
.10458 .17981 L
.11478 .17183 L
.12409 .16313 L
.145 .14218 L
.1657 .12274 L
.18485 .10725 L
.22318 .08391 L
.24184 .07574 L
.26245 .06867 L
.28179 .06353 L
.30265 .0593 L
.32269 .05626 L
.34379 .05391 L
.35333 .05309 L
.36353 .05235 L
.37309 .05178 L
.3819 .05136 L
.39214 .05097 L
.39753 .05082 L
.40324 .05069 L
.4082 .0506 L
.41058 .05057 L
.41284 .05054 L
.41411 .05053 L
.4155 .05052 L
Mistroke
.41677 .05051 L
.41793 .0505 L
.41859 .0505 L
.4193 .0505 L
.42006 .0505 L
.42076 .0505 L
.42143 .0505 L
.42214 .0505 L
.42339 .0505 L
.42462 .0505 L
.42531 .0505 L
.42595 .0505 L
.42712 .05051 L
.42837 .05052 L
.43052 .05054 L
.4329 .05056 L
.43543 .0506 L
.43815 .05065 L
.44307 .05076 L
.44774 .0509 L
.45265 .05108 L
.46142 .05152 L
.47099 .05218 L
.4812 .05315 L
.49084 .05438 L
.49958 .0558 L
.52042 .06025 L
.52957 .06235 L
.53961 .06439 L
.54428 .06519 L
.54929 .06591 L
.55362 .06642 L
.55834 .06685 L
.56109 .06704 L
.56365 .06718 L
.56609 .06728 L
.56732 .06732 L
.56869 .06736 L
.56991 .06738 L
.57103 .0674 L
.57226 .06741 L
.57356 .06741 L
.57469 .06741 L
.57574 .0674 L
.5769 .06738 L
.57813 .06736 L
.57936 .06733 L
.58071 .06729 L
.58345 .0672 L
.58836 .06696 L
Mistroke
.59409 .06659 L
.59945 .06617 L
.6196 .06416 L
.65839 .05972 L
.67811 .05765 L
.69963 .05569 L
.72047 .05411 L
.73936 .05295 L
.75905 .05201 L
.78003 .05125 L
.79929 .05075 L
.81014 .05054 L
.82011 .05038 L
.85962 .04988 L
.89761 .04943 L
.93806 .04888 L
.97619 .0484 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.03279 .05635 L
.03793 .07664 L
.04262 .09143 L
.045 .09739 L
.04758 .10263 L
.04899 .10497 L
.0503 .10681 L
.05164 .10838 L
.05288 .10958 L
.05404 .11048 L
.05509 .11114 L
.05626 .11169 L
.05752 .1121 L
.05873 .11231 L
.06005 .11238 L
.06129 .11229 L
.06244 .1121 L
.06311 .11193 L
.06382 .11173 L
.06509 .11128 L
.06795 .10993 L
.07314 .10663 L
.08284 .09889 L
.10458 .0806 L
.12444 .06631 L
.14255 .05585 L
.16206 .04702 L
.18298 .03984 L
.20206 .0349 L
.22282 .03086 L
.2426 .02799 L
.2636 .02573 L
.28307 .02418 L
.30135 .02308 L
.32154 .02217 L
.34004 .02155 L
.35897 .02108 L
.37967 .0207 L
.39928 .02044 L
.41025 .02034 L
.42023 .02026 L
.42955 .0202 L
.43941 .02015 L
.44456 .02013 L
.45023 .02012 L
.45539 .02011 L
.45772 .0201 L
.46021 .0201 L
.46279 .02009 L
Mistroke
.46394 .02009 L
.46519 .02009 L
.46595 .02009 L
.46666 .02009 L
.46731 .02009 L
.46804 .02009 L
.46929 .02009 L
.46998 .02009 L
.47062 .02009 L
.4719 .02009 L
.47311 .02009 L
.4742 .02009 L
.47539 .02009 L
.47804 .0201 L
.4805 .0201 L
.48477 .02011 L
.48949 .02012 L
.49903 .02015 L
.52005 .02024 L
.52924 .02029 L
.5341 .02031 L
.53929 .02033 L
.54442 .02034 L
.54908 .02035 L
.55132 .02036 L
.55376 .02036 L
.55487 .02036 L
.55606 .02036 L
.55714 .02036 L
.55817 .02036 L
.55941 .02037 L
.56053 .02037 L
.56174 .02037 L
.56306 .02037 L
.56421 .02037 L
.56544 .02036 L
.56648 .02036 L
.56763 .02036 L
.57021 .02036 L
.57299 .02036 L
.57803 .02035 L
.58298 .02034 L
.58758 .02032 L
.59804 .02029 L
.61914 .02019 L
.65815 .02002 L
.67804 .01994 L
.69961 .01986 L
.71863 .01981 L
.73956 .01977 L
Mistroke
.75942 .01974 L
.77028 .01973 L
.78045 .01972 L
.79084 .01971 L
.79596 .01971 L
.80071 .01971 L
.80536 .0197 L
.80957 .0197 L
.81425 .0197 L
.81663 .0197 L
.81924 .0197 L
.8216 .0197 L
.82412 .0197 L
.82552 .0197 L
.82679 .0197 L
.82807 .0197 L
.82928 .0197 L
.83039 .0197 L
.83157 .0197 L
.83258 .0197 L
.8337 .0197 L
.83489 .0197 L
.83618 .0197 L
.83739 .0197 L
.8385 .0197 L
.84101 .0197 L
.84335 .0197 L
.84865 .0197 L
.85933 .0197 L
.86986 .0197 L
.87503 .0197 L
.8798 .0197 L
.88414 .01971 L
.88632 .01971 L
.88872 .01971 L
.88998 .01971 L
.89113 .01971 L
.89177 .01971 L
.89246 .01971 L
.89372 .01971 L
.8949 .01971 L
.89615 .01971 L
.89733 .01971 L
.89839 .01971 L
.8996 .01971 L
.90073 .01971 L
.90329 .01971 L
.90578 .01971 L
.90845 .0197 L
.91329 .0197 L
Mistroke
.91769 .0197 L
.9284 .0197 L
.93853 .0197 L
.95811 .01969 L
.97619 .01968 L
Mfstroke
.055 0 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02115 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .0215 L
.03395 .0215 L
.0352 .02147 L
.03638 .02142 L
.03746 .02137 L
.04262 .02107 L
.06244 .01973 L
.08259 .01855 L
.10458 .01758 L
.12517 .0169 L
.14429 .01643 L
.16481 .01605 L
.18342 .0158 L
.20266 .0156 L
.22348 .01544 L
.24342 .01533 L
.26449 .01525 L
.28413 .01519 L
.30246 .01515 L
.32281 .01511 L
.34137 .01509 L
.36045 .01507 L
.38121 .01506 L
.40099 .01505 L
.4111 .01504 L
.422 .01504 L
.43215 .01504 L
.44147 .01504 L
.45975 .01503 L
.46955 .01503 L
.47867 .01503 L
.48868 .01503 L
.49428 .01503 L
.49937 .01503 L
.50935 .01503 L
.51856 .01503 L
.5293 .01503 L
.53935 .01503 L
.5484 .01503 L
.55812 .01503 L
.57876 .01503 L
.62003 .01502 L
Mistroke
.64066 .01502 L
.65979 .01502 L
.6795 .01502 L
.69804 .01502 L
.7186 .01502 L
.73722 .01502 L
.74701 .01502 L
.75734 .01502 L
.76616 .01502 L
.77582 .01502 L
.78108 .01502 L
.78367 .01502 L
.78605 .01502 L
.78818 .01502 L
.79052 .01502 L
.79287 .01502 L
.79416 .01502 L
.79537 .01502 L
.7966 .01502 L
.79729 .01502 L
.79794 .01502 L
.79924 .01502 L
.79997 .01502 L
.80063 .01502 L
.80182 .01502 L
.80311 .01502 L
.80433 .01502 L
.80545 .01502 L
.80796 .01502 L
.81072 .01502 L
.8163 .01502 L
.82153 .01502 L
.82649 .01502 L
.83579 .01502 L
.85669 .01502 L
.87489 .01502 L
.88525 .01502 L
.89499 .01502 L
.90449 .01502 L
.90983 .01502 L
.91474 .01502 L
.91962 .01502 L
.92239 .01502 L
.92362 .01502 L
.92496 .01502 L
.92569 .01502 L
.92637 .01502 L
.927 .01502 L
.92769 .01502 L
.9289 .01502 L
Mistroke
.93017 .01502 L
.93089 .01502 L
.93156 .01502 L
.93232 .01502 L
.93305 .01502 L
.93433 .01502 L
.93574 .01502 L
.93828 .01502 L
.94103 .01502 L
.94601 .01502 L
.95086 .01502 L
.95532 .01502 L
.96547 .01502 L
.97619 .01502 L
Mfstroke
.079 0 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .0356 L
.03072 .0433 L
.03279 .04846 L
.03405 .05079 L
.03521 .05245 L
.03649 .05382 L
.03713 .05435 L
.03784 .05483 L
.03903 .05542 L
.04031 .05581 L
.04151 .05599 L
.04262 .05602 L
.04384 .05595 L
.04514 .05577 L
.04636 .05552 L
.04748 .05523 L
.05278 .05345 L
.06244 .04947 L
.08269 .0414 L
.10458 .03448 L
.12545 .02955 L
.14465 .02616 L
.16347 .02365 L
.18413 .02159 L
.20364 .02015 L
.22456 .01902 L
.2458 .01818 L
.26592 .01761 L
.28583 .01718 L
.30425 .01689 L
.32291 .01667 L
.34352 .01649 L
.36286 .01637 L
.38372 .01627 L
.40376 .01621 L
.41384 .01618 L
.42486 .01616 L
.44447 .01613 L
.45545 .01611 L
.46542 .01611 L
.47027 .0161 L
.4754 .0161 L
.47978 .0161 L
.4846 .0161 L
.48731 .0161 L
.48978 .0161 L
.49115 .01609 L
.49264 .01609 L
Mistroke
.49404 .01609 L
.49535 .01609 L
.49667 .01609 L
.4979 .01609 L
.49902 .01609 L
.50022 .01609 L
.50153 .01609 L
.50219 .01609 L
.50292 .01609 L
.5042 .01609 L
.5054 .01609 L
.50801 .01609 L
.51042 .0161 L
.51588 .0161 L
.52579 .0161 L
.53044 .0161 L
.5348 .0161 L
.53699 .0161 L
.53935 .0161 L
.54062 .0161 L
.54132 .0161 L
.54197 .0161 L
.54311 .0161 L
.54436 .0161 L
.54564 .0161 L
.54629 .0161 L
.547 .0161 L
.54825 .0161 L
.54943 .0161 L
.55081 .0161 L
.55207 .0161 L
.55491 .0161 L
.55736 .0161 L
.56002 .0161 L
.56486 .0161 L
.57452 .01609 L
.58346 .01609 L
.62269 .01607 L
.66041 .01605 L
.68136 .01604 L
.70058 .01603 L
.7194 .01603 L
.73924 .01602 L
.74877 .01602 L
.75895 .01602 L
.77731 .01602 L
.78754 .01602 L
.79863 .01602 L
.81878 .01602 L
.85967 .01601 L
Mistroke
.89904 .01601 L
.93689 .01601 L
.97619 .01601 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.04262 .09883 L
.06244 .16764 L
.07286 .19493 L
.08255 .21497 L
.0932 .23135 L
.09916 .23816 L
.10458 .24301 L
.10941 .24633 L
.11206 .24778 L
.11454 .2489 L
.11682 .24976 L
.11891 .25039 L
.12123 .25094 L
.12251 .25117 L
.12373 .25134 L
.12503 .25148 L
.12622 .25157 L
.12688 .25161 L
.12759 .25163 L
.12888 .25164 L
.13009 .25161 L
.13137 .25154 L
.13246 .25145 L
.13366 .25132 L
.13637 .25091 L
.13927 .25031 L
.14451 .24882 L
.15468 .24473 L
.16575 .23894 L
.18587 .22643 L
.22665 .20021 L
.24691 .18885 L
.26592 .17969 L
.28431 .17226 L
.30367 .16593 L
.32385 .16087 L
.34236 .15751 L
.3519 .15623 L
.35715 .15566 L
.3621 .1552 L
.36672 .15485 L
.37172 .15454 L
.37393 .15444 L
.37627 .15434 L
.37828 .15427 L
.38047 .15421 L
.38178 .15419 L
.383 .15417 L
.38416 .15415 L
Mistroke
.3854 .15414 L
.38661 .15414 L
.38776 .15414 L
.38879 .15414 L
.3899 .15415 L
.39113 .15417 L
.39247 .15419 L
.39388 .15422 L
.39519 .15426 L
.39753 .15434 L
.40004 .15445 L
.40497 .15474 L
.40962 .1551 L
.41835 .15605 L
.42296 .15671 L
.42803 .15756 L
.4383 .15979 L
.44782 .16258 L
.45673 .166 L
.46659 .17095 L
.47696 .17792 L
.48581 .18574 L
.49547 .19665 L
.51677 .2288 L
.53609 .25935 L
.54575 .27148 L
.55084 .27663 L
.55621 .28109 L
.56092 .28416 L
.56341 .28548 L
.56609 .28665 L
.56855 .28753 L
.57079 .28816 L
.57187 .2884 L
.57305 .28863 L
.57409 .2888 L
.57518 .28894 L
.5764 .28906 L
.57751 .28913 L
.57871 .28916 L
.58002 .28916 L
.58116 .28912 L
.58238 .28904 L
.58352 .28892 L
.58457 .2888 L
.58713 .28837 L
.5899 .28774 L
.59494 .28618 L
.60024 .28404 L
.60586 .28128 L
Mistroke
.61593 .27533 L
.65379 .24772 L
.6941 .21981 L
.71265 .20941 L
.73289 .20012 L
.74386 .196 L
.75404 .19275 L
.76369 .19016 L
.77413 .18791 L
.77964 .18694 L
.78471 .18618 L
.78946 .18559 L
.79467 .18506 L
.79935 .18471 L
.8016 .18458 L
.80372 .18447 L
.80488 .18443 L
.80614 .18439 L
.80718 .18436 L
.80834 .18433 L
.80958 .18431 L
.81027 .1843 L
.81091 .1843 L
.81205 .18429 L
.81328 .1843 L
.81454 .18431 L
.81568 .18433 L
.817 .18436 L
.81825 .18439 L
.82046 .18448 L
.82286 .1846 L
.82551 .18478 L
.82831 .18501 L
.83334 .18555 L
.83853 .18628 L
.84339 .18713 L
.85444 .18975 L
.86486 .19316 L
.87475 .1973 L
.89329 .20745 L
.93155 .23619 L
.97227 .26985 L
.97619 .27289 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.04262 .09857 L
.0522 .13352 L
.06244 .16385 L
.0679 .17686 L
.07286 .18684 L
.0779 .19521 L
.08255 .20142 L
.08798 .20694 L
.09084 .20915 L
.09388 .21101 L
.09651 .21224 L
.09897 .21309 L
.10038 .21345 L
.10167 .2137 L
.10239 .21381 L
.10316 .21391 L
.1039 .21398 L
.10458 .21402 L
.10587 .21405 L
.10651 .21404 L
.10722 .21402 L
.10848 .21393 L
.10966 .21379 L
.11104 .21358 L
.11231 .21332 L
.11515 .21258 L
.12026 .21069 L
.1251 .20834 L
.14371 .19588 L
.18204 .16481 L
.22282 .13646 L
.24307 .12555 L
.26209 .11716 L
.28048 .11059 L
.29984 .10509 L
.32002 .10069 L
.33853 .0977 L
.34807 .0965 L
.35827 .09546 L
.36789 .09469 L
.37663 .09416 L
.38148 .09394 L
.38662 .09376 L
.38873 .09371 L
.391 .09366 L
.3923 .09363 L
.39349 .09361 L
.39471 .0936 L
.39582 .09358 L
Mistroke
.3971 .09357 L
.39781 .09357 L
.39847 .09357 L
.39965 .09356 L
.40092 .09357 L
.4016 .09357 L
.40233 .09357 L
.4031 .09358 L
.40382 .09358 L
.40511 .09359 L
.40649 .09361 L
.40921 .09366 L
.41179 .09373 L
.41662 .09389 L
.42122 .0941 L
.4263 .09441 L
.43124 .09478 L
.43657 .09528 L
.44608 .09644 L
.455 .09791 L
.46459 .10003 L
.47508 .10318 L
.48602 .10775 L
.49619 .11351 L
.51669 .12982 L
.53529 .14609 L
.5453 .15299 L
.55006 .15554 L
.55451 .15746 L
.55933 .15906 L
.56189 .1597 L
.56463 .16023 L
.566 .16044 L
.5675 .16063 L
.56891 .16077 L
.57022 .16087 L
.57139 .16092 L
.57269 .16096 L
.57334 .16097 L
.57405 .16097 L
.57532 .16095 L
.57657 .1609 L
.57771 .16084 L
.57903 .16074 L
.58027 .16062 L
.58248 .16036 L
.58488 .16 L
.59032 .15893 L
.59534 .15766 L
.61643 .15033 L
Mistroke
.6558 .13388 L
.69365 .12021 L
.71471 .11429 L
.73396 .10995 L
.75385 .10646 L
.77275 .10399 L
.78235 .10301 L
.79257 .10216 L
.81097 .10101 L
.82126 .10055 L
.83239 .10016 L
.83751 .10002 L
.8429 .09989 L
.84796 .0998 L
.85257 .09973 L
.8549 .0997 L
.85744 .09968 L
.85984 .09966 L
.86091 .09965 L
.86206 .09964 L
.86327 .09964 L
.8644 .09964 L
.86506 .09964 L
.86575 .09964 L
.86699 .09964 L
.86828 .09964 L
.86949 .09964 L
.87081 .09964 L
.87222 .09965 L
.8746 .09967 L
.87717 .09969 L
.88183 .09976 L
.88638 .09985 L
.89056 .09995 L
.90026 .10026 L
.90934 .10066 L
.92998 .10191 L
.96883 .10524 L
.97619 .10595 L
Mfstroke
.15 0 1 r
.02381 .01472 m
.04262 .09892 L
.06244 .16895 L
.07216 .19596 L
.08255 .21959 L
.09396 .23951 L
.09948 .24702 L
.10458 .25278 L
.10944 .25728 L
.1148 .26118 L
.12018 .26406 L
.12313 .26522 L
.12589 .26606 L
.12713 .26636 L
.12848 .26664 L
.12968 .26684 L
.13095 .26701 L
.13221 .26714 L
.13336 .26721 L
.13451 .26726 L
.13559 .26726 L
.13686 .26724 L
.1375 .26721 L
.1382 .26717 L
.13944 .26706 L
.1406 .26694 L
.14322 .26654 L
.14603 .26595 L
.15131 .26445 L
.1562 .26263 L
.16727 .25732 L
.18739 .24489 L
.22665 .21797 L
.2644 .19571 L
.28538 .18598 L
.30461 .17877 L
.32345 .17323 L
.33305 .17097 L
.34329 .16894 L
.35364 .1673 L
.36304 .16616 L
.36757 .16572 L
.37248 .16533 L
.37712 .16505 L
.3814 .16486 L
.38384 .16479 L
.385 .16476 L
.38608 .16474 L
.38731 .16472 L
.38796 .16471 L
Mistroke
.38865 .16471 L
.38993 .1647 L
.3911 .1647 L
.39227 .16471 L
.39334 .16472 L
.39452 .16473 L
.39577 .16476 L
.39787 .16481 L
.40017 .16489 L
.40287 .16502 L
.40532 .16516 L
.41085 .16559 L
.41596 .16611 L
.42081 .16674 L
.43048 .16841 L
.44075 .17089 L
.44952 .17374 L
.45919 .17787 L
.46931 .18365 L
.47857 .19066 L
.48875 .2008 L
.49944 .21474 L
.5376 .2797 L
.54772 .29387 L
.55725 .30417 L
.56253 .30853 L
.56824 .31216 L
.57077 .31343 L
.57344 .31454 L
.57572 .31532 L
.57822 .31599 L
.57953 .31626 L
.58076 .31648 L
.5819 .31664 L
.58316 .31678 L
.58429 .31686 L
.58535 .31691 L
.58647 .31694 L
.58768 .31692 L
.58891 .31687 L
.58961 .31683 L
.59026 .31678 L
.59157 .31664 L
.59297 .31645 L
.59552 .316 L
.59783 .31547 L
.60235 .31413 L
.60725 .31226 L
.61616 .30796 L
.65704 .28014 L
Mistroke
.67737 .26559 L
.69641 .2534 L
.71582 .24322 L
.72539 .23922 L
.73427 .23623 L
.73935 .23485 L
.74396 .23384 L
.74908 .23299 L
.75043 .23282 L
.75189 .23266 L
.75325 .23254 L
.75453 .23245 L
.75561 .23239 L
.75677 .23235 L
.75805 .23232 L
.75923 .23232 L
.76045 .23234 L
.76113 .23236 L
.76177 .23239 L
.76294 .23245 L
.76418 .23255 L
.76636 .23278 L
.7684 .23308 L
.77065 .23351 L
.77306 .23408 L
.77802 .23568 L
.78264 .23772 L
.78771 .24069 L
.79312 .24479 L
.79881 .2503 L
.80418 .25673 L
.81422 .27216 L
.83425 .31486 L
.85271 .36115 L
.87308 .40977 L
.89213 .44805 L
.91041 .47726 L
.93004 .50101 L
.94018 .51057 L
.95123 .51916 L
.97133 .53069 L
.97619 .5328 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.03279 .0561 L
.03793 .07542 L
.04262 .08846 L
.04517 .09353 L
.04758 .09706 L
.0489 .09851 L
.05012 .09957 L
.05146 .10045 L
.05214 .10079 L
.05288 .10109 L
.05412 .10143 L
.05526 .10157 L
.05657 .10157 L
.05782 .10142 L
.05897 .10117 L
.06003 .10085 L
.06244 .09986 L
.06509 .09844 L
.06795 .09663 L
.07314 .09287 L
.08284 .08519 L
.10458 .06876 L
.12413 .05674 L
.14558 .04657 L
.166 .0393 L
.18507 .03418 L
.20542 .03007 L
.22398 .02725 L
.24306 .02505 L
.26382 .02327 L
.2836 .02202 L
.30461 .02105 L
.32408 .02038 L
.34236 .01991 L
.36254 .01953 L
.38104 .01927 L
.39997 .01908 L
.41069 .019 L
.42067 .01894 L
.43119 .01888 L
.44113 .01885 L
.45005 .01882 L
.45508 .01881 L
.45971 .0188 L
.46439 .01879 L
.46701 .01879 L
.46941 .01879 L
.47049 .01879 L
.47163 .01879 L
Mistroke
.47289 .01879 L
.47406 .01879 L
.47525 .01879 L
.47638 .01879 L
.47739 .01879 L
.47848 .01879 L
.47977 .01879 L
.48097 .01879 L
.4823 .01879 L
.48371 .01879 L
.4866 .01879 L
.48923 .0188 L
.49431 .0188 L
.49912 .01881 L
.51737 .01886 L
.52776 .01888 L
.5375 .01891 L
.54215 .01892 L
.54704 .01892 L
.5496 .01893 L
.5524 .01893 L
.55363 .01893 L
.55495 .01893 L
.55619 .01893 L
.55731 .01893 L
.55863 .01893 L
.55929 .01893 L
.56002 .01893 L
.5613 .01893 L
.56251 .01893 L
.56324 .01893 L
.56393 .01893 L
.56522 .01893 L
.56661 .01893 L
.56813 .01893 L
.5707 .01893 L
.57343 .01892 L
.57833 .01892 L
.58769 .0189 L
.59778 .01888 L
.61605 .01883 L
.65716 .01871 L
.67766 .01865 L
.69675 .01861 L
.71633 .01858 L
.73483 .01855 L
.74463 .01854 L
.75526 .01853 L
.76486 .01853 L
.77384 .01852 L
Mistroke
.78329 .01852 L
.78872 .01851 L
.79369 .01851 L
.79889 .01851 L
.80383 .01851 L
.80653 .01851 L
.80904 .01851 L
.81179 .01851 L
.81333 .01851 L
.81473 .01851 L
.81593 .01851 L
.81705 .01851 L
.81829 .01851 L
.81961 .01851 L
.82027 .01851 L
.82099 .01851 L
.8223 .01851 L
.82358 .01851 L
.82476 .01851 L
.82689 .01851 L
.82924 .01851 L
.83399 .01851 L
.83916 .01851 L
.84473 .01851 L
.85481 .01851 L
.87448 .01852 L
.89597 .01853 L
.90591 .01853 L
.91136 .01853 L
.91651 .01853 L
.92132 .01853 L
.92403 .01853 L
.92653 .01853 L
.92863 .01853 L
.92984 .01853 L
.93094 .01853 L
.93211 .01853 L
.93336 .01853 L
.93452 .01853 L
.93562 .01853 L
.93687 .01853 L
.93757 .01853 L
.93822 .01853 L
.93941 .01853 L
.94067 .01853 L
.94285 .01853 L
.94524 .01853 L
.9478 .01853 L
.95054 .01853 L
.95548 .01853 L
Mistroke
.96511 .01853 L
.97388 .01853 L
.97619 .01852 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.03279 .05687 L
.04262 .09758 L
.04758 .1149 L
.05288 .13034 L
.05789 .14166 L
.06244 .1491 L
.06507 .15218 L
.0665 .15351 L
.06785 .15454 L
.06908 .1553 L
.07022 .15586 L
.07148 .15632 L
.07217 .1565 L
.07283 .15664 L
.07354 .15674 L
.07418 .15679 L
.07493 .1568 L
.07563 .15678 L
.07687 .15663 L
.07757 .15649 L
.07822 .15633 L
.07958 .15591 L
.08108 .1553 L
.0841 .15369 L
.08922 .15 L
.09469 .1451 L
.10458 .13492 L
.12439 .11365 L
.14594 .09321 L
.16488 .07858 L
.18579 .06583 L
.20556 .05655 L
.22657 .04903 L
.24592 .04378 L
.26677 .03951 L
.28681 .03645 L
.30791 .03405 L
.32765 .0324 L
.34602 .03125 L
.36648 .03031 L
.38506 .02971 L
.39505 .02946 L
.40425 .02928 L
.41435 .02912 L
.41994 .02905 L
.42505 .029 L
.42989 .02896 L
.43448 .02894 L
.437 .02893 L
Mistroke
.43933 .02892 L
.44065 .02891 L
.44189 .02891 L
.44258 .02891 L
.44333 .02891 L
.44462 .02891 L
.44577 .02891 L
.44684 .02891 L
.44801 .02891 L
.44927 .02891 L
.45058 .02891 L
.45183 .02891 L
.45416 .02892 L
.45635 .02893 L
.45837 .02894 L
.46293 .02897 L
.46758 .02901 L
.47259 .02907 L
.48164 .02921 L
.4924 .02944 L
.50225 .02971 L
.52282 .03041 L
.53284 .03073 L
.54193 .03097 L
.54649 .03106 L
.55143 .03114 L
.5537 .03117 L
.5561 .03119 L
.55834 .03121 L
.56039 .03122 L
.56159 .03123 L
.56273 .03124 L
.56394 .03124 L
.56524 .03124 L
.56639 .03124 L
.5676 .03124 L
.56863 .03124 L
.56978 .03124 L
.57043 .03124 L
.57111 .03123 L
.57234 .03123 L
.57509 .03122 L
.57748 .0312 L
.58009 .03118 L
.59035 .03105 L
.59968 .0309 L
.62062 .03046 L
.66057 .02959 L
.699 .02891 L
.71885 .02865 L
Mistroke
.73989 .02842 L
.75944 .02827 L
.77774 .02817 L
.78813 .02812 L
.79801 .02809 L
.80687 .02807 L
.81654 .02805 L
.82686 .02803 L
.83622 .02802 L
.8572 .028 L
.87808 .02797 L
.89729 .02794 L
.91605 .0279 L
.93586 .02785 L
.97385 .02773 L
.97619 .02772 L
Mfstroke
.221 0 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01977 L
.08259 .01861 L
.10458 .01765 L
.12517 .01697 L
.14429 .01651 L
.16481 .01613 L
.18342 .01588 L
.20266 .01568 L
.22348 .01552 L
.24342 .01541 L
.26449 .01532 L
.28413 .01526 L
.30246 .01522 L
.32281 .01519 L
.34137 .01516 L
.36045 .01515 L
.38121 .01513 L
.40099 .01512 L
.4111 .01512 L
.422 .01512 L
.43215 .01511 L
.44147 .01511 L
.4503 .01511 L
.45975 .01511 L
.46488 .01511 L
.46955 .01511 L
.47429 .01511 L
.47867 .01511 L
.48378 .01511 L
.48647 .01511 L
.48932 .01511 L
.49179 .01511 L
.4941 .01511 L
.49543 .01511 L
.49664 .01511 L
.49731 .01511 L
Mistroke
.49804 .01511 L
.49873 .01511 L
.49937 .01511 L
.50066 .01511 L
.50131 .01511 L
.50202 .01511 L
.50329 .01511 L
.50446 .01511 L
.50585 .01511 L
.50712 .01511 L
.50997 .01511 L
.51993 .01511 L
.52897 .01511 L
.53116 .01511 L
.53353 .01511 L
.53488 .01511 L
.53612 .01511 L
.53731 .01511 L
.53855 .01511 L
.53974 .01511 L
.54101 .01511 L
.54221 .01511 L
.5433 .01511 L
.54458 .01511 L
.54531 .01511 L
.54597 .01511 L
.54849 .01511 L
.55062 .01511 L
.55296 .01511 L
.55768 .01511 L
.56286 .01511 L
.56842 .01511 L
.57845 .01511 L
.61978 .0151 L
.65959 .0151 L
.69789 .0151 L
.71764 .0151 L
.73864 .0151 L
.74799 .01509 L
.75809 .01509 L
.77636 .01509 L
.78591 .01509 L
.79637 .01509 L
.81746 .01509 L
.85799 .01509 L
.89701 .01509 L
.93847 .01509 L
.97619 .01509 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.03279 .05678 L
.04262 .09694 L
.04758 .11407 L
.05288 .12977 L
.05785 .14194 L
.06244 .15103 L
.06788 .15924 L
.07075 .16254 L
.07379 .1653 L
.07642 .16714 L
.07889 .16843 L
.0803 .16899 L
.08159 .16939 L
.08231 .16957 L
.08309 .16973 L
.08377 .16985 L
.08451 .16994 L
.08522 .17001 L
.08587 .17005 L
.08715 .17006 L
.08831 .17 L
.08955 .16988 L
.09018 .16978 L
.09087 .16967 L
.09211 .16941 L
.09492 .1686 L
.09751 .16762 L
.09997 .16649 L
.10458 .16398 L
.12449 .14928 L
.14291 .13383 L
.18218 .10455 L
.21993 .0844 L
.23927 .07687 L
.26013 .07048 L
.28017 .06573 L
.30127 .06192 L
.32101 .05924 L
.33938 .05737 L
.3499 .05654 L
.35984 .05588 L
.36869 .05541 L
.37842 .05499 L
.38814 .05467 L
.39346 .05454 L
.39844 .05445 L
.40082 .05441 L
.40309 .05439 L
.40514 .05437 L
Mistroke
.40733 .05435 L
.40858 .05434 L
.40971 .05434 L
.41084 .05433 L
.4119 .05433 L
.41315 .05433 L
.4143 .05433 L
.41556 .05433 L
.41619 .05433 L
.41689 .05434 L
.4182 .05434 L
.41941 .05435 L
.42215 .05437 L
.42456 .0544 L
.42712 .05444 L
.43155 .05453 L
.43644 .05465 L
.44164 .05483 L
.44724 .05506 L
.45737 .05564 L
.46696 .0564 L
.47745 .05755 L
.48839 .0592 L
.49856 .06126 L
.51733 .06635 L
.53766 .07215 L
.54307 .07339 L
.54879 .07447 L
.55367 .0752 L
.55648 .07554 L
.55904 .0758 L
.56145 .076 L
.56407 .07617 L
.56551 .07625 L
.56684 .0763 L
.56811 .07635 L
.56882 .07637 L
.56947 .07638 L
.57061 .0764 L
.57185 .07642 L
.57294 .07642 L
.57409 .07642 L
.57536 .07641 L
.57653 .07639 L
.57782 .07636 L
.57921 .07632 L
.58179 .07622 L
.58452 .07609 L
.58943 .07576 L
.60053 .07473 L
Mistroke
.62067 .07219 L
.65853 .06682 L
.67958 .06411 L
.69883 .06197 L
.73763 .05868 L
.75662 .05755 L
.77735 .05662 L
.79704 .056 L
.80805 .05573 L
.81802 .05553 L
.85811 .05493 L
.89668 .0545 L
.91663 .05435 L
.92668 .05429 L
.93234 .05427 L
.9377 .05425 L
.94236 .05424 L
.94481 .05423 L
.94742 .05423 L
.94961 .05422 L
.95202 .05422 L
.95308 .05422 L
.95422 .05422 L
.95522 .05422 L
.95628 .05422 L
.95753 .05422 L
.9587 .05422 L
.95941 .05422 L
.96008 .05422 L
.96134 .05422 L
.96199 .05422 L
.96267 .05422 L
.9639 .05422 L
.96522 .05422 L
.96667 .05422 L
.96904 .05422 L
.97159 .05422 L
.97619 .05423 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.02846 .03692 L
.03279 .056 L
.03793 .07501 L
.04262 .0876 L
.04498 .0921 L
.04622 .09399 L
.04754 .09565 L
.04869 .09684 L
.04996 .09788 L
.05112 .0986 L
.0522 .09909 L
.05352 .09949 L
.05478 .09968 L
.0559 .0997 L
.05713 .09959 L
.05783 .09947 L
.05847 .09933 L
.05989 .09891 L
.06244 .09786 L
.06787 .09473 L
.07287 .09121 L
.08414 .08253 L
.10458 .06761 L
.125 .05547 L
.14407 .04663 L
.16239 .04006 L
.18204 .03466 L
.20328 .03031 L
.2234 .02726 L
.24331 .02502 L
.26173 .02346 L
.28039 .02226 L
.301 .02128 L
.32034 .02059 L
.3412 .02005 L
.36124 .01967 L
.38234 .01939 L
.39188 .01929 L
.40208 .0192 L
.42045 .01908 L
.43069 .01903 L
.43608 .01901 L
.44179 .01899 L
.44679 .01897 L
.45228 .01896 L
.45727 .01895 L
.46195 .01895 L
.46453 .01895 L
.46692 .01894 L
Mistroke
.4683 .01894 L
.46955 .01894 L
.47025 .01894 L
.471 .01894 L
.4717 .01894 L
.47235 .01894 L
.47354 .01894 L
.47465 .01894 L
.47586 .01894 L
.47716 .01894 L
.47852 .01894 L
.47982 .01894 L
.48223 .01895 L
.48685 .01895 L
.49112 .01896 L
.50077 .01898 L
.52106 .01904 L
.53099 .01907 L
.53534 .01908 L
.54009 .01909 L
.54469 .0191 L
.54896 .0191 L
.55133 .0191 L
.55348 .0191 L
.55467 .01911 L
.55595 .01911 L
.55717 .01911 L
.55829 .01911 L
.55942 .01911 L
.56064 .01911 L
.56179 .01911 L
.56283 .01911 L
.56406 .01911 L
.56539 .0191 L
.56782 .0191 L
.57035 .0191 L
.57305 .0191 L
.57789 .01909 L
.58725 .01907 L
.59734 .01905 L
.61561 .019 L
.65672 .01887 L
.67722 .01881 L
.69631 .01877 L
.71589 .01874 L
.73438 .01871 L
.74418 .0187 L
.75482 .01869 L
.7734 .01867 L
.78285 .01867 L
Mistroke
.79325 .01866 L
.79848 .01866 L
.80411 .01866 L
.80939 .01866 L
.81428 .01866 L
.81918 .01866 L
.8244 .01866 L
.82738 .01866 L
.83019 .01866 L
.83271 .01866 L
.83543 .01866 L
.83786 .01866 L
.83924 .01866 L
.84053 .01866 L
.84122 .01866 L
.84188 .01866 L
.84312 .01866 L
.84381 .01866 L
.84445 .01866 L
.84516 .01866 L
.8459 .01866 L
.84704 .01866 L
.84826 .01866 L
.84942 .01866 L
.85048 .01866 L
.85313 .01866 L
.85553 .01866 L
.8567 .01866 L
.85797 .01866 L
.85917 .01866 L
.86027 .01866 L
.86145 .01866 L
.86274 .01866 L
.86339 .01866 L
.86408 .01866 L
.86534 .01866 L
.86651 .01866 L
.86779 .01866 L
.87011 .01866 L
.87237 .01866 L
.87447 .01866 L
.87718 .01866 L
.87973 .01866 L
.8845 .01866 L
.88963 .01866 L
.89517 .01865 L
.90471 .01865 L
.91517 .01865 L
.93625 .01865 L
.97619 .01863 L
Mistroke
Mfstroke
.292 0 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04855 L
.03416 .0511 L
.03543 .05289 L
.03665 .05417 L
.03793 .05513 L
.03908 .05572 L
.04016 .05607 L
.04135 .05629 L
.04262 .05637 L
.04393 .0563 L
.04516 .05614 L
.04586 .05601 L
.0465 .05587 L
.04793 .0555 L
.05297 .05379 L
.06244 .04985 L
.08269 .04168 L
.10458 .03465 L
.12545 .02965 L
.14465 .0262 L
.16347 .02364 L
.18413 .02156 L
.20364 .0201 L
.22456 .01895 L
.2458 .0181 L
.26592 .01752 L
.28583 .01709 L
.30425 .0168 L
.32291 .01657 L
.34352 .01639 L
.36286 .01626 L
.38372 .01617 L
.40376 .0161 L
.41384 .01607 L
.42486 .01605 L
.44447 .01602 L
.45545 .016 L
.46542 .016 L
.47027 .01599 L
.4754 .01599 L
.4846 .01598 L
.48972 .01598 L
.49451 .01598 L
.49725 .01598 L
.49976 .01598 L
.50114 .01598 L
Mistroke
.50265 .01598 L
.50409 .01598 L
.5054 .01598 L
.50662 .01598 L
.50796 .01598 L
.50931 .01598 L
.51005 .01598 L
.51073 .01598 L
.512 .01598 L
.51315 .01598 L
.51379 .01598 L
.51449 .01598 L
.51575 .01598 L
.51687 .01598 L
.51811 .01598 L
.52061 .01598 L
.52281 .01598 L
.52511 .01598 L
.52641 .01598 L
.5271 .01598 L
.52784 .01598 L
.52913 .01598 L
.53033 .01598 L
.53106 .01598 L
.53184 .01598 L
.53259 .01598 L
.53327 .01598 L
.53457 .01598 L
.53594 .01598 L
.53715 .01598 L
.53845 .01598 L
.54078 .01598 L
.54356 .01598 L
.5461 .01598 L
.5509 .01598 L
.556 .01598 L
.56516 .01598 L
.57502 .01597 L
.58591 .01597 L
.62608 .01595 L
.66474 .01593 L
.68436 .01592 L
.70585 .01592 L
.72635 .01591 L
.74544 .01591 L
.75594 .01591 L
.76587 .01591 L
.77478 .01591 L
.77977 .01591 L
.78445 .01591 L
Mistroke
.78939 .01591 L
.7939 .01591 L
.79891 .01591 L
.80168 .01591 L
.80305 .01591 L
.8043 .01591 L
.80552 .01591 L
.80683 .01591 L
.80755 .01591 L
.80821 .01591 L
.80952 .01591 L
.81064 .01591 L
.81187 .01591 L
.81316 .01591 L
.81436 .01591 L
.81504 .01591 L
.81579 .01591 L
.81713 .01591 L
.81845 .01591 L
.81966 .01591 L
.82241 .01591 L
.82534 .01591 L
.83472 .01591 L
.84482 .01591 L
.86311 .01591 L
.8735 .01591 L
.88316 .01591 L
.88804 .01591 L
.89324 .01591 L
.89622 .01591 L
.89768 .01591 L
.89902 .01591 L
.90024 .01591 L
.90154 .01591 L
.90284 .01591 L
.90358 .01591 L
.90427 .01591 L
.90552 .01591 L
.90622 .01591 L
.90685 .01591 L
.90809 .01591 L
.90925 .01591 L
.91061 .01591 L
.91186 .01591 L
.91468 .01591 L
.91698 .01591 L
.9195 .01591 L
.92457 .01591 L
.93417 .01591 L
.94311 .01591 L
Mistroke
.96043 .01591 L
.97619 .01591 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01976 L
.08259 .0186 L
.10458 .01763 L
.12517 .01695 L
.14429 .01648 L
.16481 .0161 L
.18342 .01584 L
.20266 .01564 L
.22348 .01548 L
.24342 .01537 L
.26449 .01528 L
.28413 .01522 L
.30246 .01518 L
.32281 .01515 L
.34137 .01513 L
.36045 .01511 L
.38121 .01509 L
.40099 .01508 L
.4111 .01508 L
.422 .01508 L
.43215 .01507 L
.44147 .01507 L
.4503 .01507 L
.45975 .01507 L
.46955 .01507 L
.47867 .01507 L
.48425 .01507 L
.48952 .01507 L
.49424 .01507 L
.49937 .01507 L
.50426 .01507 L
.50884 .01507 L
.51385 .01507 L
.51925 .01507 L
.52453 .01507 L
.53017 .01507 L
Mistroke
.53548 .01507 L
.54029 .01507 L
.54551 .01507 L
.55042 .01507 L
.56146 .01506 L
.58157 .01506 L
.62017 .01506 L
.63975 .01506 L
.66122 .01506 L
.68192 .01506 L
.70076 .01506 L
.72031 .01506 L
.73119 .01506 L
.74124 .01506 L
.75034 .01506 L
.76036 .01506 L
.77044 .01506 L
.77596 .01506 L
.78114 .01506 L
.78585 .01506 L
.78852 .01506 L
.791 .01506 L
.79235 .01506 L
.79362 .01506 L
.79478 .01506 L
.79601 .01506 L
.79665 .01506 L
.79735 .01506 L
.79858 .01506 L
.79927 .01506 L
.80002 .01506 L
.80072 .01506 L
.80136 .01506 L
.80251 .01506 L
.80372 .01506 L
.80476 .01506 L
.80591 .01506 L
.80847 .01506 L
.81087 .01506 L
.8152 .01506 L
.81988 .01506 L
.82943 .01506 L
.83989 .01506 L
.86099 .01506 L
.8719 .01506 L
.88221 .01506 L
.89225 .01506 L
.89666 .01506 L
.90151 .01506 L
.90621 .01506 L
Mistroke
.90846 .01506 L
.9106 .01506 L
.91176 .01506 L
.91302 .01506 L
.91418 .01506 L
.91524 .01506 L
.91649 .01506 L
.91718 .01506 L
.91783 .01506 L
.91898 .01506 L
.92023 .01506 L
.92149 .01506 L
.92268 .01506 L
.92398 .01506 L
.92537 .01506 L
.92821 .01506 L
.9308 .01506 L
.9358 .01506 L
.94053 .01506 L
.94951 .01506 L
.95906 .01506 L
.97619 .01506 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.04262 .09891 L
.06244 .16859 L
.07286 .19674 L
.08255 .21769 L
.0932 .23501 L
.09916 .24227 L
.10458 .24745 L
.10941 .25099 L
.11206 .25253 L
.11454 .25372 L
.11682 .25462 L
.11891 .25528 L
.12123 .25584 L
.12251 .25608 L
.12373 .25625 L
.12503 .25638 L
.12622 .25646 L
.12688 .25648 L
.12759 .2565 L
.12888 .25648 L
.13009 .25643 L
.13137 .25633 L
.13246 .25621 L
.13366 .25604 L
.13637 .25554 L
.13927 .25481 L
.14451 .25306 L
.15468 .24831 L
.16575 .24166 L
.18587 .2274 L
.22665 .19787 L
.24691 .18521 L
.26592 .17504 L
.28431 .16682 L
.30367 .15982 L
.32385 .15418 L
.34236 .15039 L
.3519 .14891 L
.3621 .14767 L
.36705 .1472 L
.37172 .14683 L
.37624 .14654 L
.38047 .14634 L
.3827 .14625 L
.38509 .14618 L
.38646 .14615 L
.38776 .14612 L
.38892 .14611 L
.39019 .1461 L
Mistroke
.39089 .14609 L
.39154 .14609 L
.39277 .14609 L
.39346 .14609 L
.3941 .14609 L
.39479 .1461 L
.39553 .14611 L
.39675 .14612 L
.39789 .14615 L
.40048 .14621 L
.40288 .1463 L
.40514 .1464 L
.40939 .14664 L
.41396 .147 L
.41893 .14748 L
.42836 .14875 L
.43372 .1497 L
.43874 .15075 L
.44887 .15346 L
.45977 .15747 L
.46936 .16225 L
.47985 .16928 L
.49079 .17927 L
.50096 .19144 L
.51973 .21996 L
.54006 .25053 L
.54547 .25707 L
.55119 .26296 L
.55649 .26742 L
.56144 .27072 L
.56608 .27305 L
.56868 .27406 L
.57105 .27479 L
.57364 .27539 L
.57511 .27564 L
.57647 .27582 L
.57765 .27594 L
.57896 .27602 L
.57961 .27604 L
.58032 .27605 L
.58161 .27604 L
.58286 .27599 L
.584 .27591 L
.58531 .27577 L
.58655 .27561 L
.58876 .27523 L
.59116 .2747 L
.5966 .27308 L
.60162 .27111 L
.61186 .26597 L
Mistroke
.62271 .25931 L
.66057 .23258 L
.68162 .2185 L
.70088 .20733 L
.721 .19781 L
.73967 .19113 L
.74887 .18866 L
.75867 .18666 L
.76427 .18583 L
.76702 .18552 L
.76954 .18528 L
.77184 .18511 L
.77302 .18504 L
.77428 .18498 L
.77554 .18494 L
.77672 .18491 L
.77744 .1849 L
.77812 .18489 L
.7794 .18489 L
.78054 .1849 L
.78177 .18493 L
.78293 .18497 L
.78399 .18502 L
.78646 .18519 L
.7877 .1853 L
.78906 .18543 L
.79163 .18575 L
.79438 .18618 L
.79932 .18721 L
.80429 .1886 L
.80898 .19028 L
.81775 .19453 L
.82238 .19745 L
.82748 .20126 L
.83777 .21113 L
.84731 .22314 L
.85623 .23697 L
.89508 .3175 L
.91484 .3601 L
.93637 .40025 L
.97615 .45282 L
.97619 .45285 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.04262 .09875 L
.06244 .16637 L
.07286 .19206 L
.08255 .20988 L
.08813 .21757 L
.0932 .22306 L
.096 .2255 L
.09905 .22771 L
.10171 .22927 L
.10458 .23059 L
.10712 .23147 L
.10945 .23203 L
.11057 .23223 L
.11179 .23239 L
.11295 .23249 L
.11402 .23254 L
.11467 .23255 L
.11538 .23254 L
.11666 .23249 L
.11791 .23239 L
.11905 .23225 L
.1203 .23206 L
.12166 .23179 L
.12442 .2311 L
.12967 .22924 L
.13529 .22658 L
.14545 .22044 L
.18681 .1879 L
.22665 .15879 L
.26498 .13814 L
.28476 .13028 L
.30576 .12375 L
.32524 .11917 L
.34352 .11599 L
.35335 .11469 L
.3637 .11361 L
.37254 .11292 L
.37754 .11261 L
.3822 .11239 L
.38466 .1123 L
.38725 .11222 L
.38861 .11218 L
.3901 .11215 L
.39147 .11213 L
.39273 .11211 L
.39399 .11209 L
.3952 .11208 L
.39647 .11208 L
.39719 .11208 L
Mistroke
.39786 .11208 L
.39908 .11208 L
.40018 .11209 L
.40146 .1121 L
.40266 .11212 L
.40493 .11216 L
.40732 .11222 L
.41159 .11237 L
.4162 .1126 L
.42125 .11293 L
.42651 .11338 L
.43148 .11391 L
.4408 .11519 L
.45083 .1171 L
.46172 .11999 L
.47115 .12339 L
.48154 .12846 L
.49239 .1357 L
.50256 .14466 L
.52107 .1654 L
.53156 .1775 L
.5413 .18721 L
.55101 .19457 L
.55645 .19754 L
.56138 .19952 L
.56409 .20033 L
.5666 .20091 L
.56802 .20116 L
.56934 .20136 L
.57072 .20152 L
.57146 .20158 L
.57224 .20164 L
.57356 .2017 L
.57431 .20172 L
.57499 .20173 L
.57626 .20171 L
.5769 .20169 L
.5776 .20166 L
.57881 .20158 L
.58012 .20146 L
.58249 .20117 L
.58488 .20076 L
.58744 .20023 L
.59205 .19901 L
.60251 .19525 L
.6236 .18498 L
.66506 .1626 L
.68584 .1528 L
.70501 .14516 L
.72486 .13875 L
Mistroke
.74345 .13411 L
.76219 .13072 L
.77213 .12943 L
.77767 .12886 L
.78282 .12843 L
.78771 .12812 L
.79022 .12799 L
.79293 .12787 L
.79449 .12782 L
.79591 .12778 L
.79725 .12774 L
.79872 .12772 L
.80004 .1277 L
.80127 .12769 L
.80257 .12769 L
.8033 .12769 L
.80397 .12769 L
.80521 .1277 L
.80584 .12771 L
.80654 .12771 L
.80776 .12774 L
.80891 .12776 L
.8115 .12784 L
.81429 .12796 L
.81677 .12809 L
.81939 .12827 L
.82406 .12866 L
.82907 .1292 L
.83362 .12983 L
.84382 .13171 L
.85327 .13413 L
.86219 .13711 L
.88222 .14654 L
.90068 .15873 L
.9401 .19272 L
.97619 .22464 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03562 L
.03053 .04281 L
.03279 .04866 L
.03416 .05127 L
.03543 .05312 L
.03665 .05445 L
.03793 .05547 L
.03908 .05611 L
.04016 .05651 L
.04135 .05677 L
.04262 .05689 L
.04393 .05686 L
.04516 .05673 L
.04586 .05662 L
.0465 .05649 L
.04793 .05616 L
.05297 .05451 L
.06244 .05062 L
.08269 .0424 L
.10458 .03528 L
.12545 .03018 L
.14465 .02666 L
.16347 .02404 L
.18413 .0219 L
.20364 .0204 L
.22456 .01922 L
.2458 .01835 L
.26592 .01774 L
.28583 .0173 L
.30425 .017 L
.32291 .01676 L
.34352 .01658 L
.36286 .01645 L
.38372 .01634 L
.40376 .01627 L
.41384 .01625 L
.42486 .01622 L
.43495 .0162 L
.44447 .01619 L
.45545 .01618 L
.46542 .01617 L
.47514 .01616 L
.48004 .01616 L
.48286 .01616 L
.48543 .01616 L
.48763 .01616 L
.49003 .01616 L
.49134 .01616 L
Mistroke
.49256 .01616 L
.4938 .01616 L
.49497 .01616 L
.49606 .01616 L
.49723 .01616 L
.4983 .01616 L
.49929 .01616 L
.50035 .01616 L
.50152 .01616 L
.50275 .01616 L
.50389 .01616 L
.50515 .01616 L
.5065 .01616 L
.50891 .01616 L
.51436 .01616 L
.52428 .01616 L
.52853 .01616 L
.53311 .01616 L
.53573 .01616 L
.53813 .01616 L
.53933 .01616 L
.54043 .01616 L
.54159 .01616 L
.54285 .01616 L
.54413 .01616 L
.54477 .01616 L
.54548 .01616 L
.54674 .01616 L
.54791 .01616 L
.54862 .01616 L
.5493 .01616 L
.55056 .01616 L
.5534 .01616 L
.55587 .01616 L
.55816 .01616 L
.56334 .01616 L
.57236 .01616 L
.58194 .01615 L
.61966 .01613 L
.65983 .01611 L
.69849 .01609 L
.7185 .01609 L
.7396 .01608 L
.74912 .01608 L
.75931 .01608 L
.77767 .01608 L
.7879 .01607 L
.79899 .01607 L
.81914 .01607 L
.86002 .01607 L
Mistroke
.89939 .01607 L
.93725 .01607 L
.97619 .01607 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.04262 .0989 L
.06244 .16848 L
.07286 .19636 L
.08255 .21676 L
.08802 .22591 L
.0932 .23301 L
.09916 .23941 L
.10196 .24178 L
.10458 .24364 L
.10699 .24506 L
.10919 .24611 L
.11164 .24703 L
.11299 .24742 L
.11428 .24772 L
.11551 .24794 L
.11682 .24811 L
.11806 .24821 L
.11919 .24825 L
.11988 .24825 L
.12052 .24823 L
.12121 .24819 L
.12195 .24814 L
.12319 .248 L
.12455 .24779 L
.12696 .24726 L
.12916 .24662 L
.13409 .24467 L
.13866 .24231 L
.14299 .23964 L
.18132 .20631 L
.22211 .16958 L
.24236 .15453 L
.26137 .14269 L
.27976 .13323 L
.29912 .12521 L
.3193 .11869 L
.33781 .11415 L
.34735 .11228 L
.35755 .11062 L
.36711 .10936 L
.37592 .10844 L
.38616 .10765 L
.39155 .10735 L
.39431 .10723 L
.39726 .10713 L
.39985 .10706 L
.40222 .10701 L
.40336 .10699 L
.4046 .10698 L
Mistroke
.40577 .10697 L
.40686 .10697 L
.40752 .10697 L
.40824 .10697 L
.40954 .10697 L
.41081 .10699 L
.41197 .107 L
.41324 .10702 L
.41462 .10705 L
.41742 .10712 L
.41994 .10722 L
.42267 .10734 L
.42765 .10764 L
.43249 .10802 L
.43696 .10846 L
.44712 .10983 L
.45224 .11073 L
.45789 .11194 L
.46801 .11475 L
.47728 .11827 L
.48745 .12353 L
.49815 .1311 L
.50772 .13992 L
.51793 .15125 L
.53631 .17321 L
.54658 .18388 L
.55198 .18857 L
.55769 .19272 L
.5627 .19565 L
.56535 .19693 L
.56819 .1981 L
.57081 .199 L
.57319 .19967 L
.57559 .2002 L
.57786 .20058 L
.57899 .20073 L
.58022 .20085 L
.58138 .20094 L
.58244 .201 L
.58361 .20103 L
.5849 .20104 L
.58555 .20103 L
.58624 .20101 L
.5875 .20095 L
.58818 .20091 L
.58882 .20086 L
.59026 .20072 L
.59286 .20038 L
.59523 .19997 L
.59774 .19945 L
Mistroke
.60651 .19692 L
.61616 .19315 L
.65646 .17225 L
.69526 .15299 L
.7164 .14484 L
.72613 .14178 L
.7365 .13903 L
.7469 .13684 L
.75632 .13538 L
.76087 .13488 L
.76327 .13467 L
.76579 .1345 L
.76801 .13438 L
.76927 .13433 L
.77044 .1343 L
.77152 .13427 L
.7725 .13426 L
.77364 .13426 L
.77471 .13426 L
.77585 .13428 L
.77708 .13431 L
.77824 .13436 L
.77931 .13441 L
.78178 .13457 L
.78438 .13481 L
.78692 .13511 L
.78928 .13546 L
.79464 .13652 L
.79931 .13777 L
.80355 .13921 L
.81306 .14364 L
.81792 .14665 L
.82305 .15046 L
.83226 .15907 L
.84217 .17106 L
.85306 .18741 L
.89342 .26212 L
.91201 .29268 L
.92183 .30583 L
.93227 .31718 L
.93804 .32225 L
.94327 .3261 L
.94858 .32929 L
.95346 .3316 L
.95844 .33336 L
.96106 .33405 L
.96382 .33461 L
.96498 .33479 L
.96623 .33495 L
.9673 .33506 L
Mistroke
.96847 .33516 L
.96918 .3352 L
.96984 .33523 L
.97114 .33526 L
.97231 .33526 L
.97356 .33522 L
.97422 .33519 L
.97492 .33515 L
.97619 .33505 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.03279 .05665 L
.04262 .09541 L
.04758 .11095 L
.05288 .12423 L
.05789 .13364 L
.06244 .13972 L
.06507 .14225 L
.0665 .14336 L
.06785 .14424 L
.07022 .14541 L
.07148 .14586 L
.07283 .14622 L
.07358 .14636 L
.07427 .14646 L
.07504 .14653 L
.07585 .14657 L
.07662 .14657 L
.07735 .14654 L
.07801 .14649 L
.07872 .14641 L
.07937 .14631 L
.08008 .14618 L
.08152 .14585 L
.0841 .14503 L
.08678 .14391 L
.08922 .1427 L
.09469 .13941 L
.10458 .13219 L
.14443 .10032 L
.18275 .07668 L
.20253 .06776 L
.22354 .06033 L
.24301 .05498 L
.26129 .05105 L
.28147 .04769 L
.29997 .04533 L
.3189 .04349 L
.3396 .042 L
.35921 .04099 L
.37019 .04057 L
.38016 .04026 L
.39014 .04003 L
.39934 .03987 L
.40416 .03981 L
.40945 .03976 L
.41211 .03974 L
.41358 .03973 L
.41497 .03972 L
.41626 .03972 L
Mistroke
.41767 .03971 L
.41895 .03971 L
.42014 .03971 L
.42143 .03971 L
.42208 .03971 L
.4228 .03971 L
.42406 .03971 L
.42523 .03971 L
.42663 .03972 L
.42789 .03972 L
.43074 .03974 L
.43319 .03976 L
.43586 .03978 L
.4407 .03984 L
.4454 .03991 L
.45038 .04002 L
.45932 .04026 L
.46872 .04062 L
.47883 .04115 L
.48838 .04181 L
.49713 .04259 L
.51769 .04495 L
.52771 .04618 L
.5368 .04718 L
.54137 .0476 L
.54631 .04799 L
.55058 .04826 L
.55527 .0485 L
.55784 .0486 L
.56025 .04868 L
.56279 .04874 L
.56422 .04876 L
.56552 .04878 L
.56673 .04879 L
.56784 .0488 L
.56907 .04881 L
.57037 .04881 L
.57149 .04881 L
.57255 .0488 L
.57371 .0488 L
.57496 .04878 L
.57735 .04875 L
.57991 .0487 L
.58452 .04858 L
.59 .04839 L
.59498 .04818 L
.61607 .04701 L
.65602 .04444 L
.69446 .04234 L
.71431 .04151 L
Mistroke
.73534 .04081 L
.75489 .04031 L
.7732 .03997 L
.78359 .03982 L
.79346 .0397 L
.81199 .03953 L
.83181 .03941 L
.8502 .03931 L
.86901 .03923 L
.8789 .0392 L
.88935 .03917 L
.89467 .03916 L
.89749 .03915 L
.90051 .03915 L
.90329 .03914 L
.90582 .03914 L
.90837 .03914 L
.90961 .03914 L
.91078 .03914 L
.91194 .03914 L
.91321 .03914 L
.91446 .03913 L
.91516 .03913 L
.9158 .03913 L
.91688 .03913 L
.91806 .03914 L
.9193 .03914 L
.92044 .03914 L
.92181 .03914 L
.92311 .03914 L
.92553 .03914 L
.92813 .03914 L
.93095 .03915 L
.94043 .03917 L
.94581 .03918 L
.95084 .0392 L
.97189 .03929 L
.97619 .03931 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.04262 .09857 L
.0522 .13337 L
.06244 .1629 L
.0679 .17501 L
.07286 .18379 L
.07525 .18727 L
.07784 .19049 L
.08027 .19301 L
.08255 .19495 L
.0852 .19669 L
.0866 .1974 L
.08811 .19802 L
.08887 .19826 L
.08969 .19849 L
.09042 .19865 L
.09119 .19879 L
.09196 .19888 L
.09265 .19894 L
.09335 .19897 L
.09401 .19897 L
.09529 .19889 L
.09594 .19882 L
.09665 .19871 L
.09791 .19846 L
.09909 .19815 L
.10174 .19721 L
.10458 .19586 L
.10986 .19253 L
.11475 .18869 L
.12582 .17817 L
.14594 .15635 L
.18521 .11739 L
.22296 .09064 L
.2423 .08073 L
.26316 .07237 L
.2832 .06619 L
.3043 .06123 L
.32404 .05775 L
.34241 .05531 L
.35293 .05421 L
.36287 .05333 L
.38145 .05207 L
.39118 .05159 L
.39649 .05138 L
.40147 .05121 L
.40606 .05109 L
.41026 .05099 L
.41491 .05091 L
.41748 .05087 L
Mistroke
.41992 .05084 L
.42117 .05083 L
.42252 .05082 L
.42379 .05082 L
.42497 .05081 L
.42603 .05081 L
.42719 .05081 L
.4284 .05081 L
.42953 .05081 L
.43017 .05081 L
.43086 .05081 L
.43212 .05082 L
.43334 .05083 L
.43447 .05084 L
.43704 .05086 L
.43977 .0509 L
.44428 .05099 L
.44852 .0511 L
.45316 .05125 L
.45817 .05146 L
.46776 .052 L
.4732 .05241 L
.47825 .05286 L
.48846 .05402 L
.49936 .0557 L
.52074 .06036 L
.53055 .06279 L
.54091 .06516 L
.55046 .06693 L
.55589 .06771 L
.56096 .06828 L
.56335 .06849 L
.56562 .06867 L
.56768 .0688 L
.56987 .06891 L
.571 .06896 L
.57225 .069 L
.57339 .06904 L
.57444 .06906 L
.57568 .06909 L
.57633 .0691 L
.57701 .0691 L
.57817 .06911 L
.57943 .06911 L
.58074 .0691 L
.58196 .06909 L
.58259 .06908 L
.58329 .06907 L
.5847 .06904 L
.58727 .06896 L
Mistroke
.58968 .06886 L
.59418 .06863 L
.59901 .06831 L
.60995 .06736 L
.61996 .0663 L
.65968 .06154 L
.6979 .05754 L
.71758 .05597 L
.73856 .05472 L
.74886 .05427 L
.75427 .05408 L
.75999 .05392 L
.765 .0538 L
.76765 .05376 L
.7705 .05372 L
.77184 .0537 L
.77311 .05369 L
.77435 .05368 L
.7755 .05367 L
.77658 .05367 L
.77773 .05366 L
.77889 .05366 L
.78016 .05366 L
.78138 .05367 L
.78252 .05367 L
.78376 .05368 L
.78509 .05369 L
.7878 .05372 L
.79027 .05377 L
.79503 .05388 L
.79953 .05402 L
.80474 .05425 L
.80954 .05451 L
.82039 .05534 L
.83009 .05637 L
.83916 .05761 L
.85981 .06137 L
.89865 .07009 L
.9088 .07207 L
.91984 .07385 L
.9249 .07452 L
.93028 .07512 L
.93532 .07557 L
.93995 .07591 L
.94432 .07615 L
.94652 .07624 L
.94893 .07632 L
.95136 .07638 L
.95271 .07641 L
.95395 .07643 L
Mistroke
.9551 .07644 L
.95635 .07645 L
.95754 .07645 L
.95863 .07645 L
.95964 .07644 L
.96072 .07643 L
.96175 .07642 L
.96268 .07641 L
.96497 .07637 L
.96715 .07631 L
.97147 .07616 L
.97619 .07595 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.03279 .05678 L
.04262 .09714 L
.05288 .13072 L
.06244 .15332 L
.06792 .16259 L
.07062 .16622 L
.0731 .16906 L
.07775 .17314 L
.0802 .1747 L
.08156 .1754 L
.0828 .17593 L
.08403 .17638 L
.08538 .17677 L
.08612 .17694 L
.0868 .17707 L
.0875 .17719 L
.08815 .17727 L
.08943 .17737 L
.09058 .17739 L
.09182 .17735 L
.09252 .1773 L
.09317 .17723 L
.09453 .17703 L
.09581 .17678 L
.09872 .17599 L
.10155 .17496 L
.10458 .1736 L
.11475 .16752 L
.12582 .15922 L
.14594 .14253 L
.18672 .11176 L
.20698 .09975 L
.22599 .0905 L
.24438 .08323 L
.26374 .07709 L
.28392 .07209 L
.30243 .06854 L
.32217 .06565 L
.34054 .06364 L
.35106 .06275 L
.36099 .06205 L
.36984 .06155 L
.37958 .06112 L
.3893 .06081 L
.39462 .06069 L
.39717 .06064 L
.39959 .06061 L
.40182 .06058 L
.40299 .06057 L
Mistroke
.40424 .06056 L
.4054 .06055 L
.40645 .06054 L
.4075 .06054 L
.40849 .06054 L
.40966 .06054 L
.41088 .06054 L
.41193 .06054 L
.41308 .06054 L
.41432 .06055 L
.41565 .06056 L
.41805 .06058 L
.42062 .06061 L
.42335 .06065 L
.42825 .06076 L
.43352 .06092 L
.43933 .06115 L
.44433 .0614 L
.44972 .06172 L
.45946 .06249 L
.46906 .06354 L
.47954 .06509 L
.49048 .06732 L
.50065 .07006 L
.51943 .07664 L
.5293 .0803 L
.53975 .08367 L
.54506 .08505 L
.55088 .08626 L
.55344 .08668 L
.55618 .08707 L
.55876 .08737 L
.56114 .0876 L
.56373 .08779 L
.56509 .08786 L
.56655 .08792 L
.56781 .08796 L
.56899 .08799 L
.57028 .08801 L
.57101 .08801 L
.57168 .08801 L
.57284 .088 L
.57392 .08799 L
.5751 .08796 L
.57636 .08792 L
.57895 .08781 L
.5813 .08767 L
.58614 .0873 L
.59127 .08677 L
.60046 .08557 L
Mistroke
.62125 .0821 L
.6591 .07526 L
.68016 .07191 L
.69941 .06931 L
.71953 .06709 L
.7382 .06546 L
.7572 .06419 L
.76788 .06364 L
.77793 .06321 L
.7878 .06287 L
.79847 .06259 L
.80817 .0624 L
.81708 .06227 L
.82179 .06222 L
.82438 .0622 L
.82683 .06218 L
.82911 .06216 L
.83159 .06215 L
.83384 .06214 L
.83493 .06214 L
.83592 .06214 L
.8371 .06213 L
.83838 .06213 L
.8395 .06213 L
.84069 .06213 L
.84199 .06213 L
.8432 .06213 L
.8439 .06214 L
.84453 .06214 L
.84595 .06214 L
.84857 .06215 L
.85142 .06217 L
.85411 .06219 L
.85659 .06221 L
.86127 .06226 L
.86629 .06233 L
.87537 .06251 L
.88616 .0628 L
.89601 .06314 L
.91505 .06401 L
.93579 .06522 L
.97619 .068 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.04262 .09869 L
.0522 .13412 L
.06244 .16558 L
.07286 .19027 L
.07751 .19889 L
.08255 .2066 L
.08564 .21049 L
.08848 .21353 L
.09115 .21593 L
.09409 .21808 L
.09672 .21958 L
.09918 .22064 L
.10054 .22109 L
.10178 .22142 L
.10247 .22157 L
.10322 .22171 L
.10388 .2218 L
.10458 .22188 L
.10521 .22194 L
.10591 .22197 L
.10713 .22199 L
.10782 .22196 L
.10856 .22192 L
.10926 .22185 L
.10989 .22178 L
.11112 .22158 L
.11246 .2213 L
.1149 .22062 L
.11725 .21976 L
.11976 .21865 L
.12425 .2162 L
.13422 .20908 L
.14523 .19939 L
.18543 .16006 L
.22412 .12855 L
.24416 .11604 L
.26526 .10546 L
.28522 .09758 L
.30336 .09194 L
.32297 .08721 L
.34393 .08347 L
.36311 .08104 L
.37393 .08004 L
.38391 .07933 L
.38858 .07907 L
.3936 .07884 L
.39834 .07867 L
.40267 .07855 L
.4053 .0785 L
Mistroke
.40774 .07846 L
.40914 .07845 L
.41041 .07844 L
.41112 .07843 L
.41188 .07843 L
.4126 .07843 L
.41326 .07843 L
.41447 .07843 L
.41559 .07843 L
.41683 .07844 L
.41815 .07845 L
.41954 .07846 L
.42085 .07848 L
.42331 .07853 L
.42569 .07859 L
.42791 .07865 L
.43299 .07885 L
.43794 .07911 L
.44326 .07947 L
.45288 .08037 L
.46169 .08152 L
.47152 .08328 L
.48065 .0855 L
.49068 .08879 L
.50137 .09353 L
.52132 .10576 L
.53182 .11292 L
.54292 .11972 L
.55285 .12443 L
.55849 .1264 L
.5612 .12717 L
.56376 .12778 L
.56608 .12825 L
.5686 .12866 L
.5709 .12895 L
.57302 .12915 L
.5742 .12924 L
.57531 .1293 L
.57652 .12935 L
.57783 .12938 L
.57913 .12939 L
.57979 .12939 L
.5805 .12938 L
.58177 .12935 L
.58295 .1293 L
.58422 .12923 L
.58557 .12914 L
.58799 .12893 L
.59059 .12864 L
.59346 .12824 L
Mistroke
.60338 .12638 L
.62197 .12144 L
.66227 .10883 L
.70106 .09858 L
.72221 .09447 L
.73194 .09296 L
.74231 .09163 L
.74766 .09106 L
.75271 .09059 L
.75762 .09022 L
.76213 .08993 L
.76643 .08973 L
.76859 .08965 L
.77097 .08958 L
.77222 .08955 L
.77335 .08953 L
.77467 .08952 L
.77591 .08951 L
.77706 .08951 L
.77812 .08951 L
.77928 .08952 L
.78052 .08953 L
.78166 .08955 L
.78291 .08958 L
.78542 .08966 L
.78774 .08977 L
.7899 .08989 L
.79479 .09026 L
.80001 .09082 L
.80494 .09153 L
.80959 .09237 L
.81829 .09445 L
.82802 .09771 L
.83832 .10236 L
.85678 .11411 L
.89469 .14832 L
.91578 .16738 L
.93505 .18113 L
.94458 .18623 L
.94962 .18843 L
.95498 .19042 L
.96013 .19199 L
.96479 .19313 L
.96948 .19402 L
.97389 .19463 L
.97619 .19487 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.02846 .03631 L
.03279 .05264 L
.03527 .05985 L
.03754 .06502 L
.03879 .06735 L
.04015 .06949 L
.04142 .07115 L
.04262 .07244 L
.04386 .07354 L
.045 .07434 L
.04626 .07504 L
.04697 .07535 L
.04762 .07559 L
.04892 .07594 L
.04961 .07607 L
.05034 .07616 L
.05104 .07621 L
.0517 .07622 L
.05293 .07618 L
.05408 .07607 L
.05531 .07588 L
.05635 .07566 L
.0575 .07537 L
.06244 .07371 L
.07296 .06886 L
.08424 .06311 L
.10458 .0534 L
.12439 .04559 L
.14594 .03895 L
.16664 .03411 L
.18579 .0307 L
.20445 .02814 L
.22505 .02599 L
.2444 .02448 L
.26526 .02326 L
.2853 .02239 L
.3064 .02171 L
.32614 .02125 L
.3445 .02093 L
.36496 .02067 L
.38355 .0205 L
.39353 .02043 L
.40273 .02038 L
.41284 .02033 L
.41842 .02031 L
.42353 .0203 L
.42805 .02029 L
.43297 .02028 L
.43567 .02028 L
Mistroke
.43817 .02027 L
.44056 .02027 L
.44189 .02027 L
.44311 .02027 L
.44426 .02027 L
.44549 .02027 L
.44671 .02027 L
.44741 .02027 L
.44806 .02027 L
.44923 .02027 L
.45031 .02027 L
.45154 .02027 L
.45272 .02027 L
.45488 .02027 L
.45689 .02027 L
.46142 .02028 L
.46384 .02028 L
.46607 .02029 L
.47107 .0203 L
.48012 .02033 L
.49017 .02038 L
.50074 .02045 L
.52074 .02061 L
.52946 .02067 L
.5389 .02073 L
.54416 .02076 L
.54901 .02078 L
.55365 .02079 L
.55598 .0208 L
.55855 .0208 L
.55995 .0208 L
.56128 .02081 L
.56248 .02081 L
.56378 .02081 L
.56445 .02081 L
.56519 .02081 L
.56596 .02081 L
.56669 .02081 L
.56799 .02081 L
.56871 .02081 L
.56938 .02081 L
.5706 .02081 L
.57174 .02081 L
.57432 .0208 L
.57683 .0208 L
.57951 .02079 L
.58483 .02078 L
.58974 .02076 L
.60083 .02072 L
.62098 .02062 L
Mistroke
.66035 .02042 L
.6982 .02026 L
.71763 .02019 L
.73851 .02014 L
.74862 .02012 L
.75966 .0201 L
.7702 .02009 L
.77975 .02007 L
.79944 .02006 L
.81025 .02005 L
.82042 .02005 L
.85899 .02003 L
.90001 .02001 L
.92045 .02 L
.93952 .01999 L
.95722 .01999 L
.97619 .01998 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.03279 .05639 L
.03793 .07693 L
.04262 .09237 L
.04758 .10485 L
.0503 .10999 L
.05288 .11379 L
.05527 .11645 L
.05747 .11824 L
.05862 .11895 L
.05988 .11956 L
.06121 .12002 L
.06244 .1203 L
.0631 .1204 L
.06379 .12046 L
.06504 .12048 L
.06581 .12043 L
.06653 .12035 L
.06718 .12025 L
.06788 .12011 L
.06919 .11977 L
.07057 .11932 L
.07305 .11828 L
.07767 .11573 L
.08274 .1123 L
.10458 .09489 L
.12572 .07897 L
.145 .06691 L
.16521 .05683 L
.18391 .04953 L
.203 .04371 L
.22376 .03888 L
.24242 .03557 L
.26302 .0328 L
.28237 .03085 L
.30323 .02927 L
.32327 .02815 L
.34437 .0273 L
.36411 .02672 L
.38248 .02634 L
.393 .02617 L
.40293 .02605 L
.41185 .02597 L
.41685 .02593 L
.42152 .0259 L
.42608 .02588 L
.43099 .02586 L
.43378 .02585 L
.43515 .02585 L
.43643 .02585 L
Mistroke
.43758 .02584 L
.4388 .02584 L
.43951 .02584 L
.44016 .02584 L
.4414 .02584 L
.44262 .02584 L
.44331 .02584 L
.44396 .02584 L
.44527 .02584 L
.446 .02584 L
.44667 .02584 L
.44916 .02585 L
.45151 .02586 L
.45423 .02586 L
.45675 .02587 L
.46244 .02591 L
.46709 .02594 L
.47209 .02599 L
.48114 .02609 L
.4919 .02627 L
.50176 .02648 L
.52233 .027 L
.53234 .02724 L
.54143 .02742 L
.546 .02749 L
.55094 .02755 L
.5532 .02757 L
.5556 .02759 L
.55785 .02761 L
.5599 .02762 L
.56224 .02763 L
.56353 .02763 L
.56475 .02764 L
.56588 .02764 L
.56692 .02764 L
.56807 .02764 L
.56928 .02764 L
.5705 .02764 L
.57181 .02763 L
.57305 .02763 L
.57418 .02763 L
.57682 .02762 L
.5796 .0276 L
.58459 .02757 L
.58912 .02753 L
.59931 .02741 L
.61767 .02715 L
.65762 .02653 L
.69606 .02603 L
.71591 .02583 L
Mistroke
.73694 .02567 L
.75649 .02555 L
.7748 .02547 L
.78519 .02543 L
.79506 .02541 L
.81359 .02537 L
.82318 .02536 L
.83341 .02534 L
.8518 .02532 L
.8934 .02526 L
.93349 .02519 L
.97206 .02512 L
.97619 .02511 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.03279 .05651 L
.04262 .09362 L
.04758 .10715 L
.05035 .11304 L
.05288 .11735 L
.05524 .1205 L
.05648 .12185 L
.0578 .12306 L
.05895 .12393 L
.06021 .12471 L
.06137 .12526 L
.06244 .12565 L
.0631 .12582 L
.06379 .12597 L
.06504 .12612 L
.06581 .12614 L
.06653 .12612 L
.06718 .12607 L
.06788 .12598 L
.06919 .12571 L
.06985 .12554 L
.07057 .12531 L
.07305 .12434 L
.07547 .12309 L
.07806 .12151 L
.08274 .11816 L
.10458 .09927 L
.12439 .08287 L
.14594 .06815 L
.16664 .05712 L
.18579 .04922 L
.20445 .04324 L
.22505 .03821 L
.2444 .03464 L
.26526 .03175 L
.2853 .02968 L
.3064 .02807 L
.32614 .02696 L
.3445 .02619 L
.36496 .02557 L
.38355 .02516 L
.39353 .02499 L
.40273 .02487 L
.41284 .02476 L
.41842 .02471 L
.42353 .02467 L
.42805 .02464 L
.43297 .02462 L
.43567 .02461 L
Mistroke
.43817 .0246 L
.44071 .02459 L
.44196 .02459 L
.44311 .02459 L
.44417 .02459 L
.44534 .02459 L
.44652 .02459 L
.44776 .02459 L
.44881 .02458 L
.44994 .02458 L
.45101 .02459 L
.45198 .02459 L
.45318 .02459 L
.4543 .02459 L
.45553 .02459 L
.45683 .02459 L
.45901 .0246 L
.46142 .0246 L
.46635 .02462 L
.47154 .02465 L
.4808 .02473 L
.49078 .02484 L
.50167 .025 L
.52297 .02538 L
.53302 .02555 L
.54229 .02567 L
.54698 .02572 L
.55195 .02576 L
.55453 .02577 L
.55693 .02578 L
.55829 .02579 L
.55958 .02579 L
.56029 .02579 L
.56106 .02579 L
.56171 .02579 L
.56241 .0258 L
.56358 .0258 L
.56468 .0258 L
.56599 .0258 L
.56719 .0258 L
.56837 .02579 L
.56966 .02579 L
.57101 .02579 L
.57226 .02579 L
.57667 .02577 L
.58138 .02574 L
.59161 .02567 L
.60271 .02556 L
.62285 .02532 L
.66374 .02483 L
Mistroke
.68407 .02462 L
.70311 .02446 L
.72252 .02432 L
.74096 .02422 L
.76122 .02414 L
.77975 .02408 L
.78935 .02406 L
.79957 .02405 L
.80922 .02403 L
.81797 .02402 L
.83723 .02401 L
.85805 .024 L
.87801 .02398 L
.89908 .02396 L
.93707 .0239 L
.97619 .02383 L
Mfstroke
.601 0 1 r
.02381 .01472 m
.03279 .05623 L
.03793 .07606 L
.04262 .09001 L
.04517 .09575 L
.04758 .09995 L
.05012 .10318 L
.05156 .1045 L
.05288 .10543 L
.05402 .10603 L
.05509 .10643 L
.05626 .10671 L
.05752 .10683 L
.05884 .1068 L
.06009 .10662 L
.06122 .10635 L
.06244 .10596 L
.0653 .10471 L
.06799 .10318 L
.07302 .09972 L
.08429 .09066 L
.10458 .07453 L
.12296 .06223 L
.14313 .05154 L
.16307 .04346 L
.18413 .03704 L
.20364 .0326 L
.22456 .02905 L
.2458 .0264 L
.26592 .02455 L
.28583 .0232 L
.30425 .02226 L
.32291 .02154 L
.34352 .02096 L
.36286 .02056 L
.37282 .02039 L
.38372 .02024 L
.40376 .02004 L
.41469 .01995 L
.42486 .01989 L
.43538 .01984 L
.44055 .01982 L
.44532 .01981 L
.44956 .0198 L
.45423 .01979 L
.4565 .01978 L
.45893 .01978 L
.46027 .01978 L
.4615 .01978 L
.46266 .01978 L
Mistroke
.4639 .01978 L
.4652 .01978 L
.46641 .01978 L
.4676 .01978 L
.46868 .01978 L
.46987 .01978 L
.47116 .01978 L
.47181 .01978 L
.47251 .01978 L
.47377 .01978 L
.47624 .01978 L
.47856 .01978 L
.48293 .01979 L
.48809 .0198 L
.49287 .01981 L
.50366 .01985 L
.52396 .01994 L
.53389 .01997 L
.53823 .01999 L
.54298 .02 L
.54521 .02 L
.54758 .02001 L
.54963 .02001 L
.55186 .02001 L
.55317 .02001 L
.55437 .02001 L
.55553 .02001 L
.55675 .02001 L
.55784 .02001 L
.55886 .02001 L
.55998 .02001 L
.56119 .02001 L
.56249 .02001 L
.56371 .02001 L
.56645 .02001 L
.56886 .02001 L
.57143 .02 L
.58079 .01998 L
.59014 .01996 L
.60023 .01992 L
.6185 .01985 L
.65961 .01969 L
.68011 .01962 L
.6992 .01957 L
.71878 .01952 L
.73728 .01949 L
.74708 .01948 L
.75771 .01947 L
.77629 .01945 L
.78574 .01945 L
Mistroke
.79614 .01944 L
.80138 .01944 L
.80701 .01944 L
.81228 .01944 L
.81718 .01943 L
.82208 .01943 L
.82729 .01943 L
.83308 .01943 L
.83833 .01943 L
.8488 .01943 L
.85339 .01943 L
.85842 .01943 L
.86779 .01943 L
.87291 .01943 L
.87768 .01943 L
.88774 .01943 L
.89851 .01942 L
.91977 .01942 L
.93989 .01941 L
.97619 .01939 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.04262 .09859 L
.0522 .1335 L
.06244 .16338 L
.0679 .17585 L
.07286 .18508 L
.07784 .19235 L
.08255 .19745 L
.08522 .19961 L
.08805 .20137 L
.09046 .20245 L
.09183 .2029 L
.09312 .20323 L
.09382 .20336 L
.09459 .20348 L
.09532 .20356 L
.096 .20361 L
.09728 .20363 L
.09799 .20361 L
.09864 .20357 L
.0994 .20349 L
.10011 .20339 L
.1017 .20309 L
.1031 .20273 L
.10458 .20227 L
.10954 .20009 L
.11406 .19741 L
.12422 .18959 L
.14255 .1721 L
.1824 .13396 L
.22073 .10625 L
.2405 .0957 L
.26151 .08684 L
.28098 .08045 L
.29926 .07577 L
.31944 .0718 L
.33795 .06907 L
.35687 .06703 L
.36759 .06616 L
.37757 .06553 L
.38262 .06527 L
.38809 .06503 L
.39292 .06485 L
.39803 .06471 L
.40263 .06461 L
.40525 .06456 L
.4077 .06453 L
.40885 .06452 L
.40995 .06451 L
.41093 .06451 L
Mistroke
.412 .0645 L
.41316 .0645 L
.41439 .06449 L
.41556 .0645 L
.41662 .0645 L
.41782 .0645 L
.41895 .06451 L
.42018 .06452 L
.42151 .06453 L
.42421 .06457 L
.42667 .06461 L
.43141 .06473 L
.4359 .06487 L
.44109 .06509 L
.44589 .06535 L
.45111 .06569 L
.45673 .06614 L
.46639 .06715 L
.47544 .06844 L
.4862 .07051 L
.49605 .07304 L
.51502 .07974 L
.52587 .08414 L
.53573 .08783 L
.54059 .0894 L
.54584 .09086 L
.55039 .09189 L
.55538 .09278 L
.55812 .09316 L
.56068 .09344 L
.56339 .09367 L
.56491 .09377 L
.56629 .09384 L
.56758 .09389 L
.56876 .09392 L
.57007 .09395 L
.57072 .09395 L
.57145 .09395 L
.57266 .09395 L
.57397 .09393 L
.57521 .0939 L
.57634 .09386 L
.57882 .09375 L
.58107 .09361 L
.58613 .09318 L
.59082 .09266 L
.59524 .09207 L
.61593 .0885 L
.65437 .08081 L
.67383 .07728 L
Mistroke
.69526 .07397 L
.71582 .07141 L
.73463 .06958 L
.75405 .06817 L
.76476 .06759 L
.77493 .06717 L
.78453 .06688 L
.78989 .06676 L
.79243 .06671 L
.79475 .06668 L
.79692 .06665 L
.79931 .06663 L
.8017 .06661 L
.80301 .06661 L
.80423 .0666 L
.80538 .0666 L
.80648 .0666 L
.80746 .0666 L
.80853 .0666 L
.8097 .0666 L
.81093 .06661 L
.81198 .06661 L
.81315 .06662 L
.8155 .06664 L
.81807 .06668 L
.82325 .06677 L
.82805 .06689 L
.83251 .06703 L
.8426 .06747 L
.84824 .06779 L
.85337 .06814 L
.87257 .06996 L
.88339 .07135 L
.89337 .07287 L
.93279 .08051 L
.9707 .08832 L
.97619 .08934 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.02605 .02534 L
.02846 .03496 L
.02962 .03866 L
.03072 .04152 L
.0317 .04357 L
.03279 .04534 L
.03398 .04677 L
.03524 .04782 L
.03641 .04845 L
.0375 .04882 L
.03879 .04903 L
.03997 .04907 L
.04062 .04904 L
.04132 .04898 L
.04262 .04879 L
.04396 .04851 L
.04523 .0482 L
.04759 .0475 L
.0529 .04568 L
.06244 .04217 L
.08439 .03499 L
.10458 .02993 L
.12333 .02637 L
.14313 .02355 L
.16277 .02146 L
.1811 .02 L
.20145 .0188 L
.22001 .01798 L
.2391 .01735 L
.25986 .01685 L
.27963 .0165 L
.30064 .01622 L
.32011 .01604 L
.33839 .01591 L
.35857 .0158 L
.37708 .01573 L
.396 .01568 L
.4167 .01564 L
.43631 .01561 L
.44729 .0156 L
.45726 .01559 L
.46658 .01558 L
.47645 .01558 L
.48727 .01557 L
.49248 .01557 L
.49724 .01557 L
.50668 .01557 L
.51682 .01556 L
.53513 .01556 L
Mistroke
.55415 .01556 L
.56491 .01556 L
.57489 .01555 L
.61407 .01554 L
.63409 .01554 L
.65571 .01553 L
.67485 .01553 L
.69583 .01553 L
.7158 .01552 L
.72684 .01552 L
.73688 .01552 L
.74625 .01552 L
.75643 .01552 L
.76718 .01552 L
.77244 .01552 L
.77736 .01552 L
.78228 .01552 L
.78678 .01552 L
.79179 .01552 L
.79441 .01552 L
.79717 .01552 L
.79969 .01552 L
.80107 .01552 L
.80238 .01552 L
.8036 .01552 L
.80492 .01552 L
.80611 .01552 L
.80722 .01552 L
.80853 .01552 L
.80976 .01552 L
.81046 .01552 L
.81111 .01552 L
.81185 .01552 L
.81255 .01552 L
.81395 .01552 L
.81525 .01552 L
.81819 .01552 L
.82282 .01552 L
.8278 .01552 L
.83683 .01552 L
.85743 .01552 L
.86779 .01552 L
.87744 .01552 L
.88231 .01552 L
.88503 .01552 L
.88751 .01552 L
.88893 .01552 L
.89023 .01552 L
.89097 .01552 L
.89166 .01552 L
Mistroke
.89238 .01552 L
.89318 .01552 L
.89387 .01552 L
.89453 .01552 L
.89576 .01552 L
.89645 .01552 L
.89709 .01552 L
.89853 .01552 L
.89982 .01552 L
.90118 .01552 L
.90362 .01552 L
.90624 .01552 L
.90911 .01552 L
.91426 .01552 L
.91907 .01552 L
.92806 .01552 L
.93768 .01552 L
.95746 .01552 L
.97619 .01552 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.03279 .05634 L
.03793 .07652 L
.04262 .09104 L
.04517 .09714 L
.04758 .10169 L
.05012 .10526 L
.05156 .10676 L
.05288 .10783 L
.05402 .10853 L
.05509 .10902 L
.05626 .10937 L
.05752 .10957 L
.05884 .10959 L
.06009 .10946 L
.06122 .10922 L
.06244 .10884 L
.06382 .1083 L
.0653 .10758 L
.06799 .10602 L
.07302 .10241 L
.08429 .09289 L
.10458 .07592 L
.12413 .06231 L
.14558 .05072 L
.166 .04242 L
.18507 .03656 L
.20542 .03186 L
.22398 .02863 L
.24306 .02612 L
.26382 .02409 L
.2836 .02266 L
.30461 .02154 L
.32408 .02078 L
.34236 .02025 L
.36254 .01981 L
.38104 .01951 L
.39997 .01929 L
.41069 .0192 L
.42067 .01912 L
.43119 .01906 L
.44113 .01902 L
.45005 .01899 L
.45504 .01897 L
.45971 .01896 L
.46428 .01895 L
.46662 .01895 L
.46918 .01895 L
.47063 .01894 L
.47197 .01894 L
Mistroke
.47336 .01894 L
.47462 .01894 L
.47586 .01894 L
.47703 .01894 L
.47826 .01894 L
.47895 .01894 L
.47959 .01894 L
.48081 .01894 L
.48212 .01894 L
.48335 .01894 L
.48447 .01894 L
.48579 .01894 L
.48723 .01894 L
.48983 .01895 L
.49255 .01895 L
.49544 .01895 L
.50063 .01896 L
.52037 .019 L
.529 .01903 L
.53844 .01904 L
.54333 .01905 L
.54568 .01905 L
.54789 .01906 L
.5491 .01906 L
.55041 .01906 L
.55149 .01906 L
.55269 .01906 L
.55399 .01906 L
.5547 .01906 L
.55536 .01906 L
.55655 .01906 L
.55782 .01906 L
.5585 .01906 L
.55921 .01906 L
.5605 .01906 L
.56122 .01906 L
.56189 .01906 L
.56342 .01906 L
.56598 .01906 L
.56873 .01905 L
.57393 .01905 L
.57869 .01904 L
.59759 .01899 L
.61828 .01893 L
.65881 .01881 L
.69782 .01872 L
.71915 .01868 L
.73929 .01865 L
.749 .01864 L
.75928 .01864 L
Mistroke
.77772 .01862 L
.78714 .01862 L
.79727 .01862 L
.80684 .01861 L
.81558 .01861 L
.82478 .01861 L
.83458 .01861 L
.84533 .01861 L
.85531 .01861 L
.87673 .01861 L
.89691 .01861 L
.90668 .0186 L
.917 .0186 L
.92581 .0186 L
.93548 .0186 L
.955 .0186 L
.97592 .01859 L
.97619 .01859 L
Mfstroke
.696 0 1 r
.02381 .01472 m
.04262 .09865 L
.0522 .13385 L
.06244 .16453 L
.0679 .17762 L
.07286 .18751 L
.0779 .19557 L
.08255 .20127 L
.08519 .20377 L
.08798 .20587 L
.09079 .20743 L
.09238 .20809 L
.09388 .20855 L
.09454 .20871 L
.09526 .20886 L
.09657 .20904 L
.09785 .20912 L
.09903 .20912 L
.09976 .20907 L
.10044 .20901 L
.10172 .20882 L
.10243 .20868 L
.10309 .20853 L
.10458 .20811 L
.10704 .2072 L
.10928 .20615 L
.11432 .2031 L
.1234 .19571 L
.14407 .17408 L
.18391 .13191 L
.22224 .10164 L
.24202 .09022 L
.26302 .08069 L
.2825 .07384 L
.30077 .06882 L
.32096 .06456 L
.33946 .06162 L
.35839 .05938 L
.36911 .05841 L
.37909 .05767 L
.38961 .05706 L
.39478 .05682 L
.39954 .05663 L
.40379 .05648 L
.40846 .05635 L
.41316 .05625 L
.41573 .05621 L
.41813 .05618 L
.41938 .05617 L
.42072 .05615 L
Mistroke
.42197 .05615 L
.42311 .05614 L
.42381 .05614 L
.42446 .05614 L
.42516 .05613 L
.42591 .05613 L
.42716 .05613 L
.42787 .05614 L
.42854 .05614 L
.42982 .05614 L
.43104 .05615 L
.43331 .05617 L
.43576 .0562 L
.43842 .05625 L
.44309 .05636 L
.44805 .05652 L
.45229 .05669 L
.45696 .05692 L
.46708 .05761 L
.47634 .05851 L
.48651 .05986 L
.49721 .06179 L
.50678 .06403 L
.51699 .0669 L
.53537 .07246 L
.54564 .07512 L
.55104 .07626 L
.55676 .07723 L
.56176 .07788 L
.5646 .07816 L
.56726 .07837 L
.56969 .07852 L
.57192 .07862 L
.57315 .07866 L
.5738 .07868 L
.57449 .0787 L
.57575 .07872 L
.57692 .07873 L
.57806 .07873 L
.5793 .07872 L
.58059 .07871 L
.5818 .07868 L
.58293 .07865 L
.58396 .07862 L
.58628 .07853 L
.58877 .07839 L
.59147 .07822 L
.59637 .07782 L
.60587 .07682 L
.61464 .07568 L
Mistroke
.65401 .06961 L
.69187 .06434 L
.71129 .06223 L
.73217 .06044 L
.74229 .05976 L
.75332 .05915 L
.76375 .0587 L
.77342 .05839 L
.7785 .05828 L
.78117 .05823 L
.784 .05819 L
.78647 .05816 L
.78787 .05815 L
.78918 .05814 L
.79039 .05814 L
.79149 .05814 L
.79276 .05813 L
.79396 .05813 L
.79502 .05814 L
.7962 .05814 L
.79743 .05815 L
.79859 .05815 L
.80065 .05817 L
.80287 .0582 L
.80534 .05824 L
.80793 .0583 L
.81257 .05842 L
.81757 .0586 L
.82212 .05881 L
.83232 .05945 L
.84178 .06026 L
.8507 .06125 L
.87072 .06422 L
.88918 .06769 L
.90955 .07177 L
.9286 .07513 L
.93798 .07646 L
.94688 .07749 L
.95179 .07794 L
.95714 .07835 L
.96201 .07865 L
.96651 .07885 L
.96913 .07894 L
.97159 .07901 L
.9738 .07906 L
.97505 .07908 L
.97619 .07909 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.04262 .09859 L
.0522 .13353 L
.06244 .16353 L
.0679 .17612 L
.07286 .1855 L
.07784 .19296 L
.08255 .19827 L
.08522 .20056 L
.08805 .20246 L
.09046 .20366 L
.09183 .20418 L
.09312 .20457 L
.09382 .20474 L
.09459 .2049 L
.09532 .20501 L
.096 .20509 L
.09728 .20518 L
.09799 .20519 L
.09864 .20518 L
.0994 .20514 L
.10011 .20507 L
.10088 .20498 L
.1017 .20485 L
.10307 .20456 L
.10458 .20415 L
.10709 .20326 L
.10982 .20203 L
.11478 .19918 L
.12409 .19218 L
.145 .17224 L
.18579 .13315 L
.20604 .11734 L
.22505 .10504 L
.24344 .09532 L
.2628 .08709 L
.28299 .08036 L
.30149 .07556 L
.32123 .07163 L
.3396 .06887 L
.35012 .06763 L
.36006 .06665 L
.36891 .06593 L
.37864 .06529 L
.38837 .0648 L
.39368 .06459 L
.39866 .06443 L
.40331 .06432 L
.40755 .06425 L
.4099 .06422 L
Mistroke
.41123 .06421 L
.41246 .0642 L
.41364 .06419 L
.41471 .06419 L
.41595 .06419 L
.41711 .06419 L
.41828 .06419 L
.41953 .06419 L
.42071 .0642 L
.42178 .06421 L
.42441 .06424 L
.4269 .06427 L
.42947 .06432 L
.43185 .06438 L
.43723 .06455 L
.44149 .06473 L
.4462 .06497 L
.45571 .06563 L
.46065 .06607 L
.46583 .06663 L
.4751 .06789 L
.48507 .06974 L
.49597 .07247 L
.50627 .07585 L
.51562 .07951 L
.52653 .0841 L
.53658 .08808 L
.54593 .09113 L
.55069 .09237 L
.5558 .09343 L
.55849 .09387 L
.56093 .09421 L
.56342 .0945 L
.56572 .0947 L
.5684 .09488 L
.56981 .09495 L
.57053 .09498 L
.57131 .095 L
.57261 .09503 L
.57383 .09505 L
.57454 .09505 L
.57528 .09505 L
.57592 .09504 L
.57662 .09503 L
.57793 .09501 L
.57915 .09497 L
.58048 .09492 L
.58189 .09485 L
.58426 .0947 L
.58687 .0945 L
Mistroke
.5962 .09346 L
.60702 .0918 L
.61714 .08995 L
.65594 .0821 L
.67566 .07843 L
.69718 .07502 L
.71802 .07237 L
.73691 .07053 L
.74637 .06981 L
.7566 .06918 L
.76223 .0689 L
.7674 .06868 L
.77235 .06852 L
.77503 .06845 L
.77757 .06839 L
.77995 .06834 L
.78121 .06833 L
.78254 .06831 L
.78366 .0683 L
.78489 .06829 L
.78601 .06828 L
.78706 .06827 L
.78831 .06827 L
.78962 .06827 L
.79073 .06827 L
.79196 .06828 L
.79328 .06829 L
.79469 .0683 L
.79723 .06834 L
.7996 .06839 L
.80217 .06845 L
.80684 .06861 L
.81138 .06882 L
.81557 .06906 L
.82527 .06984 L
.83434 .07085 L
.8443 .07235 L
.85499 .07444 L
.87618 .08013 L
.89629 .08718 L
.93455 .102 L
.97527 .11388 L
.97619 .11407 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01857 L
.10458 .01759 L
.12517 .01691 L
.14429 .01644 L
.16481 .01607 L
.18342 .01581 L
.20266 .01561 L
.22348 .01545 L
.24342 .01534 L
.26449 .01526 L
.28413 .0152 L
.30246 .01516 L
.32281 .01512 L
.34137 .0151 L
.36045 .01508 L
.38121 .01507 L
.40099 .01506 L
.4111 .01505 L
.422 .01505 L
.43215 .01505 L
.44147 .01505 L
.45975 .01504 L
.46955 .01504 L
.47867 .01504 L
.48868 .01504 L
.49428 .01504 L
.49937 .01504 L
.50935 .01504 L
.51856 .01504 L
.5293 .01504 L
.53935 .01504 L
.5484 .01504 L
.55812 .01504 L
.57876 .01504 L
.62003 .01504 L
Mistroke
.64066 .01503 L
.65979 .01503 L
.6795 .01503 L
.69804 .01503 L
.7186 .01503 L
.73722 .01503 L
.74701 .01503 L
.75734 .01503 L
.76616 .01503 L
.77079 .01503 L
.77582 .01503 L
.78108 .01503 L
.78349 .01503 L
.78605 .01503 L
.78836 .01503 L
.7909 .01503 L
.79201 .01503 L
.79321 .01503 L
.79425 .01503 L
.79537 .01503 L
.79669 .01503 L
.79792 .01503 L
.79867 .01503 L
.79937 .01503 L
.8007 .01503 L
.80138 .01503 L
.8021 .01503 L
.80338 .01503 L
.80477 .01503 L
.8063 .01503 L
.80879 .01503 L
.81147 .01503 L
.8163 .01503 L
.82646 .01503 L
.83751 .01503 L
.85763 .01503 L
.87699 .01503 L
.88229 .01503 L
.88802 .01503 L
.89342 .01503 L
.89582 .01503 L
.89838 .01503 L
.90085 .01503 L
.9031 .01503 L
.90418 .01503 L
.90536 .01503 L
.90647 .01503 L
.9075 .01503 L
.90869 .01503 L
.90981 .01503 L
Mistroke
.91103 .01503 L
.91235 .01503 L
.913 .01503 L
.91372 .01503 L
.91503 .01503 L
.91748 .01503 L
.92013 .01503 L
.92254 .01503 L
.92792 .01503 L
.93291 .01503 L
.93761 .01503 L
.95771 .01503 L
.97618 .01503 L
.97619 .01503 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.03279 .05686 L
.04262 .09739 L
.04758 .11441 L
.05288 .12929 L
.05546 .13514 L
.05789 .13981 L
.06024 .14354 L
.06244 .14633 L
.06487 .14865 L
.06616 .14958 L
.06754 .15036 L
.06824 .15067 L
.06899 .15094 L
.0697 .15114 L
.07037 .15128 L
.07162 .15143 L
.07232 .15144 L
.07295 .15142 L
.0742 .15126 L
.07535 .15101 L
.07661 .15061 L
.07794 .15007 L
.08019 .1489 L
.08265 .1473 L
.09399 .13708 L
.10458 .12559 L
.14349 .08656 L
.16473 .07078 L
.18485 .05925 L
.20476 .05051 L
.22318 .04429 L
.24184 .03944 L
.26245 .03538 L
.28179 .03253 L
.30265 .03023 L
.32269 .02861 L
.34379 .02735 L
.36353 .0265 L
.3819 .02592 L
.39242 .02566 L
.40235 .02546 L
.41121 .02531 L
.42094 .02519 L
.43066 .02509 L
.43598 .02505 L
.44096 .02502 L
.4456 .02499 L
.44985 .02498 L
.4522 .02497 L
Mistroke
.45352 .02497 L
.45475 .02497 L
.45594 .02497 L
.45701 .02497 L
.45824 .02497 L
.45941 .02497 L
.46058 .02497 L
.46183 .02497 L
.463 .02497 L
.46408 .02497 L
.46671 .02498 L
.4692 .02499 L
.47415 .02501 L
.47694 .02502 L
.47953 .02504 L
.4885 .02512 L
.49801 .02523 L
.51774 .02555 L
.53581 .02586 L
.54526 .02599 L
.55001 .02604 L
.5552 .02608 L
.55794 .02609 L
.56043 .0261 L
.56181 .02611 L
.56331 .02611 L
.56399 .02611 L
.56472 .02611 L
.56602 .02612 L
.56721 .02612 L
.56849 .02612 L
.5697 .02612 L
.57081 .02611 L
.5721 .02611 L
.57351 .02611 L
.57607 .0261 L
.5784 .02609 L
.58091 .02608 L
.58545 .02605 L
.59582 .02596 L
.61682 .02572 L
.65793 .02518 L
.67843 .02494 L
.69752 .02475 L
.7171 .02459 L
.73559 .02448 L
.74539 .02443 L
.75603 .02438 L
.76562 .02435 L
.77461 .02433 L
Mistroke
.78406 .02431 L
.78907 .02431 L
.79187 .0243 L
.79446 .0243 L
.79715 .0243 L
.79858 .0243 L
.80009 .0243 L
.80079 .0243 L
.80154 .0243 L
.8022 .0243 L
.8029 .0243 L
.80353 .0243 L
.80423 .0243 L
.80545 .0243 L
.80676 .0243 L
.80796 .0243 L
.80862 .0243 L
.80934 .0243 L
.81064 .0243 L
.81316 .0243 L
.81549 .0243 L
.82013 .02431 L
.82513 .02431 L
.83417 .02433 L
.84493 .02435 L
.85478 .02438 L
.89442 .02453 L
.90471 .02457 L
.91441 .0246 L
.92385 .02462 L
.93255 .02464 L
.93713 .02465 L
.94197 .02465 L
.94448 .02465 L
.94683 .02466 L
.94941 .02466 L
.95086 .02466 L
.95218 .02466 L
.95347 .02466 L
.9542 .02466 L
.95485 .02466 L
.95612 .02466 L
.95732 .02466 L
.95801 .02466 L
.95873 .02466 L
.96002 .02466 L
.96141 .02466 L
.96293 .02466 L
.96548 .02466 L
.96821 .02465 L
Mistroke
.97313 .02465 L
.97619 .02465 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.03279 .05678 L
.04262 .09702 L
.04758 .11424 L
.05288 .13002 L
.05785 .14225 L
.06244 .15131 L
.06788 .15938 L
.07075 .16253 L
.07379 .1651 L
.07505 .16595 L
.07642 .16673 L
.0776 .1673 L
.07889 .1678 L
.07967 .16805 L
.08039 .16824 L
.08114 .1684 L
.08182 .16852 L
.08312 .16867 L
.08383 .16871 L
.08451 .16872 L
.08567 .16867 L
.08695 .16854 L
.08759 .16845 L
.08828 .16832 L
.08953 .16804 L
.09195 .16729 L
.09415 .1664 L
.09951 .16355 L
.10458 .16013 L
.14291 .12623 L
.16229 .10992 L
.18369 .09467 L
.22296 .0742 L
.2423 .0671 L
.26316 .06116 L
.2832 .0568 L
.3043 .05334 L
.32404 .05092 L
.34241 .04924 L
.35293 .04849 L
.36287 .04789 L
.37172 .04746 L
.38145 .04707 L
.39118 .04677 L
.39614 .04665 L
.40147 .04655 L
.40645 .04647 L
.411 .04642 L
.41319 .04641 L
Mistroke
.41435 .0464 L
.41558 .04639 L
.41676 .04639 L
.41783 .04638 L
.41891 .04638 L
.41992 .04638 L
.42109 .04638 L
.42234 .04638 L
.42352 .04638 L
.42459 .04639 L
.42585 .04639 L
.42722 .0464 L
.42971 .04642 L
.43231 .04644 L
.43508 .04648 L
.44004 .04656 L
.44458 .04666 L
.44883 .04678 L
.45852 .04714 L
.46323 .04737 L
.46838 .04767 L
.47875 .04843 L
.48834 .04938 L
.49726 .0505 L
.51604 .05357 L
.53636 .05699 L
.54177 .05771 L
.54749 .05832 L
.55238 .05873 L
.55519 .05891 L
.55775 .05905 L
.56033 .05915 L
.56278 .05923 L
.56412 .05926 L
.56536 .05928 L
.56601 .05929 L
.56672 .0593 L
.56747 .0593 L
.56817 .0593 L
.56936 .05931 L
.57061 .0593 L
.57168 .05929 L
.57286 .05928 L
.57412 .05926 L
.57547 .05923 L
.57791 .05917 L
.58049 .05908 L
.58323 .05897 L
.58814 .05872 L
.59923 .05798 L
Mistroke
.61938 .05623 L
.65723 .0527 L
.67829 .05097 L
.69754 .04964 L
.71766 .0485 L
.73633 .04768 L
.75533 .04704 L
.76537 .04678 L
.77606 .04655 L
.78635 .04638 L
.79749 .04625 L
.8026 .0462 L
.808 .04615 L
.81305 .04612 L
.81766 .0461 L
.82 .04609 L
.82253 .04608 L
.82473 .04607 L
.82715 .04607 L
.82847 .04607 L
.82971 .04607 L
.83102 .04606 L
.83176 .04606 L
.83243 .04606 L
.83357 .04606 L
.83481 .04606 L
.83611 .04606 L
.83731 .04606 L
.83846 .04607 L
.83971 .04607 L
.84196 .04607 L
.84416 .04608 L
.84618 .04608 L
.85078 .0461 L
.85565 .04613 L
.86059 .04617 L
.8651 .04621 L
.87524 .04633 L
.88464 .04648 L
.89356 .04665 L
.91342 .04716 L
.93183 .04774 L
.97103 .04914 L
.97619 .04933 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01977 L
.08259 .01861 L
.10458 .01765 L
.12517 .01697 L
.14429 .0165 L
.16481 .01613 L
.18342 .01587 L
.20266 .01567 L
.22348 .01551 L
.24342 .0154 L
.26449 .01532 L
.28413 .01526 L
.30246 .01521 L
.32281 .01518 L
.34137 .01516 L
.36045 .01514 L
.38121 .01512 L
.40099 .01511 L
.4111 .01511 L
.422 .01511 L
.43215 .0151 L
.44147 .0151 L
.4503 .0151 L
.45975 .0151 L
.46955 .0151 L
.47867 .0151 L
.48425 .0151 L
.48699 .0151 L
.48952 .0151 L
.49177 .0151 L
.49424 .0151 L
.49673 .0151 L
.4981 .0151 L
.49937 .0151 L
.50062 .0151 L
.50132 .0151 L
Mistroke
.50195 .0151 L
.50319 .0151 L
.50435 .0151 L
.50501 .0151 L
.50571 .0151 L
.50696 .0151 L
.50765 .0151 L
.5083 .0151 L
.50978 .0151 L
.51228 .0151 L
.51455 .0151 L
.51966 .0151 L
.52422 .0151 L
.52663 .0151 L
.52918 .0151 L
.53141 .0151 L
.53259 .0151 L
.53387 .0151 L
.53503 .0151 L
.5361 .0151 L
.53712 .0151 L
.53819 .0151 L
.53943 .0151 L
.54013 .0151 L
.54078 .0151 L
.54196 .0151 L
.54321 .0151 L
.54538 .0151 L
.54776 .0151 L
.55031 .0151 L
.55304 .0151 L
.55798 .0151 L
.56759 .0151 L
.57636 .0151 L
.61617 .01509 L
.65447 .01509 L
.67383 .01509 L
.69522 .01509 L
.71544 .01509 L
.73445 .01509 L
.74426 .01509 L
.75461 .01509 L
.7731 .01509 L
.78263 .01509 L
.79282 .01509 L
.81118 .01509 L
.85265 .01509 L
.8926 .01509 L
.93103 .01509 L
.97192 .01508 L
Mistroke
.97619 .01508 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .0356 L
.03072 .0433 L
.03279 .04846 L
.03405 .05078 L
.03521 .05245 L
.03649 .05381 L
.03713 .05434 L
.03784 .05482 L
.03903 .05541 L
.04031 .05579 L
.04151 .05597 L
.04262 .056 L
.04384 .05593 L
.04514 .05574 L
.04636 .05548 L
.04748 .0552 L
.05278 .05341 L
.06244 .0494 L
.08269 .04131 L
.10458 .03438 L
.12545 .02945 L
.14465 .02606 L
.16347 .02355 L
.18413 .02149 L
.20364 .02006 L
.22456 .01894 L
.2458 .0181 L
.26592 .01753 L
.28583 .01711 L
.30425 .01683 L
.32291 .01661 L
.34352 .01643 L
.36286 .01631 L
.38372 .01621 L
.40376 .01615 L
.41384 .01612 L
.42486 .0161 L
.44447 .01607 L
.45545 .01605 L
.46542 .01605 L
.47027 .01604 L
.4754 .01604 L
.47984 .01604 L
.4846 .01604 L
.48728 .01604 L
.48972 .01603 L
.4922 .01603 L
.49451 .01603 L
Mistroke
.49718 .01603 L
.49859 .01603 L
.49932 .01603 L
.5001 .01603 L
.50084 .01603 L
.50153 .01603 L
.50219 .01603 L
.50288 .01603 L
.50408 .01603 L
.5054 .01603 L
.50671 .01603 L
.50792 .01603 L
.50925 .01603 L
.51066 .01603 L
.51563 .01603 L
.52495 .01604 L
.52742 .01604 L
.52872 .01604 L
.53009 .01604 L
.53129 .01604 L
.5326 .01604 L
.53379 .01604 L
.5349 .01604 L
.53559 .01604 L
.53634 .01604 L
.53704 .01604 L
.53769 .01604 L
.53892 .01604 L
.54021 .01604 L
.54089 .01604 L
.54161 .01604 L
.54291 .01604 L
.54588 .01604 L
.54843 .01603 L
.55115 .01603 L
.55603 .01603 L
.56129 .01603 L
.56709 .01603 L
.58721 .01602 L
.62738 .016 L
.66603 .01598 L
.68605 .01598 L
.70714 .01597 L
.72686 .01597 L
.74522 .01596 L
.75572 .01596 L
.76565 .01596 L
.77456 .01596 L
.77955 .01596 L
.78423 .01596 L
Mistroke
.78916 .01596 L
.79368 .01596 L
.79869 .01596 L
.80149 .01596 L
.80408 .01596 L
.80679 .01596 L
.80924 .01596 L
.81196 .01596 L
.81346 .01596 L
.81487 .01596 L
.81612 .01596 L
.81743 .01596 L
.81856 .01596 L
.81979 .01596 L
.82049 .01596 L
.82112 .01596 L
.82185 .01596 L
.82255 .01596 L
.82378 .01596 L
.82512 .01596 L
.82745 .01596 L
.82997 .01596 L
.83452 .01596 L
.8449 .01596 L
.85494 .01596 L
.85769 .01596 L
.86063 .01596 L
.8634 .01596 L
.8646 .01596 L
.86592 .01596 L
.86717 .01596 L
.86785 .01596 L
.8685 .01596 L
.86964 .01596 L
.87087 .01596 L
.87156 .01596 L
.87231 .01596 L
.87302 .01596 L
.87367 .01596 L
.87492 .01596 L
.87624 .01596 L
.87887 .01596 L
.88135 .01596 L
.88597 .01596 L
.88855 .01596 L
.89126 .01596 L
.89612 .01596 L
.90708 .01596 L
.91659 .01596 L
.92677 .01596 L
Mistroke
.94512 .01596 L
.97619 .01596 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.02846 .03633 L
.03279 .05287 L
.03523 .06022 L
.03754 .06586 L
.0402 .07088 L
.04262 .07426 L
.04502 .07666 L
.04623 .07757 L
.04756 .07836 L
.0487 .07889 L
.04992 .07932 L
.05107 .07961 L
.05212 .07978 L
.05344 .07989 L
.05465 .0799 L
.05536 .07986 L
.05599 .07981 L
.05672 .07973 L
.05742 .07963 L
.05983 .07913 L
.06244 .07838 L
.06753 .07646 L
.07312 .07393 L
.08439 .06824 L
.10458 .05825 L
.12572 .04939 L
.145 .04293 L
.16498 .03768 L
.18391 .03382 L
.20382 .0307 L
.22224 .02848 L
.24091 .02675 L
.26151 .0253 L
.28086 .02428 L
.30171 .02346 L
.32175 .02288 L
.34285 .02243 L
.36259 .02213 L
.38096 .02193 L
.39148 .02185 L
.40142 .02178 L
.41034 .02174 L
.41533 .02172 L
.42001 .0217 L
.42495 .02169 L
.42947 .02168 L
.43204 .02167 L
.43449 .02167 L
.43574 .02167 L
Mistroke
.43707 .02167 L
.43783 .02167 L
.43853 .02167 L
.43917 .02167 L
.43988 .02167 L
.4412 .02167 L
.44192 .02167 L
.4426 .02167 L
.4438 .02167 L
.44509 .02167 L
.44582 .02167 L
.44661 .02167 L
.44804 .02167 L
.45072 .02167 L
.4533 .02168 L
.45603 .02168 L
.46092 .0217 L
.46583 .02171 L
.47032 .02173 L
.48043 .02179 L
.48935 .02186 L
.49873 .02195 L
.51873 .02218 L
.52745 .02228 L
.53689 .02238 L
.54215 .02242 L
.547 .02246 L
.55164 .02248 L
.5542 .02249 L
.55654 .0225 L
.55903 .02251 L
.5604 .02251 L
.5617 .02251 L
.5629 .02251 L
.56401 .02251 L
.56523 .02251 L
.56653 .02251 L
.56782 .02251 L
.56855 .02251 L
.56921 .02251 L
.57044 .02251 L
.57174 .02251 L
.57449 .02251 L
.5775 .0225 L
.58278 .02248 L
.58776 .02246 L
.59709 .02241 L
.61803 .02226 L
.65646 .02197 L
.67592 .02184 L
Mistroke
.69735 .02171 L
.71791 .02161 L
.73672 .02154 L
.75614 .02149 L
.76685 .02147 L
.77703 .02145 L
.78662 .02143 L
.79685 .02142 L
.81524 .02141 L
.82554 .0214 L
.83667 .0214 L
.85684 .02139 L
.86717 .02138 L
.8768 .02138 L
.88205 .02138 L
.88684 .02138 L
.88939 .02138 L
.89216 .02138 L
.89369 .02138 L
.89509 .02138 L
.89644 .02138 L
.89718 .02138 L
.89787 .02138 L
.89901 .02138 L
.90025 .02138 L
.90146 .02138 L
.90276 .02138 L
.90397 .02138 L
.90511 .02138 L
.90614 .02138 L
.90725 .02138 L
.9098 .02138 L
.91251 .02138 L
.91735 .02138 L
.92185 .02138 L
.92606 .02138 L
.93564 .02139 L
.94605 .02139 L
.95594 .0214 L
.97448 .02141 L
.97619 .02141 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.02605 .02535 L
.02846 .03505 L
.02962 .03887 L
.03072 .0419 L
.0317 .04413 L
.03279 .04614 L
.03398 .04785 L
.03524 .04919 L
.03641 .05008 L
.0375 .05068 L
.03879 .05114 L
.03997 .05138 L
.04062 .05145 L
.04132 .05148 L
.04262 .05146 L
.04326 .05141 L
.04396 .05133 L
.04523 .05113 L
.04759 .05061 L
.0529 .04904 L
.06244 .04566 L
.08293 .03864 L
.10458 .03271 L
.12413 .02864 L
.14558 .02528 L
.16509 .02302 L
.18601 .02121 L
.20725 .01987 L
.22737 .01894 L
.24728 .01826 L
.2657 .01779 L
.28436 .01743 L
.30496 .01714 L
.32431 .01693 L
.34517 .01677 L
.36521 .01666 L
.37541 .01662 L
.38631 .01658 L
.39665 .01654 L
.40605 .01652 L
.42442 .01648 L
.4344 .01647 L
.4436 .01646 L
.4537 .01645 L
.4588 .01645 L
.46148 .01645 L
.4644 .01645 L
.4671 .01644 L
.46961 .01644 L
Mistroke
.47201 .01644 L
.47335 .01644 L
.47456 .01644 L
.47576 .01644 L
.47686 .01644 L
.47807 .01644 L
.47934 .01644 L
.48046 .01644 L
.48149 .01644 L
.48263 .01644 L
.48385 .01644 L
.48654 .01644 L
.48946 .01644 L
.49478 .01645 L
.49996 .01645 L
.50474 .01645 L
.52503 .01646 L
.52987 .01647 L
.53496 .01647 L
.53968 .01647 L
.54197 .01647 L
.54406 .01647 L
.54608 .01647 L
.54827 .01647 L
.54947 .01647 L
.55058 .01647 L
.55164 .01647 L
.55276 .01647 L
.55389 .01647 L
.5551 .01647 L
.55624 .01647 L
.55729 .01647 L
.55851 .01647 L
.55984 .01647 L
.56226 .01647 L
.5646 .01647 L
.56719 .01647 L
.57244 .01647 L
.58186 .01647 L
.60118 .01645 L
.62203 .01644 L
.66314 .01641 L
.68364 .01639 L
.70273 .01638 L
.72231 .01638 L
.74081 .01637 L
.75061 .01637 L
.76124 .01637 L
.77083 .01636 L
.77982 .01636 L
Mistroke
.78927 .01636 L
.79967 .01636 L
.80981 .01636 L
.8155 .01636 L
.82071 .01636 L
.84131 .01636 L
.85134 .01636 L
.86043 .01636 L
.86996 .01636 L
.87893 .01636 L
.89865 .01636 L
.91874 .01635 L
.93722 .01635 L
.97619 .01635 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.04262 .09854 L
.0522 .13329 L
.06244 .16282 L
.0679 .17497 L
.07286 .18383 L
.07784 .19064 L
.08255 .19522 L
.08522 .19705 L
.08668 .19783 L
.08805 .19842 L
.08931 .19886 L
.09046 .19917 L
.09174 .1994 L
.09244 .19949 L
.09312 .19955 L
.09384 .19958 L
.09449 .19958 L
.09525 .19955 L
.09596 .19949 L
.09723 .19932 L
.09794 .19918 L
.0986 .19904 L
.10151 .19814 L
.10297 .19754 L
.10458 .19677 L
.10982 .1936 L
.11478 .18981 L
.12409 .18122 L
.145 .15879 L
.18333 .12033 L
.20272 .1049 L
.22412 .09114 L
.2446 .0808 L
.26338 .07334 L
.28273 .06732 L
.30359 .06236 L
.32251 .05896 L
.34321 .05619 L
.36282 .05429 L
.3738 .0535 L
.38377 .05292 L
.39375 .05247 L
.40296 .05216 L
.40777 .05204 L
.41306 .05194 L
.41572 .0519 L
.41719 .05188 L
.41858 .05186 L
.41988 .05185 L
Mistroke
.42128 .05184 L
.42256 .05184 L
.42375 .05183 L
.42504 .05183 L
.42569 .05183 L
.42641 .05183 L
.42767 .05183 L
.42885 .05183 L
.42956 .05183 L
.43024 .05184 L
.4315 .05184 L
.43287 .05185 L
.43435 .05187 L
.43686 .0519 L
.43953 .05194 L
.44431 .05204 L
.44889 .05217 L
.45317 .05233 L
.46293 .05281 L
.46765 .05311 L
.47279 .05351 L
.48316 .05454 L
.49276 .05583 L
.50167 .05736 L
.52045 .06148 L
.54077 .066 L
.54618 .06694 L
.55191 .06776 L
.55679 .0683 L
.5596 .06855 L
.56216 .06873 L
.56474 .06888 L
.56719 .06898 L
.56853 .06902 L
.56977 .06905 L
.57113 .06908 L
.57182 .06909 L
.57258 .06909 L
.57384 .0691 L
.575 .0691 L
.57627 .06909 L
.5769 .06908 L
.5776 .06907 L
.57878 .06905 L
.58005 .06901 L
.58232 .06894 L
.5849 .06883 L
.58764 .06869 L
.59255 .06837 L
.60364 .0674 L
Mistroke
.62379 .06508 L
.66164 .06034 L
.6827 .05802 L
.70195 .05624 L
.72207 .05474 L
.74074 .05366 L
.75974 .05287 L
.76978 .05257 L
.77535 .05243 L
.78047 .05233 L
.78548 .05225 L
.79077 .05219 L
.79351 .05216 L
.79607 .05214 L
.79754 .05214 L
.79888 .05213 L
.79963 .05213 L
.80043 .05213 L
.80119 .05213 L
.8019 .05212 L
.80305 .05212 L
.8043 .05212 L
.80547 .05213 L
.80655 .05213 L
.80774 .05213 L
.80905 .05214 L
.81168 .05216 L
.81429 .05218 L
.81707 .05221 L
.82207 .05229 L
.82741 .05239 L
.83232 .05252 L
.84343 .05291 L
.85323 .05338 L
.86359 .05401 L
.9015 .05728 L
.92259 .0594 L
.94186 .06119 L
.97619 .06351 L
Mfstroke
.933 0 1 r
.02381 .01472 m
.02605 .02542 L
.02846 .03562 L
.03053 .04281 L
.03279 .04867 L
.03416 .05129 L
.03543 .05314 L
.03665 .05447 L
.03793 .0555 L
.03908 .05615 L
.04016 .05656 L
.04135 .05683 L
.04262 .05695 L
.04393 .05693 L
.04516 .0568 L
.04586 .05669 L
.0465 .05657 L
.04793 .05624 L
.05297 .0546 L
.06244 .05073 L
.08269 .04251 L
.10458 .03537 L
.12545 .03025 L
.14465 .02671 L
.16347 .02408 L
.18413 .02192 L
.20364 .02042 L
.22456 .01922 L
.2458 .01834 L
.26592 .01774 L
.28583 .01729 L
.30425 .01698 L
.32291 .01675 L
.34352 .01656 L
.36286 .01643 L
.38372 .01633 L
.40376 .01626 L
.41384 .01623 L
.42486 .0162 L
.44447 .01617 L
.45545 .01616 L
.46542 .01615 L
.47027 .01615 L
.4754 .01614 L
.47984 .01614 L
.4846 .01614 L
.48728 .01614 L
.48972 .01614 L
.49218 .01614 L
.49451 .01614 L
Mistroke
.49582 .01614 L
.49721 .01614 L
.49853 .01614 L
.49972 .01614 L
.50045 .01614 L
.50113 .01614 L
.50187 .01614 L
.50265 .01614 L
.50396 .01614 L
.50471 .01614 L
.5054 .01614 L
.50667 .01614 L
.50801 .01614 L
.51042 .01614 L
.51588 .01614 L
.52579 .01614 L
.53005 .01614 L
.53228 .01614 L
.53463 .01614 L
.53588 .01614 L
.53725 .01614 L
.53849 .01614 L
.53965 .01614 L
.54085 .01614 L
.54193 .01614 L
.54318 .01614 L
.54436 .01614 L
.54552 .01614 L
.54676 .01614 L
.54794 .01614 L
.54901 .01614 L
.55163 .01614 L
.55411 .01614 L
.55904 .01614 L
.56442 .01614 L
.574 .01613 L
.58288 .01613 L
.62211 .01611 L
.65983 .01609 L
.68078 .01608 L
.7 .01607 L
.71883 .01606 L
.73866 .01606 L
.74819 .01606 L
.75838 .01606 L
.77673 .01605 L
.78696 .01605 L
.79806 .01605 L
.8182 .01605 L
.85909 .01605 L
Mistroke
.89846 .01605 L
.93631 .01605 L
.97619 .01604 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.03279 .05635 L
.03793 .07662 L
.04262 .09135 L
.045 .09724 L
.04758 .10238 L
.04899 .10465 L
.0503 .10642 L
.05164 .10792 L
.05288 .10904 L
.05404 .10987 L
.05509 .11046 L
.05626 .11093 L
.05752 .11125 L
.05873 .11138 L
.06005 .11135 L
.06129 .11118 L
.06244 .11091 L
.06382 .11045 L
.06509 .10993 L
.06795 .10841 L
.07314 .10486 L
.08284 .0968 L
.10458 .07828 L
.125 .06371 L
.14407 .05301 L
.16239 .04501 L
.18204 .03842 L
.20328 .0331 L
.2234 .02937 L
.24331 .02663 L
.26173 .02471 L
.28039 .02324 L
.301 .02203 L
.32034 .0212 L
.3412 .02053 L
.36124 .02007 L
.38234 .01971 L
.40208 .01948 L
.42045 .01933 L
.43097 .01926 L
.4409 .01921 L
.44982 .01918 L
.45482 .01916 L
.45949 .01915 L
.46406 .01915 L
.4664 .01914 L
.46896 .01914 L
.47041 .01914 L
.47175 .01914 L
Mistroke
.47314 .01913 L
.4744 .01913 L
.47564 .01913 L
.47681 .01913 L
.47804 .01913 L
.47873 .01913 L
.47937 .01913 L
.48059 .01913 L
.4819 .01913 L
.48313 .01913 L
.48425 .01913 L
.48557 .01913 L
.487 .01914 L
.48961 .01914 L
.49233 .01914 L
.49522 .01915 L
.50041 .01915 L
.52014 .0192 L
.52878 .01922 L
.53821 .01925 L
.54311 .01925 L
.54766 .01926 L
.55018 .01926 L
.55137 .01926 L
.55247 .01926 L
.55374 .01926 L
.55441 .01926 L
.55511 .01926 L
.5563 .01926 L
.5576 .01926 L
.55827 .01926 L
.559 .01926 L
.55968 .01926 L
.56032 .01926 L
.56152 .01926 L
.5628 .01926 L
.56546 .01926 L
.56839 .01926 L
.57359 .01925 L
.57847 .01924 L
.58829 .01922 L
.59863 .01919 L
.61712 .01913 L
.6552 .019 L
.67643 .01894 L
.69573 .0189 L
.71602 .01886 L
.73474 .01883 L
.7539 .01881 L
.764 .0188 L
Mistroke
.77469 .0188 L
.78411 .01879 L
.79424 .01879 L
.8038 .01878 L
.81255 .01878 L
.83155 .01878 L
.85228 .01878 L
.89294 .01877 L
.91175 .01877 L
.93209 .01877 L
.95352 .01876 L
.97369 .01876 L
.97619 .01876 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.03279 .05651 L
.04262 .09364 L
.04758 .10724 L
.0503 .11311 L
.05288 .11762 L
.05528 .12095 L
.05789 .12369 L
.05904 .12463 L
.06026 .12546 L
.0613 .12604 L
.06244 .12654 L
.06314 .12678 L
.06378 .12696 L
.06505 .12722 L
.0662 .12733 L
.06743 .12734 L
.06813 .12729 L
.06888 .12721 L
.06959 .12709 L
.07025 .12695 L
.07149 .12663 L
.0728 .12619 L
.07742 .12403 L
.0825 .1208 L
.10458 .10267 L
.12572 .08552 L
.145 .07235 L
.16521 .06127 L
.18391 .0532 L
.203 .04676 L
.22376 .0414 L
.24242 .03773 L
.26302 .03465 L
.28237 .03247 L
.30323 .03072 L
.32327 .02948 L
.34437 .02853 L
.36411 .02789 L
.38248 .02746 L
.393 .02728 L
.40293 .02715 L
.41185 .02705 L
.41685 .02701 L
.42152 .02698 L
.42608 .02696 L
.42843 .02695 L
.43099 .02694 L
.43243 .02693 L
.43378 .02693 L
Mistroke
.43517 .02693 L
.43643 .02692 L
.43767 .02692 L
.43883 .02692 L
.44007 .02692 L
.44076 .02692 L
.4414 .02692 L
.44262 .02692 L
.44392 .02692 L
.44516 .02692 L
.44628 .02693 L
.44903 .02693 L
.45164 .02694 L
.45433 .02695 L
.45681 .02696 L
.46244 .027 L
.46709 .02704 L
.47209 .02709 L
.48114 .02722 L
.4919 .02742 L
.50176 .02765 L
.52233 .02822 L
.53234 .02848 L
.54143 .02867 L
.546 .02874 L
.5484 .02877 L
.55094 .0288 L
.55316 .02882 L
.5556 .02884 L
.55782 .02885 L
.5589 .02886 L
.5599 .02886 L
.56112 .02886 L
.56176 .02886 L
.56245 .02887 L
.5636 .02887 L
.56487 .02887 L
.56599 .02887 L
.5672 .02887 L
.56835 .02886 L
.5694 .02886 L
.57177 .02885 L
.57436 .02884 L
.5796 .0288 L
.58487 .02875 L
.58985 .02869 L
.59918 .02855 L
.62012 .02819 L
.65856 .0275 L
.67802 .02719 L
Mistroke
.69944 .02692 L
.72001 .0267 L
.73882 .02655 L
.75824 .02644 L
.76895 .02639 L
.77912 .02635 L
.78872 .02632 L
.79894 .0263 L
.81734 .02627 L
.82763 .02626 L
.83876 .02624 L
.84838 .02623 L
.85894 .02623 L
.86857 .02622 L
.87387 .02622 L
.87889 .02621 L
.88162 .02621 L
.88459 .02621 L
.88706 .02621 L
.88847 .02621 L
.88979 .02621 L
.89113 .02621 L
.89235 .02621 L
.89366 .02621 L
.89435 .02621 L
.89507 .02621 L
.89628 .02621 L
.89741 .02621 L
.89864 .02621 L
.89996 .02621 L
.9012 .02621 L
.90255 .02621 L
.9053 .02621 L
.90784 .02621 L
.91021 .02621 L
.91557 .02621 L
.92132 .02622 L
.93186 .02623 L
.94148 .02624 L
.97619 .02629 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02137 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02121 L
.04262 .0209 L
.06244 .01954 L
.08259 .01838 L
.10458 .01743 L
.12517 .01678 L
.14429 .01632 L
.16481 .01596 L
.18342 .01572 L
.20266 .01553 L
.22348 .01537 L
.24342 .01527 L
.26449 .01519 L
.28413 .01513 L
.30246 .01509 L
.32281 .01506 L
.34137 .01504 L
.36045 .01502 L
.38121 .01501 L
.40099 .015 L
.4111 .015 L
.422 .01499 L
.43215 .01499 L
.44147 .01499 L
.45975 .01499 L
.46955 .01498 L
.47867 .01498 L
.48868 .01498 L
.49937 .01498 L
.50961 .01498 L
.52072 .01498 L
.54087 .01498 L
.58179 .01498 L
.62119 .01498 L
.65908 .01498 L
.67852 .01498 L
.69942 .01498 L
.70955 .01498 L
Mistroke
.72059 .01497 L
.73114 .01497 L
.74069 .01497 L
.75017 .01497 L
.76041 .01497 L
.76604 .01497 L
.77122 .01497 L
.77617 .01497 L
.77885 .01497 L
.78139 .01497 L
.78378 .01497 L
.78637 .01497 L
.78872 .01497 L
.79089 .01497 L
.79211 .01497 L
.79324 .01497 L
.79449 .01497 L
.79519 .01497 L
.79583 .01497 L
.79705 .01497 L
.79774 .01497 L
.79838 .01497 L
.79968 .01497 L
.80041 .01497 L
.80107 .01497 L
.80343 .01497 L
.8056 .01497 L
.81051 .01497 L
.81484 .01497 L
.81942 .01497 L
.83903 .01497 L
.85735 .01497 L
.86779 .01497 L
.87768 .01497 L
.88199 .01497 L
.88656 .01497 L
.88895 .01497 L
.89158 .01497 L
.89399 .01497 L
.89623 .01497 L
.89746 .01497 L
.89857 .01497 L
.89981 .01497 L
.90049 .01497 L
.90114 .01497 L
.90243 .01497 L
.90362 .01497 L
.90492 .01497 L
.90558 .01497 L
.90631 .01497 L
Mistroke
.90751 .01497 L
.90861 .01497 L
.91108 .01497 L
.91338 .01497 L
.91555 .01497 L
.92073 .01497 L
.92552 .01497 L
.9364 .01497 L
.94698 .01497 L
.95694 .01497 L
.97555 .01497 L
.97619 .01497 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.03279 .05675 L
.04262 .0963 L
.04758 .11242 L
.05288 .12623 L
.05546 .13158 L
.05789 .13582 L
.06024 .1392 L
.06244 .14173 L
.06487 .14386 L
.06616 .14473 L
.06754 .14546 L
.06824 .14576 L
.06899 .14602 L
.06966 .14622 L
.07037 .14638 L
.07107 .14649 L
.07171 .14656 L
.07295 .1466 L
.0742 .14653 L
.07535 .14635 L
.07661 .14606 L
.07794 .14565 L
.08019 .14472 L
.08265 .14342 L
.08812 .13968 L
.09399 .13477 L
.10458 .12469 L
.12439 .10537 L
.14594 .08693 L
.16488 .07373 L
.18579 .06221 L
.20556 .05379 L
.22657 .04696 L
.24592 .04219 L
.26677 .03829 L
.28681 .03549 L
.30791 .0333 L
.32765 .03179 L
.34602 .03073 L
.36648 .02988 L
.38506 .02932 L
.39505 .0291 L
.40425 .02893 L
.41435 .02879 L
.41944 .02874 L
.42505 .02869 L
.43026 .02865 L
.43283 .02864 L
.43521 .02863 L
Mistroke
.43736 .02862 L
.43965 .02862 L
.44096 .02861 L
.44219 .02861 L
.4433 .02861 L
.44449 .02861 L
.4458 .02861 L
.44702 .02861 L
.44772 .02861 L
.44836 .02861 L
.44979 .02862 L
.45117 .02862 L
.45266 .02863 L
.45538 .02864 L
.45791 .02865 L
.46058 .02867 L
.46539 .02871 L
.47029 .02876 L
.47478 .02882 L
.4849 .02899 L
.49381 .0292 L
.50319 .02947 L
.5232 .03017 L
.53191 .03047 L
.54135 .03074 L
.54662 .03086 L
.55146 .03095 L
.5561 .03101 L
.55843 .03103 L
.561 .03106 L
.5624 .03106 L
.56373 .03107 L
.56493 .03108 L
.56623 .03108 L
.5669 .03108 L
.56764 .03108 L
.56841 .03108 L
.56914 .03108 L
.57044 .03108 L
.57117 .03108 L
.57184 .03108 L
.57306 .03107 L
.57419 .03107 L
.57677 .03106 L
.57928 .03104 L
.58196 .03102 L
.58728 .03096 L
.59219 .03089 L
.60328 .0307 L
.62343 .03027 L
Mistroke
.6628 .02938 L
.70065 .0287 L
.72008 .02844 L
.74096 .02822 L
.75108 .02814 L
.76211 .02807 L
.77253 .02802 L
.78221 .02798 L
.78729 .02796 L
.79278 .02795 L
.79797 .02794 L
.80044 .02794 L
.80274 .02793 L
.805 .02793 L
.80706 .02793 L
.80816 .02793 L
.80935 .02793 L
.81061 .02793 L
.8118 .02793 L
.81294 .02793 L
.81421 .02793 L
.81553 .02793 L
.81676 .02793 L
.81792 .02793 L
.81897 .02793 L
.82136 .02793 L
.82384 .02793 L
.8261 .02794 L
.83117 .02794 L
.83586 .02795 L
.84029 .02796 L
.85023 .028 L
.861 .02805 L
.88089 .02818 L
.90194 .02836 L
.93985 .02871 L
.97619 .02896 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.03279 .05689 L
.04262 .098 L
.04758 .11596 L
.05288 .13261 L
.05785 .14553 L
.06244 .15503 L
.06788 .16326 L
.07075 .16633 L
.07221 .16757 L
.07379 .16868 L
.07516 .16946 L
.07642 .17002 L
.07769 .17045 L
.07889 .17074 L
.07956 .17085 L
.08028 .17093 L
.08157 .17098 L
.08237 .17095 L
.08311 .17088 L
.08378 .17079 L
.08451 .17066 L
.08576 .17035 L
.08693 .16999 L
.08959 .16889 L
.09218 .16749 L
.09496 .16569 L
.10458 .15767 L
.14594 .11545 L
.16664 .09751 L
.18579 .08396 L
.20556 .0728 L
.22412 .06452 L
.24278 .05798 L
.26338 .05241 L
.28356 .04829 L
.30207 .04541 L
.32099 .04317 L
.34169 .04135 L
.3613 .04011 L
.37228 .03959 L
.38225 .0392 L
.39157 .03891 L
.40144 .03867 L
.40659 .03858 L
.41226 .03849 L
.41474 .03846 L
.41741 .03843 L
.41995 .03841 L
.42224 .0384 L
Mistroke
.42478 .03838 L
.42618 .03838 L
.42749 .03837 L
.42871 .03837 L
.42984 .03837 L
.43107 .03837 L
.43237 .03837 L
.43368 .03837 L
.43442 .03837 L
.43509 .03837 L
.4364 .03838 L
.43764 .03838 L
.4404 .0384 L
.44341 .03842 L
.44848 .03848 L
.45386 .03857 L
.45845 .03866 L
.46351 .03879 L
.47363 .03913 L
.4829 .03957 L
.49307 .0402 L
.50377 .04103 L
.52377 .04288 L
.53249 .04363 L
.54193 .0443 L
.54719 .04458 L
.55204 .04478 L
.55444 .04485 L
.55668 .04491 L
.55901 .04496 L
.56035 .04498 L
.56158 .045 L
.56288 .04501 L
.56356 .04501 L
.56429 .04502 L
.56552 .04502 L
.56621 .04502 L
.56687 .04502 L
.56808 .04502 L
.56919 .04502 L
.57041 .04501 L
.57169 .045 L
.57437 .04496 L
.57687 .04492 L
.58254 .04479 L
.58758 .04463 L
.59305 .04442 L
.60297 .04398 L
.62156 .043 L
.66244 .04081 L
Mistroke
.68277 .0399 L
.70181 .03918 L
.72122 .03859 L
.73967 .03816 L
.74936 .03797 L
.75993 .0378 L
.77846 .03758 L
.78879 .03749 L
.79815 .03743 L
.80334 .0374 L
.80895 .03737 L
.81421 .03735 L
.81912 .03734 L
.8241 .03733 L
.82864 .03732 L
.83105 .03731 L
.83368 .03731 L
.83512 .03731 L
.83645 .03731 L
.83772 .03731 L
.83908 .03731 L
.84039 .03731 L
.84158 .0373 L
.84273 .0373 L
.84394 .0373 L
.84458 .0373 L
.84526 .0373 L
.8465 .0373 L
.84725 .03731 L
.84796 .03731 L
.8493 .03731 L
.85061 .03731 L
.85201 .03731 L
.85451 .03731 L
.85719 .03732 L
.86015 .03732 L
.86537 .03733 L
.87032 .03735 L
.87961 .03739 L
.88961 .03745 L
.90051 .03753 L
.92023 .03772 L
.94123 .03798 L
.97619 .03843 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01973 L
.08259 .01856 L
.10458 .01759 L
.12517 .01691 L
.14429 .01644 L
.16481 .01607 L
.18342 .01581 L
.20266 .01561 L
.22348 .01546 L
.24342 .01534 L
.26449 .01526 L
.28413 .0152 L
.30246 .01516 L
.32281 .01513 L
.34137 .0151 L
.36045 .01509 L
.38121 .01507 L
.40099 .01506 L
.4111 .01506 L
.422 .01506 L
.43215 .01505 L
.44147 .01505 L
.45975 .01505 L
.46955 .01505 L
.47867 .01505 L
.48868 .01505 L
.49428 .01505 L
.49937 .01504 L
.50422 .01504 L
.50935 .01504 L
.51856 .01504 L
.52858 .01504 L
.53411 .01504 L
.53935 .01504 L
.54958 .01504 L
.55893 .01504 L
Mistroke
.57724 .01504 L
.61548 .01504 L
.63684 .01504 L
.65618 .01504 L
.6766 .01504 L
.69536 .01504 L
.71465 .01504 L
.72543 .01504 L
.73548 .01504 L
.74536 .01504 L
.75435 .01504 L
.76433 .01504 L
.76952 .01504 L
.77502 .01504 L
.77975 .01504 L
.78496 .01504 L
.78724 .01504 L
.7897 .01504 L
.79201 .01504 L
.79415 .01504 L
.79547 .01504 L
.79667 .01504 L
.79801 .01504 L
.79874 .01504 L
.79943 .01504 L
.80011 .01504 L
.80082 .01504 L
.8021 .01504 L
.80281 .01504 L
.80348 .01504 L
.80421 .01504 L
.80499 .01504 L
.80627 .01504 L
.80766 .01504 L
.81018 .01504 L
.81492 .01504 L
.81976 .01504 L
.8243 .01504 L
.83467 .01504 L
.85567 .01504 L
.86549 .01504 L
.87084 .01504 L
.87583 .01504 L
.8801 .01504 L
.88248 .01504 L
.88354 .01504 L
.88466 .01504 L
.8859 .01504 L
.88704 .01504 L
.88827 .01504 L
Mistroke
.88897 .01504 L
.88963 .01504 L
.89081 .01504 L
.89189 .01504 L
.89314 .01504 L
.89433 .01504 L
.89557 .01504 L
.89692 .01504 L
.89936 .01504 L
.90392 .01504 L
.90925 .01504 L
.91415 .01504 L
.92309 .01504 L
.93254 .01504 L
.95219 .01504 L
.97053 .01504 L
.97619 .01504 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.03279 .05655 L
.04262 .0944 L
.04758 .10898 L
.0503 .11556 L
.05288 .12085 L
.05528 .12496 L
.05789 .12858 L
.06026 .13115 L
.06244 .13295 L
.06369 .13374 L
.06487 .13436 L
.06623 .1349 L
.06747 .13524 L
.06864 .13545 L
.06972 .13555 L
.07091 .13555 L
.07218 .13544 L
.0729 .13533 L
.07357 .1352 L
.07507 .13482 L
.0764 .13437 L
.0778 .1338 L
.0829 .13104 L
.09323 .12319 L
.10458 .11304 L
.12572 .09417 L
.145 .07926 L
.16521 .06654 L
.18391 .05721 L
.203 .04973 L
.22376 .04348 L
.24242 .03919 L
.26302 .03559 L
.28237 .03304 L
.30323 .03098 L
.32327 .02951 L
.34437 .02838 L
.36411 .02761 L
.38248 .0271 L
.393 .02687 L
.40293 .0267 L
.41178 .02658 L
.41681 .02652 L
.42152 .02647 L
.4266 .02643 L
.43124 .0264 L
.4362 .02637 L
.43894 .02636 L
.44153 .02636 L
Mistroke
.44375 .02635 L
.44499 .02635 L
.44612 .02635 L
.44717 .02635 L
.4483 .02635 L
.44938 .02634 L
.45036 .02634 L
.45152 .02635 L
.4526 .02635 L
.45378 .02635 L
.45505 .02635 L
.45763 .02636 L
.45999 .02636 L
.46481 .02639 L
.46993 .02642 L
.47429 .02646 L
.47911 .02651 L
.48983 .02666 L
.49988 .02684 L
.5184 .02729 L
.52888 .02756 L
.53862 .02778 L
.54834 .02795 L
.55377 .02802 L
.55617 .02804 L
.5587 .02806 L
.56142 .02808 L
.56392 .02809 L
.56531 .02809 L
.56661 .0281 L
.56736 .0281 L
.56804 .0281 L
.56883 .0281 L
.56957 .0281 L
.57081 .0281 L
.57212 .0281 L
.57324 .0281 L
.57448 .02809 L
.5758 .02809 L
.57723 .02808 L
.57982 .02807 L
.58476 .02804 L
.58937 .02799 L
.59983 .02787 L
.62092 .02755 L
.65994 .02688 L
.67983 .02658 L
.7014 .02631 L
.72218 .0261 L
.74135 .02595 L
Mistroke
.76009 .02585 L
.77075 .02581 L
.78072 .02578 L
.78569 .02577 L
.78832 .02576 L
.79111 .02576 L
.7938 .02576 L
.79623 .02575 L
.79868 .02575 L
.79978 .02575 L
.80099 .02575 L
.80215 .02575 L
.80324 .02575 L
.80439 .02575 L
.80562 .02575 L
.80677 .02575 L
.80786 .02575 L
.80883 .02575 L
.80989 .02575 L
.81104 .02575 L
.81231 .02575 L
.81489 .02575 L
.81728 .02576 L
.81951 .02576 L
.82422 .02577 L
.82936 .02578 L
.83971 .02581 L
.8493 .02585 L
.85822 .02589 L
.89729 .02615 L
.91721 .02629 L
.93881 .02642 L
.94826 .02646 L
.95826 .0265 L
.9668 .02652 L
.97619 .02654 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.02499 .01859 L
.02605 .02009 L
.02729 .02091 L
.02846 .02132 L
.02954 .02154 L
.03053 .02167 L
.03163 .02176 L
.03279 .0218 L
.03395 .02182 L
.0352 .02181 L
.03638 .02179 L
.03746 .02176 L
.04011 .02165 L
.04262 .02152 L
.06244 .02027 L
.08429 .01902 L
.10458 .01811 L
.12307 .01747 L
.14277 .01695 L
.16418 .01652 L
.18435 .01622 L
.20443 .016 L
.22291 .01585 L
.24173 .01573 L
.26239 .01563 L
.2819 .01556 L
.30282 .01551 L
.32406 .01547 L
.34418 .01544 L
.36409 .01542 L
.38251 .01541 L
.40117 .0154 L
.4118 .0154 L
.42177 .01539 L
.43161 .01539 L
.43697 .01539 L
.44196 .01539 L
.44659 .01539 L
.45079 .01539 L
.45547 .01539 L
.45804 .01539 L
.46046 .01539 L
.46161 .01539 L
.46285 .01539 L
.46402 .01539 L
.46509 .01539 L
.46634 .01539 L
.46705 .01539 L
.4677 .01539 L
Mistroke
.4689 .01539 L
.47018 .01539 L
.47088 .01539 L
.47152 .01539 L
.47297 .01539 L
.47558 .01539 L
.47796 .01539 L
.48048 .01539 L
.48503 .01539 L
.48928 .01539 L
.49893 .01539 L
.5176 .01539 L
.52745 .0154 L
.53789 .0154 L
.54315 .0154 L
.54614 .0154 L
.54895 .0154 L
.5502 .0154 L
.55152 .0154 L
.55266 .0154 L
.55387 .0154 L
.55518 .0154 L
.5564 .0154 L
.55715 .0154 L
.55785 .0154 L
.55917 .0154 L
.56033 .0154 L
.56162 .0154 L
.56295 .0154 L
.5642 .0154 L
.56644 .0154 L
.56884 .0154 L
.57431 .0154 L
.5793 .0154 L
.59836 .01539 L
.61912 .01539 L
.65986 .01538 L
.68009 .01538 L
.6991 .01538 L
.71747 .01538 L
.73682 .01537 L
.74644 .01537 L
.75698 .01537 L
.77547 .01537 L
.78573 .01537 L
.79506 .01537 L
.80583 .01537 L
.816 .01537 L
.85444 .01537 L
.87429 .01537 L
Mistroke
.89532 .01537 L
.93318 .01537 L
.97348 .01537 L
.97619 .01537 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01858 L
.10458 .01761 L
.12517 .01694 L
.14429 .01647 L
.16481 .0161 L
.18342 .01585 L
.20266 .01565 L
.22348 .01549 L
.24342 .01538 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .01511 L
.40099 .0151 L
.4111 .0151 L
.422 .01509 L
.43215 .01509 L
.44147 .01509 L
.4503 .01509 L
.45975 .01509 L
.46955 .01509 L
.47393 .01508 L
.47867 .01508 L
.48425 .01508 L
.48681 .01508 L
.48952 .01508 L
.49196 .01508 L
.49464 .01508 L
.49709 .01508 L
.49937 .01508 L
.50062 .01508 L
.50131 .01508 L
Mistroke
.50195 .01508 L
.50321 .01508 L
.50435 .01508 L
.50501 .01508 L
.50571 .01508 L
.50696 .01508 L
.50765 .01508 L
.5083 .01508 L
.50902 .01508 L
.50978 .01508 L
.51243 .01508 L
.51495 .01508 L
.51966 .01508 L
.52397 .01508 L
.52614 .01508 L
.52738 .01508 L
.52854 .01508 L
.5298 .01508 L
.53096 .01508 L
.53223 .01508 L
.53286 .01508 L
.53356 .01508 L
.53472 .01508 L
.53596 .01508 L
.53713 .01508 L
.53819 .01508 L
.54051 .01508 L
.54306 .01508 L
.5482 .01508 L
.55297 .01508 L
.55742 .01508 L
.56746 .01508 L
.57823 .01508 L
.61956 .01508 L
.65937 .01508 L
.67757 .01508 L
.69767 .01508 L
.71742 .01507 L
.72837 .01507 L
.73842 .01507 L
.74764 .01507 L
.75774 .01507 L
.76789 .01507 L
.77339 .01507 L
.77859 .01507 L
.78351 .01507 L
.78885 .01507 L
.7937 .01507 L
.79818 .01507 L
.80067 .01507 L
Mistroke
.80302 .01507 L
.80558 .01507 L
.80702 .01507 L
.80834 .01507 L
.80901 .01507 L
.80971 .01507 L
.81099 .01507 L
.81176 .01507 L
.8125 .01507 L
.81316 .01507 L
.81387 .01507 L
.8145 .01507 L
.8152 .01507 L
.81592 .01507 L
.8166 .01507 L
.81782 .01507 L
.81912 .01507 L
.82168 .01507 L
.82441 .01507 L
.8293 .01507 L
.84037 .01507 L
.85006 .01507 L
.85271 .01507 L
.85551 .01507 L
.85792 .01507 L
.85925 .01507 L
.8605 .01507 L
.86171 .01507 L
.86303 .01507 L
.86422 .01507 L
.86532 .01507 L
.86636 .01507 L
.8675 .01507 L
.86869 .01507 L
.86981 .01507 L
.87112 .01507 L
.87237 .01507 L
.87471 .01507 L
.87724 .01507 L
.87998 .01507 L
.88458 .01507 L
.88947 .01507 L
.89827 .01507 L
.90859 .01507 L
.91974 .01507 L
.93992 .01507 L
.97619 .01507 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.03279 .05689 L
.04262 .09813 L
.04758 .11625 L
.05288 .13312 L
.05785 .14628 L
.06244 .15594 L
.06503 .16032 L
.06788 .16423 L
.07075 .16725 L
.07232 .16852 L
.07379 .16948 L
.07517 .17018 L
.07648 .17067 L
.07766 .17098 L
.07895 .17118 L
.07968 .17122 L
.08035 .17123 L
.08111 .17119 L
.08183 .17111 L
.08312 .17087 L
.08384 .17069 L
.08451 .17048 L
.08691 .16951 L
.08916 .1683 L
.09427 .16463 L
.10458 .1546 L
.14349 .1108 L
.1633 .09233 L
.18485 .07632 L
.20555 .06445 L
.22469 .05599 L
.24336 .04959 L
.26396 .04419 L
.28331 .04037 L
.30416 .03727 L
.3242 .03507 L
.3453 .03336 L
.36505 .03221 L
.38341 .03143 L
.39394 .03109 L
.40387 .03083 L
.41279 .03064 L
.41778 .03056 L
.42246 .03049 L
.4274 .03043 L
.43192 .03038 L
.43694 .03034 L
.43971 .03033 L
.44233 .03032 L
Mistroke
.44364 .03031 L
.44486 .03031 L
.44554 .03031 L
.44628 .0303 L
.44756 .0303 L
.44879 .0303 L
.45008 .0303 L
.45119 .0303 L
.4524 .0303 L
.45314 .0303 L
.45384 .03031 L
.45514 .03031 L
.45655 .03031 L
.45808 .03032 L
.46083 .03033 L
.46338 .03035 L
.46802 .03039 L
.47303 .03045 L
.48208 .0306 L
.48732 .03071 L
.49284 .03086 L
.5027 .03117 L
.5227 .03196 L
.54086 .03265 L
.54571 .03279 L
.55097 .03292 L
.55593 .03301 L
.55814 .03304 L
.5605 .03307 L
.56302 .0331 L
.56414 .0331 L
.56536 .03311 L
.5661 .03312 L
.56679 .03312 L
.56744 .03312 L
.56815 .03312 L
.56938 .03312 L
.57069 .03313 L
.57137 .03313 L
.57209 .03312 L
.57337 .03312 L
.57408 .03312 L
.57474 .03312 L
.57625 .03311 L
.57877 .03309 L
.58147 .03307 L
.58679 .03301 L
.5917 .03293 L
.60279 .03272 L
.62293 .03221 L
Mistroke
.66231 .03114 L
.70016 .03031 L
.71958 .03 L
.74047 .02974 L
.75058 .02964 L
.76162 .02955 L
.77204 .02949 L
.78171 .02945 L
.78679 .02943 L
.78947 .02942 L
.79229 .02942 L
.79476 .02941 L
.79748 .02941 L
.79995 .0294 L
.80114 .0294 L
.80225 .0294 L
.80341 .0294 L
.80466 .0294 L
.80577 .0294 L
.80695 .0294 L
.808 .0294 L
.80899 .0294 L
.81007 .0294 L
.81123 .0294 L
.8124 .0294 L
.81368 .0294 L
.81626 .02941 L
.81864 .02941 L
.82086 .02942 L
.82592 .02943 L
.8314 .02945 L
.84133 .02949 L
.85101 .02955 L
.85993 .02962 L
.89935 .03 L
.91916 .03019 L
.92782 .03025 L
.93726 .03032 L
.94226 .03034 L
.94689 .03036 L
.9516 .03038 L
.95603 .0304 L
.9585 .0304 L
.96116 .03041 L
.96337 .03041 L
.9658 .03041 L
.96716 .03042 L
.96843 .03042 L
.96978 .03042 L
.97053 .03042 L
Mistroke
.97122 .03042 L
.97244 .03042 L
.97313 .03042 L
.97377 .03042 L
.97495 .03042 L
.97619 .03042 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01977 L
.08259 .01861 L
.10458 .01764 L
.12517 .01696 L
.14429 .01649 L
.16481 .01612 L
.18342 .01586 L
.20266 .01566 L
.22348 .0155 L
.24342 .01539 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01517 L
.34137 .01514 L
.36045 .01513 L
.38121 .01511 L
.40099 .0151 L
.4111 .0151 L
.422 .0151 L
.43215 .01509 L
.44147 .01509 L
.4503 .01509 L
.45975 .01509 L
.46955 .01509 L
.47867 .01509 L
.48425 .01509 L
.48952 .01509 L
.49424 .01509 L
.49691 .01509 L
.49937 .01509 L
.50181 .01509 L
.50404 .01509 L
.50528 .01509 L
.50593 .01509 L
.50662 .01509 L
Mistroke
.50789 .01509 L
.50906 .01509 L
.51024 .01509 L
.51152 .01509 L
.51272 .01509 L
.51382 .01509 L
.51592 .01509 L
.51813 .01509 L
.52289 .01509 L
.5255 .01509 L
.52798 .01509 L
.52938 .01509 L
.53017 .01509 L
.5309 .01509 L
.5322 .01509 L
.53285 .01509 L
.53357 .01509 L
.53486 .01509 L
.53559 .01509 L
.53625 .01509 L
.53748 .01509 L
.53877 .01509 L
.54001 .01509 L
.54136 .01509 L
.54379 .01509 L
.54616 .01509 L
.54834 .01509 L
.55331 .01509 L
.55855 .01509 L
.56731 .01508 L
.57693 .01508 L
.61733 .01508 L
.6562 .01508 L
.67599 .01508 L
.69753 .01508 L
.7182 .01508 L
.73734 .01508 L
.75599 .01507 L
.7666 .01507 L
.77658 .01507 L
.78639 .01507 L
.79674 .01507 L
.81523 .01507 L
.85331 .01507 L
.8729 .01507 L
.89384 .01507 L
.9353 .01507 L
.97525 .01507 L
.97619 .01507 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.03279 .05687 L
.04262 .09756 L
.04758 .11479 L
.05288 .12998 L
.05546 .136 L
.05789 .14083 L
.06024 .1447 L
.06244 .14762 L
.06487 .15006 L
.06616 .15104 L
.06754 .15187 L
.06824 .1522 L
.06899 .15249 L
.0697 .1527 L
.07037 .15286 L
.07162 .15301 L
.07232 .15303 L
.07295 .15301 L
.0742 .15286 L
.07535 .1526 L
.07661 .15219 L
.07794 .15162 L
.08019 .1504 L
.08265 .14873 L
.09399 .13804 L
.10458 .12607 L
.14349 .08585 L
.16473 .06978 L
.18485 .05809 L
.20476 .04927 L
.22318 .04302 L
.24184 .03815 L
.26245 .0341 L
.28179 .03125 L
.30265 .02897 L
.32269 .02735 L
.34379 .02611 L
.36353 .02526 L
.3819 .02468 L
.39242 .02443 L
.40235 .02422 L
.42094 .02394 L
.43066 .02383 L
.43598 .02379 L
.44096 .02375 L
.44555 .02372 L
.44974 .0237 L
.4544 .02369 L
.45697 .02368 L
Mistroke
.45941 .02368 L
.46066 .02367 L
.46131 .02367 L
.46201 .02367 L
.46328 .02367 L
.46445 .02367 L
.46558 .02367 L
.46663 .02367 L
.46779 .02367 L
.46902 .02367 L
.47034 .02367 L
.47177 .02368 L
.47438 .02368 L
.47691 .02369 L
.47925 .0237 L
.4835 .02372 L
.48818 .02374 L
.49765 .02382 L
.51704 .02402 L
.52701 .02414 L
.53791 .02426 L
.54294 .0243 L
.54832 .02433 L
.55093 .02435 L
.55339 .02436 L
.5556 .02436 L
.55799 .02437 L
.5593 .02437 L
.56053 .02437 L
.56124 .02438 L
.56188 .02438 L
.56263 .02438 L
.56333 .02438 L
.56401 .02438 L
.56474 .02438 L
.56604 .02438 L
.56676 .02437 L
.56743 .02437 L
.56898 .02437 L
.57022 .02437 L
.57152 .02437 L
.57385 .02436 L
.5791 .02434 L
.58409 .02431 L
.58863 .02428 L
.59882 .0242 L
.61718 .02402 L
.65713 .0236 L
.69556 .02328 L
.71541 .02316 L
Mistroke
.73645 .02306 L
.74587 .02303 L
.756 .02299 L
.7743 .02295 L
.78442 .02293 L
.79545 .02292 L
.80587 .02291 L
.81555 .0229 L
.82063 .0229 L
.82612 .0229 L
.82865 .0229 L
.83131 .0229 L
.83362 .0229 L
.83608 .0229 L
.83849 .0229 L
.84068 .0229 L
.84173 .0229 L
.84288 .0229 L
.84396 .0229 L
.84496 .0229 L
.84612 .02289 L
.8472 .02289 L
.8484 .0229 L
.84968 .0229 L
.85096 .0229 L
.8523 .0229 L
.8547 .0229 L
.85727 .0229 L
.8597 .0229 L
.86425 .0229 L
.87445 .0229 L
.89282 .02291 L
.91116 .02291 L
.91618 .02292 L
.92157 .02292 L
.92623 .02292 L
.93131 .02292 L
.93265 .02292 L
.93408 .02292 L
.93531 .02292 L
.93665 .02292 L
.93736 .02292 L
.93801 .02292 L
.9393 .02292 L
.94047 .02292 L
.94171 .02292 L
.94284 .02292 L
.94405 .02292 L
.9452 .02292 L
.94624 .02292 L
Mistroke
.94879 .02292 L
.9512 .02292 L
.95375 .02292 L
.95645 .02292 L
.96129 .02292 L
.96651 .02292 L
.97225 .02291 L
.97619 .02291 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02125 L
.03053 .02133 L
.03163 .02137 L
.03279 .02138 L
.03395 .02136 L
.0352 .02133 L
.03638 .02128 L
.03746 .02123 L
.04262 .02091 L
.06244 .01957 L
.08259 .01843 L
.10458 .01749 L
.12517 .01684 L
.14429 .01639 L
.16481 .01603 L
.18342 .01579 L
.20266 .0156 L
.22348 .01545 L
.24342 .01535 L
.26449 .01526 L
.28413 .01521 L
.30246 .01517 L
.32281 .01514 L
.34137 .01512 L
.36045 .0151 L
.38121 .01509 L
.40099 .01508 L
.41097 .01508 L
.422 .01507 L
.44134 .01507 L
.45222 .01507 L
.4622 .01507 L
.46694 .01506 L
.472 .01506 L
.47638 .01506 L
.48112 .01506 L
.48403 .01506 L
.4867 .01506 L
.48921 .01506 L
.49197 .01506 L
.49444 .01506 L
.49675 .01506 L
.49803 .01506 L
.4992 .01506 L
.49984 .01506 L
Mistroke
.50054 .01506 L
.50182 .01506 L
.50247 .01506 L
.50316 .01506 L
.50438 .01506 L
.50571 .01506 L
.50645 .01506 L
.50715 .01506 L
.50957 .01506 L
.51217 .01506 L
.52153 .01506 L
.52424 .01506 L
.52718 .01506 L
.52853 .01506 L
.52995 .01506 L
.53119 .01506 L
.53184 .01506 L
.53252 .01506 L
.5338 .01506 L
.53497 .01506 L
.53607 .01506 L
.53728 .01506 L
.53859 .01506 L
.53933 .01506 L
.53999 .01506 L
.5413 .01506 L
.54252 .01506 L
.54484 .01506 L
.54738 .01506 L
.55253 .01506 L
.55697 .01506 L
.56174 .01506 L
.57263 .01506 L
.58255 .01506 L
.62237 .01506 L
.66067 .01506 L
.68003 .01506 L
.70141 .01506 L
.72164 .01505 L
.74065 .01505 L
.75046 .01505 L
.76081 .01505 L
.76964 .01505 L
.7793 .01505 L
.78458 .01505 L
.78956 .01505 L
.79409 .01505 L
.79889 .01505 L
.80411 .01505 L
.80894 .01505 L
Mistroke
.81412 .01505 L
.81707 .01505 L
.81983 .01505 L
.83838 .01505 L
.84347 .01505 L
.84888 .01505 L
.85399 .01505 L
.85862 .01505 L
.86386 .01505 L
.86952 .01505 L
.87977 .01505 L
.89024 .01505 L
.89987 .01505 L
.93938 .01505 L
.97619 .01505 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.03279 .05662 L
.04262 .09474 L
.04758 .10928 L
.0503 .11573 L
.05288 .1208 L
.05528 .12465 L
.05789 .12791 L
.06026 .13011 L
.06244 .13154 L
.06371 .13213 L
.06487 .13253 L
.0655 .13269 L
.0662 .13283 L
.06747 .13297 L
.06865 .13297 L
.06991 .13286 L
.0711 .13266 L
.07218 .13239 L
.07356 .13195 L
.07483 .13145 L
.0777 .13003 L
.0829 .12667 L
.10458 .10789 L
.125 .09012 L
.14407 .07602 L
.16357 .06435 L
.18204 .05561 L
.20239 .04812 L
.22095 .04287 L
.24086 .03855 L
.25928 .03549 L
.27794 .03312 L
.29854 .03114 L
.31789 .02976 L
.33875 .02866 L
.35879 .0279 L
.36899 .0276 L
.37989 .02733 L
.39023 .02713 L
.39963 .02697 L
.40908 .02685 L
.418 .02677 L
.42262 .02673 L
.42772 .0267 L
.43028 .02669 L
.43303 .02668 L
.43563 .02667 L
.43678 .02667 L
.43801 .02667 L
Mistroke
.43924 .02666 L
.44036 .02666 L
.44148 .02666 L
.44254 .02666 L
.44377 .02666 L
.44491 .02666 L
.44616 .02666 L
.44747 .02666 L
.44855 .02666 L
.44969 .02666 L
.45176 .02667 L
.45422 .02668 L
.45646 .02668 L
.46128 .02671 L
.4664 .02675 L
.47077 .02678 L
.47558 .02684 L
.48631 .02699 L
.49636 .02719 L
.51487 .02766 L
.52536 .02795 L
.5351 .02819 L
.54481 .02837 L
.55025 .02845 L
.55518 .0285 L
.55789 .02852 L
.5604 .02853 L
.5617 .02853 L
.56314 .02854 L
.56387 .02854 L
.56464 .02854 L
.56538 .02854 L
.56604 .02854 L
.56735 .02854 L
.56856 .02854 L
.56919 .02854 L
.56989 .02854 L
.5713 .02854 L
.57254 .02853 L
.57388 .02853 L
.57629 .02852 L
.58124 .02848 L
.58585 .02844 L
.59631 .02832 L
.6174 .02798 L
.65641 .0273 L
.6763 .02699 L
.69788 .02671 L
.71689 .02651 L
.73783 .02634 L
Mistroke
.75768 .02622 L
.76854 .02617 L
.77871 .02614 L
.78368 .02613 L
.7891 .02611 L
.79388 .0261 L
.79898 .0261 L
.80157 .02609 L
.80402 .02609 L
.8064 .02609 L
.80859 .02609 L
.81067 .02609 L
.81287 .02609 L
.81401 .02609 L
.81508 .02609 L
.81625 .02609 L
.8175 .02608 L
.81872 .02609 L
.81942 .02609 L
.82007 .02609 L
.82138 .02609 L
.82212 .02609 L
.8228 .02609 L
.82518 .02609 L
.82769 .02609 L
.83043 .02609 L
.83298 .02609 L
.83876 .0261 L
.84386 .02611 L
.84849 .02612 L
.85889 .02615 L
.86888 .02618 L
.87809 .02622 L
.89889 .02632 L
.93831 .02657 L
.97619 .02679 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.02846 .0369 L
.03279 .05586 L
.03754 .07313 L
.0402 .08066 L
.04262 .08604 L
.04385 .08825 L
.04516 .09021 L
.04629 .09161 L
.0475 .09284 L
.04881 .09385 L
.05003 .09455 L
.05077 .09486 L
.05148 .09508 L
.05212 .09523 L
.05281 .09533 L
.05408 .09539 L
.05523 .0953 L
.05587 .0952 L
.05656 .09505 L
.05781 .0947 L
.06022 .09375 L
.06244 .09262 L
.08253 .07836 L
.10458 .06307 L
.12523 .0517 L
.14407 .0437 L
.16358 .03735 L
.18449 .03225 L
.20358 .02877 L
.22434 .02595 L
.24411 .02397 L
.26512 .02241 L
.28459 .02135 L
.30287 .0206 L
.32305 .01998 L
.34156 .01956 L
.36048 .01924 L
.38118 .01899 L
.40079 .01882 L
.41177 .01875 L
.42174 .01869 L
.43106 .01865 L
.44093 .01862 L
.44608 .01861 L
.45175 .0186 L
.4569 .01859 L
.46172 .01858 L
.46431 .01858 L
.4667 .01858 L
Mistroke
.46808 .01858 L
.46933 .01858 L
.47003 .01858 L
.47077 .01858 L
.47148 .01858 L
.47213 .01858 L
.47332 .01858 L
.47442 .01858 L
.47564 .01858 L
.47694 .01858 L
.47759 .01858 L
.4783 .01858 L
.47959 .01858 L
.48201 .01858 L
.48423 .01858 L
.48669 .01858 L
.49165 .01859 L
.50055 .01861 L
.52156 .01866 L
.53076 .01868 L
.53562 .01869 L
.5408 .0187 L
.54345 .0187 L
.54594 .0187 L
.54836 .0187 L
.55059 .0187 L
.55169 .01871 L
.55272 .01871 L
.55378 .01871 L
.55496 .01871 L
.55615 .01871 L
.55724 .01871 L
.5585 .01871 L
.55969 .01871 L
.56082 .01871 L
.56208 .01871 L
.56462 .0187 L
.56698 .0187 L
.56919 .0187 L
.57417 .01869 L
.57954 .01869 L
.59956 .01864 L
.62065 .01859 L
.65873 .01849 L
.67995 .01844 L
.69926 .0184 L
.71955 .01837 L
.73827 .01835 L
.75743 .01834 L
.76752 .01833 L
Mistroke
.77822 .01833 L
.78764 .01832 L
.79777 .01832 L
.80733 .01832 L
.81607 .01832 L
.82593 .01832 L
.83507 .01831 L
.84034 .01831 L
.84511 .01831 L
.84776 .01831 L
.85062 .01831 L
.85193 .01831 L
.85332 .01831 L
.8545 .01831 L
.8558 .01831 L
.85711 .01831 L
.85832 .01831 L
.85895 .01831 L
.85964 .01831 L
.86037 .01831 L
.86105 .01831 L
.8623 .01831 L
.86344 .01831 L
.8647 .01831 L
.86602 .01831 L
.86832 .01831 L
.87046 .01831 L
.87533 .01831 L
.88063 .01831 L
.88544 .01832 L
.89625 .01832 L
.91545 .01832 L
.93625 .01832 L
.97619 .01833 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.03279 .05637 L
.03793 .07676 L
.04262 .09184 L
.04758 .10358 L
.0503 .10818 L
.05156 .10987 L
.05288 .11138 L
.05402 .11247 L
.05527 .11346 L
.05642 .11418 L
.05747 .1147 L
.05871 .11515 L
.05939 .11532 L
.06004 .11544 L
.06119 .11556 L
.06244 .11555 L
.06316 .11549 L
.06382 .1154 L
.06454 .11526 L
.0653 .11508 L
.06658 .11469 L
.06799 .11415 L
.07302 .1115 L
.08429 .10316 L
.10458 .08638 L
.12572 .07095 L
.145 .05963 L
.16498 .05044 L
.18391 .04372 L
.20382 .03831 L
.22224 .03448 L
.24091 .03151 L
.26151 .02903 L
.28086 .0273 L
.30171 .02591 L
.32175 .02493 L
.34285 .02417 L
.36259 .02366 L
.38096 .02332 L
.39148 .02317 L
.40142 .02305 L
.41027 .02297 L
.42001 .0229 L
.42973 .02285 L
.43504 .02283 L
.4376 .02282 L
.44002 .02281 L
.44224 .02281 L
.44467 .0228 L
Mistroke
.44573 .0228 L
.44687 .0228 L
.44794 .0228 L
.44891 .0228 L
.45016 .0228 L
.45081 .0228 L
.4515 .0228 L
.45266 .0228 L
.45393 .0228 L
.45507 .0228 L
.45628 .0228 L
.45743 .0228 L
.45847 .0228 L
.46077 .02281 L
.46329 .02281 L
.46841 .02283 L
.47315 .02285 L
.47759 .02287 L
.4876 .02294 L
.49837 .02304 L
.51806 .02328 L
.52846 .0234 L
.53417 .02346 L
.53956 .02351 L
.54474 .02355 L
.54746 .02356 L
.55034 .02357 L
.55277 .02358 L
.55406 .02359 L
.55544 .02359 L
.55671 .02359 L
.55786 .02359 L
.55903 .0236 L
.56013 .0236 L
.56122 .0236 L
.56243 .0236 L
.56369 .0236 L
.56488 .0236 L
.56598 .02359 L
.56699 .02359 L
.56928 .02359 L
.57159 .02358 L
.57413 .02358 L
.57924 .02355 L
.5895 .0235 L
.59882 .02343 L
.61977 .02325 L
.65972 .02289 L
.69815 .02262 L
.718 .02252 L
Mistroke
.73904 .02244 L
.74846 .02241 L
.75859 .02238 L
.77689 .02234 L
.78701 .02233 L
.79804 .02232 L
.80846 .02231 L
.81814 .0223 L
.83867 .02229 L
.85729 .02228 L
.86732 .02228 L
.87209 .02228 L
.87655 .02228 L
.88138 .02228 L
.88394 .02228 L
.88668 .02228 L
.88805 .02228 L
.88883 .02228 L
.88955 .02228 L
.89087 .02228 L
.89154 .02228 L
.89227 .02228 L
.89354 .02228 L
.89425 .02228 L
.8949 .02228 L
.89611 .02228 L
.89737 .02228 L
.89861 .02228 L
.89995 .02228 L
.90238 .02228 L
.90693 .02228 L
.91224 .02228 L
.91713 .02228 L
.92605 .02229 L
.9355 .02229 L
.97341 .02231 L
.97619 .02232 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.02605 .02542 L
.02846 .03566 L
.03053 .04294 L
.03279 .04901 L
.03416 .0518 L
.03543 .05383 L
.03665 .05535 L
.03793 .05657 L
.03908 .05739 L
.04016 .05795 L
.04135 .05838 L
.04262 .05865 L
.04393 .05878 L
.04516 .05878 L
.04586 .05873 L
.0465 .05867 L
.04723 .05857 L
.04793 .05845 L
.05035 .0579 L
.05297 .05712 L
.06244 .05352 L
.08293 .04524 L
.10458 .03794 L
.12413 .03284 L
.14558 .0286 L
.16509 .02572 L
.18601 .02341 L
.20725 .02169 L
.22737 .02049 L
.24728 .01961 L
.2657 .019 L
.28436 .01853 L
.30496 .01814 L
.32431 .01788 L
.34517 .01767 L
.36521 .01752 L
.37541 .01746 L
.38631 .01741 L
.39665 .01737 L
.40605 .01734 L
.41497 .01732 L
.42442 .0173 L
.4344 .01728 L
.4436 .01727 L
.44872 .01726 L
.4535 .01726 L
.45625 .01726 L
.45876 .01726 L
.46014 .01726 L
Mistroke
.46165 .01726 L
.46308 .01726 L
.4644 .01726 L
.46569 .01726 L
.46634 .01726 L
.46705 .01726 L
.46831 .01726 L
.46949 .01726 L
.47021 .01726 L
.47088 .01726 L
.47215 .01726 L
.47351 .01726 L
.47499 .01726 L
.47751 .01726 L
.48017 .01726 L
.48496 .01726 L
.48953 .01727 L
.49382 .01727 L
.50358 .01728 L
.52209 .01731 L
.53258 .01733 L
.53768 .01733 L
.54232 .01734 L
.54472 .01734 L
.54732 .01734 L
.54977 .01734 L
.55203 .01734 L
.55328 .01734 L
.55443 .01734 L
.55571 .01734 L
.55642 .01734 L
.55707 .01734 L
.55838 .01734 L
.55912 .01734 L
.55981 .01734 L
.56106 .01734 L
.5617 .01734 L
.5624 .01734 L
.56513 .01734 L
.56763 .01734 L
.57039 .01734 L
.57328 .01734 L
.58351 .01733 L
.59304 .01732 L
.60323 .01731 L
.62159 .01728 L
.66305 .01722 L
.68383 .0172 L
.703 .01718 L
.72166 .01716 L
Mistroke
.74144 .01715 L
.75086 .01715 L
.76099 .01714 L
.77929 .01714 L
.78941 .01713 L
.80044 .01713 L
.82054 .01713 L
.8612 .01713 L
.90035 .01712 L
.92034 .01712 L
.9316 .01712 L
.94195 .01712 L
.94989 .01712 L
.95445 .01712 L
.95861 .01712 L
.963 .01712 L
.96525 .01712 L
.9677 .01712 L
.96997 .01712 L
.97096 .01712 L
.97206 .01712 L
.97303 .01712 L
.97406 .01712 L
.97516 .01712 L
.97619 .01712 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04856 L
.03416 .05113 L
.03543 .05293 L
.03665 .05421 L
.03793 .05519 L
.03908 .05578 L
.04016 .05615 L
.04135 .05638 L
.04262 .05647 L
.04393 .05641 L
.04516 .05626 L
.04586 .05613 L
.0465 .056 L
.04793 .05564 L
.05297 .05395 L
.06244 .05004 L
.08269 .04188 L
.10458 .03483 L
.12545 .02981 L
.14465 .02634 L
.16347 .02377 L
.18413 .02166 L
.20364 .02019 L
.22456 .01903 L
.2458 .01817 L
.26592 .01758 L
.28583 .01714 L
.30425 .01685 L
.32291 .01662 L
.34352 .01643 L
.36286 .01631 L
.38372 .01621 L
.40376 .01614 L
.41384 .01611 L
.42486 .01609 L
.44447 .01606 L
.45545 .01604 L
.46542 .01603 L
.47027 .01603 L
.4754 .01603 L
.47984 .01602 L
.4846 .01602 L
.48972 .01602 L
.49451 .01602 L
.49743 .01602 L
.5002 .01602 L
Mistroke
.50269 .01602 L
.5041 .01602 L
.5054 .01602 L
.50669 .01602 L
.50734 .01602 L
.50806 .01602 L
.50932 .01602 L
.51049 .01602 L
.51121 .01602 L
.51188 .01602 L
.51315 .01602 L
.51451 .01602 L
.516 .01602 L
.52083 .01602 L
.52596 .01602 L
.52818 .01602 L
.53057 .01602 L
.53193 .01602 L
.53319 .01602 L
.53438 .01602 L
.53564 .01602 L
.53671 .01602 L
.53786 .01602 L
.53894 .01602 L
.53991 .01602 L
.54107 .01602 L
.54232 .01602 L
.54458 .01602 L
.54695 .01602 L
.54949 .01602 L
.55407 .01602 L
.55952 .01602 L
.5645 .01602 L
.57531 .01601 L
.58555 .01601 L
.62385 .01599 L
.6646 .01597 L
.68483 .01596 L
.70384 .01595 L
.72198 .01595 L
.74155 .01595 L
.76157 .01594 L
.77164 .01594 L
.78266 .01594 L
.80225 .01594 L
.82319 .01594 L
.86466 .01594 L
.90461 .01594 L
.94304 .01593 L
.97619 .01593 L
Mistroke
Mfstroke
1 0 .617 r
.02381 .01472 m
.03279 .05621 L
.03793 .07596 L
.04262 .08971 L
.04517 .09525 L
.04758 .09925 L
.04881 .10084 L
.05012 .10222 L
.05156 .1034 L
.05225 .10384 L
.05288 .10419 L
.05401 .10466 L
.05523 .10498 L
.05636 .10512 L
.05743 .10512 L
.05868 .10498 L
.05983 .10474 L
.0611 .10435 L
.06244 .10382 L
.06529 .10237 L
.06791 .10073 L
.07382 .09635 L
.08454 .08747 L
.10458 .07155 L
.125 .05826 L
.14407 .04861 L
.16239 .04142 L
.18204 .03553 L
.20328 .0308 L
.2234 .02749 L
.24331 .02505 L
.26173 .02336 L
.28039 .02206 L
.301 .021 L
.32034 .02026 L
.3412 .01967 L
.36124 .01926 L
.38234 .01895 L
.40208 .01875 L
.42045 .01861 L
.43097 .01855 L
.4409 .01851 L
.44982 .01848 L
.45482 .01846 L
.45949 .01845 L
.46444 .01844 L
.46896 .01843 L
.47136 .01843 L
.47398 .01843 L
.47674 .01843 L
Mistroke
.478 .01843 L
.47937 .01843 L
.48011 .01842 L
.4808 .01842 L
.48144 .01842 L
.48214 .01842 L
.48337 .01842 L
.48466 .01842 L
.48539 .01842 L
.48606 .01842 L
.48684 .01842 L
.48757 .01842 L
.48887 .01842 L
.49029 .01843 L
.49284 .01843 L
.49555 .01843 L
.50041 .01843 L
.50981 .01845 L
.51992 .01846 L
.5294 .01848 L
.53821 .01849 L
.54286 .01849 L
.54545 .0185 L
.54781 .0185 L
.54916 .0185 L
.5504 .0185 L
.55105 .0185 L
.55176 .0185 L
.55251 .0185 L
.55321 .0185 L
.55449 .0185 L
.55566 .0185 L
.55631 .0185 L
.55701 .0185 L
.55829 .0185 L
.5596 .0185 L
.56082 .0185 L
.56361 .01849 L
.56632 .01849 L
.56926 .01849 L
.57941 .01848 L
.58896 .01846 L
.59942 .01843 L
.62051 .01838 L
.66104 .01828 L
.67975 .01824 L
.70006 .01821 L
.72138 .01818 L
.74152 .01816 L
.76137 .01815 L
Mistroke
.77139 .01814 L
.78241 .01814 L
.80183 .01813 L
.81274 .01813 L
.82272 .01813 L
.86244 .01812 L
.90066 .01811 L
.94132 .0181 L
.97619 .0181 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.03279 .05686 L
.04262 .09749 L
.04758 .11465 L
.05288 .12978 L
.05546 .13578 L
.05789 .14062 L
.06024 .14451 L
.06244 .14747 L
.06487 .14997 L
.06616 .151 L
.06754 .15188 L
.06824 .15223 L
.06899 .15255 L
.06966 .15279 L
.07037 .15298 L
.07107 .15312 L
.07171 .15321 L
.07295 .15326 L
.0742 .15318 L
.07535 .15298 L
.07661 .15263 L
.07794 .15215 L
.08019 .15105 L
.08265 .14951 L
.08812 .1451 L
.09399 .13935 L
.10458 .12771 L
.12439 .10593 L
.14594 .08569 L
.16488 .07148 L
.18579 .05928 L
.20556 .05047 L
.22657 .04341 L
.24592 .03852 L
.26677 .03456 L
.28681 .03173 L
.30791 .02953 L
.32765 .02801 L
.34602 .02696 L
.36648 .02609 L
.38506 .02552 L
.40425 .0251 L
.41507 .02492 L
.42505 .0248 L
.42972 .02475 L
.43474 .02471 L
.43908 .02468 L
.44381 .02465 L
.44668 .02463 L
Mistroke
.44934 .02462 L
.4521 .02461 L
.4533 .02461 L
.4546 .02461 L
.45588 .02461 L
.45705 .0246 L
.45818 .0246 L
.45937 .0246 L
.46062 .0246 L
.46179 .0246 L
.46308 .0246 L
.4638 .0246 L
.46445 .0246 L
.46563 .0246 L
.46674 .02461 L
.46927 .02461 L
.47174 .02462 L
.47439 .02463 L
.47918 .02465 L
.48357 .02468 L
.4937 .02477 L
.50435 .02489 L
.52435 .02519 L
.53307 .02531 L
.54251 .02542 L
.54777 .02547 L
.55008 .02549 L
.55262 .0255 L
.55486 .02551 L
.55726 .02552 L
.55858 .02552 L
.55979 .02553 L
.56101 .02553 L
.56216 .02553 L
.56336 .02553 L
.56404 .02553 L
.56468 .02553 L
.56598 .02553 L
.5667 .02553 L
.56737 .02553 L
.56849 .02553 L
.56972 .02553 L
.57219 .02552 L
.57493 .02551 L
.57785 .0255 L
.58312 .02547 L
.59335 .02538 L
.60444 .02526 L
.62459 .02502 L
.66547 .02452 L
Mistroke
.68581 .02432 L
.70484 .02416 L
.72309 .02404 L
.7427 .02394 L
.75281 .0239 L
.76385 .02387 L
.77439 .02384 L
.78394 .02382 L
.79408 .0238 L
.80363 .02379 L
.81371 .02378 L
.81939 .02378 L
.82461 .02378 L
.82931 .02377 L
.83195 .02377 L
.83435 .02377 L
.83659 .02377 L
.83786 .02377 L
.83903 .02377 L
.84004 .02377 L
.84117 .02377 L
.84235 .02377 L
.84345 .02377 L
.84466 .02377 L
.84598 .02377 L
.84664 .02377 L
.84736 .02377 L
.84864 .02377 L
.85113 .02377 L
.8534 .02377 L
.85891 .02378 L
.86412 .02378 L
.87385 .02378 L
.88414 .02379 L
.9026 .0238 L
.92088 .02382 L
.93095 .02382 L
.94051 .02383 L
.94483 .02383 L
.94943 .02383 L
.95208 .02383 L
.95448 .02383 L
.95689 .02383 L
.95797 .02383 L
.95916 .02383 L
.96016 .02383 L
.96124 .02383 L
.96237 .02383 L
.96343 .02383 L
.96448 .02383 L
Mistroke
.96548 .02383 L
.96638 .02383 L
.96735 .02383 L
.96841 .02383 L
.96958 .02383 L
.97195 .02383 L
.97414 .02383 L
.97619 .02383 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.03279 .05625 L
.03793 .07618 L
.04262 .0904 L
.04517 .09634 L
.04758 .10078 L
.05012 .10428 L
.05156 .10576 L
.05288 .10683 L
.05402 .10755 L
.05509 .10806 L
.05626 .10845 L
.05752 .10869 L
.05884 .10876 L
.06009 .10868 L
.06122 .10849 L
.06244 .10818 L
.06382 .10771 L
.0653 .10707 L
.06799 .10565 L
.07302 .10229 L
.08429 .09321 L
.10458 .07662 L
.12413 .06312 L
.14558 .05151 L
.166 .04316 L
.18507 .03723 L
.20542 .03246 L
.22398 .02918 L
.24306 .02662 L
.26382 .02454 L
.2836 .02308 L
.30461 .02193 L
.32408 .02115 L
.34236 .0206 L
.36254 .02015 L
.38104 .01985 L
.39997 .01962 L
.41069 .01952 L
.42067 .01945 L
.43119 .01938 L
.44113 .01934 L
.45005 .01931 L
.45508 .01929 L
.45971 .01928 L
.46439 .01928 L
.46701 .01927 L
.46941 .01927 L
.47163 .01927 L
.47289 .01927 L
Mistroke
.47406 .01927 L
.47518 .01927 L
.4762 .01927 L
.47737 .01927 L
.47848 .01927 L
.47968 .01927 L
.48099 .01927 L
.48237 .01927 L
.48365 .01927 L
.48594 .01927 L
.4884 .01928 L
.49401 .01928 L
.49912 .01929 L
.51985 .01935 L
.52897 .01938 L
.53381 .01939 L
.53901 .01941 L
.54403 .01942 L
.54623 .01942 L
.54863 .01942 L
.55075 .01942 L
.55302 .01943 L
.55427 .01943 L
.55541 .01943 L
.55656 .01943 L
.55764 .01943 L
.55878 .01943 L
.56004 .01943 L
.56135 .01943 L
.56258 .01943 L
.56372 .01943 L
.56477 .01943 L
.56713 .01942 L
.56965 .01942 L
.5724 .01942 L
.5774 .01941 L
.58678 .01939 L
.59715 .01936 L
.61815 .01929 L
.65832 .01914 L
.69697 .01904 L
.71699 .019 L
.73808 .01896 L
.74761 .01895 L
.7578 .01894 L
.77616 .01893 L
.78638 .01892 L
.79748 .01892 L
.80795 .01892 L
.81762 .01891 L
Mistroke
.83636 .01891 L
.84702 .01891 L
.85699 .01891 L
.86738 .01891 L
.87725 .01891 L
.89578 .01891 L
.90611 .01891 L
.91583 .01891 L
.934 .0189 L
.94346 .0189 L
.95368 .0189 L
.97466 .0189 L
.97619 .0189 L
Mfstroke
1 0 .545 r
.02381 .01472 m
.02846 .03633 L
.03279 .05283 L
.03523 .06013 L
.03754 .06566 L
.0402 .0705 L
.04135 .07214 L
.04262 .07366 L
.04377 .0748 L
.04502 .0758 L
.04633 .07663 L
.04756 .07721 L
.04878 .07762 L
.04994 .07788 L
.05099 .07801 L
.05212 .07806 L
.05282 .07805 L
.05348 .07801 L
.05471 .07786 L
.05541 .07774 L
.05604 .07762 L
.05748 .07726 L
.05989 .0765 L
.06244 .0755 L
.10458 .05354 L
.12444 .04514 L
.14255 .03909 L
.16206 .03401 L
.18298 .02989 L
.20206 .02706 L
.22282 .02474 L
.2426 .0231 L
.2636 .02181 L
.28307 .02093 L
.30135 .0203 L
.32154 .01978 L
.34004 .01943 L
.35897 .01916 L
.37967 .01894 L
.39928 .0188 L
.41025 .01874 L
.42023 .01869 L
.43021 .01866 L
.43941 .01864 L
.44422 .01863 L
.44951 .01862 L
.45218 .01861 L
.45504 .01861 L
.45774 .01861 L
.46021 .01861 L
Mistroke
.4615 .01861 L
.46272 .01861 L
.46381 .01861 L
.46499 .01861 L
.46628 .01861 L
.46693 .01861 L
.46764 .01861 L
.4689 .01861 L
.47008 .01861 L
.47127 .01861 L
.47239 .01861 L
.4745 .01861 L
.47677 .01861 L
.47923 .01861 L
.48446 .01862 L
.49001 .01863 L
.49997 .01865 L
.5197 .01871 L
.52834 .01873 L
.53777 .01875 L
.54267 .01876 L
.54722 .01877 L
.54974 .01877 L
.55203 .01877 L
.5533 .01878 L
.55467 .01878 L
.55596 .01878 L
.55716 .01878 L
.55836 .01878 L
.55966 .01878 L
.56088 .01878 L
.56199 .01878 L
.5633 .01878 L
.56403 .01878 L
.56472 .01878 L
.56605 .01878 L
.5673 .01878 L
.56977 .01877 L
.5725 .01877 L
.57803 .01877 L
.58784 .01875 L
.59819 .01873 L
.61668 .01868 L
.65476 .01857 L
.67598 .01852 L
.69529 .01848 L
.71558 .01844 L
.7343 .01842 L
.75346 .0184 L
.76356 .01839 L
Mistroke
.77425 .01839 L
.78367 .01838 L
.7938 .01838 L
.80336 .01838 L
.81211 .01837 L
.81688 .01837 L
.82196 .01837 L
.82676 .01837 L
.8311 .01837 L
.83378 .01837 L
.83623 .01837 L
.83893 .01837 L
.84029 .01837 L
.84106 .01837 L
.84178 .01837 L
.84309 .01837 L
.84429 .01837 L
.84558 .01837 L
.84631 .01837 L
.84698 .01837 L
.8481 .01837 L
.84933 .01837 L
.85062 .01837 L
.85183 .01837 L
.85427 .01837 L
.85654 .01837 L
.86168 .01837 L
.86668 .01837 L
.87203 .01837 L
.88173 .01837 L
.89054 .01838 L
.93054 .01838 L
.94924 .01839 L
.95867 .01839 L
.96903 .01839 L
.97619 .01839 L
Mfstroke
1 0 .522 r
.02381 .01472 m
.02605 .02542 L
.02846 .03563 L
.03053 .04285 L
.03279 .04878 L
.03416 .05145 L
.03543 .05336 L
.03665 .05475 L
.03793 .05584 L
.03908 .05653 L
.04016 .05698 L
.04135 .0573 L
.04262 .05747 L
.04393 .05749 L
.04516 .0574 L
.04586 .05731 L
.0465 .0572 L
.04793 .0569 L
.05052 .05618 L
.05297 .05535 L
.06244 .05155 L
.08439 .0427 L
.10458 .03613 L
.12333 .0314 L
.14313 .02759 L
.16277 .02476 L
.1811 .02276 L
.20145 .02109 L
.22001 .01995 L
.2391 .01907 L
.25986 .01836 L
.27963 .01787 L
.30064 .01748 L
.32011 .01722 L
.33839 .01704 L
.35857 .01689 L
.37708 .01679 L
.396 .01671 L
.40672 .01668 L
.4167 .01665 L
.42722 .01663 L
.43716 .01662 L
.44608 .0166 L
.45107 .0166 L
.45575 .01659 L
.46069 .01659 L
.46521 .01659 L
.46761 .01659 L
.47023 .01659 L
.473 .01659 L
Mistroke
.47426 .01659 L
.47562 .01659 L
.47637 .01659 L
.47705 .01659 L
.47769 .01659 L
.4784 .01658 L
.47962 .01658 L
.48091 .01658 L
.48165 .01658 L
.48232 .01658 L
.48309 .01658 L
.48382 .01658 L
.48513 .01659 L
.48654 .01659 L
.48909 .01659 L
.4918 .01659 L
.49666 .01659 L
.50606 .01659 L
.51617 .0166 L
.52566 .01661 L
.53447 .01661 L
.53911 .01661 L
.54171 .01661 L
.54406 .01661 L
.54532 .01661 L
.54665 .01661 L
.54735 .01661 L
.54811 .01661 L
.54882 .01661 L
.54946 .01661 L
.55073 .01661 L
.55143 .01661 L
.55209 .01661 L
.55327 .01661 L
.55455 .01661 L
.55585 .01661 L
.55707 .01661 L
.55841 .01661 L
.55986 .01661 L
.56281 .01661 L
.56551 .01661 L
.57045 .01661 L
.57566 .01661 L
.59538 .01659 L
.61374 .01658 L
.65275 .01654 L
.67264 .01653 L
.69421 .01651 L
.71499 .0165 L
.73416 .0165 L
Mistroke
.7529 .01649 L
.76356 .01649 L
.77353 .01649 L
.78392 .01649 L
.7938 .01649 L
.80266 .01648 L
.81233 .01648 L
.83201 .01648 L
.85299 .01648 L
.87298 .01648 L
.88349 .01648 L
.89459 .01648 L
.90455 .01648 L
.90983 .01648 L
.91548 .01648 L
.92067 .01648 L
.92541 .01648 L
.92769 .01648 L
.93017 .01648 L
.93252 .01648 L
.93468 .01648 L
.93702 .01648 L
.93824 .01648 L
.93953 .01648 L
.94066 .01648 L
.94171 .01648 L
.94286 .01648 L
.94409 .01648 L
.94479 .01648 L
.94543 .01648 L
.94614 .01648 L
.94689 .01648 L
.94815 .01648 L
.94953 .01648 L
.95208 .01648 L
.95447 .01648 L
.95977 .01648 L
.9646 .01648 L
.97548 .01648 L
.97619 .01648 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.02846 .03632 L
.03279 .05274 L
.03527 .06006 L
.03754 .06535 L
.04015 .06996 L
.04132 .07158 L
.04262 .07306 L
.04377 .07414 L
.04502 .07509 L
.04633 .07586 L
.04756 .07639 L
.04878 .07677 L
.04994 .077 L
.05099 .07711 L
.05212 .07714 L
.05282 .07712 L
.05348 .07707 L
.05471 .07691 L
.05541 .07679 L
.05604 .07666 L
.05748 .0763 L
.06244 .07456 L
.07221 .06986 L
.08293 .0641 L
.10458 .05315 L
.12572 .04446 L
.145 .03826 L
.16498 .03331 L
.18391 .02972 L
.20382 .02685 L
.22224 .02483 L
.24091 .02327 L
.26151 .02197 L
.28086 .02106 L
.30171 .02034 L
.32175 .01982 L
.34285 .01943 L
.36259 .01916 L
.38096 .01898 L
.39148 .0189 L
.40142 .01883 L
.42001 .01874 L
.42973 .01871 L
.43504 .01869 L
.44002 .01868 L
.44461 .01867 L
.44881 .01867 L
.45347 .01866 L
.45603 .01866 L
Mistroke
.45847 .01866 L
.45972 .01865 L
.46107 .01865 L
.46226 .01865 L
.46352 .01865 L
.46465 .01865 L
.4659 .01865 L
.46703 .01865 L
.46808 .01865 L
.46872 .01865 L
.46941 .01865 L
.47067 .01865 L
.47189 .01865 L
.47303 .01865 L
.47559 .01866 L
.47832 .01866 L
.48283 .01866 L
.48707 .01867 L
.49672 .01869 L
.50657 .01871 L
.51694 .01875 L
.52665 .01877 L
.53546 .0188 L
.54005 .01881 L
.54503 .01882 L
.54776 .01882 L
.55028 .01882 L
.55269 .01883 L
.55402 .01883 L
.55524 .01883 L
.55628 .01883 L
.55742 .01883 L
.55862 .01883 L
.55977 .01883 L
.56083 .01883 L
.56196 .01883 L
.56293 .01883 L
.564 .01883 L
.56524 .01883 L
.56638 .01883 L
.56896 .01883 L
.57123 .01882 L
.57362 .01882 L
.57861 .01882 L
.58315 .01881 L
.59333 .01879 L
.61169 .01874 L
.65164 .01862 L
.69008 .01853 L
.70993 .01849 L
Mistroke
.73096 .01846 L
.75051 .01844 L
.76882 .01843 L
.77921 .01842 L
.78908 .01842 L
.79794 .01842 L
.80761 .01841 L
.81794 .01841 L
.8273 .01841 L
.83249 .01841 L
.8381 .01841 L
.84336 .01841 L
.84828 .01841 L
.85287 .01841 L
.85544 .01841 L
.85779 .01841 L
.85912 .01841 L
.86036 .01841 L
.86171 .01841 L
.8624 .01841 L
.86315 .01841 L
.86441 .01841 L
.86512 .01841 L
.86577 .01841 L
.86697 .01841 L
.86823 .01841 L
.86955 .01841 L
.87075 .01841 L
.87344 .01841 L
.87594 .01841 L
.87829 .01841 L
.88358 .01841 L
.8893 .01841 L
.90919 .01841 L
.93024 .01841 L
.93968 .01841 L
.94489 .01841 L
.94983 .01841 L
.95441 .01841 L
.95683 .01841 L
.9594 .01841 L
.96063 .01841 L
.96178 .01841 L
.96291 .01841 L
.96394 .01841 L
.96492 .01841 L
.96596 .01841 L
.967 .01841 L
.96814 .01841 L
.96919 .01841 L
Mistroke
.97018 .01841 L
.97107 .01841 L
.97203 .01841 L
.97419 .01841 L
.97619 .01841 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.02846 .03631 L
.03279 .05261 L
.03527 .05978 L
.03754 .06487 L
.03879 .06714 L
.04015 .0692 L
.04142 .07079 L
.04262 .072 L
.04386 .07301 L
.045 .07373 L
.04626 .07433 L
.04696 .07458 L
.04762 .07477 L
.04894 .07503 L
.05016 .07513 L
.05086 .07514 L
.0515 .07511 L
.05223 .07506 L
.05293 .07497 L
.05408 .07478 L
.05531 .0745 L
.0575 .07385 L
.06244 .0719 L
.08424 .06055 L
.10458 .0506 L
.12408 .04287 L
.14255 .0371 L
.1629 .0322 L
.18146 .0288 L
.20137 .02602 L
.21979 .02407 L
.23845 .02256 L
.25906 .02131 L
.2784 .02044 L
.29926 .01975 L
.3193 .01926 L
.3404 .01888 L
.36014 .01862 L
.37851 .01844 L
.38903 .01836 L
.39896 .0183 L
.41755 .01821 L
.42727 .01818 L
.43757 .01815 L
.44635 .01813 L
.45135 .01812 L
.45602 .01812 L
.461 .01811 L
.46381 .01811 L
Mistroke
.46516 .01811 L
.46643 .01811 L
.46763 .01811 L
.46894 .01811 L
.47012 .01811 L
.47121 .01811 L
.47239 .01811 L
.47369 .01811 L
.47434 .01811 L
.47504 .01811 L
.47631 .01811 L
.47755 .01811 L
.4787 .01811 L
.48129 .01811 L
.48358 .01811 L
.48601 .01812 L
.49484 .01813 L
.50424 .01814 L
.51435 .01816 L
.53265 .0182 L
.53729 .01821 L
.54224 .01822 L
.54509 .01822 L
.54768 .01822 L
.55013 .01823 L
.55273 .01823 L
.55402 .01823 L
.55471 .01823 L
.55544 .01823 L
.55674 .01823 L
.55794 .01823 L
.55867 .01823 L
.55946 .01823 L
.56021 .01823 L
.5609 .01823 L
.5622 .01823 L
.56286 .01823 L
.56359 .01823 L
.56613 .01823 L
.56756 .01823 L
.56887 .01823 L
.57384 .01822 L
.57857 .01822 L
.58363 .01821 L
.59274 .01819 L
.61343 .01815 L
.6549 .01805 L
.67567 .01801 L
.69485 .01798 L
.71469 .01795 L
Mistroke
.73328 .01793 L
.75202 .01792 L
.76196 .01791 L
.77265 .01791 L
.78276 .01791 L
.7938 .0179 L
.80422 .0179 L
.81389 .0179 L
.82447 .0179 L
.83443 .0179 L
.84337 .0179 L
.85304 .01789 L
.86256 .01789 L
.86796 .01789 L
.873 .01789 L
.87573 .01789 L
.87832 .01789 L
.88064 .01789 L
.88317 .01789 L
.88447 .01789 L
.88591 .01789 L
.88664 .01789 L
.88742 .01789 L
.88816 .01789 L
.88883 .01789 L
.89005 .01789 L
.89074 .01789 L
.89138 .01789 L
.89268 .01789 L
.89341 .01789 L
.89407 .01789 L
.89638 .01789 L
.89892 .01789 L
.90406 .01789 L
.91327 .01789 L
.91845 .01789 L
.92131 .01789 L
.92402 .01789 L
.92653 .01789 L
.92786 .01789 L
.92927 .01789 L
.93058 .01789 L
.93176 .01789 L
.93295 .01789 L
.93407 .01789 L
.93524 .01789 L
.93649 .01789 L
.93767 .01789 L
.93874 .01789 L
.94001 .01789 L
Mistroke
.94138 .01789 L
.94387 .01789 L
.94648 .01789 L
.94924 .01789 L
.9542 .01789 L
.95874 .01789 L
.963 .01789 L
.97269 .01789 L
.97619 .01789 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02149 L
.03638 .02145 L
.03746 .0214 L
.04262 .02111 L
.06244 .0198 L
.08259 .01865 L
.10458 .0177 L
.12517 .01703 L
.14429 .01656 L
.16481 .01619 L
.18342 .01594 L
.20266 .01574 L
.22348 .01558 L
.24342 .01547 L
.26449 .01539 L
.28413 .01533 L
.30246 .01529 L
.32281 .01525 L
.34137 .01523 L
.36045 .01521 L
.38121 .0152 L
.40099 .01519 L
.41097 .01518 L
.422 .01518 L
.43142 .01518 L
.44134 .01518 L
.44654 .01518 L
.45222 .01518 L
.4622 .01517 L
.46748 .01517 L
.47008 .01517 L
.47247 .01517 L
.47461 .01517 L
.47695 .01517 L
.47931 .01517 L
.4806 .01517 L
.48181 .01517 L
.4831 .01517 L
.48384 .01517 L
.48452 .01517 L
Mistroke
.48576 .01517 L
.48646 .01517 L
.48709 .01517 L
.48828 .01517 L
.48957 .01517 L
.49079 .01517 L
.49191 .01517 L
.49443 .01517 L
.49719 .01517 L
.50276 .01517 L
.51365 .01517 L
.52395 .01517 L
.52843 .01518 L
.53319 .01518 L
.53567 .01518 L
.53841 .01518 L
.53961 .01518 L
.5409 .01518 L
.54213 .01518 L
.54324 .01518 L
.54442 .01518 L
.54569 .01518 L
.54687 .01518 L
.54797 .01518 L
.54927 .01518 L
.55046 .01518 L
.55177 .01518 L
.55315 .01518 L
.55572 .01518 L
.55812 .01518 L
.56357 .01518 L
.56827 .01518 L
.57256 .01517 L
.5822 .01517 L
.62201 .01517 L
.66031 .01517 L
.67967 .01516 L
.70106 .01516 L
.72129 .01516 L
.74029 .01516 L
.75011 .01516 L
.76045 .01516 L
.77014 .01516 L
.77895 .01516 L
.78848 .01516 L
.79866 .01516 L
.8081 .01516 L
.81702 .01516 L
.83532 .01516 L
.85546 .01516 L
Mistroke
.87531 .01516 L
.89634 .01516 L
.93665 .01516 L
.97544 .01516 L
.97619 .01516 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.03279 .05637 L
.03793 .07676 L
.04262 .09181 L
.045 .09797 L
.04758 .10346 L
.0503 .10796 L
.05153 .10956 L
.05288 .11104 L
.05404 .11209 L
.0553 .113 L
.05662 .11373 L
.05785 .11421 L
.05908 .11452 L
.06025 .11466 L
.0613 .11467 L
.06244 .11457 L
.06316 .11445 L
.06382 .11431 L
.0653 .11388 L
.06661 .11338 L
.06799 .11275 L
.07302 .10975 L
.08429 .10077 L
.10458 .08335 L
.12444 .06854 L
.14255 .05765 L
.16206 .04843 L
.18298 .04092 L
.20206 .03574 L
.22282 .03151 L
.2426 .0285 L
.2636 .02613 L
.28307 .0245 L
.30135 .02335 L
.32154 .0224 L
.34004 .02174 L
.35897 .02125 L
.37967 .02085 L
.39928 .02058 L
.41025 .02047 L
.42023 .02039 L
.42955 .02033 L
.43941 .02028 L
.44456 .02025 L
.45023 .02024 L
.45539 .02022 L
.46021 .02021 L
.46279 .02021 L
.46519 .02021 L
Mistroke
.46657 .02021 L
.46782 .02021 L
.46851 .02021 L
.46926 .02021 L
.46997 .02021 L
.47062 .02021 L
.4718 .02021 L
.47291 .02021 L
.47412 .02021 L
.47542 .02021 L
.47679 .02021 L
.47808 .02021 L
.4805 .02021 L
.48274 .02022 L
.48511 .02022 L
.48938 .02023 L
.49903 .02026 L
.51877 .02035 L
.5274 .02039 L
.53684 .02042 L
.54141 .02044 L
.54628 .02045 L
.54899 .02046 L
.55144 .02046 L
.55262 .02046 L
.5539 .02046 L
.55502 .02046 L
.55622 .02046 L
.55752 .02046 L
.55874 .02047 L
.55948 .02047 L
.56018 .02047 L
.5615 .02047 L
.56217 .02046 L
.56289 .02046 L
.56418 .02046 L
.56556 .02046 L
.56709 .02046 L
.56957 .02046 L
.57224 .02045 L
.57709 .02044 L
.58665 .02042 L
.59711 .02038 L
.6182 .02028 L
.65873 .02008 L
.69774 .01994 L
.71906 .01988 L
.73921 .01984 L
.74891 .01983 L
.75919 .01982 L
Mistroke
.77764 .0198 L
.78706 .01979 L
.79719 .01978 L
.80675 .01978 L
.81549 .01978 L
.82535 .01978 L
.83449 .01977 L
.84453 .01977 L
.85522 .01977 L
.86552 .01977 L
.87093 .01977 L
.87665 .01977 L
.88166 .01977 L
.88716 .01977 L
.89683 .01977 L
.90769 .01977 L
.91799 .01977 L
.92722 .01977 L
.93244 .01977 L
.93727 .01977 L
.94624 .01977 L
.95615 .01977 L
.96649 .01976 L
.97619 .01976 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.02605 .02542 L
.02846 .03563 L
.03053 .04285 L
.03279 .04876 L
.03416 .05142 L
.03543 .05331 L
.03665 .05469 L
.03793 .05576 L
.03908 .05644 L
.04016 .05687 L
.04135 .05717 L
.04262 .05732 L
.04393 .05732 L
.04516 .05721 L
.04586 .05711 L
.0465 .057 L
.04793 .05668 L
.05052 .05593 L
.05297 .05507 L
.06244 .0512 L
.08439 .04229 L
.10458 .0357 L
.12333 .03099 L
.14313 .0272 L
.16277 .02438 L
.1811 .02239 L
.20145 .02074 L
.22001 .01962 L
.2391 .01875 L
.25986 .01805 L
.27963 .01756 L
.30064 .01718 L
.32011 .01692 L
.33839 .01674 L
.35857 .01659 L
.37708 .01649 L
.396 .01642 L
.40685 .01639 L
.4167 .01636 L
.43631 .01632 L
.44709 .01631 L
.45726 .0163 L
.46698 .01629 L
.47188 .01629 L
.47727 .01628 L
.48187 .01628 L
.48445 .01628 L
.48567 .01628 L
.48681 .01628 L
Mistroke
.48796 .01628 L
.489 .01628 L
.49015 .01628 L
.49138 .01628 L
.49246 .01628 L
.49362 .01628 L
.49472 .01628 L
.49573 .01628 L
.497 .01628 L
.4982 .01628 L
.50044 .01628 L
.50286 .01628 L
.50549 .01628 L
.51459 .01629 L
.52443 .01629 L
.52965 .01629 L
.53239 .01629 L
.53527 .01629 L
.53782 .01629 L
.53926 .01629 L
.54061 .01629 L
.54185 .01629 L
.54297 .01629 L
.54427 .01629 L
.54549 .01629 L
.54666 .01629 L
.54789 .01629 L
.54894 .01629 L
.5501 .01629 L
.55267 .01629 L
.55508 .01629 L
.56038 .01629 L
.56522 .01629 L
.5761 .01628 L
.59516 .01627 L
.61591 .01626 L
.65666 .01623 L
.67689 .01622 L
.6959 .01621 L
.71426 .01621 L
.73362 .0162 L
.74324 .0162 L
.75377 .0162 L
.77227 .01619 L
.78253 .01619 L
.79186 .01619 L
.80263 .01619 L
.8128 .01619 L
.85123 .01619 L
.89212 .01619 L
Mistroke
.93149 .01619 L
.96935 .01619 L
.97619 .01619 L
Mfstroke
1 0 .379 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01857 L
.10458 .0176 L
.12517 .01693 L
.14429 .01646 L
.16481 .01608 L
.18342 .01583 L
.20266 .01563 L
.22348 .01547 L
.24342 .01536 L
.26449 .01527 L
.28413 .01521 L
.30246 .01517 L
.32281 .01514 L
.34137 .01511 L
.36045 .0151 L
.38121 .01508 L
.40099 .01507 L
.4111 .01507 L
.422 .01506 L
.43215 .01506 L
.44147 .01506 L
.4503 .01506 L
.45975 .01506 L
.46955 .01506 L
.47867 .01506 L
.48425 .01505 L
.48952 .01505 L
.49424 .01505 L
.49937 .01505 L
.50426 .01505 L
.50884 .01505 L
.51146 .01505 L
.51385 .01505 L
.51925 .01505 L
.52453 .01505 L
Mistroke
.53017 .01505 L
.5329 .01505 L
.53548 .01505 L
.54029 .01505 L
.54505 .01505 L
.54943 .01505 L
.55931 .01505 L
.5694 .01505 L
.58005 .01505 L
.61807 .01505 L
.65855 .01505 L
.67722 .01505 L
.69751 .01505 L
.71879 .01505 L
.72837 .01504 L
.73892 .01504 L
.75874 .01504 L
.76959 .01504 L
.77976 .01504 L
.78962 .01504 L
.79998 .01504 L
.8185 .01504 L
.8385 .01504 L
.85666 .01504 L
.87631 .01504 L
.89727 .01504 L
.93731 .01504 L
.97582 .01504 L
.97619 .01504 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.02605 .02534 L
.02846 .03496 L
.02962 .03866 L
.03072 .04153 L
.0317 .04358 L
.03279 .04536 L
.03398 .0468 L
.03524 .04785 L
.03641 .04849 L
.0375 .04886 L
.03879 .04909 L
.03997 .04914 L
.04062 .04911 L
.04132 .04905 L
.04262 .04887 L
.04326 .04875 L
.04396 .0486 L
.04523 .04829 L
.04759 .0476 L
.0529 .0458 L
.06244 .04231 L
.08293 .03557 L
.10458 .03009 L
.12413 .0264 L
.14558 .0234 L
.16509 .0214 L
.18601 .01982 L
.20725 .01865 L
.22737 .01785 L
.24728 .01726 L
.2657 .01686 L
.28436 .01655 L
.30496 .0163 L
.32431 .01613 L
.34517 .01599 L
.36521 .0159 L
.38631 .01583 L
.40605 .01578 L
.42442 .01575 L
.43494 .01573 L
.44487 .01572 L
.45372 .01571 L
.46346 .01571 L
.47318 .0157 L
.47814 .0157 L
.48347 .0157 L
.48846 .0157 L
.49301 .0157 L
.49758 .0157 L
Mistroke
.50193 .01569 L
.50453 .01569 L
.50697 .01569 L
.51154 .01569 L
.5141 .01569 L
.51646 .01569 L
.52177 .01569 L
.52641 .01569 L
.53073 .01569 L
.53523 .01569 L
.53762 .01569 L
.54017 .01569 L
.54547 .01569 L
.55037 .01569 L
.56145 .01569 L
.57122 .01569 L
.58159 .01568 L
.61939 .01567 L
.65964 .01566 L
.67816 .01565 L
.69838 .01565 L
.71846 .01565 L
.72953 .01565 L
.73958 .01564 L
.75922 .01564 L
.77002 .01564 L
.78019 .01564 L
.78994 .01564 L
.80024 .01564 L
.81871 .01564 L
.85665 .01564 L
.87613 .01564 L
.89704 .01564 L
.93837 .01564 L
.97619 .01564 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.02605 .02534 L
.02846 .03499 L
.02962 .03873 L
.03072 .04165 L
.0317 .04376 L
.03279 .04561 L
.03398 .04713 L
.03524 .04827 L
.03641 .04899 L
.0375 .04942 L
.03879 .04971 L
.03997 .04981 L
.04062 .04981 L
.04132 .04978 L
.04262 .04964 L
.04326 .04953 L
.04396 .0494 L
.04523 .04912 L
.04759 .04847 L
.0529 .0467 L
.06244 .04322 L
.08293 .03635 L
.10458 .03071 L
.12413 .02689 L
.14558 .02378 L
.16509 .0217 L
.18601 .02005 L
.20725 .01883 L
.22737 .01799 L
.24728 .01737 L
.2657 .01695 L
.28436 .01663 L
.30496 .01636 L
.32431 .01618 L
.34517 .01604 L
.36521 .01594 L
.38631 .01586 L
.40605 .01581 L
.42442 .01578 L
.43494 .01576 L
.44487 .01575 L
.45372 .01574 L
.46346 .01573 L
.47318 .01573 L
.47814 .01572 L
.48347 .01572 L
.48846 .01572 L
.49301 .01572 L
.49758 .01572 L
Mistroke
.50193 .01572 L
.50453 .01572 L
.50697 .01572 L
.51154 .01572 L
.5141 .01572 L
.51646 .01572 L
.52177 .01572 L
.52634 .01572 L
.53066 .01572 L
.53305 .01572 L
.53564 .01571 L
.54017 .01571 L
.54525 .01571 L
.54993 .01571 L
.55903 .01571 L
.56907 .01571 L
.57971 .01571 L
.61751 .01569 L
.65777 .01568 L
.69651 .01567 L
.71659 .01567 L
.7268 .01567 L
.7377 .01566 L
.74807 .01566 L
.75748 .01566 L
.77586 .01566 L
.78587 .01566 L
.79509 .01566 L
.8159 .01566 L
.85535 .01566 L
.89329 .01566 L
.93368 .01566 L
.97256 .01565 L
.97619 .01565 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.03279 .05633 L
.03793 .07649 L
.04262 .09096 L
.04517 .09702 L
.04758 .10154 L
.05012 .10507 L
.05156 .10655 L
.05288 .1076 L
.05402 .10829 L
.05509 .10877 L
.05626 .10912 L
.05752 .10931 L
.05884 .10932 L
.06009 .10918 L
.06122 .10894 L
.06244 .10856 L
.06382 .10802 L
.0653 .10731 L
.06799 .10574 L
.07302 .10216 L
.08429 .09269 L
.10458 .07579 L
.12413 .06223 L
.14558 .05066 L
.166 .04238 L
.18507 .03653 L
.20542 .03182 L
.22398 .0286 L
.24306 .02609 L
.26382 .02405 L
.2836 .02262 L
.30461 .0215 L
.32408 .02074 L
.34236 .02021 L
.36254 .01977 L
.38104 .01947 L
.39997 .01925 L
.41069 .01916 L
.42067 .01908 L
.43119 .01902 L
.44113 .01897 L
.45005 .01894 L
.45504 .01893 L
.45971 .01892 L
.46428 .01891 L
.46918 .0189 L
.47197 .0189 L
.47334 .0189 L
.47462 .0189 L
Mistroke
.47587 .0189 L
.477 .0189 L
.47825 .01889 L
.47894 .01889 L
.47959 .01889 L
.48081 .01889 L
.48151 .01889 L
.48215 .01889 L
.48346 .01889 L
.48419 .0189 L
.48486 .0189 L
.48605 .0189 L
.48735 .0189 L
.48971 .0189 L
.49246 .0189 L
.49538 .0189 L
.50063 .01891 L
.52037 .01895 L
.529 .01897 L
.53844 .01899 L
.54081 .01899 L
.54333 .019 L
.54552 .019 L
.54789 .019 L
.54928 .019 L
.55057 .019 L
.55179 .019 L
.55309 .019 L
.55426 .019 L
.55535 .019 L
.55654 .019 L
.55782 .019 L
.5585 .019 L
.55921 .019 L
.5605 .019 L
.56189 .019 L
.56342 .019 L
.56616 .019 L
.56873 .01899 L
.57352 .01899 L
.57869 .01898 L
.59871 .01893 L
.6198 .01887 L
.65787 .01875 L
.6791 .0187 L
.6984 .01866 L
.71846 .01862 L
.73742 .0186 L
.74712 .01859 L
.75741 .01858 L
Mistroke
.77585 .01857 L
.78527 .01857 L
.7954 .01856 L
.81371 .01856 L
.85495 .01855 L
.89468 .01854 L
.93289 .01853 L
.97356 .01852 L
.97619 .01852 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.02605 .02534 L
.02846 .03503 L
.02962 .03883 L
.03072 .04182 L
.0317 .04401 L
.03279 .04596 L
.03398 .04761 L
.03524 .04889 L
.03641 .04973 L
.0375 .05027 L
.03879 .05067 L
.03997 .05086 L
.04062 .05091 L
.04132 .05092 L
.04262 .05086 L
.04326 .05079 L
.04396 .05069 L
.04523 .05046 L
.04759 .0499 L
.0529 .04825 L
.06244 .04483 L
.08293 .03785 L
.10458 .032 L
.12413 .02799 L
.14558 .02471 L
.16509 .0225 L
.18601 .02074 L
.20725 .01943 L
.22737 .01852 L
.24728 .01786 L
.2657 .0174 L
.28436 .01705 L
.30496 .01677 L
.32431 .01657 L
.34517 .01641 L
.36521 .0163 L
.38631 .01622 L
.40605 .01616 L
.42442 .01613 L
.43494 .01611 L
.44487 .0161 L
.45379 .01609 L
.46346 .01608 L
.46802 .01608 L
.47293 .01608 L
.4783 .01608 L
.48334 .01608 L
.48604 .01607 L
.48746 .01607 L
Mistroke
.48898 .01607 L
.49044 .01607 L
.49176 .01607 L
.49239 .01607 L
.49308 .01607 L
.49433 .01607 L
.49555 .01607 L
.49624 .01607 L
.49688 .01607 L
.49818 .01607 L
.49891 .01607 L
.49957 .01607 L
.50204 .01607 L
.50438 .01607 L
.50898 .01608 L
.51406 .01608 L
.52433 .01608 L
.52891 .01608 L
.53384 .01608 L
.53611 .01608 L
.5385 .01608 L
.54054 .01608 L
.54162 .01608 L
.54276 .01608 L
.54339 .01608 L
.54409 .01608 L
.54531 .01608 L
.54599 .01608 L
.54673 .01608 L
.54743 .01608 L
.54806 .01608 L
.54929 .01608 L
.54999 .01608 L
.55063 .01608 L
.55181 .01608 L
.55306 .01608 L
.55535 .01608 L
.5575 .01608 L
.56241 .01608 L
.56767 .01608 L
.57249 .01608 L
.58337 .01607 L
.62297 .01605 L
.66104 .01603 L
.68227 .01602 L
.70157 .01601 L
.72163 .01601 L
.74058 .01601 L
.75029 .016 L
.76057 .016 L
Mistroke
.77902 .016 L
.78844 .016 L
.79857 .016 L
.81687 .016 L
.85812 .016 L
.89785 .016 L
.93606 .01599 L
.97619 .01599 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04856 L
.03416 .05112 L
.03543 .05292 L
.03665 .0542 L
.03793 .05518 L
.03908 .05577 L
.04016 .05614 L
.04135 .05637 L
.04262 .05645 L
.04393 .05639 L
.04516 .05624 L
.04586 .05611 L
.0465 .05598 L
.04793 .05562 L
.05297 .05392 L
.06244 .05001 L
.08269 .04185 L
.10458 .03481 L
.12545 .02979 L
.14465 .02632 L
.16347 .02376 L
.18413 .02165 L
.20364 .02019 L
.22456 .01903 L
.2458 .01817 L
.26592 .01758 L
.28583 .01715 L
.30425 .01685 L
.32291 .01662 L
.34352 .01644 L
.36286 .01631 L
.38372 .01621 L
.40376 .01614 L
.41384 .01612 L
.42486 .01609 L
.44447 .01606 L
.45545 .01605 L
.46542 .01604 L
.47027 .01603 L
.4754 .01603 L
.47984 .01603 L
.4846 .01603 L
.48972 .01603 L
.49451 .01602 L
.49743 .01602 L
.49887 .01602 L
Mistroke
.5002 .01602 L
.50151 .01602 L
.50269 .01602 L
.504 .01602 L
.50468 .01602 L
.5054 .01602 L
.50661 .01602 L
.50773 .01602 L
.50842 .01602 L
.50907 .01602 L
.51029 .01602 L
.51158 .01602 L
.51276 .01602 L
.51545 .01602 L
.51993 .01602 L
.52469 .01602 L
.52946 .01602 L
.53077 .01602 L
.53214 .01602 L
.53333 .01602 L
.5346 .01602 L
.53533 .01602 L
.53599 .01602 L
.53729 .01602 L
.53802 .01602 L
.53881 .01602 L
.53955 .01602 L
.54023 .01602 L
.54146 .01602 L
.54215 .01602 L
.5428 .01602 L
.54412 .01602 L
.54552 .01602 L
.54811 .01602 L
.55052 .01602 L
.55595 .01602 L
.56065 .01602 L
.56585 .01602 L
.5844 .01601 L
.62457 .01599 L
.66322 .01597 L
.68285 .01597 L
.70433 .01596 L
.72483 .01595 L
.74392 .01595 L
.75443 .01595 L
.76435 .01595 L
.78293 .01595 L
.79264 .01595 L
.80292 .01595 L
Mistroke
.82137 .01594 L
.85922 .01594 L
.89953 .01594 L
.93832 .01594 L
.97619 .01594 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.03279 .05621 L
.03793 .07595 L
.04262 .08967 L
.04517 .09519 L
.04758 .09914 L
.0489 .10082 L
.05012 .10208 L
.05146 .10316 L
.0522 .10363 L
.05288 .10399 L
.05401 .10444 L
.05523 .10474 L
.05636 .10486 L
.05743 .10484 L
.05868 .10468 L
.05983 .10442 L
.0611 .10401 L
.06244 .10346 L
.06791 .10031 L
.07382 .0959 L
.08454 .08699 L
.10458 .07112 L
.12413 .05841 L
.14558 .04767 L
.166 .04001 L
.18507 .03461 L
.20542 .03029 L
.22398 .02732 L
.24306 .02502 L
.26382 .02316 L
.2836 .02185 L
.30461 .02083 L
.32408 .02013 L
.34236 .01964 L
.36254 .01924 L
.38104 .01897 L
.39997 .01877 L
.41069 .01868 L
.42067 .01862 L
.43119 .01856 L
.44113 .01852 L
.45005 .01849 L
.45504 .01847 L
.45971 .01846 L
.46466 .01845 L
.46918 .01845 L
.47158 .01844 L
.4742 .01844 L
.47563 .01844 L
Mistroke
.47696 .01844 L
.47833 .01844 L
.47959 .01844 L
.48091 .01844 L
.48161 .01844 L
.48235 .01844 L
.48358 .01844 L
.48428 .01844 L
.48494 .01844 L
.48616 .01844 L
.48728 .01844 L
.48856 .01844 L
.48978 .01844 L
.49248 .01844 L
.49498 .01844 L
.50063 .01845 L
.51029 .01846 L
.51933 .01847 L
.52938 .01849 L
.53486 .0185 L
.53995 .0185 L
.54236 .0185 L
.54463 .01851 L
.54588 .01851 L
.54724 .01851 L
.54848 .01851 L
.54962 .01851 L
.55088 .01851 L
.55206 .01851 L
.55336 .01851 L
.55408 .01851 L
.55475 .01851 L
.55544 .01851 L
.55608 .01851 L
.55753 .01851 L
.55881 .01851 L
.56017 .01851 L
.56471 .0185 L
.56897 .0185 L
.57869 .01848 L
.58851 .01847 L
.59885 .01844 L
.61735 .01839 L
.65542 .0183 L
.67665 .01825 L
.69595 .01822 L
.71601 .01819 L
.73496 .01817 L
.74467 .01817 L
.75495 .01816 L
Mistroke
.7734 .01815 L
.78282 .01814 L
.79295 .01814 L
.81125 .01814 L
.8525 .01813 L
.89223 .01812 L
.93044 .01811 L
.9711 .0181 L
.97619 .0181 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01858 L
.10458 .01761 L
.12517 .01694 L
.14429 .01647 L
.16481 .0161 L
.18342 .01584 L
.20266 .01565 L
.22348 .01549 L
.24342 .01538 L
.26449 .01529 L
.28413 .01524 L
.30246 .0152 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .01511 L
.40099 .0151 L
.41097 .0151 L
.422 .01509 L
.44134 .01509 L
.45222 .01509 L
.4622 .01509 L
.46694 .01508 L
.472 .01508 L
.47638 .01508 L
.48112 .01508 L
.48403 .01508 L
.4867 .01508 L
.48921 .01508 L
.49197 .01508 L
.49444 .01508 L
.49675 .01508 L
.49801 .01508 L
.4992 .01508 L
.50057 .01508 L
Mistroke
.50182 .01508 L
.50307 .01508 L
.50378 .01508 L
.50442 .01508 L
.50561 .01508 L
.50687 .01508 L
.50799 .01508 L
.50905 .01508 L
.51143 .01508 L
.51638 .01508 L
.52167 .01508 L
.52404 .01508 L
.52529 .01508 L
.52662 .01508 L
.52777 .01508 L
.52905 .01508 L
.53021 .01508 L
.5313 .01508 L
.53237 .01508 L
.5335 .01508 L
.53447 .01508 L
.53552 .01508 L
.53666 .01508 L
.53788 .01508 L
.54007 .01508 L
.54267 .01508 L
.54541 .01508 L
.55034 .01508 L
.55563 .01508 L
.56145 .01508 L
.58162 .01508 L
.62201 .01508 L
.66089 .01508 L
.68067 .01508 L
.70221 .01507 L
.72289 .01507 L
.73276 .01507 L
.74203 .01507 L
.76067 .01507 L
.77057 .01507 L
.78126 .01507 L
.79082 .01507 L
.80128 .01507 L
.82237 .01507 L
.8436 .01507 L
.8629 .01507 L
.88296 .01507 L
.90191 .01507 L
.94035 .01507 L
.97619 .01507 L
Mistroke
Mfstroke
1 0 .19 r
.02381 .01472 m
.02499 .0186 L
.02605 .02012 L
.02729 .02098 L
.02846 .02141 L
.02954 .02165 L
.03053 .02179 L
.03163 .02189 L
.03279 .02196 L
.03395 .02199 L
.0352 .02199 L
.03638 .02198 L
.03746 .02196 L
.03873 .02192 L
.04011 .02187 L
.04262 .02175 L
.06244 .02054 L
.08284 .01935 L
.10458 .01832 L
.1259 .01756 L
.14523 .01703 L
.16447 .01662 L
.18529 .01629 L
.20523 .01606 L
.22629 .01587 L
.24593 .01575 L
.26427 .01566 L
.28462 .01558 L
.30318 .01553 L
.32226 .01549 L
.34302 .01546 L
.36279 .01543 L
.3838 .01542 L
.39317 .01541 L
.40327 .01541 L
.42155 .0154 L
.43112 .0154 L
.44159 .01539 L
.44688 .01539 L
.45252 .01539 L
.45785 .01539 L
.46269 .01539 L
.465 .01539 L
.46754 .01539 L
.46882 .01539 L
.47019 .01539 L
.47149 .01539 L
.47267 .01539 L
.47385 .01539 L
.47493 .01539 L
Mistroke
.47613 .01539 L
.4774 .01539 L
.47861 .01539 L
.47975 .01539 L
.48188 .01539 L
.48441 .01539 L
.48709 .01539 L
.49188 .01539 L
.50268 .01539 L
.52258 .0154 L
.53126 .0154 L
.53584 .0154 L
.5407 .0154 L
.54318 .0154 L
.54592 .0154 L
.54712 .0154 L
.54841 .0154 L
.54962 .0154 L
.55074 .0154 L
.5519 .0154 L
.55316 .0154 L
.55439 .0154 L
.5557 .0154 L
.55693 .0154 L
.55809 .0154 L
.55912 .0154 L
.56025 .0154 L
.56277 .0154 L
.56554 .0154 L
.57114 .0154 L
.57633 .0154 L
.58118 .0154 L
.6015 .01539 L
.62005 .01539 L
.65986 .01538 L
.69816 .01538 L
.71791 .01538 L
.73891 .01537 L
.74827 .01537 L
.75836 .01537 L
.77663 .01537 L
.78619 .01537 L
.79665 .01537 L
.80757 .01537 L
.81774 .01537 L
.85675 .01537 L
.89822 .01537 L
.93817 .01537 L
.97619 .01537 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02137 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02122 L
.04262 .0209 L
.06244 .01954 L
.08259 .01839 L
.10458 .01744 L
.12517 .01679 L
.14429 .01634 L
.16481 .01598 L
.18342 .01573 L
.20266 .01554 L
.22348 .01539 L
.24342 .01529 L
.26449 .01521 L
.28413 .01515 L
.30246 .01511 L
.32281 .01508 L
.34137 .01506 L
.36045 .01504 L
.38121 .01503 L
.40099 .01502 L
.4111 .01502 L
.422 .01502 L
.43215 .01501 L
.44147 .01501 L
.45975 .01501 L
.46955 .01501 L
.47867 .01501 L
.48868 .01501 L
.49428 .01501 L
.49937 .01501 L
.50935 .01501 L
.51856 .015 L
.5293 .015 L
.53935 .015 L
.5484 .015 L
.55812 .015 L
.57876 .015 L
.62003 .015 L
Mistroke
.64066 .015 L
.65979 .015 L
.6795 .015 L
.69804 .015 L
.7186 .015 L
.73722 .015 L
.74701 .015 L
.75734 .015 L
.76701 .015 L
.77582 .015 L
.78533 .015 L
.7955 .015 L
.80493 .015 L
.81385 .015 L
.8321 .015 L
.84249 .015 L
.85223 .015 L
.87204 .015 L
.89306 .015 L
.9318 .015 L
.97299 .015 L
.97619 .015 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.02605 .02542 L
.02846 .03561 L
.03053 .04277 L
.03279 .04857 L
.03416 .05114 L
.03543 .05294 L
.03665 .05423 L
.03793 .05522 L
.03908 .05582 L
.04016 .0562 L
.04135 .05643 L
.04262 .05652 L
.04393 .05648 L
.04516 .05633 L
.04586 .0562 L
.0465 .05607 L
.04793 .05572 L
.05297 .05405 L
.06244 .05015 L
.08269 .042 L
.10458 .03496 L
.12545 .02992 L
.14465 .02644 L
.16347 .02386 L
.18413 .02175 L
.20364 .02027 L
.22456 .01911 L
.2458 .01824 L
.26592 .01765 L
.28583 .01721 L
.30425 .01691 L
.32291 .01669 L
.34352 .0165 L
.36286 .01637 L
.38372 .01627 L
.40376 .0162 L
.41384 .01618 L
.42486 .01615 L
.44447 .01612 L
.45545 .01611 L
.46542 .0161 L
.47027 .01609 L
.4754 .01609 L
.47984 .01609 L
.4846 .01609 L
.48728 .01609 L
.48972 .01609 L
.4922 .01609 L
.49451 .01608 L
Mistroke
.49718 .01608 L
.49859 .01608 L
.49932 .01608 L
.5001 .01608 L
.50084 .01608 L
.50153 .01608 L
.50219 .01608 L
.50288 .01608 L
.50408 .01608 L
.5054 .01608 L
.50671 .01608 L
.50792 .01608 L
.50925 .01608 L
.51066 .01608 L
.51563 .01608 L
.52495 .01609 L
.52974 .01609 L
.53226 .01609 L
.5349 .01609 L
.53632 .01609 L
.53712 .01609 L
.53786 .01609 L
.53917 .01609 L
.5399 .01609 L
.54057 .01609 L
.54188 .01609 L
.54262 .01609 L
.5433 .01609 L
.54455 .01609 L
.54588 .01609 L
.54842 .01609 L
.55082 .01609 L
.55534 .01609 L
.5602 .01608 L
.56549 .01608 L
.57501 .01608 L
.58382 .01608 L
.62305 .01605 L
.66077 .01603 L
.68172 .01602 L
.70094 .01602 L
.71976 .01601 L
.7396 .01601 L
.74912 .01601 L
.75931 .01601 L
.77767 .016 L
.7879 .016 L
.79899 .016 L
.81914 .016 L
.8386 .016 L
Mistroke
.86002 .016 L
.89939 .016 L
.9397 .016 L
.97619 .01599 L
Mfstroke
1 0 .119 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .0215 L
.03279 .02152 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01978 L
.08259 .01862 L
.10458 .01765 L
.12517 .01697 L
.14429 .0165 L
.16481 .01613 L
.18342 .01587 L
.20266 .01567 L
.22348 .01551 L
.24342 .0154 L
.26449 .01532 L
.28413 .01526 L
.30246 .01522 L
.32281 .01518 L
.34137 .01516 L
.36045 .01514 L
.38121 .01513 L
.40099 .01512 L
.41097 .01511 L
.422 .01511 L
.44134 .01511 L
.45222 .0151 L
.4622 .0151 L
.46694 .0151 L
.472 .0151 L
.47638 .0151 L
.48112 .0151 L
.48403 .0151 L
.4867 .0151 L
.48921 .0151 L
.49197 .0151 L
.49444 .0151 L
.49675 .0151 L
.49803 .0151 L
.4992 .0151 L
.49984 .0151 L
Mistroke
.50054 .0151 L
.50182 .0151 L
.50247 .0151 L
.50316 .0151 L
.50438 .0151 L
.50571 .0151 L
.50645 .0151 L
.50715 .0151 L
.50957 .0151 L
.51217 .0151 L
.52153 .0151 L
.52424 .0151 L
.52567 .0151 L
.52718 .0151 L
.5285 .0151 L
.5292 .0151 L
.52995 .0151 L
.53065 .0151 L
.53128 .0151 L
.53252 .0151 L
.53373 .0151 L
.53485 .0151 L
.53608 .0151 L
.53739 .0151 L
.53806 .0151 L
.53878 .0151 L
.54008 .0151 L
.54252 .0151 L
.54489 .0151 L
.54743 .0151 L
.55201 .0151 L
.55746 .0151 L
.56244 .0151 L
.58349 .0151 L
.6233 .0151 L
.6616 .01509 L
.68096 .01509 L
.70235 .01509 L
.72258 .01509 L
.74159 .01509 L
.7514 .01509 L
.76174 .01509 L
.77143 .01509 L
.78024 .01509 L
.78977 .01509 L
.79996 .01509 L
.81832 .01509 L
.83909 .01509 L
.85827 .01509 L
.8967 .01509 L
Mistroke
.93607 .01509 L
.97393 .01509 L
.97619 .01509 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02124 L
.03053 .02132 L
.03163 .02137 L
.03279 .02137 L
.03395 .02136 L
.0352 .02132 L
.03638 .02127 L
.03746 .02122 L
.04262 .0209 L
.06244 .01954 L
.08259 .01839 L
.10458 .01744 L
.12517 .01678 L
.14429 .01633 L
.16481 .01597 L
.18342 .01573 L
.20266 .01554 L
.22348 .01539 L
.24342 .01528 L
.26449 .0152 L
.28413 .01514 L
.30246 .0151 L
.32281 .01507 L
.34137 .01505 L
.36045 .01503 L
.38121 .01502 L
.40099 .01501 L
.4111 .01501 L
.422 .015 L
.43215 .015 L
.44147 .015 L
.45975 .015 L
.46955 .015 L
.47867 .01499 L
.48868 .01499 L
.49424 .01499 L
.49937 .01499 L
.50961 .01499 L
.51501 .01499 L
.52072 .01499 L
.53043 .01499 L
.54087 .01499 L
.56044 .01499 L
.57876 .01499 L
.62003 .01499 L
Mistroke
.65979 .01499 L
.67986 .01499 L
.69804 .01499 L
.71775 .01499 L
.72869 .01498 L
.73874 .01498 L
.75802 .01498 L
.76816 .01498 L
.77885 .01498 L
.78836 .01498 L
.79853 .01498 L
.81688 .01498 L
.83673 .01498 L
.85829 .01498 L
.87903 .01498 L
.89819 .01498 L
.93751 .01498 L
.97531 .01498 L
.97619 .01498 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01974 L
.08259 .01857 L
.10458 .0176 L
.12517 .01692 L
.14429 .01646 L
.16481 .01608 L
.18342 .01582 L
.20266 .01563 L
.22348 .01547 L
.24342 .01536 L
.26449 .01527 L
.28413 .01521 L
.30246 .01517 L
.32281 .01514 L
.34137 .01511 L
.36045 .0151 L
.38121 .01508 L
.40099 .01507 L
.4111 .01507 L
.422 .01506 L
.43215 .01506 L
.44147 .01506 L
.45975 .01506 L
.46955 .01506 L
.47867 .01505 L
.48382 .01505 L
.48868 .01505 L
.49428 .01505 L
.49937 .01505 L
.504 .01505 L
.50663 .01505 L
.50909 .01505 L
.51405 .01505 L
.51684 .01505 L
.51938 .01505 L
.52832 .01505 L
Mistroke
.53331 .01505 L
.53784 .01505 L
.54292 .01505 L
.54771 .01505 L
.55686 .01505 L
.56683 .01505 L
.5776 .01505 L
.61865 .01505 L
.65819 .01505 L
.69622 .01505 L
.71576 .01504 L
.73669 .01504 L
.74689 .01504 L
.75797 .01504 L
.76755 .01504 L
.77811 .01504 L
.78833 .01504 L
.79792 .01504 L
.81894 .01504 L
.83745 .01504 L
.85768 .01504 L
.87776 .01504 L
.89887 .01504 L
.93949 .01504 L
.97619 .01504 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.02499 .01856 L
.02605 .01999 L
.02729 .02074 L
.02846 .02108 L
.02954 .02125 L
.03053 .02133 L
.03163 .02137 L
.03279 .02138 L
.03395 .02137 L
.0352 .02133 L
.03638 .02128 L
.03746 .02123 L
.04262 .02092 L
.06244 .01958 L
.08259 .01844 L
.10458 .01749 L
.12517 .01684 L
.14429 .01639 L
.16481 .01603 L
.18342 .01579 L
.20266 .0156 L
.22348 .01545 L
.24342 .01534 L
.26449 .01526 L
.28413 .0152 L
.30246 .01516 L
.32281 .01513 L
.34137 .01511 L
.36045 .01509 L
.38121 .01508 L
.40099 .01507 L
.4111 .01507 L
.422 .01506 L
.43215 .01506 L
.44147 .01506 L
.4503 .01506 L
.45975 .01506 L
.46955 .01505 L
.47867 .01505 L
.48425 .01505 L
.48952 .01505 L
.49424 .01505 L
.49691 .01505 L
.49937 .01505 L
.50181 .01505 L
.50404 .01505 L
.50528 .01505 L
.50662 .01505 L
.50789 .01505 L
Mistroke
.50906 .01505 L
.51025 .01505 L
.51137 .01505 L
.51237 .01505 L
.51346 .01505 L
.51464 .01505 L
.51589 .01505 L
.51813 .01505 L
.52289 .01505 L
.5255 .01505 L
.52798 .01505 L
.52938 .01505 L
.53017 .01505 L
.5309 .01505 L
.5322 .01505 L
.53285 .01505 L
.53357 .01505 L
.53486 .01505 L
.53559 .01505 L
.53625 .01505 L
.53748 .01505 L
.53877 .01505 L
.54136 .01505 L
.54379 .01505 L
.54834 .01505 L
.5509 .01505 L
.55325 .01505 L
.55855 .01505 L
.56749 .01505 L
.57693 .01505 L
.61487 .01505 L
.65527 .01505 L
.69414 .01505 L
.71536 .01504 L
.73547 .01504 L
.74511 .01504 L
.75536 .01504 L
.77377 .01504 L
.78312 .01504 L
.79321 .01504 L
.81149 .01504 L
.83111 .01504 L
.85259 .01504 L
.8731 .01504 L
.89219 .01504 L
.9312 .01504 L
.97266 .01504 L
.97619 .01504 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .0208 L
.02846 .02116 L
.02954 .02134 L
.03053 .02144 L
.03163 .02149 L
.03279 .02151 L
.03395 .02151 L
.0352 .02148 L
.03638 .02144 L
.03746 .02139 L
.04262 .0211 L
.06244 .01976 L
.08259 .0186 L
.10458 .01763 L
.12517 .01696 L
.14429 .01649 L
.16481 .01611 L
.18342 .01586 L
.20266 .01566 L
.22348 .0155 L
.24342 .01539 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .01511 L
.40099 .0151 L
.4111 .01509 L
.422 .01509 L
.43215 .01509 L
.44147 .01509 L
.4503 .01508 L
.45975 .01508 L
.46955 .01508 L
.47867 .01508 L
.48425 .01508 L
.48952 .01508 L
.49424 .01508 L
.49691 .01508 L
.49937 .01508 L
.50181 .01508 L
.50404 .01508 L
.50528 .01508 L
.50662 .01508 L
.50789 .01508 L
Mistroke
.50906 .01508 L
.51025 .01508 L
.51137 .01508 L
.51237 .01508 L
.51346 .01508 L
.51464 .01508 L
.51589 .01508 L
.51813 .01508 L
.52289 .01508 L
.5255 .01508 L
.52679 .01508 L
.52798 .01508 L
.52865 .01508 L
.52938 .01508 L
.53012 .01508 L
.5309 .01508 L
.53157 .01508 L
.53228 .01508 L
.53357 .01508 L
.5342 .01508 L
.53489 .01508 L
.53628 .01508 L
.53757 .01508 L
.53877 .01508 L
.54141 .01508 L
.54384 .01508 L
.54651 .01508 L
.54932 .01508 L
.55406 .01508 L
.55927 .01508 L
.56889 .01508 L
.57787 .01508 L
.61675 .01508 L
.65808 .01507 L
.67875 .01507 L
.69789 .01507 L
.71645 .01507 L
.73619 .01507 L
.74554 .01507 L
.75563 .01507 L
.7739 .01507 L
.78346 .01507 L
.79392 .01507 L
.81501 .01507 L
.83624 .01507 L
.85554 .01507 L
.8756 .01507 L
.89455 .01507 L
.93299 .01507 L
.97387 .01507 L
Mistroke
.97619 .01507 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .01857 L
.02605 .02003 L
.02729 .02079 L
.02846 .02116 L
.02954 .02134 L
.03053 .02143 L
.03163 .02149 L
.03279 .02151 L
.03395 .0215 L
.0352 .02147 L
.03638 .02143 L
.03746 .02138 L
.04262 .02108 L
.06244 .01975 L
.08259 .01859 L
.10458 .01762 L
.12517 .01695 L
.14429 .01648 L
.16481 .0161 L
.18342 .01585 L
.20266 .01565 L
.22348 .0155 L
.24342 .01538 L
.26449 .0153 L
.28413 .01524 L
.30246 .0152 L
.32281 .01516 L
.34137 .01514 L
.36045 .01512 L
.38121 .01511 L
.40099 .0151 L
.4111 .0151 L
.422 .01509 L
.43215 .01509 L
.44147 .01509 L
.4503 .01509 L
.45975 .01508 L
.46955 .01508 L
.47867 .01508 L
.48425 .01508 L
.48699 .01508 L
.48952 .01508 L
.49424 .01508 L
.49673 .01508 L
.498 .01508 L
.49937 .01508 L
.50068 .01508 L
.5019 .01508 L
.50306 .01508 L
Mistroke
.5043 .01508 L
.50552 .01508 L
.50667 .01508 L
.5077 .01508 L
.50881 .01508 L
.51003 .01508 L
.51073 .01508 L
.51138 .01508 L
.51409 .01508 L
.51643 .01508 L
.51894 .01508 L
.52387 .01508 L
.52629 .01508 L
.52853 .01508 L
.53056 .01508 L
.53158 .01508 L
.53271 .01508 L
.53384 .01508 L
.53506 .01508 L
.53621 .01508 L
.53726 .01508 L
.53854 .01508 L
.53975 .01508 L
.54084 .01508 L
.54201 .01508 L
.54465 .01508 L
.54709 .01508 L
.55153 .01508 L
.55622 .01508 L
.56609 .01508 L
.57693 .01508 L
.61733 .01508 L
.6562 .01508 L
.67599 .01507 L
.69753 .01507 L
.7182 .01507 L
.73734 .01507 L
.75599 .01507 L
.7666 .01507 L
.77658 .01507 L
.78639 .01507 L
.79674 .01507 L
.81523 .01507 L
.83518 .01507 L
.85331 .01507 L
.8729 .01507 L
.89384 .01507 L
.93379 .01507 L
.97222 .01507 L
.97619 .01507 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 370.812},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001LR000`400?l00000o`00003ooooooooo
oooooe[ooooo001Nooooo`Go00000oooool2o`0004;ooooo0ol00003ooooo`;o0000@_ooool3o`00
00Cooooo0_l00011ooooo`?o00001?ooool2o`0003oooooo0ol00004ooooo`;o00001?ooool2o`00
03_ooooo0ol00002ooooo`Go00000oooool2o`0003_ooooo0ol00004ooooo`?o00000oooool2o`00
02oooooo001Oooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000@_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000?oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo0000?oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0/ooooo`00H?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0003oooooo1Ol00002ooooo`04o`000?oooooo
ooooo`00043ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003oo
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003_o
oooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?ooooooooooo`0002kooooo001Qoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0mooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo0000@?ooool4o`0000?ooooo00Co0000oooooooooooo
0000@?ooool3o`0000?ooooo00Co0000oooooooooooo0000?oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000>oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0iooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0;?ooool005kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`00043ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00010ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000?oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000?oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000>oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool0000^ooooo`00G_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo0000@Oooool2o`0000?ooooo00Co0000
oooooooooooo0000@Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0003oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003kooooo0_l00004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000>_ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003[ooooo0_l00005ooooo`;o
00000oooool01?l0003oooooooooool0000^ooooo`006_ooool00ol0003oooooooooo`12ooooo`?o
00001?ooool2o`0004?ooooo00?o0000ooooooooool00_ooool2o`0004?ooooo0_l00004ooooo`;o
0000@Oooool3o`0000Cooooo0_l00010ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
0000??ooool00ol0003oooooooooo`02ooooo`?o00001?ooool2o`0003cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`;o0000;oooool001[ooooo00?o0000ooooooooool0
ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_ooool0
0ol0003oooooooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0oooooooooooo
ocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_ooool00ol0003ooooo
ooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000J
ooooo`03o`000?oooooooooo0?oooooooooooolmooooo`003?ooool>o`000003ool00?l0003o0000
063o00003?oo01Soool00<7oo`003_l00001ooooo`006_ooool00ooo003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooooljool002Goo`0`oooo02BLool090oo
oooo000Jooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool01ooooolIool000goo`0`
2?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo0onU0?l<ool0E0_oo`18
6?oo02@8ool0I`coo`252ooo0:TTool0NOooo`0lFOoo03`?ooooo`006_ooool00ooo02Coo`00oooo
o`0>ooooo`_oo`003Ooo030Qooooo`03o`000?oooooo0<3o00[o0<3o0_nU0?l;ool0E1Soo`0T2?oo
08D<ool0ZA[oo`1i;Ooo03`Pool0CS3oo`1]9?oo04kTool0K@oooooo000Jooooo`03o`000?oo02Co
o`0000koo`00<_ooool9o`30o`03ojD0oooo05Coo`1D00Woo`1D3?oo02@00ooo04Soo`1Wool0I`07
ool0I`?oo`2Y2ol0og48o`3oAPcoo`1i0_oo07lHool0?0_oo`1>8Ooo06eEom`0ob_oQ`3oG_oL0?mk
ool0/0oooooo000Jooooo`03o`000?oo02Cooooo03_ooooo1Ol0`?l00onU0?ooo`1Dool0E007ool0
E0;oo`182Ooo02@00ooo04Soo`1Wool0I`07ool0I`?oo`2Y2_l0og400ol0odKoo`1iool0N@0Bool0
N@03ool0Oooo08_oo`0l00_oo`0l3?oo04hFool0K@gog03odooo0;2Kool0U`oooooo000Jooooo`03
o`000?oo02Cooooo03Gooooo1Ol0`?l7ool0E0Goo`181_oo02@8ool0I`;oo`2Y0_oolP09o`3oL@Co
0?m60oooK@05ool0N@[oo`1o00?oo`2fool0??oo03`02Ooo03`3ool0CPWoo`2A2ooo06d<oooooaSo
o`2`3Ooo0<S6ool0UbCoa03o9?oo0>ICol@0o`oooooo000Jooooo`03o`000?oo02Cooooo02oooooo
1Ol0`?l6ool0E0Koo`181_oo02@3ool0I`;oo`2500?oo`2Yooob0?oolP001?oolP06o`3oL@03oooo
ool0odKo0?m600Co0?m62Ooo07T4ool0O`?oo`2f2Ooo03`8ool0CP?oo`2A3?oo06dGool0/0koo`38
5ooo09M=ool0_0_oo`3V0_n=0?l]ol@0oa;oS@3ob?oo0;`?ooooo`006_ooool00ol0003oo`0Tool0
?00Zooooo`Go0<3o1Ooo05@6ool0B003oooooooo02Coo`0T00?oo`0T00?oo`1Wool0QOoo08D00ooo
08D00ooo0:Wooo80ooob0003ooob00Ko0?ma1?l0odH9ool0N@Coo`1o1_oo0;H00ooo09goo`0lool0
?003ool0?0Woo`1>0_od0?l9ool0K@;ooi402Ooo0;0<o`16o`;o0?nQ00?oT`3oool0b?oo0<P01ooo
0<P3ol@0o`_oo`2G5_oo0;`8oooh0003oonl0?oo0?Soo`3h03[oo`3h1?oon005ooX0odcoo`2l0_oo
0>HAooX0o`;oooP01?ook0000olb0?ooo`3hool0n02/ool0n0oooooo000Jooooo`03o`000?oo02Co
o`0l02Gooooo1Ol0`?l5ool0E0Goo`1800?ohP3ooolN0?oo02@01?oo02@2ool0I`?oo`250_oo0:T4
ooob00Ko0?ma1Ol0odH5ool0N@03ooo20?oo07ooo`1o00Coo`1o00?oQ`3oool0]_oo0;H00ooo0;H0
0ooL0?ooo`2Mool0?004ool0?0Goo`1>1Ood0?l6ool0K@Gooi401_oo0;09o`16o`03o`3oj_l0oj7o
T`3o00KoT`3o1_oo0<P<ool0U`Koo`2l1?oo0>H00ooo_03oo`3hool0n00Mool0n0Ko<P3o>_oo0=@O
ool0n0Goon`02Ooon009ooo/03Goo`3h[_oo0=@?ooooo`006_ooool00ol0003oo`1iool0900Qoooo
o`Co0<3o0_oo05/3ool0E0Goo`180_oR0?l00ooo7P3oo`0Tool09002ool090?oo`1W00Coo`25ool0
ZOoo0:Woo`2Y1?oolP05o`3oL@03ooooool0odKo0?m600?o0?m61Ooo07T00ooo08_oo`1oool0O`03
ool0O`;oQ`3o1Ooo0;H00ooL0?ooo`2Mool0W@04ool0?0Goo`1>1?od0?l6ool0K@03oooP0?ooT@3o
oi4000;ooi401_oo0;06o`16o`;o0?nQ2?nC0?l5ool0b0Woo`2G1ooo0;`2ool0iP?ooooo2ooo0?P;
oc80oa[oo`3D>_l08_lEool0e0?o0;Co1olb0?lGool0n0?o<P3o2_l0]?lXool0e2Oo02;oIOoooolR
olCo00oooooo000Jooooo`03o`000?ooooooo`0T01gooooo1?l0`?l3ool0F`?oo`1D0ooo04P4on80
o`Coo`0T0_oo06L00ooo08Goo`2Yool0Z@02ool0Z@04ooob0?oocP3oojT0oonY00Co0?ma00?ooooo
o`3oA_l0odH00ol0odH00oooK@3oo`1iool0N@02ool0N@03ool0Rooo07ooo`1o00?oo`1o00?oQ`3o
ooooooooool01?oo0;H2om`0o`;oo`2M1?oo03`4ool0CP?om03o1_oo06d00oooh03ooi40oonA0003
oonA00Goo`2`1_l0A_l2o`3oX@KoT`3o1_oo0<P00ooo0;coo`2Gool0U`04ool0U`Coo`2l0_oo0>H3
ooooo`coo`3h2_ooool<ool0e1Co02;o=Oo4o`03ooCo00Sooooo5?l08_l00oooooooo`3Dool0e00/
ool0e2;o02;o5_ooool00oodo`3oa?l0olCo000;olCo093o0;[o3oooool001[ooooo00Co0000oooo
oooo02Coj03o6?ooool4o`30o`04oooooooo05_oo`1Kool0F`?oo`1D0ooo04P3on80o`Coo`0T00?o
o`1Wool0QOoo08D01?oo0:T00ooocP3oojT0oonY0002oonY00?o0?ma1Ol0odH2oom]00Coo`1i00?o
o`2;ool0Oooo07l00_oo07l01?n70?ooooooooooooooool4ool0]P;og03o00?oA03oool0WOoo03`0
0ooo03`4ool0CP;om03o1Ooo06d00oooh03ooi40oonA0003oonA00Koo`2`1Ol0A_l00oooooooS@3o
oi<0o`05oi<0o`03ohd0oooo0<Soo`3800Coo`2l1_oo09L00ooo0>Koooooooooo`03ooooo`Woo`3h
0olb0?l7ooooo`coo`3D3?l08_l:olCo00;ooooo0_l0g_m8o`2jo`Soa?l02_ooool]o`0Roa7ooooo
4oodo`000oo4o`3o0;[oo`2jo`0Qo`2jocGo0=koFol0od0?ooooo`006_ooool01?l0003oooooool0
9?oo03`Dooooo`Co0<3o0_ooool3ool0F`?oo`1D0ooo04P00ooR0?oooah0oolN0003ool09004ool0
Iooo08Goo`25ool0Q@?oo`2Y00?oolh0oonY0?ooZ@000_ooZ@001?oooooo0?mao`3oLOl0og43o`3o
AP?oofd000Co0:Ooool0NOoo07Woo`1i0_oo08/3ool0O`03ohL0oooooooooooo00;oonH00ooo0;H0
1?oL0?oo;03ood@0oom40?l4ool0?0Coo`1>0_od0?l4ool0K@03oooP0?ooT@3ooi4000;ooi4000?o
ooooool0/?oo0;000ooo0;000ol0on[o04Koo`16o`03o`16o`03oooooon=0?ooT`3o00CoT`3o0ooj
0?l01?oo0<Soo`2lool0_?oo0;`6ool0U`Kooooo1_oo0?P6oc80o`04ooCo0?o:o`3ob_l0ol[o00Wo
o`3D3?l08_l3ooooo`Go[?l04_l0^_loo`3o@0Wo0=ko4?l0^_l6olCo02Wooooo00?om?l0olCo0?o4
o`004?o4o`0Bo`2job7o0=ko00?o0?m0oi?o0?nCo`005?nCo`000olDo`3oo`3bool0lP1Mool0lQ_o
5?l03oooool001[ooooo00Co0000oooooooo07Woo`0T4Oooool3o`30o`?ooooo0ooo05/3ool0E0?o
o`180ooo7P03ool09003ool0Iooo08Goo`2500Coo`2Y1?ooZ@02ooooo`?o0?ma0_l0odH00ooooooo
ofd0oom]0002o`2Wo`?oo`1i00?oo`2;ool0Oooo07l00_oo07l2ooooo`?oonH00ooo0;H01?m4o`3o
;03ood@0oom40?l3ool0?0Coo`1>00?oo`2Aoo@0ool0obh00ooo06d2oooP00;ooi4000?oooooool0
/?oo0;000ooo0;02ooooo`Co04Ko00?oooooohd0oonC0?l01?nC0?l01?lbo`3onP3oooX0oooj0?l3
ool0_0Goo`2G1_ooool6ool0n0Ko<P3o1?o:o`06ool0e0Wo02;o2On/o`02o`3No`Wo0;[o00?o0=ko
oi?o0?nCo`003_l0od0lool0lP[oTol02_l0od09o`3NoaOo0;[o1?o4o`0Wo`2jo`oo0=ko0ol0od02
ojco00[oTol0;Ooo0?8@oon;00ko01Ko@Om_0?lKool0lPoooooo000Jooooo`05o`000?ooooooo`2f
ool09?l0`?l03Oooool3o`30o`?ooooo0ooo05/3ool0E0?oo`180ooo7P03ool09003ool0Iooo08Go
05oo00?oo`2Y00Coolh0oonY0?ooZ@3oojT00oooool3o`3oL@;o0?m600?ooooooom]0?ooK@000_l0
Yol3ool0N@Coo`1o00?oQ`3oooooooooool00oooiP03ool0]P04odCo0?l/0?ooA03ood@0o`?oo`0l
0ooo04h2ool0T@03oo@0ool0obkoo`1]00;oo`1]0_ooh0000oooT@3oooooool0/003ool0/004o`3o
j_ooooooooooooooo`?o04Ko00?oooooohd0oonC0?l00onC0?l00ol0oj7o<_l0oc;o0002ooX0o`?o
o`2l1?oo09L00oo40?ooooooooooo`02ooooo`Koo`3h1_lb0?l3ol[o0003olCo0?oo0=Coo`3D00Co
o`3D1_l08_l6ojco00Go0=ko2Ol0^_l:o`3o@003ofl0oooo0?;oo`3b00goo`3b>Om_0?l2o`0Fo`03
oaCo0?oo0?;oo`3b013oo`3b0onCo`0;o`3o@1Co0=ko1Ol0^_l6o`3ogQko0=ko0_l0od06oi?o01So
o`3b00?o5?l0oon;0?ooR`002OooR`07o`0FocSoK`3o:?ooooldo`3No`oooooo000Jooooo`05o`00
0?ooooooooooool0??oo02@02_ooool3o`30o`?ooooo0ooo05/3ool0E0?oo`180ooo7P03ool09003
ool0Iol0Gooo05oo00?oo`2Y00?oolh0oonY0?ooZ@001?ooool3o`3oL@?o0?m60_ooK@02o`2Wo`?o
o`1i0ooo07l2ohL0o`;ooooo0oooiP03ool0]P;oA?l00_m40?l3ool0?0?oo`1>0_oo09400ood0?oo
0?l^ool0K@02ool0K@;oon0000?ooi40ool0/?oo0;000_oo0;02o`3ojP;ooooo1?l0A_l00on=0?oo
T`3ooi<0o`02oi<0o`03o`3oXOlbo`3o<_l000;onP3o0ooo0;`4ool0U`Cooooo1Ooo0?P6oc80o`Co
b_l01_oo0=@6o`0Ro`03ojco0?l0g_oo0=ko00So0=ko1_l0^_l7o`3o@003ofl0oooo0?;oo`3b00[o
o`3b00?o5?l0o`0Fool05_l04ol05_lboooooa7oK`3o1?lDo`06ool0lP;ooooo1_nCo`0:ojco0003
ooo80?l0od3o0?m000Oo0?m02ol0g_l5o`3o@0Oo[?l03_nCo`0<ool0lPgo5?l000?o01Koofl0oom_
0?l06om_0?lRoooooaGo0?l@K?ooool001[ooooo00Go0000ooooooooooooo`0lool09002o`30o`Ko
oooo0_l0`?l3ooooo`?oo`1K0ooo05@3ool0B003oooooooo7P3ooah000?oo`0T00?oo`1Wo`1Oool0
Gol00ooo0:T00ooocP3oojT0oonY0004ooooo`?o0?ma00Coooooo`3oA_l0odKooooo0_ooK@02o`2W
o`;oo`1i0_oo07l2ool0R`03ohL0oooooooooooo00?oonH00ooo0;H2odCo00;oA03o0ooo03`3ool0
CP;oo`2A00?om03oo`3o;_l80?l00_oo06d2oooP0004oonA0?oo0;3oo`2`ool0/0?o0?oZ00?ooooo
o`16ool0A_l00_l0A_l00on=0?ooT`3ooi<0o`02oi<0o`03o`3oXOnUo`3o<_l000;onP3o1?oo0;`3
ool0U`Cooooo1?oo0?P5oc80o`;ob_l00_ooool00on/o`3oo`3Dool0e003ool0e0Ko02;o1ol0g_l4
oi?o00Ko0;[o00?o0?m0ofl0oom_0?l02ooo0?800olDo`3o01Koo`0Fo`0:o`0Foa;ooooo=_l0oa0=
ooooo`?o01Ko1_m_0?l01?ooR`3o5?l0oaCo0?lDo`0?ool0lQ[oTol06?oo0?88oaCo01;oK`3o4_oo
ool]o`3o41Gooooo=?l0oa0hooooo`006_ooool3o`000003ool0]_oo02Coo`1800Oo0<3o0oooool2
ool0F`?oo`1D0ooo04P2ooooo`07oolN0?oF0?ooo`0Tool09?oo06Ooo`25o`1Oo`03ool0Z@;oolh0
00?oojT0ooooooooool00oooool2o`3oL@;ooooo0_l0odH01?ooooooofd0o`2Wool0Yol3ool0N@04
ool0Oooo08_oo`2;ohL0o`;ooooo0_ooiP02om`0o`;oo`2f0_m4o`02od@0o`?oo`0l00?oo`2Mool0
C_oo04h00ooo09400ol0obko203oo`P0o`02ool0K@03oooP0?ooT@3oo`2`00;oo`2`0ol0onX4o`16
o`03ohd0oonC0?ooT`3o00;oT`3o00?o01coo`3oXOnUo`000_oj0?l4ool0_004ool0b?oo09Ooo`2G
ool0U`?ooooo1?oo0?P4oc80o`;om?l000Coa?l0ojco0?n/o`3o[?l01?oo0=@5o`0Ro`Go0=ko00?o
oooooi?o0?nCo`000onCo`02o`2jo`CoK`3o2Ooo0?82oon;0003oaCo0?l05_oo01Ko00Oo01Ko3?oo
oolBo`3o43Kooooo3?l0oa0:ooooo`coK`3o0oooR`03ooooo`03oaCo0?oo0?;oo`3b01Soo`3b1OlD
o`09oon;00Oooooo2om_0?l5o`0Foa?ooooo3?l0oa0boooooboobP3o5OoooolYo`3o40oooooo000J
ooooo`07o`000?oooooooooooooooooo03coo`0Tool0B006ooooo`?oo`1K0_oo05@3ool0B0;ooooo
00?ooah0omH0oooF0?l00_oo02@2ool0Q@?oo`2Y0_oocP000oooZ@3oooooooooo`04ooooo`;o0?ma
0_ooool2o`3oAP;oofd000Co0:Ooool0NOoo07Woo`1i0_oo07l2ool0R`;ooooo00CoonH0om`0oooL
0?oog03o0ooo0;H2odCo0006od@0oooo03coo`0lool0??oo09goNol00_oo04h2ool0T@03oo@0ool8
0?oo203o00?oo`1]00Cooi40ool0/?oo0;3oo`2`0ol0onX3o`16o`;oS@3o0onC0?l2o`0Lo`04o`3o
XOnUo`3onP3oooX0o`?oo`2l0_oo0<P3ool0U`?ooooo0ooo0?P4oc80o`03ooooooo4o`3o[?l000?o
[?l01?oo0=@4o`0Ro`Co0=ko00?oooooooo80?oob0000onCo`07ofl0o`Goo`3b1_ooR`06o`0Fo`oo
oooo1_l0oa03ooooodCobP3o3Oooool9o`3o40Wooooo1?l05_l7ofl0o`Co01Ko6OooR`000ooooooo
01Koo`0Fo`03o`0Fo`coK`3o0ol05_lDooooo`co0?l@6?oooolVolX0oboooooo<?o:0?lMooooo`00
6_ooool01ol0003oooooooooooooooooo`0lool09?oo04P00_oo05@2ool0F`Goo`1D0_oo04P3oooo
o`;oeP3o0ooo02@01?oo08Go05ooool0ZOoo0:T3ooo>00Kooooo0ol0og42ooooo`;o0?m60_ooK@03
ool0N@04oooD0?oo07ooo`1oool0R`;ooooo00GoonH0om`0oooL0?oog03oooooo`02ool0]P04oooo
oom4o`3oA?l0od@0o`;oo`0l00?oo`2Mog_o0?oo04h00_oo04h2ool0T@?o203o0_oo06d01?ooT@3o
o`2`ool0/?oo0;03o`3ojP03ooooool0A_oo04Ko00;oS@3o0onC0?l2o`0Lo`04o`3oXOnUo`3onP3o
ooX0o`?oo`2l0_oo0<P3ool0U`;ooooo00Com?l0ool0n?oo0?Soo`3h0olb0?l00oooooooa?l0ojco
0003ojco0004oooooooo0=Coo`3Dool0e0Co02;o0ol0g_l01OooooooolP0ooo80?oob03oTol000Ko
K`3o00?o0?m0ool0l_oo0?801?oo0?85oon;00Ko01Ko3?ooool3o`3o40oobP3oA?ooool<olX0o`[o
oooo2Ol0oa0;ooooob?oK`3o4_oooolAo`3o40gooooo5oo:0?lhooooob7o0?l4;?l20?l>olX0o`oo
oooo000Jooooo`07o`000?oooooooooooooooooo03coo`1Wool09009ool0B0;ooooo00?ooah0omH0
oooF0?l00_oo02@2ool0Q@03o`1Ooooo0:Woo`2Y00;oolh01oooool2o`3oL@?ooooo0_l0odH2oom]
00;oo`1i00Koom@0oooooooo07ooo`1oool0Roooool2oooV00;og03o0_ooool2ool0]P04oooooom4
o`3oA03ood@0o`;oo`0l00Coo`2Mog_o0?oo04koo`1>0ooo0942o`P0o`?oo`1]00?ooi40ool0/?oo
0;000ol0onX01Ooooooo04Koo`16ool0A_ooS@3o00?oT`3o0_l07?l2o`3oX@;onP3o0ooo0;`2ool0
b0?oo`2G00?oooooooCo0?odo`000ooo0?P3oc80o`03oooooon/o`3o[?l000;o[?l00_ooool3ool0
e0?o02;o0ol0g_l01?ooooooolP0ooo80?nCo`05ofl0o`03o`2joooo0?;oo`3b00Coo`3b1OooR`06
o`0Fo`Wooooo1?l0oa08olX0oa[ooooo2_l20?lUogD0o`03o`80oooooooooooo01?ooooo1Oo:0?l>
ooooo`Go0?l@:oooool@o`3o41;ooooo3?o:0?lTooooo`co0?l4@?l20?m9ooooo`006_ooool01ol0
003oooooooooooooooooo`0lool0NOoo02@00oooool2on80o`Cooooo0_oo7P03ool090;oo`250ooo
0:T00ooocP3oojT0ooooo`06ooooo`;o0?ma0_ooool3o`3oAP04oom]0?l0Yoooo`1iool0N@;ooooo
0_oo07l01?oo08_oonH0oooV0?ooiP02om`0o`;ooooo0_oo0;H01?ooooooA?l0od@0oom40?l2ool0
?004ool0WOmko`3oo`1>ool0CP;oo`2A00?oe_l0o`P0ool80?l00_oo06d01?ooh03ooi40ool0/?oo
0;02o`3ojP;ooooo0_l0A_l01?ooooooS@3ooi<0oonC0?l3o`0Lo`03o`3oXOoj0?oonP3o00?oo`2l
0_oo0<P01_oo0>Koo`2Gool0Uooooooom?l0ol[o00?oo`3h00?ooooooc80oolb0?l01?n/o`03oooo
o`?oo`3D0ol08_l3o`3No`03ooo80?nCo`3oTol000CoK`3o00?o0;[oool0l_oo0?800ooo0?86oon;
00Go01Ko2_ooool3o`3o40KobP3o4Oooool>o`80o`CoM@3o=?oX0?l:ogD0o`_ooooo1Oo:0?l>oooo
oa3o0?l@2_oooolAo`3o41Oooooo2oo:0?lUooooo`co0P3o>_oX0?loooooo`coJOl03oooool001[o
oooo00?o0000ooooooooool00_ooool01?oo03coo`1Wool09?l0oa`5ooooo`;ooah00_oo02@00ooo
06Ooo`25ool0Q@02ool0Z@03ooo>0?ooZ@3oojT000Oooooo0_l0og42ooooo`;o0?m60_ooK@000ol0
Yoooo`1iool0N@02ooooo`;oo`1o0oooiP000ooooooog03oom`0o`02ooooo`;oo`2f00SoooooodCo
0?m40?ooA03oob`0oooo03coo`2Mog_o00;oo`1>0_oo0943o`P0o`;oo`1]00Goooooool0/?oo0;3o
o`2`o`3ojP03ooooo`;o04Ko00Coooooohd0oonC0?ooT`3o0_l07?l00ol0oj7onP3oooX0o`03ool0
_003oonG0?oo0<Soo`3800?oo`2G00?om?l0ol[o0?oo0?P00_oo0?P2ooooo`;o<P3o0_n/o`04oooo
o`?oo`3D0ol08_l2o`3No`04ooo80?nCo`3oTol0oi?o00?oK`3o00?o0;[oool0l_oo0?800_oo0?80
0ol0od3ooh/0oon;0002oon;00;ooooo1?l05_l9ooooo`?o0?l@1_o:0?l>ooooo`Wo0P3o0ome0?l?
onP0o`;oJOl08_ln0?l@ooooo`goj03o0ome0?l00ol20?oo0?l4ooooo`07ooooo`KobP3o6?ooool:
o`3o41gooooo2oo:0?lTooooo`03o`80oooX0?ooj03o01Goj03o9_me0?l=ooooo`OoJOl03ooX0?l0
0omYo`3o?P3ooch0o`0ioch0o`oooooo000Jooooo`03o`000?oooooooooo00;ooooo00?oo`0loooo
oooo0:T02?oo02@2ool0I`?oo`2Y0_ooZ@08ooooo`;o0?ma0_ooool2o`3oAP;oofd000Go0:Ooool0
NOoo07WoooooohL0o`02ool0O`;oonH00_ooool2om`0o`;ooooo0_oo0;H01OooooooA?l0od@0oom4
0?oo;03o00;oo`0l00?oo`2Mool0C_oo04h00_oo0942o`P0o`?oo`1]00?oooooool0/?oo0;000_l0
onX3ooooo`;o04Ko00Cooooooi<0oonC0?ooT`3o0_l07?l2ooX0o`?oo`2l00CooiL0ool0b?oo0<So
o`380_oo09L00oodo`3ob_l0ol[o0002ool0n0;ooooo0olb0?l00oo4o`3oooooooooo`03ooooo`;o
o`3D0ol08_l00ol0g_ooolP0ooo80002oi?o00CoK`3o1?oo0?82o`3o@0?ooh/00oooool3o`0Fo`So
oooo0_l0oa06olX0o`_ooooo2Ol20?l3ogD0o`Woj03o00?oJOl0och0ooln0?l03_ln0?l00ooooooo
MOl0ogGo0008ogGo01_o/P3o3oln0?l:ooooo`Goj03o0ome0?l2o`3o10Wooooo1_o:0?l]ooooo`co
bP3o8_ooool00ol0o`Co0P3oo`80o`0;onP0o`WoM@3o4?l0oelCofWo017o?P3o3?me0?lGoch0o`_o
j03o@?ooool001[ooooo00?o0000ooooooooool00_ooool01?oo03coo`1ioooooooo0:T2ool0I`04
ool09?oo06Ooo`1Wool0I`?oo`2Y0oooZ@08ooooo`;o0?ma0_ooool2o`3oAP03oom]0?l0Yooo0:Oo
00;oo`1i00CoooooohL0oooo07ooo`1o0_ooiP02ooooo`;og03o0_ooool2ool0]P;ooooo0_m40?l0
1_l/0?ooo`0lool0??oo09goNol0ool0CP;oo`2A0_l80?l2ool0K@04oooP0?ooooooo`2`ool0/0;o
0?oZ1?ooool01?l0A_oooooooi<0oonC0?l3o`0Lo`;onP3o0_oo0;`01Olbo`3oo`3Vool0b?oo0<So
a03o00;oo`2G0_o:o`03ool0n005oooooon/o`3o<P3ooc80ooo4o`001_ooool2ool0e0;o02;o00Co
0=koooo80?oob03oTol01?m_0?l01?ooooooo`3bool0l_oo0?83o`3o@0?ooh/00_ooool4o`0Fo`Oo
oooo1_o:0?l;ooooo`Ko0P3o00?o0?mOogD0oome0?l00ome0?l6onP0o`[o?P3o2omeo`0@ok80oa_o
oooo3onb0?l7och0o`Sooooo1_oX0?l2ogD0o`03o`3o1?oooooooooo00Wooooo2?o:0?lLooooo`Wo
bP3o8_ooool6o`80o`Woj03o2Ome0?l8o`3oG`Gooooo2_mYo`0Doch0o`ko/P3o1_meo`0<o`3oG`Go
M@3o7Oooool;onP0ocGooooo000Jooooo`03o`000?oooooooooo00;ooooo00Goo`0lool0NOoooooo
ooooooo>0005ool0Z@03ooob0?ooZ@3oojT000Wooooo0_l0og42ooooo`;o0?m600?oofd0o`2Wool0
Yol00_oo07T01?ooooooo`1oool0Oooo07l2oooV00;ooooo0_oL0?l2ooooo`;oo`2f0_ooool00om4
o`3oA03oob`0o`02ool0?00;ool0WOmko`3oo`1>ool0C_od0?ooe_l0o`P0ool0obkoo`1]oooP0?oo
ool00_oo0;02o`3ojPCooooo0_l0A_l2oi<0o`;o01co0ooj0?l2ool0_005oc;o0?oo0>Koo`38ool0
b?o40?l00_oo09L2ol[o00;oo`3h00?oooooojco0?n/o`000_lb0?l6ooooo`?oo`3D0_l08_l2ooo8
0004oi?o0?m_0?ooK`3oofl0o`;ooooo0ooo0?800ooooooo0?m0o`3o@003oon;0003ooooool05_oo
01Ko00;o01Ko00?o5?l0ooooooooool00_ooool6olX0o`cooooo1Ol20?l00ol0oeooM@3oogD0o`03
ogD0o`Koj03o0_ln0?l8ooooo`?oMOl03_nb0?ljooooo`_o/P3o0_ln0?l7ooooo`03o`3oGooX0?oo
j03o00?oj03o00?oM@3oo`3o1?ooool03_oooolLolX0ob7ooooo2Ol20?l7onP0o`KoM@3o2?l0oel5
ooooo`[oJOl01_ln0?lJok80o`kooooo4onb0?l4o`3oG`OoM@3o6Oooool8o`3oo0coj03o6_l0oo`?
ooooo`006_ooool00ol0003oooooooooo`02ooooo`03ool0Uooo03co0?ma00?ooooo1?ooZ@0:oooo
o`;o0?ma0_ooool2o`3oAP03oom]0?l0Yooo0:Oo00;oo`1i00CoQ`3oool0Oooo07ooo`2;0_ooiP00
1?oooooog03oom`0oooL0?l2ooooo`;oo`2f0_ooool01om4o`3oA03ood@0ool/0?ooo`0lool0WOmk
o`000_oo04h2oo@0o`;o203o0_oo06d00oooh03oo`2`ool0/002o`3ojPCooooo0_l0A_l2oi<0o`;o
01co0_oj0?l01?l0oj7oo`2lool0_?lbo`02ool0iP06ool0b?o40?ooo`2Gool0Uoo:o`3ooooo0_oo
0?P2ojco00?o<P3o1_ooool2ool0e0;o02;o00?oooooooo80?m_0?l00om_0?l2ooooo`?oo`3b00Co
ooooo`3o@?l0od3o0?m00_ooR`001?oooooo01Koo`0Fool05_l2oaCo00?ooooo1?o:0?l3o`3o40_o
oooo1?l20?l00ol0oeooM@3oogD0o`03ogD0o`Goj03o2?ooool2ogGo00Wo/P3o2Ooooolaog/0oaKo
oooo0omYo`03ok80o`Co?P3o1_ooool2o`3oG`Goj03o00?oM@3oo`3o1?ooool0?oooool7o`80o`03
o`3o1?me0?ooj03o00Koj03o0_me0?l7o`3oG`Gooooo2omYo`08och0o`Wo/P3o7ooooolLo`3oo0_o
/P3o1Ome0?lDo`3oo0[ooooo2_l0Mol;onP0o`oo07Oo3oooool001[ooooo00?o0000ooooooooool0
0oooool00ooo03coo`1io`3oL@0>ooooo`;o0?ma0_ooool2o`3oAP03oom]0?l0Yooo0:Oo00;oo`1i
00CoQ`3oool0Oooo07ooo`2;0_ooiP000ooooooog03oom`0o`03ooooo`;oo`2f0oooool2od@0o`04
ob`0oooo03coo`0log_o00;oo`1>00Wooooooo@0ool80?oo203oo`3o;_oo06goon00oooooooo0;00
0_l0onX5ooooo`03o`16oonC0?ooT`3o00;o01co0_oj0?l01?l0oj7oo`2lool0_?lbo`02ool0iP;o
o`380_oo09L2ooooo`;oo`3h0_n/o`02oc80o`Oooooo0_oo0=@00ol08_ooooooooo80003ofl0o`?o
oooo0ooo0?801?l0^_oo0?m0o`3o@?l0od02oon;0004ooooool05_oo01Koo`0Fo`;o5?l00oooool3
olX0o`04ooooool0oa3o0?l@o`3o40[ooooo1?l20?l00ol0oeooM@3oogD0o`02ogD0o`Goj03o1?oo
ool6ogGo00Go/P3o1_ooool<og/0oa;o__l00ooooolLo`3oo0[oN`3o4_ooool4ok80o`Co?P3o1ooo
ool2o`3oG`Coj03o0_me0?l2o`3o13?ooooo1ol20?l2ogD0o`Ooj03o1?l0oel6ooooo`_oJOl01oln
0?l<ok80oaCooooo2_l0oo`aog/0o`Ko/P3o6?mk0?l5o`1goaGooooo2_oX0?lDooooo`006_ooool0
0ol0003oooooooooo`03ooooo`03ool0??oo07ooo`1i00cooooo0_l0og42ooooo`;o0?m600?oofd0
o`2Wool0Yol00_oo07T01?n70?ooo`1oool0Oooo08/2oooV0003oooooooL0?oog03o00Cooooo00Oo
o`2fooooooooooooooooodCo0?m40?oo;03o00;oo`0l00Coo`2Mog_o0?oo04kooooo0_od0?l01Ol8
0?oo0?l^oooooooo06gooooo00;oo`2`00?o0?oZooooooooool00oooool00ol0A_ooT`3ooi<0o`02
o`0Lo`03ojGo0?oj0?oo0?nQ00;oo`2l00?oooooool0i_oo0>H00_oo0<P2ool0U`;ooooo0_oo0?P0
1?n/o`3oa?l0oc80oolb0?l7ooooo`;oo`3D00?o0=kooooooom_0?l00_m_0?l4ooooo`;oo`3b0_l0
^_l2o`3o@0;ooh/00_ooool2o`0Fo`;o5?l00oooool3olX0o`04ooooool0oa3o0?l@o`3o40Oooooo
0_mYo`04o`80o`04och0oome0?ooM@3oogD0o`Goj03o1?ooool5ogGo0003oooooonb0?oo/P3o00?o
/P3o0oooool8og/0o`co__l00oooool8o`3oo2So^03o0_l0Mol6o`3oo0KoN`3o1?nno`0<ooooo`Go
/P3o0_ln0?l9ooooo`03o`3oGooX0?ooj03o00;oj03o00?oM@3oo`80ool20?l00ol0o`@Sooooo`[o
0P3o0_me0?l7onP0o`03o`3oGooooooooooo00Cooooo2_mYo`02ogGo00Ko?P3o2_nb0?lEooooo`Ko
0?ol3omk0?l2okko00?ooooo5_l0Mol?okko00gooooo1_nb0?l2ogD0o`WoMOl01oooool;og/0oa?o
oooo1_m:o`05onP0o`oooooo000Jooooo`03o`000?oooooooooo00?ooooo00Coo`0lool0]_oo07Wo
0?ma2?ooool3o`3oL@;ooooo0_l0odH2oom]0004o`2Woooo07Woo`1iooooo`;oo`1o00?oo`2;oooV
0?ooiP000ooL0?l4ooooo`;oo`2f0oooool2od@0o`08ob`0oooo03coo`2Mog_o0?nI0?ooo`1>oooo
oood0?l2o`P0o`03oooooooo06goo`1]00;oo`2`0_l0onX5ooooo`;oT`3o0_l07?l00onUo`3onP3o
ooX0o`02ool0_007oooooooo0>Koo`3Vo`So0?oo0<Soa03oool0U`02ooooo`;oo`3h00Co[?l0oooo
oolb0?oo<P3o1oooool2ool0e004oooooom_0?ooK`3oofl0o`Gooooo0_oo0?800ol0^_oo0?m0o`3o
@002oon;00;ooooo0ol05_l2oaCo00;ooooo0oo:0?l01?oooooo0?l@o`3o4?l0oa05ooooo`?oJOl0
0ol20?l3och0o`;oM@3o1?oX0?l4ooooo`GoMOl00_ooool4ok80o`SoN`3o0_ooool6okko00Kooooo
4Onh0?l00onO0?oo07Ooo`1go`03o`1goa_ooooo1onO0?l<okP0o`03o`1gool0oocoN`3o00GoN`3o
0onno`0<ooooo`?o/P3o0oln0?l:ooooo`Coj03o00?oM@3oo`80ool20?l01?l20?lCooooo`_o0P3o
00?o0?l4oooooooX0?l02OoX0?l00ol0oeooooooooooo`03ooooo`SoJOl01Omeo`000ooooooo?P3o
och0o`03och0o`Oo/P3o5_ooool4o`3oo0_oN`3o5?l0Mol6oooooa;oW`3o3Oooool;okko00Sooooo
1Onb0?l00ome0?ooooooooooo`03ooooo`koMOl01?m:o`0Bog/0o`co0?oH3oooool001[ooooo00?o
0000ooooooooool00oooool01?oo09Ooo`0lool0NOl0odH2o`3oL@Cooooo0_l0og43ooooo`;o0?m6
0_ooK@02o`2Wo`04ool0NOooooooo`1oool0O`;oo`2;00?oooooom`0oooL0?l01_ooool01?oo0;Ko
ooooooooooooool2od@0o`05ob`0oooo03coo`0log_o0?nI0?l00_oo04h2oo@0o`09o`P0oooooooo
ooooool0KOooooooo`2`oonA0?l0on[ooj<000Cooooo0_nC0?l2o`0Lo`09ojGo0?oj0?oonP3oo`3o
XOoo0;cooooooonG0?oo0>Ko2?l000;oo`380_oo09L01Oooooooo`3hool0n?o4o`3ooooo00;o<P3o
1oooool00ol0g_ooo`3Dofl0o`02ofl0o`03ooo80?oooooooooo00;ooooo0ooo0?801?l0^_oo0?m0
o`3o@?ooR`03ooooo`;o01Ko0_lDo`02ooooo`?obP3o0_ooool2o`3o40?ooooo1OmYo`02o`80o`Co
?P3o00?oM@3oonP0oooX0?l00_oX0?l5ooooo`?oMOl00oooool4ok80o`?oN`3o1_ooool5okko00Ko
oooo1_nh0?l4oil0o`Oo07Oo1?oooolTod[o00cooooo1_nO0?l5okP0o`03o`1gool0ooco0?ol00Ko
N`3o00?o__l0ooooooooool02Oooool3ok80o`?o?P3o2_ooool00ol0oeooj03oonP0o`06onP0o`;o
M@3o4?l20?l=onP0o`04ogD0ool0oeoo0?mOo`3oG`Gooooo1omYo`04ogGo00?ooooo1Oln0?l7ok80
oa7ooooo1Onno`0;og/0o`;ooooo1ol0MolAoil0oa?o^03o2_oooolIoil0o`[oB_l00_l0omP6ok80
ob;o0?oH0_ooool<og/0o`oooooo000Jooooo`03o`000?oooooooooo00Cooooo00Coo`0loooooooo
07Wo0:Oo1_l0og42ooooo`;o0?m60_ooK@02o`2Wo`;oo`1i0_oo07l2ool0R`;ooooo00?og03ooooo
ooooool01?ooool2ool0]P?ooooo00goA03oob`0ool/0?ooo`0lool0WOmko`3oV@3oool0C_oooooo
m03oomKo0?l80?oooooo00;oo`1]0_oo0;02o`3ojPCooooo00CoS@3ooi<0ool07?oo01co0_nUo`00
1Ooj0?oo0?nQool0_?oo0;cooooo00;oo`3V0_oo0<P2ool0U`05oooooon/o`3oo`3holCo0?ooool0
0_lb0?l00oook03oooooooooo`04ooooo`04o`3Noooo0=Coo`3Dofl0o`;oolP01?ooool2ool0lP;o
0;[o0_l0od001?ooR`3oooooooooooooool2o`0Fo`;o5?l000CoooooolX0ooo:0?oobP3o0_ooool3
o`3o4003oooooomYo`3oJOl000;oJOl000?oooooo`80ool20?l01?ln0?l00ol0oeooj03oonP0o`02
onP0o`Kooooo0omeo`02ooooo`Co/P3o0_mk0?l5ooooo`Ko__l00_ooool00onO0?oo^03ookP0o`06
okP0o`;oW`3o0ol0Mol@od[o00?ooooo5ooXo`0:ooooo`[oB_l03?ooool00onO0?oo^03ookP0o`03
okP0o`04o`1gool0ooco0?olo`3oo0CoN`3o2oooool3ok80o`?o?P3o3oooool00ol0oeooj03oonP0
o`0@onP0o`CoM@3o2oooool7ofWo00GoMOl000?ooooooch0ooln0?l01?ln0?l7ok80o`kooooo1_nn
o`09og/0o`03o`3oo?oooooooooo00Gooooo00?o07Oooil0oonO0?l01onO0?lCokP0o`gooooo1Om:
o`000ol0omSo^03ookP0o`0=okP0oaCo0?oH2?nO0?l2o`3of003oooooonno`3o__l000Go__l01_nb
0?lQo`3oGaSooooo000Jooooo`03o`000?oooooooooo00Cooooo00Goo`0lool0]_oo08_oo`1io`2W
o`07o`3oAP;oofd00_l0Yol2ool0N@;oo`1o0_oo08/2ooooo`;og03o1_ooool01ooo0;Kooooooooo
ooooooooA?l0od@0ool/0?l00_oo03`01?mko`3oV@3oool0C_oo04h2oo@0o`;o203o00Ooooooool0
KOoo0;3oo`2`oonA0?l0on[ooj<000Cooooo00?oS@3ooi<0ool07?l00_nUo`02ooX0o`;oo`2l0_oo
ool00ooo0>Ko2?l0ool0b002ool0U`;o[?l00_oo0?P01?oooooo<P3ooc80ooook007ooooo`;oo`3D
00?oK`3oooo80?oob0001?ooool2ool0lP05o`2joooooooo0?m0o`3o@?ooR`000oooool2o`0Fo`;o
5?l00oo:0?l3ooooo`;o0?l@00CoooooofWo0?mYo`3oJOl00_ooool00ol20?oo?P3ooch0o`02och0
o`;o0?mO0ooX0?l7ooooo`?oMOl000?oN`3ook80oonb0?l00_nb0?l5ooooo`Ko__l000?oW`3ookP0
oonh0?l01_nh0?l00ol0ooco07Ooo`1go`04o`1go`KoB_l00_ooool@onSo02_o0?oH00?ooooood[o
0?m:o`001?m:o`09ooooo`?oW`3o0onh0?l01Ol0Mooooooooooooooooooo0?ol00?oN`3o2oooool3
ok80o`?o?P3o00?oMOl0ooooooooool09?ooool7ofWo00KoMOl01oln0?l6ok80o`kooooo1_nno`00
0ol0oocoN`3oog/0o`04og/0o`;o0?ol1oooool9oil0o`03oooooonh0?oo^03o00Ko^03o4Oooool5
od[o00oo0?oH4?oXo`06okP0oaKoj?l01_nO0?l00ooXo`3oooooooooo`05ooooo`;oM@3o1_nb0?lT
okko00oooooo000Jooooo`03o`000?oooooooooo00Cooooo00Goo`0lool0]_ooooooo`2;ool0N@02
o`2Wo`?oofd01?l0Yol2ool0N@;oo`1o0_oo08/3ooooo`03om`0oooooooooooo00Gooooo00Coo`2f
oooooooooooooooo0_m40?l02ol/0?ooo`0log_o0?mko`3oV@3oool0C_oooooom03oomKo0?l80?oo
oooo00;oo`1]00Coo`2`oonA0?l0on[o0?oZ1?ooool01On=0?ooT`3ooi<0ool07?ooYOl000;onP3o
00Co0?nQool0_?oooooooooo0_oo0>H00ol8o`3oo`38ool0U`02ojco00;oo`3h0_ooool00olb0?oo
on`0ooooo`06ooooo`03ofl0oooo0=CoTol000;oolP01?ooool2ool0lP04o`2joooooooo0?m0o`3o
@0Cooooo0_l05_l01?lDo`3obP3oolX0ooo:0?l3ooooo`?o0?l@0omYo`02ooooo`Co?P3o0ol0oel3
onP0o`Oooooo00CoMOl0og/0oomk0?ooN`3o0onb0?l4ooooo`Go__l00_ooool00onO0?oo^03ookP0
o`02okP0o`;ooooo00?o0?olo`1gool0Mol01?l0Mol3od[o00_oj?l01?ooool<o`3of0Go^?l06Ooo
ool=okSo00[o0?oH0om:o`08ooooo`05oil0oonh0?oo^03ookP0ool0Mol01?ooool3og/0o`_ooooo
1Onb0?l4och0o`03ofWo0?meo`3oMOl001Sooooo1_mYo`04ogGo00Wo?P3o0_ooool5ok80o`gooooo
1Onno`09og/0o`Wooooo1?nO0?l<okP0o`cooooo0_oXo`08od[o00So0?oH2?oXo`0Mooooo`Ko^03o
5_ooool5oil0o`Koj?l01Ome0?l5ok80oaCoj?l06_ooool001[ooooo00?o0000ooooooooool01?oo
ool01Ooo09Ooo`0looooooooooooo`1o00Woo`1i0_oo07l2ool0R`;ooooo0ooL0?l6ooooo`;oo`2f
0_ooool01_m4o`3oA03oob`0ool0a_ooo`0log_o00;oV@3o00coo`1>oo@0oood0?ooe_l0o`P0oooo
ooooo`1]oooP0?oo0;3ooi40o`3oj_ooX`03ooooo`;oS@3o00?oT`3oo`0Lool07?l00_oj0?l02ol0
oj7oo`2lool0_?oooooob_l0ool0i_l8o`3oooooool0b?oo09Oo[?l000;oo`3h0_ooool2oc80o`03
ooo/0?oooooooooo00Cooooo00GoK`3oool0e?oo0=CoTol0ooo80005ooooo`03ool0l_l0^_oooooo
00;o0?m01?ooool2o`0Fo`?obP3o1?ooool2o`3o40?oJOl000?ooooooch0ooln0?l00_ln0?l01Ooo
oooo0?mOo`3oGol0oeooM@3o00;oj03o1oooool4og/0o`?o/P3o1?ooool3okko00?ooooo00?oW`3o
okP0oonh0?l00_nh0?l2ooooo`Go07Oo0om:o`06onSo00Oooooo0_nho`06o`3of003okSo0?oooooo
oooo03Gooooo1_nho`03onSo00Go0?oH1?m:o`05ooooo`05oil0oonh0?oo^03ookP0ool0Mol01?oo
ool3og/0o`gooooo1Onb0?l4och0oaKoJOl000?oMOl0och0ooln0?l01oln0?l5ooooo`Ko/P3o3?oo
ool2okko00WoN`3o0_l0oo`:ooooo`03oil0oonh0?oo^03o00Oo^03o3Oooool2onSo00OoB_l03?l0
omP/okSo00Oooooo1Onh0?lFooooo`GoW`3o1_ooool5ogD0o`Ko/P3o3_ooool;onSo00oooooo000J
ooooo`?o00001Oooool01Ooo03coooooooooooooooooo`2;00;oo`1o0on70?l3ool0O`;oo`2;00Co
ooooom`0oooL0?oog03o2?ooool01ooo0;KoooooooooooooooooA?l0od@0ool/0?l00_oo03`01_mk
o`3oV@3oool0C_oo04kom03oomKo00;o203o0_oo06d2ool0/003oonA0?l0on[ooj<000?ooooo00Oo
S@3oo`16oonC0?oo01coojGo0?oj0?oo0?nQ00;oo`2l00[ooooool[o0?oo0>Koo`3Vo`So0?oooooo
o`38ool0Uoooooooo`3h0_ooool2oc80o`03ooo/0?oooooooooo00Cooooo00GoK`3oool0e?oo0=Co
Tol0ooo80005ooooo`;oo`3b00?oooooo`3o@?l0od001?ooool2o`0Fo`;obP3o1Oooool2o`3o40;o
JOl000Kooooooch0ooln0?oo?P3oo`80ooooool3o`3oG`04o`3o1?oX0?ooj03oonP0o`Gooooo1?mk
0?l01?oooooo/P3ook80oonb0?l4ooooo`?o__l00_ooool00onO0?oo^03ookP0o`02okP0o`;ooooo
1?l0Mol2od[o00Koj?l01?ooool6okSo00Go0?oHA?ooool5okSo00?oj?l00ol0omP01?ooooooB_l0
od[o0?m:o`05ooooo`05oil0oonh0?oo^03ookP0ool0Mol00oooool01?nno`3oN`3oog/0oomk0?l?
ooooo`Co/P3o5oln0?l3ooooo`_o/P3o3Oooool2okko00GoN`3o00?oooooo`3oo?l0oo`00ol0oo`9
ooooo`03oil0oonh0?oo^03o00Co^03o3Oooool2onSo00OoB_l02Ol0omP9okSo02oooooo3?nho`04
okP0o`Co^?l04oooool5oil0o`cooooo1Onb0?lDogD0o`oooooo000Jooooo`03o`000?oooooooooo
00Gooooo00?oo`0lool0]_ooool00_ooool00ooL0?ooo`2;ool0O`02ool0O`;oo`2;0_ooool2om`0
o`Wooooo0_oo0;H3ooooo`;oA03o00Ko0<Koool0??oo09goNol0oiT0oooo04h2oo@0o`07omKo0?l8
0?ooooooool0KOooh03oo`2`oonA0002o`3ojP?ooooo0_n=0?l2oi<0o`06o`0Loooj0?oonP3oo`3o
XOoo0;cooooo0_o:o`001?oo0>Ko2?l0o`So0?oo0<P2ool0U`;oo`3h00Cooooooc80oolb0?ooon`0
1oooool01?m_0?ooo`3Doi?o0?oob005ooooo`;oo`3b00?o0;[ooon;0?l0od001?ooool2o`0Fo`;o
bP3o1?ooool3o`3o4003ofWo0?oooooooooo00;o?P3o00?o0P3oooooool0oel00_l0oel2o`3o10;o
j03o1?ooool4og/0o`03ogGo0?oooooo/P3o00;o/P3o1?ooool3okko0003oooooonh0?oo^03o00?o
^03o00?ooooood[o0?m:o`000ol0Mol01?l0oocoj?l0onSo0?oXo`06ooooo`Ko^?l01_l0omP;oooo
o`gok_l01_m@o`0Eoh40o`Ook_l05?ooool5okSo0003onSo0?l0omSo0?oH00;o0?oH0om:o`05oooo
o`05oil0oonh0?oo^03ookP0ool0Mol00oooool01?nno`3oN`3oog/0oomk0?l@ooooo`_o/P3o1?oo
ool;ok80oa?ooooo00?o__l0og/0oomk0?l01?mk0?l00ooooooo0?olo`3oo003o`3oo0Sooooo00?o
W`3ookP0oonh0?l01?nh0?l00ol0Moooooooooooo`0:ooooo`;oj?l01_m:o`07o`3of0Ko^?l08_oo
oolKonko00kooooo1?nh0?l<okSo00cooooo1?nO0?l=oe3o00go/P3o5_ooool001[ooooo00?o0000
ooooooooool01Oooool00ooo09Ooo`0looooo`03ooooo`Sog03o2_ooool03_oo0;Kooooooooooooo
ooooA?l0od@0ool/0?oo0<Koool0??oo09gooooooiT0oooo04kom03o0_oFo`002?l80?ooo`1]ool0
KOooh03oo`2`oonA0?l0on[ooj<00_ooool2ohd0o`03o`16oonC0?oo01co00;onP3o00?oooooo`3o
XOoo0;`00_o:o`02ool0iP04o`So0?ooooooo`38ool0U`;oo`3h0_ooool00olb0?ooon`0ooo/0006
ooooo`04ofl0oooo0=Coo`3Dooo800Kooooo00?oo`3bo`2jooooR`000_l0od03ooooo`;o01Ko0_o:
0?l4ooooo`;o0?l@00?oJOl0ooooooooool00oln0?l01ol20?ooooooo`3oGol0oeooooooo`3o1?me
0?l00_oX0?l2ooooo`CoN`3o0_meo`001?oooooo/P3ook80oonb0?l4ooooo`?o__l01?nh0?l4od[o
00Co07Oo1oooool6okSo00Ko0?oH2?ooool2onko00[oD?l04?n10?lEo`2?oa3oP@3o1?o^o`0<oooo
o`?o^?l00_oXo`03o`3of0;oB_l01_ooool01?nO0?oo^03ookP0ool0Mol4ooooo`04o`3oo?mk0?oo
N`3oog/0oaOooooo1Onb0?lJooooo`GoN`3o0_ooool5o`3oo0Oooooo00?oW`3ookP0oonh0?l01?nh
0?l00ol0Moooooooooooo`0:ooooo`?oj?l01Om:o`06o`3of0;o^?l05ooooolFonko01Kooooo5om@
o`04okP0oaGoD?l00oooool5oil0oaGooooo1onb0?l?ooooo`006_ooool00ol0003oooooooooo`05
ooooo`03ool0Uooo03cooooo01Cooooo00Ooo`2fooooooooooooooooodCo0?m40?oo;03o00;oo`0l
00KoNol0oooooonI0?ooo`1>oo@0oooFo`02o`P0o`04ool0KOooh03oo`2`ool0/0;o0?oZ00Cooj<0
ooooooooooooS@3o0_l0A_l01OnC0?oo01coooX0oooo_03o0?nQ00;oo`2l00[ob_l0ooCo0?oo0>Ko
oiL0o`So0?ooooooo`38ool0Uooo0?Soa?l00_ooool00olb0?ooon`0ooooo`05ooooo`;oK`3o00?o
o`3Doi?o0?oob0001Oooool2ool0lP03o`2jooooR`3o0?m000?ooooo0_l05_l2olX0o`Cooooo00?o
JOl0o`3o4?mYo`000_ooool2och0o`03o`80oooooooooooo00;o0?mO00?oooooo`3o1?me0?l00_oX
0?l01?ooooooN`3oog/0oomk0?l3ogGo00;ooooo0_nb0?l4ooooo`?o__l00onh0?l01?nO0?ooB_l0
od[o0?oXo`04o`1go`03o`3oo?oooooooooo00?ooooo1Onho`02ooooo`Co0?oH1Oooool;oe3o0003
oooooon10?ooP@3o00OoP@3o2?l0SolSooooo`[o08oo1On10?l3onko00_ooooo1?nho`000ooXo`3o
0?oHo`3of002od[o00Kooooo00?oW`3ookP0oonh0?l00_l0Mol3ooooo`;o0?ol0omk0?l^ooooo`Go
N`3o0_ooool5o`3oo0Kooooo0_nO0?l5okP0o`;o07Oo3?ooool3onSo00GoB_l01Ol0omP00onho`3o
ooooooooo`0@ooooo`cok_l07?ooool@oe3o01_ooooo0onh0?l>onko00co^?l01OnO0?l6onko023o
oooo000Jooooo`03o`000?oooooooooo00Kooooo00?oo`0lod@0ooooool04Oooool2ool0]P?ooooo
0_m40?l01?l0a_ooo`0lool0WOmko`02oiT0o`04ool0C_od0?ooe_l0o`P0o`;oo`1]00Goon00ool0
/?ooT@3o0?oZoonS0003ooooo`04ohd0ool0A_ooT`3ooi<0o`;onP3o00?oooooo`3oXOoo0;`00_o:
o`002?odo`3oo`3Vo`So0?l8o`3o[?l0ool0b?oo09Ooo`3h0oooool00olb0?ooon`0ooooo`05oooo
o`04ofl0oooo0=Coo`3Dooo800Kooooo00?oo`3bo`2jooooR`000_l0od03ooooo`04o`0Fooo:0?oo
bP3ooaCo00;ooooo0_mYo`02o`3o40;ooooo0_ln0?l00ol20?ooooooooooo`02o`3oG`03oooooome
0?ooM@3o00;oj03o0omk0?l00oooooooMOl0ogGo0002ooooo`?o/P3o0oooool2okko0004oil0oonh
0?oo^03ookP0o`;oB_l00_oXo`03o`1go`;o0?ol0oooool5okSo00Cooooo0ol0omP4ooooo`GoD?l0
00?ok_l0ooooooooool02On10?l2o`2?oaKooooo5Ol0ok@@ooooo`03oe3o0?l0Sooo08oo00?o08oo
1_n10?l<ooooo`?o^?l00ol0omP00om:o`3oooooooooo`05ooooo`;o^03o0_l0Mol3ooooo`?o0?ol
0omk0?l2okko02Cooooo00?o__l0og/0oomk0?l00_mk0?l2ooooo`Go0?ol1_ooool2oil0o`Go^03o
0_l0Mol;ooooo`Coj?l01Om:o`05o`3of13ooooo2?o^o`0Looooo`coD?l0;_ooool3okP0oacooooo
1OnO0?l3okSo00ooQol03oooool001[ooooo00?o0000ooooooooool01_ooool00ooo09Ooo`0loooo
o`0@ooooo`03ool0]_oooooooooo00;ooooo00OoA03oob`0ool0a_ooo`0lool0WOooooooV@3o00;o
o`1>00Com03oomKo0?l80?ooo`1]0_ooh0001?oo0;3o0?oZo`3oj_ooX`02ooooo`;oS@3o00Ko04Ko
oi<0oooj0?oonP3ooonl0?ooool2ool0_005ol[o0?odo`3oo`3Vool0i_l8o`000_n/o`000ooo0<So
o`2GolCo0002ooooo`;o<P3o00?oon`0ooooooooool00oooool2ofl0o`03ool0e?nCo`3oolP000Go
oooo0_oo0?800ol0^_oooh/0o`3o@003ooooo`;o01Ko00CobP3ooaCo0?oooooooooo0_mYo`001?oo
oooo0?l@ooooooooool2och0o`03o`80oooooooooooo00;o0?mO00?oooooogD0oome0?l00_oX0?l2
og/0o`;ooooo0_meo`02ooooo`;o/P3o0oooool2okko0004oil0oonh0?oo^03ookP0o`;oB_l00_oX
o`03o`1go`;o0?ol0_ooool4okSo00Kooooo0ol0omP00oooooooD?l0oe3o0004oe3o00;ooooo1_n1
0?l5o`2?o`_ooooo4Ol0ok@Eooooo`ko0?nd2?ooool00om@o`3o08ooo`2?o`03o`2?o`CoP@3o2ooo
ool2okSo0003onSo0?l0omSo0?oH00;oB_l01_ooool3okP0o`03o`1goooooooooooo00?ooooo0_l0
oo`3og/0o`Go__l06?ooool3okko00CoN`3o0_ooool4o`3oo0Gooooo0onO0?l5okP0o`;o07Oo2Ooo
ool6onSo00GoB_l000?o^?l0o`3of?l0omP00_l0omP=ooooo`Sok_l06?ooool<oe3o03gooooo0onh
0?l9oooooaGoQol01_nO0?l<o`3o5Poooooo000Jooooo`03o`000?oooooooooo00Kooooo00?oo`2G
ool0??oo0;H03oooool01?oo0;Koooooooooooooool2od@0o`07ob`0ool0a_ooo`0lool0WOoooooo
V@3oool0CP02oo@0o`;o203o00Koo`1]oooP0?oo0;3oo`2`o`3oj_ooX`03ooooo`05ohd0oooooooo
04Kooi<0oooj0?l00_oo_0002_ooooooo`2lol[o0?odo`3oooooool0i_ooU`3o2?l0ojco0?ooool2
ool0U`?ooooo00?o<P3oooo/0?ook0001?ooool2ofl0o`03o`3Noooo0=CoTol000Kooooo00Goo`3b
o`2jooooR`3oooooo`3o@002ooooo`;o01Ko0_o:0?l01OooooooJOl0ofWo0?mYo`3ooooo00;o0?l@
00Cooooooch0ooln0?oo0P3o0_ooool2o`3oG`03oooooome0?ooM@3o00;oj03o00?oN`3ooooooooo
ool00omeo`02ooooo`;o/P3o0_ooool2okko0004oil0oonh0?oo^03ookP0o`;oB_l000?oj?l0oooo
ooooool00_l0Mol2o`3oo0;ooooo0onho`07ooooo`?o0?oH1?m@o`03ooooo`GoP@3o1Ol0Sol9oooo
o`So0?nd:_n7o`0:ooooo`Oo0?nd1_ooool01Om@o`3o08ooo`2?ool0Sooooooo00?oP@3o00?ok_l0
ooooooooool01oooool2okSo0003onSo0?l0omSo0?oH00;oB_l01oooool3okP0o`03o`1goooooooo
oooo00Gooooo1Omk0?lBokko00WoN`3o0_ooool4o`3oo0Cooooo1?nO0?l4okP0o`;o07Oo2Oooool5
onSo0003oooooom:o`3oB_l000?oB_l00onho`03o`3of0_ooooo1_o^o`0Dooooo`coD?l0?_ooool>
ohOo00;o^03o1on7o`04oooooaOo0?lF1OnO0?l7oa[o00oooooo000Jooooo`03o`000?oooooooooo
00Kooooo00?oo`2Gool0??oo0;H03Oooool2ool0]P?ooooo013oA03oodCo0?l/0?ooPOl0ool0??oo
09gooooooiT0oooo04kom03oomKo0?l80?oo0?l^ool0KOooh03oo`2`0_l0onX02_ooX`3ooooooooo
ooooooooS@3oooooool0A_ooT`3oooX0oooo_002ooooo`0;ool0_?o:o`3om?l0oooooooo0>KooiL0
o`So0?n/o`3oooooool0Uoo4o`000oooool00olb0?ooon`0ooooo`04ooooo`05ofl0ool0g_ooo`3D
ool0e?oob0001Oooool2ool0lP04o`2joooooooo0?m0o`3o@0;ooooo00Co01KoolX0ooo:0?oo5?l0
0_mYo`03ooooo`05o`3o4?oooooo?P3ooch0ool20?l00_ooool2o`3oG`;oM@3o00?oN`3oonP0oooX
0?l00oooool2ogGo00;ooooo0onb0?l2ooooo`03okko0?nO0?oo^03o00;o^03o0_m:o`000ooXo`3o
ooooooooo`03o`1go`;o0?ol00CooooookSo0?nho`3o^?l01Oooool2oe3o00?o0?oH00?oD?l0onko
0?o^o`000oooool4oh40o`Co08oo1oooool8o`3o]0CoQol07?ooool;o`3o5POooooo1on7o`0:oooo
o`Co0?nd1_ooool3o`2?o`04oooooon10?ooP@3oonko00Wooooo0onho`02o`3of0;oB_l02?ooool3
okP0o`03o`1goooooooooooo00Gooooo0_l0oo`Bog/0o`?ooooo2?l0oo`2ooooo`GoW`3o1Onh0?l2
o`1go`Sooooo1OoXo`000oooooooB_l0od[o0003od[o00?o^?l000?oooooo`3of?l0omP00_l0omP8
ooooo`Kok_l04Oooool9oe3o03?ooooo3?n7o`0Ko`3o5P?o^03o2?l0oaH3oooooa;o6_l01oooool5
oil0oa7ooooo000Jooooo`03o`000?oooooooooo00Oooooo00?oo`2Gool0??oo0;H02oooool00ooo
0;Koooooooooo`02ooooo`0Aod@0oom4o`3o;03ooh7o0?oo03coNol0oooooonI0?ooo`1>oo@0oooF
o`3o203oo`3o;_oo06goon00ool0/?l0onX00_ooX`02ooooo`;oS@3o0_l0A_l01?nC0?oonP3ooonl
0?ooool2ool0_009ooCo0?ooooooo`3Vool0i_ooU`3o2?l0ojco0?ooooooo`2G00Cooooo00?o<P3o
ooo/0?ooool00oooool2ofl0o`04o`3Noooo0=CoTol0ooo800Gooooo00Goo`3bo`2jooooR`3ooooo
o`3o@002ooooo`03o`0Fooo:0?oobP3o00;o5?l000CoJOl0oooooooooooooooo0_l0oa02och0o`;o
0P3o0_ooool01?l0oeooM@3oogD0oomk0?l2onP0o`?ooooo0_meo`02ooooo`;o/P3o0oooool01?nn
o`3oW`3ookP0oonh0?l3od[o00?ooooo0_l0Mol2o`3oo004oooooonho`3o^?l0okSo00?ooooo0om@
o`04o`3of0?ok_l00_ooool4oh40o`?o08oo1_ooool2ohOo00Co0?nd5OoooolCo`3o5P_ooooo3Ol0
oaH00oooooooQol0ohOo0007ohOo00Gooooo0ol0ok@5ooooo`04oe3o0?l0Sooo08ooo`2?o`;oP@3o
00?ok_l0ooooooooool02?ooool2okSo00;o0?oH0_m:o`08ooooo`05oil0oonh0?oo^03ookP0ool0
Mol02_oooolAo`3oo0?ooooo1onO0?l5okP0o`;o07Oo2Oooool4onSo00;ooooo1?m:o`03okSo00;o
oooo1?l0omP7ooooo`Gok_l04Oooool6oe3o00cooooo7?n10?l8ohOo01So0?lF7Oooool00olJo`3o
^03ookP0o`09oa[o01kooooo0_nO0?l?ooooo`006_ooool00ol0003oooooooooo`07ooooo`04ool0
Uooo03coA03oool0]PWooooo00?oo`2fooooooooool00_ooool01_m40?ooA?l0ob`0oon1o`3oo`0l
og_o00;oV@3o00Coo`1>oo@0oooFo`3o203o0_oo06d01?ooh03oo`2`o`3oj_ooX`03ooooo`03ohd0
oooooooo04Ko00;oT`3o00_onP3ooonl0?ooooooo`2lo`3oXOodo`3oooooool0i_oooooooiL0o`So
0002ooooo`03ool0Uooooooooooo00;ooooo00?o<P3oooo/0?ooool00_ooool2ofl0o`04o`3Nool0
8_ooo`3Dooo800Gooooo0_oo0?801_l0^_oooh/0o`3o@?l0od3oooooo`0Fo`;obP3o00?ooooooaCo
0?mYo`001?ooool00ol0oa3o?P3ooch0o`02o`80o`;ooooo0_l0oel01?me0?ooN`3oonP0oooX0?l3
ooooo`;oMOl00_ooool2ok80o`;ooooo0_nno`000onO0?oo^03ookP0o`02od[o00Cooooo0_l0Mol2
o`3oo0?o^?l000?ooooooe3o0?m@o`000om@o`03o`3of0?ok_l00oooool3oh40o`?o08oo1?ooool4
ohOo00Co0?nd5?ooool5o`3o5P;ooooo:?lJo`000ooooooo0?lFo`3o5P09o`3o5P;oQol01Oooool3
o`3o]0Cooooo0_m@o`02o`2?o`;oP@3o00?ok_l0ooooooooool02?ooool2okSo00;o0?oH0om:o`08
ooooo`03oil0oonh0?oo^03o00?oW`3o5_ooool4oil0o`03oooooonh0?oo^03o00Co^03o0_l0Mol:
ooooo`Coj?l00oooool3od[o00?o^?l00oooool3o`3of0Kooooo1Oo^o`0@ooooo`KoD?l02_ooool8
oh40o`Sooooo2on7o`06ooooo`?o0?lF1_n10?l2o`3o5QCooooo8OlJo`03ooooo`?o^03o=Oooool0
01[ooooo00?o0000ooooooooool01oooool01Ooo09Ooo`1>ool0??m40?ooo`2f00Kooooo0_oo0;H4
ooooo`07od@0ool/0?oo;03ooh7o0?oo03coNol0oiT0o`02ool0CP04oo@0ool80?oo203oool0K@;o
on0000?oo`2`o`3oj_ooX`000oooool01_n=0?ooooooo`16oonC0?oo01coooX0o`;ooooo00Soo`2l
o`3oXOooooooooooool0i_oooooooiL0o`So00;ooooo00?oo`2Gooooooooool00_ooool00olb0?oo
on`0ooooo`02ooooo`06ofl0oooooooo0=koo`0Roooo0=CoolP01Oooool01Ooo0?;oooooo`2joooo
oooo0?m000;ooooo0_o:0?l2ooooo`03oaCo0?oooooooooo00;ooooo00Go0?l@och0ooln0?oooooo
o`80o`03ooooo`05o`3oGoooooooN`3oog/0oooX0?l01?ooool01Omeo`3ooooooooooooooooo/P3o
00;ooooo00?o__l0oil0oonh0?l00_nh0?l00om:o`3oooooooooo`03ooooo`;o07Oo0_l0oo`2okSo
00CoD?l00_ooool3o`3of0;ok_l01?ooool3oh40o`;o08oo0_ooool6ohOo00Co0?nd3?ooool<o`3o
5POo6_l000?oooooob00oolP0?l05olP0?l>ooooo`Go6_l01oooool4o`3o5P03ohOo0?oooooooooo
00?ooooo0ol0ok@4ooooo`03oe3o0?l0SoooD?l000;oP@3o00?ok_l0ooooooooool02?ooool2okSo
00;o0?oH00?ooooood[o0?m:o`002Oooool6okP0oa?oW`3o1Onh0?l2o`1go`_ooooo1OoXo`03oooo
o`CoB_l00_nho`03ooooo`Co0?oH1Oooool4onko00oooooo1_m@o`0:ooooo`KoP@3o2?ooool8ohOo
00[ooooo1ol0oaH9ooooo`CoP@3o1_ooool<oa[o02Oooooo0_nh0?lcooooo`006_ooool00ol0003o
ooooooooo`07ooooo`05ool0Uooo06goo`0lob`0oom40?l01_oo0;H4ooooo`;oA03o00go;03ooooo
oon1o`3oo`0log_o0?nI0?ooo`1>oooooood0?oo203oo`3o;_oo06goon0000;oo`2`00Co0?oZoonS
0?oooooooooo0_n=0?l02_oooooo04Kooi<0ool07?oonP3oooooooo:o`3oo`2lo`3oXOooool2ool0
iP06ooooool8o`3o2?l0ooooooo4o`3oo`2G1?ooool01?lb0?ooon`0ooooooooool2ofl0o`;o0=ko
00?o02;oool0e?ooool01?ooool2ool0lP05ooooool0^_ooooooo`3o@?ooool00_o:0?l2ooooo`;o
5?l01?ooool00ol0oa3o?P3oooooo`02o`80o`;ooooo0_l0oel01?me0?ooN`3oonP0oooX0?l3oooo
o`;oMOl00_ooool2ok80o`03oooooonno`3oW`3o00;o^03o00?oB_l0ooooooooool01?ooool2o`1g
o`;o0?ol00Co^?l0oe3o0?m@o`3oD?l01?ooool2o`3of0;ok_l01?ooool01Ol0SoooP@3ooh40ool0
Sooooooo00GoQol00_ooool4o`3o]0_ooooo1Ol0oaH00ooooooo6_l0oa[o0002oa[o00oo803o6Ooo
ool=ob00o`Kooooo1OlJo`06ooooo`?o0?lF00?oQol0ooooooooool00oooool2o`3o]0Cooooo0_l0
Sol01?m@o`3oP@3ooh40ooo^o`0:ooooo`;o^?l00_l0omP00oooooooB_l0od[o000=oooooa?o^03o
0_l0Mol<ooooo`Coj?l01?ooool4od[o00?o^?l00_ooool4o`3of0Gooooo1?o^o`0>ooooo`GoD?l0
2_ooool6oh40o`Sooooo1_n7o`09ooooo`Wo0?lF2oooool9oa[o00CoP@3o0_lJo`0eooooo`;o^03o
<Oooool001[ooooo00?o0000ooooooooool02?ooool01?oo09Ooo`1>ool0??m40?l8ooooo`;oA03o
0_l/0?l03Oooooooo`0lool0??mko`3oV@3oool0C_oooooom03oo`P0ool0obkoo`1]oooP0?oo0;00
0_l0onX01?ooX`3ooooooooooon=0?l2ooooo`0Ao`16oonC0?oook`0ooX0oooooooob_l0ool0_?l0
oj7oooooool0i_oooooo<_l0o`So0?ooW@3oooooolCo0?oo09L01?ooool00olb0?ooon`0ooooo`02
ofl0o`05ooooool0g_ooTol0o`0Roooo0=@01Oooool02?oo0?;oooooo`2jool0^_ooooooo`3o@?oo
oooobP3o0_ooool00omYo`3o5?l0ooooo`04ooooo`;o?P3o0_l20?l3ooooo`05o`3oGoooooooN`3o
og/0oooX0?l00oooool2ogGo00;ooooo0_nb0?l00ooooooo__l0oil0o`02okP0o`03od[o0?oooooo
oooo00Gooooo00?o07Ooo`3oo?l0oo`00om@o`05ooooo`;o0?oH00Cok_l0oooooooooooooooo0_l0
Sol3oh40o`CoQol00oooool4o`3o]0_ooooo1?l0oaH4oa[o00Ko803o=Oooool5ob00o`Kooooo1_lJ
o`03ooooo`?o0?lF00?oQol0ooooooooool00_ooool2o`3o]0Cooooo00Co08oooe3o0?ooooooP@3o
0_o^o`0:ooooo`05okSo0?oXo`3o0?oHo`3of?ooool00_m:o`0Wooooo`Goj?l01Oooool3od[o00?o
^?l00_ooool4o`3of0Gooooo1?o^o`0>ooooo`CoD?l02?ooool7oh40o`Sooooo1_n7o`07ooooo`So
0?lF3?ooool8oa[o00gooooo0on10?lfooooo`?o^03o;_ooool001[ooooo00?o0000ooooooooool0
2?ooool01?oo09Ooo`1>ool0TOoo03`2od@0o`Cooooo0_m40?l2ob`0o`;ooooo00goo`0log_o0?mk
o`3oV@3oool0C_oooooom03oo`P0ool0obkoo`1]oooP0?oo0;3o0?oZ00;ooj<00_ooool05?n=0?oo
ooooo`16ool0A_ooT`3ooonl0?oj0?oooooooiWo0?oo0;co0?nQoooooooo0>Kooooooc;o0?l8o`3o
oid0ooooooo4o`3oo`2G1?ooool01?lb0?ooon`0oooooom_0?l2ooooo`04o`3NoonCo`3o02;oool0
e0Cooooo0_oo0?802?oooooo0;[ooooooooooooo0?m0ooooooo:0?oooooo0_mYo`000olDo`3ooooo
ooooo`02ooooo`;o?P3o00?oooooo`80ooooool00_ooool2o`3oG`;oN`3o0_oX0?l2ooooo`;oMOl0
0oooool01onb0?oooooookko0?nno`3oW`3ookP0oooXo`001oooool2o`1go`03o`3oo?m@o`3oD?l0
00Gooooo00?ok_l0o`3of?l0omP00oooool3o`2?o`;oP@3o0on7o`03ooooo`Co0?nd3?ooool3o`3o
5PSo803o@?ooool5ob00o`Oooooo1?lJo`02ooooo`?o0?lF00CoQol0oooooooooooooooo0_l0ok@3
ooooo`;o08oo00?oD?l0oh40oon10?l00_o^o`09ooooo`;o^?l000Coj?l0o`3of?l0omSo0?oH0om:
o`0Pooooo`Coj?l01Oooool5od[o00;o^?l00_ooool4o`3of0Gooooo1?o^o`0?ooooo`?oD?l01ooo
ool5oh40o`Wooooo1_n7o`08ooooo`Go0?lF2oooool9oa[o01Sooooo0on10?lfooooo`;o^03o;?oo
ool001[ooooo00?o0000ooooooooool02?ooool01?oo09Ooo`1]ool0C_oo03`2ob`0o`CoA03o0_l/
0?l01OooooooPOl0ool0??oo03coNol000;oV@3o00[oo`1>oooooood0?oo203ooooooooo06goon00
ool0/?l0on[ooj<00_ooool2ohd0o`0@ooooool0A_ooT`3ooi<0oooo_03onP3ool[o0?nIo`3oo`2l
o`3oXOooooooo`3Voooooolbo`3o2?l0oonM00;oa?l000?oo`2Gooooooooool00_ooool01Olb0?oo
on`0ofl0oom_0?oooooo00;o0=ko00?oTol0o`0Roooo0=@01?ooool01?oo0?;oooooooooool0^_l2
ooooo`05o`3o@?o:0?oobP3ooooooomYo`000_lDo`03ooooo`;o?P3o00?oooooo`80ool20?l00ooo
ool01Ol0oeooN`3oog/0ool0o`Coj03o00?ooooo00CoMOl0oooooooooooooooo0_nb0?l2okko0003
oil0oonh0?oo^03o00Oooooo0_l0Mol2oe3o00Gooooo0_o^o`02o`3of0?ooooo0_l0Sol3oh40o`04
ohOo0?ooooooooooooooo`Co0?nd2oooool8ob00odgooooo1OlP0?l6ooooo`?o6_l00_ooool2o`3o
5P04ohOo0?ooooooooooooooo`;o0?nd0oooool00ol0SoooD?l0ooooo`02oh40o`;ok_l02Oooool3
okSo0004onSo0?l0omSo0?oHo`3of0?oB_l06Oooool4onSo00?ooooo1_m:o`03okSo00;ooooo1?l0
omP5ooooo`Cok_l03oooool4oe3o00Kooooo1?n10?l8ooooo`KoQol02Oooool5o`3o5P_ooooo1OlJ
o`0Jooooo`[o803o0on10?laob00o`Cooooo0onh0?lYooooo`006_ooool00ol0003oooooooooo`08
ooooo`06ool0Uooo0;coo`1]ool0C_oo03coodh01?l/0?l01?ooooooPOl0ool0??oo03`2og_o000<
oiT0oooo04koo`1>oooooood0?oo203ooooooooo06goon00ool0/?l0on[ooj<00_ooool01On=0?oo
ooooooooool0A_ooT`3o00;ook`000konP3ool[o0?nIo`3oo`2lo`3oXOooooooo`3Voooooolbo`3o
2?l0oonM0?o4o`3oooooool0U`Cooooo00?o<P3oooo/0?m_0?l00_ooool01Ol0g_ooTol0oi?o0?l0
8_ooo`3D00Cooooo00Coo`3booooooooR`3o0;[o0_ooool00ol0od3obP3oo`0Fo`02ofWo0004oaCo
0?ooooooooooooooo`;o?P3o00?o0?l@o`80ool20?l01?ooool2og/0o`03ogD0oooX0?ooj03o00?o
oooo00?oMOl0ooooooooool00_nb0?l00onno`3oB_l0oil0o`02okP0o`Oooooo0_l0Mol2oe3o00Go
oooo0_o^o`02o`3of0;ooooo0_l0Sol3oh40o`Cooooo0ol0ok@;ooooo`Co803o00?o0?lFoa[o0?oo
ool0Eoooool3ob00o`Kooooo0_lJo`02ooooo`;o0?lF00CoQol0oooooooooooooooo0_l0ok@2oooo
o`;o08oo00CoD?l0oooooon10?oooooo0_o^o`0:ooooo`;o^?l000GoooooonSo0?l0omSo0?oHonSo
0005od[o00gooooo1ooXo`03ooooo`CoB_l000?ooooookSo0?nho`000_nho`02ooooo`Co0?oH1Ooo
ool4onko00oooooo1?m@o`07ooooo`?oP@3o1_ooool6ohOo00_ooooo1?l0oaH2oooooa?o08oo2Ol0
ok@Aob00o`gooooo0_n10?l_ooooo`Oo803o0onh0?l2ob00obCooooo000Jooooo`03o`000?oooooo
oooo00Wooooo00Coo`2Gool0_?oo04koo`2A0_oo03`4oh7o0003ool0??mko`3oNol000;oV@3o00Oo
o`1>oj`0oooooooom03oo`P0ooooooooo`1]00;oo`2`00Go0?oZoonS0?ooooooooooohd0o`02oooo
o`03o`16oonC0?oook`000;onP3o00gob_l0oiWo0?oo0;co0?nQoooooooo0>Ko[?l0oc;o0?l8o`3o
oid0olCo0?ooooooo`2G00Cooooo00Co<P3oooo/0?m_0?oooooo0_l0g_l01?nCo`3oooooo`0Roooo
0=@4ooooo`04ool0l_oooooooh/0o`2jo`;ooooo00Ko0?m0olX0ool05_ooJOl0oooooolDo`02oooo
o`;o?P3o0_l0oa000ol20?ooooooooooo`02ooooo`05o`3oGomk0?ooM@3oogD0oooX0?l00oooool2
ogGo00;ooooo00Ko/P3ooooooom:o`3oB_l0oil0oonh0?l7ooooo`;o07Oo0_m@o`05ooooo`;ok_l0
0_l0omP2ooooo`04o`2?oon10?ooP@3ooh40o`Cooooo0ol0ok@:ooooo`Co803o00?o0?lFoa[o0?oo
ool0G_ooool2ob00o`Kooooo00Co6_l0oooooooooooooooo0_l0oaH4ooooo`;o0?nd0_ooool2o`2?
o`04oooooon10?ooP@3oooooo`?ok_l02Oooool4okSo00?o0?oH0ooXo`0God[o00Go^?l00_ooool4
o`3of0Gooooo1?o^o`0@ooooo`?oD?l01oooool4oh40o`Cooooo1On7o`0=ooooo`?o0?lF1ol0Sol0
0ol0okCooooooa[o0005oa[o00Sooooo3?lP0?l3ooooo`Ko0?nd5oooool00on10?ooooooooooo`0f
ooooo`?o^03o2_lP0?l:o`2Eo`oooooo000Jooooo`03o`000?oooooooooo00Wooooo00Goo`2Gool0
_?oo06goo`1>ool0T@05ool0?003ool0WOnI0?ooV@3o00;oo`1>00[o[03ooo@0oood0?oo203ooooo
oooo06goo`2`ooooool0on[ooj<00_ooool01on=0?ooooooooooool0A_ooT`3ooonl0?oj0?l00_o:
o`001_nIo`3oo`2lo`3oXOooooooo`3Vojco00;o2?l000Cooid0olCo0?oo0?Soo`2G1?ooool01Olb
0?ooon`0ofl0oooooooo0=ko00;oTol000?oooooo`0Roooo0=@01?ooool01?oo0?;ooooooon;0?l0
^_l2ooooo`;obP3o00Go01KoofWo0?oooooo5?l0ooooo`02och0o`04ooooool0oa3o0P3oo`80o`Co
oooo0_mk0?l00ome0?ooj03oonP0o`03ooooo`08ogGo0?oooooooooooooooonb0?oo__l0od[o0?nO
0?l2okP0o`Oooooo00?o07Oooe3o0?ooool01Oooool2onko00;o0?oH00?oooooohOo0?n10?l00_n1
0?l4ooooo`?o0?nd2Oooool4ob00o`03o`3o5_lJo`3o6_l006Cooooo0_lP0?l5ooooo`;o6_l00ooo
ool2o`3o5PCooooo0_l0ok@2ooooo`03o`2?oom@o`3ooooo00;oP@3o0_ooool2onko00_ooooo0onh
o`03o`3of17ooooo1_nho`000ooooooo0?oHo`3of004o`3of0Gooooo1?o^o`0@ooooo`CoD?l01_oo
ool4oh40o`Gooooo0on7o`0?ooooo`Ko08oo0_l0ok@2ooooo`Go6_l02Oooool5ob00o`Sooooo0ol0
Sol:ooooo`?o0?nd5Oooool2oh40ocOooooo0_l0UOl4okP0o`Ko09Go2_lP0?l?ooooo`006_ooool0
0ol0003oooooooooo`09ooooo`04ool0Uooo0;conP3oool0K@;oo`1>1OnI0?l01Ooo097oo`1>oj`0
oon/0?oom03o00;o203o00?oon00ool0KOoo0;000_l0onX01?ooX`3oooooohd0oon=0?l2ooooo`05
o`16oonC0?oook`0ooX0ooo:o`000_nIo`001ooo0;co0?nQoooooooo0>Ko[?l0o`So0?ooU`000_o4
o`000ooo0?Soo`38ool0U`03ooooo`06oc80ooook03oK`3oooooool0g_ooTol00_ooool00ol08_oo
o`3Dooooo`02ooooo`;oo`3b00?ooooooon;0?l0^_l00_ooool00oo:0?ooooooo`0Fo`02ooooo`03
oaCo0?oooooo?P3o00;ooooo0_l20?l4ooooo`;oN`3o00?oooooogD0oooX0?l01?ooool01omeo`3o
oooooooooooooooo/P3ood[o0?nO0?l00_nh0?l6ooooo`03oe3o0?l0Mooo07Oo00Kooooo0_o^o`00
1?oooooo0?oHohOo0?n7o`02oh40o`Gooooo0_l0ok@8ooooo`Co803o0_l0oaH2oa[o02_ooooo0ol0
UOlNofT0o`;o09Go6oooool2ob00o`Gooooo00?o6_l0ooooooooool00_ooool00ol0oaKooooooooo
o`03ooooo`03o`3o]?oooooooooo00;o08oo0_ooool01?n10?ooooooooooooooool2onko00gooooo
0_nho`04o`3of0go^?l00oooool4o`3of0Oooooo1?o^o`0Aooooo`?oD?l01oooool3oh40o`Kooooo
0on7o`0=ooooo`Go08oo0_l0ok@4ooooo`Co6_l02?ooool6ob00oa3ooooo0ol0Sol:ooooo`;o0?nd
5Oooool2oh40obCooooo4Ol0UOl6ooooo`?o^03o7?ooool001[ooooo0ol00009ooooo`05onP0oooo
09Ooo`2lool0KOod0?l01ooo04h02Ooooooom03ooo@0ool80?oooooooooP0?oo06goo`2`o`3ojP02
oonS0003oooooon=0?oooooo00;ooooo0_nC0?l2ooX0o`0?ol[o0?nIo`3oo`2lool0_?l0oj7ooooo
ool0i_n/o`3o2?l0oonG0?o4o`3oooooool0n?oo0<Soo`2G00?ooooo00Ko<P3oofl0oom_0?oooooo
o`3NoonCo`02ooooo`03o`0Roooo0=Cooooo00;ooooo00[oo`3boooooooooooooh/0o`2joooooooo
0?m0olX0oomYo`3o01Ko0_ooool00olDo`3ooooooch0o`02ooooo`03o`80oooooooooooo00?ooooo
00GoN`3ooooooome0?ooM@3oonP0o`04ooooo`03ogGo0?oooooooooo00;o/P3o00?oB_l0oil0oonh
0?l01_ooool01?m@o`3o07Ooo`1gool0oo`5ooooo`;ok_l000Coooooo`3of?l0omSoQol00_n10?l5
ooooo`;o0?nd1oooool3ob00o`05ooooool0oaKo0?lFo`3o5_lJo`008oooool3o`2Eo`_oJ@3o7_oo
ool7ofT0o`?o09Go5Oooool2ob00o`Cooooo0_lJo`03ooooo`;o0?lF1?ooool02?l0okCooooooooo
oooooooo08oooe3o0?ooooooP@3o1?ooool00oo^o`3oooooooooo`0@oooooa3o0?oH1oooool4onko
01;ooooo0om@o`07ooooo`?oP@3o1Oooool4ohOo00_ooooo1Ol0Sol2o`3o]0Kooooo0olJo`07oooo
o`Go803o6Oooool3o`2?o`Wooooo0ol0ok@Dooooo`03oh40oooooooooooo013ooooo4Ol0UOlJoooo
o`?o^03o6Oooool001[ooooo00?o0000ooooooooool02_ooool00ooo09Ooo`2lohd0o`02ool0K@;o
m03o0_n/0?l3oo@0o`;o203o00Koon00ool0KOoo06goo`2`o`3oj_ooX`02ooooo`0;ohd0oooooooo
oooooooooonC0?oo01coooX0ooo:o`3om?l0oiWo0?oo0;`00_l0oj402_ooooooo`3Vooooool8o`3o
oiL0olCo0?ooooooo`3hool0b?oo09L3ooooo`06oc80oom_0?ooooooooooool0g_ooTol00_ooool0
0ooob03oo`3Dooooo`02ooooo`06ool0l_oooooooh/0oon;0?l0^_oooooo0_o:0?l01OmYo`3o01Ko
oooooooooooo5?l000;o?P3o0_ooool00ol20?ooooooooooo`02ooooo`;oN`3o00CoooooogD0oooX
0?ooj03o0oooool2ogGo00;ooooo00?o/P3ood[o0?m:o`000_nh0?l5ooooo`04oe3o0?l0Mooo07Oo
o`3oo0Gooooo0_o^o`001?oooooo0?oHo`3of?n7o`02oh40o`Cooooo0ol0ok@6ooooo`?o803o0_oo
ool2o`3o5P03oa[o0?oooooooooo01kooooo0ol0UOl6ofT0oc3ooooo2?mY0?lBooooo`;o803o1?oo
ool2oa[o00?ooooo00?o0?lFooooooooool00_ooool01?l0okCoooooooooooooool2o`2?o`03oe3o
0?n10?oooooo00?ooooo0oo^o`0Sooooo`?ok_l04_ooool4oe3o00Oooooo0on10?l5ooooo`?oQol0
2oooool4o`2?o`?o0?nd00?o0?lFooooooooool01?ooool3oa[o00Cooooo1_lP0?lQooooo`;o08oo
2_ooool2o`3o]1?ooooo0_n10?l4ooooo`co09Go;_ooool4okP0oaGooooo000Jooooo`03o`000?oo
oooooooo00[ooooo00Koo`2Gool0_?oj0?ooS@3oool0KOl80?l4oo@0o`;o203o00?oooooool0KOoo
06d00_oo0;02oonS0003oooooon=0?ooS@3o00;ooooo00WoooP0oi<0ool07?oonP3ool[o0?odo`3o
VOl0ool0_?l0oj400_ooool00ooo0>Koooooo`So0002olCo0004oooooooo0?Soo`38ool0U`?ooooo
00Ko<P3oofl0ooooooooooooo`3NoonCo`02ooooo`03ooo80?l08_ooo`3D00;ooooo00Soo`3boooo
ooooR`3oooooo`2joooooooobP3oofWo00;o01Ko0_ooool00olDo`3o?P3oooooo`02ooooo`04o`80
ooooooooooooooooo`;oN`3o00CoooooogD0oome0?ooj03o1?ooool01_meo`3ooooooooooooooooo
/P3ood[o00;o^03o1?ooool3oe3o0003o`1gool0ooco0?ol00Gooooo00Gok_l0oooooon7o`3o0?oH
ohOo0002oh40o`Cooooo0_l0ok@6ooooo`?o803o0_ooool00olJo`3o0?lFo`3o5P0Mooooo`Co09Go
1OmY0?l4ooooo`[oKol06omM0?lDooooo`04o`2EoomY0?ooJ@3oofT0o`;o09Go3oooool2ob00o`Co
oooo0_lJo`02ooooo`;o0?lF0oooool00ol0okCoooooooooo`02ooooo`03o`2?oom@o`3oP@3o00Ko
oooo0oo^o`0Mooooo`?ok_l04_ooool3oe3o00Sooooo0on10?l5ooooo`?oQol02_ooool4o`2?o`Co
0?nd00?o0?lFooooooooool01?ooool3oa[o0003oooooolP0?oo803o00Co803o:Oooool00ol0Sooo
ooooooooo`09ooooo`;o0?nd4ol0UOl01?n10?oo09Goo`2Eool0UOlmooooo`04o`04oonh0?oo^03o
okP0o`?o00Co3oooool001[ooooo00?o0000ooooooooool02_ooool01Ooo0=Coo`2Gool0_?o:o`3o
S@3o00?oo`1]0_l0obh3ool0K@;oo`2`00Go0?oZoonS0?ooooooooooohd0o`03ooooo`04oooh0?nC
0?oo01coooX0o`;om?l000CoVOl0ool0_?l0oj7ooooo0_oo0>H02?oooooo2?l0olCo0?ooW@3ooooo
ool0n?oo0<Soo`2G0oooool01_lb0?ooK`3ooooooooooooo0=kooi?o00;ooooo00?oolP0o`0Roooo
0=@00_ooool02Ooo0?;ooooooon;0?oooooo0;[oooooooo:0?ooJOl0o`0Fo`03ooooo`04oaCo0?ln
0?ooooooooooo`;o0P3o0oooool01_mk0?oo0?mOoooooome0?oo0?l4onP0o`Cooooo00?oMOl0oooo
ooooool00_nb0?l00om:o`3o^03oooooo`03ooooo`;oD?l000Co^?l0o`1gool0Mooo0?ol1Oooool2
onko0003ohOo0?l0omSo0?oH00;oP@3o1?ooool2o`3o]0Gooooo0olP0?l2ooooo`;o6_l00_l0oaHJ
ooooo`Co09Go1OmY0?l9ofoo00[oG@3o6ol01?l:oed0o`kooooo0omY0?l2o`2Eo`kooooo0_lP0?l4
ooooo`;o6_l00_ooool01?l0oaKoooooooooooooool2o`3o]0?ooooo00Co08oooe3o0?n10?ooP@3o
1oooool3onko01Oooooo0oo^o`0Booooo`?oD?l02?ooool3oh40o`Gooooo0on7o`09ooooo`Co08oo
00Coooooo`3o]?l0okCo0?nd0_l0oaH6ooooo`?o6_l01?lP0?l`ooooo`;o08oo0_ooool9o`2Eo`;o
0?nd4_ooool2oh40oc?ooooo2ol01?l4o`;o00?o^03o3oooool001[ooooo00?o0000ooooooooool0
2_ooool01_oX0?ooo`2Gool0_?oj0?ooS@3oooooo`;oo`2`0_oo06d3ool0/0;o0?oZ00Cooj<0oooo
ooooooooS@3o0oooool02ooon03oT`3oooX0oooj0?oom?l0oooooonIo`3oo`2lo`3oXOooooooo`3V
00;ooooo00Oo2?l0olCo0?ooW@3oooooool0n?oo0<Soo`2G00?ooooo0_m_0?l2ooooo`07o`3NoonC
o`3ooooooooooooob03o02;oool0e002ooooo`05ool0l_oooooooh/0ooooool0^_l00_o:0?l00ooo
oooo01Koooooo`02ooooo`;o?P3o0_ooool00ol20?oo0?l@ooooo`02ooooo`04og/0oooooooooooo
ogD0o`;oj03o0oooool2ogGo00;ooooo00Co/P3ood[o0?nh0?oo^03o1?ooool01_m@o`3oooooo`1g
ool0Moooooooo`3oo0Cooooo00Gok_l0ohOo0?n7o`3o0?oHo`2?o`02oh40o`Gooooo00?o0?ndoooo
ooooool00_ooool3ob00o`?ooooo0_lJo`02o`3o5QWooooo0ol0UOl4ofT0o`;oKol03?mM0?l5o`04
o`?o0_l06?ooool;o`;o00Co00Co1OmM0?l<ooooo`;oJ@3o0_l0UOl>ooooo`03ob00oooooooooooo
00?ooooo00Go6_l0oooooooooooo0?lFohOo0003ooooo`04o`3o]?ooooooooooooooo`;o08oo00?o
D?l0oh40oon10?l02?ooool6onko00Wooooo2?o^o`0Booooo`?oD?l02?ooool3oh40o`Gooooo0on7
o`08ooooo`Co08oo0_ooool3o`3o]0;o0?lF1_ooool3oa[o00?o803o<_ooool4o`2Eo`03o`2?ool0
UOoooooo00[ooooo0_l0ok@Booooo`03oh40oooooooooooo01kooooo4_l01?l5o`;o01cooooo000J
ooooo`03o`000?oooooooooo00_ooooo00Koo`2Gool0_?l0A_oonP3oohd0ooooX`06o`3ojP;ooj<0
0_ooool00on=0?ooooooooooo`02oooh0005oi<0oooj0?oob_l0ooCo0?ooool00_oo0;`00ol0oj7o
[?l0ool0iP02ooooo`07o`So0?o4o`3ooid0oooooooo0?Soo`38ool0U`03ooooo`06ofl0ooook03o
ooooooooool0g_ooTol00_ooool00ooob03o02;oool0e003ooooo`08ool0l_ooR`3oooooo`2jooo:
0?oo0?m0ooooool05_l3ooooo`06och0ooooooooooooooooool20?oo0?l@0_ooool2og/0o`;ooooo
00?oM@3oonP0ooooool00oooool01Omeo`3ooooooooooooooooo/P3o00;o^03o1?ooool2oe3o0003
ooooool0Mooooooo00;o0?ol0oooool01?o^o`3oQol0ohOo0?ooool2o`2?o`03oh40oooooooooooo
00?ooooo0_l0ok@3ooooo`;o803o1?ooool01?lJo`3o0?lFo`3o5_l0oaHGooooo`Co09Go0omY0?l0
0oooooooG@3ooed0o`03oed0o`Ko00Co<oooool5o`;o00;oKol01OmM0?l9ooooo`?oJ@3o00?o09Go
ooooooooool02oooool00olP0?ooooooooooo`03ooooo`05oa[o0?ooooooooooo`3o5_n7o`000ooo
ool2o`3o]0?ooooo00Co08oooooooom@o`3oP@3o3Oooool9onko01Kooooo1?m@o`08ooooo`?oP@3o
1Oooool3ohOo00Oooooo1?l0Sol2ooooo`Co0?nd0_l0oaH6ooooo`?o6_l00olP0?l_ooooo`Ko09Go
1Oooool2o`2?o`cooooo00?o0?ndooooooooool04?ooool00on10?ooooooooooo`0;oooooa;o00Co
3?l2o`0Wooooo`006_ooool00ol0003oooooooooo`0;ooooo`05ool0e?oo09Ooo`2looX0ooo:o`00
0on=0?l4oonS0004oooooon=0?ooS@3oohd0o`;ooooo00CoooP0oi<0oonC0?oonP3o0_odo`001_oo
ooooo`2looooool0oj7o[?l0ool0iP;ooooo00Oo2?l0olCo0?ooW@3oooooool0n?oo0<Soo`2G00?o
oooo00KoK`3oooo/0?ooooooooooo`3NoonCo`02ooooo`03ooo80?l08_ooo`3D00?ooooo00Soo`3b
oon;0?oooooo0;[oolX0ool0od3oooooo`0Fo`;ooooo0_ln0?l3ooooo`06o`80ool0oa3ooooooooo
oomk0?oo0?mO0_ooool00ome0?ooj03oooooo`03ooooo`07ogGo0?oooooooooood[o0?nb0?oo^03o
oil0o`03ooooo`;oD?l000GooooookSo0?l0Moooooooo`3oo003ooooo`04onko0?n7o`3oQol0oooo
o`;o08oo0_n10?l4ooooo`;o0?nd0oooool2ob00o`?ooooo0_lJo`02o`3o5QGooooo00?oKol0o`2E
ool0UOl00_l0UOl01?m_o`3oJ@3oofT0oomY0?l4oed0o`Go00Co?_ooool5o`;o00;oKol00omM0?l9
ooooo`;oJ@3o00?o09Goooooooooool02_ooool2ob00o`Cooooo00Co6_l0oooooooooooo0?lF0_n7
o`03ooooo`07o`3o]?ooooooooooooooool0Sooooooooe3o0002oh40obKooooo1?m@o`09ooooo`?o
P@3o1Oooool3ohOo00Kooooo1?l0Sol3ooooo`?o0?nd00Coooooo`3o5_l0oaKo0?lF1Oooool3oa[o
00?o803o;Oooool5o`2Eo`gooooo00?o08ooooooooooool02_ooool00ol0okCoooooooooo`0@oooo
o`03oh40ool01?oo00Co00[o00Co1_ooool<o`;o01kooooo1_l0ojL?ooooo`006_ooool00ol0003o
ooooooooo`0;ooooo`08onP0oooo09Ooo`3hool0_?oj0?oob_l0ooooooooT@05ohd0o`Cooooo00Go
ooP0oi<0oooj0?oonP3oooCo0002ooooo`05ool0_?oooooo0?nQojco0?oo0>H00_ooool01ol8o`3o
oooooonM0?ooooooo`3hool0b?oo09L00oooool00om_0?ooon`0ooooo`02o`3No`06oi?o0?oooooo
ooooooo80?l08_ooo`3D0oooool00ooo0?;ooooooon;0002olX0o`03o`3o@?oooooo01Ko00;ooooo
00?o?P3ooaCo0?ooool00_ooool01_l20?oo0?l@ooooooooooooN`3oo`3oG`;ooooo00?oM@3oonP0
ooooool00oooool00omeo`3oooooooooo`02ok80o`03okP0oonO0?oooooo00;ooooo00OoD?l0oooo
oooooooo^?l0o`1goooooooo0?ol00;ooooo0on7o`001Ooooooo08ooo`2?ool0omSoP@3o00Gooooo
00?o0?ndooooooooool00olP0?l3ooooo`;o6_l00_l0oaHBooooo`?oKol00ol0UOl2ooooo`?oJ@3o
0_mM0?l4o`04odWooooo0ol2o`000oooooooKol0oed0o`02oed0o`Sooooo0_mY0?l00ol0UOoooooo
ooooo`0:ooooo`03ob00oooooooooooo00;ooooo00?o6_l0ooooooooool00_l0oaH01On7o`3ooooo
oooooooooooo0?nd00?ooooo0_l0Sol2ooooo`?oP@3o8?ooool3oe3o00[ooooo0on10?l5ooooo`?o
Qol01_ooool3o`2?o`Cooooo0ol0ok@01?oooooo0?lFo`3o5_l0oaH5ooooo`?o6_l00olP0?lZoooo
o`Ko09Go4oooool00ol0Sooo/_l0ok;o0009ok;o0003ofoo0?l0okCoKol000GoKol03?l01?l00on1
0?oo0_l0o`;o000?o`;o01ooKol02ol0ojL6ofoo00oooooo000Jooooo`03o`000?oooooooooo00_o
oooo00Ooj03oool0Uooo0?Soo`2lo`16oooj0?ooT`3o00Wooooo00?oooP0oi<0oooj0?l00_odo`02
ooooo`05ool0_?oooooo0?nQoooooooo0>H00_ooool01ol8o`3ooooooonM0?ooooooo`3hool0b?oo
09L00oooool01?m_0?ooon`0ooooool0g_l2oi?o00;ooooo00?oolP0o`0Roooo0=@00oooool02?oo
0?;ooooooon;0?o:0?ooooooo`3o@?oooooo01Ko0_ooool00oln0?oo5?l0ooooo`02ooooo`03o`80
ool0oa3ooooo00;oN`3o00Go0?mOooooooooooooM@3oonP0o`03ooooo`;oMOl000Gooooood[o0?nb
0?oo__l0okP0o`03ooooo`;oD?l000OooooookSo0?l0Mooo07Ooooooool0oocooooo00;oQol00_oo
ool2o`2?o`03o`3of?n10?ooP@3o00Cooooo0_l0ok@00ooooooo803oob00o`04ooooo`;o6_l00_l0
oaH@ooooo`CoKol00ol0UOl2ooooo`?oJ@3o00CoG@3oo`04ool01?oo00CoDOooool3o`;o0003oooo
oom_o`3oG@3o00;oG@3o1oooool2ofT0o`03o`2Eoooooooooooo00Wooooo00?o803oooooooooool0
0_ooool2oa[o00;ooooo00?o0?lFohOo0?n7o`000_ooool00ol0okCoooooooooo`02ooooo`03o`2?
oooooooooooo00;ooooo0on10?lHooooo`GoD?l02?ooool5oh40o`Gooooo0on7o`06ooooo`?o08oo
1?ooool3o`3o]0;ooooo0_l0oaH6ooooo`;o6_l00olP0?lXooooo`Go09Go2?oooolAok;o0003o`2?
oom_o`3oKol000KoKol02ol01?l=o`;o0003oh40oooooooooooo00gooooo3onbo`0Ao`3oYb3ooooo
000Jooooo`03o`000?oooooooooo00_ooooo00[o^03oool0e?oo09OoK`3oool0_?l0A_oonP3ooi<0
ooo:o`3oooP00_ooool2oooh00;oT`3o0_oj0?l01oodo`3oooooooooooooooooo`2lojco0?l0oj40
0_oo0>H2ooooo`07o`So0?oooooooid0oooooooo0?Soo`38ool0U`02ooooo`;oK`3o00Coon`0oooo
ool0g_ooTol00oooool00ooob03o02;oool0e003ooooo`09ool0l_ooooooJOl0olX0oooooooo0?m0
ooooool05_oooooo00;o?P3o00[o5?l0ooooooooooooooooo`80ool0oa3oooooog/0oooooooo0?mO
0_ooool00ome0?ooj03oooooo`02ooooo`05ogGo0?ooooooB_l0od[o0?nb0?l00_nh0?l3ooooo`05
oe3o0?oooooooooookSo0?l0Mol00_ooool00ol0oocoQol0ohOo0002ooooo`;o08oo0_l0omP00on1
0?ooooooooooo`02ooooo`;o0?nd00?oooooob00oolP0?l01Oooool00olJo`3oooooo`3o5P0>oooo
o`CoKol000Co/_l0o`2Eool0UOoo09Go0_ooool3ofT0o`03oed0ool01?oo00Co02Cooooo9?l0ojL@
ooooo`?o0_l000Goooooofoo0?mM0?ooG@3ook;o0006ooooo`;oJ@3o00?o09Goooooooooool02?oo
ool2ob00o`Cooooo00Ko6_l0oooooooooooo0?lFoooooon7o`02ooooo`03o`3o]?oooooooooo00;o
oooo00?o08ooooooooooool01?ooool3oh40o`03oe3o0?oooooooooo00cooooo1_m@o`08ooooo`Go
P@3o1oooool3ohOo00Kooooo0ol0Sol4ooooo`?o0?nd0_ooool3o`3o5PGooooo0_lJo`03ob00obKo
oooo1Ol0UOl8ooooo`Go/_l00oooool;ofoo00co00Co1ol2o`000ol0okCoooooooooo`0?ooooo`03
oh40oooooooooooo00Sooooo4ol0ojL4oooooaGo/_l06?ooool001[ooooo00?o0000ooooooooool0
3?ooool01_oX0?ooo`2Gool0n?oo0>Koo`2lo`16o`;onP3o1OnC0?l2ooX0o`03ooCo0?oooooooooo
00;ooooo00Coo`2lojco0?l0oj7oo`3V0oooool01ol8o`3ooooooonM0?ooooooo`3hool0b?oo09L0
0_ooool01_m_0?oo<P3oooo/0?oooooo0=kooi?o00?ooooo00?oolP0o`0Roooo0=@00oooool03?oo
0?;oooooolX0ooo:0?ooooooo`3o@?oooooo01Koooooooln0?oooooooaCo00?ooooo00Ko0P3oo`3o
4?ooooooN`3oooooool0oel2ooooo`03ogD0oooX0?oooooo00;ooooo00?oMOl0oooooom:o`000_nb
0?l01?nh0?ooW`3oooooooooool2oe3o00;ooooo00?o^?l0o`1gooooool00_l0oo`00on7o`3ok_l0
ooooo`02o`2?o`04ooooool0omSoP@3ooh40o`Cooooo00Co0?ndoooooolP0?oo803o1Oooool2oa[o
00;o0?lF3?ooool3ofoo0003ok;o0?oooooo09Go00;o09Go0_ooool3ofT0o`03oed0ool01?oo00Co
027ooooo1_l0ojLTooooo`Oo0?nW3?ooool3o`;o0004oooooomM0?ooG@3ook;o00Kooooo0_mY0?l0
0ol0UOooooooooooo`08ooooo`03ob00oooooooooooo00;ooooo00Go6_l0oooooooooooo0?lFoooo
o`02ohOo0003ooooool0okCooooo00?ooooo0_l0Sol7ooooo`;oP@3o3Om@o`0:ooooo`CoP@3o2Ooo
ool3ohOo00Kooooo0ol0Sol4ooooo`?o0?nd0_ooool3o`3o5PGooooo0_lJo`03ob00obGooooo1?l0
UOl00ooooooo/_l0ok;o0006ok;o00coKol00_ooool9o`04o`Go0_l000?o08ooo`;o0?ooool03?oo
ool00ol0okCoooooooooo`0>ooooo`03o`3oYon10?oo0?nW00So0?nW;?ooool9ok;o00oooooo000J
ooooo`03o`000?oooooooooo00cooooo00Ooj03oool0Uooo0?SoK`3oool0i_oo0;co04Ko00OonP3o
1?ooool2ool0_003ojco0?oo0>Koo`3V00;ooooo0_l8o`001_oooooooid0oooooooo0?Soooooool0
U`;ooooo00KoK`3ooc80ooook03oooooo`3NoonCo`03ooooo`04ooo80?l08_oo0;Coool0e0;ooooo
00coo`3booooooo:0?ooooooo`2joooooooo0?m0o`0Foooooooo?P3ooooooolDo`03ooooo`06o`80
ool0oa3oN`3oog/0oooooooo0?mO0_ooool00ome0?ooj03oooooo`02ooooo`06ogGo0?m:o`3oB_l0
ok80oonno`3o^03o0oooool00om@o`3oooooooooo`02okSo0003o`1goooooooo0?ol00;oQol000?o
k_l0ooooool0Sol00_ooool00ol0omSoP@3oooooo`03ooooo`;o0?nd0_lP0?l5ooooo`;o6_l00_l0
oaH;ooooo`?oKol000?o/_l0ooooool0UOl00_l0UOl00ooooooo0_l0ofT0o`02ofT0o`03oed0ool0
1?oo00Co01kooooo1_l0ojLaooooo`Go0?nW2_ooool3o`;o00;oG@3o00?o/_l0ooooooooool01?oo
ool00omY0?oo09Goooooo`09ooooo`03ob00oooooooooooo00;ooooo00Co6_l0oooooooooooo0?lF
0_ooool2ohOo0003o`3o]?oooooooooo00?ooooo00?o08ooooooooooool01_ooool2oh40oa;ooooo
0on10?l:ooooo`?oQol01_ooool3o`2?o`Cooooo0ol0ok@3ooooo`;o0?lF1_ooool2oa[o00;o803o
9?ooool4o`2Eo`Go/_l00_ooool6ofoo00Wooooo0_l01?lDoed0o`gooooo00?o0?ndooooooooool0
0_ooool;o`3oY`;ooooo00?oP@3oooooooooool0B_ooool001[ooooo00?o0000ooooooooool03?oo
ool02?oX0?ooo`3Dool0Uooo0?Soa?l0ool0_?oooooo[?l01?l0A_l5ooooo`04ool0_?n/o`3o[?l0
ool0iP?ooooo013o2?l0oc;o0?oooooooid0oooooooo0?Soooooool0b?oo09Ooooooofl0oolb0?oo
on`0ooooool0g_ooTol00oooool01?oob03o02;oo`2doooo0=@2ooooo`08ool0l_oooooobP3ooooo
ool0^_ooooooo`3o@?l05_l2och0o`03oooooolDo`3ooooo00;ooooo00?o0P3oo`3o4?mk0?l00_oo
ool01Ol0oeoooooooooooome0?ooj03o00?ooooo0_m:o`001?oXo`3o/P3ooil0oonh0?l2ooooo`;o
D?l00_ooool01onho`3oooooo`1goooooooo0?olohOo0?o^o`000_ooool00ol0Soooooooo`3of002
oh40o`?ooooo0_l0ok@2ob00o`Kooooo00?o6_l0ooooool0oaH02_ooool3ofoo0003ok;o0?oooooo
oooo00;o09Go00?oooooo`;o0?mY0?l00_mY0?l00omM0?oo00Coo`04o`0Kooooo`Ko0?nW??ooool3
o`3oY`[ooooo0_l2o`02oed0o`Kooooo0_mY0?l:ooooo`;o803o0oooool00olJo`3oooooooooo`02
o`3o5P;ooooo00?oQol0o`3o]?ooool01?ooool2o`2?o`Sooooo4_n10?l:ooooo`?oQol01_ooool3
o`2?o`Cooooo0ol0ok@4ooooo`;o0?lF1Oooool2oa[o00?o803o8oooool3o`2Eo`Co/_l00_ooool5
ofoo00Kooooo2omM0?l5o`;o00kooooo00?o08oooed0oomM0?l02OmM0?l3o`3oY`04o`3o]?l0ojOo
0?nWo`3oY`kooooo00?oP@3oooooooooool0BOooool001[ooooo00?o0000ooooooooool03?ooool0
1_nh0?ooj03oool0Uooo0?SoK`3oolCo00;oo`2l0on/o`04ooooo`;oo`2l00?o[?l0ool0i_oo0>H0
0oooool04?l8o`3o<_l0ooooooooW@3oooooool0n?ooooooo`38ool0UoooooooK`3ooc80ooook03o
ooooo`3NoonCo`03ooooo`04ooo80?l08_oo0;Coool0e0;ooooo00Woo`3bofWo0?o:0?ooooooo`2j
oooooooo0?m0ooooooln0?l00_ooool02?lDo`3ooooooooooooooooo0P3oo`3o4?mk0?oooooo0_l0
oel2ooooo`03ogD0oooX0?oooooo00;ooooo00OoB_l0onSo0?oXo`3o/P3ooil0oonh0?oooooo00;o
D?l00oooool01Onho`3o07Ooo`1goooooooo0?ol00;ok_l00_ooool01?l0Soooooooo`3of?n10?l4
ooooo`03o`3o]?lP0?oo803o00Kooooo0_lJo`02o`3o5PSooooo0om_o`001?nbo`3ooooooooooooo
ool2o`2Eo`05o`;o0?mY0?ooJ@3oofT0oomM0?l00_l01?lIooooo`Go0?nW5Oooool2oeOo01Ko03Co
6?ooool3o`3oY`Wooooo00Co0_l0ofoo0?mM0?oo/_l01_ooool00omY0?ooooooooooo`09ooooo`04
ob00ooooooooooooooooo`;o6_l00_ooool01?l0oaKooooooooooon7o`02o`3o]0Gooooo0_l0SolN
ooooo`CoQol01Oooool4o`2?o`Cooooo0ol0ok@4ooooo`?o0?lF1?ooool2oa[o00?o803o8oooool3
o`2Eo`?o/_l000?oooooofoo0?m_o`000om_o`05ooooo`KoG@3o0ol01?l00ooooooo0_l0o`;o0004
o`;o01?ooooo0_l0ojL00ol0Sooo0?nWo`3oY`04o`3oY`Cooooo0omM0?l00ooooooo0?ndo`3o]00@
ooooo`;oP@3oBOooool001[ooooo00?o0000ooooooooool03Oooool01ooX0?ooo`2Gool0n?m_0?oo
0?nQoooooooo0>H01ooo0;`00onIo`3oooooool0iP03ooooo`03olCo0?l8o`3o<_l000;ooid000Go
ooooool0n?ooooooo`38ool0U`02ofl0o`05oc80ooook03oooooo`3NoonCo`000oooool01?oob03o
ooooo`0Roooo0=@2ooooo`09ool0l_mYo`3obP3oooooool0^_ooooooo`3o@?oooooo?P3o00;ooooo
00Go5?l0ooooooooooooooooo`80o`02og/0o`03ooooool0oeoooooo00;ooooo00?oM@3oonP0oooo
ool00_ooool01?m:o`3oj?l0oooooonb0?l2okP0o`03oooooom@o`3ooooo00;ooooo0_nho`001Ol0
MoooooooohOo0?l0oocok_l000;ooooo0_l0Sol00ooooooo0?oHoh40o`03ooooo`03o`3o]?lP0?oo
803o00Kooooo0_lJo`000ooooooo0?lFooooo`06ooooo`?oKol000?o/_l0ooooooooool00_ooool2
o`2Eo`04o`;o0?mY0?ooJ@3ooed0o`;o00Co6?ooool4o`3oY`kooooo0omGo`0;o`0doaGooooo00?o
Eol0o`0dool0=?l02?l0=?lAooooo`?o0?nW1oooool2o`;o00;oG@3o1_ooool00omY0?oooooooooo
o`09ooooo`03ob00oooooooooooo00;ooooo00Co6_l0oooooooooooo0?lF0oooool00on7o`3o0?nd
o`3o]005ooooo`?o08oo6?ooool3ohOo00Gooooo1?l0Sol5ooooo`?o0?nd1Oooool2o`3o5PGooooo
00Co6_l0ob00oolP0?oo803o8oooool3o`2Eo`?o/_l01?m_o`05ooooo`GoG@3o1?l01?l00ooooooo
0_l0o`;o0003o`;o01?ooooo1_l0ojL2ooooo`03o`2?oooooooooooo00_ooooo1?mM0?lAooooo`03
oh40oooooooooooo04Kooooo0002ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Wo
oooo00?o0000ooooooooool03Oooool01ooX0?ooo`3Dool0Uooo0?SoK`3oo`3oXOooool00ooo0>H3
oiWo0003oooooooo0>Koo`3V00?ooooo00Goa?l0o`So0?lbo`3ooid0ooooo`02ool0n00:oooooooo
0<Soo`2Gofl0oooooooo<P3oooo/0?oooooo0=kooi?o00?ooooo00CoolP0ooooool08_ooo`3D0_oo
ool01ooo0?;oJOl0olX0oooooooo0;[oooooool0od000_ln0?l2ooooo`06oaCo0?oooooooooooooo
ool20?ooN`3o0_ooool01_l0oeooooooooooooooooooM@3oonP0o`?ooooo00KoB_l0onSo0?oooooo
W`3ookP0ooooool2oe3o00?ooooo00?o^?l0ooooool0Mol00_n7o`001Ol0oocok_l0oooooooooooo
08oo00;ooooo00?o0?oHoh40ooooool00_ooool2ob00o`Oooooo00Co6_l0ooooool0oaKo0?lF1_oo
ool2ofoo0003ok;o0?oooooooooo00?ooooo00?o0_l0o`2EoomM0?l00_mY0?l3o`04oaKooooo1?l0
ojL<ooooo`?oEol01_l0=?l6oooooa[o0?m<2_ooool00omGo`3o03Coo`0do`04o`0do`kooooo0_l0
ojL7ooooo`03o`;o0?m_o`3oG@3o00Kooooo00?oJ@3oooooooooool02Oooool00olP0?oooooooooo
o`02ooooo`04oa[o0?ooooooooooo`3o5P?ooooo0_n7o`02o`3o]0Kooooo0ol0SolBooooo`?oQol0
1?ooool4o`2?o`Kooooo0ol0ok@6ooooo`;o0?lF1Oooool00olJo`3o803oob00o`0Sooooo`?o09Go
0_nbo`001?ooooooKol0ofoo0?m_o`04ooooo`GoG@3o1?l01?l3oooooa3oJ@3o1Oooool6o`3oY`Wo
oooo00?o08ooooooooooool03_ooool4oed0o`kooooo00?oP@3oooooooooool0AOooool00005oooo
ool0003oooooooooool000002?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00gooooo00Wo^03oonP0oooo09Oo0=koool0n?oooooo0?nQolCo0?ooool01Ooo0>H00ol0oj7ooooo
ooooo`02olCo0005o`So0?lbo`3ooid0oooooooo0?P00_ooool02Ooo0<Soo`2Gofl0oooooooo<P3o
ooo/0?oooooo0=kooi?o0003ooooo`04ooo80?oooooo02;oool0e0;ooooo00Woo`3bofWo0?o:0?oo
ooooo`2joooooooo0?m0och0ool05_l00_ooool01_lDo`3ooooooooooooooooo0P3oog/0o`;ooooo
00Ko0?mOooooooooooooooooogD0oooX0?l3ooooo`07od[o0?oXo`3ooooooil0oonh0?oooooooe3o
0004ooooo`07okSo0?oooooo07OoohOo0?oooooo0?olonko0002ooooo`03o`2?oooooooooooo00;o
P@3o0_ooool2ob00o`Oooooo0_lJo`000ooooooo0?lFooooo`04ooooo`?oKol000?o/_l0oooooooo
ool00_ooool2o`;o00;oG@3o0_mY0?l2o`04oaKooooo0ol0ojL;ooooo`;oEol01_l0=?l3ooooo`Wo
0?m<6_ooool:o`3oC0Kooooo00CoEol0o`0dool0=?oo03Co3Oooool2o`3oY`Kooooo0_l2o`02oed0
o`Gooooo00?oJ@3oooooooooool02Oooool00olP0?ooooooooooo`02ooooo`04oa[o0?oooooooooo
o`3o5PGooooo00CoQol0o`3o]?l0okCo0?nd1_ooool4o`2?o`_ooooo0on7o`000ooooooo08ooo`2?
o`04o`2?o`Oooooo0ol0ok@6ooooo`?o0?lF1?ooool01?lJo`3o803oob00oolP0?lQooooo`;o/_l0
0_l0UOl3ooooo`?oKol00oooool4oed0o`03ooooool01?oo00Co00;o00Co0_ooool5ofT0o`oooooo
00?o0?nWofT0oomY0?l01OmY0?l>ooooo`03o`2?oooooooooooo00kooooo00?o0?ndooooooooool0
0omM0?l<ooooo`03oh40oooooooooooo04Cooooo00001Ooooooo0000oooooooooooo000000Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`07onko0?oX0?ooo`2GolX0oooo
0?SoK`3oooooo`07o`3oX@03ooooooo4o`3oa?l000;o2?l000So<_l0oonM0?ooooooo`3hooooooo4
0?ooo`38ool0U`;ooooo00Go<P3oooo/0?oooooo0=kooi?o0003ooooo`04ooo80?oooooo02;oool0
e0;ooooo00Woo`3booooooo:0?ooooooo`2joooooooo0?m0och0ool05_l00_ooool01?lDo`3ooooo
ooooooooool2og/0o`;ooooo00Ko0?mOooooooooooooooooogD0oooX0?l3ooooo`05od[o0?oXo`3o
oooooil0oonh0?l00_m@o`03ooooo`;o^?l000Goooooo`1goon7o`3oooooo`3oo002ooooo`;o08oo
0_ooool01On10?oooooooooooooooooo803o00Oooooo0_lJo`000ooooooo0?lFo`3o5P04ooooo`;o
Kol000?o/_l0ooooooooool00_ooool2o`;o00?oG@3o00CoooooofT0ool01?oo00Co5Oooool3o`3o
Y`_ooooo1Ol0=?l3ooooo`Ko0?m<2Oooool<ob3o01Sooooo1_l0od`4ooooo`?o03Co3?ooool00ol0
ojOoooooooooo`05ooooo`03o`;o0?m_o`3oG@3o00Gooooo00?oJ@3oooooooooool02Oooool00olP
0?ooooooooooo`02ooooo`03oa[o0?oooooooooo00;o0?lF1_ooool00on7o`3o0?ndo`3o]002ohOo
00Kooooo3ol0Sol:ooooo`?o0?nd1oooool2o`3o5PGooooo00?o6_l0ob00oolP0?l08Oooool3ok;o
00;o09Go0_ooool3ofoo00?ooooo0omM0?l2ooooo`?o00Co1_mY0?l2o`;o00gooooo1Ol0ojL8oooo
o`?oJ@3o2oooool00ol0Soooooooooooo`0?ooooo`03o`3o]?oooooooooo00;ooooo0_mM0?l;oooo
o`03oh40oooooooooooo04?ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000oooo
ooooool02?ooool4o`0000gooooo00Soj03oool0e?oo09Ooa03oool0n?m_0?oo2?l0ooooo`Ooa?l0
00Co2?l0oooooolbo`3ooid00_oo0?P01?ooooooa03oool0Uooo09L2ooooo`05oc80ooook03o0=ko
o`3NoonCo`000oooool01?oob03oooooo`0Roooo0=@2ooooo`09ool0l_oooooobP3oooooool0^_oo
ooooo`3o@?ln0?oo01Ko00?ooooo00Go5?l0ooooooooooooN`3oo`3o4002ooooo`06o`3oGooooooo
oooooooooome0?ooj03o0_ooool2od[o0005onSo0?ooooooW`3ookP0oom@o`001?ooool01onho`3o
ooooooooool0MoooQol0ooooool0oo`00_ooool01Ol0SoooooooooooooooooooP@3o00;ooooo0_lP
0?l7ooooo`04oa[o0?ooooooooooo`3o5PCooooo0_m_o`000onbo`3oooooooooo`02ooooo`;o0_l0
0_mM0?l01Ol0UOooooooofT0oomY0?oo00Co01Cooooo0ol0ojL9ooooo`Go03Co0_ooool6o`3oC0;o
oooo3OlPo`0<ooooo`oo8?l03oooool4o`3oC0?ooooo0ol0=?l:ooooo`;o0?nW1_ooool00ol2o`3o
Kol0oed0o`05ooooo`03ofT0oooooooooooo00Wooooo00?o803oooooooooool00_ooool01OlJo`3o
oooooooooooooooo0?lF00Sooooo00?o0?ndoooooon7o`002?n7o`0Booooo`Co0?nd2?ooool2o`3o
5PGooooo0olP0?lPooooo`?o/_l000Coooooo`2Eool0UOoooooo0om_o`02ooooo`CoG@3o0_ooool6
ofT0o`Co0_l03?ooool5o`3oYa3ooooo0_mY0?l:ooooo`03o`2?oooooooooooo00oooooo00?o0?nd
ooooooooool00oooool3oed0o`Wooooo00?oP@3oooooooooool0@_ooool00005ooooool0003ooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool03_oo
ool01onh0?ooj03oool0e?oo09Oo<_l0ool0n?m_0?l00_l8o`03ooooo`?o2?l000CooiL0oc;o0?oo
W@3oo`3h0_ooool00oo40?ooo`2Gooooo`02ooooo`03oc80ooook03o0=ko00;oTol00oooool03ooo
b03oooooo`0Rool0]?ooo`3Doooooooo0?;oooooolX0oooooooo0?oNo`2jool0od3o?P3oo`0Fo`03
ooooo`05oaCo0?ooooooooooog/0ool0oa000_ooool01_l0oeooooooooooooooooooM@3oonP0o`;o
oooo00OoB_l0ogGo0?oXo`3ooooooil0oonh0?ooD?l000Cooooo00Co^?l0oooooooooooo07Oo0_oo
ool01?l0oocoooooooooool0Sol2ooooo`;oP@3o0_ooool00olP0?oo0?ndooooo`05ooooo`;o6_l0
00?oooooo`3o5_l0oaH00oooool2ofoo0003ok;o0?oooooooooo00;ooooo0_l2o`02oed0o`04o`2E
ooooooooJ@3oofT0oaCooooo0ol0ojL8ooooo`04oeOo0?l0=?oo03Coo`0do`;ooooo1Ol0od`8ob3o
01;ooooo3_l0oo08ooooo`Oo8?l03?ooool3o`3oC0?ooooo0ol0=?l9ooooo`03o`3oYooooooooooo
00Cooooo00?o0_l0ofoo0?mM0?l01?ooool00omY0?oo09Goooooo`0:ooooo`03ob00oooooooooooo
00;ooooo0_lJo`02ooooo`;o0?lF1oooool3o`3o]1Kooooo0ol0ok@9ooooo`?o0?lF1?ooool3ob00
ob7ooooo0_nbo`02ooooo`;o09Go0om_o`000oooooooG@3ooed0o`02oed0o`;ooooo1?mY0?l2oooo
o`Co0_l03?ooool4o`3oYaOooooo0_mY0?l9ooooo`03o`2?oooooooooooo00oooooo00?o0?ndoooo
ooooool01Oooool2oed0o`Sooooo00?oP@3oooooooooool0@Oooool00005ooooool0003ooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool03_ooool0
1oo^o`3oj03oool0e?oo09Ooa03ooc;o0?oo0?P00_m_0?l3o`So00;ooooo0_lbo`001_ooooooo`3h
ooooooooooooa03oool0U`?ooooo00Co<P3oooo/0?l0g_ooTol01?ooool01ooob03oooooo`0Rool0
]?ooo`3DofWo0?oo0?800_o:0?l01_oooooo0?oNo`2joooooooo?P3oo`0Fo`?ooooo00Go5?l0oooo
oomk0?ooN`3oo`3o4002ooooo`06o`3oGooooooooooooooooome0?ooj03o0_ooool01om:o`3oMOl0
ooooooooooooW`3ookP0oom@o`000oooool2okSo0003oooooon7o`3o07Oo00;ooooo00Co0?oloooo
oooooooo08oo0_ooool01_n10?oo0?oHoooooooooooo803oo`3o]0Gooooo0_lJo`02ooooo`04o`3o
5_ooooooooooooooo`;oKol000Co/_l0oooooooooooooooo0ol2o`001?ooooooG@3oo`2Eooooool2
ofT0oaCooooo0_l0ojL8ooooo`04oeOo0?l0=?oo03Coo`0do`;ooooo0ol0od`3ob3o01;ooooo2_l0
oo0>ooooo`go0?o`0_ooool6ob3o00Wooooo0ol0od`2ooooo`03oeOo0?l0=?oo03Co00Sooooo0_l0
ojL5ooooo`03o`;o0?m_o`3oG@3o00Cooooo00?oJ@3oo`2Eooooool02_ooool00olP0?oooooooooo
o`03ooooo`05oa[o0?ooooooooooooooool0oaH02Oooool6o`3o]0Sooooo2?l0ok@:ooooo`;o0?lF
1Oooool2ob00ob7ooooo0onbo`02ooooo`;o09Go0_m_o`001?ooooooG@3ooed0oomM0?l3ooooo`?o
J@3o00?o00Coooooooooool00ol2o`0=ooooo`?o0?nW7Oooool00omY0?ooooooooooo`07ooooo`03
o`2?oooooooooooo00oooooo00?o0?ndooooooooool01_ooool2oed0o`Oooooo00?oP@3ooooooooo
ool0@?ooool000;ooooo0_l00009ooooo`?o00002_ooool00ol0003oooooooooo`0?ooooo`04onP0
oooo0=CobP3oool0U`;ooooo0_oo0?P00om_0?oooid0oonM0002oc;o0007oonM0?oo0?Soo`3hoooo
oom_0?ooa03oool0U`03ooooo`04oc80ooook03o0=kooi?o00Cooooo00ooolP0ooooool08_oo0;Co
ool0e?mYo`3oo`3bolX0ooooR`3oooooo`3og_l0^_oooooooch0ool05_l00oooool01OlDo`3ooooo
og/0oooooooo0?l@00;ooooo00Ko0?mOooooooooooooooooogD0oooX0?l2ooooo`07od[o0?meo`3o
oooooooooonO0?oo^03ooe3o0003ooooo`09okSo0?ooooooooooohOo0?l0Moooooooonko0?l0ooco
oooo00;o08oo0_ooool00on10?oo0?oHooooo`02ob00o`Kooooo00?o6_l0ooooooooool00_l0oaH0
1OooooooKol0ofoo0?m_o`3o/_l000?ooooo0_l2o`02ooooo`;oG@3o00?o09Goo`04oomY0?l05?oo
ool2o`3oY`Oooooo00GoEol0o`0dool0=?oo03Coob3o0004o`3oC003ob3o0?oooooooooo00[ooooo
2ol0oo0Uooooo`Co0?o`1?ooool4ob3o00Sooooo0ol0od`01?ooooooEol0o`0dool0=?l8ooooo`03
o`3oYooooooooooo00;ooooo00Co0_l0oooooom_o`3oG@3o1?ooool00omY0?oo09Goooooo`0:oooo
o`03ob00oooooooooooo00?ooooo00Co6_l0oooooooooooooooo0ol0oaH<ooooo`So0?nd3oooool3
o`3o5PCooooo0olP0?lPooooo`?o/_l00oooool2o`2Eo`03ofoo0?ooooooG@3o00;oG@3o0oooool3
ofT0o`03o`04oooooooooooo00?o0_l03Oooool3o`3oYb7ooooo0omY0?l6ooooo`03o`2?oooooooo
oooo013ooooo00?o0?ndooooooooool01oooool3oed0o`Gooooo00?oP@3oooooooooool0;?ooool4
ob3o00oooooo000Jooooo`03o`000?oooooooooo00oooooo00Co^03oonP0oooo0=Coo`2G0_o40?l0
0oooooooo`3hool0n005ool0n0?oK`3o00?oa03oool0Uoooool00_ooool00olb0?ooon`0o`3No`05
ooooo`0?ooo80?oooooo02;oo`2doooo0=CoJOl0ool0l_o:0?oooh/0ooooool0omko0;[oooooooln
0?oo01Ko00?ooooo00Go5?l0oooooomk0?ooooooo`3o4002ooooo`06o`3oGooooooooooooooooome
0?ooj03o0_ooool01_m:o`3oMOl0ooooooooooooW`3ookP0o`Cooooo00[o^?l0ooooooooooooQol0
o`1gooooooook_l0o`3oo?oooooo08oo0oooool01On10?oo0?oHoooooolP0?oo0?nd00Kooooo00Go
6_l0oooooooooooo0?lFooooo`02ofoo0003ok;o0?oooooooooo00;ooooo0_l2o`02ooooo`;oG@3o
0_l01?l2ofT0oa?ooooo0_l0ojL6ooooo`04oeOo0?l0=?oo03Coo`0do`Co0?m<3?ooool5o`3ol0ko
oooo6OmG0?l=ooooo`Go0?o`0oooool3ob3o00Sooooo0_l0od`01?ooooooEol0o`0dool0=?l7oooo
o`03o`3oYooooooooooo00;ooooo00?o0_l0oooooomM0?l01Oooool00omY0?oo09Goooooo`0:oooo
o`;o803o1?ooool00olJo`3oooooooooo`03ooooo`;o0?lF7_ooool3o`3o5PGooooo0_lP0?l00olJ
o`3oooooooooo`0Nooooo`;o/_l00oooool00om_o`3o09Goo`2Eo`02ooooo`;oG@3o0oooool3ofT0
o`;o00Co00Coooooo`;o0?l2o`3o0_l03Oooool3o`3oYbOooooo00?oJ@3oooooooooool01?ooool0
0ol0Soooooooooooo`0@ooooo`03o`3o]?oooooooooo00Wooooo0_mM0?l4ooooo`03oh40oooooooo
oooo01Kooooo5OlPo`04o`3oJ`oooooo000Jooooo`03o`000?oooooooooo00oooooo00Co013oonP0
oooo0=CobP3o0_oo09L00oo40?ooooooooooo`07ooooo`03ol@0oooo09Oooooo00;ooooo00?o<P3o
o`3Nool0g_l01Oooool02Ooob03oooooo`0Rool0]?ooo`3DofWo0?oo0?;obP3ooon;0002ooooo`04
o`2joooooooo?P3oo`0Fo`Cooooo00Oo5?l0og/0ooooooooooooo`3o4?oooooo0?mO00?ooooo00Ko
M@3oonP0oooooooooooood[o0?meo`02ooooo`03oil0oonh0?oooooo00?ooooo00[o^?l0oooooon7
o`3oQol0o`1gooooooook_l0o`3oo?oooooo08oo0_ooool2oh40o`04oooooolP0?oo803oo`3o]0Ko
oooo00Co6_l0ooooool0oaKo0?lF0_m_o`000onbo`3oooooooooo`02ooooo`;o0_l00_ooool2oed0
o`;o00Co0_mY0?lDooooo`03o`3oYooooooooooo00?ooooo00Co8?l0o`0dool0=?oo03Co0ol0od`<
ooooo`Co0?o`2oooool8oeL0oaWo07go1omG0?l;ooooo`Go0?o`00?oooooob3o0?lPo`002?ooool0
1?l0odcooooooooooomGo`02o`0do`Kooooo00?o0?nWooooooooool00_ooool00ol2o`3ooooooed0
o`05ooooo`03ofT0ool0UOoooooo00_ooooo00?o803oooooooooool00_ooool2oa[o00Gooooo00?o
0?lFooooooooool06?ooool3o`3o5PGooooo0olP0?lPooooo`?o/_l00_ooool2ofoo00;o09Go00Co
oooooed0oomM0?ooG@3o0oooool2ofT0o`;o00Co00Coooooo`;o0?l2o`3o0_l03Oooool3o`3oYb_o
oooo00?oJ@3oooooooooool01?ooool00ol0Soooooooooooo`0@ooooo`03o`3o]?oooooooooo00[o
oooo00?oG@3oooooooooool00_ooool2oh40o`Gooooo4OlPo`0>ooooo`Co0?m[1ol0oi/?ooooo`00
6_ooool00ol0003oooooooooo`0@ooooo`07onP0ool20?ooo`3Doc80ooooooooo`2Gol@0o`05oooo
o`?oa03o00?oo`2Gooooooooool00_lb0?l00ol0g_ooooooooooo`04ooooo`09ooo80?oooooo02;o
o`2doooo0=Coooooool0l_o:0?oooh/000;ooooo00Co0;[ooch0ooln0?oo01Ko1?ooool01olDo`3o
N`3ooooooooooooo0?l@ooooool0oel00oooool01_me0?ooj03oooooooooooooB_l0ogGo00;ooooo
00?oW`3ookP0ooooool00oooool02?nho`3oooooohOo0?oooooo07Ooooooooo^o`3o0?ol0_l0Sol2
ooooo`05oh40ool0omSoooooob00ool0ok@01_ooool2oa[o0005ooooool0oaKoKol0ofoo0?nbo`00
1?ooool2o`;o00;ooooo0_mM0?l2o`04o`03oooooomY0?oooooo01?ooooo0_l0ojL3ooooo`;o8?l0
0_l0=?l2o`3oC0gooooo0ol0oo08ooooo`03o`1moomG0?ooE`3o00CoE`3o1?l0OOl:o`3oJ`oooooo
2ol0of/8oeL0o`Sooooo0ol0oo02ob3o00Oooooo0_l0od`01?ooooooEol0oeOo0?l0=?l6ooooo`03
o`3oYooooooooooo00;ooooo00?o0_l0ofoo0?mM0?l01Oooool00omY0?ooooooooooo`0;ooooo`;o
803o1?ooool2oa[o00Cooooo0ol0oaHDooooo`?o0?lF1_ooool2ob00o`03oa[o0?oooooooooo01ko
oooo0_nbo`03ooooo`;oKol00_l0UOl00oooooooG@3ooed0o`04ooooo`;oJ@3o0_l01?l00ooooooo
0_l0o`;o000>ooooo`;o0?nW;oooool00omY0?ooooooooooo`03ooooo`03o`2?oooooooooooo017o
oooo00?o0?ndooooooooool01?ooool6ob3o00;oG@3o1?lPo`000on10?oo8?l0ob3o0002ob3o01So
oooo0ol0of/5o`3oV`[o07go3oooool001[ooooo00?o0000ooooooooool04?ooool01onh0?ooj03o
ool0e?o:0?oo<P3ooooooooo09L01Oo40?l00ooo0<Soo`2Gool0U`02ooooo`03oc80ooook03o0=ko
00Kooooo00WoolP0o`0Rool08_oo0;Coool0e?ooooooo`3bolX0ooooR`000_ooool01?l0^_oo?P3o
o`3o@?l05_l4ooooo`;oN`3o0_ooool00ol0oa3oooooo`3oG`03ooooo`03ogD0oooX0?oooooo00;o
B_l000GoMOl0ooooooooooooW`3ookP0o`04ooooo`03okSo0?ooooooQol000;ooooo00Co07Ooonko
0?l0ooco08oo0oooool01On10?oo0?oHoooooolP0?oo0?nd00Kooooo00Ko6_l0oooooooooooo0?lF
ofoo0?nbo`04ooooo`;o0_l00_ooool2oed0o`;o00Co00?oooooofT0oomY0?l04oooool2o`3oY`;o
oooo0olPo`02o`0do`03o`3oC?oooooooooo00[ooooo1?l0oo06ooooo`KoE`3o1_l0of/;oooooaWo
0?nK1Oooool4o`3oJ`?o07go1?mG0?l7ooooo`?o0?o`2?ooool01?l0odcooooooooooomGo`02o`0d
o`Gooooo00?o0?nWooooooooool00_ooool00ol2o`3oKol0oed0o`05ooooo`03ofT0oooooooooooo
00cooooo00?o803oooooooooool00oooool2oa[o00Gooooo1Ol0oaH9ooooo`Ko0?lF1_ooool3ob00
o`03oa[o0?oooooooooo01gooooo0onbo`02ooooo`?oKol00_l0UOl00oooooooG@3ooed0o`03oooo
o`?oJ@3o0_l01?l3o`;o00kooooo0_l0ojLbooooo`03ofT0oooooooooooo00?ooooo00?o08oooooo
ooooool02oooool6ob3o0003o`3o]?lPo`3o8?l000?o8?l02?ooool00omM0?ooooooooooo`02oooo
o`03oh40oooooooooooo013ooooo1Ol0of/00ol0oi_o07goo`1mo`09o`1moaWooooo000Jooooo`03
o`000?oooooooooo013ooooo00GoJ@3oonP0oooo0=CobP3oooooo`02oc80o`Koo`2G0_ooool2oc80
o`;o0=ko1_ooool02Ooob03o02;oooooool0]?ooo`3Doooooooo0?;obP3ooon;0002ooooo`;o?P3o
00?o0?m0o`0Fooooool00oooool01omk0?oo0P3ooooooooooooo0?l@ooooool0oel00oooool01ome
0?ooj03ooooooom:o`3oj?l0ogGo0?ooool00_nO0?l00onh0?ooooooooooo`02ooooo`03okSo0?oo
ooooQol000;ooooo00Co07Ooonko0?l0ooco08oo0_ooool2oh40o`04o`3of?lP0?oo803oo`3o]0Ko
oooo00Ko6_l0oooooooooooo0?lFofoo0?nbo`04ooooo`07o`;o0?oooooooooooooooomM0?oooooo
o`04o`02ooooo`03ofT0oooooooooooo017ooooo0_l0ojL01?oooooo8?l0ob3o0?lPo`03o`0do`_o
oooo1?l0oo05ooooo`GoE`3o00?o07goo`3oJol0of/00ol0of/;ooooo`Ko0?nK6Oooool:o`3oV`04
ooooool0of_o0?m[o`3oJ`;o07go1?mG0?l6ooooo`;o0?o`1oooool2o`3oC004oooooomGo`3oEol0
o`0do`Gooooo00?o0?nWooooooooool00_ooool00ol2o`3oKol0oed0o`04ooooo`03ofT0ool0UOoo
oooo00gooooo0_lP0?l5ooooo`?o6_l01oooool9o`3o5PSooooo0_lJo`02ob00o`03oa[o0?oooooo
oooo01kooooo0_nbo`03ooooo`;oKol000Coooooo`2Eool0UOoooooo0_mM0?l3ooooo`;oJ@3o0_l0
1?l00ooooooo0_l0o`;o000?ooooo`;o0?nW=Oooool00omY0?ooooooooooo`03ooooo`03o`2?oooo
oooo8?l000[o8?l01oooool00ol0okCoooooooooo`0;ooooo`03oed0oooooooooooo00;ooooo00?o
P@3oooooooooool01?ooool7o`3oJ`[o07go9?ooool001[ooooo00?o0000ooooooooool04Oooool0
1OoX0?oo0P3oool0e?o:0?oooooo00;o<P3o00?oooooo`3Nool0g_l00ol0g_l00olb0?oo0=kooi?o
0007ooooo`09ooo80?l08_ooooooo`2doooo0=Coooooool0l_o:0?oooh/000;ooooo00Co?P3ooooo
ool0od3o01Ko1?ooool01omk0?oo0P3ooooooooooooo0?l@ooooool0oel00oooool02_me0?ooj03o
oooooom:o`3oj?l0ogGo0?ooooooW`3ooe3o0?nh0?l4ooooo`03okSo0?ooooooQol000;ooooo00Co
07Ooonko0?l0ooco08oo0_ooool01?n10?ooooooo`3of?lP0?l2o`3o]0Kooooo00Go6_l0oooooom_
o`3o0?lFok;o0004ooooo`;o0_l00_ooool2oed0o`03o`2Eool01?oooooo00;oJ@3o4_ooool2o`3o
Y`04oooooolPo`3o8?l0oeOo00;o03Co00?o0?m<ooooooooool02?ooool3o`3ol0Cooooo1OmG0?l3
o`1mo`;o0?m[2oooool3o`3oVb7o6P3o2oooool5o`3oV`;o0?m[0ol0OOl2oeL0o`Kooooo00?o0?o`
ob3o0?ooool01_ooool01Ol0odcooooooooooomGo`3o03Co00Gooooo00?o0?nWooooooooool00_oo
ool00ol2o`3oKol0oed0o`04ooooo`03ofT0ool0UOoooooo00kooooo00?o803oooooooooool01Ooo
ool2oa[o01;ooooo1?lJo`02ob00ob7ooooo0_nbo`03ooooo`;oKol00ol0UOl00oooooooG@3ooed0
o`03ooooo`;oJ@3o0_l01?l00ooooooo0_l0o`;o000?ooooo`;o0?nW<oooool5ob3o0003ofT0oolP
o`3o8?l000?o8?l000?o08ooooooooooool04Oooool00ol0okCoooooooooo`0;ooooo`;oG@3o0ol0
of/00on10?oo0?m[o`3oJ`02o`3oJ`So07go00?o0?nKooooooooool0:oooool001[ooooo00?o0000
ooooooooool04Oooool01onh0?ooj03oool0e?mk0?oobP3ooooooomYo`001_lb0?l00oook03ooooo
ooooo`06ooooo`0:ooo80?l08_ooooooo`2doooo0=Coooooool0l_o:0?oooh/0ooooo`;o?P3o00?o
0;[oo`3o@?l05_l01?ooool01omk0?oo0P3ooooooooooooo0?l@ooooool0oel00oooool02_me0?oo
j03ooooooom:o`3oj?l0ogGo0?ooooooW`3ooe3o0?nh0?l4ooooo`03okSo0?n7o`3oQol000;ooooo
00Co07Ooonko0?l0Sooo08oo0_ooool01On10?ooooooob00oolP0?oo0?nd00Kooooo0_lJo`001?oo
ooooKol0o`3o5_nbo`03ooooo`;o0_l00_ooool2oed0o`05ooooool01?oo00CooooooomY0?l04_oo
ool2o`3oY`?o8?l000CoEol0o`0dool0=?oo0?m<2Oooool3o`3ol0?ooooo1?mG0?l3o`1mo`?o0?m[
2Oooool00ol0oi_o6P3ooaX0o`06oaX0o`Go?_l07?ooool7oaX0o`Wooooo0ol0oi/3o`3oJ`03o`1m
oomG0?ooE`3o00Gooooo0_l0oo000olPo`3oooooooooo`04ooooo`05o`3oC?oooooooooooeOo0?l0
=?l01Oooool02?l0ojOooooooooooooooooo0_l0oooooom_o`3oG@3o1?ooool00omY0?oo09Gooooo
o`0>ooooo`?o803o1_ooool4oa[o00Wooooo1OlJo`001?oooooo803oob00oolP0?lQooooo`;o/_l0
0_ooool3ofoo00;o09Go0_ooool2oed0o`?ooooo0_mY0?l2o`04o`?o0_l03oooool2o`3oYbcooooo
2OlPo`06ooooo`03ofT0oooooooooooo00;ooooo00?o08ooooooooooool04_ooool00ol0okCooooo
ooooo`03ooooo`So0?m[00?ooooooed0ool0OOl00_l0OOl01?n10?oo07goo`1mool0OOlfooooo`00
6_ooool00ol0003oooooooooo`0Aooooo`09ofT0oooX0?oo0P3oool0e?mk0?oobP3ooooooomYo`3o
oooo00?oon`02?ooool2ooo80004o`0RoomYo`3o0;Coool0e0;oo`3b00SobP3ooon;0?oooooo?P3o
o`3og_l0^_ooooooo`0Fo`Cooooo00OoN`3oo`80ooooooooooooo`3o4?oooooo0?mO00Cooooo00Wo
j03ooooooom:o`3oj?l0ogGo0?ooooooW`3ookko0?nh0?l01?ooool00onho`3oQol0ooooo`02oooo
o`04o`1gooo^o`3o08ooo`3oo0;ooooo00GoP@3ooooooolP0?ooooooo`3o]006ooooo`05oa[o0?oo
ooooKol0ofoo0?l0oaH00oooool2o`;o00;ooooo0_mM0?l00ooooooo09Goo`04o`02ooooo`03ofT0
oooooooooooo013ooooo00?o0?nWob3o0?lPo`000_mGo`02o`0do`Wooooo0ol0oo03ooooo`?oE`3o
0ol0OOl4o`3oJ`Oooooo1_lJ0?l00olno`3oooooooooo`0]ooooo`Co6P3o0_lno`06ooooo`;o0?nK
00Coooooo`3oJol0of_o0?m[0omG0?l4ooooo`;o0?o`00?o8?l0ooooooooool00oooool01Ol0odco
oooooooooomGo`3o03Co00Cooooo00?o0?nWooooooooool00_ooool01?l2o`3oooooo`04oomM0?l4
ooooo`03ofT0ool0UOoooooo013ooooo0_lP0?l8ooooo`Wo6_l01?ooool2ob00ob;ooooo0_nbo`02
ooooo`;oKol000Coooooo`2Eool0UOoooooo0omM0?l3ooooo`;oJ@3o0_l01?l2o`;o013ooooo0_l0
ojLXooooo`Ko8?l04?ooool00omY0?ooooooooooo`02ooooo`03o`2?oooooooooooo00oooooo0ol0
of/01Ol0okCo0?m[o`3oJol0of_o0?nK00Wo07go00?ooooooed0oomM0?l00_ooool00on10?oooooo
ooooo`0fooooo`006_ooool00ol0003oooooooooo`0Aooooo`09o`0@oooX0?oo0P3ooon;0?oo0=Co
02;oolX0ooooooooJOl000[ooooo00OoolP0o`0Rool08_ooJOl0o`2doooo0=Coo`3b00;obP3o00Oo
oh/0och0ooln0?oo0?oNo`2joooooooo01Ko00?ooooo0_mk0?l01_l20?oooooooooooooooooo0?l@
o`3oG`Cooooo00WoM@3oonP0oom:o`3oj?l0ogGo0?ooooooW`3ookko0?nh0?l01?ooool00onho`3o
Qol0ooooo`02ooooo`04o`1gooo^o`3o08ooo`3oo0;ooooo00?oP@3ooooooolP0?l00_l0ok@6oooo
o`05oa[o0?m_o`3oKol0ok;o0?l0oaH00oooool01Ol2o`3oooooooooooooooooG@3o00;ooooo0_l0
1?l00oooooooJ@3oofT0o`0@ooooo`03ob3o0?l0ojOo0?nW00?oEol00_l0=?l8ooooo`?o0?o`0ooo
ool3oeL0o`?o07go0ol0of/6ooooo`Go6P3o0_lno`0:ooooob3o00[o3_ooool4oaX0o`;o?_l01?oo
ool3o`3oV`04ooooool0of_o0?m[o`1mo`?oE`3o0oooool2o`3ol0Gooooo0_l0od`00oooooooEol0
o`0do`04ooooo`03o`3oYooooooooooo00;ooooo00Co0_l0ooooool01?ooG@3o1?ooool00omY0?oo
09Goooooo`0Aooooo`Go803o2?ooool8ob00ob;ooooo0_nbo`02ooooo`;oKol000Coooooo`2Eool0
UOoooooo0_mM0?l4ooooo`;oJ@3o0_l01?l2o`;o013ooooo0_l0ojLTooooo`Ko8?l05oooool00omY
0?ooooooooooo`02ooooo`03o`2?oooooooooooo00Oooooo0ol0of/00ol0oi_o07goo`1mo`09o`1m
o`cooooo00CoG@3oooooooooooooP@3o=oooool001[ooooo00?o0000ooooooooool04_ooool02?nh
0?ooj03oo`0Foooo0=Coo`3bolX0oooob03ooooo0_mYo`07ooooo`08ooo80?l08_ooJOl0ofWo0?l0
]?ooo`3Dool0l_o:0?l2oon;0006och0oooooooo0?oNo`2joooooooo01Ko0oooool00omk0?oooooo
o`80o`03ooooo`03o`3o4?l0oeoooooo00?ooooo00WoM@3oonP0oom:o`3oj?l0ogGo0?ooooooW`3o
okko0?nh0?l01?ooool00onho`3oQol0ooooo`02ooooo`04o`1gooo^o`3o08ooo`3oo0;ooooo00Co
P@3oob00oolP0?oo0?nd1_ooool2oa[o0004ofoo0?nbo`3o/_l0o`3o5P;ooooo0_l2o`02ooooo`;o
G@3o00?oooooo`2Eool01?l00_ooool00omY0?ooooooooooo`0>ooooo`03ob3o0?l0ojOo0?nW00;o
Eol00ol0=?l7ooooo`?o0?o`0oooool3oeL0o`?o07go0_l0of/5ooooo`Go6P3o00?o0?nKocko0?ln
o`002?ooool6o`0:o`Cooooo7?l0@?l:o`0:o`Sooooo0olJ0?l2ocko00Cooooo0ol0oi/2o`3oJ`;o
07go0_mG0?l3ooooo`;o0?o`1Oooool01?l0odcooooooeOo0?l0=?l4ooooo`03o`3oYooooooooooo
00;ooooo00Co0_l0ooooool01?ooG@3o1?ooool00omY0?ooooooooooo`0Eooooo`So803o:?ooool2
ok;o00;ooooo0_m_o`001?oooooo09Goo`2Eooooool2oed0o`?ooooo0omY0?l2o`04o`;o0_l04?oo
ool2o`3oYb7ooooo1OlPo`0Mooooo`03ofT0oooooooooooo00;ooooo00?o08ooooooool0oi/00_l0
oi/9o`1mo`Wooooo00?o0?ndooooooooool03?ooool01?mM0?oooooooooooon10?lfooooo`006_oo
ool00ol0003oooooooooo`0Booooo`06ofT0oooX0?oo0P3oo`2joooo0=Coo`3b0_o:0?l2ooo800Oo
JOl000Go02;oooooool0]?oo0;Coool0e002olX0o`08oon;0?ln0?oo?P3oooooool0omko0;[ooooo
ool05_l3ooooo`03og/0oooooooo0P3o00?ooooo00?o0?l@o`3oGoooool00oooool02Ome0?ooj03o
onSo0?oXo`3oMOl0oe3o0?nO0?oo__l0okP0o`04ooooo`;oQol00oooool01?l0Moook_l0o`2?ool0
oo`2ooooo`04oh40oolP0?oo0?oHo`3o]0Kooooo00Ko6_l0ofoo0?m_o`3o/_l0ooooool0oaH2oooo
o`05o`;o0?oooooooooooooooomM0?l00_ooool01Ol0UOoo00CoooooooooooooJ@3o00oooooo00?o
8?l0o`3oYol0ojL00_mGo`02o`0do`03o`3oC?oooooooooo00Cooooo0ol0oo03ooooo`?oE`3o0ol0
OOl00ol0of_oooooooooo`03ooooo`Co6P3o0ol0oi/2ocko00Gooooo1_l02_l:o`10oakooooo1ol0
@?l00ooooooo00[oo`0:o`03o`0:o`Kooooo0_lJ0?l2ocko00Gooooo0ol0oi/01?l0of_o07gooooo
oomG0?l4ooooo`03o`3ol?oooooooooo00?ooooo00Co0?m<oooooomGo`3o03Co1?ooool00ol0ojOo
ooooooooo`02ooooo`04o`;o0?oooooo00Cooed0o`Cooooo00?oJ@3oooooooooool0@oooool00onb
o`3oooooooooo`02ofoo0004ooooool0UOoo09Goooooo`;oG@3o0oooool2ofT0o`;o00Co0_ooool0
0ol2o`3oooooooooo`0>ooooo`;o0?nW7?ooool2oeOo00Go8?l00omGo`0Nooooo`;o0?nK00?oJ@3o
o`3oVol0oi/01_l0OOlCooooo`03o`3o]?oooooooooo00cooooo00CoG@3oooooooooooooP@3o=Ooo
ool001[ooooo00?o0000ooooooooool04_ooool02_mY0?ooj03oo`80ool05_ooooooool0e?oooooo
02;oolX0ooln0?l4ooo80005ooooool08_oo02;oooooool0]?l00_oo0=@01?o:0?oooooooon;0?ln
0?l2ooooo`04o`3og_l0^_ooooooo`0Fo`?ooooo00CoN`3oooooool20?oo5?l00_ooool00ol0oa3o
0?mOooooo`03ooooo`09ogD0oooX0?ooj?l0oooooomeo`3oD?l0oil0oonno`3o^03o00Cooooo00?o
Qol0ooooooooool00_ooool01?l0Moook_l0o`2?ool0oo`2ooooo`04oh40oolP0?oo0?oHo`3o]0Ko
oooo00Oo6_l0ofoo0?nbo`3o/_l0ooooool0oaKooooo00;o0_l00oooool00omM0?ooooooo`2Eo`02
o`04o`03oooooomY0?ooJ@3o00gooooo0olPo`000ol0ojOoEol0oeOo0002o`0do`;o0?m<1Oooool2
o`3ol0?ooooo0omG0?l3o`1mo`03o`3oJooooooooooo00?ooooo0olJ0?l01Ooooooo0?nKo`3oVol0
oi_o?_l000?ooooo1_l02_l6o`10o`_ooooo7OlV0?l7ooooo`Co043o0_ooool3o`0:o`Gooooo0olJ
0?l00olno`3oooooooooo`04ooooo`;o0?nK0_l0OOl00omG0?ooooooooooo`02ooooo`03o`3ol?oo
oooooooo00?ooooo00?o0?m<ooooool0=?l01Oooool00ol0ojOoooooooooo`02ooooo`04o`;o0?oo
oooo00Cooed0o`?ooooo00?oJ@3oo`2Eooooool0@Oooool2ok;o0004oooooom_o`3oKol0ooooo`;o
09Go00?ooooooed0oomM0?l00oooool2ofT0o`;o00Co0_ooool2o`;o00oooooo0_l0ojLGooooo`Go
Eol01?lPo`08ooooo`WoEol03_ooool00ol0of_o0?nKo`3oV`04o`3oV`?o07go00GoJ@3oo`1moooo
ooooooooo`2?o`0Gooooo`03o`3o]?oooooooooo00cooooo00CoG@3oooooooooooooP@3o=?ooool0
01[ooooo00?o0000ooooooooool04_ooool02Ol04?oo/P3oonP0ool20?oo0;[ooooooooo0=CoN`3o
o`0Ro`02olX0o`Co02;o0_ooool01ol0]?ooo`3DolX0oooo0?;ooooooon;0?ln0?l00_ooool01?l0
omko0;[oooooool05_l3ooooo`04og/0oooooooo0P3ooaCo00;ooooo00?o0?l@o`3oGoooool00ooo
ool02Ome0?ooj03oonSo0?ooooooMOl0oe3o0?nO0?oo__l0okP0o`04ooooo`03ohOo0?oooooooooo
00?ooooo00?o07Ooo`2?ool0oo`00_ooool01?n10?ooooooooooool0omP6ooooo`04oa[o0?oooooo
/_l0ooooo`;o0?lF00?oooooo`;o0?ooool00_ooool2oed0o`03ooooool0UOoo00Co00;ooooo00?o
J@3oooooooooool02oooool2ob3o0004ooooool0ojOo0?nWoeOo00;o03Co0_l0od`5ooooo`;o0?o`
0_ooool3oeL0o`?o07go00?o0?m[ooooooooool00_ooool4oaX0o`04ooooool0oi_o0?nKo`3oV`;o
oooo1Ol02_l6o`10o`Oooooo2_lV0?lMooooo`Oo9P3o1?ooool5o`10o`?o00[o1Oooool2oaX0o`03
ocko0?oooooooooo00Cooooo00Co0?nKo`3oJol0OOooE`3o1?ooool00ol0oo3oooooooooo`03oooo
o`03o`3oC?oooooo03Co00Cooooo00?o0?nWooooooooool00oooool00ol2o`3ooooooed0o`04oooo
o`03ofT0ool0UOoooooo03kooooo0_nbo`001?ooooooKol0ofoo0?ooool2o`2Eo`03oooooomM0?oo
G@3o00?ooooo0_mY0?l2o`04o`;ooooo0_l2o`0?ooooo`;o0?nW4oooool6oeOo00;ooooo0olPo`0E
ooooo`?oEol01oooool5o`3oV`Ko07go1?ooool01OmY0?oooooooooooooooooo08oo01Oooooo00?o
0?ndooooooooool03?ooool2oed0o`03oooooon10?ooP@3o03;ooooo000Jooooo`03o`000?oooooo
oooo01?ooooo00[oJ@3oonP0ool20?oo01Koo`3og_ooooooo`3Dool0l_l0]?oooooo1_o:0?l00ooo
0=Coo`3bool0lP03och0o`;ooooo0_l0^_l01?oooooo01Koooooooooool2og/0o`03ooooool20?oo
5?l000;ooooo00?o0?l@o`3oGoooool00oooool00ome0?ooj03oonSo0002ooooo`04oe3o0?nO0?oo
__l0okP0o`Cooooo00?oQol0ooooooooool00oooool00ol0Mooo08ooo`3oo002ooooo`04oh40oooo
ooooooooo`3of0Gooooo0_lJo`02ok;o0003ooooool0oaKooooo00;o0_l00oooool01OmM0?oooooo
ooooool0UOoo00Co00;ooooo00?oJ@3oooooooooool02_ooool2ob3o00;ooooo00Co0?nWoeOo0?l0
=?oo03Co0_l0od`5ooooo`;o0?o`0_ooool2oeL0o`?o07go0_l0of/2ooooo`Co6P3o0_ooool3o`3o
V`03ooooool02_oo00[o00;o00[o1Ol0@?l9ooooo`Co9P3o;_ooool5obH0o`Cooooo0ol0@?l3o`0:
o`Cooooo0_lJ0?l00olno`3oooooooooo`03ooooo`04o`3oVol0of_o07gooeL0o`Cooooo00?o0?o`
ooooooooool00oooool00ol0odcoEol0o`0do`04ooooo`03o`3oYooooooooooo00;ooooo00Co0_l0
ooooooooooooG@3o1?ooool00omY0?oo09Goooooo`0kooooo`;o/_l00_ooool01?m_o`3oooooo`2E
ool0UOl2ooooo`04oed0ooooooooooooooooo`;oJ@3o0_l01?l2ooooo`;o0_l03oooool2o`3oYa7o
oooo1?mGo`05ooooo`?o8?l06oooool3oeOo00?o0?nK1_l0OOl;ooooo`04ofT0ooooooooooooo`2?
oaSooooo0_l0ok@>ooooo`04oed0oooooooooooooh40oc7ooooo000Jooooo`?o00004oooool01omY
0?oo/P3oonP0ool20?oo01Koo`3og_ooool00ooo0=@00ooo0?;o0;Cooch0o`03ool0e0?o?P3o00Go
oh/0ooooooooooooooooo`2jo`02ooooo`04o`0FooooooooN`3oog/0o`;ooooo00Ko0P3ooaCo0?oo
ooooooooo`3o4?l0oel4ooooo`04ogD0oooX0?ooj?l0ooooo`;oD?l000?oW`3ookko0?nh0?l01?oo
ool00on7o`3oooooooooo`03ooooo`03o`1gool0Sooo0?ol00;ooooo00CoP@3ooooooooooooo0?oH
1?ooool01?m_o`3o6_l0oooooonbo`02ooooo`03o`3o5_oooooo0_l000?ooooo0_mM0?l2ooooo`;o
00Co00?oooooofT0oomY0?l02oooool2ob3o00;ooooo0_l0ojL01?mGo`3o03Coooooool0od`5oooo
o`;o0?o`0_ooool2oeL0o`;o07go0ol0of/4oaX0o`?ooooo0ol0oi/4o`0:o`Co043o2oooool3obH0
ocOooooo0olV0?l4ooooo`;o043o00?oooooo`0:ool02_l01?ooool2oaX0o`03ocko0?oooooooooo
00;ooooo00?o0?nKooooool0of/00_mG0?l3ooooo`03o`3ol?oooooooooo00;ooooo00Co0?m<oooo
oomGo`3o03Co1?ooool00ol0ojOoooooooooo`02ooooo`04o`;o0?oooooo00Cooed0o`Cooooo00?o
J@3oo`2Eooooool0>?ooool2ok;o00;ooooo0_m_o`02o`2Eo`;ooooo0_mM0?l2ooooo`;oJ@3o0_l0
1?l2ooooo`;o0_l04?ooool00ol0ojOoooooooooo`0>ooooo`?oEol01_ooool3ob3o01cooooo0_l0
of/6o`1moa;ooooo00CoJ@3ooooooooooooo08oo6Oooool00ol0okCoooooooooo`0<ooooo`04oed0
oooooooooooooh40oc3ooooo000Jooooo`03o`000?oooooooooo01?ooooo00Ko013ooh40oonh0?oo
j03oo`3oGol05_l2ooooo`03og/0oooo0=Coo`3D00;oo`3D0oooool2oon;00?ooooo0_l0^_l00ooo
oooo01Koo`0Fo`02og/0o`;ooooo0_l20?l01OlDo`3oooooooooool0oa3o0?mO00Cooooo00OoM@3o
onP0oooXo`3ooooooe3o0?meo`3oW`3o00;o^03o0oooool2ohOo00Gooooo00Ko07Ooo`2?oooooooo
0?olob00oon10?l2ooooo`03o`3of?oooooooooo00;ooooo00CoKol0oa[o0?nbo`3o/_l00_ooool0
0ol0oaKoooooo`;o0003ooooo`05oed0ooooooooooooooooool01?l00_ooool00omY0?oooooooooo
o`09ooooo`;o8?l00oooool01?l0ojOoEol0o`0dool0=?l2o`3oC0Cooooo0_l0oo02ooooo`;oE`3o
00Co07goooooool0of_o0?m[0olJ0?l4ooooo`03ocko0?l0oi_o0?nK00?o00[o00Coooooo`10ool0
@?oo043o2_ooool5obH0oa?ooooo5_lho`0Dooooo`Co9P3o0_ooool2o`10o`03ooooool02_oo00[o
00Cooooo0_lJ0?l01?lno`3oooooooooooooool2o`3oV`03o`3oJol0OOooE`3o00;ooooo00?o0?o`
ob3o0?ooool00oooool00ol0odcoooooo`0do`05ooooo`03o`3oYooooooooooo00;ooooo00Co0_l0
ooooool01?ooG@3o1?ooool00omY0?oo09Goooooo`0eooooo`;o/_l00_ooool2ofoo00;o09Go0_oo
ool2oed0o`;ooooo0_mY0?l2o`04o`;ooooo0_l2o`0@ooooo`;o0?nW3_ooool3oeOo00Kooooo0olP
o`0Iooooo`?o0?m[1Ol0OOl6ooooo`;oEol04Oooool00omY0?ooooooo`2?o`0Jooooo`03o`3o]?oo
oooooooo00cooooo00?oG@3oooooooooool00_n10?l^ooooo`006_ooool00ol0003oooooooooo`0D
ooooo`08ofT0oon10?ooj03oo`80ool05_oo0;[oo`3og_ooool2og/0o`Gooh/01?ooool01?l0^_oo
ooooooooool05_l2og/0o`?ooooo00?o0P3ooaCo0?lDo`000_ooool00ol0oa3o0?mOooooo`03oooo
o`09ogD0oooX0?oooooooooooom@o`3oMOl0oil0oonh0?oo/P3o00?ooooo00?oQol0okSo0?ooool0
1?ooool01_l0Mooo08ooooooool0ooco803ooh40o`;ooooo00Co0?oHoooooooooooooooo0_m_o`00
0olJo`3o/_l0ooooo`02ooooo`03o`3o5_l2o`3o0_l000?ooooo00GoG@3oooooooooooooooooo`04
o`02ooooo`03ofT0oooooooooooo00Sooooo0_lPo`03ooooo`;o0?nW0_l0=?l2o`3oC0Cooooo0_l0
oo02ooooo`;oE`3o00Co07goooooool0of_o0?m[0_lJ0?l5ooooo`03ocko0?l0oi_o00[o00;o00[o
00Coooooo`10ool0@?oo043o2?ooool5obH0o`cooooo3?lho`0Fooooo`Ko>?l04_ooool3obH0o`04
ooooool0@?oo043oooooo`;o00[o1?ooool00olJ0?oo?_l0ocko0003ooooo`04o`3oVol0of_ooooo
oeL0o`;ooooo00?o0?o`ob3o0?ooool00oooool00ol0odcoooooo`0do`05ooooo`03o`3oYooooooo
oooo00;ooooo00Co0_l0ooooool01?ooG@3o1?ooool00omY0?oo09Goooooo`0booooo`;o/_l00_oo
ool2ofoo00;o09Go0_ooool2oed0o`;ooooo0_mY0?l2o`04o`;ooooo0_l2o`0Aooooo`03o`3oYooo
oooooooo00_ooooo0omGo`06ooooo`?o8?l06?ooool3o`3oJ`Co07go00?o0?nKooooooooool02_oo
ool00omGo`3oooooooooo`0>ooooo`04ofT0ooooooooooooo`2?oa[ooooo00?o0?ndooooooooool0
3?ooool01OmM0?ooooooooooooooooooP@3o02gooooo000Jooooo`03o`000?oooooooooo01Cooooo
00GoJ@3ooh40oonh0?ooj03oo`80o`02o`0Fo`03o`3og_oooooooooo00;oN`3o1_ooool01Ol0^_oo
ooooo`0Fool05_ooN`3o00Cooooo00?o0P3ooaCo0?ooool00_ooool00ol0oa3o0?mOooooo`03oooo
o`0:ogD0oooX0?oooooooooooom@o`3oMOl0oil0oonh0?oooooook80o`;ooooo00?oQol0okSo0?oo
ool01?ooool01_l0Moooooooooooool0ooco803ooh40o`;ooooo00Go0?oHooooooooooooooooofoo
0002oa[o0006ok;o0?ooooooooooooooool0oaKo0_l00oooool2oed0o`;ooooo0_l01?l2ooooo`03
ofT0oooooooooooo00Oooooo0_lPo`04ooooo`05o`3oYomGo`3o03Coooooool0od`01Oooool00ol0
oo3oooooooooo`02oeL0o`;o07go0_l0of/2oaX0o`Cooooo00?o?_l0o`3oVol02_l00_l02_l01?oo
oooo043oo`10ool0@?l7ooooo`Co9P3o2oooool6ocSo02Sooooo1_lho`0?ooooo`;o9P3o00Cooooo
o`10ool0@?oooooo0_l02_l3ooooo`;o6P3o00So?_l0ooooooooooooooooo`3oVol0of_ooooooeL0
o`;ooooo00?o0?o`ooooooooool00_ooool01?l0odcooooooeOo0?l0=?l4ooooo`03o`3oYooooooo
oooo00?ooooo00Co0_l0ooooool01?ooG@3o1?ooool00omY0?oo09Goooooo`0_ooooo`;o/_l00_oo
ool2ofoo0004ooooool0UOooooooooooo`;oG@3o0oooool00omY0?ooooooo`04o`03ooooo`03o`;o
0?oooooooooo00oooooo0_l0ojL<ooooo`;oEol01_ooool3ob3o01Sooooo0ol0of/3o`1mo`03o`3o
Vooooooooooo00oooooo0_mGo`0?ooooo`03ofT0oooooooo08oo01_ooooo00?o0?ndooooooooool0
3?ooool2oed0o`;ooooo00?oP@3oooooooooool0:_ooool001[ooooo00?o0000ooooooooool05?oo
ool01ol04?ooJ@3ooh40oooX0?oo0?mOo`80ool0od000_l05_l00ol0omkoooooooooo`0:og/0o`Co
oooo00?o0P3ooaCo0?ooool00_ooool00ol0oa3o0?mOooooo`03ooooo`03ogD0oooX0?oooooo00;o
D?l000GoMOl0oil0oonh0?oooooook80o`02ooooo`03ohOo0?nho`3ooooo00Cooooo00Ko07Oooooo
oooooooo0?olob00oon10?l2ooooo`03o`3of?oooooooooo00;oKol000?o6_l0ok;o0?ooool00ooo
ool00ol0oaKo0_l0ooooo`02ooooo`05oed0ooooooooooooooooool01?l00oooool00omY0?oooooo
ooooo`06ooooo`;o8?l01?ooool2o`3oY`;o03Co0_l0od`4ooooo`;o0?o`00?ooooooeL0oomG0?l0
0_l0OOl01?l0of_ooooooaX0oolJ0?l4ooooo`05ocko0?l02_oo00[oo`0:ooooool00ol0@?l7oooo
o`?o9P3o2Oooool6ocSo03Cooooo1_lho`0;ooooo`;o9P3o00Goooooo`10ool0@?ooooooo`0:o`04
ooooo`03oaX0oolno`3o?_l000;ooooo00Co0?nKo`3oJol0OOooE`3o0_ooool00ol0oo3ooooooooo
o`02ooooo`04o`3oC?ooooooEol0o`0do`Cooooo00?o0?nWooooooooool00oooool01?l2o`3ooooo
o`04oomM0?l4ooooo`03ofT0ool0UOoooooo02gooooo00?o/_l0ooooooooool00_m_o`001?oooooo
09Goo`2Eooooool2oed0o`?ooooo0_mY0?l2o`04o`;ooooo0_l2o`0Aooooo`03o`3oYooooooooooo
00Wooooo0omGo`05ooooo`?o8?l06?ooool3o`3oJ`?o07go5oooool00omGo`3oooooooooo`0=oooo
o`03ofT0oooooooo08oo01_ooooo0_l0ok@>ooooo`03oed0oooooooooooo00;oP@3o:_ooool001[o
oooo00?o0000ooooooooool05Oooool01_mY0?ooP@3ookP0oooX0?ooooooo`80o`;o0?m000?o01Ko
o`2jool0^_l01?l0^_l00ooooooo01Koo`0Fo`06ooooo`04o`80oolDo`3oooooooooo`;o0?l@00?o
0?mOooooooooool00_ooool02_me0?ooj03ooooooom@o`3oooooogGo0?nO0?oo^03ooooooonb0?l2
ooooo`03ohOo0?nho`3ooooo00Cooooo00Ko07Oooooooooooooo0?olob00oon10?l2ooooo`07o`3o
f?ooooooooooofoo0?oooooo6_l0ok;o0004ooooo`04o`3o5_ooooooooooooooo`;oG@3o0_ooool2
o`04o`?ooooo00?oJ@3oooooooooool01Oooool2ob3o00Gooooo00Go0?nWo`0dool0=?ooooooo`3o
C004ooooo`;o0?o`00OooooooeL0oomG0?ooooooo`1mool0of_ooooo00;o6P3o1?ooool3o`0:o`04
ooooool0@?oo043oo`10o`Oooooo0olV0?l7ooooo`Go>?l0@?ooool4ocSo00Wooooo0_lV0?l00ooo
oooo043oo`10o`02o`0:o`?ooooo0_lJ0?l01olno`3oooooooooool0oi_o0?m[o`1moomG0?l00_oo
ool00ol0oo3oooooooooo`02ooooo`03o`3oC?oooooo03Co00Gooooo00?o0?nWooooooooool00ooo
ool01?l2o`3oooooo`04oomM0?l4ooooo`03ofT0ool0UOoooooo02[ooooo0_nbo`001?ooooooKol0
ofoo0?ooool2o`2Eo`03oooooomM0?ooG@3o00?ooooo0_mY0?l2o`04o`;ooooo0_l2o`0Aooooo`;o
0?nW2_ooool2oeOo00Gooooo0olPo`0Hooooo`?o0?m[0ol0OOlKooooo`;oEol03_ooool00omY0?oo
ooooo`2?o`0Looooo`;o0?nd3Ol0@?l01OmM0?oo043oo`10ool0@?ooP@3o01[o043o3oooool001[o
oooo00?o0000ooooooooool05Oooool01?mY0?ooP@3oo`;o0?oX0?l2o`3oG`;o0P3o00?o0?m0o`0F
ool05_l01Ol05_l6ooooo`;o0P3o00Co5?l0oooooooooooo0?l@0_l0oel3ooooo`0<od[o0?me0?oo
j03ooooooom@o`3oooooogGo0?nO0?oo^03ooooooonb0?oooooo0_n7o`000onho`3oooooooooo`03
ooooo`03o`2?ool0Mooooooo00;o803o00GoP@3ooooooooooooo0?oHooooo`02ofoo0003oooooolJ
o`3ooooo00?ooooo00?o0_l0o`3o5_ooool00_ooool01_mM0?oooooooooooooooooo00Coo`2Eo`?o
oooo00?oJ@3oooooooooool01?ooool2ob3o00Kooooo00?o0?nWo`0doomGo`000_l0od`4ooooo`05
o`3ol?ooooooE`3ooeL0ooooool00_l0OOl00ooooooo6P3ooaX0o`03ooooo`?o00[o00Co0?nKoooo
ool0@?oo043o1oooool3obH0o`Kooooo1?lho`19ooooo`?o>?l02?ooool2obH0o`04ooooool0@?oo
043oo`0:o`Cooooo00Oo6P3oocko0?ooooooooooo`3oVol0of_oE`3o00?ooooo00Go0?o`oooooooo
ooooooooo`3oC002ooooo`03o`0doooooooooooo00?ooooo00?o0?nWooooooooool00_ooool01Ol2
o`3oooooo`04oom_o`3oG@3o00Cooooo00?oJ@3oo`2Eooooool09oooool2ok;o0004oooooom_o`3o
Kol0ooooo`;o09Go0_ooool01?mM0?ooooooooooooooool2ofT0o`;o00Co0_ooool2o`;o017ooooo
0_l0ojL:ooooo`;oEol01?ooool3ob3o01Wooooo0_l0of/3o`1mob3ooooo00?oEol0ooooooooool0
3?ooool00omY0?oo08ooooooo`0Booooo`_o043o00?o0?ndooooooooool02oooool01OmM0?oooooo
ooooooooooooP@3o02Sooooo000Jooooo`03o`000?oooooooooo01Gooooo00Wo05WoofT0oon10?oo
j03oo`3o4?lDo`3o0?mOooooool20?l01Ol0od06ooooo`;o0P3o00KooooooaCo0?ooooooooooo`3o
4?l0oel4ooooo`0=od[o0?me0?ooj03ooooooom@o`3oooooogGo0?nO0?oo^03ooooooonb0?oooooo
ohOo0002okSo00Gooooo00Ko08ooo`1goooooooo803ooooooon10?l2ooooo`03o`3o]?l0omSoKol0
00;ooooo00?o6_l0ooooooooool00_ooool00ol2o`3o0?lFooooo`02ooooo`06oed0oooooooooooo
ooooool01?oo09Go0_ooool2ofT0o`Kooooo00?o8?l0ooooooooool01?ooool2o`3oY`03o`0doooo
oooo0?m<00Cooooo0_l0oo02oeL0o`03ooooool0OOoo07go00?o6P3o0_ooool3o`0:o`;o0?nK0ol0
@?l6ooooo`?o9P3o1_ooool3ocSo01[ooooo9?l0;_lBooooo`;o>?l02?ooool2obH0o`04ooooool0
@?oo00[oo`0:o`?ooooo00Oo6P3oooooooooooooooooo`3oVol0of_oE`3o00?ooooo00So0?o`oooo
ooooooooooooo`3oC?ooooooEol0o`0do`Gooooo00?o0?nWooooooooool00_ooool01_l2o`3ooooo
o`04oom_o`3oG@3ook;o00?ooooo00?oJ@3oo`2Eool0UOl09Oooool01Onbo`3oooooofoo0?m_o`3o
oooo00;o09Go0_ooool2oed0o`;ooooo0_mY0?l2o`04o`;ooooo0_l2o`0Booooo`03o`3oYooooooo
oooo00Oooooo0omGo`04ooooo`;o8?l06Oooool2o`3oJ`?o07go9?ooool2oeOo00cooooo00?oJ@3o
ooooool0Sol01_ooool<o`10o`cooooo0_l0ok@<ooooo`04oed0ooooooooooooooooo`;oP@3o5Ooo
ool2o`3o]0oooooo000Jooooo`03o`000?oooooooooo01Kooooo00KoJ@3ooh40oonh0?ooj03oo`3o
4?l0oel2ooooo`;o0P3o1oooool2o`80o`;ooooo00?o5?l0ooooooooool00_l0oel4ooooo`03od[o
0?me0?ooj03o00;oD?l000WoooooogGo0?nO0?oo^03ooooooonb0?ooooooohOo0?nho`001_ooool0
1_l0Sooo07OooooooolP0?oooooooh40o`;ooooo00Ko0?ndo`3of?m_o`3ooooook;o0?lJo`03oooo
o`;o0_l000?o0?lFooooooooool00_mM0?l2ooooo`;o00Co00Co09GoooooooooooooJ@3o1_ooool2
ob3o00Kooooo00?o0?nWo`0dool0=?l00_l0od`3ooooo`;o0?o`0_mG0?l2ooooo`03o`1moolJ0?oo
6P3o00;ooooo0ol02_l00olno`3o0?nKo`3oV`02o`10o`Kooooo0olV0?l6ooooo`?o>?l05oooool6
o`0^o`[ooooo4ol0l?l7ooooo`Go02ko3oooool2ocSo00Sooooo0_lV0?l2o`10o`05o`0:oooooooo
oooooooooolJ0?l00oooool00ol0oi_ooooooeL0o`02ooooo`03o`3ol?oooooooooo00;ooooo00?o
0?m<ooooool0=?l01Oooool00ol0ojOoooooooooo`03ooooo`06o`;o0?oooooo00Coofoo0?mM0?oo
/_l00oooool00omY0?ooooooo`2Eo`0Rooooo`;o/_l00_m_o`000ooooooo09Goo`2Eo`02ooooo`;o
G@3o0oooool00omY0?ooooooo`04o`02ooooo`;o0_l04_ooool2o`3oY`Sooooo0_mGo`05ooooo`;o
8?l06Oooool2o`3oJ`;o07go6_ooool<oaX0o`?ooooo00?oEol0ooooooooool01oooool3o`10o`03
ofT0ool0@?oo043o00Go043o6_ooool2o`3o]0_ooooo0_mM0?l3ooooo`;oP@3o4Oooool2o`3o]17o
oooo000Jooooo`03o`000?oooooooooo01Kooooo00KoE`3oofT0oon10?ooj03oogD0ool0oa02o`3o
G`;ooooo1ol20?l3ooooo`04oaCo0?ooooooooooo`3oG`Gooooo00CoB_l0ogD0oooX0?ooD?l00_oo
ool01Omeo`3oW`3ookP0oooooooo/P3o00;oQol000?o^?l0ooooooooool01?ooool01_l0Sooo07Oo
oooooolP0?oo0?oloh40o`;ooooo00Ko0?ndo`3of?oooooooooook;o0?lJo`03ooooo`03o`;o0?oo
oooo0?lF00;ooooo00OoG@3oooooooooooooooooo`04oooooooo09Go00;ooooo00?oJ@3ooooooooo
ool00oooool2ob3o00Oooooo00Co0?nWo`0dool0odco0?m<1?ooool00ol0oo3oE`3ooeL0o`02oooo
o`03o`1moolJ0?oo6P3o00;ooooo0_l02_l2ocko0004ooooool0oi_o043oo`10o`Kooooo0_lV0?l6
ooooo`?o>?l05_ooool4o`0^o`Gooooo2ol0l?lCooooo`Wo0?3o0oooool5o`0^o`cooooo0_lho`08
ooooo`04obH0oooooooo043oo`0:o`?ooooo00Oo6P3oooooooooooooooooo`3oVoooooooE`3o00;o
oooo00?o0?o`ooooooooool00_ooool00ol0odcoooooo`0do`05ooooo`03o`3oYooooooooooo00?o
oooo00Go0_l0ooooool01?ooKol0oed0o`02ok;o00;ooooo00CoJ@3oooooool0UOoo09Go7_ooool2
ok;o00;oKol000?oooooo`2Eool0UOl00_ooool2oed0o`?ooooo0_mY0?l2o`04o`;ooooo00?o0_l0
ooooooooool04Oooool00ol0ojOoooooooooo`06ooooo`;oEol01_ooool00olPo`3oooooooooo`0A
ooooo`Ko0?m<00Co0?m[o`1mool0OOoo07go1?l0od`FoeL0o`;o6P3o3?ooool9oaX0o`Co043o1?oo
ool00omY0?oo08ooooooo`0Pooooo`03o`3o]?oooooooooo00[ooooo00?oG@3oooooooooool00_oo
ool00on10?ooooooooooo`0<ooooo`;o0?nd4oooool001[ooooo00?o0000ooooooooool05oooool0
2?mY0?ooP@3ookP0oooX0?ooM@3oo`3o4?m:o`3o0?mO2Oooool2oaCo0003ooooool0oeoo0?mO00Co
oooo0_m:o`001?me0?ooj03ooe3o0?ooool2ogGo0007oil0oonh0?oooooook80oon7o`3ooooookSo
0006ooooo`06o`2?ool0Mooo803oob00ool0oocoP@3o0_ooool00ol0okCo0?oHooooo`02ok;o0003
oa[o0?oooooooooo00;o0_l00_ooool00ol0oaKoG@3ooed0o`03ooooo`03o`04ool0UOoo09Go00;o
oooo00?oJ@3oooooooooool00oooool00olPo`3oooooooooo`05ooooo`;o0?nW00?o03Coo`3oC?oo
ool00oooool2o`3ol003oeL0oooooooooooo00?o6P3o0_ooool2o`0:o`03oooooolno`3ooooo00?o
043o1_ooool2obH0o`Gooooo0olho`0Fooooo`?o02ko0oooool6o`3`obOooooo1?l0l?l4ooooo`Co
02ko2_ooool2ocSo00Oooooo00Co9P3oooooool0@?oo00[o0_ooool00olJ0?oo?_l0ooooo`02oooo
o`03o`3oVomG0?oooooo00;ooooo00Go0?o`ooooooooooooooooo`3oC002ooooo`03o`0doooooooo
oooo00?ooooo00?o0?nWooooooooool00oooool01?l2o`3oooooo`04oom_o`02oed0o`04ok;o0?oo
ooooooooofT0o`;ooooo00?o09Goooooooooool06?ooool3ok;o00;oKol00ol0UOl2ooooo`;oG@3o
0oooool2ofT0o`;o00Co0_ooool2o`;o01;ooooo0_l0ojL8ooooo`03oeOo0?oooooooooo00Cooooo
0_lPo`0?ooooo`Go0?m<0oooool2o`3oJ`;o07go00?o0?nKo`0dool0=?l01?mG0?l3o`0do`?ooooo
1olJ0?l9ooooo`?oE`3o2Oooool2o`10o`Wo00[o1_lJ0?l3o`0:o`03ofT0ool02_oo00[o00oo00[o
4Oooool2o`3o]0_ooooo00?oG@3oooooooooool00_ooool3oh40o`Wooooo0_l0ok@6o`3`o`oooooo
000Jooooo`03o`000?oooooooooo01Oooooo00SoJ@3ooh40oonb0?oo^03oonP0oooooooo0?l@od[o
00;o0?mO1?ooool3oaCo00;ooooo00?o0?mOooooooooool00oooool01?m:o`3oM@3oogD0oooX0?l2
ooooo`09ogGo0?nO0?ooW`3ookP0oooooooo/P3oohOo0?oooooo^?l000Kooooo00Ko08ooo`1goolP
0?ooooooo`3oo?n10?l2ooooo`06o`3o]?l0omSooooook;o0?oooooo6_l00_ooool01_l2o`3ooooo
oooooooooooo0?lFoed0o`?ooooo0_l01?l01Ol0UOooooooooooooooooooJ@3o00Cooooo0_lPo`07
ooooo`04o`3oYol0=?oo03Coo`3oC0?ooooo0_l0oo02oeL0o`04oooooolJ0?oo6P3oo`3oJ`?ooooo
00Co00[ooooooolno`3o?_l00_l0@?l7ooooo`;o9P3o1?ooool3ocSo01Cooooo1Ol0;_l2ooooo`Co
0?3o<Oooool5o`3`o`?ooooo0ol0;_l9ooooo`;o>?l01_ooool01?lV0?ooooooo`10ool02_l2oooo
o`03oaX0oolno`3ooooo00;ooooo00Ko0?nKoeL0ooooooooooooo`3ol?lPo`03ooooo`04o`3oC?oo
ooooEol0o`0do`Gooooo00?o0?nWooooooooool00oooool01_l2o`3oooooo`04ooooooooKol0oed0
o`;o/_l000CoooooofT0oomY0?oooooo0ol0UOlEooooo`;o/_l000?oooooofoo0?l0UOl00_l0UOl3
ooooo`;oG@3o0oooool2ofT0o`;o00Co0_ooool2o`;o01?ooooo00?o0?nWooooooooool01_ooool2
oeOo00Gooooo0_lPo`0=ooooo`Co0?m<1_ooool3o`0do`KoE`3o1oooool3oaX0o`03o`0doooooooo
oooo00Co0?m<3?ooool3oeL0o`So00[o1_ooool00omGo`3oooooooooo`06ooooo`?o6P3o00?oJ@3o
o`2?ooooool03oooool6o`0:o`gooooo00?o0?ndooooooooool02Oooool00omM0?ooooooooooo`04
ooooo`?oP@3o00?oooooo`3`ool0l?l01Ol0l?lEooooo`006_ooool00ol0003oooooooooo`0Goooo
o`0:oeL0oomY0?ooP@3ook80oonh0?ooj03oogD0ool0oa3oB_l0oaCo00;o0?mO0olDo`001?oooooo
0?mOo`3oGol0oel4ooooo`;oB_l000?oM@3oonP0oooX0?l00_ooool02Omeo`3oW`3ookko0?nh0?oo
oooook80oon7o`3ooooookSo0006ooooo`0?o`2?ool0Mooo803oooooool0oocoP@3ooooooom_o`3o
0?ndo`3of?oooooo/_l0oooooolJo`3ooooo00;o0_l00oooool00ol0oaKoG@3oooooo`02ooooo`03
o`04oooooooo09Go00?ooooo00?oJ@3oooooooooool00_ooool00olPo`3oooooooooo`06ooooo`03
o`3oYol0=?oo0?m<00Cooooo00?o0?o`oeL0oomG0?l00_ooool00olJ0?oo07goooooo`02ooooo`;o
00[o0_lno`02o`10o`Oooooo0_lV0?l4ooooo`;o>?l04oooool4o`0^o`Cooooo0ol0l?ljooooo`?o
0?3o0oooool2o`0^o`Wooooo0_lho`05ooooo`04obH0oooooooo043oo`0:o`;ooooo00?o6P3oocko
0?ooool00_ooool01_l0oi_oE`3ooooooooooooo0?o`ob3o00?ooooo00?o0?m<ooooool0=?l01Ooo
ool00ol0ojOoooooooooo`04ooooo`03o`;o0?oooooo00Co00;ooooo0_mM0?l01?nbo`3ooooooooo
oomY0?l3ooooo`?o09Go4?ooool2ok;o0004ofoo0?l0UOoo09Goo`2Eo`Cooooo0_mM0?l4ooooo`03
ofT0oooooooo00Co00;ooooo0_l2o`0Cooooo`;o0?nW1oooool2oeOo00Kooooo00?o8?l0oooooooo
ool02_ooool3o`3oC0Oooooo0_l0=?l4oeL0o`03o`3oVooooooooooo00Kooooo1?lJ0?l4ooooo`Go
03Co00?oooooo`3oC?ooool01?ooool7o`0:o`;o043o0_mG0?l=ooooo`03oeOo0?oooooooooo00So
oooo00?o6P3oofT0oolJ0?l05Oooool6o`0:o`Sooooo1?l0ok@8ooooo`03oed0oooooooooooo00Ko
0?3o0on10?lJooooo`006_ooool00ol0003oooooooooo`0Hooooo`07ofT0oon10?oo0_l0ok80oonh
0?ooj03oogD0o`03o`3o4003od[o0?l0oeoo0?mO00;o0?mO00Co0?l@oooooooooooooooo0om:o`02
ogD0o`06onP0oooooooooooooooooomeo`3oW`3o0_nh0?l01Ooooooo/P3ooooooooooooo^?l000Go
oooo0_l0Sol02Ol0Mooo803oooooool0oocoP@3ooooooom_o`3o0?ndo`3of002ok;o0004oooooolJ
o`3oooooo`;o00Cooooo00?o0?lFoed0ooooool00_ooool00ol01?ooooooo`2Eo`03ooooo`04ofT0
ooooooooooooooooo`;o8?l01oooool2o`3oY`03o`0dool0odcooooo00;ooooo0_l0oo000omG0?oo
ooooooooo`02oaX0o`?ooooo0_l02_l01?oooooo?_l0o`10ool0@?l7ooooo`;o9P3o0oooool3ocSo
01;ooooo0ol0;_l3ooooo`Go0?3o2_ooool4of?o01OoGOl01_mSo`0Eooooo`;o0?3o0oooool2o`0^
o`Wooooo0_lho`04ooooo`03obH0oooooooo00[o00?ooooo00Oo6P3oocko0?ooooooooooo`3oVol0
OOooE`3o00;ooooo00Go0?o`ooooooooooooooooo`3oC002ooooo`03o`0doooooooooooo00?ooooo
00?o0?nWooooooooool01?ooool00ol2o`3oooooo`04o`03ooooo`04oed0oonbo`3o/_l0ok;o00;o
J@3o1?ooool2o`2Eo`_ooooo0onbo`03o`2Eo`Gooooo0_mM0?l4ooooo`;oJ@3o0_l01?l00ooooooo
0_l0o`;o000Dooooo`03o`3oYooooooooooo00Gooooo0_mGo`06ooooo`;o8?l02oooool2o`3oC0Oo
oooo0_l0=?l3oeL0o`03ooooool0oi_o0?nK00Kooooo1?lJ0?l=ooooo`03o`0dool02_oo00[o00Co
00[o0ol0@?l8ooooo`?oE`3o2oooool00omGo`3oooooooooo`08ooooo`03ofT0ool0Sooo6P3o00;o
6P3o6?ooool6o`0:o`Kooooo0ol0ok@6o`3`o`;oG@3o1?l0ok@5ooooo`?oP@3o5oooool001[ooooo
00?o0000ooooooooool06?ooool01omY0?ooG@3ooh40oonb0?oo^03ooil0oooX0?l00oooool4o`3o
40GoB_l000?oj?l0oe3o0?me0?l00_oX0?l3ooooo`03ogGo0?nO0?oo^03o00;ooooo00Co/P3ooooo
oooooooo^?l01Oooool01ol0Soooooooo`1goolP0?ooooooo`3oo?n10?l00_m_o`001?l0okCo0?oH
ok;o0?ooool2oa[o00;o0_l01?ooool01?l0oaKoG@3oooooooooool2o`04o`04ooooool0UOoooooo
ooooo`;oJ@3o0_ooool2ob3o00Sooooo00?o0?nWo`0dool0=?l01?ooool01?l0oo3oE`3ooeL0oooo
ool2oaX0o`03o`3oJooooooooooo00;o00[o00Goooooocko0?lno`3o043oo`3oV`06ooooo`;o9P3o
0oooool2ocSo01;ooooo0ol0;_l2ooooo`Co0?3o1?ooool5of?o00[oGOl05oooool9oego00KoHol0
3_ooool3o`3`o`;ooooo0_l0;_l9ooooo`03ocSo0?oooooooooo00;ooooo00?o9P3oooooool02_l0
0oooool01_lJ0?oooooooooooooooooo0?nKoeL0o`;ooooo00?o0?o`ob3o0?ooool00_ooool01?l0
odcoooooooooool0=?l5ooooo`03o`3oYooooooooooo00Cooooo00Co0_l0ooooool01?oo00Co0_oo
ool2oed0o`04oooooonbo`3o/_l0ofT0o`Gooooo1Ol0UOl00ooooooo/_l0ok;o0002ok;o00Co09Go
1_ooool2oed0o`Cooooo0_mY0?l2o`04o`03ooooool2o`3o0_l001Cooooo0_l0ojL6ooooo`;oEol0
1_ooool2ob3o00_ooooo0_l0od`6ooooo`;o03Co0omG0?l01?l0OOooooooo`3oVol0oi/5ooooo`?o
6P3o3_ooool4o`0:o`;o03Co0_l0@?l@ooooo`;oE`3o2_ooool00omGo`3oooooooooo`08ooooo`04
ofT0ooooooooooooooooo`?o6P3o6oooool5o`0:o`Co0?3o2?ooool00omM0?ooooooooooo`09oooo
o`OoP@3o4?ooool001[ooooo00?o0000ooooooooool06?ooool01omG0?ooJ@3ooed0oon10?oo/P3o
okP0oonO0?l00_oX0?l3ooooo`OoD?l00_me0?l01?oX0?ooooooooooooooool2ogGo0003oil0oonh
0?oooooo00;o/P3o0_ooool00onho`3oooooooooo`03ooooo`0@o`2?oooooooo803oob00oooooooo
0?oloh40oom_o`3oooooo`3o]?nbo`3o0?oHoooooolJo`3oooooo`;o00Gooooo0_mM0?l2ooooo`04
o`04ooooooooooooo`2Eo`;ooooo00GoJ@3oooooooooooooooooob3o0009ooooo`03o`3oYol0=?oo
0?m<00?ooooo0_l0oo001OmG0?oooooooooooolJ0?oo0?m[00;ooooo0_l02_l00ooooooo?_l0ocko
0002o`10o`Kooooo0_lV0?l3ooooo`;o>?l04Oooool3o`0^o`;ooooo0ol0l?l4ooooo`CoHol01OmM
o`0Zooooo`KoGOl00omSo`0>ooooo`?o0?3o00?oooooo`0^ool0;_l02?ooool00olho`3ooooooooo
o`02ooooo`03obH0oooooooo00[o00?ooooo00Ko6P3oooooooooooooooooo`3oVomG0?l2ooooo`03
o`3ol?lPo`3ooooo00;ooooo00?o0?m<ooooool0=?l01_ooool00ol0ojOoooooooooo`04ooooo`04
o`;o0?ooooooooooo`04o`?ooooo00CoG@3oofoo0?oooooooooo0_mY0?l7ok;o00Ko09Go0om_o`05
ooooo`;oG@3o0oooool3ofT0o`;o00Co0_ooool00ol2o`3oooooooooo`0Cooooo`03o`3oYooooooo
oooo00Gooooo00?oEol0ooooooooool01?ooool2ob3o00_ooooo0_l0od`5ooooo`;o03Co0omG0?l2
o`1mo`;ooooo00?o0?nKooooooooool00_ooool3oaX0o`kooooo0ol02_l01?oooooo043oo`10ool0
@?l2ooooo`03o`0doooooooo0?m<017ooooo00?oE`3oooooooooool02?ooool00omGo`3ooooooooo
o`07ooooo`03ofT0ool0Sooooooo00Cooooo0olJ0?lAooooo`So0?3o1?ooool4o`0:o`Wooooo00?o
G@3oooooooooool03oooool00on10?ooooooooooo`0=ooooo`006_ooool00ol0003oooooooooo`0I
ooooo`06ofT0ool01?ooP@3oo`2?oonb0?oo^03o0_nO0?l2onP0o`Kooooo00CoM@3oonP0oooX0?oo
j03o0oooool01_meo`3oW`3ooil0oonh0?ooQol0ok80o`?ooooo00?o^?l0ooooooooool00oooool0
0ol0Soooooooob00o`02ooooo`09o`3oo?n10?ooKol0ooooool0okCo/_l0o`3of?oooooo6_l000;o
0_l01Oooool01_mM0?oooooooooooooooooo00Coooooo`;o09Go0_ooool00omY0?ooooooooooo`02
ob3o00Wooooo00?o0?nWo`0dool0od`00oooool01?l0oo3oE`3ooeL0ooooool2oaX0o`?ooooo00Co
00[ooooooooooooo?_l00_l0@?l00ol0oi_oooooooooo`03ooooo`;o9P3o0_ooool3ocSo013ooooo
0ol0;_l2ooooo`?o0?3o1?ooool00omSo`3oGOl0oego0004oego03Gooooo1OmMo`02of?o00gooooo
0ol0l?l2o`0^o`Oooooo00?o>?l0ooooooooool00_ooool00olV0?ooooooo`0:o`03ooooo`0:oaX0
ooooooooooooo`3oVol0OOooE`3oooooool0oo3oooooob3o00;ooooo00Co0?m<oooooooooooo03Co
1_ooool00ol0ojOoooooooooo`04ooooo`;o0_l000?oooooo`04ool01?l00_ooool3oed0o`;oKol0
0omY0?l3ooooo`GoKol01oooool3oed0o`03oooooomY0?ooJ@3o00;oJ@3o0_l01?l3ooooo`;o0_l0
5?ooool2o`3oY`Kooooo0_mGo`06ooooo`03ob3o0?oooooooooo00Wooooo0_l0od`4ooooo`?o03Co
0_mG0?l00ooooooo07goo`1mo`02ooooo`;o0?nK0_ooool3oaX0o`Gooooo2Olno`03o`0:o`04ocko
0?l0@?oo043oo`10o`?o?_l00oooool00ol0=?ooooooo`3oC00Aooooo`;oE`3o2Oooool00omGo`3o
ooooooooo`07ooooo`03ofT0ool0Sooooooo00Kooooo0_lJ0?l8ooooo`Oo0?3o4?ooool4o`0:o`Ko
oooo00?oG@3oooooooooool07_ooool001[ooooo00?o0000ooooooooool06Oooool01_mG0?ooJ@3o
oed0oon10?oo08oook80o`;o^03o00?oW`3oonP0oooX0?l01_oX0?l5ooooo`06ogGo0?nO0?oo^03o
okP0oon7o`3o/P3o0oooool00onho`3oooooooooo`02ooooo`;o08oo0_lP0?l2ooooo`;oP@3o0_oo
ool01_l0okCo/_l0o`3of?oooooo6_l0o`;o00Kooooo00OoG@3oooooooooooooooooo`04oooooooo
09Go00?ooooo00CoJ@3ooooooooooooo8?l02_ooool00ol0ojOo03Coo`3oC003ooooo`06o`3ol?mG
0?ooooooo`1moolJ0?oo0?m[0_ooool2o`0:o`04oooooolno`3o043oo`10o`;o0?nK1Oooool00olV
0?ooooooooooo`02ocSo017ooooo0_l0;_l2ooooo`?o0?3o0_ooool6oego01gooooo4_l0C?lAoooo
o`?oGOl00omSo`0<ooooo`;o0?3o0_l0;_l6ooooo`03ocSo0?oooooooooo00;ooooo00?o9P3ooooo
ool02_l00_ooool01_lJ0?oo?_l0oooooooooooo0?nKoeL0o`;ooooo00?o0?o`oooooolPo`000_oo
ool01?l0odcoooooo`0doomGo`05ooooo`03o`3oYooooooooooo00Kooooo00Co0_l0oooooooooooo
00Co1?ooool00omM0?ooooooooooo`02ofoo00?oJ@3o2Oooool3oed0o`CoJ@3o00?oooooo`04ool0
1?l01?ooool2o`;o01Gooooo00?o0?nWooooooooool01?ooool2oeOo00Kooooo0_lPo`09ooooo`?o
0?m<1?ooool2o`0do`04oooooomG0?ooE`3oooooo`;o07go0_ooool2o`3oV`;ooooo0_lJ0?l5oooo
o`?o?_l01_ooool3o`0:o`04ooooool0@?oo043oo`10o`Kooooo1?lno`000ol0=?oo?_l0o`3oC00B
ooooo`03oeL0oooooooooooo00Oooooo00?oEol0ooooooooool01_ooool00omY0?oo08ooooooo`08
ooooo`;o6P3o1_l0l?lKooooo`Co00[o0oooool00omM0?ooooooooooo`0Mooooo`006_ooool3o`00
01[ooooo00SoJ@3oo`04oon10?oo0_l0o`2?oonb0?oooooookP0o`;oW`3o2Oooool01?meo`3oW`3o
oil0oonh0?l2ohOo0003ok80oooooooooooo00;o^?l01?ooool01?l0Sooo803oob00ool0Mol2oooo
o`08oh40ool0oocoooooooooool0okCo/_l0o`3of?ooool2o`;o00Kooooo00?oG@3oooooooooool0
0_l01?l00ooooooo09Goooooo`02ooooo`04ofT0oooooooo8?l0ob3o00[ooooo0_l0=?l3ooooo`;o
0?o`00CoE`3ooooooolJ0?oo6P3o0_ooool2o`0:o`06oooooolno`3o043oo`10oooooooo0?nK1Ooo
ool2obH0o`03oooooolho`3o>?l0013ooooo0ol0;_l2ooooo`;o0?3o00?ooooooego0?mMo`000_mM
o`000omSo`3oooooooooo`0Gooooo`Wo04co00Co0=Sooooooooooooooooo2Ol0[_l5ooooo`_o04co
2Oooool3oego00;oHol03?ooool00ol0l?ooooooo`0^o`06ooooo`03ocSo0?oooooooooo00;ooooo
00?o9P3oo`10ool02_l00_ooool01_lJ0?oo?_l0oooooooooooo0?nKoeL0o`;ooooo00?o0?o`ob3o
0?ooool00_ooool00ol0odcoooooo`0do`06ooooo`03o`3oYooooooooooo00Kooooo0_l2o`001?oo
oooo00Coo`04ool01?l2ooooo`KoG@3o00?oooooofT0oomY0?l02_mY0?l3ooooo`;o00Co1?ooool2
o`;o01Gooooo0_l0ojL5ooooo`;oEol01_ooool2ob3o00Sooooo0ol0od`4ooooo`?o03Co00Cooooo
oeL0oomG0?oooooo0_l0OOl3ooooo`03o`3oVooooooooooo00;o6P3o0oooool4ocko00Kooooo0ol0
2_l01?oooooo043oo`10ool0@?l>ooooo`;o03Co00?o0?m<ocko0?ooool04?ooool00omG0?oooooo
ooooo`07ooooo`03oeOo0?oooooooooo00Kooooo00?oJ@3oo`2?ooooool00oooool6o`3`o`;o6P3o
8oooool4o`0:o`03oed0oooooooooooo01cooooo000Jooooo`03o`000?oooooooooo01[ooooo00So
E`3oofT0oomM0?ooP@3oo`;o0?lP0?oo/P3oooooo`;o^03o0_nO0?l4ooooo`?oW`3o0onh0?l00on7
o`3o/P3ook80o`02ooooo`03okSo0?oooooooooo00?ooooo00Co08ooob00oooooooo07Oo0_ooool0
2On10?oo0?oloooooooooooo0?ndooooool0omSoooooo`;o0007ooooo`04oed0ooooooooooooo`04
o`;ooooo00Go09GoooooooooooooooooofT0o`02ob3o00[ooooo00?oEol0o`0dool0od`00oooool0
1Ol0oo3oE`3ooeL0ool0OOoo6P3o00;ooooo0_l02_l2ooooo`;o043o00?oooooo`3oVol0oi/01?oo
ool2obH0o`;ooooo00?o>?l0ooooooooool03_ooool2o`0^o`?ooooo0_l0l?l3oego01Sooooo1_l0
C?l=o`2^o`Wooooo3?l0[_l2ooooo`;o0=So0ol0C?l9ooooo`?oGOl000?oHol0ooooooooool02Ooo
ool2o`3`o`;o02ko1?ooool00olho`3oooooooooo`02ooooo`03obH0oooooooo00[o00?ooooo00[o
6P3oocko0?oooooo0?nKo`3oJomG0?ooooooo`3ol?oooooo8?l00_ooool01?l0odcoooooooooool0
=?l6ooooo`03o`3oYooooooooooo00Oooooo00Co0_l0oooooooooooooooo0ol01?l4ooooo`CoG@3o
2oooool2o`04o`?ooooo0ol2o`0Fooooo`03o`3oYooooooooooo00Cooooo00?oEol0ooooooooool0
1Oooool00olPo`3oooooooooo`06ooooo`;o0?m<1Oooool2o`0do`;ooooo0_mG0?l00ooooooo07go
o`1mo`03ooooo`;o0?nK0olJ0?l00ooooooo?_l0ocko0002ocko00Oooooo0ol02_l01?oooooo043o
o`10ool0@?lCooooo`03o`0dool0odco?_l000;o?_l03oooool00omG0?ooooooooooo`07ooooo`03
oeOo0?oooooooooo00Gooooo00?oJ@3oo`2?ool0l?l00ol0l?l8ooooo`03oaX0oooooooooooo02Co
oooo00?o00[ooed0ool02_l07?ooool001[ooooo00?o0000ooooooooool06_ooool02?l0FOooJ@3o
o`04oomM0?ooP@3oo`;o0?lP0?oo/P3o0_ooool3okP0o`?oW`3o0onh0?l01?n7o`3ooooooooooonb
0?l2ooooo`;o^?l01Oooool2ob00o`0;ooooool0Moooooooofoo0?n10?oo0?oloooooonbo`3o0?nd
ooooool0omP00_l2o`06ooooo`;oG@3o0_ooool01?l01?ooooooooooool0UOl3ooooo`03ofT0oolP
o`3ooooo00[ooooo00?oEol0o`0dool0od`00oooool00ol0oo3oE`3oo`1mo`02oaX0o`;ooooo00Go
00[ooooooooooooo?_l0o`10o`02ooooo`03o`3oVooooooooooo00?ooooo00?o9P3oooooooooool0
0_lho`0?ooooo`;o02ko0_ooool3o`3`o`;oGOl05Oooool6o`1<o`Ko0:ko8_ooool7o`2^o`Co04co
00?o0=Soooooooooool01Oooool2oego0003of?o0?oooooooooo00Wooooo00?o0?3oooooool0;_l0
1?ooool00olho`3oooooooooo`02ooooo`03obH0oooooooo00[o00?ooooo00Go6P3oocko0?oooooo
0?nKoeL0o`02ooooo`03o`3ol?oooooo8?l000;ooooo00Co0?m<ooooool0=?ooEol01_ooool00ol0
ojOoooooooooo`07ooooo`;o0_l01?ooool2o`04o`kooooo0ol01?l3ooooo`;o0_l05oooool2o`3o
Y`Gooooo0_mGo`06ooooo`;o8?l01oooool2o`3oC0Gooooo0_l0=?l2ooooo`;oE`3o00Coooooo`1m
ool0OOoo0?m[0oooool01?l0oi_o6P3ooaX0ooooool3ocko00Sooooo0ol02_l2ooooo`;o043o5ooo
ool01?l0=?oo0?m<ooooooooool2ocko00kooooo00?oE`3oooooooooool01oooool00omGo`3o0?3o
o`3`o`04o`3`o`03oooooomY0?oo08oo00cooooo0_lJ0?lVooooo`03oed0ool02_oo00[o00;o00[o
6?ooool001[ooooo00?o0000ooooooooool06oooool01omG0?ooJ@3oo`04oomM0?ooP@3oo`;o0?lP
0?l00_nb0?l3ooooo`?o^03o1?ooool2ok80o`03oooooonho`3o^?l000Kooooo00Wo803oonko0?oo
oooo07Oooooooom_o`3oP@3oo`3oo?ooool00_l0ok@01?oooooo0?oHo`;o0?lJo`06ooooo`03oed0
ool0oaKooooo00;o00Co0_ooool00ol0UOooooooooooo`02ofT0o`03ob3o0?oooooooooo00Wooooo
00?oEol0o`0dooooool00_ooool2o`3ol003oeL0oolJ0?oo6P3o00;ooooo0_l02_l01Ooooooo?_l0
o`10ool0@?oooooo00;o0?nK1?ooool2obH0o`03oooooolho`3o>?l000oooooo0_l0;_l2ooooo`;o
0?3o0_mMo`0Cooooo`Go04co1_l0[_l6oooooaoo0?nE2_ooool4o`2^o`Co04co00?o0=Sooooooooo
ool00oooool2oego00;oHol02Oooool00ol0l?ooooooo`0^o`04ooooo`03ocSo0?oooooooooo00;o
oooo00?o9P3oooooool02_l00_ooool01_lJ0?oo?_l0oooooooooooo0?nKoeL0o`;ooooo00?o0?o`
ob3o0?ooool00_ooool01?l0odcoooooo`0doomGo`06ooooo`03o`3oYooooooooooo00Sooooo00?o
0_l0ooooooooool00oooool5o`04o`03ooooool01?oo00Co00Ko00Co0oooool3o`;o01Sooooo00?o
0?nWooooooooool00oooool2oeOo00Kooooo0_lPo`08ooooo`03o`3oC?oooooooooo00?ooooo0_l0
=?l2ooooo`;oE`3o0_ooool00ol0OOoo0?m[o`3oJ`02ooooo`03o`3oVolJ0?oo6P3o00?o?_l02?oo
ool3o`0:o`;ooooo0ol0@?lIooooo`03o`0doooooooo0?m<00?ooooo00?o?_l0ooooooooool03?oo
ool01?mG0?ooooooooooooooool6o`3`o`03oeOo0?oooooooooo00Cooooo00?oJ@3oooooool0Sol0
3Oooool2oaX0obGooooo00CoG@3ooooooooooooooooo1?l02_l5o`3Ho`oooooo000Jooooo`03o`00
0?oooooooooo01_ooooo00Oo013oofT0oolJ0?ooG@3ooh40oooooooo0_l000;o803o0_nb0?l6oooo
o`;o/P3o0_ooool00onho`3oooooooooo`04ooooo`;o803o00?ok_l0ooooool0Mol00_m_o`001?n1
0?oo0?olok;o0?l0ok@2ooooo`03o`3of?l2o`3o6_l000Kooooo00CoG@3oo`3o5_oooooo00Co0ooo
ool01Ol0UOoooooooooooomY0?oo8?l000cooooo00?oEol0o`0dooooool00_ooool01_l0oo3oE`3o
oeL0oolJ0?oo0?m[ooooo`;o00[o0_ooool2o`10o`;ooooo00?o0?nKooooooooool00_ooool2obH0
o`;ooooo00?o>?l0ooooooooool03Oooool2o`0^o`;ooooo0_l0l?l00omMo`3oooooooooo`0Aoooo
o`?o04co1Ol0[_l6ooooo`Ko0?nE7oooool4o`3oU@[ooooo1?l0[_l3o`1<o`03o`3Hoooooooooooo
00;ooooo00CoGOl0oooooomSo`3oHol02?ooool00ol0l?ooooooo`0^o`04ooooo`03ocSo0?oooooo
oooo00;ooooo00?o9P3oo`10ool02_l00_ooool02_lJ0?oo?_l0ooooool0oi_o0?m[oeL0oooooooo
0?o`oooooolPo`02ooooo`04o`3oC?ooooooooooo`0do`Kooooo00?o0?nWooooooooool02Oooool3
o`;o00Oooooo0_l01?l7ooooo`?o0_l06Oooool2o`3oY`Gooooo00?oEol0ooooooooool01Oooool0
0olPo`3oooooooooo`06ooooo`;o0?m<1?ooool2o`0do`;ooooo0_mG0?l2ooooo`;o07go00?o0?m[
ooooooooool00olJ0?l2ocko00Sooooo0ol02_l3ooooo`;o043o7Oooool00ol0=?ooooooo`3oC003
ooooo`;o?_l02oooool2o`3`o`03oeL0ool0l?oo0?3o00Oooooo00?oEol0ooooooooool01?ooool0
0omY0?oo08ooooooo`0>ooooo`;o6P3o8oooool00ol0f?ooG@3ooed0o`05o`3Ho`?o00[o4Oooool0
01[ooooo00?o0000ooooooooool06oooool02Ol0FOooE`3oofT0ool01?ooG@3ooh40oooooooo0_l0
ooooo`02ob00o`Ko/P3o00CooooookSo0?nho`3o^?l01?ooool2o`2?o`06ob00ooo^o`3ok_l0oooo
ool0MoooKol00_n10?l00ol0ooco/_l0o`3o]002ooooo`03o`3of?oooooo6_l000Kooooo00CoG@3o
o`3o5_oooooo00Co0_ooool2o`2Eo`;ooooo00?oJ@3oooooooooool02_ooool00omGo`3o03Coo`0d
o`03ooooo`07o`3ol?mG0?oo6P3ooaX0ool0of_oooooo`0:o`02ooooo`;o043o0_ooool2o`3oV`Co
oooo00?o9P3oooooooooool00_lho`0=ooooo`?o02ko00Cooooooego0?l0l?oo0?3o4_ooool4o`1<
o`?o0:ko1Oooool6o`3oUBWooooo1_l0oiD8ooooo`?o0:ko0_l0C?l01?l0f?ooooooooooooooool2
oego0003oooooomSo`3ooooo00Oooooo00?o0?3oooooool0;_l01?ooool02?lho`3ooooooooooooo
oooo9P3oooooool0@?oo00[o0_ooool02_lJ0?oo?_l0ooooool0oi_o07gooeL0oooooooo0?o`oooo
oolPo`02ooooo`04o`3oC?oooooo03CooeOo00Kooooo00?o0?nWooooooooool02oooool3o`;o00Wo
oooo1?l2o`0Kooooo`03o`3oYooooooooooo00?ooooo0_mGo`06ooooo`;o8?l01oooool2o`3oC0Go
oooo00?o03Coooooooooool00_mG0?l2ooooo`;o07go0_l0of/01Ooooooo6P3ooaX0ool0oi_o?_l0
00Wooooo0_l02_l4ooooo`;o043o8?ooool00ol0=?ooooooo`3oC004ooooo`03ocko0?oooooooooo
00;ooooo1_l0l?l3ooooo`03oeL0oooooooooooo00Oooooo00?oEol0ooooooooool01?ooool00omY
0?oo08ooooooo`0?ooooo`03oaX0oooooooooooo01Sooooo2?l0f?l3ooooo`03oed0oooooooooooo
00Gooooo0_l02_l?ooooo`006_ooool00ol0003oooooooooo`0Looooo`05o`0@oomY0?oo6P3ooed0
ool0Mol00_n10?l01Ol2o`3ooooooooooolP0?oooooo00Go^?l01_ooool02Ol0Sooo803oob00ooo^
o`3oooooofoo0?l0Mooooooooh40o`02o`3oo007ok;o0?l0okCoooooo`;o0?l0omSooooooa[o0006
ooooo`04oed0ool0oaKoooooo`04o`;ooooo00Go09Gooooooooooooo8?l0ofT0o`0<ooooo`03oeOo
0?l0=?oo0?m<00;ooooo0_l0oo001?mG0?oo6P3oo`3oJoooool2o`0:o`;ooooo00Go043ooooooooo
ooooooooo`3oV`04ooooo`;o9P3o00?oooooocSo0?lho`003Oooool2o`0^o`03oooooomMo`3oGOl0
00;o0?3o4?ooool4o`1<o`Co0:ko00?oooooo`3oUOl0oiD01Ol0oiDeooooo`Co0?nE1oooool2o`2^
o`;o04co00Co0=Sooooooooooooooooo0_mMo`000omSo`3oooooooooo`06ooooo`03o`3`oooooooo
02ko00Cooooo00_o>?l0ooooooooooooooooobH0oooooooo043oo`0:oooooooo6P3oocko0002oooo
o`07o`3oVomG0?ooooooooooool0oo3oooooob3o0002ooooo`04o`3oC?oooooo03CooeOo00Kooooo
00?o0?nWooooooooool03Oooool9o`;o01gooooo0_l0ojL5ooooo`03oeOo0?oooooooooo00Cooooo
0_lPo`07ooooo`;o0?m<1Oooool2o`0do`03oooooomG0?ooE`3o00?ooooo00Co07goooooool0of_o
oooo0_lJ0?l00ol0oi_o?_l0ooooo`08ooooo`;o00[o0oooool3o`10oa7ooooo2Olho`09ooooo`03
o`0doooooooo0?m<00?ooooo1Ol0l?l:ooooo`03oeL0oooooooooooo00Kooooo00?oEol0oooooooo
ool01?ooool00omY0?oo08ooooooo`0@ooooo`03oaX0oooooooooooo013ooooo1ol0f?l<ooooo`03
oed0oooooooooooo01Gooooo000Jooooo`03o`000?oooooooooo01cooooo00Go013ooeL0oomY0?oo
00Cooed0o`02o`1go`04oh40oonbo`3o/_l0o`2?o`Co803o0oooool3o`2?o`?o803o0_o^o`001om_
o`3o07Ooo`1gooooooooP@3oo`3oo?nbo`000_l0ok@2o`;o0003o`3of?lJo`3o6_l000Gooooo0_mM
0?l00ol0oaKo00Coo`04o`02ooooo`05o`2Eoooooooo8?l0ob3o0?mY0?l03?ooool00omGo`3o03Co
ooooo`02ooooo`05o`3ol?mG0?ooE`3ooaX0ool0of/00_l02_l2ooooo`;o043o0oooool01?l0oi_o
ooooooooooooool2obH0o`;ooooo00?o>?l0ooooooooool02oooool2o`0^o`;oGOl00ol0l?l?oooo
o`?o04co1?l0[_l00ooooooo0?nEo`3oU@02o`3oUD3ooooo0ol0oiD6ooooo`;o0:ko0_l0C?l01_l0
f?ooooooooooooooooooGOl0of?o00Sooooo00?o0?3oooooool0;_l01?ooool04olho`3ooooooooo
oooooooo9P3oooooool0@?oo00[ooooooolJ0?oo?_l0ooooool0oi_o0?m[oeL0oooooooo0?o`oooo
oolPo`000_ooool01Ol0odcoooooooooool0=?ooEol000Kooooo00?o0?nWooooooooool0<Oooool0
0ol0ojOoooooooooo`04ooooo`03oeOo0?oooooooooo00Cooooo00?o8?l0ooooooooool01_ooool0
0ol0odcoooooooooo`03ooooo`;o03Co0_ooool01?mG0?ooooooooooooooool2o`1mo`04ooooool0
of_o6P3ooaX0o`;o0?nK2_ooool01?l02_ooooooooooooooool2o`10o`cooooo2?lho`09ooooo`So
>?l000?oooooo`0dooooool01?l0l?l3ooooo`03ocko0?oooooooooo00Wooooo00?oE`3ooooooooo
ool01oooool00omGo`3oooooooooo`04ooooo`03ofT0ool0Sooooooo013ooooo0_lJ0?l:ooooo`Ko
0=So5?ooool00omM0?ooooooooooo`03ooooo`;o0?nE3oooool001[ooooo00?o0000ooooooooool0
7Oooool01ol04?ooJ@3ooaX0ool01?ooG@3oo`3o]?n10?l00_l2o`001?nbo`3ooooooooooom_o`07
ob00o`03oooooom_o`3oKol000;oKol000co07OoooooooooooooP@3oo`3oo?oooooo0?ndooooool2
o`3oooooo`3of?lJo`06ooooo`04oed0oooooooo0?lFo`04o`?ooooo00Go09GooooooolPo`3ooooo
ofT0o`0;ooooo`;oEol000[o03Coooooooooooooooooo`3ol?mG0?oo6P3oo`3oJooooooo00[o0ooo
ool01?l0@?ooooooooooooooool2o`3oV`?ooooo00?o9P3oooooooooool00_lho`0<ooooo`;o02ko
0_mMo`02o`3`o`oooooo0ol0C?l3o`2^o`;ooooo0ol0oiDEoooooaOo0?l:6oooool3o`3oU@Gooooo
0_l0[_l2o`1<o`03o`3Hoooooooooooo00;oGOl000?oHol0ooooooooool01Oooool00ol0l?oo02ko
ooooo`03ooooo`03ocSo0?oooooooooo00;ooooo00?o9P3oo`10ool02_l00_ooool02_lJ0?oooooo
ooooool0oi_o07gooeL0oooooooo0?o`oooooolPo`02ooooo`04o`3oC?oooooo03CooeOo00Oooooo
00?o0?nWooooooooool0;_ooool2o`3oY`Gooooo0_mGo`05ooooo`;o8?l01oooool2o`3oC0Gooooo
00?o03Coooooooooool00_mG0?l2ooooo`;o07go00Koooooo`3oJol0of_o6P3oocko0?l0oi/:oooo
o`;o00[o0_ooool2o`10o`[ooooo1?lho`0Iooooo`;o0?3o00?o03CoocSo0?l0od`01_ooool00oln
o`3oooooooooo`09ooooo`03oeL0oooooooooooo00Oooooo00?oEol0ooooooooool00oooool00omY
0?ooooooo`2?o`0Booooo`03oaX0oooooooooooo00;ooooo1Ol0f?lKooooo`03oed0ool0oiGo0?nE
00;o0?nE4Oooool001[ooooo00?o0000ooooooooool07Oooool01ol04?ooE`3oofT0ool0omSoG@3o
oa[o0?l0Mol00_n10?l2o`;o0004ok;o0?ooooooooooooooo`KoKol000Gok_l0ooooool0Mooo07Oo
ooooo`02oh40o`03o`3oo?l0okCo0?nd00;o0_l000?oooooo`3of?lJo`001_ooool01?mM0?oooooo
o`3o5_l01?l3ooooo`05o`2EoolPo`3o8?l0oooooomY0?l02oooool00omGo`3o03Coo`0do`02oooo
o`;o0?o`00?oE`3oo`1mool0of/00_l02_l2ooooo`;o043o0oooool01?l0oi_oooooooooooooool2
obH0o`03oooooolho`3o>?l000cooooo0_l0;_l01?mMo`3oHol0o`3`ool0l?l?ooooo`;o04co0ol0
[_l2ooooo`?o0?nE2_ooool>o`3o2QOooooo2_l0o`XDooooo`?o0?nE1?ooool2o`2^o`;o04co0ooo
ool00omMo`3oHol0ooooo`05ooooo`03o`3`oooooooo02ko00Cooooo00So>?l0oooooooooooooooo
obH0oooooooo043oo`0:o`;ooooo00Oo6P3ooooooooooooo0?nKoeL0oooooooo0?o`00;ooooo00Oo
8?l0oooooooooooo0?m<ooooool0=?ooEol000Oooooo00?o0?nWooooooooool0;?ooool00ol0ojOo
ooooooooo`04ooooo`03oeOo0?oooooooooo00?ooooo0_lPo`07ooooo`;o0?m<1Oooool2o`0do`03
oooooomG0?ooE`3o00?ooooo00Co07gooooooooooooo0?m[0_lJ0?l2o`3oV`Wooooo0_l02_l2oooo
o`;o043o1Oooool6o`3ol003ocSo0?oooooooooo01Sooooo0ol0l?l3ooooo`03o`0doooooooo0?m<
00;o>?l01?ooool00olno`3oooooooooo`09ooooo`03oeL0oooooooooooo00Oooooo00?oEol0oooo
ooooool00oooool00omY0?oo08ooooooo`0@ooooo`;o0=So00Co6P3oo`3Hool0f?oo0=So6Oooool7
o`3oU@03oooooomM0?oooooo01?ooooo000Jooooo`03o`000?oooooooooo01gooooo00Oo05WoobH0
oomY0?oo6P3oo`04oomM0?oo6_l000;o07Oo00?oP@3oonko0?l2o`000onbo`04onko00?ooooo00Oo
07Oooh40oon10?ooP@3oooooool0ooco0?nd00;o0_l000?oooooo`3of?l0omP01oooool01?mM0?oo
ooooo`04ool01?l3ooooo`05o`2EoolPo`3ooooooooooomY0?l02oooool00omGo`3o03Coo`3oY`02
ooooo`06o`3ol?mG0?ooE`3oo`1mool0of_o00[o0oooool01?l0@?ooooooooooooooool2o`3oV`;o
oooo0_lV0?l2ooooo`03ocSo0?oooooooooo00[ooooo00CoGOl0o`0^oomMo`3oHol00_l0l?l>oooo
o`?o04co0_l0[_l2ooooo`?o0?nE2?ooool5o`3o2Roooooo1_l0o`XAooooo`;o0?nE1?ooool2o`2^
o`;o04co0_ooool00omMo`3oHol0of?o0005ooooo`03o`3`oooooooo02ko00Cooooo00Oo>?l0oooo
ooooooooooooobH0oooooooo00[o00;ooooo00[o6P3oocko0?oooooo0?nKo`3oJomG0?ooooooo`3o
l?oooooo8?l00_ooool01Ol0odcoooooo`0dooooooooEol000Oooooo00?o0?nWooooooooool0:Ooo
ool2o`3oY`Gooooo0_mGo`05ooooo`03ob3o0?oooooooooo00Kooooo00?o0?m<ooooooooool00ooo
ool2o`0do`03oooooomG0?ooE`3o00?ooooo0_l0OOl2ooooo`;o6P3o00?o?_l0o`3oVoooool02?oo
ool2o`0:o`?ooooo00?o043oo`3ol?l0oo001Ol0oo03ocSo00?ooooo1_l0oo0Booooo`?o0?3o1_oo
ool00ol0=?ooooooo`3oC002ooooo`;o>?l00oooool00olno`3oooooooooo`09ooooo`03oeL0oooo
oooooooo00Oooooo00?oEol0ooooooooool00_ooool00omY0?ooooooo`2?o`0;ooooo`Go0=So0ooo
ool2oaX0oa?ooooo1ol0oiD9ooooo`03oed0oooooooooooo017ooooo000Jooooo`03o`000?oooooo
oooo01kooooo00Wo013ooeL0oomY0?oo6P3oo`04oomM0?oo6_l0o`3o]?l0Mol00_n10?l2o`;o0003
oooooonbo`3o/_l000;o/_l00ol0Mol00on10?ooooooooooo`02o`3oo006o`3o]?oooooooooooooo
ool0omSo6_l01oooool00omM0?ooooooo`04o`03ooooo`;o09Go0oooool00omY0?ooooooooooo`09
ooooo`03oeOo0?l0=?oo0?nW00;ooooo00Co0?o`oeL0ool0OOoo0?m[0_l02_l2ooooo`;o043o0ooo
ool01Ol0oi_ooooooooooooooooo9P3o00;ooooo0_lho`0;ooooo`06oego0?l0;_oo02koof?o0?oo
oooo0?3o3_ooool2o`1<o`?o0:ko0_ooool2o`3oU@Oooooo1?l0o`Xjooooo`Co0?l:3oooool2o`3o
U@Cooooo00So0:koooooool0C?oo04cooooooomMo`3oooooof?o00Gooooo00?o0?3oooooool0;_l0
1?ooool01olho`3ooooooooooooooooo9P3oo`10ool02_l00_ooool02_lJ0?ooooooooooool0oi_o
07gooeL0oooooooo0?o`oooooolPo`02ooooo`05o`3oC?oooooo03CooooooomGo`001oooool00ol0
ojOoooooooooo`0Wooooo`03o`3oYooooooooooo00Cooooo00?oEol0ooooooooool00oooool2ob3o
00Oooooo0_l0od`5ooooo`04o`0doooooooooooooeL0o`Cooooo00?o07goooooooooool00_lJ0?l0
0olno`3o0?nKo`3oV`08ooooo`;o00[o0oooool2o`10o`03o`3ol?oooooooooo00;ooooo0olho`0<
ooooo`?o0?o`3?ooool3o`3`o`[ooooo00?o03Coooooool0od`00oooool2ocSo00;ooooo00?o?_l0
ooooooooool02?ooool00omG0?ooooooooooo`08ooooo`03oeOo0?oooooooooo00;ooooo00?oJ@3o
o`2?ooooool01Oooool5o`3Ho`[ooooo00?o6P3oooooooooool02Oooool7o`3oUA7ooooo00?oG@3o
ooooooooool04?ooool001[ooooo00?o0000ooooooooool07_ooool02Ol04?oo9P3oofT0oolJ0?oo
ooooo`04oomM0?oo6_l0ooooo`02o`1go`[oP@3o0_l2o`000ol0ooco0?ndooooo`02ooooo`;o0?oH
1oooool2oed0o`03ooooool01?oooooo00;ooooo00?o09Goob3o0?ooool00_ooool00omY0?oooooo
ooooo`08ooooo`;oEol000Wo03Coo`3oYooooooo0?o`oaX0oomG0?oo07goo`3oJol02_l00_ooool2
o`10o`Cooooo00?o0?nKooooooooool00_lV0?l00ooooooo>?l0ocSo000;ooooo`05oego0?l0;_oo
02koof?o0?ooool00_l0l?l=ooooo`;o04co0_l0[_l2ooooo`?o0?nE1Oooool4o`3o2Q?ooooo8?l0
ofD?ooooo`?o0?l:3_ooool2o`3oU@?ooooo0_l0[_l01_l0f?oo04cooooooomMo`3oooooof?o00Go
oooo00?o0?3oooooool0;_l00oooool02?lho`3ooooooooooooooooo9P3oooooool0@?oo00[o0_oo
ool01olJ0?ooooooooooool0oi_oE`3oooooool0oo000_ooool02?lPo`3oooooooooool0odcooooo
o`0dooooooooEol01oooool00ol0ojOoooooooooo`0Tooooo`;o0?nW1Oooool2oeOo00Gooooo00?o
8?l0ooooooooool01Oooool2o`3oC0Gooooo0_l0=?l2ooooo`03oeL0oooooooooooo00;ooooo00Co
07gooooooooooooo6P3o0_lno`000ol0oi_oooooooooo`06ooooo`;o00[o0ol0oo02o`10o`Cooooo
0olho`0Booooo`;o0?o`1oooool3o`3`o`kooooo00?o03Coooooool0od`01?ooool2ocSo0003ocko
0?oooooooooo00Wooooo00?oE`3oooooooooool02?ooool01omGo`3oooooooooooooooooJ@3ooooo
ool0Sol01Ol0f?l@ooooo`;o6P3o0oooool6o`3oUAWooooo00?oG@3oooooooooool03oooool001[o
oooo00?o0000ooooooooool07_ooool02_l0FOoo013oobH0oomY0?oo6P3oooooool01?ooG@3oo`3o
o?ooool3o`3o]0Cooooo0ol2o`000ol0okCo0?olo`3oo004ooooo`03o`3of?lJo`3ooooo00Gooooo
0_mM0?l2ooooo`05o`04ooooooooooooob3o0?l0UOl00oooool2ofT0o`[ooooo00KoEol0o`3oC?l0
=?oo0?nWoooooolJ0?l2oeL0o`03o`1mool02_oo00[o00;ooooo00?o043oocko0?ooool00oooool0
1?l0oi_ooooooooooolV0?l2ooooo`03ocSo0?oooooooooo00Sooooo0omMo`000ol0;_ooHol0oooo
o`02o`3`o`cooooo0ol0C?l2o`2^o`;ooooo0_l0oiD4ooooo`Co0?l:4_ooool5o`3oIB3ooooo2Ol0
ofD9ooooo`?o0?l:3Oooool2o`3oU@?ooooo00Co0:koooooool0C?oooooo0_mMo`06ooooo`03o`3`
oooooooo02ko00?ooooo00Oo>?l0ooooooooooooooooobH0ool0@?oo00[o00;ooooo00So6P3ooooo
oooooooo0?nKo`1moomG0?ooooooo`3ol0;ooooo00Go8?l0ooooool0odcoooooo`0do`02ooooo`03
oeOo0?oooooooooo00Gooooo00?o0?nWooooooooool08_ooool00ol0ojOoooooooooo`04ooooo`03
oeOo0?oooooooooo00?ooooo0_lPo`07ooooo`03o`3oC?oooooooooo00Cooooo00?o03Cooooooooo
ool00_mG0?l3ooooo`;o07go0_ooool01?lJ0?oo?_l0ooooool0oi/8ooooo`04o`0:ool0oo3ooooo
ooooo`;o043o0oooool3ocSo01Oooooo00Co0?o`oooooooooooooooo0ol0l?lAooooo`03o`0doooo
oooo0?m<00Kooooo0_lho`0;ooooo`03oeL0oooooooooooo00Oooooo00?oEol0ooooooooool00_l0
f?l00omY0?oo0=Soo`2?o`0Dooooo`;o0?nE00?o6P3oo`3oUOl0oiD08?ooool00omM0?oooooooooo
o`0>ooooo`006_ooool00ol0003oooooooooo`0Oooooo`04o`0@oolV0?ooJ@3ooaX0o`;ooooo00Go
00Cooed0ool0ooco0?olooooo`07o`3o]0;o0?ol1?ooool2o`3of0Kooooo0_mM0?l2ooooo`;o00Co
0_ooool00olPo`3o09Goooooo`02ooooo`03ofT0oooooooooooo00Wooooo00SoEol0o`0dool0=?oo
0?nWoooooolJ0?ooE`3oo`1mo`;o00[o0_ooool2o`10o`Cooooo0_l0oi/2ooooo`04obH0oooooooo
>?l0ocSo00Wooooo0_mMo`000omSo`3o02koo`0^o`02ooooo`03o`3`oooooooooooo00[ooooo0_l0
C?l3o`2^o`05ooooool0oiGo0?nEo`3oUOooool01Ol0o`X@ooooo`Ko0?mU2ooooolIo`0Xo`[ooooo
0ol0ofD9ooooo`?o0?l:3?ooool01?l0oiGoooooooooooooool2o`2^o`04o`1<oooooooooooooego
00Kooooo00?o0?3oo`0^ooooool00oooool01olho`3ooooooooooolV0?ooooooo`10ool02_l00_oo
ool02_lJ0?ooooooooooool0oi_o07gooeL0oooooooo0?o`oooooolPo`02ooooo`03o`3oC?oooooo
03Co00;ooooo00?oEol0ooooooooool01Oooool00ol0ojOoooooooooo`0Oooooo`;o0?nW1Oooool2
oeOo00Gooooo00?o8?l0ooooooooool01Oooool2o`3oC0Gooooo0_l0=?l2ooooo`03oeL0oooooooo
oooo00;ooooo00?o07goooooooooool00_lJ0?l00olno`3oooooo`3oV`07ooooo`;o00[o0oooool0
0ol0@?ooooooooooo`03ocSo01_ooooo00?o0?o`o`3`ool0l?l05Oooool00ol0=?ooooooo`3oC007
ooooo`;o>?l02Oooool00omG0?ooooooooooo`05ooooo`Go0=So0_ooool00omY0?ooooooo`2?o`0>
ooooo`Ko0?nE0oooool00olJ0?ooooooooooo`0Pooooo`03oed0oooooooooooo00gooooo000Joooo
o`03o`000?oooooooooo01oooooo00Go05Woo`0@oolV0?ooJ@3ooaX0o`02ooooo`03o`04oomM0?oo
G@3o00?o0?ol0oooool2o`3oo0Gooooo00?o0?oHoa[o0?ooool01?ooool2oed0o`?ooooo00?o00Co
ooooooooool00_lPo`001Ol0UOooooooooooooooooooJ@3o00_ooooo00CoEol0o`0dool0ojOo0?nW
0_lJ0?l00omG0?oo07goo`0:o`03ooooo`03o`10oolno`3ooooo00?ooooo00?o0?nKooooooooool0
0_lV0?l00ooooooo>?l0ooooo`08ooooo`;oGOl000?oHol0o`0^ool0;_l00_ooool2o`3`o`_ooooo
0_l0C?l2o`2^o`04ooooool0oiGo0?nEo`3oU@Co0?l:3oooool6o`3oI@Kooooo2ol0:?lIooooo`Oo
02So1_ooool4o`3oI@Sooooo0_l0o`X;ooooo`;o0?nE0oooool01Ol0[_oo04coooooooooooooGOl0
00Kooooo00?o0?3oo`0^ooooool00oooool01_lho`3ooooooooooolV0?ooooooo`0:o`?ooooo00Oo
6P3oooooool0oi_o0?m[oeL0oooooooo0?o`00;ooooo00Ko8?l0oooooooooooo0?m<ooooool0=?l2
ooooo`03oeOo0?oooooooooo00Gooooo0_l0ojLNooooo`03o`3oYooooooooooo00Cooooo00?oEol0
ooooooooool00oooool2ob3o00Oooooo00?o0?m<ooooooooool01?ooool01Ol0=?oooooooooooooo
ooooE`3o00?ooooo0_l0OOl2ooooo`05oaX0oolno`3oooooooooool0oi/01_ooool2o`0:o`03o`3o
l?oooooooooo00;o043o00?oooooocSo0?lho`007Oooool2o`3`o`03o`3ol?oooooooooo01Gooooo
00?o03Coooooool0od`01oooool00olno`3o>?l0ocSo0008ooooo`03oeL0oooooooooooo00Co0=So
1?ooool01omGo`3oooooooooooooooooJ@3oooooool0Sol01oooool6o`3oU@[ooooo0_lJ0?l`oooo
o`006_ooool00ol0003oooooooooo`0Pooooo`05o`0@ool0:?ooJ@3oo`10oolJ0?l00_ooool2o`04
o`03oed0oooooooo0?ol00?o0?ol1_lJo`000ol0omSoooooooooo`04ooooo`04oed0oooooooooooo
ooooo`;o00Co0_ooool00olPo`3oooooo`2Eo`03ooooo`03ofT0oooooooooooo00Wooooo00?o0?m<
o`0dool0ojL00_lJ0?l2oeL0o`;o00[o0_ooool2o`10o`Gooooo00Go0?nKoooooooooooo9P3ooooo
o`02ocSo00Oooooo0omMo`000omSo`3o02koo`0^o`02ooooo`;o0?3o2_ooool3o`1<o`;o0:ko00?o
ooooo`3oUOl0oiD00ol0o`X=ooooo`Ko0?mU1_ooool6o`0Xo`[ooooo7?l0i?l5ooooo`Ko02So1?oo
ool4o`3oI@Kooooo0_l0o`X;ooooo`06o`3oUOooooooooooooooool0[_oo04co0_ooool00omMo`3o
ooooooooo`03ooooo`03o`3`oooooooo02ko00?ooooo00Oo>?l0ooooooooooooooooobH0ool0@?oo
00[o00;ooooo00So?_l0oaX0oooooooo0?nKo`1moomG0?ooooooo`3ol0;ooooo00Go8?l0ooooool0
odcoooooo`0do`03ooooo`03oeOo0?oooooooooo00Kooooo00?o0?nWooooooooool06Oooool2o`3o
Y`Kooooo00?oEol0ooooooooool00oooool00olPo`3oooooooooo`05ooooo`;o0?m<1Oooool2o`0d
o`;ooooo0_mG0?l3ooooo`07o`1mooooooooooooo`3oJolJ0?oo?_l0ooooo`02o`3oV`Gooooo0_l0
2_l00ol0oo3oooooooooo`02o`10o`03oooooolho`3o>?l001kooooo00Co0?3ooooooooooooooooo
0_l0oo02oooooa?oHol000?o03Coof?o0?l0od`00_mSo`06ooooo`04ocko0?oooooo>?l0ocSo00Co
oooo0ol0f?l00omG0?oo0=Soooooo`08ooooo`04oeOo0?ooooooooooofT0o`;ooooo00?o08ooo`3o
UOl0oiD01?l0oiDBooooo`03oaX0oooooooooooo02gooooo000Jooooo`03o`000?oooooooooo023o
oooo00Ko05Woo`0@oolV0?ooJ@3ooaX0ool0UOl3ooooo`03o`04oomM0?ooG@3o00;oG@3o1?ooool3
o`3of0Gooooo0_mM0?l3ooooo`03o`04oooooooooooo00;o8?l000?oooooo`2Eooooool00_ooool0
0omY0?ooooooooooo`08ooooo`09oeOo0?l0odco03Coo`3oYolJ0?oo0?o`oeL0ool0OOoo00[o00?o
oooo00?o043oocko0?ooool00oooool2o`3oV`05oooooolV0?oo9P3ooooooolho`001oooool2oego
0004oooooomSo`3oHol0o`0^o`?ooooo00?o0?3oooooooooool02?ooool2o`1<o`?o0:ko0ol0oiD2
o`3o2Pcooooo1?l0ofD7ooooo`Go02So2oooool5o`3To`?o0?lX6?l0oc@00ooooooo0>Coo`3To`02
o`3To`Oooooo1Ol0:?l3ooooo`?o0?mU1Oooool2o`3o2P[ooooo00Ko0?nEooooooooooooooooo`1<
ool0f?l2ooooo`03oego0?oooooooooo00?ooooo00?o0?3oo`0^ooooool00oooool01_lho`3ooooo
oooooolV0?ooooooo`0:o`?ooooo00[o6P3ooooooooooooo0?nKo`1moomG0?ooooooo`3ol?oooooo
8?l00_ooool00ol0odcoooooo`0do`03ooooo`03oeOo0?oooooooooo00Kooooo1?l0ojLDooooo`?o
0?nW1_ooool2oeOo00Cooooo0_lPo`06ooooo`;o0?m<1_ooool01Ol0=?ooooooooooooooooooE`3o
00?ooooo0_l0OOl2ooooo`;o6P3o0_ooool00ol0oi_oooooooooo`02ooooo`;o0?o`00?o00[ooooo
ooooool00_ooool01?l0@?ooooooocSo0?lho`0Nooooo`;o0?3o1_mSo`000ol0oo3oHol0ooooo`0C
ooooo`04o`0doooooooo0?m<ooooo`CoHol00oooool00olno`3oooooo`3Ho`04o`3Ho`?ooooo00?o
E`3oooooooooool02Oooool3o`3oU@04ofT0ool0oiGo0?nEo`2?oaSooooo00?o6P3oooooooooool0
;?ooool001[ooooo0ol0000Qooooo`06o`0@ool0:?oo9P3oofT0oolJ0?oo09Go0oooool2o`04o`;o
0?oH0omM0?l00ol0omSoooooooooo`06oed0o`?ooooo0_l01?l3ob3o0003ooooool0UOoo09Go00?o
oooo00?oJ@3oooooooooool02?ooool00omGo`3o03Coo`0do`02oaX0o`;oE`3o0_l02_l2ooooo`;o
043o1Oooool01Ol0oi_ooooooooooolV0?oooooo00;o>?l01_ooool2oego0003oooooomSo`3oHol0
00;o02ko0_ooool2o`3`o`Wooooo0_l0C?l2o`2^o`03ooooool0oiGo0?nE00;o0?l:3?ooool3o`3o
I@Oooooo1?l0:?l:ooooo`03o`3o:?l0i?oo0>Co00?o0>Co2?l0oc@Aooooo`Oo0?lX1Ol0oc@8o`3T
o`Cooooo0ol0:?l3ooooo`;o0?mU1Oooool2o`3o2PWooooo00Go0?nEoooooooooooo0:koo`1<o`03
ooooo`03oego0?oooooooooo00?ooooo00?o0?3oo`0^ooooool00oooool01_lho`3ooooooooooolV
0?oo043oo`0:o`;ooooo00So?_l0oaX0oooooooo0?nKo`3oJomG0?ooooooo`3ol0;ooooo00Ko8?l0
oooooooooooo0?m<ooooool0=?l3ooooo`03oeOo0?oooooooooo00Wooooo00?o0?nWooooooooool0
3_ooool3o`3oY`Sooooo00?oEol0ooooooooool00oooool00olPo`3oooooooooo`05ooooo`03o`3o
C?oooooooooo00Cooooo0_l0=?l3ooooo`05oeL0ooooooooooooooooool0OOl00oooool01OlJ0?oo
?_l0oooooooooooo0?nK00?ooooo0_l0oo02o`0:o`?ooooo0_l0@?l2ocSo01kooooo0_l0l?l00omS
o`3oooooooooo`06ooooo`03o`3ol?ooooooGOl001;oGOl000?o03Cooego0?l0od`00omMo`02oooo
o`Go0=So0_ooool2ocSo00Gooooo00?oE`3oooooooooool00_ooool6o`3oU@04oooooomGo`3ooooo
ofT0o`;ooooo00?o08ooooooooooool05oooool2oaX0obcooooo000Jooooo`03o`000?oooooooooo
027ooooo00So05Woo`0@oolV0?ooE`3oofT0oolJ0?oo09Goo`3o5P?ooooo0_l01?l00olPo`3ooooo
oed0o`04oed0o`Gooooo0ol01?l2ob3o00?ooooo00?o09Goooooooooool00_ooool00omY0?oooooo
ooooo`08ooooo`06o`3oC?l0=?oo6P3ooaX0ool0oo3oE`3o0_l02_l3ooooo`03o`10oolno`3ooooo
00Cooooo00Co0?nKoooooolV0?oo9P3o0_lho`06ooooo`;oGOl000?oooooof?o0?mSo`000_l0;_l2
ooooo`;o0?3o2Oooool2o`1<o`;o0:ko0ol0oiD00ol0o`[oooooooooo`0:ooooo`?o0?mU1_ooool4
o`0Xo`;ooooo1ol0obP6o`3To`Go0?ld8oooool5o`3o:0Go0?ld0ol0i?l4ooooo`?o02So0_ooool3
o`3oI@Cooooo00?o0?l:ooooooooool01oooool01Ol0oiGoooooooooool0[_oo04co00;ooooo00?o
GOl0ooooooooool01?ooool00ol0;_ooooooooooo`02ooooo`07ocSo0?ooooooooooobH0oooooooo
043oo`0:o`02ooooo`08ocko0?lJ0?ooooooo`3oVol0OOooE`3oooooool0oo02ooooo`05ob3o0?oo
ooooooooo`3oC?l0=?l01?ooool00omGo`3oooooooooo`09ooooo`Co0?nW2?ooool4o`3oY`Wooooo
0_mGo`04ooooo`;o8?l01_ooool2o`3oC0Gooooo0_l0=?l3ooooo`;oE`3o0_ooool2o`1mo`;ooooo
0_lJ0?l3ooooo`07o`3oVoooooooooooooooool0oo3oooooo`0:o`03ooooo`;o043o0_lho`0Foooo
oa;o9P3o0omMo`000ol0oo3oGOl0ooooo`0Cooooo`03o`0doooooooo0=So00Co0=So0_mMo`03oooo
o`04ocko0?mSo`3oHol0of?o00;o>?l00oooool00omG0?oo0?nEo`3oU@02o`3oU@Oooooo00CoEol0
ooooooooooooJ@3o0_ooool00ol0Soooooooooooo`0Hooooo`03oaX0oooooooooooo02Wooooo000J
ooooo`03o`000?oooooooooo02;ooooo00So013oo`0XoolV0?ooE`3oofT0oolJ0?oo09Goo`3o5PCo
oooo0ol01?l5ob3o00Co00Co0_l0oaH4ooooo`;o09Go1?ooool00omY0?ooooooooooo`08ooooo`04
o`3oC?l0=?oo6P3oo`3oY`;oE`3o00Co00[oo`3oJooooooooooo0_l0@?l6ooooo`05o`3oVooooooo
9P3ooooooolho`001_ooool2oego0005oooooomSo`3oHol0ooooool0;_l00oooool00ol0l?oooooo
ooooo`07ooooo`;o04co0_l0[_l2o`3oU@03o`3o2_oooooooooo00[ooooo0ol0ofD6ooooo`?o02So
0_ooool4o`3o:0;ooooo1Ol0i?l5o`3o=2kooooo1Ol0obP3o`3o=0?o0>Co1?ooool3o`0Xo`;ooooo
0_l0ofD3ooooo`;o0?l:2?ooool01Ol0oiGoooooooooool0[_oo04co00;ooooo00?oGOl0oooooooo
ool01?ooool00ol0;_ooooooooooo`02ooooo`06ocSo0?ooooooooooobH0oooooooo00[o0oooool0
1olJ0?ooooooo`3oVol0of_o07gooeL0ool0oo000oooool01OlPo`3oooooo`3oC?oooooo03Co00Co
oooo00?oEol0ooooooooool03?ooool8o`3oY`[ooooo0omGo`05ooooo`03ob3o0?oooooooooo00Go
oooo00?o0?m<ooooooooool01?ooool00ol0=?ooooooooooo`02ooooo`05oeL0oooooooooooooooo
ool0OOl00oooool00olJ0?ooooooooooo`02ooooo`03o`3oVooooooooooo00;o0?o`00?oooooo`0:
ooooool00_ooool00ol0@?oo>?l0ocSo000Eooooo`?o9P3o0oooool3of?o00;o0?3o0oooool4oego
00?ooooo1?lV0?l00ol0oo3oooooooooo`0@ooooo`;o0=So00?o03Coo`3Hool0od`01_ooool4oego
0003ocko0?mMo`3ooooo00Go0?nE00?ooooooeL0ooooool02_ooool00omGo`3oooooofT0o`03oooo
o`03o`2?oooooooooooo01Sooooo00?o6P3oooooooooool0:?ooool001[ooooo00?o0000oooooooo
ool08_ooool02?l0FOoo013oo`0XoolV0?ooE`3oofT0oolJ0?oo09Go0_l0oaH5ooooo`Go00Co0ooo
ool00ol0oaKoooooooooo`03ooooo`03o`2Eoooooooooooo00?ooooo00?oJ@3oooooooooool02?oo
ool01Ol0odco6P3ooaX0ool0oo3oE`3o00;o00[o0_ooool2o`10o`03ocko0?oooooooooo00?ooooo
0_l0oi/2obH0o`;o>?l01Oooool2oego00;ooooo00CoHol0ooooool0;_oo02ko0_ooool2o`3`o`Wo
oooo00?o04coo`2^ool0[_l00_l0oiD=ooooo`;o0?mU1_ooool3o`0Xo`;ooooo0ol0obP2ooooo`Co
0>Co1?l0oc@Hooooo`oo0?mg4_ooool3o`3o:0?o0?ld0ol0i?l4ooooo`;o02So0_ooool2o`3oI@?o
oooo00?o0?l:ooooooooool01_ooool01Ol0oiGoooooooooool0[_oo04co00;ooooo00?oGOl0oooo
ooooool00oooool00ol0l?oo02koooooo`02ooooo`07ocSo0?oooooooooooooooolV0?oo043oo`0:
o`02ooooo`08ocko0?lJ0?ooooooo`3oVol0of_oE`3oooooool0oo03ooooo`05ob3o0?oooooo0?m<
ooooool0=?l01?ooool00omGo`3oooooooooo`0Kooooo`;oEol01_ooool2ob3o00Kooooo0_l0od`5
ooooo`;o03Co0oooool2oeL0o`?ooooo00Go07gooooooooooooo?_l0oaX0o`03ooooo`;o0?nK00Co
ooooo`3ol?l0oo3ooooo0_l02_l2ooooo`;o043o00?o>?l0ooooooooool04_ooool3obH0o`;ooooo
1?mSo`001?oooooo0?3oo`3`ooooool4oego00_ooooo00?o9P3oo`3ol?ooool03Oooool3o`3Ho`?o
oooo00?o03Coooooool0od`01oooool5o`3oU@?oGOl00_lho`000omSo`3ooooooeL0o`0;ooooo`03
oeOo0?ooooooJ@3o00?ooooo00?o08ooooooooooool06?ooool2oaX0obSooooo000Jooooo`03o`00
0?oooooooooo02?ooooo00Oo013oo`0XoolV0?oo03CooeL0oomY0?oo6P3o00;o09Go0ol0oaH7oooo
o`?o0?lF1?ooool2o`2Eo`Gooooo00?oJ@3oooooooooool01oooool01?l0odco6P3ooaX0ooooool2
oeL0o`06o`0:ool0of_oooooooooool0@?oo?_l01_ooool01Ol0oi_oooooobH0oooooooo>?l000Go
oooo0_mMo`02ooooo`;oHol00_l0;_l2ooooo`;o0?3o2Oooool2o`1<o`03o`2^ool0f?oo0?nE00co
oooo0ol0ofD5ooooo`?o02So00?oooooo`3o:?l0obP00_l0obP2ooooo`?o0>Co0ol0oc@@ooooo`go
0?mg3oooool<o`3oM`Wooooo0_l0obP01?oooooo0?ldo`3o=?l0oc@3o`3To`?ooooo0_l0:?l2oooo
o`04o`3oIOooooooooooooooo`;o0?l:1oooool02?l0oiGoooooooooool0[_oo04cooooooomMo`3o
Hol01Oooool00ol0;_ooooooooooo`02ooooo`06ocSo0?ooooooooooobH0oooooooo00[o0oooool0
2?lJ0?ooooooo`3oVol0of_o07gooeL0oooooooo0?o`0oooool01OlPo`3oooooo`3oC?oooooo03Co
00Cooooo0_mGo`0Iooooo`;oEol01oooool00olPo`3oooooooooo`05ooooo`03o`3oC?oooooooooo
00?ooooo0_l0=?l4ooooo`04oeL0ooooooooooooooooo`;o07go0_ooool2oaX0o`?ooooo00Co0?nK
ooooool0oo3o0?o`0_ooool01_l02_oooooooooooooooooo043oocSo01?ooooo0olV0?l3ooooo`;o
Hol00oooool2o`3`o`?oGOl04?ooool3obH0o`Wooooo0ol0f?l6ooooo`03o`0doooooooo0?m<00?o
oooo1?l0oiD4ooooo`04ocko0?ooooooooooooooo`;oGOl000Co>?l0of?o0?mG0?ooHol02oooool0
0omGo`3oJ@3oooooo`02ooooo`03o`2?oooooooooooo01[ooooo00?o6P3oooooooooool09Oooool0
01[ooooo00?o0000ooooooooool08oooool02Ol0FOoo013oo`0XoolV0?oo03CooeL0oomY0?oo6P3o
ooooo`03o`2Eo`Oo0?lF1?ooool3o`2Eo`Gooooo0_mY0?l9ooooo`;o6P3o00Go03CooooooomG0?oo
00[oo`1mo`02ooooo`;o043o00?o?_l0ooooooooool01?ooool00ol0oi_oooooobH0o`02ocSo00Co
oooo0_mMo`02ooooo`;oHol000?oooooo`0^ooooool00_ooool00ol0l?ooooooooooo`07ooooo`;o
04co00?o0:koo`3Hool0oiD02oooool3o`3oI@Gooooo0ol0:?l4o`3o:0;ooooo1?l0i?l2o`3o=0ko
oooo1_l0ogLXooooo`Co0?mg1oooool3o`3o:004ooooool0ocCo0?ldooooo`;o0>Co0oooool00ol0
:?ooooooooooo`02o`3oI@?ooooo00?o0?l:ooooooooool01Oooool01ol0oiGoooooooooool0[_oo
04cooooooomMo`001_ooool00ol0;_ooooooooooo`02ooooo`06ocSo0?ooooooooooobH0ool0@?oo
00[o0oooool01olJ0?ooooooo`3oVol0of_o07gooeL0ool0oo001?ooool01OlPo`3oooooo`3oC?l0
odco03Co00Gooooo00?oEol0ooooooooool05?ooool2oeOo00Oooooo0_lPo`06ooooo`;o0?m<1Ooo
ool00ol0=?ooooooooooo`02ooooo`;oE`3o0oooool01Ol0OOoooooooooooolno`3o6P3o00Cooooo
00?o0?nKo`3ol?l0oo000_ooool2o`0:o`?ooooo00?o043oocSo0?ooool04Oooool2obH0o`?ooooo
0omSo`04ooooo`03o`3`oomMo`3oGOl001Cooooo00?o0?o`oooooolV0?l01Oooool3o`3Ho`[ooooo
00?o03Coo`3oUOl0oiD00_l0oiD9ooooo`03ocko0?oooooooooo00?ooooo0_lho`000omG0?ooHol0
of?o000:ooooo`03oeOo0?mY0?oooooo00;ooooo00?o08ooooooooooool06_ooool00olJ0?oooooo
ooooo`0Tooooo`006_ooool00ol0003oooooooooo`0Tooooo`06o`0@ool0:?oo9P3oocko0?l0=?oo
E`3o0_mY0?l3ooooo`?o09Go1?ooool4o`2Eo`Gooooo0omY0?l9ooooo`04o`3oC?lJ0?oo03Cooooo
o`;oE`3o00?o00[oo`3oJoooool00_l0@?l2ocko00Gooooo0_l0oi/2obH0o`03ocSo0?oooooooooo
00?ooooo00?oGOl0ooooooooool00_mSo`000ooooooo02koo`0^o`02ooooo`;o0?3o2?ooool2o`1<
o`03o`2^ool0f?oo0?nE00[ooooo0ol0ofD5ooooo`?o02So0ol0obP2ooooo`Co0>Co0_l0oc@>oooo
o`Co0?mg2ooooolJo`23o`gooooo0ol0ogL7ooooo`?o0?lX0ol0oc@2o`3To`;ooooo0_l0:?l2oooo
o`05o`3oIOooooooooooooooool0o`X01_ooool02?l0oiGoooooooooool0[_oo04coo`3Hoooooooo
GOl01Oooool00ol0;_oo0?3oooooo`02ooooo`06ocSo0?ooooooooooobH0oooooooo00[o0oooool0
2?lno`3o6P3oooooool0oi_o07gooeL0oooooooo0?o`1?ooool01OlPo`3oooooooooool0odco03Co
00Gooooo1?mGo`0@ooooo`;oEol02?ooool00olPo`3oooooooooo`04ooooo`;o0?m<1Oooool2o`0d
o`Cooooo00CoE`3ooooooooooooooooo0_l0OOl2ooooo`03ocko0?lJ0?oooooo00?ooooo00?o0?nK
o`3ol?ooool00_ooool01?l02_ooooooooooooooool2o`10o`03ocSo0?oooooooooo00kooooo0olV
0?l3ooooo`;oHol01?ooool00omMo`3o0?3oo`3`o`0Hooooo`04o`3ol?oooooo9P3oooooo`?o0=So
2Oooool4o`3oU@03o`0doooooooo0?m<00cooooo00?o?_l0ooooooooool01?ooool00omG0?ooGOl0
oego0003of?o00Sooooo00?oJ@3oooooooooool00_ooool00ol0Soooooooooooo`0Jooooo`03oaX0
oooooooooooo00gooooo1ol0ofD?ooooo`006_ooool00ol0003oooooooooo`0Tooooo`0:o`1Iool0
4?oo02SoobH0oolno`3o03CooeL0ool0@?ooJ@3ooaX0o`Cooooo1?l0UOl8ooooo`03ofT0oooooooo
oooo00Wooooo0_lJ0?l01Ol0=?ooE`3ooeL0ool02_oo07go00;ooooo00?o043ooooooolno`001_oo
ool00ol0oi_oooooobH0o`02ocSo00Cooooo0_mMo`001?ooooooHol0of?o0?ooool2o`0^o`?ooooo
00?o0?3oooooooooool01_ooool2o`1<o`03o`2^ool0f?oo0=So00[ooooo0_l0ofD5ooooo`?o02So
0ol0obP2ooooo`?o0>Co0ol0oc@>ooooo`?o0?mg1?ooool;o`23o`Wooooo2Ol04?l8ooooo`Oo08?o
2Oooool4o`3oM`Kooooo0ol0obP2o`3o=005o`3Tooooooooooooooooool0:?l00_ooool2o`3oI@;o
oooo00?o0?l:ooooooooool01?ooool01Ol0oiGoooooooooool0[_oo04co00;ooooo00?oGOl0oooo
ooooool00oooool00ol0;_ooooooooooo`02ooooo`06ocSo0?ooooooooooobH0oooooooo00[o0ooo
ool02?lJ0?ooooooo`3oVol0of_o07gooeL0oooooooo0?o`1?ooool01OlPo`3oooooooooool0odco
03Co00Sooooo0omGo`09ooooo`CoEol02?ooool2ob3o00Kooooo00?o0?m<ooooooooool00oooool2
o`0do`Cooooo0_mG0?l3ooooo`04o`1mooooooooooooooooo`;o6P3o1?ooool2o`3ol0;ooooo0_l0
2_l3ooooo`03o`10oolho`3ooooo00kooooo0olV0?l4ooooo`;oHol00oooool2oego00;o0?3o6ooo
ool2o`3Ho`03obH0oooooooooooo00Kooooo1?l0oiD5ooooo`03o`0doooooooo0?m<00cooooo00?o
?_l0ooooooooool01?ooool01OmG0?oooooooego0?mMo`3ooooo00;oHol01oooool00omY0?ooEol0
ooooo`02ooooo`03o`2?oooooooooooo01[ooooo00Co6P3ooooooooooooooooo2ol0ofD5ooooo`;o
08oo3oooool001[ooooo00?o0000ooooooooool09Oooool02?l04?oo02Soo`0^oolV0?oo?_l0o`0d
oomG0?oo043o0_mY0?l=ooooo`;oJ@3o2_ooool2oaX0o`04o`0dool02_ooE`3oo`0:o`;o07go00Go
ooooo`10ool0@?ooooooocko0006ooooo`04o`3oVolV0?oo9P3oocSo00Cooooo0_mMo`02ooooo`04
of?o0?ooooooooooo`0^o`?ooooo0_l0l?l7ooooo`;o04co00?o0:koo`3Hool0f?l02Oooool3o`3o
I@Cooooo0ol0:?l2o`3o:0?ooooo0ol0i?l00ooooooo0?ldo`3o=00=ooooo`Co0?mg00?oooooo`23
ool0Pol01?l0Pol8ooooo`co013o2Ol0D_l<o`0@o`?ooooo1?l0Pol9ooooo`Co0?mg1Oooool2o`3o
:003o`3o=?l0i?oo0>Co00;ooooo0_l0:?l2ooooo`04o`3oIOooooooooooo`3o2PKooooo00So0?nE
oooooooooooo0:koo`1<ooooooooGOl0of?o00Gooooo00Go02koooooooooooooooooocSo0003oooo
o`03obH0ool0@?oo00[o00?ooooo00Oo6P3oooooool0oi_o0?m[o`1moomG0?oo0?o`00Gooooo0_lP
o`000ooooooo0?m<o`0do`0:ooooo`WoEol02Oooool3ob3o00Kooooo0_l0od`4ooooo`;o03Co1Ooo
ool00omG0?ooooooooooo`02ooooo`05o`1mooooooooooooocko0?lJ0?l01?ooool2o`3ol0?ooooo
00Co00[ooooooooooooooooo0_l0@?l00olho`3oooooooooo`0<ooooo`;o9P3o1Oooool2of?o00?o
oooo0_mMo`02o`3`oa[ooooo0ol0f?l00ol0oo3oooooooooo`02obH0o`?ooooo0ol0oiD9ooooo`03
o`0doooooooo0?m<00gooooo00?o?_l0ooooooooool00oooool01?mG0?oo>?l0ooooooooool3oego
00;oHol01_ooool00omY0?ooEol0ooooo`02ooooo`03o`2?oooooooooooo017ooooo2Ol0ofD2oaX0
o`03o`3oIOoooooooooo00gooooo00?o08ooooooooooool03oooool001[ooooo00?o0000oooooooo
ool09Oooool01ol0FOoo013oo`0Xool0;_oo9P3oocko0?l0=?l00_mG0?l01?ooooooJ@3oofT0oomY
0?l7ooooo`?oJ@3o2Oooool3oaX0o`;o00[o0_mG0?l2o`1mo`04ooooool0@?oo043oooooo`;o?_l0
1_ooool2obH0o`;o>?l00oooool2oego00;ooooo0_mSo`000ooooooo02koo`0^o`03ooooo`03o`3`
oooooooooooo00Cooooo00Co0?l:o`1<ool0C?oo0:ko0_l0f?l9ooooo`;o0?mU1?ooool3o`0Xo`03
o`3o:?oooooooooo00;ooooo0ol0i?l01?oooooo0?ldo`3o=?l0oc@;ooooo`Co0?mg1Ol0Pol5oooo
o`Wo013o1ol0D_l>ooooo`co05;o1?l04?l00ol0m_ooooooooooo`05o`23o`Sooooo0_l0ogL5oooo
o`;o0?lX00?o0?ldo`3Tool0i?l00_ooool01?l0:?ooooooooooool0ofD2ooooo`03o`3o2_oooooo
oooo00Cooooo00So0?nEoooooooooooo04coo`3HooooooooGOl0of?o00Cooooo00?o02kooooooooo
ool00_ooool01_lho`3ooooooooooolV0?ooooooo`0:o`?ooooo00So6P3oooooool0oi_oooooo`1m
oomG0?ooooooo`3ol0Kooooo00?o8?l0ooooool0od`00_l0=?lHooooo`;o8?l02?ooool00ol0odco
ooooooooo`02ooooo`;o03Co1_ooool01?mG0?ooooooooooooooool2o`1mo`;ooooo00?o?_l0oaX0
ooooool00_ooool2o`3ol0?ooooo0_l02_l3ooooo`03o`10oolho`3ooooo00gooooo0_lV0?l5oooo
o`;oHol00oooool2oego0003ooooool0l?oooooo01Sooooo0ol0f?l4ooooo`05o`3ol?oooooooooo
oooooolV0?l00_l0oiD=ooooo`03o`0doooooooo0?m<00gooooo00?o?_l0ooooooooool00oooool0
0omG0?oo>?l0ocSo0003ooooo`?oGOl00_mSo`03ooooo`03ofT0ooooooooEol000?ooooo00?o08oo
ooooooooool01oooool9o`3oI@_ooooo00?o6P3oooooooooool02oooool2o`2?oa;ooooo000Joooo
o`03o`000?oooooooooo02Kooooo00Ko013oo`1Bool0:?oo0?nKobH0oolno`02o`0do`04oeL0oooo
oooo6P3ooaX0o`OoJ@3o2Oooool3oaX0o`?o00[o0_mG0?l2o`1mo`?o043o0_ooool00olno`3ooooo
ooooo`04ooooo`04o`3oVolV0?oo>?l0ocSo00?ooooo0_mMo`02ooooo`;oHol00_ooool01?l0;_oo
ooooooooooooool2o`3`o`Gooooo0_l0o`X01?l0C?oo0:koo`3oUOl0f?l9ooooo`;o0?mU0oooool0
0ol0obSo02Soo`0Xo`06ooooo`;o0>Co0_ooool2o`3o=0_ooooo0ol0ogL4o`23o`Oooooo0ol04?l4
o`1Bo`Go0?Ko8Oooool4o`1Bo`Ko013o00?o0?Koooooool0Pol00ol0Pol6ooooo`;o0?mg1Oooool0
0ol0obSo0?ldo`3o=002o`3To`05ooooool0:?oo02Soooooool0ofD00_ooool00ol0o`[ooooooooo
o`04ooooo`07o`3oUOoooooo0:koo`1<ool0f?oooooooego0005ooooo`03o`0^oooooooooooo00;o
oooo00Ko>?l0oooooooooooo9P3oo`10ool02_l3ooooo`08oaX0oooooooo0?nKo`3oJol0OOooE`3o
ooooool0oo06ooooo`05ob3o0?oooooo0?m<ooooool0=?l05Oooool2ob3o00Sooooo0_l0od`4oooo
o`03o`0doooooooooooo00Cooooo0_mG0?l3ooooo`04o`1mooooooooooooooooo`;o6P3o0oooool0
0ol0oo3o0?nKooooo`02ooooo`03o`0:oooooooooooo00;ooooo00?o043oocSo0?ooool03Oooool0
0olV0?ooooooooooo`03ooooo`;oHol00oooool2oego00;ooooo00?o0?3oooooooooool05Oooool3
o`3Ho`Sooooo00Go0?o`o`3oUOl0oiGoooooobH0o`0>ooooo`04o`0dooooooooooooo`3oC0gooooo
00?o?_l0ooooooooool00_ooool01?mG0?oooooooooooolho`05ooooo`;oGOl00_mSo`02ooooo`03
ofT0ooooooooEol000?ooooo00?o08ooooooooooool01_l0ofDEooooo`03oaX0oooooooooooo00So
oooo0_l0SolDooooo`006_ooool00ol0003oooooooooo`0Vooooo`0:o`1Iool04?oo02Soo`0^ool0
o`[o9P3oocko0?oooooo03CooeL0o`;o043o00?o00[ooaX0oolJ0?l00_lJ0?l7ooooo`Co6P3o0ol0
2_l00ol0=?ooE`3ooeL0o`02o`1mo`;o043o1?ooool00olno`3oooooooooo`04ooooo`;o9P3o00Co
>?l0oooooooooooooooo0_mMo`02ooooo`;oHol00_ooool2o`0^o`?ooooo00?o0?3oooooooooool0
0oooool2o`3o2P;o04co00?o0?nEo`3Hool0f?l01oooool3o`3oI@;ooooo0_l0obP2o`0Xo`Kooooo
0_l0i?l2ooooo`;o0?ld2Oooool4o`3oM`?o08?o1_ooool5o`0@o`03o`1Bool0m_oooooo02oooooo
1?l0D_l00ooooooo013oo`0@o`02o`0@o`04o`3foooooooo08?oo`23o`Kooooo0_l0ogL4ooooo`;o
0?lX0_l0oc@2o`3To`04ooooool0:?ooooooo`3oI@;ooooo00?o0?l:ooooooooool01?ooool01ol0
oiGoooooo`2^ool0C?oooooooego0?mSo`001?ooool00ol0;_ooooooooooo`02ooooo`06ocSo0?oo
ooooooooobH0oooooooo00[o1?ooool01olJ0?oo0?nKooooool0of_o07gooeL0ool0oo001oooool2
ob3o00;o0?m<0_l0=?lBooooo`03ob3o0?oooooooooo00Gooooo0ol0od`4ooooo`;o03Co1_ooool0
0omG0?ooooooooooo`02ooooo`06o`1mooooooooooooocko0?lJ0?oo0?m[0_ooool2o`3ol005o`3o
Voooooooooooooooool02_l00oooool2o`10o`03ocSo0?oooooooooo00_ooooo0_lV0?l4ooooo`;o
Hol00oooool2oego00;ooooo0_l0l?lFooooo`;o0=So2Oooool2o`3oU@03ooooool0oo3ooooo00;o
oooo00?o9P3oooooooooool02oooool01?l0=?ooooooooooool0od`>ooooo`03ocko0?oooooooooo
00;ooooo00CoE`3ooooooooooooo>?l01_ooool3oego0004of?o0?mY0?ooooooooooo`Co0?mU00?o
08ooo`3oIOooool06oooool00olJ0?ooooooooooo`06ooooo`03o`2?oooooooooooo01Cooooo000J
ooooo`03o`000?oooooooooo02Oooooo00Wo05Woo`0@ool0:?oo0?nKo`3o2_lV0?oo0?nWooooool0
=?l00_mG0?l00ol0@?ooooooo`0:o`02o`0:o`Oo6P3o1?l02_l2o`0do`;oE`3o0_l0OOl2o`10o`Co
oooo0_lno`05ooooo`;o9P3o0_lho`02ooooo`;oGOl00oooool01OmSo`3ooooooooooooooooo02ko
00?ooooo0_l0l?l4ooooo`;o0?l:0_l0C?l00ol0oiGo0=Soo`3Ho`07ooooo`;o0?mU0oooool01?l0
obSo02Soo`0Xool0:?l5ooooo`?o0>Co00Coooooo`3o=?l0ocCo0?ld1oooool4o`3oM`Co08?o0ooo
ool6o`0@o`Co0?Ko=oooool3o`1Bo`;ooooo0ol04?l00ol0m_oo08?oo`23o`06ooooo`;o0?mg1?oo
ool2o`3o:006o`3o=?oooooo0>Coooooool0:?oo0?mU0oooool00ol0o`[oooooooooo`04ooooo`07
o`3oUOoooooo04coo`3HooooooooGOl0of?o0004ooooo`03o`0^oooooooooooo00;ooooo00Ko>?l0
oooooooooooo9P3oooooool02_l3ooooo`08oaX0oooooooo0?nKo`3oJoooooooE`3oooooool0oo09
ooooo`04ob3o0?oooooo0?m<o`0do`oooooo0_lPo`06ooooo`;o0?m<1Oooool2o`0do`Kooooo0_mG
0?l3ooooo`;o07go0_ooool01?lno`3o6P3oooooooooool2o`3ol004ooooool0oi_oooooooooo`;o
00[o0oooool00ol0@?oo>?l0ooooo`0<ooooo`;o9P3o1?ooool2of?o00?ooooo0_mMo`03ooooo`03
o`3`oooooooooooo01Gooooo00?o0=Soooooooooool01oooool2o`3oU@?ooooo00Go0?o`oooooooo
ooooooooobH0o`0>ooooo`04o`0dooooooooooooo`3oC0kooooo00Go?_l0oooooooooooooooooeL0
o`03ooooo`03ocSo0?oooooooooo00Cooooo1?l0ofD01?mY0?oo0?mUoooooomGo`03ooooo`03o`2?
oooooooooooo01_ooooo0_lJ0?l4ooooo`;o08oo5oooool001[ooooo00?o0000ooooooooool09ooo
ool02Ol0FOoo013oo`1Bool0:?oo0?nKo`3o2_lV0?oo0?nWooooo`02o`0do`04oeL0ool0@?oo0?m<
o`3oC0Kooooo1?l0od`2o`0do`;oE`3o00Co07goo`10ool0@?oo043o1?ooool2ocko00Kooooo00?o
9P3oo`3oVolho`000_ooool2oego00?ooooo0_mSo`02ooooo`;o02ko0oooool01?l0l?oooooooooo
ooooool3o`3o2P;o04co0_l0oiD00ol0f?ooooooooooo`04ooooo`?o0?mU0_ooool2o`3o:0;o02So
1_ooool2o`3To`;ooooo0_l0oc@7ooooo`?o0?mg1?l0Pol2ooooo`Go013o0_ooool4o`3fockooooo
0ol0D_l2ooooo`?o013o0_l0Pol6ooooo`;o0?mg1?ooool01ol0obSo0?ldooooool0i?ooooooo`0X
ool0ofD00oooool00ol0o`[oooooooooo`03ooooo`08o`3oUOoooooo0:koo`1<ool0f?oooooooego
0?mSo`04ooooo`05o`0^oooooooooooooooooolho`000oooool00olV0?oo043oo`0:o`03ooooo`07
oaX0oooooooo0?nKo`3oJol0OOooE`3oo`3ol00:ooooo`;o8?l000?o0?m<o`0dool0=?l02Oooool4
ob3o00Gooooo0ol0od`5ooooo`;o03Co1oooool00omG0?ooooooooooo`02ooooo`04o`1moooooooo
ooooooooo`;o6P3o00Coooooo`3ol?l0oo3ooooo0_l0oi/2ooooo`03o`0:oooooooooooo00;ooooo
00?o043oocSo0?ooool02oooool2obH0o`Cooooo0_mSo`03ooooo`;oGOl01?ooool00ol0l?oooooo
ooooo`0Dooooo`;o0=So1oooool3o`3oU@Kooooo00Go0?o`ooooooooooooooooobH0o`0=ooooo`04
o`0dooooooooooooo`3oC0oooooo00Go?_l0oooooooooooooooooeL0o`03ooooo`Ko0?mU1?ooool0
1?mY0?ooGOl0of?o0?ooool2oeOo00;ooooo0_l0SolMooooo`04oaX0ooooooooooooo`2?oaWooooo
000Jooooo`03o`000?oooooooooo02Sooooo00Wo05Woo`0@ool0:?oo02koo`3oVol0o`[o9P3oo`3o
Yolno`000_ooool5oeL0o`Go0?o`1OmG0?l3o`10o`03o`3oYooooooooooo00;ooooo0_lno`06oooo
o`;o9P3o00?o>?l0ooooooooool00_mMo`03ooooo`;oHol00_ooool2o`0^o`?ooooo0_l0l?l2oooo
o`;o0?l:00?oooooo`1<ool0C?l00_l0oiD2o`3Ho`Gooooo0_l0ofD2ooooo`?o0?lX0_l0:?l6oooo
o`;o0>Co00Coooooo`3o=?l0ocCo0?ld1_ooool3o`3oM`?o08?o0oooool3o`0@o`?ooooo1?l0m_l>
ooooob?o0?mI5?ooool3o`1Bo`;ooooo0ol04?l2o`23o`Gooooo0_l0ogL3ooooo`07o`3o:?l0ocCo
ooooo`3Toooooooo02Soo`3oI@03ooooo`03o`3o2_oooooooooo00?ooooo00Oo0?nEooooool0[_oo
04coo`3HooooooooGOl000Cooooo00?o02koooooooooool00_ooool01_lho`3ooooooooooolV0?oo
ooooo`0:o`?ooooo00So6P3oocko0?l0oi_oooooo`3oJol0OOooE`3oo`3ol0cooooo00?o8?l0o`3o
C?l0=?l02?lPo`06ooooo`?o0?m<1Oooool3o`0do`Oooooo0_mG0?l3ooooo`;o07go0_ooool01Oln
o`3o6P3oo`3oJooooooo0?o`00;ooooo00?o0?nKooooooooool00_l02_l3ooooo`;o043o00?o>?l0
ooooooooool02_ooool00olV0?ooooooooooo`02ooooo`;oHol00oooool2oego00Gooooo00?o0?3o
ooooooooool04oooool2o`3Ho`Oooooo0_l0oiD:ooooo`05o`3ol?oooooooooooooooolV0?l03Ooo
ool01?l0=?ooooooooooool0od`?ooooo`04ocko0?l0ofGo0?mUoeL0o`?o0?mU00?oooooocSo0?lh
o`002?ooool01_mY0?ooGOl0of?o0?mSo`3ooooooeOo00?ooooo0_l0SolLooooo`03oaX0ool0Sooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo02Sooooo00Oo05Woo`0@ool0D_oo02Soo`0^ool0
oi_o0?l:00;o9P3o00?o0?nWooooooooool00_l0OOl00ol0=?ooE`3ooeL0o`04oeL0o`Go043o0_l0
ojL4ooooo`;o?_l01_ooool2obH0o`03o`3oVolho`3oGOl000;oGOl00_ooool3of?o00?ooooo00?o
02koooooooooool00_ooool00ol0l?ooooooooooo`02o`3o2P03ooooool0C?oo04co00;o0?nE0_l0
f?l5ooooo`;o0?mU0_ooool2o`3o:0?o02So1_ooool2o`3To`03ooooool0ocCo0?ld00Kooooo0ol0
ogL3o`23o`?ooooo0ol04?l3ooooo`?o0?Ko3?ooool6o`3oFB?ooooo1ol0oeT@ooooo`?o05;o00Co
ooooo`3fool04?oo013o0_l0Pol5ooooo`0;o`3oMoooooooooooooooool0obSo0?ldooooool0i?oo
ooooo`0Xool0ofD00oooool00ol0o`[oooooooooo`03ooooo`07o`3oUOl0[_oo04coo`3Hoooooooo
GOl0of?o0004ooooo`03o`0^oooooooooooo00;ooooo00Ko>?l0oooooooooooo9P3oo`10ool02_l3
ooooo`06oaX0oooooooo0?nKo`3oJooooooo07go0_mG0?l>ooooo`;o03Co0_l0od`7ooooo`?o0?m<
1Oooool3o`0do`Wooooo00?oE`3oooooooooool00_ooool01?l0OOooooooooooooooool2oaX0o`03
ooooool0oo3o0?o`00;ooooo00Co0?nKoooooooooooo00[o1?ooool00ol0@?oo>?l0ooooo`0;oooo
o`;o9P3o1?ooool01?mSo`3oooooooooooooool2oego00Gooooo0_l0l?lEooooo`03o`3Hoooooooo
oooo00Gooooo0_l0oiD<ooooo`03o`3ol?oooooooooo00;ooooo00?o9P3oooooooooool02_ooool0
1?l0=?ooooooooooool0od`:ooooo`Ko0?mU00Co?_l0ooooooooooooE`3o1Oooool00olho`3ooooo
ooooo`05ooooo`04ofT0ooooooooGOl0oego00;oHol00_mGo`03ooooo`;o08oo6?ooool2o`2?o`03
oooooolJ0?oooooo01Wooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000
2Oooool00ol0003oooooooooo`0Yooooo`0:o`1Iool04?oo05;oo`0Xool0ofGo0?nKo`3o2_lho`3o
9P3oo`3oY`;o?_l02oooool2o`3oY`?ooooo0olno`05ooooo`?o9P3o00Co0?nKocSo0?mMo`3oGOl0
0oooool2of?o00Cooooo0_l0;_l3ooooo`;o0?3o00?oooooo`3o2_l0o`X00_ooool00ol0C?oo0?nE
o`3oU@02o`3Ho`Cooooo0ol0ofD01?oooooo0?lXo`3o:?l0obP2o`0Xo`Kooooo0ol0i?l00ooooooo
0?ldo`3o=005ooooo`?o0?mg0ol0Pol3ooooo`?o013o0oooool3o`3fo`Wooooo1_l0oeT`ooooo`Go
0?mI3_ooool3o`1Bo`03o`3fool04?oo013o00;o08?o1?ooool2o`3oM`;ooooo00Oo0?lXo`3o=?oo
oooo0>Coo`0Xoooooooo0?mU00;ooooo00?o0?l:ooooooooool00oooool02?l0oiGoooooo`2^ool0
C?oo0=SooooooomMo`3oHol00oooool00ol0;_ooooooooooo`02ooooo`07ocSo0?ooooooooooobH0
oooooooo043oo`0:o`03ooooo`08oaX0ool0oi_oooooo`3oJooooooo07gooooooomG0?l?ooooo`Co
03Co1Ol0od`5ooooo`?o03Co2_ooool2oeL0o`Cooooo00Ko07gooooooooooooooooooaX0ool0of/2
o`3ol0?ooooo00Co0?nKoooooooooooo00[o0oooool2o`10o`03ocSo0?oooooooooo00Wooooo0_lV
0?l5ooooo`03of?o0?oooooooooo00;oGOl01_ooool00ol0l?ooooooooooo`0Cooooo`;o0=So1Ooo
ool3o`3oU@kooooo00?o0?l:o`3ol?l0o`X00_l0o`X00olV0?oo0?l:o`3o2P0;o`3o2P04o`0dool0
o`[o0?l:o`3oC0;o0?l:00?oooooo`3oIOl0ofD01?l0ofD7ooooo`03ocko0?ooooooE`3o00Kooooo
00?o>?l0ooooooooool01Oooool00omY0?ooooooooooo`02oego00;oHol000?oEol0ooooooooool0
0_ooool00ol0Soooooooooooo`0Cooooo`;o08oo1?ooool00olJ0?ooooooooooo`0Gooooo`0000Go
ooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:_ooool01Ol0FOoo013oo`0Xool0;_oo0?mU00;o0?nK00?o>?l0obH0oolV0?l00ol0ojL5ooooo`Co
0?nW00?oooooocko0?lno`000_lno`06ooooo`;o9P3o0_lho`000ol0oi_oGOl0oego0003ooooo`;o
Hol01Oooool00ol0;_ooooooooooo`02ooooo`04o`3`oooooooo0?l:o`3o2P;ooooo0_l0C?l00ol0
oiGo0=Soo`3Ho`04ooooo`;o0?mU0_ooool2o`3o:003ooooool0:?oo02So00Kooooo0_l0i?l2oooo
o`;o0?ld1Oooool2o`3oM`?o08?o0oooool3o`0@o`?ooooo0ol0m_l7ooooo`Go0?mI>oooool3o`3o
F@kooooo0_l0D_l00ol0m_oo013oo`0@o`02o`23o`Cooooo00[o0?mgoooooooooooo0?lXo`3o=?l0
i?ooooooo`0Xoooooooo0?mU0_ooool00ol0o`[oooooooooo`03ooooo`04o`3oUOoooooo04coo`3H
o`;ooooo00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`02ooooo`07ocSo0?oooooooooo
obH0oooooooo043oo`0:o`02ooooo`09oaX0oolno`3o0?nKooooool0of_oooooo`1mooooooooE`3o
01;ooooo2_l0=?l;ooooo`;oE`3o1?ooool2o`1mo`;ooooo00Co?_l0oaX0ool0of_o0?o`1?ooool0
1?l0oi_oooooo`0:ool02_l3ooooo`03o`10oolho`3o>?l000_ooooo00?o9P3oooooooooool00ooo
ool2of?o00;ooooo00?oGOl0ooooooooool01Oooool00ol0l?ooooooooooo`0Booooo`;o0=So1Ooo
ool2o`3oU@Oooooo2_l0o`X00ooooooo0?o`ooooo`03ooooo`03obH0oooooooooooo00[ooooo00?o
03Coooooool0ofD01?l0ofD6o`3o2PSooooo00?o?_l0oooooomG0?l01_ooool00olho`3ooooooooo
o`04ooooo`03ofT0oooooooooooo00;ooooo00?oGOl0oooooomSo`000_mGo`03ooooo`;o08oo2_oo
ool6o`3To`?o08oo1ol0i?l2oaX0o`So0>Co3oooool00005ooooool0003oooooooooool000001ooo
ool5o`0000Wooooo1?l0000Yooooo`08o`1Iool04?oo05;oo`0Xool0;_oo0?mUooooool0oi/2ocSo
0003obH0oomMo`3oGOl000Go0?nW1Olno`08ooooo`;o9P3o0_lho`02o`3oV`03oego0?oooooooooo
00?oHol01Oooool2o`0^o`?ooooo0_l0l?l2o`3o2P;ooooo0_l0C?l00ol0oiGoooooo`3Ho`03oooo
o`?o0?mU00Coooooo`3o:?l0obSo0?lX0ol0:?l6ooooo`;o0>Co00Coooooo`3o=?l0ocCo0?ld1?oo
ool3o`3oM`;o08?o0oooool3o`0@o`?ooooo0ol0m_l5ooooo`Go0?mI6?oooolHo`3o>Q?ooooo0ol0
oeT=ooooo`;o05;o00?o0?Koo`0@ool04?l00_l0Pol3ooooo`0:o`3oMoooooooooooo`3o:?l0ocCo
0>Coooooool0:?ooooooo`3oI@;ooooo00?o0?l:ooooooooool00oooool01ol0oiGo0:koo`1<ool0
f?oooooooego0?mSo`000oooool00ol0l?oo02koooooo`03ooooo`06ocSo0?ooooooooooobH0ool0
@?oo00[o0oooool02OlJ0?ooooooo`3oVooooooo0?m[ooooool0OOoooooooeL0o`0Uooooo`03oeL0
oooooooooooo00?ooooo00Co07gooooooooooooooooo0_lJ0?l2o`3ol0?ooooo0_l0oi/00ooooooo
00[oooooo`03ooooo`03o`10oolho`3ooooo00[ooooo0_lV0?l5ooooo`03of?o0?oooooooooo00;o
GOl01_ooool2o`3`oaCooooo00?o0=Soooooooooool00oooool2o`3oU@Gooooo1?l0o`X;ooooo`03
o`3ol?oooooooooo00?ooooo00?o9P3oooooooooool01Oooool5o`3oI@04o`0dooooooooooooo`3o
C0Sooooo1Ol0o`X4ooooo`03ocko0?mG0?oooooo00Kooooo0_lho`05ooooo`03ofT0oooooooooooo
00;ooooo0_mMo`02of?o00Go0>Co1Ol0Sol5o`3To`;ooooo1?l0Sol<ooooo`03oaX0oooooooooooo
01Cooooo00001Ooooooo0000oooooooooooo000000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`0[ooooo`04o`1Iool04?oo0=Soo`0Xo`;o02ko00Coooooo`3oVol0oi_oHol0
0_lV0?l3oego00cooooo0olV0?l2ocSo00;o0?nK0oooool2of?o00Oooooo00?o02koooooooooool0
0_ooool00ol0l?oo0?l:ooooo`02ooooo`;o04co00Co0?nEooooool0f?oo0=So0_ooool2o`3oI@;o
oooo0_l0obP00ooooooo02Soo`0Xo`07ooooo`;o0>Co00?oooooo`3o=?l0oc@01Oooool2o`3oM`?o
08?o0_ooool3o`0@o`Cooooo0_l0m_l4ooooo`Co0?mI4oooool:o`3o>QSooooo1ol0ocX?ooooo`?o
0?mI3?ooool2o`1Bo`04o`3fool04?ooooooo`23o`?ooooo00Wo0?mgoooooooooooo0?lXo`3o=?l0
i?ooooooo`0Xool0ofD00_ooool00ol0o`[oooooooooo`03ooooo`04o`3oUOoooooo04coo`3Ho`;o
oooo00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`02ooooo`07ocSo0?ooooooooooobH0
oooooooo043oo`0:o`03ooooo`09oaX0oooooooo0?nKooooool0of_oooooo`1mooooooooE`3o02;o
oooo0_mG0?l5ooooo`05o`1moooooooooooooooooolJ0?l00_l0oo04ooooo`04o`3oVooooooooooo
o`0:o`?ooooo0_l0@?l00olho`3oooooooooo`09ooooo`03obH0oooooooooooo00?ooooo0_mSo`02
ooooo`03oego0?oooooooooo00Gooooo00?o0?3oooooooooool04_ooool2o`3Ho`Cooooo0_l0oiD4
ooooo`?o0?l:4?ooool00ol0oo3oooooooooo`02ooooo`03obH0oooooooooooo00Go0?mU1Oooool0
1?l0=?ooooooooooool0od`=ooooo`Go0?l:00?ooooooeL0ooooool01oooool00olho`3ooooooooo
o`02o`3To`03ofT0ool0i?oo0>Co00Ko0>Co00?oHol0oeOo0?mGo`001oooool7o`2?oa7ooooo00Co
6P3ooooooooooooooooo0omGo`0?ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooooooool0:oooool01ol0FOoo013oo`1Bool0f?oo02Soo`1<
ool0;_l00_ooool00ol0oi_oHol0of?o0003obH0o`CoGOl01_ooool2obH0o`?o>?l00_l0oi/3oooo
o`;oHol01oooool2o`0^o`?ooooo0_l0l?l3ooooo`;o04co00Go0?nEooooool0f?oo0=Soooooo`03
o`3oI@05ooooool0obSo0?lXo`3o:?ooool00_l0:?l7ooooo`;o0>Co00?oooooo`3o=?l0oc@01Ooo
ool2o`3oM`;o08?o0_ooool3o`0@o`Cooooo0ol0m_l2ooooo`Co0?mI4Oooool6o`3o>PWooooo7?l0
ob84ooooo`Ko0?lj3?ooool3o`3oF@_ooooo0_l0D_l00ol04?ooooooo`23o`03ooooo`09o`3oMooo
ooooooooo`3o:?l0ocCo0>Coooooool0:?oo0?mU00;ooooo00?o0?l:ooooooooool00oooool01ol0
oiGo0:koo`1<ool0f?oooooooego0?mSo`000oooool00ol0l?oo02koooooo`03ooooo`07ocSo0?oo
ooooooooobH0ool0@?ooooooo`0:o`03ooooo`09oaX0ool0oi_oooooooooool0of_oooooo`1moooo
ooooE`3o01oooooo0_mG0?l5ooooo`;o07go0_ooool00olno`3o6P3oo`3ol005ooooo`04o`3oVooo
oooo00[oo`0:o`?ooooo00?o043oocSo0?lho`002_ooool2obH0o`Gooooo00GoHol0oooooooooooo
oooooego0007ooooo`03o`3`oooooooooooo017ooooo0_l0f?l4ooooo`;o0?nE0oooool3o`3o2Q?o
oooo00Co0?o`oooooooooooooooo0_l0ofD00olV0?oo0?mUooooo`0:ooooo`04o`0doooooooooooo
o`3oC17ooooo00?o0?l:oeL0ool0i?l02_l0i?l3ooooo`03ofT0oooooooooooo00Gooooo0_mMo`00
0omSo`3oEol0ooooo`0Nooooo`03oaX0oomGo`3oEol001;ooooo00001Ooooooo0000oooooooooooo
000000Wooooo0_l0000:ooooo`03o`000?oooooooooo02cooooo00Ko05Woo`0@ool0D_oo0=Soo`0X
ool0C?l2o`0^o`06ooooool0oi_o0?l:o`3o2_mSo`3o>?l02_lV0?l3ooooo`;o0?nK0oooool2of?o
00Sooooo00Ko02koooooooooooooooooo`3o2_l0l?l3ooooo`;o04co00Go0?nEooooool0f?oo0=So
ooooo`02o`3oI@04ooooool0obSo0?lXo`3o:0;ooooo0_l0:?l6ooooo`?o0>Co00?oooooo`3o=?l0
oc@01?ooool2o`3oM`?o08?o0_ooool2o`0@o`Cooooo0ol0m_l00ooooooo0?mIo`3oF@02o`3oF@oo
oooo1_l0ocX4ooooo`_o0?lR7?ooool9o`3o8P03ooooool0oc[o0?lj00Co0?lj2Oooool3o`3oF@[o
oooo00Co05;oo`0@oooooooo08?o0oooool02Ol0ogOoooooooooool0obSo0?ldo`3Toooooooo02So
o`3oI@02ooooo`03o`3o2_oooooooooo00?ooooo00Oo0?nEo`2^ool0C?oo0=SooooooomMo`3oHol0
00?ooooo00?o02koooooooooool00_ooool01olho`3ooooooooooolV0?ooooooo`10ool02_l00ooo
ool00olJ0?oo?_l0o`3oV`02ooooo`04o`3oJooooooo07goooooo`;oE`3o6oooool2oeL0o`Kooooo
00Co07gooooooooooooooooo0_lJ0?l00ol0of_oooooooooo`03ooooo`03o`3oVooooooo00[o00Co
oooo00?o043oocSo0?ooool02_ooool00olV0?ooooooooooo`04ooooo`03of?o0?oooooooooo00;o
GOl01oooool00ol0l?ooooooooooo`0Aooooo`03o`3Hoooooooooooo00;ooooo0_l0oiD2ooooo`?o
0?l:5oooool00ol0oo3o0?mUo`3oI@03ooooo`03obH0oooooooooooo00Wooooo00Co03Cooooooooo
oooo0?m<2_ooool9o`3To`03oeL0oooooooo0?l:00?o0?l:1?ooool00olho`3oooooooooo`02oooo
o`03ofT0oooooooooooo00Kooooo0_mMo`03oeOo01_ooooo0_mGo`000olJ0?ooooooooooo`0Aoooo
o`000_ooool2o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`06
o`1Iool0Jooo013oo`1Bool0f?oo02So0_l0C?l00ol0;_ooooooo`3oV`02o`3oV`;o0?l:00?oHol0
ooooooooool01Oooool4o`3oV`GoHol02?ooool2o`0^o`03ooooool0o`[o0?l:00;o0?3o0oooool0
0ol0C?oo0?nEooooo`02o`3Ho`03ooooool0ofGo0?mU00?o0?lX0oooool2o`0Xo`Kooooo0_l0i?l2
ooooo`;o0?ld1?ooool01?l0ogOo08?oo`23ool0Pol2ooooo`03o`1Bool04?oo013o00?ooooo0ol0
m_l4o`3oF@kooooo1Ol0ocX5ooooo`Go0?lR4Oooool7o`3Zo`Co06_o2ol0j_l9ooooo`?o0?lR1?oo
ool4o`3o>PSooooo0_l0oeT9ooooo`04o`1Bool04?oo013oo`23o`?ooooo00_o0?mgoooooooooooo
0?ldooooool0i?oo02Soooooool0ofGoooooo`3o2P05ooooo`04o`3oUOoooooo04coo`3Ho`;ooooo
00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`02ooooo`07ocSo0?ooooooooooobH0ool0
@?ooooooo`0:o`03ooooo`03oaX0oolno`3o0?nK00;ooooo00Ko0?m[ooooool0OOooooooo`3ol?mG
0?lHooooo`;oE`3o1oooool01_l0OOoooooooooooooooooo6P3oo`3oJ`Kooooo00?o0?nKooooool0
2_l00oooool2o`10o`03ocSo0?oooooooooo00Wooooo00?o9P3oooooooooool00oooool2of?o00;o
oooo00?oGOl0ooooooooool01Oooool2o`3`oa;ooooo0_l0f?l3ooooo`;o0?nE00Coooooo`3o2_l0
o`[o0?l:5oooool3o`3oI@03o`3ol?oooooooooo00?ooooo00?o9P3oooooooooool02_ooool01?l0
=?ooooooooooool0od`3ooooo`Ko0>Co2Oooool00omG0?ooooooooooo`03ooooo`?o0?l:0_ooool0
1Olho`3oooooooooooooooooJ@3o00[ooooo00?oGOl0oooooomSo`000omGo`0Fooooo`;oEol00ooo
ool2oaX0oa7ooooo000Jooooo`03o`000?oooooooooo02gooooo00So05Woo`1[ool04?oo05;oo`3H
ool0:?oo0?3oo`1<o`;o02ko0_ooool:o`3oV`CoHol02_ooool3o`0^o`?o0?l:0_l0l?l3ooooo`;o
04co00?oooooo`3Hool0f?l00ol0ofD2o`3o:0Cooooo0_l0:?l6ooooo`;o0>Co00Coooooo`3o=?l0
ocCo0?ld1?ooool3o`23o`;ooooo00Co05;oo`0@ool04?oo013o0oooool2o`3fo`?o0?mI3Oooool5
o`3o>PKooooo1?l0ob8;ooooo`;o0>[o4Ol0Jol2o`29oa3o06_o0_l0ROl3o`3Zo`?ooooo1?l0ob84
ooooo`?o0?lj1oooool2o`3oF@Sooooo00Co05;oo`3fool04?oo08?o0oooool02?l0ogOoooooo`3o
:?l0ocCo0>Coooooool0:?oo0?mU0_ooool00ol0o`[oooooooooo`03ooooo`07o`3oUOl0[_oo04co
o`3HooooooooGOl0of?o0003ooooo`03o`3`ool0;_oooooo00?ooooo00Oo>?l0oooooooooooo9P3o
o`10oooooooo00[o00?ooooo00?o6P3oocko0?l0oi/00_ooool01Ol0of_oooooo`1moooooooo0?o`
00;oE`3o5?ooool2oeL0o`Oooooo0_l0OOl2ooooo`;o6P3o00?o0?m[ooooooooool00oooool2o`3o
V`;o00[o0oooool00ol0@?ooooooocSo000:ooooo`;o9P3o1Oooool00omSo`3oooooooooo`02oego
00Oooooo00?o0?3oooooooooool04?ooool2o`3Ho`Cooooo00Co0?nEo`3o2_l0o`[o0?l:5oooool3
o`3oI@Cooooo00?o0?o`ooooooooool00oooool00olV0?ooooooooooo`09ooooo`03o`0dool0i?oo
0>Co00Co0>Co4?ooool00omG0?ooooooooooo`05ooooo`?o0?l:0_lho`02ooooo`03ofT0oooooooo
oooo00Sooooo0_mMo`02of?o0003oooooomGo`3oEol000;oEol03Oooool5oeOo00Oooooo00?o6P3o
ooooooooool03_ooool001[ooooo00?o0000ooooooooool0;_ooool01ol0FOoo06_oo`0@ool0D_oo
0=Soo`0Xool0l?l00_l0C?l00ol0;_ooooooooooo`02ooooo`?o0?l:3_ooool01?l0o`[o02koo`0^
ool0;_l2o`3o2P;ooooo0_l0l?l3ooooo`;o04co0_ooool00ol0f?oo0?mUo`3oI@03o`3o:0Cooooo
0_l0:?l6ooooo`;o0>Co00?oooooo`3o=?l0oc@01Oooool2o`23o`;ooooo0_l0D_l2o`0@o`?ooooo
0ol0m_l00ol0oeWoooooooooo`0;ooooo`Co0?lj1oooool4o`3o8PWooooo0_l0j_l6o`1[o`03o`29
oooooooooooo023ooooo1ol0Jol00ol0ROooooooooooo`02ooooo`Go0?lR0_ooool2o`3o>POooooo
00?o0?mIooooooooool01_ooool01?l0D_ooooooo`0@ool0Pol3ooooo`08o`3oMooooooo0?lXo`3o
=?l0i?ooooooo`0Xool0ofD2ooooo`03o`3o2_oooooooooo00;ooooo00Co0?nEooooool0C?oo0=So
0_ooool00omMo`3oHol0ooooo`02ooooo`03o`0^oooooooooooo00;ooooo00So>?l0oooooooooooo
9P3oooooool0@?ooooooo`0:o`?ooooo00?o6P3oocko0?l0oi/00_ooool01?l0of_oooooo`1moooo
ool2o`3ol0;oE`3o3oooool3oeL0o`Oooooo0_l0OOl2ooooo`04o`3ol?lJ0?ooooooo`3oJ`Gooooo
00?o0?nKooooool02_l01?ooool00ol0@?oo>?l0ocSo000:ooooo`03obH0oooooooooooo00?ooooo
0_mSo`02ooooo`03oego0?oooooooooo00Kooooo00?o0?3oooooooooool04?ooool00ol0f?oooooo
ooooo`02ooooo`;o0?nE00?o0?l:ooooooooool05Oooool3o`3oI@Oooooo00?o0?o`ooooooooool0
1?ooool00olV0?ooooooooooo`03ooooo`Ko0>Co00Co03Cooooooooooooo0?m<4_ooool00omG0?oo
?_l0ooooo`08ooooo`?o0?l:00?oooooofT0ooooool02oooool2oego00;oHol00oooool=oeOo00go
oooo00?o6P3oooooooooool03Oooool001[ooooo00?o0000ooooooooool0;_ooool01?l0Vooo05Wo
o`3fool04?l2o`1Bo`04o`0Xool0l?oo0?3oo`1<o`?o02ko1?ooool;o`3o2PCo02ko1Oooool2o`3`
o`?ooooo0_l0C?l2ooooo`;o0=So00?o0?mUo`3o:?l0obP01Oooool2o`0Xo`Gooooo0ol0i?l00ooo
oooo0?ldo`3o=004ooooo`?o08?o00Coooooo`1Bool0D_oo05;o0_l04?l2ooooo`?o0?Ko3Oooool4
o`3o>POooooo1?l0ob87ooooo`;o0>[o1_l0Jol00ol0ROooooooooooo`0]ooooo`Go06_o1Oooool3
o`3o8P03ooooool0oc[o0?lj00Kooooo0_l0oeT7ooooo`;o05;o00Go013oo`23ooooooooooooo`3o
M`02ooooo`06o`3o:?l0ocCo0>Coo`0Xoooooooo0?mU0_ooool00ol0o`[oooooooooo`02ooooo`07
o`3oUOl0[_oo04coo`3HooooooooGOl0of?o0003ooooo`03o`3`ool0;_oooooo00?ooooo00Oo>?l0
oooooooooooo9P3oo`10oooooooo00[o00Cooooo00?o6P3oocko0?l0oi/00_ooool2o`3oJ`?o07go
00?o0?o`oooooomG0?l00_mG0?l:ooooo`;oE`3o2?ooool2o`1mo`;ooooo0_l0oo000olJ0?oo0?m[
o`3oJ`05ooooo`03o`3oVooooooo00[o00?ooooo0_l0@?l00olho`3oooooooooo`09ooooo`03obH0
oooooooooooo00?ooooo00?oHol0ooooooooool00_mMo`07ooooo`;o0?3o4_ooool01?l0f?oooooo
ooooooooool2o`3oUAOooooo0ol0ofD:ooooo`03o`3ol?oooooooooo00Cooooo00?o9P3oo`3Tool0
i?l00ol0i?l6ooooo`04o`0dooooooooooooo`3oC1?ooooo00?oE`3oocko0?ooool02_ooool2o`3o
2P03ofT0oooooooooooo00_ooooo0_mMo`02of?o02_ooooo000Jooooo`03o`000?oooooooooo02oo
oooo00Ko05Woo`1[ool0m_oo013oo`3oMol0D_l2o`0Xo`04o`3`ool0C?oo04coo`2^o`?o02ko2Ooo
ool3o`0^o`Kooooo0ol0l?l2ooooo`?o04co0_ooool2o`3Ho`;o0?lX1_ooool2o`0Xo`Cooooo0ol0
i?l2ooooo`;o0?ld0oooool3o`23o`04o`3oMol0D_oo05;oo`1Bo`?o013o00Coooooo`3oFOl0m_oo
0?Ko3?ooool4o`3o>POooooo1?l0ob85ooooo`?o0>[o1Ol0Jol00ol0ROooooooooooo`0gooooo`04
o`29ool0Jooo06_oo`1[o`;o0>[o0oooool2o`3o8P03ooooool0oc[ooooo00Kooooo0_l0oeT7oooo
o`03o`1Bool04?oo08?o00;ooooo00_o0?mgoooooooooooo0?lXo`3o=?l0i?oo02Soooooool0ofGo
ooooo`3o2P04ooooo`04o`3oUOoooooo04coo`3Ho`;ooooo00?oGOl0of?o0?ooool00_ooool00ol0
;_ooooooooooo`03ooooo`07ocSo0?oooooo9P3oooooool0@?ooooooo`0:o`04ooooo`;o6P3o00Go
0?nKooooooooooooooooo`3oJ`02ooooo`;o07go00?o0?o`ooooooooool02_mG0?l8ooooo`;o07go
00Coooooo`3ol?l0oo3o0?o`0_lJ0?l00ol0of_oooooooooo`04ooooo`03o`3oVol02_oo00[o00?o
oooo00?o043ooooooolho`002_ooool2obH0o`Cooooo0_mSo`02ooooo`03oego0?oooooooooo00Ko
oooo00?o0?3oooooooooool04Oooool00ol0f?ooooooooooo`02o`3oUAKooooo0ol0ofD>ooooo`03
o`3ol?oooooooooo00Co0>Co00?o9P3oooooooooool01Oooool3o`3o:005o`0dool0obSo0?lXo`3o
:?l0od`04_l0obP00omG0?ooooooocko000;ooooo`04ocSo0?ooooooJ@3oo`3o2Pgooooo0_mMo`00
0omSo`3oooooooooo`0Xooooo`006_ooool00ol0003oooooooooo`0`ooooo`08o`1Iool0Jooo0?Ko
o`0@ool0ogOo05;oooooool0:?l2o`3`o`04o`1<ool0[_oo0?mUo`3oI@Wo02ko1oooool2o`3`o`?o
oooo0_l0C?l2ooooo`04o`3oIOl0f?oo0=Soo`3o:0Kooooo0ol0:?l4ooooo`;o0>Co0_ooool3o`3o
=0;ooooo0ol0Pol01Ol0ogOo05;oo`1Bool0D_oooooo00;o013o00?oooooo`3oFOl0m_l00_l0m_l:
ooooo`Co0?lj2?ooool3o`3o8PCooooo0ol0j_l5o`1[o`03o`29oooooooooooo03oooooo00Co08Wo
o`1[ool0Jooo06_o0_l0j_l2ooooo`;o0?lR0_l0ocX7ooooo`03o`3oFOoooooooooo00Gooooo00?o
05;oo`0@ool0Pol00_ooool02ol0ogOoooooooooool0obSo0>Coooooool0:?ooooooo`3oIOoooooo
0?l:00Cooooo00Co0?nEooooool0C?oo0=So0_ooool01_mMo`3oHol0oooooooooooo0?3oo`0^o`Co
oooo00Go>?l0oooooooooooo9P3oo`10o`02ooooo`03o`0:oooooooooooo00?ooooo00?o6P3oo`3o
Voooool00_ooool2o`3oJ`;ooooo00?o07goo`3ol?l0oo000_l0oo0=ooooo`?o07go0ol0oo000ooo
oooo6P3ooaX0o`08ooooo`03o`3oVol02_oooooo00;ooooo0_l0@?l00ooooooo>?l0ooooo`09oooo
o`03obH0oooooooooooo00?ooooo00?oHol0ooooooooool00_mMo`08ooooo`03o`3`oooooooooooo
013ooooo0_l0f?l2o`3o2P03o`3oUOoooooooooo01Cooooo0_l0ofD@ooooo`Co0>Co0_ooool2o`3o
:003obH0ool0obSo0?lX00Go0?lX1?ooool01?l0=?ooooooooooool0od`Cooooo`03oeL0ool0obSo
0?lX00Oo0?lX1?ooool00olho`3oJ@3oooooo`02o`3o2Pgooooo0_mMo`000omSo`3oooooooooo`0V
ooooo`006_ooool00ol0003oooooooooo`0`ooooo`08o`2Kool0FOoo06_oo`3oD_l04?oo0?mgo`1B
ooooool2o`0Xo`05ooooool0C?oo04coo`1<ool0[_l00ol0obP9ooooo`?o0?3o0_l0oiD3o`1<o`03
o`3o:?l0ofGo0=So00;o0=So1_ooool3o`0Xo`Cooooo0ol0i?l2ooooo`;o0?ld0oooool2o`23o`04
o`3oMol0D_oo05;oo`1Bo`;ooooo0_l04?l01?l0oeWo0?Koo`3fool0m_l9ooooo`Co0?lj2?ooool4
o`3o8PCooooo0_l0j_l4o`1[o`03o`29oooooooooooo013ooooo7_l0oe8Iooooo`05o`29ool0Jooo
06_oo`1[ool0j_l00_ooool2o`3o8P;o0?lj1_ooool2o`3oF@Kooooo00?o05;oo`0@ool0Pol00_oo
ool02?l0ogOoooooo`3o:?oooooo0>Coo`0Xoooooooo0?mU0_ooool00ol0o`[oooooooooo`02oooo
o`03o`3oUOl0C?oo0=So00;ooooo00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`03oooo
o`07ocSo0?ooooooooooobH0ool0@?ooooooo`0:o`06ooooo`03oaX0ool0oi_ooooo00?ooooo00?o
0?m[ooooooooool00ol0OOl00ooooooo0?o`o`3ol007ooooo`Co07go0ol0oo02ooooo`;o6P3o2?oo
ool2o`3oV`05o`0:ooooooooooooooooool0@?l00_ooool00olho`3oooooooooo`08ooooo`03obH0
oooooooooooo00?ooooo00CoHol0ooooooooooooGOl02Oooool00ol0l?ooooooooooo`0@ooooo`05
o`3Hool0o`[o0?l:ooooool0oiD05?ooool3o`3oI@gooooo0_l0obP3o`3To`;o0?lX00Co0?o`o`3o
:?l0obSo0?lX0oooool00olV0?ooooooooooo`08ooooo`05o`0dooooooooooooooooool0od`04_oo
ool01?mG0?oooooooooooolno`06ooooo`Ko0?lX00?oJ@3oooooooooool00ol0o`X<ooooo`03oego
0?mSo`3oHol002Kooooo000Jooooo`03o`000?oooooooooo037ooooo00Oo09_oo`1Iool0Jooo0?mB
o`0@ool0ogOo05;o00;ooooo0ol0:?l00ooooooo04coo`1<o`03o`1<o`03o`2^ool0l?oo0?3o00;o
0?3o00?o0:koo`1<ool0C?l01Ol0C?l3o`3oI@;o0=So1_ooool3o`0Xo`Gooooo0_l0i?l3ooooo`;o
0?ld0oooool2o`23o`03o`3oMol0D_oo05;o00;ooooo0ol04?l00ol0oeWo0?Koo`3fo`09ooooo`?o
0?lj2?ooool4o`3o8PGooooo0_l0j_l3o`1[o`03o`29oooooooooooo00[ooooo2_l0oe82oooooago
0?oB1_l0oe8Eooooo`04o`29ool0Jooo06_oo`3Zo`;ooooo0_l0ob82o`3o>PKooooo00?o0?mIoooo
ooooool01?ooool00ol0D_oo013oooooo`02ooooo`0:o`3oMooooooo0?lXooooool0i?oo02Sooooo
ool0ofGoooooo`3o2PCooooo00Co0?nEooooool0C?oo0=So0_ooool01_mMo`3oHol0oooooooooooo
0?3oo`0^o`Gooooo00Oo>?l0oooooolV0?ooooooo`10oooooooo00[o00Kooooo00?o6P3oo`3oVoln
o`000oooool2o`3oJ`;ooooo2ol0OOl4o`3ol0?ooooo0_lJ0?l9ooooo`03o`3oVol02_oo00[o00?o
oooo00Co043ooooooolho`3o>?l02Oooool2obH0o`Cooooo0_mSo`02ooooo`03oego0?oooooooooo
00Oooooo00?o0?3oooooooooool04?ooool00ol0f?oo0?l:ooooo`02o`3oU@?ooooo2ol0;_l5oooo
o`;o0?mU3Oooool2o`3o:0?o0>Co1Oooool00ol0oo3oooooooooo`04ooooo`03obH0oooooooooooo
00Sooooo00Go03Coooooooooooooooooo`3oC00Booooo`05oeL0oooooooooooooooooolno`002ooo
ool00omY0?oo0?lXo`3o:002o`3o:003ooooool0o`[o0?l:00_ooooo0_mMo`03of?o02?ooooo000J
ooooo`03o`000?oooooooooo03;ooooo00Ko05Woo`29ool0Jooo0?mBo`0@ool0ogL2o`1Bo`03oooo
ool0f?oo0=So00?o02So0_ooool7o`1<o`Go0?mU0_ooool3o`3Ho`Cooooo1?l0:?l5ooooo`?o0>Co
0_ooool3o`3o=0?ooooo0_l0Pol3o`1Bo`;ooooo0_l04?l01?l0oeWo0?Koo`3fool0m_l8ooooo`?o
0?lj2?ooool3o`3o8PKooooo00?o0>[oo`1[ool0Jol00_l0Jol00ol0ROooooooooooo`08ooooo`Go
0?mB1_ooool6o`3odQgooooo1ol0om85o`3oDQ7ooooo00Co08Woo`1[ool0Jooo0>[o0_ooool01?l0
ob;oooooo`3o>_l0ocX5ooooo`03o`3oFOoooooooooo00Cooooo00Go05;oo`0@ooooooooooooo`3o
M`02ooooo`08o`3o:?l0i?ooooooo`0Xoooooooo0?mUooooool0o`X4ooooo`03o`3oUOl0C?oo0=So
00;ooooo00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`03ooooo`08ocSo0?oooooooooo
obH0oooooooo043oooooool02_l6ooooo`03oaX0ool0oi_o?_l000Cooooo00?o0?m[ooooooooool0
3oooool2oaX0o`Wooooo0_l0oi/01?l02_ooooooooooooooool2o`10o`03oooooolho`3ooooo00Wo
oooo00?o9P3oooooooooool00oooool00omSo`3oooooooooo`02oego00Wooooo00?o0?3ooooooooo
ool03oooool2o`3Ho`;ooooo1_l0;_l;ooooo`Co02ko00?o0?mUooooooooool02?ooool4o`3o:0?o
0>Co2Oooool00ol0oo3oooooooooo`04ooooo`03obH0oooooooooooo00Sooooo00Go03Cooooooooo
ooooooooo`3oC00Booooo`05oeL0oooooooooooooooooolno`002oooool01?mY0?oo>?l0oooooooo
ool6o`3o:0[ooooo0_mMo`001?ooooooHol0of?o0?mSo`0Pooooo`006_ooool00ol0003ooooooooo
o`0cooooo`05o`1Iool0ROoo06_oo`3oD_l04?l00_l0ogL2o`1Bo`;ooooo0_l0f?l00ol0:?oooooo
ooooo`0:ooooo`?o0=So0oooool4o`0Xo`Kooooo0ol0i?l3ooooo`;o0?ld1?ooool2o`23o`;o05;o
0oooool2o`0@o`?o0?Ko2?ooool3o`3o>PSooooo0ol0ob86ooooo`Co06_o0_l0ROl7ooooo`Ko0?mB
0_ooool9o`3odPCooooo8Ol0c?l5ooooo`Go0?oB1?l0oe8@ooooo`04o`1[ool0ROoo0>[oooooo`;o
0?lR00?oooooo`3o>_ooool01?ooool00ol0oeWoooooooooo`03ooooo`03o`1Boooooooo013o00;o
oooo00Ko0?mgoooooooooooo0?lXo`3Tool0:?l2ooooo`03o`3oIOoooooo0?l:00?ooooo00Co0?nE
ooooool0C?oo0=So0_ooool01_mMo`3oHol0oooooooooooo0?3oo`0^o`Gooooo00So>?l0oooooooo
oooo9P3oooooool0@?ooooooo`0:o`Kooooo0_lJ0?l2ocko00?ooooo0_l0of/<ooooo`04o`3oJolJ
0?oo6P3oo`3oJ`Wooooo00?o0?nKooooool02_l00oooool01?l0@?oooooooooooolho`09ooooo`;o
9P3o1?ooool2of?o00;ooooo00?oGOl0ooooooooool02?ooool00ol0l?ooooooooooo`0>ooooo`03
o`3o2_l0f?oooooo00?o02ko4_ooool2o`3oI@04ooooool0;_oo02koo`0^o`Cooooo1?l0obP01?oo
oooo0>Coo`3Tool0i?l<ooooo`03o`3ol?oooooooooo00Cooooo00?o9P3oooooooooool02?ooool0
0ol0=?ooooooooooo`02ooooo`03o`3oC?oooooooooo00oooooo00?oE`3oooooooooool00_ooool0
0olno`3oooooooooo`09ooooo`03ofT0oolho`3ooooo00Gooooo00?o0?l:o`3o:?l0obP01Ol0obP5
ooooo`;oGOl00_ooool2of?o01kooooo000Jooooo`03o`000?oooooooooo03?ooooo00Go09_oo`1I
ool0ROoo06_oo`3oDP02o`0@o`03o`3oMol0ocCo05;o00?ooooo00?o0=Soo`0Xool0:?l00ol0:?l7
o`3Ho`03ooooool0:?oo02So00?o02So1oooool3o`3To`?ooooo0ol0oc@4ooooo`;o08?o0_l0D_l2
ooooo`?o013o0_l0m_l8ooooo`?o0?lj2?ooool3o`3o8PGooooo1?l0Jol3o`29o`Cooooo1_l0oe88
o`3odP?ooooo0_l0oh<8o`3<o`?o0?n35Oooool9o`3oP`So0<co0_ooool5o`3odP;o0?mB3_ooool2
o`1[o`05o`29ool0j_ooooooo`3o8_ooool00_l0ocX4ooooo`03o`3oFOoooooooooo00?ooooo00?o
05;oooooool04?l00_ooool02_l0ogOoooooo`3o:?oooooo0>Coo`0Xoooooooo0?mUooooool0o`X4
ooooo`07o`3oUOoooooo04coo`3HooooooooGOl0of?o0003ooooo`03o`0^oooooooooooo00?ooooo
00Co>?l0oooooooooooo9P3o0_ooool00ol0@?ooooooo`0:o`07ooooo`?o6P3o00Co?_l0oooooooo
oooooooo2_l0of/3oaX0o`[ooooo0_l0oi/2o`0:o`?ooooo00Co043ooooooooooooo>?l02Oooool0
0olV0?ooooooooooo`03ooooo`03of?o0?oooooooooo00;oGOl02Oooool2o`3`o`oooooo0_l0o`X3
o`0^o`03ooooool0oiGooooo013ooooo0_l0ofD6ooooo`;o02ko0_l0obP2ooooo`?o0>Co4?ooool0
0ol0oo3oooooooooo`04ooooo`03obH0oooooooooooo00Sooooo00Go03Coooooooooooooooooo`3o
C00Booooo`03oeL0oooooooooooo00;ooooo00?o?_l0ooooooooool02?ooool00omY0?ooooooocSo
0008ooooo`;o0?l:0oooool5o`3o:0;ooooo0omMo`001?ooooooHol0of?o0?mSo`0Kooooo`006_oo
ool00ol0003oooooooooo`0dooooo`04o`1Iool0c?oo08Woo`1[o`;o0?mB0_l04?l01?l0ocCo05;o
o`1Bool0i?l6ooooo`So02So2_ooool2o`3To`?ooooo0ol0oc@3ooooo`?o08?o0ol0D_l01?oooooo
013oo`0@ool04?l3o`3fo`Oooooo0ol0ocX8ooooo`?o0?lR1Oooool3o`1[o`04o`3Zool0ROoo08Wo
o`29o`;ooooo1Ol0oe82ooooo`Co0?oB1Oooool3o`3oP`Go0<co;?ooool5o`3oP`Co0<co0oooool3
o`3odP?o0?mB3?ooool2o`1[o`06o`29oooooooo0?lRo`3o8_oooooo0?lj1?ooool00ol0oeWooooo
ooooo`03ooooo`03o`1Bool04?oo08?o00;ooooo00[o0?mgooooool0obSo0?ldo`3Tool0:?oooooo
o`3oIOoooooo0?l:0oooool01?l0oiGoooooo`1<ool0f?l2ooooo`03oego0?mSo`3ooooo00;ooooo
00?o02koooooooooool00oooool01?lho`3ooooooooooolV0?l2ooooo`04o`10oooooooo00[oo`0:
o`Kooooo00?o0?nKoooooolJ0?l00_lJ0?l3ocko00;ooooo0_lno`04oaX0o`[ooooo0ol0oi/2o`0:
o`?ooooo0_l0@?l00ooooooo>?l0ocSo0008ooooo`;o9P3o1Oooool01?mSo`3ooooooooooomMo`0:
ooooo`03o`3`oooooooooooo00kooooo00?o0?l:o`0^ool0;_l00_ooool2o`3oUA3ooooo0_l0ofD6
ooooo`?o0?lX00?oooooo`0^ooooool00_l0i?lCooooo`03o`3ol?oooooooooo00Cooooo00?o9P3o
ooooooooool02?ooool00ol0=?ooooooooooo`02ooooo`03o`3oC?oooooooooo00oooooo00?oE`3o
ooooooooool00oooool00olno`3oooooooooo`08ooooo`04ofT0oooooooo>?l0ocSo00Sooooo0_l0
o`X6ooooo`Go0?lX0_mMo`02ooooo`?oHol06?ooool001[ooooo00?o0000ooooooooool0=Oooool0
2?l0FOoo0<coo`29ool0Jooo0?n3o`3oD_l0m_oo013o0_l0oc@01?l0D_oo0>Coo`3Tool0i?lBoooo
o`?o0>Co0_ooool3o`3o=0;ooooo1?l0Pol3o`1Bo`05o`3oMol04?oo013oo`0@ooooool00_l0m_l7
ooooo`?o0?lj2?ooool3o`3o8PGooooo0ol0Jol01Ol0j_oo08Woo`29ool0ROoooooo00Co0?mB0ooo
ool4o`3odP?ooooo0ol0oh<6o`3<ocKooooo0ol0oh<00ooooooo0<coo`3<o`02o`3<o`;ooooo0ol0
om83o`3oDP_ooooo0_l0Jol01?l0ROooooooo`3o8_ooool2o`3o>P?ooooo00?o0?mIooooooooool0
0oooool01Ol0D_oo013oo`3foooooooo0?mg00;ooooo00?o0?lXo`3Tool0:?l00_ooool00ol0ofGo
0?l:ooooo`03ooooo`04o`3oUOoooooo04coo`3Ho`;ooooo00GoGOl0of?o0?ooooooooooo`0^o`06
ooooo`04ocSo0?ooooooooooobH0o`;ooooo00Co043ooooooooooooo00[o1_ooool3o`3oV`So6P3o
3?ooool2o`3oV`03ooooool02_oo00[o00Cooooo00Co043ooooooooooooo>?l02Oooool00olV0?oo
ooooooooo`04ooooo`04of?o0?oooooooooooego00[ooooo00?o0?3oooooooooool03Oooool01?l0
o`[o02koo`0^ool0f?l2ooooo`03o`3oUOoooooooooo00gooooo0ol0ofD5ooooo`?o0?lX1?ooool0
0ol0i?oo02koooooo`0Eooooo`03o`3ol?oooooooooo00Cooooo00?o9P3oooooooooool01oooool0
0ol0=?ooooooooooo`02ooooo`03o`3oC?oooooooooo013ooooo00?oE`3oooooooooool00oooool0
0olno`3oooooooooo`07ooooo`04ofT0ooooooooooooooooo`;o>?l02?ooool3o`3o2PSooooo1Ol0
obP2ooooo`;oHol05_ooool001[ooooo00?o0000ooooooooool0=Oooool02?l0Vooo05Woo`3<ool0
c?oo06_oo`3oPol0oe;o0?Ko0_l04?l01?l0ogOo05;oo`1Bool0D_l5o`3To`Oooooo1_l0i?l00ooo
oooo0?ldo`3o=002o`3o=0;ooooo0ol0Pol4o`1Bo`04o`3oMol04?oo013oo`0@o`;ooooo0_l0m_l6
ooooo`?o0?lj2?ooool3o`3o8PGooooo0ol0Jol01?l0j_oo08Woo`29ool0ROl4o`3oDPCooooo0ol0
om82ooooo`?o0?n31Ol0c?l@ooooo`So0?o<5Ol0ooH6o`3oc0cooooo1?l0oh<01?oooooo0<coo`3<
ool0c?l2ooooo`?o0?oB0_l0oe8;ooooo`;o06_o00Goooooo`3o8_l0ob;oooooo`3o>P03ooooo`03
o`3oFOoooooooooo00?ooooo00Go05;oo`0@ooooooooooooo`3oM`02ooooo`03o`3o:?l0i?oo02So
00;ooooo00?o0?mUo`3o2_ooool00_ooool01?l0oiGoooooo`1<ool0f?l2ooooo`03oego0?mSo`3o
oooo00;ooooo00?o02koooooooooool00oooool01?lho`3ooooooooooolV0?l3ooooo`04o`10oooo
ooooooooo`0:o`Sooooo0ol0oi/?ooooo`;o0?nK0_ooool00ol02_ooooooooooo`03ooooo`04o`10
ooooooooooooocSo00Sooooo0_lV0?l6ooooo`04of?o0?oooooooooooego00[ooooo00?o0?3ooooo
ooooool03?ooool01?l0o`[o02koo`0^ool0f?l3ooooo`03o`3oUOoooooooooo00cooooo0_l0ofD5
ooooo`?o0?lX1Oooool2o`3To`03ooooool0;_oooooo01Gooooo00?o0?o`ooooooooool01?ooool0
0olV0?ooooooooooo`08ooooo`03o`0doooooooooooo00;ooooo00?o0?m<ooooooooool03oooool0
0omG0?ooooooooooo`04ooooo`03ocko0?oooooooooo00Oooooo00?oJ@3oooooooooool00_ooool2
ocSo00Wooooo0_l0o`X;ooooo`Co0?lX0omSo`0Cooooo`006_ooool00ol0003oooooooooo`0foooo
o`07o`2Kool0FOoo05Woo`3<ool0Jooo0?n3o`3oDP02o`3fo`04o`0@ool0ogOo0?mgo`3oM`?o05;o
00?o0?ldooooool0i?l01_l0i?l4ooooo`?o0?ld0oooool3o`23o`?o05;o0_l0ogL3o`0@o`;ooooo
0ol0m_l5ooooo`?o0?lj2?ooool3o`3o8PGooooo0ol0Jol01?l0j_oo08Woo`29ool0ROl3o`3oDPCo
oooo1?l0om83o`3oP`Go0<co2_ooool4o`3oc0oo0?of5Oooool7o`3omPGo0?o<2_ooool4o`3oP`?o
0<co0_ooool3o`3odP;o0?mB2_ooool01_l0Jooo08Woooooool0ob;oooooo`3o>P;ooooo00?o0?mI
ooooooooool01?ooool01Ol04?oo08?ooooooooooooo0?mg00;ooooo00Oo0?ldo`3Tool0:?oooooo
o`3oIOoooooo0?l:00?ooooo00Co0?nEooooool0C?oo0=So0_ooool01_mMo`3oHol0oooooooooooo
0?3oo`0^o`Gooooo00Co>?l0oooooooooooo9P3o0oooool01?l0@?ooooooooooool02_l:ooooo`;o
0?nK2_ooool3o`3oV`;ooooo0_l02_l4ooooo`;o043o0_ooool00olho`3oooooooooo`06ooooo`03
obH0oooooooooooo00Gooooo00CoHol0ooooooooooooGOl02_ooool00ol0l?ooooooooooo`0;oooo
o`05o`3o2_l0;_oo02koooooool0f?l00_ooool2o`3oU@gooooo0_l0ofD4ooooo`?o0?lX1_ooool2
o`3To`Cooooo00?o02koooooooooool04oooool00ol0oo3oooooooooo`05ooooo`03obH0oooooooo
oooo00Oooooo00?o03Coooooooooool00_ooool00ol0odcoooooooooo`0@ooooo`03oeL0oooooooo
oooo00Cooooo00?o?_l0ooooooooool01oooool00omY0?ooooooooooo`03ooooo`;o>?l02Oooool2
o`3o2P_ooooo0_mMo`05o`3o:003of?o0?oooooooooo00kooooo000Jooooo`?o0000=oooool01_l0
Vooo0:7oo`1Iool0c?oo06_oo`3oP`;o0?mB00Co0?Koo`0@ool04?oo013o0ol0ogL5o`1Bo`So08?o
2Ol0D_l00ol0ogOo013oo`0@o`02o`0@o`?ooooo0_l0m_l5ooooo`?o0?lj2?ooool3o`3o8PGooooo
0ol0Jol01?l0j_oo08Woo`29ool0ROl2o`3oDPCooooo1?l0om83o`3oP`Co0<co1oooool7o`3oc0Go
0?of:oooool6o`3omPCo0?o<2_ooool2o`3oP`?o0<co0_ooool3o`3odP03o`3oD_oooooooooo00Oo
oooo0_l0Jol01?oooooo0?lRooooool0ocX2ooooo`03o`3oFOoooooooooo00Cooooo00Wo013oo`23
ooooooooooooo`3oMooooooo0?lXo`3Tool0:?l00_ooool00ol0ofGo0?l:ooooo`03ooooo`03o`3o
UOl0C?oo0=So00;ooooo00?oGOl0of?o0?ooool00_ooool00ol0;_ooooooooooo`04ooooo`04ocSo
0?ooooooooooobH0o`?ooooo0_l0@?l00ooooooo00[oooooo`0:ooooo`[o0?nK0oooool2o`0:o`Co
oooo0_l0@?l3ooooo`03ocSo0?oooooooooo00Gooooo0_lV0?l6ooooo`;oHol000?ooooooego0?mM
o`002_ooool00ol0l?ooooooooooo`0;ooooo`;o02ko00?oooooo`3Hool0f?l00_ooool00ol0oiGo
ooooooooo`0;ooooo`;o0?mU1?ooool2o`3o:0Oooooo0_l0i?l7ooooo`03o`0^oooooooooooo01?o
oooo00?o0?o`ooooooooool01?ooool00olV0?ooooooooooo`07ooooo`03o`0dool0Pooo08?o00oo
08?o1_ooool00omG0?ooooooooooo`05ooooo`;o?_l01oooool00omY0?ooooooooooo`05ooooo`;o
>?l02Oooool3o`3o2P_ooooo0_mMo`02ooooo`;o0?lX3oooool001[ooooo00?o0000ooooooooool0
>?ooool01Ol0Vooo0:7oo`1Iool0FOoo06_o00;o0?n300Co0?mBo`3fool0m_oo0?Ko0ol04?l3o`3o
M`03ooooool0oeWo05;o00Oo05;o0ol0oeT3o`3oM`Co013o1?ooool3o`3fo`Cooooo0ol0ocX8oooo
o`?o0?lR1Oooool3o`1[o`05o`3Zool0ROoo08Woo`29ool0oe801?ooool4o`3odP?o0?n31?l0c?l6
ooooo`Go0?o<00?oooooo`3om_l0ooH01?l0ooH=ooooobKo05Wo0oooool6o`3omP?o0?o<2?ooool2
o`3oP`;o0<co0oooool2o`3odP[ooooo00Go06_oo`3Zool0ob;oooooo`3o>P02ooooo`03o`3oFOoo
oooooooo00?ooooo00?o05;oo`0@ool0Pol00_ooool02Ol0ogOoooooo`3o:?l0i?oo02Soooooool0
ofGoooooo`3o2P03ooooo`04o`3oUOoooooo04coo`3Ho`;ooooo00KoGOl0of?o0?ooooooooooo`3`
ool0;_l6ooooo`;o>?l000?o9P3oooooooooool00oooool00ol0@?ooooooo`0:o`02o`0:oa?ooooo
0_l02_l5ooooo`04o`10ooooooooooooooooo`;o>?l01oooool00olV0?ooooooooooo`05ooooo`04
of?o0?oooooooooooego00_ooooo00?o0?3oooooooooool02_ooool2o`0^o`;ooooo00Go0=Sooooo
ooooooooooooo`3oU@0=ooooo`03o`3oIOoooooooooo00;ooooo0_l0obP7ooooo`;o0>Co2_ooool0
0ol0;_ooooooooooo`0Booooo`03o`3ol?oooooooooo00Co08?o00?o9P3oo`23ool0Pol01ol0Pol0
0ooooooo03Coooooo`03ooooo`03o`3oC?oooooooooo00Wooooo1ol0Pol01?mG0?oo08?oo`23ool0
Pol5ooooo`03ocko0?oooooooooo00Gooooo00?oJ@3oooooooooool01_ooool2ocSo00[ooooo0ol0
o`X:ooooo`?oGOl04?ooool001[ooooo00?o0000ooooooooool0>Oooool01?l0Vooo0:7oo`3o^_l0
FOl2o`1[o`04o`3oPol0oe;o0?mBooooo`?o0?Ko1Ol04?l8o`3oM`Ko013o1?ooool4o`3fo`;ooooo
1Ol0ocX7ooooo`Co0?lR1Oooool3o`1[o`04o`3Zool0ROoo08Woo`29o`Cooooo1?l0om83o`3oP`Co
0<co1Oooool5o`3oc0Ko0?of2?ooool;o`1Io`?o0?nj7_ooool5o`3o^PGo05Wo1?ooool4o`3omP;o
0?o<1oooool2o`3oP`?o0<co0_ooool00ol0om;o0?mBooooo`08ooooo`05o`1[ool0j_oo0?lRoooo
ool0ocX00_ooool00ol0oeWoooooooooo`03ooooo`05o`0@ool0m_oo08?oooooool0ogL00_ooool0
1_l0ocCo0>Coo`0Xoooooooo0?mUo`3o2PCooooo00?o0?nEo`1<ool0f?l00oooool01OmMo`3ooooo
oooooooooooo02ko00Sooooo00?o>?l0obH0ooooool01?ooool2o`10o`;ooooo0_l02_l>ooooo`?o
00[o1Oooool2o`10o`;ooooo0_lho`07ooooo`;o9P3o1oooool01?mSo`3ooooooooooomMo`0:oooo
o`;o0?3o3?ooool01Ol0;_oo0?l:oooooooooooo0=So00?ooooo00?o0?nEooooooooool02_ooool2
o`3oI@;ooooo0ol0obP7ooooo`;o0>Co3Oooool00ol0;_ooooooooooo`0?ooooo`Go08?o1Oooool0
0olV0?ooooooooooo`07ooooo`03o`0doooooooooooo00?ooooo00?o0?m<ooooooooool03oooool0
1?mG0?ooooooooooooooool5o`23o`03oooooolno`3ooooo00Kooooo00?oJ@3oooooooooool01ooo
ool2ocSo00_ooooo0_l0o`X;ooooo`03oego0?oooooooooo00gooooo000Jooooo`03o`000?oooooo
oooo03[ooooo00Wo09_oo`2Qool0ok[o05Woo`29ool0Jooo0?oBo`3oPol0oe800oooool3o`3fo`;o
oooo2?l04?l6ooooo`Co0?Ko00?oooooo`3o>_l0ocX00ol0ocX8ooooo`Co0?lR1_ooool3o`1[o`04
o`3Zool0ROoo08Woo`29o`?ooooo1?l0om83o`3oP`Co0<co1Oooool4o`3oc0Go0?of2Oooool5o`1I
o`;ooooo1_l0okX[ooooo`?o0?nj0ol0FOl5ooooo`?o0?of0_l0ol`6ooooo`03o`3oPooooooooooo
00;o0<co00?oooooo`3od_l0om802Oooool01?l0Jooo0>[oo`3o8_l0ocX3ooooo`03o`3oFOoooooo
oooo00;ooooo00?o05;oo`0@ool0Pol00_ooool02Ol0ogOoooooo`3o:?l0ocCo02Soooooool0ofGo
ooooo`3o2P03ooooo`04o`3oUOoooooo04coo`3Ho`;ooooo00KoGOl0of?o0?ooooooooooo`3`ool0
;_l8ooooo`03ocSo0?lV0?oooooo00Gooooo00Co043ooooooooooooooooo0ol02_l7ooooo`Co00[o
1_ooool2o`10o`;ooooo0_lho`08ooooo`03obH0oooooooooooo00Kooooo00CoHol0oooooooooooo
GOl02_ooool00ol0l?ooooooooooo`0:ooooo`;o02ko00Co0?l:oooooooooooo0=So0_ooool2o`3o
U@cooooo00?o0?mUooooooooool00_l0obP8ooooo`;o0>Co4?ooool00ol0;_ooooooooooo`0:oooo
o`Co08?o0oooool00ol0oo3oooooooooo`04ooooo`03obH0oooooooooooo00Sooooo00?o03Cooooo
ooooool00_ooool00ol0odcoooooooooo`0@ooooo`03oeL0oooooooooooo00Gooooo1_l0Pol4oooo
o`03ofT0oooooooooooo00Sooooo0_lho`0;ooooo`?o0?l:6?ooool001[ooooo00?o0000oooooooo
ool0>oooool00ol0Vooo0:7oo`3o^P02o`1Io`?o06_o0_l0oe801?l0ob;oooooooooool0ocX@o`3f
o`Go0?lj2_ooool3o`3o8PKooooo1?l0Jol01?l0j_oo08Woo`29ool0ROl3ooooo`?o0?oB0_l0oh<0
0ooooooo0<coo`3<o`02o`3<o`Gooooo1?l0ol`4o`3omPSooooo1_l0FOl00ooooooo0?njo`3o^P04
o`3o^SKooooo00?o0?njo`1Iool0FOl00_l0FOl4ooooo`;o0?of0ol0ol`4ooooo`;o0?n30_ooool0
1Ol0c?ooooooooooool0om;o0?mB00Oooooo00Go06_oo`29ool0j_oo0?lRo`3o>P03ooooo`03o`3o
FOoooooooooo00;ooooo00Go05;oo`0@ool0Poooooooo`3oM`02ooooo`07o`3o=?l0i?oo02Sooooo
ool0ofGoooooo`3o2P03ooooo`04o`3oUOl0[_oo04coo`3Ho`;ooooo00GoGOl0of?o0?oooooooooo
o`0^o`09ooooo`03ocSo0?lV0?oooooo00Gooooo0_l0@?l4ooooo`Oo00[o2?ooool2o`10o`?ooooo
00?o>?l0ooooooooool01_ooool2obH0o`Sooooo00CoHol0ooooooooooooGOl02_ooool00ol0l?oo
ooooooooo`0:ooooo`04o`0^ool0o`[oooooooooo`;o0=So0_ooool00ol0oiGoooooooooo`0:oooo
o`;o0?mU00?oooooo`3o:?l0obP02Oooool00ol0i?ooooooooooo`06ooooo`go02So1oooool3o`23
o`Sooooo00?o0?o`ooooooooool01?ooool00olV0?ooooooooooo`07ooooo`03o`0doooooooooooo
00?ooooo00?o0?m<ooooooooool02oooool4o`3oF@03oeL0ool0oeWo0?mI00_o0?mI1?l0Pol00omY
0?oo0?mIo`3oF@0Lo`3oFACooooo000Jooooo`03o`000?oooooooooo03cooooo00Go09_oo`2Qool0
ok[o0?njo`1Io`02o`29o`?o06_o0_l0oe86ooooo`Wo0?lj3?ooool5o`3o8PCooooo1Ol0Jol00ol0
j_oo08Woo`29o`02o`29o`;ooooo1?l0om800ol0oh?oooooo`3<o`03o`3<o`Gooooo1?l0ol`01?oo
oooo0?ofo`3om_l0ooH7ooooo`Go05Wo00?oooooo`3o^_l0okX01?l0okXLooooo`Oo0?mm7_ooool5
o`1Io`04ooooool0ooKo0?ofo`3omP;o0?o<1?ooool3o`3oP`;o0<co00?oooooo`3od_l0om801ooo
ool01Ol0Jooo08Woo`3Zool0ob;o0?lj00?ooooo00?o0?mIooooooooool00_ooool03Ol04?oo0?Ko
o`23oooooooo0?mgooooool0obSo0?ldo`0Xoooooooo0?mUooooool0o`X00oooool01?l0oiGooooo
o`1<ool0f?l3ooooo`05oego0?ooooooooooooooool0;_l02Oooool00olho`3o9P3oooooo`06oooo
o`03o`10oooooooooooo00kooooo0_l0@?l3ooooo`;o>?l02?ooool00olV0?ooooooooooo`07oooo
o`04of?o0?ooooooGOl0oego00[ooooo00?o0?3oooooooooool02Oooool2o`0^o`04o`3o2_oooooo
ooooo`3Ho`?ooooo00?o0?nEooooooooool02_ooool01?l0ofGoooooooooool0obP9ooooo`;o0>Co
0oooool6o`0Xo`cooooo00?o02koo`0Xool0:?l00ol0:?l2o`23o`_ooooo00?o0?o`ooooooooool0
1?ooool00olV0?ooooooooooo`07ooooo`03o`0doooooooooooo00?ooooo3_l0oeT5ooooo`03oeL0
oooooooooooo00Wooooo00?o?_l0ooooooooool00oooool01?mY0?oo08?oo`23ool0Pol9ooooo`?o
>?l03?ooool2o`3o2PGo0?mI3oooool001[ooooo00?o0000ooooooooool0?Oooool01ol0Vooo0:7o
o`2Qool0ok[o05Woooooool0c?l00_l0ROl2o`1[o`?o0?mB5?ooool4o`3o8PGooooo1?l0Jol00ol0
j_oo08Woo`29o`03o`29o`;ooooo1?l0om800ol0oh?oooooo`3<o`03o`3<o`Cooooo1Ol0ol`00ooo
oooo0?ofo`3omP02o`3omPGooooo1Ol0FOl6o`3o^Q?ooooo3ol0ogd7ooooo`ko0?mm4oooool2o`3o
^P?o05Wo00Goooooo`3om_l0ooKo0?ofo`3oc005ooooo`;o0?n300Go0<cooooooooooooo0?oBo`3o
DP06ooooo`05o`1[ool0ROoo0>[oo`3o8_l0ocX00_ooool00ol0oeWoooooooooo`02ooooo`05o`1B
ool04?ooooooo`23ool0ogL00_ooool01ol0ocCo0>Coo`0Xoooooooo0?mUooooool0o`X00oooool0
1?l0oiGo0:koo`1<ool0f?l2ooooo`05oego0?mSo`3oooooooooool0;_l02_ooool00olho`3o9P3o
obH0o`06ooooo`Co043o2?ooool4o`10o`?ooooo0_lho`08ooooo`;o9P3o2Oooool00omSo`3ooooo
oego000;ooooo`03o`3`oooooooooooo00Wooooo00?o02koo`3o2_l0o`X00_ooool00ol0f?oooooo
ooooo`02o`3oU@_ooooo0_l0ofD00ooooooo0?lXo`3o:008ooooo`;o0>Co0_ooool3o`0Xoa7ooooo
0_l0Pol00ol0;_oo08?oooooo`02ooooo`?o02So2oooool00ol0oo3oooooooooo`04ooooo`03obH0
oooooooooooo00?ooooo1?l0oeT00ol0=?oo0?mIo`3oF@02o`3oF@03ooooool0odcooooo013ooooo
00?oE`3oooooooooool02_ooool00olno`3oooooooooo`03ooooo`03ofT0oooooooooooo00?o08?o
2Oooool3ocSo00cooooo0ol0o`X@ooooo`006_ooool00ol0003oooooooooo`0nooooo`;o09_o00Co
0:7oo`3o^_l0FOoooooo0_l0c?l00ol0ROoo0>[oo`1[o`02o`1[o`?o0?mB4Ol0ob86ooooo`?o06_o
00?o0>[oo`29ool0ROl00_l0ROl2ooooo`Go0?oB0_ooool4o`3<o`?ooooo1Ol0ol`00ooooooo0?of
o`3omP03o`3omPGooooo1?l0FOl5o`3o^Q7ooooo2?l0ogd5oooooako0:7o00?oooooo`3oOOl0ogd0
0ol0ogdAooooo`;o0?nj0_l0FOl2ooooo`?o0?of1Oooool01?l0oh?o0<coo`3<ooooool2o`3odPKo
oooo00Go06_oo`29ool0ob;oooooo`3o>P02ooooo`03o`3oFOoooooooooo00;ooooo00Go05;oo`0@
oooooooo08?oo`3oM`02ooooo`06o`3o=?l0i?oo02Soo`3oIOoooooo0?l:0oooool01?l0oiGooooo
o`1<ool0f?l3ooooo`05oego0?ooooooooooooooool0;_l02_ooool2ocSo0003obH0oooooooooooo
00Kooooo2Ol0@?l5ooooo`;o>?l02Oooool00olV0?ooooooooooo`07ooooo`;oHol000?ooooooego
0?ooool02_ooool00ol0l?ooooooooooo`08ooooo`;o02ko00Go0?l:ooooooooooooooooo`3Ho`02
ooooo`03o`3oUOoooooooooo00[ooooo00Co0?mUooooool0obSo0?lX2?ooool2o`3To`04ooooool0
:?oo02Soo`0Xoa7ooooo0ol0Pol2ooooo`03o`0^oooooooooooo00Gooooo0_l0:?l9ooooo`03o`3o
l?oooooooooo00Cooooo00?o9P3oo`3oFOl0oeT00ol0oeT4ooooo`03o`0doooooooooooo00?ooooo
00?o0?m<ooooooooool04?ooool00omG0?ooooooooooo`0:ooooo`03ocko0?oooooooooo00?ooooo
00?oJ@3oooooooooool00_ooool4o`23o`Sooooo0olho`0<ooooo`03o`3o2_oooooooooo00gooooo
000Jooooo`03o`000?oooooooooo043ooooo00Co09_oo`2Qool0olKo05Wo0_ooool00ol0c?oo08Wo
o`29o`02o`29o`;o06_o00?o0?n3o`3oD_l0oe802?l0oe800ooooooo0?mBo`3oDP07o`3oDP?o06_o
1?l0ROl6o`3odP?ooooo1?l0c?l3ooooo`Co0?o<00?oooooo`3om_l0ooH00ol0ooH6ooooo`Co05Wo
1?l0okX=ooooo`Wo0?mm00?oooooo`2Qool0XOl02_l0XOlNooooo`Oo0:7o1Ol0ogd>ooooo`03o`3o
^_l0FOoo05Wo00?ooooo0_l0ooH5ooooo`06o`3oPol0c?ooooooooooool0om;o0?mB1Oooool01Ol0
Jooo0>[oo`3o8_oooooo0?lj00;ooooo00Wo0?mIooooooooooooooooo`1Bool04?oo0?Koo`23ool0
ogL00_ooool01ol0obSo0>Coo`0Xoooooooo0?mUooooool0o`X00oooool01?l0oiGo0:koo`1<ool0
f?l3ooooo`04oego0?ooooooooooo`0^o`gooooo0_lV0?lCooooo`03ocSo0?oooooooooo00Oooooo
0_lV0?l9ooooo`04of?o0?oooooooooooego00_ooooo00?o0?3oooooooooool01oooool2o`0^o`03
ooooool0o`[ooooo00;ooooo00Co0=Sooooooooooooo0?nE3?ooool00ol0ofGoooooo`3o:009oooo
o`04o`3Tool0:?oo02Soo`0Xoa;ooooo0_l0Pol6ooooo`03o`0^oooooooooooo00Kooooo00?o02So
ooooooooool01_ooool00ol0oo3o0?mIo`3oF@04o`3oF@03oooooolV0?oooooo00Oooooo00?o03Co
ooooooooool01?ooool00ol0odcoooooooooo`0?ooooo`03oeL0oooooooooooo00_ooooo0_lno`04
ooooo`03ofT0oooooooooooo00Gooooo0ol0Pol8ooooo`?o>?l06Oooool001[ooooo00?o0000oooo
ooooool0@Oooool00ol0Vooo0:7oo`3oaP02o`1Io`;ooooo00Go0?ofo`3<ool0c?oo0<coo`29o`06
o`1[o`Cooooo0_l0oe89o`1[o`;o08Wo1Ol0om85ooooo`Co0<co0_ooool5o`3oc0Go0?of1oooool4
o`1Io`Co0?nj3?ooool5o`3oO@Gooooo1Ol0XOlaooooo`Go0:7o1Ol0ogd<ooooo`03o`1Iool0ok[o
0?nj00;ooooo00?o0?ofooooooooool00oooool01_l0oh?o0<coo`3<oooooooo0?oBo`3oDPGooooo
00Oo06_oo`3Zool0ob;oooooo`3o>_oooooo0?mI00Cooooo00Go05;oo`0@oooooooo08?oo`3oM`02
ooooo`06o`3o=?l0i?oo02Soo`3oIOoooooo0?l:1?ooool00ol0oiGo04coo`3Ho`03ooooo`05oego
0?ooooooooooooooool0;_l03Oooool00olho`3o9P3oobH0o`0?ooooo`;o>?l01oooool3obH0o`[o
oooo00CoHol0ooooooooooooGOl02_ooool2o`3`o`Wooooo00Co02kooooooooooooo0?l:0_ooool2
o`3Ho`;ooooo00?o0?nEooooooooool02Oooool2o`3oI@;o0?lX2?ooool3o`0Xoa;ooooo0ol0Pol9
ooooo`03o`0^oooooooooooo00Kooooo0_l0:?l00ooooooo0?mIo`3oF@04o`3oF@03o`3ol?oooooo
oooo00Cooooo00?o9P3oooooooooool01oooool00ol0=?ooooooooooo`03ooooo`03o`3oC?oooooo
oooo013ooooo00?oE`3oooooooooool03?ooool2ocko00?ooooo00?oJ@3oooooooooool01oooool3
o`23o`Sooooo1Olho`0Dooooo`006_ooool00ol0003oooooooooo`12ooooo`04o`2Kool0XOoo0?o6
o`3oaP?o05Wo0ol0ooH2o`3<o`Go08Wo1_l0Jol7o`29o`Co0?oB1_ooool4o`3<o`;ooooo1?l0ol`5
o`3omPOooooo1Ol0FOl4o`3o^P_ooooo1Ol0ogd4ooooo`Ko0:7o2ooooolRo`3oaPkooooo1Ol0XOl3
o`3oO@[ooooo0_l0FOl2o`3o^P03ooooool0ooKo0?of00Cooooo00Ko0?n3ooooool0c?ooooooo`3o
d_l0oe84ooooo`05o`1[ool0ROoo0>[oo`3o8_l0ocX00_ooool00ol0oeWoooooooooo`02ooooo`0=
o`1Bool04?oo08?oooooool0ogOoooooo`3o:?l0ocCo02Soooooool0ofGoooooo`3o2P03ooooo`04
o`3oUOl0[_oo04coo`3Ho`?ooooo00CoGOl0oooooooooooo02ko3_ooool2ocSo0003obH0oooooooo
oooo00Sooooo1?lho`07ooooo`;o9P3o3?ooool01?mSo`3ooooooego0?mMo`0:ooooo`03o`3`oooo
oooooooo00Oooooo0_l0;_l00ooooooo0?l:o`3o2P02ooooo`05o`3Hooooooooooooooooool0oiD0
2oooool00ol0ofGo0?lXo`3o:008ooooo`;o02So4oooool2o`23o`cooooo00?o02koooooooooool0
1?ooool4o`3oF@;o02So1Oooool00ol0oo3oooooooooo`05ooooo`03obH0oooooooooooo00Kooooo
00?o03Coooooooooool01?ooool00ol0odcoooooooooo`0?ooooo`03oeL0oooooooooooo00kooooo
0_lno`02ooooo`03ofT0oooooooooooo00Wooooo0ol0Pol:ooooo`Go>?l03oooool001[ooooo00?o
0000ooooooooool0@oooool01_l0Vooo0:7oo`2Qool0olKo0?mmo`3o^P;o05Wo00Coooooo`3om_l0
ooKo0?of0ol0c?l3ooooo`So0?oB1oooool6o`3<o`Ko0?o<1?l0ooH8ooooo`Co05Wo1Ol0okX;oooo
o`Co0?mm1?ooool5o`2Qo`Oooooo2_l0olH4oooooaOo0?n?1oooool4o`3oaPoooooo0ol0XOl2o`3o
O@[ooooo0_l0FOl01?l0ok[oooooooooool0ooH4ooooo`06o`3oPooooooo0<coooooool0om;o0?mB
1?ooool01Ol0Jooo08Woo`3Zool0ob;o0?lj00;ooooo00Wo0?mIooooooooooooooooo`1Bool04?oo
0?Koo`23ool0ogL00_ooool01ol0ocCo0>Coo`0Xoooooooo0?mUooooool0o`X00oooool00ol0oiGo
04coo`3Ho`04ooooo`04oego0?ooooooooooo`0^oa3ooooo0_lV0?l8ocSo00Sooooo0olV0?l=oooo
o`03of?o0?ooooooGOl000_ooooo00?o0?3oooooooooool01oooool01?l0;_ooooooooooool0o`X3
ooooo`05o`3Hooooooooooooooooool0oiD02_ooool2o`3oI@03o`3o:?oooooooooo00Gooooo0ol0
:?l00ol0i?ooooooooooo`0@ooooo`;o08?o3oooool00ol0;_ooooooo`3oF@03o`3oF@?o05;o0ooo
ool2o`0Xo`Cooooo00?o0?o`ooooooooool01?ooool00olV0?ooooooooooo`07ooooo`03o`0doooo
oooooooo00Cooooo00?o0?m<ooooooooool03oooool00omG0?ooooooooooo`0?ooooo`?o?_l000?o
J@3oooooooooool02oooool3o`23oa_ooooo000Jooooo`03o`000?oooooooooo04Cooooo0_l0Vol2
o`2Qo`04o`3oOOl0ok[o0?njo`1Io`?ooooo0ol0ooHBo`3<o`Ko0?o<1_l0ooH8ooooo`Co05Wo1?l0
okX<ooooo`Co0?mm0_ooool6o`2Qo`Cooooo2?l0olH4ooooo`[o0?n?5oooool;o`3oS`Ko0?o63?oo
ool3o`2Qo`;o0?mm2Oooool2o`1Io`04o`3o^_oooooo0?ofo`3omP?ooooo00Ko0?n3ooooool0c?oo
ooooo`3od_l0oe84ooooo`07o`1[ool0ROoo0>[oo`3o8_l0oc[oooooo`3oF@04ooooo`05o`1Bool0
4?ooooooo`23ool0ogL00_ooool01_l0ocCo0>Coo`0Xool0ofGoooooo`3o2P?ooooo00Co0?nEo`2^
ool0C?oo0=So0oooool01OmMo`3oHol0oooooooooooo02ko017ooooo0olV0?l;ooooo`;o9P3o3ooo
ool00omSo`3ooooooego000;ooooo`03o`3`oooooooooooo00Kooooo0_l0;_l2ooooo`05o`3o2_oo
ooooooooooooool0f?l00oooool00ol0oiGoooooooooo`08ooooo`03o`3oIOl0obSo0?lX00Kooooo
0_l0:?l00ooooooo0>Coo`3To`0@ooooo`?o08?o3Oooool4o`1Bo`03o`0^ool0D_oo05;o00?o05;o
0oooool5o`1Bo`03o`0Xool0D_oo05;o00?o05;o1_ooool00olV0?ooooooooooo`06ooooo`03o`0d
oooooooooooo00Cooooo00?o0?m<ooooooooool03oooool00omG0?ooooooooooo`0Booooo`03ocko
0?mY0?oo?_l000kooooo0ol0PolHooooo`006_ooool00ol0003oooooooooo`16ooooo`;o09_o00Co
0:7oo`3oOOl0oggo0?nj0ol0FOl3oooooaSo0?of2Oooool5o`1Io`Co0?nj2oooool5o`3oO@03oooo
ool0XOoo0:7o00?o0:7o00?oooooo`3oa_l0olH01ol0olH<o`3oSa3ooooo3?l0ol0Aooooo`Co0?n?
00?oooooo`3oa_l0olH01?l0olH9ooooo`?o0:7o0_l0ogd8ooooo`05o`1Iool0ok[oooooooooool0
ooH00oooool01_l0oh?oooooo`3<oooooooo0?oBo`3oDPCooooo00Co06_oo`29oooooooo0?lj0_oo
ool02Ol0oeWooooooooooooooooo05;oooooool04?oo08?oo`3oM`02ooooo`07o`3o=?l0i?oo02So
ooooool0ofGoooooo`3o2P03ooooo`03o`3oUOl0C?oo0=So00Cooooo00GoGOl0of?o0?oooooooooo
o`0^o`0Cooooo`_o9P3o3oooool2of?o0003oooooomMo`3ooooo00[ooooo00?o0?3oooooooooool0
1_ooool00ol0;_ooooooooooo`02o`3o2P?ooooo00?o0=Soooooooooool00_l0oiD9ooooo`;o0?mU
00?o0?lXooooooooool01?ooool2o`0Xo`;ooooo00?o0>Coooooooooool03_ooool2o`23o`_ooooo
1Ol0D_l3o`3oF@;ooooo00?o02koooooooooool02oooool01Ol0:?ooooooooooool0oo3ooooo00?o
05;o0oooool00olV0?ooooooooooo`06ooooo`03o`0doooooooooooo00Gooooo00?o0?m<oooooooo
ool03oooool00omG0?ooooooooooo`0Cooooo`04ofT0oolno`3o?_l0ocko00kooooo0ol0Pol3oooo
o`?o?_l03oooool001[ooooo00?o0000ooooooooool0B?ooool01?l0Vooo0:7oo`2Qool0olH3o`3o
^PKo05Wo6Oooool5o`1Io`Go0?nj2Oooool6o`3oO@03ooooool0XOoo0:7o00?o0:7o00?oooooo`3o
a_l0olH00ol0olH3ooooo`Ko0?n?3?ooool=o`3o`1;o09_o3?l0ol06ooooo`Go0?n?0_ooool4o`3o
aPSooooo0_l0XOl3o`3oO@Kooooo0_l0FOl01?l0ok[oooooo`3om_l0ooH2ooooo`05o`3oPooooooo
0<coooooool0om801Oooool01?l0Jooo08Woo`3o8_l0ocX2ooooo`09o`3oFOooooooooooooooool0
D_oo013oooooool0Pooo0?mg00;ooooo00Ko0?ldo`3Tool0:?oo0?mUooooool0o`X3ooooo`04o`3o
UOl0[_oo04coo`3Ho`Cooooo00CoGOl0of?o0?oooooo02ko;?ooool01?mSo`3ooooooooooomMo`0:
ooooo`;o0?3o1oooool2o`0^o`;ooooo00Co0?l:oooooooooooooooo0_l0f?l2ooooo`03o`3oUOoo
oooooooo00Sooooo00?o0?mUo`3o:?ooool01_ooool00ol0:?ooooooooooo`02o`3To`oooooo0_l0
Pol9ooooo`Co05;o0_ooool3o`3oF@Kooooo00?o02koooooooooool02oooool01?l0:?oooooooooo
ool0oo03ooooo`?o05;o00?oooooobH0ooooool01oooool00ol0=?ooooooooooo`04ooooo`03o`3o
C?oooooooooo00oooooo00?oE`3oooooooooool05?ooool00omY0?ooooooooooo`04ocko00_ooooo
0_lno`03o`23oa;ooooo000Jooooo`03o`000?oooooooooo04Wooooo0_l0Vol2o`2Qo`;o0?o61_l0
okX8o`1Io`Cooooo3Ol0FOl5o`3o^PSooooo1_l0ogd2ooooo`Go0:7o1_l0olH3ooooo`Go0?n?3?oo
ool6o`3o`0go09_o4_ooool9o`2Ko`?ooooo1Ol0ol06ooooo`Go0?n?00Coooooo`3oa_l0olKo0?o6
1oooool2o`2Qo`03ooooool0oggo0?mm00Kooooo0_l0FOl2ooooo`08o`3om_ooooooooooo`3oPooo
oooo0<coo`3od_l0oe85ooooo`06o`1[ool0j_oo0?lRo`3o>_oooooo0?mI1?ooool01?l0D_oo013o
o`23ool0ogL2ooooo`07o`3o=?l0i?oo02Soooooool0ofGoooooo`3o2P03ooooo`04o`3oUOl0[_oo
04coo`3Ho`?ooooo00GoGOl0oooooomSo`3oooooo`0^o`0Zooooo`04of?o0?ooooooGOl0oego00[o
oooo00?o0?3oooooooooool01_ooool01Ol0;_oooooooooooooooooo0?l:00?ooooo00Go0=Sooooo
ooooooooooooo`3oU@09ooooo`;o0?mU00?o0?lXooooooooool01?ooool2o`0Xo`;ooooo00?o0>Co
ooooooooool03Oooool2o`23o`Sooooo0ol0D_l3ooooo`?o0?mI2Oooool00ol0;_ooooooooooo`0<
ooooo`03o`0Xoooooooo0?o`00Kooooo00?o05;oobH0ool0D_l01oooool00ol0=?ooooooooooo`05
ooooo`03o`3oC?oooooooooo00oooooo00?oE`3oooooooooool05?ooool00omY0?ooooooooooo`03
ooooo`_o?_l01Oooool3o`23o`oooooo000Jooooo`03o`000?oooooooooo04_ooooo0_l0Vol2o`2Q
o`?o0?o60oooool4o`3o^P?ooooo1_l0FOl3ooooo`Wo0?nj1oooool6o`3oO@?ooooo1Ol0XOl5o`3o
aP?ooooo1_l0ohl:ooooo`03o`3o`?l0Vooo09_o00[o09_o:?ooool;o`2Ko`?o0?o01Oooool3o`3o
S`03ooooool0olKo0?o600Oooooo0_l0XOl00ooooooo0?mmooooo`06ooooo`;o05Wo00Woooooo`3o
m_ooooooooooo`3oPooooooo0<coo`3od_l0oe801Oooool00ol0Joooooooo`3o>P02ooooo`09o`3o
FOooooooooooooooool0D_oo013oo`3fool0Pooo0?mg00;ooooo00Co0?ldo`3Tool0:?oo0?mU0_oo
ool01ol0o`[ooooooooooooooooo0:koo`1<ool0f?l01?ooool01OmMo`3oooooof?o0?oooooo02ko
02Oooooo0_mSo`000oooooooGOl0ooooo`0:ooooo`03o`3`oooooooooooo00Gooooo0_l0;_l3oooo
o`05o`3o2_ooooooooooooooool0f?l00oooool00ol0oiGoooooooooo`07ooooo`03o`3oIOl0obSo
oooo00Gooooo0_l0:?l3ooooo`03o`3Toooooooooooo00cooooo0_l0Pol7ooooo`?o05;o0oooool3
o`3oF@gooooo00?o02koooooooooool03?ooool00ol0:?ooooooo`3ol006ooooo`03obH0oooooooo
05;o00?o05;o0oooool00ol0=?ooooooooooo`05ooooo`03o`3oC?oooooooooo00oooooo00?oE`3o
ooooooooool05Oooool2ofT0obGooooo000Jooooo`03o`000?oooooooooo04gooooo0_l0Vol4o`2Q
o`;o0?o60_l0ogd2ooooo`co0?nj2oooool5o`3oO@Cooooo1Ol0XOl3o`3oaPCooooo1_l0ohl9oooo
o`?o0?o01Ol0Voloooooo`?o09_o1?l0ol04ooooo`;o0?n?00?oooooo`3oa_l0olH01oooool2o`2Q
o`;o0?mm1oooool00ol0FOoo0?ofooooo`02ooooo`05o`3oPooooooo0<coo`3od_l0oe801?ooool0
1?l0Jooo08Woo`3o8_l0ocX2ooooo`08o`3oFOooooooooooooooool0D_oo013oo`23ool0ogL3oooo
o`06o`3Toooooooo02Soo`3oIOoooooo0?l:0oooool01?l0oiGo0:koo`1<ool0f?l4ooooo`05oego
0?ooooooHol0ooooool0;_l09Oooool01?mSo`3ooooooego0?mMo`0;ooooo`03o`3`oooooooooooo
00Gooooo00Co02kooooooooooooooooo0_l0o`X3ooooo`05o`3Hooooooooooooooooool0oiD02Ooo
ool00ol0ofGoooooooooo`05ooooo`04o`0Xooooooooooooooooo`;o0>Co3Oooool2o`23o`Kooooo
0ol0D_l4ooooo`;o0?mI4?ooool00ol0;_ooooooooooo`0=ooooo`03o`0Xool0oo3ooooo00Kooooo
00?o9P3oooooooooool00_ooool3o`1Bo`03ooooool0=?oooooo00Kooooo00?o0?m<ooooooooool0
3oooool00omG0?ooooooooooo`0Fooooo`03ofT0oooooooooooo02;ooooo000Jooooo`?o0000Cooo
ool3o`2Ko`03ooooool0XOoo0:7o00;o0:7o0ol0olH4o`3oO@Sooooo2_l0ogd4ooooo`Go0:7o0_l0
olH4ooooo`Ko0?n?2?ooool4o`3o`0Ko09_oAoooool4o`2Ko`?o0?o00oooool3o`3oS`?o0?o61_oo
ool01?l0XOooooooo`3oOOl0ogd6ooooo`03o`1Iool0ooKooooo00;ooooo00Go0?n3ooooool0c?oo
0?oBo`3oDP04ooooo`06o`1[oooooooo0?lRo`3o>_oooooo0?mI0oooool01Ol0D_oo013oo`3fool0
Pooo0?mg00;ooooo00Co0?ldo`3Tool0:?oo0?mU0_ooool01ol0o`[ooooooooooooooooo0:koo`1<
ool0f?l01Oooool01?mMo`3oooooof?o0?l0;_lTooooo`03of?o0?ooooooGOl000cooooo00?o0?3o
ooooooooool01?ooool2o`0^o`?ooooo00?o0?l:ooooooooool00_ooool01Ol0f?oooooooooooooo
oooo0?nE00Wooooo00?o0?mUooooooooool01?ooool2o`0Xo`?ooooo00?o0>Coooooooooool02ooo
ool2o`23o`Gooooo0ol0D_l4ooooo`?o0?mI4oooool00ol0;_ooooooooooo`0=ooooo`03o`0Xool0
oo3ooooo00Gooooo00?o9P3oooooooooool01Oooool00ol0D_oo03Coooooo`06ooooo`03o`3oC?oo
oooooooo00oooooo00?oE`3oooooooooool05oooool2ofT0ob;ooooo000Jooooo`03o`000?oooooo
oooo05;ooooo0ol0Vol2ooooo`Ko0:7o0ol0olH6o`3oO@Gooooo2Ol0XOl00ol0olKo0?n?o`3oS`08
o`3oS`Oooooo1Ol0ol06o`2Koe7ooooo1Ol0Vol4ooooo`;o0?n?00?oooooo`3oa_l0olH01Oooool2
o`2Qo`03ooooool0oggooooo00Cooooo00?o0?njo`1Iool0ooH00oooool01Ol0oh?oooooo`3<ool0
om;o0?mB00Cooooo00?o06_oooooool0ocX00_ooool02?l0oeWooooooooooooooooo05;oo`0@oooo
oooo08?o0oooool01_l0i?ooooooo`0Xool0ofGoooooo`3o2P?ooooo00Co0?nEo`2^ool0C?oo0=So
1Oooool01?mMo`3oooooof?o0?l0;_lQooooo`;oHol00_mMo`0;ooooo`;o0?3o1Oooool2o`0^o`Co
oooo00?o0?l:ooooooooool00_ooool00ol0f?ooooooooooo`02o`3oU@Sooooo0_l0ofD5ooooo`;o
02So0oooool2o`3To`cooooo0_l0Pol4ooooo`?o05;o1?ooool3o`3oFAKooooo00?o02kooooooooo
ool03_ooool00ol0:?ooooooooooo`04ooooo`03obH0oooooooooooo00Oooooo00?o03Cooooooooo
ool01Oooool00ol0odcoooooooooo`0?ooooo`03oeL0oooooooooooo01Sooooo0_mY0?lPooooo`00
6_ooool00ol0003oooooooooo`1Eooooo`?o09_o0_ooool3o`3oS`ko0:7o2Ol0ohl;ooooo`Co0?o0
2?l0VomLooooo`?o09_o0oooool2o`3oS`03ooooool0olKo0?o600Gooooo00Co0:7oooooool0oggo
0?mm1?ooool00ol0ok[o05Woo`3omP03ooooo`05o`3oPooooooo0<coo`3od_l0oe800oooool01?l0
Jooo08Woo`3o8_l0ocX2ooooo`08o`3oFOooooooooooo`1Boooooooo013oo`23ool0ogL2ooooo`04
o`3o=?l0i?oo02Soo`3oI@;ooooo00Oo0?l:ooooooooooooooooo`2^ool0C?oo0=So00Kooooo00Co
GOl0oooooomSo`3o02ko7oooool00omSo`3ooooooego000<ooooo`03o`3`oooooooooooo00Cooooo
00?o02koooooooooool00oooool01?l0o`[oooooooooooooool2o`3Ho`;ooooo00?o0?nEoooooooo
ool01oooool00ol0ofGo0?lXooooo`04ooooo`03o`0Xoooooooooooo00;ooooo00?o0>Cooooooooo
ool02oooool00ol0Poooooooooooo`02ooooo`;o05;o1Oooool2o`3oFA[ooooo00?o02kooooooooo
ool03Oooool00ol0oo3o02Soooooo`05ooooo`03obH0oooooooooooo00Kooooo00?o03Coo`1Bool0
D_l01_ooool00ol0odcoooooooooo`0>ooooo`03oeL0oooooooooooo01[ooooo00?oJ@3ooooooooo
ool07Oooool001[ooooo00?o0000ooooooooool0F?ooool2o`2Ko`?o0?o01oooool6o`3oS`cooooo
1?l0ol09o`2KofOooooo0_l0Vol00ol0ol3oooooooooo`03o`3oS`;o0?o61?ooool2o`2Qo`03oooo
ool0oggooooo00?ooooo00?o0?njo`1Iool0ooH00oooool01?l0oh?oooooo`3<ool0om84ooooo`06
o`1[oooooooo0?lRo`3o>_oooooo0?mI0oooool01?l0D_oo013oooooool0Pol3ooooo`04o`3o=?l0
i?oo02Soo`3oI@;ooooo00Oo0?l:oooooooooooo0?nEo`2^ool0C?oo0=So00Kooooo00CoGOl0oooo
oomSo`3o02ko7Oooool00omSo`3oGOl0oego000<ooooo`03o`3`oooooooooooo00?ooooo0_l0;_l4
ooooo`;o0?l:0oooool01Ol0f?oooooooooooooooooo0?nE00Wooooo00?o0?mUooooooooool01?oo
ool00ol0:?ooooooooooo`02ooooo`03o`3Toooooooooooo00[ooooo0_l0Pol3ooooo`;o05;o1?oo
ool3o`3oFAcooooo00?o02koooooooooool03_ooool00ol0oo3o02Soooooo`04ooooo`03obH0oooo
oooooooo00Kooooo00Co03Cooooooooooooo05;o1Oooool00ol0odcoooooooooo`0?ooooo`03oeL0
oooooooooooo01[ooooo00?oJ@3oooooooooool07?ooool001[ooooo00?o0000ooooooooool0F_oo
ool6o`2Koa?o0?o01ol0Vombooooo`;o09_o0_l0ol02ooooo`;o0?n?00?o0?o6ooooooooool00ooo
ool01?l0XOooooooo`3oOOl0ogd3ooooo`03o`3o^_l0FOoo0?of00?ooooo00Co0?n3ooooool0c?oo
0?mB1?ooool00ol0Joooooooo`3o>P02ooooo`08o`3oFOooooooooooooooool0D_oo013oo`23ool0
ogL2ooooo`04o`3o=?l0i?ooooooo`0Xo`;ooooo00So0?l:ooooooooooooooooo`3oUOl0[_oo04co
o`3Ho`Kooooo00CoGOl0oooooomSo`3o02ko6_ooool2of?o0003oego0?oooooooooo00[ooooo0_l0
l?l5ooooo`03o`0^oooooooooooo00?ooooo00?o0?l:ooooooooool00_ooool01Ol0f?oooooooooo
oooooooo0?nE00Wooooo00?o0?mUooooooooool00oooool2o`0Xo`?ooooo0_l0i?l<ooooo`04o`23
ooooooooooooooooo`;o05;o1?ooool2o`3oFAoooooo00?o02koooooooooool03_ooool00ol0oo3o
02Soooooo`05ooooo`03obH0oooooooooooo00Kooooo00?o03Coooooooooool00_l0D_l4ooooo`03
o`3oC?oooooooooo00kooooo00?oE`3oooooooooool06oooool3ofT0oa_ooooo000Jooooo`03o`00
0?oooooooooo063ooooo4ol0Vomkooooo`;o09_o0_l0ol02ooooo`03o`3oSol0olKo0?o600Cooooo
0_l0XOl00ooooooo0?mmooooo`02ooooo`03o`3o^_l0FOoo0?of00?ooooo00Co0?n3ooooool0c?oo
0?mB0oooool01?l0Jooo08Woo`3o8_l0ocX2ooooo`08o`3oFOooooooooooo`1Bool04?ooooooo`23
ool0ogL2ooooo`04o`3o=?l0i?oo02Soo`3oI@;ooooo00Oo0?l:ooooooooooooooooo`2^ool0C?oo
0=So00Oooooo0_mMo`000ooooooo02koooooo`0Fooooo`;oHol00_mMo`0<ooooo`03o`3`oooooooo
oooo00?ooooo0_l0;_l5ooooo`03o`3o2_oooooooooo00;ooooo00Go0=Soooooooooooooooooo`3o
U@08ooooo`;o0?mU1Oooool00ol0:?ooooooooooo`02ooooo`03o`3Toooooooooooo00_ooooo2?l0
C?l00ooooooo0?mIo`3oF@0Rooooo`03o`0^oooooooooooo00kooooo00?o0?o`o`0Xooooool01?oo
ool00olV0?ooooooooooo`06ooooo`03o`0doooooooooooo00;ooooo00Go05;ooooooooooooooooo
o`3oC00Aooooo`03oeL0oooooooooooo01gooooo1?mY0?lGooooo`006_ooool00ol0003ooooooooo
o`3`ooooo`;o09_o00?o0?o0ooooooooool00_l0ohl00ol0olKoooooooooo`03ooooo`03o`2Qoooo
oooo0?mm00?ooooo00?o0?njo`1Iool0ooH00_ooool01Ol0oh?oooooo`3<ool0om;o0?mB00?ooooo
00Ko06_oooooool0ob;o0?ljooooool0oeT3ooooo`04o`1Bool04?oo08?oo`3oM`;ooooo00Oo0?ld
o`3Toooooooo02Soo`3oIOoooooo0?l:00?ooooo00Co0?nEo`2^ool0C?oo0=So2?ooool01?mMo`3o
ooooo`0^oomSo`0Dooooo`03of?o0?ooooooGOl000cooooo0_l0l?l4ooooo`;o02ko1_ooool00ol0
o`[oooooooooo`02ooooo`05o`3Hooooooooooooooooool0oiD02?ooool00ol0ofGoooooooooo`04
ooooo`04o`0Xooooooooooooooooo`;o0>Co2?ooool6o`1<o`;ooooo0_l0D_l4ooooo`Ko04co7ooo
ool00ol0;_ooooooooooo`0>ooooo`03o`3ol?oooooo02So00Cooooo00?o9P3oooooooooool01ooo
ool00ol0=?ooooooooooo`02ooooo`05o`1Booooooooooooooooool0od`04?ooool00omG0?oooooo
ooooo`0Qooooo`SoJ@3o3oooool001[ooooo00?o0000ooooooooool0l_ooool2o`2Ko`04o`3o`?oo
ooooooooo`3oS`;o0?o61?ooool00ol0XOooooooo`3oO@03ooooo`03o`3o^_l0FOoo0?of00;ooooo
00Co0?n3ooooool0c?oo0?mB1?ooool00ol0Jooo0?lRo`3o>P02ooooo`08o`3oFOooooooooooo`1B
ool04?ooooooo`23ool0ogL2ooooo`04o`3o=?l0i?oo02Soo`3oI@;ooooo00So0?l:oooooooooooo
ooooo`2^ool0C?ooooooo`3Ho`Sooooo0_mMo`000ol0;_ooHol0ooooo`0@ooooo`;oHol00_mMo`0<
ooooo`03o`3`oooooooooooo00;ooooo0_l0;_l6ooooo`;o0?l:0oooool2o`3Ho`?ooooo00?o0?nE
ooooooooool01_ooool00ol0ofGoooooooooo`03ooooo`;o02So0oooool00ol0i?ooooooooooo`05
ooooo`?o04co0oooool00ol0Poooooooooooo`02o`1Bo`Cooooo0_l0oeT6ooooo`03o`1<oooooooo
oooo01gooooo00?o02koooooooooool03Oooool01?l0oo3oooooooooool0:?l4ooooo`03obH0oooo
oooooooo00Kooooo00?o03Coooooooooool00oooool01?l0D_ooooooooooool0od`Aooooo`03oeL0
oooooooooooo03Oooooo000Jooooo`03o`000?oooooooooo0?Cooooo00Co09_oo`3o`?oooooooooo
0_l0ohl00ol0olKoooooooooo`02ooooo`03o`2Qoooooooo0?mm00?ooooo00?o0?njo`1Iool0ooH0
0_ooool01?l0oh?oooooo`3<ool0oe83ooooo`06o`1[ool0j_oo0?lRo`3o>_oooooo0?mI0oooool0
1?l0D_oo013oooooool0Pol3ooooo`04o`3Toooooooo02Soo`3oI@;ooooo00Oo0?l:oooooooooooo
0?nEo`2^ool0C?oo0=So00[ooooo00?oGOl0o`0^ool0l?l00_mSo`09ooooo`CoHol00omMo`0=oooo
o`03o`3`oooooooooooo00;ooooo00?o02koooooooooool01Oooool00ol0o`[oooooooooo`02oooo
o`04o`3Hooooooooooooooooo`;o0?nE1oooool2o`3oI@Gooooo00?o02Soooooooooool00_ooool0
0ol0i?ooooooooooo`03ooooo`?o04co1?ooool2o`23o`03ooooool0D_oo05;o00Cooooo0_l0oeT9
ooooo`?o04co7?ooool00ol0;_ooooooooooo`0>ooooo`03o`3ol?oooooo02So00Cooooo00?o9P3o
ooooooooool01_ooool00ol0om;o03Coo`3odP04o`3odP;o05;o4_l0om800omG0?oo0?oBo`3odP07
o`3odS3ooooo000Jooooo`03o`000?oooooooooo0?Gooooo0_l0Vol01?l0ol3oooooooooool0ohl2
o`3oaP?ooooo00?o0:7oooooool0ogd00oooool00ol0ok[o05Woo`3omP02ooooo`04o`3oPol0c?oo
0?oBo`3oDP?ooooo00Ko06_oooooool0ob;o0?ljooooool0oeT2ooooo`05o`1Bool04?ooooooo`23
ool0ogL00_ooool01?l0ocCo0>Coo`0Xool0ofD3ooooo`07o`3o2_ooooooooooo`3oUOl0[_oo04co
o`3Ho`0:ooooo`04oego0?l0;_oo02koo`3`o`WoHol000Cooooooego0?mMo`3oGOl03_ooool2o`3`
o`?ooooo0_l0;_l7ooooo`03o`3o2_oooooooooo00;ooooo00Go0=Soooooooooooooooooo`3oU@08
ooooo`03o`3oIOl0obSooooo00?ooooo0_l0:?l4ooooo`04o`3Tooooooooooooooooo`?o04co1_oo
ool01?l0Poooooooo`1Bool0D_l5ooooo`03o`3oFOoooooooooo00cooooo0_l0C?l00ooooooo0?lj
o`3o>P0:o`3o>Pkooooo00?o02koooooooooool03Oooool01?l0oo3oooooooooool0:?l3ooooo`03
obH0oooooooooooo00Ko0?oB00?oooooo`0dooooool01_ooool00ol0D_ooooooo`3oC00?ooooo`03
oeL0oooooooooooo00Oooooo2Ol0om8Wooooo`006_ooool00ol0003oooooooooo`3gooooo`;o09_o
0_ooool2o`3oS`07o`3oa_ooooooooooooooool0XOooooooo`3oO@03ooooo`03o`1Ioooooooo0?of
00;ooooo00Co0?n3o`3<oooooooo0?mB0_ooool01_l0Jooo08Woo`3o8_l0oc[oooooo`3oF@?ooooo
00Co05;oo`0@oooooooo08?o0oooool01?l0i?ooooooo`0Xool0ofD2ooooo`08o`3o2_oooooooooo
ooooool0[_oo04coooooool0f?l<ooooo`03o`0^ool0l?ooGOl000SoGOl03_ooool3o`3`o`?ooooo
0_l0;_l7ooooo`;o0?l:1?ooool01Ol0f?oooooooooooooooooo0?nE00Sooooo00?o0?mUoooooooo
ool00oooool00ol0:?ooooooooooo`02ooooo`;o0>Co00Coooooo`1<ool0C?oo04co1oooool2o`23
o`03ooooool0D_oooooo00Cooooo0_l0oeT;o`3o=0Ko0?lj00?o04coooooooooool02_ooool5o`3o
>PWooooo00?o02koooooooooool03_ooool01?l0oo3o0?oBo`3od_l0:?l3o`3odP03obH0ool0om;o
oooo00Kooooo00?o03Coooooooooool01_ooool00ol0D_oo0?m<ooooo`0?ooooo`03oeL0oooooooo
oooo00oooooo2_l0om8Mooooo`006_ooool00ol0003oooooooooo`3iooooo`06o`2Kool0ol3ooooo
ooooool0ohoo0?o60oooool00ol0XOooooooo`3oO@03ooooo`03o`1Iool0ooKo0?o<00;ooooo00?o
0?n3o`3<ool0oe800oooool01_l0Joooooooo`3o8_l0oc[oooooo`3oF@?ooooo00Co05;oo`0@ool0
Pooo0?mg0_ooool01Ol0ocCo0>Coo`0Xoooooooo0?mU00;ooooo00Oo0?l:ooooooooooooooooo`2^
ool0C?oo0=So00gooooo0_l0;_l00ol0l?ooooooooooo`0@ooooo`?o0?3o1?ooool2o`0^o`Sooooo
00?o0?l:ooooooooool00_ooool2o`3Ho`;ooooo0_l0oiD8ooooo`03o`3oIOoooooooooo00?ooooo
00?o02Soooooooooool00_ooool01?l0i?ooooooo`1<ool0C?l9ooooo`04o`23oooooooo05;oo`1B
o`go0:ko0oooool3o`3o>PGooooo0_l0oc@00ol0C?ooooooooooo`0>ooooo`?o0?lj1oooool00ol0
;_ooooooooooo`04ooooo`Wo0?oB00Go0?o`ooooooooooooooooo`0Xo`02ooooo`03obH0oooooooo
oooo00Oooooo00?o03Coooooooooool01_ooool00ol0D_oo0?m<ooooo`0>ooooo`03oeL0oooooooo
oooo01Wooooo2Ol0om8Dooooo`006_ooool00ol0003oooooooooo`3jooooo`;o09_o0_ooool00ol0
ohoo0?o6ooooo`02ooooo`03o`2Qoooooooo0?mm00?ooooo00?o05Woo`3om_ooool00_ooool00ol0
c?oo0?oBo`3oDP03ooooo`03o`1[oooooooo0?lj00;ooooo00Oo0?mIoooooooooooo05;oo`0@oooo
oooo08?o00?ooooo00Co0>Coooooool0:?oo0?mU0oooool01ol0o`[oooooooooool0[_oo04cooooo
ool0f?l03_ooool3o`0^o`03o`3`oooooooooooo00_ooooo0_l0l?l4ooooo`?o02ko2Oooool00ol0
o`[oooooooooo`02ooooo`05o`3Hooooooooooooooooool0oiD02?ooool2o`3oI@Cooooo0_l0:?l4
ooooo`03o`3Tool0C?oo04co00Wooooo0_l0Pol2o`1Bo`04o`2^oooooooo0?ldo`3o=0;o0?mI2Ooo
ool3o`2^o`[ooooo00?o04coo`3o=?l0oc@04Oooool3o`3o>PCooooo00?o02koo`3od_l0om801?l0
om89ooooo`05o`3ol?ooooooooooooooool0:?l00_ooool00olV0?ooooooooooo`07ooooo`03o`0d
oooooooooooo00Oooooo00?o05;oo`3oC?ooool03_ooool00omG0?ooooooooooo`0Qooooo`Go0?oB
3oooool001[ooooo00?o0000ooooooooool0o?ooool01Ol0Vooo0?o0ooooool0ohoo0?o600?ooooo
00?o0:7oooooool0ogd00_ooool00ol0FOooooooo`3omP02ooooo`04o`3oPol0c?oo0?oBo`3oDP;o
oooo00Ko06_oo`29ool0ob;o0?ljooooool0oeT3ooooo`04o`1Bool04?oo08?oo`3oM`;ooooo00Go
0?ldo`3Tool0:?ooooooo`3oI@03ooooo`07o`3o2_ooooooooooo`2^ool0C?ooooooo`3Ho`0@oooo
o`;o02ko0_l0l?l6ooooo`Co0?3o0oooool3o`0^o`_ooooo00?o0?l:ooooooooool00_ooool00ol0
f?ooooooooooo`02o`3oU@Sooooo00?o0?mUooooooooool00oooool00ol0:?ooooooooooo`02oooo
o`03o`3Tool0C?oo04co00Sooooo0_l0[_l01?l0Poooooooo`1Booooool3o`3o=003ooooool0oeWo
oooo00Oooooo0ol0ocX3ooooo`?o0:ko2?ooool00ol0C?ooooooo`3o=00Cooooo`05o`3o>_l0om;o
0?oBo`3od_l0;_l04?ooool01Ol0oo3ooooooooooooooooo02So00;ooooo00?o9P3oooooooooool0
1oooool00ol0=?ooooooooooo`07ooooo`;o05;o3_ooool00omG0?ooooooooooo`0eooooo`006_oo
ool00ol0003oooooooooo`3mooooo`05o`2Kool0ol3oooooo`3oSol0olH00oooool00ol0XOoooooo
o`3oO@02ooooo`03o`1Iool0ooKo0?o<00;ooooo00?o0?n3o`3<ool0oe800oooool01_l0Jooooooo
o`3o8_l0oc[oooooo`3oF@;ooooo00Co05;oo`0@oooooooo08?o0oooool01?l0i?ooooooo`0Xool0
ofD3ooooo`07o`3o2_ooooooooooooooool0[_oo04coooooo`02o`3Hoa3ooooo0_l0;_l6o`3`o`Co
oooo0ol0;_l<ooooo`;o0?l:1?ooool01?l0f?ooooooooooool0oiD9ooooo`03o`3oIOoooooooooo
00?ooooo00Co02Sooooooooooooooooo0ol0C?l7ooooo`?o0:ko00Coooooo`23ool0D_oo05;o0_l0
oc@2ooooo`;o0?mI1oooool2o`3o>PWooooo0_l0[_l7ooooo`04o`1<oooooooo0?ldo`3o=0oooooo
0ol0om82ooooo`;o0?lj00?o02koooooooooool03Oooool00ol0oo3oooooooooo`02ooooo`03o`0X
oooooooo9P3o00Wooooo00?o03Coooooooooool02?ooool00ol0odco05;oooooo`0=ooooo`03oeL0
oooooooooooo03Cooooo000Jooooo`03o`000?oooooooooo0?kooooo00Go09_oo`3o`?oooooo0?n?
o`3oaP03ooooo`03o`2Qoooooooo0?mm00;ooooo00?o05Woo`3om_ooool00_ooool00ol0c?oo0?oB
o`3oDP03ooooo`05o`1[ool0ob;o0?ljooooool0oeT00oooool01?l0D_oo013oo`23ool0ogL3oooo
o`04o`3Tool0:?ooooooo`3oI@?ooooo00Ko0?l:ooooooooooooooooo`2^ool0C?l2ooooo`03o`3H
oooooooooooo00oooooo2_l0;_l>ooooo`03o`3o2_oooooooooo00;ooooo0_l0f?l2ooooo`03o`3o
UOoooooooooo00Oooooo00?o0?mUooooooooool00_ooool2o`0Xo`;ooooo0_l0C?l00ol0i?oooooo
ooooo`04ooooo`?o0:ko0_ooool01?l0Pooo05;oo`1Bool0oc@3ooooo`;o0?mI1_ooool3o`3o>POo
oooo3ol04?l2ooooo`03o`3o=?oooooooooo00Wooooo0ol0om87ooooo`03o`0^ool0oc[o0?lj00ko
oooo00Go0?o`ooooooooooooooooo`0Xo`02ooooo`03obH0oooooooooooo00Kooooo00?o03Cooooo
ooooool02Oooool00ol0odco05;oooooo`0<ooooo`03oeL0oooooooooooo03Cooooo000Jooooo`03
o`000?oooooooooo0?oooooo00Go09_oo`3o`?oooooo0?n?o`3oaP03ooooo`07o`2Qool0oggooooo
ooooool0ok[o05Woo`3omP02ooooo`04o`3oPol0c?oo0?oBo`3oDP;ooooo00Ko06_oo`29ool0ob;o
0?ljooooool0oeT2ooooo`04o`1Bool04?ooooooo`23o`?ooooo00Go0>Coooooool0:?ooooooo`3o
I@03ooooo`06o`3o2_ooooooooooo`2^ool0oiGo04co0_ooool00ol0f?ooooooooooo`0Uooooo`03
o`3o2_oooooooooo00;ooooo00?o0=Soooooooooool00_l0oiD8ooooo`;o0?mU1?ooool00ol0:?oo
ooooooooo`02o`1<o`03ooooool0i?oooooo00?ooooo0ol0[_l4ooooo`03o`23ool0D_oo0?ld00Co
oooo00?o0?mIooooooooool00oooool3o`3o>PCooooo1_l04?l8ooooo`03o`2^oooooooooooo00Co
oooo0ol04?l2o`3o=0Kooooo0ol0om8;ooooo`03o`0^oooooooo0?lj00gooooo00?o0?o`oooooooo
ool00_ooool00ol0:?ooooooobH0o`09ooooo`03o`0doooooooooooo00Wooooo00?o0?m<o`1Boooo
ool03?ooool00omG0?ooooooooooo`0cooooo`006_ooool00ol0003oooooooooo`3oooooo`7ooooo
00Go09_oo`3o`?oooooo0?n?o`3oaP03ooooo`07o`2Qool0oggoooooooooool0FOooooooo`3omP02
ooooo`04o`3oPol0c?ooooooo`3oDP;ooooo00Go06_oo`3o8_l0oc[oooooo`3oF@03ooooo`04o`1B
ool04?ooooooo`23o`?ooooo00Co0>Coo`0Xoooooooo0?mU1?ooool01Ol0o`[oooooooooool0[_oo
04co00?ooooo00?o0=Soooooooooool08oooool00ol0o`[oooooooooo`02ooooo`04o`3Hoooooooo
ooooo`3oU@Wooooo00?o0?mUooooooooool00oooool01Ol0:?ooooooo`1<ool0C?oooooo00;o0>Co
0oooool2o`2^o`Gooooo0_l0Pol00ol0D_oo0?ldooooo`02ooooo`;o0?mI1?ooool2o`3o>PGooooo
0_l04?l?ooooo`03o`2^oooooooooooo00Cooooo00?o04coooooool04?l00ol04?l01?oooooo0?oB
o`3od_l0om8>ooooo`04o`0^ooooooooooooo`3o>Pcooooo00?o0?o`ooooooooool00oooool00ol0
:?oo9P3oooooo`08ooooo`03o`0doooooooooooo00[ooooo00?o0?m<o`1Booooool02oooool00omG
0?ooooooooooo`0cooooo`006_ooool3o`000?oooooo0_ooool01Ol0Vooo0?o0ooooool0ohoo0?o6
00?ooooo00Ko0:7oo`3oOOooooooooooo`1Iool0ooH2ooooo`04o`3oPol0c?oo0?oBo`3oDP;ooooo
00Ko06_oo`29ool0ob;o0?ljooooool0oeT3ooooo`04o`1Bool04?oo08?oo`3oM`;ooooo00Go0>Co
ooooool0:?ooooooo`3oI@03ooooo`06o`3o2_ooooooooooooooool0[_oo04co0oooool00ol0f?oo
ooooooooo`0Pooooo`;o0?l:1?ooool01?l0f?ooooooo`3oUOl0oiD9ooooo`03o`3oIOoooooooooo
00;ooooo0_l0:?l2o`1<o`;ooooo00Co0>Cooooooooooooooooo0_l0[_l6ooooo`03o`23ool0D_oo
05;o00?ooooo0_l0oeT4ooooo`;o0?lj1?ooool3o`0@oa;ooooo00?o0:koooooooooool01?ooool0
0ol0C?ooooooooooo`02o`3odP;o013o4Oooool01?l0;_ooooooooooool0ocX<ooooo`03o`3ol?oo
oooooooo00;ooooo00?o02SooooooolV0?l02Oooool00ol0=?ooooooooooo`0:ooooo`03o`3oC?l0
D_oooooo00_ooooo00?oE`3oooooooooool0<_ooool001[ooooo00?o0000ooooooooool0ooooool3
ooooo`05o`2Kool0ol3oooooo`3oSol0olH00_ooool01ol0XOoo0?mmoooooooooooo0?njo`1Iool0
ooH00_ooool01?l0oh?o0<coo`3od_l0oe82ooooo`05o`1[oooooooo0?lRo`3o>_l0oeT00oooool0
1?l0D_oo013oooooool0Pol3ooooo`04o`3Toooooooo02Soo`3oI@Cooooo00Ko0?l:oooooooooooo
ooooo`2^ool0C?l3ooooo`03o`3Hoooooooooooo01kooooo00?o0?l:ooooooooool00oooool00ol0
f?ooooooo`3oU@09ooooo`;o0?mU1?ooool00ol0:?ooooooo`1<o`03ooooo`03o`3Toooooooo0:ko
00;o0:ko1oooool00ol0Pooo05;oooooo`03ooooo`03o`3oFOoooooooooo00?ooooo00Co0?ljoooo
oooooooooooo0ol04?lFooooo`03o`2^oooooooooooo00?ooooo00Go0?oBo`1<ool0om;oooooo`3o
=002ooooo`03o`0@ool0oh?o0?n300Wo0?n31Ol0c?l00ol0;_oo0<coo`3<o`0=o`3<o`03o`3ol?oo
oooooooo00?ooooo00?o02SoobH0ooooool02?ooool00ol0=?ooooooooooo`0;ooooo`03o`3oC?l0
D_oooooo00[ooooo00?oE`3oooooooooool08_ooool00ol0odcoooooooooo`0=ooooo`006_ooool0
0ol0003oooooooooo`3oooooo`Cooooo00Go09_oo`3o`?oooooo0?n?o`3oaP02ooooo`07o`2Qool0
oggoooooooooool0FOooooooo`3omP02ooooo`03o`3<ool0om;o0?mB00?ooooo00Go06_oo`3o8_l0
oc[oooooo`3oF@03ooooo`04o`1Bool04?oo08?oo`3oM`;ooooo00Go0?ldo`3Toooooooo02Soo`3o
I@04ooooo`;o0?l:00Coooooo`2^ool0oiGo04co0oooool2o`3Hoacooooo0_l0o`X4ooooo`;o0=So
0_l0oiD9ooooo`03o`3oIOoooooooooo00;ooooo0_l0:?l2o`1<o`;ooooo0_l0i?l2o`2^o`Sooooo
0_l0Pol00ol0D_ooooooooooo`02ooooo`03o`3oFOoooooooooo00;ooooo0_l0ocX2ooooo`;o013o
6_ooool00ol0[_oo0?mBo`3odP02o`3odP03o`3oD_l0C?oo0?n300Co0?n300?o0?mBo`0@ool04?l0
0ol0oe86o`3<o`Gooooo00?o02koooooooooool00_ooool2o`3o>P?o0?n31_ooool7o`3<o`03obH0
ool0c?oooooo00Oooooo00?o03Coooooooooool03?ooool00ol0odco05;oooooo`0:ooooo`03oeL0
oooooooooooo01oooooo0_l0od`@ooooo`006_ooool00ol0003oooooooooo`3oooooo`Gooooo00Go
09_oo`3o`?oooooo0?n?o`3oaP02ooooo`0<o`2Qool0oggoooooooooool0FOoo0?ofo`3oc?oooooo
0?n3o`3<ool0om;o0?mB0_ooool01_l0Joooooooo`3o8_l0oc[oooooo`3oF@;ooooo00Co05;oo`0@
oooooooo08?o0oooool01Ol0i?ooooooo`0Xoooooooo0?mU00Gooooo00Go0?l:ooooool0[_oo0?nE
o`1<o`04ooooo`03o`3Hoooooooooooo01Sooooo00?o0?l:ooooooooool00_ooool2o`3Ho`03oooo
ool0oiGooooo00Sooooo0_l0ofD4ooooo`03o`0Xool0C?oo04co00?ooooo00?o0>Coo`2^ool0[_l0
2?ooool01?l0ocCo08?oo`1Bool0D_l3ooooo`;o0?mI0oooool2o`3o>P;ooooo0_l04?lGooooo`Co
0?mB0_l0om800ol0[_oo0?n3o`3oP`03o`3oP`05o`1<ooooooooooooooooool0oc@00_ooool01?l0
c?oo013oo`3<ool0c?l2ooooo`?o0?mB1oooool00ol0;_ooooooooooo`03ooooo`03o`3o>_oooooo
oooo00Co0?n30oooool00ol0oo3oooooooooo`03ooooo`03o`0XoolV0?oo0<co00;o0<co1_ooool0
0ol0=?ooooooooooo`0<ooooo`03o`3oC?l0D_oooooo00Wooooo00?oE`3oooooooooool07_ooool0
0ol0odcoooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`3oooooo`Kooooo00So09_oo`3o
`?oooooo0?n?o`3oa_oooooo0:7oo`3oO@?ooooo00Oo05Woo`3om_ooooooooooo`3oPol0c?oo0?oB
00?ooooo00Go06_oo`3o8_l0oc[oooooo`3oF@03ooooo`04o`1Bool04?oo08?oo`3oM`?ooooo00Co
0>Coooooool0:?oo0?mU1_ooool01Ol0o`[oooooo`2^ool0oiGo04co00Cooooo0_l0f?lFooooo`;o
0?l:0oooool2o`3Ho`03ooooool0oiGo0?nE00Wooooo00?o0?mUo`3o:?ooool00_ooool2o`0Xo`03
o`1<oooooooooooo00;ooooo0_l0[_l8ooooo`;o0?ld00?o08?oo`1Booooool00oooool01?l0oeWo
ooooooooooooool2o`3o>P?ooooo00?o013oooooooooool05?ooool3o`3oDP;ooooo0_l0om82o`3o
P`03o`2^oooooooooooo00Cooooo00?o04coo`3<ool0c?l00ol0c?l2ooooo`03o`0@oooooooooooo
00Cooooo1?l0oe83ooooo`03o`0^ool0olco0?o<00;o0?o<0_ooool00ol0oc[oooooooooo`03oooo
o`?o0?n300?o0?o`o`3oPoooool01?ooool01?lV0?ooooooooooooooool3o`3<o`?ooooo00?o03Co
ooooooooool03Oooool00ol0odco05;oooooo`09ooooo`03oeL0oooooooooooo01cooooo00?o0?m<
ooooooooool04Oooool001[ooooo00?o0000ooooooooool0ooooool7ooooo`04o`2Kool0ol3ooooo
o`3oaP;ooooo00co0:7oo`3oOOooooooooooo`3o^_l0FOoo0?ofooooool0oh?o0<coo`3od_l0oe82
ooooo`06o`1[ool0ROoo0?lRo`3o>_oooooo0?mI0oooool00ol0D_oo013oo`23o`03ooooo`05o`3o
=?l0i?ooooooo`0Xool0ofD01_ooool01Ol0o`[oooooo`2^ool0oiGo04co00Gooooo00?o0=Sooooo
ooooool04Oooool2o`3o2P?ooooo0_l0f?l2ooooo`03o`3oUOoooooooooo00Sooooo00?o0?mUoooo
ooooool00_ooool00ol0:?oo04coooooo`04ooooo`03o`2^oooooooooooo00Kooooo0_l0oc@2o`23
o`03o`1Boooooooooooo00;ooooo00Go0?mIooooooooooooooooo`3o>P03ooooo`;o013o5?ooool3
o`3oDP;ooooo0ol0om85ooooo`03o`2^oooooooooooo00?o0<co00?o04coooooooooool00_ooool0
1Ol0ocCoooooooooool04?oooooo00go0?o<00?o02koooooooooool03Ol0ol`01?l0oo3o0?n3o`3o
Pol0oh<2ooooo`03o`0XoolV0?oooooo00Cooooo0ol0c?l00ooooooo03Coooooo`0>ooooo`03o`3o
C?l0D_oo05;o00Sooooo00?oE`3oooooooooool06oooool00ol0odcoooooooooo`0Booooo`006_oo
ool00ol0003oooooooooo`3oooooo`Sooooo00Co09_oo`3o`?l0ohoo0?o60_ooool03?l0XOoo0?mm
oooooooooooo05Woooooool0ooKoooooo`3oPol0c?oo0?oBo`3oDP;ooooo00Go06_oo`3o8_oooooo
0?ljo`3oF@03ooooo`04o`1Bool04?oo08?oo`3oM`?ooooo00Go0>Cooooooooooooo02Soo`3oI@06
ooooo`05o`3o2_oooooo0:koooooool0C?l01Oooool3o`3Ho`kooooo0_l0o`X2ooooo`?o0=So0_oo
ool2o`3oU@Wooooo0_l0ofD3ooooo`;o02So1Oooool2o`2^o`Sooooo00?o0?ldooooool0Pol00_l0
D_l3ooooo`;o0?mI0_ooool2o`3o>P;ooooo0_l04?lCooooo`?o0?mB0_ooool00ol0oh?o0?oBo`3o
dP08ooooo`03o`3<ool0[_oo0<co00Cooooo00?o04coooooool0ol`01Ol0ol`00ol04?oooooooooo
o`0:ooooo`03o`3oD_l0;_oooooo00Kooooo00?o0?ljooooooooool01Oooool00ol0oo3o0?o<o`3o
c002o`3oc003o`3oPooooooo9P3o00Sooooo00?o0<coo`0dool0c?l03oooool00ol0odcoooooo`1B
o`08ooooo`03oeL0oooooooooooo01Sooooo0_l0od`Eooooo`006_ooool00ol0003oooooooooo`3o
ooooo`Sooooo00So09_oo`3o`?oooooo0?n?o`3oa_oooooo0:7oo`3oO@?ooooo00Oo05Woo`3om_oo
ooooooooo`3<ool0om;o0?mB00;ooooo00Ko06_oo`29ool0ob;o0?ljooooool0oeT3ooooo`03o`1B
ool04?oo08?o00?ooooo00Ko0?ldo`3Toooooooo02Soooooool0ofD6ooooo`;o0?l:00Co0:kooooo
ool0C?oo0?nE1_ooool00ol0f?ooooooooooo`09ooooo`;o0?l:0_ooool2o`3Ho`?ooooo0_l0oiD:
ooooo`06o`3oIOl0obSoooooooooool0C?oo02So1Oooool2o`2^o`Sooooo0_l0oc@00ooooooo08?o
o`1Bo`04ooooo`05o`3oFOooooooooooooooool0ocX00_ooool2o`0@oa;ooooo0ol0oe82ooooo`;o
0?n30_l0om87ooooo`?o0<co0_ooool01?l0[_ooooooooooooooool2o`3oc003o`1<oooooooooooo
00;ooooo00Co0?ldoooooooooooo013o3Oooool00ol0;_ooooooooooo`05ooooo`03o`3o>_oooooo
oooo00Gooooo00Co0?o`oooooooooooooooo0ol0ol`00olV0?oo0?o<o`3oc007ooooo`04o`0dool0
c?oo0<coo`3<o`gooooo0_l0od`00ol0D_ooooooooooo`05ooooo`03oeL0oooooooooooo01Kooooo
0_l0od`Gooooo`006_ooool00ol0003oooooooooo`3oooooo`Wooooo00So09_oo`3o`?oooooo0?n?
o`3oa_oooooo0:7oo`3oO@;ooooo00So0?njo`1Iool0ooKoooooo`3oPol0c?oo0?oBo`3oDP;ooooo
00Go06_oo`3o8_oooooo0?ljo`3oF@03ooooo`04o`1Bool04?ooooooo`23o`?ooooo00Ko0?ldo`3T
oooooooo02Soooooool0ofD7ooooo`03o`3o2_l0[_oo0:ko00;o04co1_ooool4o`3Ho`Cooooo0_l0
o`X5o`3Ho`?ooooo0_l0oiD;ooooo`04o`3oIOooooooooooo`1<o`;o02So1?ooool2o`2^o`03o`3T
oooooooooooo00Kooooo00Go0?ldooooool0Pooo08?oo`1Bo`03ooooo`;o0?mI0_ooool2o`3o>P03
ooooool04?oo013o01;ooooo0_l0oe82ooooo`?o0?n30_l0om86ooooo`?o0<co1Oooool01?l0olco
0:koo`3oc?l0ol`2ooooo`03o`1<oooooooooooo00;ooooo00Go0?ldooooooooooooooooo`0@o`0<
ooooo`03o`0^ool0oe;o0?mB00Kooooo00?o0?ljooooooooool01?ooool00ol0oo3oooooooooo`04
ooooo`03obH0ool0oh?ooooo00Co0?o<0oooool01?l0=?ooooooooooooooool2o`3<o`gooooo00?o
0?m<o`1Booooool01_ooool00omG0?ooooooooooo`0Cooooo`;o0?m<6Oooool001[ooooo00?o0000
ooooooooool0ooooool:ooooo`04o`2Kool0ol3o0?n?o`3oaP;ooooo00_o0:7oo`3oOOoooooooooo
o`1Ioooooooo0?ofooooool0oh?o0<coo`3odP03ooooo`05o`1[ool0ob;o0?ljooooool0oeT00ooo
ool01?l0D_oo013oo`23ool0ogL3ooooo`06o`3Tooooooooooooo`0Xoooooooo0?mU2Oooool00ol0
[_oo0?l:o`1<o`02o`3oU@Oooooo1_l0f?l6ooooo`;o0?nE2oooool2o`3oI@04ooooool0C?oo04co
o`0Xo`?ooooo0ol0[_l00ooooooo0>Coooooo`06ooooo`;o0?ld00Coooooo`23ool0D_oo05;o0ooo
ool01_l0oeWooooooooooooooooo0?ljooooo`;o013o4Oooool3o`3oDP;ooooo0_l0oh<00ooooooo
0?oBo`3odP06ooooo`;o0<co1?ooool4o`3oc0;ooooo00?o0:koooooooooool00_ooool00ol0C?oo
ooooooooo`02ooooo`05o`3o=?ooooooooooooooool04?l02oooool01?l0;_ooooooooooool0oe86
ooooo`03o`3o>_oooooooooo00Cooooo00?o0?o`ooooooooool00oooool01?lV0?oo02Soo`3oPol0
oh<3ooooo`?o0?o<00?o03Coooooooooool00oooool2o`3<o`cooooo00?o0?m<o`1Booooool01Ooo
ool00omG0?ooooooooooo`0Aooooo`;o0?m<6oooool001[ooooo00?o0000ooooooooool0ooooool;
ooooo`07o`2Kool0ol3o0?n?o`3oa_oooooo0:7oo`3oO@03ooooo`07o`1Iool0ooKoooooo`3oPol0
c?oo0?oBo`3oDP02ooooo`06o`1[ool0j_oo0?lRo`3o>_oooooo0?mI0oooool00ol0D_oo013oo`23
o`03ooooo`07o`3o=?l0i?ooooooooooool0:?ooooooo`3oI@09ooooo`05o`2^ool0o`[o04coo`1<
ool0oiD01ol0o`X8ooooo`?o0?nE3?ooool01_l0ofGo0?lXo`1<ool0C?ooooooo`0Xo`;ooooo0_l0
[_l2ooooo`;o0>Co1oooool01Ol0ocCoooooooooool0Pooo05;o00Cooooo00?o0?mIooooooooool0
0_l0ocX00ooooooo013oooooo`0@ooooo`;o0?mB0oooool2o`3oP`03ooooool0om;o0?oB00Kooooo
0_l0c?l3ooooo`?o0?o<1oooool00ol0[_ooooooooooo`02ooooo`03o`1<oooooooooooo00;ooooo
00Go0?ldooooooooooooooooo`0@o`0;ooooo`03o`0^oooooooooooo00;o0?mB1Oooool00ol0oc[o
ooooooooo`03ooooo`03o`3ol?oooooooooo00Cooooo00?o9P3oo`0Xooooool00_l0oh<4ooooo`03
o`3oc?l0=?oo0?o<00Gooooo0ol0c?l;ooooo`03o`1Boooooooooooo00Cooooo00?oE`3ooooooooo
ool03_ooool2o`3oC1gooooo000Jooooo`03o`000?oooooooooo0?oooooo3?ooool01ol0Vooooooo
o`3oSol0olKoooooo`2Qool0ogd00_ooool01ol0ok[o05Woo`3om_oooooo0?n3o`3<ool0om800ooo
ool01_l0Jooo0?lRooooool0oc[oooooo`3oF@;ooooo00Co05;oo`0@ool0Pooo0?mg0oooool01ol0
ocCo0>Cooooooooooooo02Soooooool0ofD02Oooool01?l0[_ooooooooooool0C?l5o`3oU@Kooooo
1?l0oiD=ooooo`05o`3oIOl0C?oo04coo`1<ooooool00_l0:?l00ooooooo0:koo`2^o`03ooooo`03
o`3Toooooooooooo00Gooooo0_l0oc@01?oooooo08?oo`23ool0D_l3ooooo`;o0?mI0_ooool01?l0
oc[oooooo`0@ool04?l@ooooo`;o0?mB0oooool2o`3oP`03ooooool0om;o0?oB00Gooooo0ol0c?l3
ooooo`;o0?o<2_ooool00ol0[_ooooooooooo`02ooooo`03o`1<oooooooooooo00?ooooo00Go0?ld
ooooooooooooooooo`0@o`0:ooooo`03o`0^oooooooooooo00;ooooo00?o0?mBooooooooool00ooo
ool00ol0oc[oooooooooo`02ooooo`03o`3ol?oooooooooo00Cooooo00?o9P3oo`0Xooooool00_oo
ool00ol0oh?oooooooooo`02ooooo`03o`0doooooooo0?o<00;o0?o<1Oooool2o`3<o`[ooooo00?o
05;oo`3oC?l0od`00oooool00omG0?ooooooooooo`0<ooooo`;o0?m<7oooool001[ooooo00?o0000
ooooooooool0ooooool<ooooo`08o`2Kool0ol3oooooo`3oSol0olKoooooo`2Qool0ogd2ooooo`07
o`1Iool0ooKo0?o<ooooool0c?oo0?oBo`3oDP02ooooo`04o`1[ool0j_oo0?lRo`3o>P;ooooo00Oo
0?mIoooooooooooo05;oo`0@ool0Pooo0?mg00?ooooo00Oo0?ldo`3Tooooooooooooo`0Xoooooooo
0?mU00Wooooo0_l0[_l00ooooooo04coo`1<o`02ooooo`Oo0?nE4?ooool2o`1<o`?ooooo00Co02So
o`2^ool0[_oo0:ko1?ooool00ol0i?ooooooooooo`05ooooo`04o`3o=?ooooooooooo`23o`;o05;o
0oooool00ol0oeWoooooooooo`02o`3o>P;o013o4?ooool2o`3oDP?ooooo0_l0oh<2ooooo`03o`3o
d_l0ob;o0?lR00?o0?lR0_l0c?l4o`3o8P;o0?o<1Ol0ob88ooooo`03o`2^oooooooooooo00;ooooo
00?o04coooooooooool00_ooool01Ol0ocCooooooooooooooooo013o00_ooooo00?o02kooooooooo
ool00_ooool2o`3oDPCooooo00?o0?ljooooooooool00_ooool00ol0oo3oooooooooo`04ooooo`03
obH0ool0:?oooooo00;ooooo0_l0oh<3ooooo`04o`0dooooooooooooooooo`;o0?o<1Oooool2o`3<
o`Wooooo00?o05;oooooool0od`00_l0od`00oooooooE`3oooooo`09ooooo`?o0?m<8Oooool001[o
oooo00?o0000ooooooooool0ooooool=ooooo`07o`2Kool0ol3o0?n?ooooool0olKo0:7oo`3oO@02
ooooo`07o`3o^_l0FOoo0?ofooooool0oh?o0<coo`3odP03ooooo`06o`1[ool0ob;oooooo`3o>_oo
oooo0?mI0_ooool01Ol0D_oo013oo`23oooooooo0?mg00;ooooo00?o0?ldo`3Tool0obP00_ooool0
1?l0:?ooooooo`3oIOl0ofD9ooooo`03o`2^oooooooooooo00?o04co4oooool3o`1<o`03o`3o:?oo
oooooooo00;o02So00?o0:koooooooooool01?ooool00ol0i?ooooooooooo`04ooooo`;o0?ld0_oo
ool00ol0Pooo05;oooooo`03ooooo`04o`3oFOooooooooooo`3o>P;o013o4?ooool2o`3oDP?ooooo
0_l0oh<01?oooooo0?lRo`3od_l0om84ooooo`;o0<co0oooool3o`3oc0Oooooo0ol0ob85ooooo`03
o`2^oooooooooooo00;ooooo00?o04coooooooooool00oooool01Ol0ocCooooooooooooooooo013o
00[ooooo00?o02koooooooooool01?ooool2o`3oDP;ooooo00?o0?ljooooooooool00_ooool00ol0
oo3oooooooooo`04ooooo`03obH0ool0:?oooooo00Cooooo0_l0oh<00ooooooo03Coooooo`04oooo
o`?o0?o<1?ooool2o`3<o`Sooooo00Ko05;oooooooooooooooooo`3oC?mG0?l2o`3oC0?ooooo1Ol0
od`Tooooo`006_ooool00ol0003oooooooooo`3oooooo`kooooo00Oo09_oo`3o`?l0ohoo0?o6oooo
ool0XOoo0?mm00;ooooo00Oo05Woooooool0ooKoooooo`3oPol0c?oo0?oB00;ooooo00Co06_oo`3Z
ool0ob;o0?lj0_ooool01ol0oeWoooooooooool0D_oo013oo`23ool0ogL00oooool00ol0ocCo0>Co
o`3o:002ooooo`04o`0Xooooooooooooo`3oI@Wooooo0ol0[_l2ooooo`;o04co3_ooool3o`1<o`;o
0?mU0_ooool00ol0[_oo02Soo`2^o`07ooooo`03o`3Toooooooooooo00?ooooo0_l0oc@2ooooo`;o
08?o00Co05;ooooooooooooooooo0_l0oeT01?oooooo0?ljo`3o>_l04?l@ooooo`;o0?mB0oooool2
o`3oP`;o0?lR0_l0om84ooooo`;o0<co0_ooool3o`3oc0gooooo0ol0ob83ooooo`03o`2^oooooooo
oooo00;ooooo00?o04coooooooooool00oooool01Ol0ocCooooooooooooooooo013o00Wooooo00?o
02koooooooooool01_ooool2o`3oDP03ooooool0oc[ooooo00?ooooo00?o0?o`ooooooooool01?oo
ool00olV0?oo02Soooooo`05ooooo`03o`3oPooooooo03Co00Oooooo0ol0ol`3ooooo`;o0<co1ooo
ool00ol0D_ooooooooooo`02ooooo`03oeL0oooooooo0?m<00?o0?m<:?ooool001[ooooo00?o0000
ooooooooool0ooooool?ooooo`07o`2Koooooooo0?n?o`3oa_oooooo0:7oo`3oO@02ooooo`07o`1I
ool0ooKo0?o<ooooool0c?oo0?oBo`3oDP02ooooo`04o`1[ool0j_ooooooo`3o>P;ooooo00Oo0?mI
oooooooooooo05;oo`0@ool0Pooo0?mg00?ooooo00Ko0?ldo`3Tool0i?oo0?lXooooool0:?l2oooo
o`;o0?mU2_ooool01?l0[_ooooooooooooooool>o`1<o`04ooooool0ofGo0?mUo`3o:0;o0:ko0_l0
:?l7ooooo`;o0>Co1Oooool01Ol0ocCooooooooooooooooo08?o00;o05;o0oooool01?l0oeWooooo
ooooool0ocX2o`0@o`oooooo0_l0oe82ooooo`03o`3oMol0oh?o0?n300;o0?mg0_l0om84o`3oM`;o
0<co0_l0ogL2o`3oc003o`3oMooooooooooo013ooooo0_l0ob800ooooooo0:koooooo`03ooooo`03
o`1<oooooooooooo00Cooooo00Go0?ldooooooooooooooooo`0@o`09ooooo`03o`0^oooooooooooo
00Oooooo0_l0oe801Ol0oc[ooooooooooooooooo0?o`00Kooooo00?o9P3oooooool0:?l01_ooool0
0ol0oh?o03Coooooo`09ooooo`;o0?o<0oooool2o`3<o`Kooooo00Go05;ooooooooooooooooooeL0
o`0]ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000[ooooo00?o0000
ooooooooool0ooooool@ooooo`06o`2Kool0ohooooooo`3oa_l0XOoo0?mm0_ooool01ol0ok[o05Wo
o`3om_oooooo0?n3o`3<ool0om800oooool01?l0Jooo0?lRooooool0ocX2ooooo`07o`3oFOoooooo
0?Koo`0@oooooooo08?oo`3oM`03ooooo`06o`3o=?oooooo0>Coo`3o:?oooooo02So0oooool00ol0
ofGoooooooooo`08ooooo`Co0:ko3Oooool01_l0ofGo0:koo`2^ool0[_ooooooo`0Xo`Sooooo00?o
0>Coooooooooool00oooool2o`3o=0?ooooo00?o08?oo`1Booooool00oooool01Ol0oeWoooooo`3o
>_l0oc[o013o00oooooo0_l0oe801_oooooo0?mgo`3oMol0ogOo0?n3o`3o8P;ooooo00?o0?oBoooo
ooooool00_ooool2o`3<o`;ooooo0_l0ol`3ooooo`?o0?mg4Oooool00ol0ob;oooooo`2^o`04oooo
o`03o`1<oooooooooooo00?ooooo00?o0?ldooooooooool00_ooool00ol04?ooooooooooo`06oooo
o`03o`0^oooooooooooo00Wooooo00Go0?mBo`3o>_ooooooooooo`3ol006ooooo`03obH0oooooooo
02So00Sooooo00?o03Coo`3oPoooool02Oooool3o`3oc0;ooooo0_l0c?l5ooooo`05o`1Boooooooo
oooooooooomG0?l0;?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool0ooooool@ooooo`07o`2Kool0ol3o0?n?ooooool0
olKo0:7oo`3oO@02ooooo`07o`1Iool0ooKo0?o<ooooool0c?oo0?oBo`3oDP02ooooo`04o`1[ool0
j_oo0?lRo`3o>P;ooooo00Oo0?mIoooooooooooo0?Koo`0@ool0Pooo0?mg00Cooooo00?o0?ldoooo
ool0i?l00_l0obP01Ol0:?oooooooooooooooooo0?mU00gooooo3_l0[_l2ooooo`;o02So1oooool2
o`3To`Cooooo0_l0oc@3ooooo`03o`23ool0D_oo05;o00?ooooo0_l0oeT01?oooooo0?ljo`0@ool0
4?l?ooooo`Co0?mg00?o0?lRo`3oPol0oh<00_ooool2o`3odP?ooooo0_l0c?l2ooooo`;o0?o<2?oo
ool3o`3oM`Kooooo2_l0ooH00ol0[_oo0?ofo`3omP02o`3omP03o`1<ool0ooKooooo00Cooooo00?o
0?ldooooooooool00_ooool00ol04?ooooooooooo`06ooooo`03o`0^oooooooooooo00Wooooo00Go
0?mBo`3o>_ooooooooooo`3ol006ooooo`03obH0oooooooo02So00Oooooo00Co03Coooooool0oh?o
0?n32oooool2o`3oc0;ooooo0_l0c?l4ooooo`04o`1BoooooooooooooeL0obcooooo00001Ooooooo
0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000009ooooo`Co0000ooooool@
ooooo`0?o`2Koooooooo0?n?o`3oa_oooooo0:7oo`3oOOoooooo0?njo`1Iool0ooKo0?o<ooooool0
c?oo0?oB00?ooooo00Co06_oo`3o8_oooooo0?lj0_ooool01ol0oeWoooooo`3fool04?ooooooo`23
ool0ogL01?ooool01Ol0ocCoooooo`3Toooooooo0?lX00;o02So0_ooool3o`3oIA;ooooo0ol0ofD0
0ol0obSoooooooooo`02o`0Xo`Oooooo0_l0i?l5ooooo`03o`3o=?oooooooooo00;ooooo00?o08?o
o`1Booooool00oooool01Ol0oeWoooooo`3o>_l0oc[o013o00gooooo1?l0ogL00ooooooo0?lRo`3o
8P02o`3oP`?ooooo00Co0?oBoooooooooooooooo0_l0c?l2ooooo`;o0?o<3Oooool00ol0ogOo0?of
o`3omP03o`3omP_ooooo00?o0:koooooooooool00_ooool00ol0C?oo0?ofo`3omP03ooooo`03o`3o
=?oooooooooo00?ooooo00?o013oooooooooool01Oooool00ol0;_ooooooooooo`0:ooooo`04o`3o
D_l0oc[oooooo`3ol0Kooooo00?o9P3oooooool0:?l01oooool01Ol0=?oooooooooooooooooo0?n3
00cooooo0_l0ol`2ooooo`;o0<co0oooool01?l0D_oooooooooooomG0?l[ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`Co00002_ooool00ol0003oooooooooo`3ooooooa;ooooo00Ko09_o
ooooool0ohoo0?o6o`2Qool0ogd2ooooo`07o`3o^_l0FOoo0?ofooooool0oh?o0<coo`3odP02oooo
o`05o`1[ool0j_oo0?lRooooool0ocX00_ooool01ol0oeWoooooo`3fool04?ooooooo`23ool0ogL0
1?ooool01?l0ocCoooooo`3Tooooool2o`3o:003o`0Xoooooooooooo00;ooooo0ol0ofD<ooooo`?o
0?mU0_l0obP3ooooo`03o`0Xoooooooooooo00Kooooo00?o0>Coooooooooool00oooool2o`3o=0?o
oooo0_l0Pol01?l0D_ooooooooooooooool2o`3oF@04ooooool0oc[o013oo`0@o`cooooo0_l0ogL0
0ooooooo0?mBooooo`02o`3o8P03ooooool0oh?ooooo00;ooooo0_l0om83ooooo`03o`3<oooooooo
oooo00;o0?o<2_ooool6o`3omP03ooooool0ogOooooo00gooooo00?o0:koo`3o8_l0ob800_ooool0
0ol0C?ooooooooooo`03o`3omP03ooooool0ocCooooo00?ooooo00?o013oooooooooool01Oooool0
0ol0;_ooooooooooo`0;ooooo`04o`3oD_l0oc[oooooo`3ol0Kooooo00?o9P3oooooool0:?l01ooo
ool01?l0=?ooooooooooooooool2o`3oP`cooooo0_l0ol`2ooooo`;o0<co0_ooool00ol0D_oooooo
oeL0o`0[ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0oooooolCooooo`06o`2Kool0ohooooooo`3oa_l0XOoo0?mm0_ooool01_l0
FOoo0?ofo`3oc?oooooo0<coo`3odP?ooooo00Co06_oo`3Zool0ob;o0?lj0_ooool02?l0oeWooooo
ooooool0m_oo013oooooool0Pooo0?mg1?ooool01_l0ocCoooooo`3Tool0i?ooooooo`3o:0;o02So
1Oooool<o`3oI@?o0?lX0_ooool3o`0Xo`Oooooo0_l0i?l4ooooo`;o0?ld1?ooool00ol0Pooo05;o
o`1Bo`03ooooo`05o`3oFOoooooo0?ljo`3o>_l04?l03Oooool01?l0ogOoooooo`3oD_l0oe82o`3o
8P03ooooool0oh?o0?n300?ooooo00Co0?oBoooooooooooooooo0_l0c?l2ooooo`03o`3oc?oooooo
oooo00Oooooo0ol0ooH8ooooo`;o0?mg3Oooool00ol0[_ooooooo`3o8P02ooooo`03o`1<oooooooo
oooo00;ooooo0_l0ooH00ol0ocCoooooooooo`02ooooo`03o`0@oooooooooooo00Gooooo00?o02ko
ooooooooool02oooool00ol0oe;o0?ljo`3ol006ooooo`03obH0oooooooo02So00Oooooo00?o03Co
ooooooooool00oooool2o`3oP`cooooo0_l0ol`2ooooo`;o0<co00Coooooo`1BooooooooE`3o:_oo
ool00005ooooool0003oooooooooool000002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0?oooooo5?ooool03_l0Vooo0?n?ooooool0olKo0:7oo`3oOOoooooo0?njo`1Iool0ooKo
ooooo`3oPol0c?oo0?oB0_ooool01Ol0ROoo06_oo`3o8_oooooo0?lj00;ooooo00Oo0?mIooooool0
m_ooooooo`0@oooooooo08?o00Gooooo0_l0oc@00ooooooo0>Coooooo`02o`3o:0;o02So3?ooool3
o`3o:0;ooooo0ol0:?l8ooooo`;o0>Co1Oooool00ol0ocCoooooooooo`02ooooo`;o08?o00Co05;o
oooooooooooooooo0_l0oeT01?oooooo0?ljo`0@ool04?l<ooooo`;o0?mg00Goooooo`3oD_oooooo
0?lRooooo`02o`3oP`?ooooo0_l0om83ooooo`03o`3<oooooooooooo00;o0?o<1oooool3o`3omPgo
oooo00?o0?mgooooooooool02_ooool01_l0[_ooooooooooool0ob;oooooo`1<o`Kooooo0ol0ooH3
ooooo`03o`0@oooooooooooo00Cooooo00?o02koooooooooool03?ooool00ol0oe;o0?o`ooooo`06
ooooo`03obH0oooooooo02So00Oooooo00?o03Coooooooooool01?ooool00ol0oh?oooooooooo`0;
ooooo`;o0?o<0_ooool2o`3<o`03o`1BoomG0?oooooo02Wooooo0002ooooo`;o00002_ooool2o`00
00[ooooo00?o0000ooooooooool0oooooolDooooo`06o`2Koooooooo0?n?o`3oa_l0XOoo0?mm0_oo
ool01ol0FOoo0?ofo`3oc?oooooo0<coo`3od_l0oe800_ooool01Ol0Jooo0>[oo`3o8_oooooo0?lj
00;ooooo00Oo0?mIooooool0m_ooooooo`0@oooooooo08?o00Kooooo00Co0?ldooooool0i?oo0>Co
0_ooool00ol0obSo02Soo`0Xo`02o`0Xo`?ooooo1Ol0obP2ooooo`?o02So2_ooool00ol0i?oooooo
ooooo`03ooooo`;o0?ld1?ooool00ol0Pooo05;oo`1Bo`03ooooo`05o`3oFOooooooooooo`3o>_l0
4?l02oooool3o`3oM`03ooooool0oe;o0?mB00;o0?lR00?oooooo`3oPoooool00oooool01?l0om;o
ooooooooooooool2o`3<o`03ooooool0olco0?o<00Oooooo0_l0ooHAooooo`03o`3oMooooooooooo
00[ooooo00Ko0:kooooooooooooo0?lRooooool0C?l6ooooo`06o`3o=?oooooo0?ofo`3om_oooooo
013o1oooool00ol0;_ooooooooooo`0<ooooo`03o`3oD_l0oo3ooooo00Gooooo00?o9P3oooooool0
:?l01oooool00ol0=?ooooooooooo`05ooooo`;o0?n33Oooool2o`3oc0;ooooo00?o0<coo`1BoomG
0?l0:Oooool001[ooooo00?o0000ooooooooool0oooooolEooooo`0>o`2Kool0ohooooooo`3oa_l0
XOoo0?mmooooool0ok[o05Woo`3om_l0olcoooooo`3<ool0om83ooooo`0>o`1[oooooooo0?lRoooo
ool0oc[oooooo`3oFOoooooo0?Koooooool04?oo05;oooooool0Pol6ooooo`04o`3o=?oooooooooo
o`3To`Kooooo2_l0:?l;ooooo`;o0>Co1?ooool2o`3o=0Cooooo0_l0Pol01?l0D_oooooooooooooo
ool2o`3oF@04ooooool0oc[o013oo`0@o`Wooooo0ol0ogL2ooooo`;o0?mB0_l0ob800ooooooo0?n3
o`3oP`03ooooo`;o0?oB0oooool01?l0c?ooooooo`3oc?l0ol`6ooooo`?o0?of4oooool00ol0ogOo
ooooooooo`0:ooooo`06o`2^ooooooooooooooooool0ob;o04co1_ooool01?l0ocCooooooooooooo
ool2o`3omP03o`0@oooooooooooo00Cooooo00?o02koooooooooool03Oooool00ol0oo3o0?ljoooo
o`04ooooo`04obH0ooooooooooooo`0Xo`Oooooo00?o03Coooooooooool01_ooool2o`3oP`gooooo
0_l0ol`2ooooo`03oeL0ool0c?oooooo02Oooooo000Jooooo`03o`000?oooooooooo0?oooooo5_oo
ool03_l0Vooo0?n?ooooool0XOooooooo`3oOOoooooo0?njo`1Iool0olcoooooo`3oPol0c?oo0?oB
0_ooool01Ol0Jooo0>[oooooool0ob;o0?lj00;ooooo00So0?mIooooool0m_ooooooo`0@ool0D_oo
0?mgo`23o`Kooooo00?o0?ldooooooooool00ol0i?lEooooo`?o0>Co1Oooool00ol0ocCooooooooo
o`03ooooo`03o`23ool0D_oo05;o00?ooooo00?o0?mIooooooooool00_l04?l9ooooo`;o0?mg1?oo
ool00ol0oe;o0?lRo`3o8P02ooooo`03o`3oPooooooooooo00;ooooo00Co0?oBoooooooooooooooo
0_l0c?l2o`3oc0Kooooo0_l0ooHGooooo`03o`3oMooooooooooo00[ooooo00Ko0:kooooooooooooo
ooooo`3o8_l0C?l6ooooo`03o`3o=?oooooooooo00;ooooo00?o013oo`3om_ooool01?ooool00ol0
;_ooooooooooo`0>ooooo`03o`3ol?l0oc[ooooo00Cooooo00Co9P3ooooooooooooo02So1_ooool0
0ol0=?ooooooooooo`08ooooo`03o`3oPooooooooooo00cooooo0_l0ol`01?ooooooE`3oo`3<ool0
c?lVooooo`006_ooool00ol0003oooooooooo`3ooooooaKooooo00oo09_oooooool0ohoo0?o6o`2Q
ool0oggoooooo`3o^_l0FOoo0?ofo`3oc?oooooo0<coo`3od_l0oe800_ooool01Ol0Jooo0>[oo`3o
8_oooooo0?lj00;ooooo00So0?mIooooool0m_ooooooo`0@ool0D_oo0?mgo`23o`Kooooo00?o0?ld
ooooooooool00_ooool00ol0i?ooooooooooo`0@ooooo`;o0>Co1_ooool2o`3o=0Cooooo0_l0Pol0
1?l0D_ooooooooooooooool2o`3oF@03ooooool0oc[o013o00Wooooo0_l0ogL4ooooo`;o0?mB00Go
0?lRooooooooooooooooo`3oP`03ooooo`;o0?oB0oooool00ol0c?oo0?o<o`3oc006ooooo`;o0?of
6_ooool00ol0ogOoooooooooo`09ooooo`06o`2^ooooooooooooooooool0ob;o04co1oooool00ol0
ocCoooooooooo`02ooooo`03o`0@ool0ooKooooo00Cooooo00?o02koooooooooool03Oooool00ol0
oo3o0?mBo`3o>P04ooooo`04obH0ooooooooooooo`0Xo`Oooooo00?o03Coooooooooool02?ooool2
o`3oP`kooooo00Co0?o<oeL0ool0D_oooooo0_l0c?lTooooo`006_ooool00ol0003oooooooooo`3o
oooooaOooooo00ko09_oo`3oSooooooo0?o6o`2Qool0oggoooooo`3o^_l0FOoo0?ofo`3oc?oooooo
0<coo`3odP;ooooo00So08Woo`1[oooooooo0?lRooooool0oc[oooooo`3oF@;ooooo00Go0?Kooooo
ool04?oo05;oo`23o`07ooooo`?o0?ld0_ooool3o`3To`cooooo0ol0i?l6ooooo`;o0?ld1?ooool2
o`23o`;o05;o0oooool00ol0oeWoooooooooo`02o`0@o`Sooooo0_l0ogL5ooooo`03o`3oD_l0ob;o
oooo00;ooooo0_l0oh<3ooooo`04o`3od_ooooooooooooooo`;o0<co00?o0?o<ooooooooool01?oo
ool2o`3omQgooooo00?o0?mgooooooooool02Oooool01_l0[_oooooooooooooooooo0?lRo`1<o`Ko
oooo00?o0?ldooooooooool00oooool00ol04?oo0?ofo`3omP03ooooo`03o`0^oooooooooooo00ko
oooo00?o0?o`o`3oD_l0ocX01?ooool01?lV0?ooooooooooool0:?l7ooooo`03o`0doooooooooooo
00Wooooo00?o0?n3ooooooooool03Oooool01?mG0?oo05;oooooooooool2o`3<ob;ooooo000Joooo
o`03o`000?oooooooooo0?oooooo5oooool01_l0Voooooooo`3oSol0olKo0:7oo`3oO@;ooooo00Oo
05Woo`3om_l0olcoooooo`3<oooooooo0?oB00;ooooo00Go06_oo`3Zoooooooo0?lRo`3o>P02oooo
o`03o`3oFOoooooo0?Ko00;ooooo00?o013oo`1Bool0Pol02Oooool00ol0ocCoooooooooo`02oooo
o`co0>Co1_ooool3o`3o=0Cooooo0_l0Pol00ooooooo05;oooooo`02ooooo`;o0?mI0_ooool00ol0
4?ooooooooooo`06ooooo`;o0?mg1Oooool2o`3oDP05o`3o8_ooooooooooooooool0oh<00oooool2
o`3odP?ooooo00?o0<coo`3oc?ooool01Oooool2o`3omR3ooooo00?o0?mgooooooooool02?ooool0
0ol0[_ooooooooooo`02ooooo`03o`1<oooooooooooo00Gooooo00?o0?ldooooooooool00_ooool0
1?l04?ooooooooooool0ooH3ooooo`03o`0^oooooooooooo00gooooo00?o0?o`o`3oD_l0ocX01?oo
ool01?lV0?ooooooooooool0:?l7ooooo`03o`0doooooooooooo00[ooooo00?o0?n3ooooooooool0
3?ooool01?mG0?ooooooo`1Bool0D_l2ooooo`?o0<co7oooool001[ooooo00?o0000ooooooooool0
oooooolHooooo`0?o`2Koooooooo0?n?o`3oa_l0XOoo0?mmooooool0ok[o05Woo`3om_l0olcooooo
o`3<ool0om;o0?mB00;ooooo00Go06_oooooool0ob;oooooo`3o>P02ooooo`03o`3oFOoooooo0?Ko
00;ooooo00Co013oo`1Bool0Pooo08?o2?ooool4o`3o=0kooooo1?l0oc@6ooooo`04o`23oooooooo
ooooo`1Bo`?ooooo00?o0?mIooooooooool00_l04?l7ooooo`;o0?mg1_ooool00ol0oe;o0?lRoooo
o`02ooooo`;o0?n30oooool01?l0om;oooooooooooooool2o`3<o`03o`3oc?oooooooooo00?ooooo
0_l0ooHSooooo`03o`3oMooooooooooo00Sooooo00?o0:koooooooooool00_ooool00ol0C?oooooo
ooooo`04ooooo`03o`3o=?oooooooooo00?ooooo00Co013ooooooooooooo0?of0_ooool00ol0;_oo
ooooooooo`0>ooooo`03o`3ol?l0oe;o0?lj00Cooooo00Co9P3ooooooooooooo02So1oooool00ol0
=?ooooooooooo`0:ooooo`;o0?n33Oooool01OmG0?ooooooooooool0D_oo0?o<00?ooooo0_l0c?lM
ooooo`006_ooool00ol0003oooooooooo`3ooooooaWooooo00ko09_oo`3oSooooooo0:7oooooool0
oggoooooo`3o^_l0FOooooooo`3oc?oooooo0<coo`3odP;ooooo00Ko06_oo`3Zoooooooo0?lRoooo
ool0ocX2ooooo`03o`3oFOoooooo0?Ko00;ooooo0_l04?l00ol0ogOo08?oo`23o`0:ooooo`Go0?ld
0oooool6o`3o=0Sooooo0_l0Pol00ooooooo05;oo`1Bo`02ooooo`;o0?mI00?oooooo`0@ool04?l0
1oooool2o`3oM`Kooooo0_l0oe84ooooo`04o`3oPoooooooooooooooo`;o0?oB0oooool00ol0c?oo
0?o<ooooo`04ooooo`;o0?of9_ooool00ol0ogOoooooooooo`07ooooo`03o`2^oooooooooooo00;o
oooo00?o04coo`3o8_ooool01Oooool00ol0ocCoooooooooo`02ooooo`07o`0@oooooooooooooooo
ool0ooKoooooo`0^o`0@ooooo`04o`3ol?oooooo0?mBo`3o>P?ooooo00Co9P3ooooooooooooo02So
2?ooool00ol0=?ooooooooooo`0;ooooo`03o`3oPooooooooooo00_ooooo00CoE`3ooooooooooooo
05;o0ol0ol`2ooooo`;o0<co6oooool001[ooooo00?o0000ooooooooool0oooooolIooooo`0?o`2K
oooooooo0?n?o`3oa_l0XOoo0?mmooooool0ok[o05Woo`3om_l0olcoooooo`3oPol0c?oo0?oB00;o
oooo00Ko06_oo`3Zoooooooo0?lRooooool0ocX2ooooo`03o`3oFOoooooo0?Ko00?ooooo00Co013o
o`1Bool0ogOo08?o3Oooool5o`3o=0_ooooo0_l0Pol2ooooo`06o`1Booooooooooooooooool0oeWo
oooo0_l04?l00ol0oc[oooooooooo`03ooooo`?o0?mg1oooool00ol0oe;o0?lRooooo`02ooooo`;o
0?n30_ooool2o`3odP?ooooo0_l0c?l00ol0olcoooooooooo`02ooooo`;o0?of:?ooool00ol0ogOo
ooooooooo`08ooooo`07o`2^ooooooooooooooooool0C?ooooooo`3o8P05ooooo`03o`3o=?oooooo
oooo00?ooooo00Oo013oooooooooooooooooo`3om_oooooo02ko013ooooo00Co0?o`ooooool0oe;o
0?lj0_ooool01OlV0?oooooooooooooooooo02So00Oooooo00?o03Coooooooooool03?ooool2o`3o
P`cooooo00CoE`3ooooooooooooo05;o0_ooool3o`3oc003ooooool0c?oo0<co01Wooooo000Joooo
o`03o`000?oooooooooo0?oooooo6_ooool05?l0Voooooooo`3oSol0olKo0:7oo`3oOOoooooo0?nj
o`1Iool0ooKo0?o<ooooool0c?oo0?oBo`3oD_oooooo08Woo`1[oooooooo0?lR0_ooool01_l0oc[o
ooooooooool0oeWoooooo`3fo`?ooooo0_l04?l00ol0ogOo08?oooooo`0Iooooo`;o08?o0_ooool2
o`1Bo`;ooooo0_l0oeT2o`0@o`;o0?lj1?ooool2o`3oM`Sooooo0_l0oe84ooooo`05o`3oPooooooo
ooooooooool0om801?ooool00ol0c?oo0?o<ooooo`04ooooo`04o`3om_ooooooooooooooo`co0?Ko
7?ooool00ol0ogOoooooooooo`07ooooo`03o`2^oooooooooooo00;ooooo00?o04coooooool0ob80
1Oooool00ol0ocCoooooooooo`02ooooo`03o`0@oooooooooooo00;ooooo00?o0?ofo`0^ooooool0
3oooool01Ol0oo3oooooooooool0oe;o0?lj00;ooooo00Co9P3ooooooooooooo02So2?ooool00ol0
=?ooooooooooo`0=ooooo`03o`3oPooooooooooo00Wooooo00GoE`3oooooooooooooooooo`1Bo`04
ooooo`?o0?o<0_l0c?lGooooo`006_ooool00ol0003oooooooooo`3ooooooa[ooooo01Go09_oo`3o
`?l0ohoo0?o6o`2Qoooooooo0?mmooooool0ok[o05Woo`3om_l0olcoooooo`3<ool0om;o0?mBoooo
ool0Jooo0>[oooooool0ob800_ooool00ol0oc[oooooooooo`02o`3oF@03o`3foooooooooooo00;o
oooo00?o013oo`1Bool0Pol00_l0PolFooooo`03o`23oooooooo05;o00;o05;o0oooool01Ol0oeWo
013oo`0@oooooooo0?lj00Cooooo0_l0ogL8ooooo`03o`3o8_l0oe;ooooo00?ooooo0_l0oh<2oooo
o`;o0?oB0oooool2o`3<o`03o`3oc?oooooooooo00;ooooo00?o0?ofo`3fool0m_l00ol0m_l<oooo
o`Co0?Ko6Oooool00ol0ogOoooooooooo`07ooooo`05o`2^ooooooooooooooooool0C?l00_ooool0
0ol0ob;oooooooooo`03ooooo`03o`3o=?oooooooooo00;ooooo00?o013oooooooooool00_ooool0
0ol0ooKo02koooooo`0?ooooo`07o`3ol?ooooooooooo`3oD_l0oc[oooooobH0o`03ooooo`03o`0X
oooooooooooo00Gooooo00?o03Coooooooooool03_ooool2o`3oP`[ooooo00GoE`3ooooooooooooo
ooooo`1Bo`06ooooo`;o0?o<0ol0c?lDooooo`006_ooool00ol0003oooooooooo`3ooooooa_ooooo
01;o09_oooooool0ohoo0?o6o`2Qool0oggoooooo`3o^_l0FOoo0?ofo`3oc?oooooo0?n3o`3<ool0
om;o0?mBooooool0Jol2ooooo`04o`3o8_ooooooooooo`3o>P?ooooo00?o0?mIo`3fooooool00ooo
ool2o`0@o`04o`3oMooooooo08?oo`23oa;ooooo0_l0Pol2o`1Bo`Cooooo00Co0?mIo`0@ool04?oo
oooo0_l0ocX2ooooo`?o0?mg2Oooool2o`3oDPCooooo00Go0?n3ooooooooooooooooo`3odP04oooo
o`03o`3<ool0olcooooo00;ooooo1?l0m_lEooooo`?o0?Ko5_ooool00ol0ogOoooooooooo`07oooo
o`03o`2^oooooooooooo00;ooooo00?o04coooooool0ob801Oooool00ol0ocCoooooooooo`02oooo
o`03o`0@oooooooooooo00?ooooo00?o02koooooooooool03oooool01ol0oo3oooooooooool0oe;o
0?ljoooooolV0?l00oooool00ol0:?ooooooooooo`05ooooo`03o`0doooooooooooo00oooooo00?o
0?n3ooooooooool02?ooool01?mG0?ooooooooooooooool2o`1Bo`Oooooo0_l0ol`2o`3<oa;ooooo
000Jooooo`03o`000?oooooooooo0?oooooo7?ooool04_l0Vooo0?n?ooooool0XOooooooo`3oOOoo
oooo0?njo`1Iool0ooKo0?o<ooooool0oh?o0<coo`3od_oooooo08Woo`1[o`;ooooo00Co0?lRoooo
oooooooo0?lj0oooool00ol0oeWo0?Koooooo`04ooooo`04o`0@ool0D_oo05;oooooo`Co08?o2?oo
ool5o`23o`?o05;o1?ooool00ol0oeWo013oo`0@o`02ooooo`03o`3o>_oooooooooo00;o0?mg2_oo
ool00ol0ob;o0?mBooooo`04ooooo`03o`3oPooooooooooo00;o0?oB1?ooool00ol0c?oo0?o<o`3f
o`03o`3fo`03o`3om_oooooooooo00cooooo4?l0JolDooooo`03o`3oMooooooooooo00Oooooo00Go
0:koooooooooooooooooo`1<o`02ooooo`03o`3o8_oooooooooo00?ooooo00?o0?ldooooooooool0
0_ooool00ol04?ooooooooooo`02ooooo`03o`0^ool0ooKooooo00oooooo00Oo0?o`oooooooooooo
ooooo`3oD_l0oc[o9P3o00?ooooo00?o02Soooooooooool01_ooool00ol0=?ooooooooooo`0?oooo
o`;o0?n32Oooool00omG0?ooooooooooo`02ooooo`03o`1Boooooooooooo00Oooooo00?o0?o<o`3<
ool0c?l04?ooool001[ooooo00?o0000ooooooooool0oooooolLooooo`0;o`2Kool0ol3o0?n?o`3o
a_l0XOooooooo`3oOOoooooo0?njo`1Iool0ooH00_ooool01_l0c?ooooooo`3od_oooooo06_oo`3Z
o`;ooooo00?o0?lRooooooooool00_l0ocX3ooooo`;o0?Ko1?ooool00ol04?ooooooo`1Bo`04oooo
o`So08?o0oooool2o`1Bo`Gooooo00?o0?mIo`0@ool04?l00oooool01?l0oc[o0?mgo`3oMol0ogL:
ooooo`03o`3o8_l0oe;o0?mB00Cooooo0_l0oh<2ooooo`03o`3od_oooooooooo00;ooooo0_l0c?l2
o`3fo`;ooooo0_l0ooH9ooooo`Ko06_o3oooool00ol0m_oo06_oo`1[o`03o`1[oa3ooooo00?o0?mg
ooooooooool01_ooool00ol0[_ooooooooooo`02ooooo`04o`1<ooooooooooooo`3o8PCooooo00?o
0?ldooooooooool00_ooool00ol04?ooooooooooo`03ooooo`03o`0^ool0ooKooooo00oooooo00Oo
0?o`ooooooooooooooooo`3oD_oooooo9P3o00?ooooo00?o02Soooooooooool01Oooool00ol0=?oo
ooooooooo`0Aooooo`03o`3oPooooooooooo00Oooooo00?oE`3oooooooooool00_ooool00ol0D_oo
ooooooooo`09ooooo`03o`3<oooooooooooo00gooooo000Jooooo`?o0000oooooolMooooo`06o`2K
oooooooo0?n?o`3oa_l0XOoo0?mm0_ooool02_l0FOooooooo`3om_oooooo0?n3o`3<ool0om;o0?mB
o`29ool0Jol3ooooo`05o`3o8_ooooooooooooooool0ocX00oooool00ol0oeWo0?Koooooo`03oooo
o`;o013o3ol0D_l5ooooo`03o`3oFOl04?oo013o00?ooooo0ol0ogL<ooooo`;o0?mB1Oooool00ol0
oh?oooooooooo`02o`3odP?ooooo00?o0?Koo`3<ool0m_l00oooool2o`3omPSooooo0ol0JolHoooo
o`;o0?Ko00?oooooo`1[ooooool03_ooool00ol0ogOoooooooooo`07ooooo`05o`2^oooooooooooo
ooooool0C?l00oooool00ol0ob;oooooooooo`02ooooo`03o`3o=?oooooooooo00;ooooo00?o013o
ooooooooool00_ooool00ol0;_ooooooo`3omP0?ooooo`03o`3ol?oooooooooo00;ooooo00?o0?mB
obH0ooooool00_ooool00ol0:?ooooooooooo`06ooooo`03o`0doooooooooooo017ooooo00?o0?n3
ooooooooool01_ooool00omG0?ooooooooooo`03ooooo`03o`1Boooooooooooo01Sooooo000Joooo
o`03o`000?oooooooooo0?oooooo7Oooool04ol0Vooo0?o0o`3oSol0olKo0:7oooooool0oggooooo
o`3o^_l0FOoo0?ofo`3oc?oooooo0?n3o`3<ool0om;o0?mBo`29ool0Jol00oooool2o`3o8P;ooooo
0_l0ocX3ooooo`03o`3foooooooooooo00?ooooo1?l04?l2o`3oM`[ooooo1Ol04?l2ooooo`?o0?mg
3Oooool00ol0ob;o0?mBooooo`04ooooo`;o0?n30_ooool00ol0om;oooooooooo`02o`3fo`;o0<co
1?ooool00ol0ooKoooooooooo`05ooooo`?o06_o5Oooool:o`1Io`03o`1[oooooooooooo00gooooo
00?o0?mgooooooooool01_ooool00ol0[_ooooooooooo`02ooooo`04o`1<ooooooooooooo`3o8PGo
oooo00?o0?ldooooooooool00_ooool00ol04?ooooooooooo`02ooooo`03o`0^ool0ooKooooo00oo
oooo00?o0?o`ooooooooool00_ooool00ol0oe;o9P3oooooo`02ooooo`03o`0Xoooooooooooo00Go
oooo00?o03Coooooooooool04_ooool2o`3oP`Oooooo00?oE`3oooooooooool00oooool00ol0D_oo
ooooooooo`0Gooooo`006_ooool00ol0003oooooooooo`3ooooooakooooo00_o09_oooooool0ohoo
0?o6o`2Qoooooooo0?mmooooool0ok[o05Woo`3omP02ooooo`06o`3<oooooooo0?oBo`3oD_l0Jooo
0>[o1?ooool01Ol0ob;ooooooooooooooooo0?lj00?ooooo00?o0?Koo`3oFOl0oeT01_ooool<o`0@
o`Oo0?mg00?o0?ljooooooooool02oooool00ol0ob;o0?mBo`3oDP05ooooo`04o`3oPooooooooooo
o`3odPCo0?Ko00?oooooo`3<ool0ol`00oooool2o`3omPKooooo0_l0JolAooooo`Oo05Wo2Oooool0
0ol0m_oo05Woo`1Io`03o`1Io`cooooo00?o0?mgooooooooool01_ooool01Ol0[_oooooooooooooo
oooo04co00?ooooo00?o0?lRooooooooool00_ooool00ol0ocCoooooooooo`02ooooo`03o`0@oooo
oooooooo00;ooooo00?o02koooooool0ooH03oooool00ol0oo3oooooooooo`03ooooo`05obH0oooo
ooooooooooooool0:?l02?ooool00ol0=?ooooooooooo`0Cooooo`03o`3oPooooooooooo00Gooooo
00?oE`3oooooooooool00oooool00ol0D_ooooooooooo`0Fooooo`006_ooool00ol0003ooooooooo
o`3ooooooaoooooo00Ko09_oooooool0ohoo0?o6o`2Qool0ogd2ooooo`0;o`1Ioooooooo0?ofoooo
ool0oh?o0<coooooool0om;o0?mBo`1[ool0j_l01?ooool01?l0ob;oooooooooooooool2o`3o>P;o
oooo00?o0?Koooooool0oeT00_l0oeT:ooooo`04o`3oFOl0ogOo0?mgo`3oM`;o0?mI0oooool2o`3o
>Pgooooo0_l0ob800ol0oe;oooooooooo`03ooooo`;o0?n300Coooooo`3fool0m_oo0?Ko0oooool2
o`3<o`?ooooo0_l0ooH5ooooo`?o06_o4?ooool3o`1Ioa7ooooo00Go0?Koooooooooooooooooo`1[
o`03o`1Io`Wooooo00?o0?mgooooooooool01_ooool00ol0[_ooooooooooo`02ooooo`05o`1<oooo
ooooooooooooool0ob801?ooool00ol0ocCoooooooooo`02ooooo`03o`0@oooooooooooo00;ooooo
00?o02koooooool0ooH03oooool00ol0oo3oooooooooo`03ooooo`05obH0ooooooooooooooooool0
:?l02?ooool00ol0=?ooooooooooo`0Cooooo`;o0?n31_ooool00omG0?ooooooooooo`03ooooo`03
o`1Boooooooooooo01Gooooo000Jooooo`03o`000?oooooooooo0?oooooo7oooool04ol0Vooo0?o0
o`3oSol0olKo0:7oooooool0oggoooooo`3o^_l0FOooooooo`3om_oooooo0<coooooool0om;ooooo
o`3oD_l0Jol01Oooool00ol0ob;oooooooooo`02ooooo`03o`3o>_oooooooooo00;o0?Ko0_ooool:
o`3oF@Gooooo1?l0ocX=ooooo`;o0?lR0_l0oe84ooooo`;o0?n30ol0m_l00ol0om;oooooooooo`02
ooooo`03o`3<ool0olcooooo00;ooooo00?o0?ofooooooooool00_ooool3o`1[oa3ooooo0ol0FOlE
ooooo`03o`3foooooooooooo00;ooooo00Co06_oooooool0FOoo05Wo2?ooool00ol0ogOooooooooo
o`06ooooo`05o`2^ooooooooooooooooool0C?l01?ooool01Ol0ob;ooooooooooooooooo0?ld00Co
oooo00?o013oooooooooool00_ooool01?l0;_ooooooooooool0ooH>ooooo`03o`3ol?oooooooooo
00?ooooo00Go9P3oo`3o>_ooooooooooo`0Xo`08ooooo`03o`0doooooooooooo01Gooooo0_l0oh<4
ooooo`03oeL0oooooooooooo00Cooooo0_l0D_lEooooo`006_ooool00ol0003oooooooooo`3ooooo
ob3ooooo01?o09_oooooool0ohoo0?o6o`2Qoooooooo0?mmooooool0FOooooooo`3om_l0olcooooo
o`3<oooooooo0?oBooooool0oe;o06_o00Gooooo00?o0?lRooooooooool00_ooool3o`3o>P03oooo
ool0m_oooooo00cooooo0ol0ocX@ooooo`03o`3o8_oooooo0?mB00Gooooo0ol0m_l2o`3odPCooooo
0_l0c?l3ooooo`;o0?of0_ooool3o`1[oa3ooooo0ol0FOlIooooo`03o`3foooooooooooo00;ooooo
00?o06_oooooooooool00ol0FOl6ooooo`03o`3oMooooooooooo00Gooooo00Go0:kooooooooooooo
ooooo`1<o`04ooooo`03o`3o8_oooooooooo00;ooooo00?o0?ldooooooooool00_ooool00ol04?oo
ooooooooo`02ooooo`04o`0^ooooooooooooo`3omPkooooo00?o0?o`ooooooooool00oooool01OlV
0?oo0?ljoooooooooooo02So00Sooooo00?o03Coooooooooool05_ooool00ol0oh?oooooooooo`02
ooooo`03oeL0oooooooooooo00Gooooo00?o05;oooooooooool04_ooool001[ooooo00?o0000oooo
ooooool0oooooolQooooo`06o`2Koooooooo0?o6ooooool0XOoo0?mm0_ooool01Ol0FOooooooo`3o
m_l0olcooooo00;o0<co00Co0?oBooooool0oe;o06_o1Oooool2o`3o8PGooooo0_l0ocX3o`3fo`Ko
oooo1?l0ocXAooooo`;o0?lR0_l0oe83ooooo`?o0?Ko0_ooool00ol0om;oooooooooo`02ooooo`;o
0<co00?o0?o<ooooooooool00_l0ooH2ooooo`;o06_o4?ooool3o`1Ioa7ooooo2_l0olH2ooooo`03
o`3foooooooooooo00;ooooo00?o06_oooooooooool00_ooool2o`1Io`Cooooo00?o0?mgoooooooo
ool01_ooool01Ol0[_oooooooooooooooooo04co00Cooooo00?o0?lRooooooooool00_ooool01Ol0
ocCooooooooooooooooo013o00Cooooo00Go02koooooooooooooooooo`3omP0=ooooo`03o`3ol?oo
oooooooo00?ooooo00?o9P3oo`3oD_l0ocX00_ooool00ol0:?ooooooooooo`05ooooo`03o`0doooo
oooooooo01Oooooo0_l0oh<3ooooo`03oeL0oooooooooooo00Gooooo00?o05;oooooooooool04Ooo
ool001[ooooo00?o0000ooooooooool0oooooolQooooo`07o`2Kool0ol3o0?n?o`3oa_oooooo0:7o
o`3oO@02ooooo`0;o`1Ioooooooo0?ofo`3oc?oooooo0?n3o`3<ool0om;oooooo`3oD_l0Jol01_oo
ool00ol0ob;oooooooooo`05ooooo`;o0?lj0ol0m_l3o`3o>Q?ooooo0_l0ob82o`3oDP;ooooo0ol0
m_l00ol0oh?oooooooooo`02o`3odPCooooo00?o0<coo`3oc?ooool00_ooool00ol0ooKooooooooo
o`02o`1[o`oooooo0ol0FOl>ooooo`Ko0?o62_l0ohl3o`3oaP06o`3fool0olKo0?o6o`3oa_oooooo
06_o1Oooool00ol0FOooooooooooo`02ooooo`03o`3oMooooooooooo00Gooooo00Go0:kooooooooo
ooooooooo`1<o`05ooooo`05o`3o8_ooooooooooooooool0oc@01?ooool00ol04?ooooooooooo`02
ooooo`05o`0^ooooooooooooooooool0ooH03Oooool00ol0oo3oooooooooo`03ooooo`05obH0ool0
oe;o0?ljooooool0:?l02?ooool00ol0=?ooooooooooo`0Hooooo`;o0?n30_ooool00omG0?oooooo
ooooo`05ooooo`03o`1Boooooooooooo013ooooo000Jooooo`03o`000?oooooooooo0?oooooo8_oo
ool02Ol0Vooo0?o0o`3oSol0olKo0:7oooooool0oggoooooo`1Io`02ooooo`08o`3om_l0olcooooo
o`3oPol0c?oo0?oBooooool0oe82o`1[o`Gooooo00?o0?lRooooooooool02Oooool3o`3foa7ooooo
0_l0ob800ooooooo0?mBo`3fo`03o`3fo`03ooooool0oh?o0?n300;ooooo00?o0?oBooooooooool0
0_ooool2o`3<o`?ooooo0_l0ooH3o`1[o`kooooo0ol0FOl;ooooo`Ko0?o61_l0ohl;ooooo`?o0?n?
00?o0?Koooooooooool00_l0olH00ol0Joooooooooooo`03ooooo`;o05Wo0_ooool00ol0ogOooooo
ooooo`06ooooo`05o`2^ooooooooooooooooool0C?l01Oooool01Ol0ob;ooooooooooooooooo0?ld
00?ooooo00?o013oooooooooool00_ooool00ol0;_ooooooooooo`02ooooo`03o`3om_oooooooooo
00[ooooo00?o0?o`ooooooooool00oooool00olV0?ooooooo`3oDP02ooooo`03o`0Xoooooooooooo
00Gooooo00?o03Coooooooooool06_ooool01?l0oh?ooooooooooomG0?l7ooooo`03o`1Boooooooo
oooo00oooooo000Jooooo`03o`000?oooooooooo0?oooooo8oooool02Ol0Voooooooo`3oSol0olKo
0:7oooooool0oggoooooo`1Io`02ooooo`0:o`3om_ooooooooooo`3oPol0c?oo0?oBooooool0oe;o
08Woo`1[o`Gooooo00?o0?lRooooooooool02oooool3o`3fo`_ooooo0ol0ob84o`3fo`?ooooo0_l0
oh<2ooooo`;o0?oB0oooool2o`3<o`03o`3oc?oooooooooo00;o0?of0_l0Jol?ooooo`;o05Wo2ooo
ool3o`3oaPGo0?n?5Oooool00ol0m_oo0?n?o`3oS`02o`3oS`03o`1[ool0olKooooo00Gooooo00Co
05Wooooooooooooo0?mg1oooool01Ol0[_oooooooooooooooooo04co00Gooooo00?o0?lRoooooooo
ool00_ooool01Ol0ocCooooooooooooooooo013o00Cooooo00?o02koooooooooool00_ooool00ol0
ooKoooooooooo`0:ooooo`03o`3ol?oooooooooo00;ooooo00Ko9P3ooooooooooooo0?mBooooool0
:?l8ooooo`03o`0doooooooooooo01[ooooo0_l0oh<00omG0?ooooooooooo`06ooooo`03o`1Boooo
oooooooo00kooooo000Jooooo`03o`000?oooooooooo0?oooooo8oooool01ol0Vooo0?o0ooooool0
olKoooooo`2Qool0ogd00_ooool01?l0FOooooooooooool0ooH3ooooo`05o`3<ool0om;oooooo`3o
D_l0ROl00_l0Jol4ooooo`?o0?lR3Oooool>o`3fo`03o`3oD_oooooooooo00;ooooo0_l0oh<2oooo
o`;o0?oB1?ooool01Ol0c?oo0?o<oooooooooooo0?of00?o06_o3_ooool3o`1Io`[ooooo2Ol0ROlH
ooooo`03o`3foooooooooooo00;ooooo00?o06_oo`3oa_l0olH01Oooool01?l0FOooooooooooool0
ogL6ooooo`03o`2^oooooooooooo00;ooooo00?o04coooooooooool00oooool01Ol0ob;ooooooooo
oooooooo0?ld00?ooooo00?o013oooooooooool00_ooool00ol0;_ooooooooooo`03ooooo`03o`3o
m_oooooooooo00[ooooo00?o0?o`ooooooooool00_ooool01_lV0?ooooooooooool0oe;oooooo`0X
o`Sooooo00?o03Coooooooooool06oooool00ol0oh?oE`3oooooo`07ooooo`03o`1Boooooooooooo
00gooooo000Jooooo`03o`000?oooooooooo0?oooooo9?ooool02_l0Vooo0?o0ooooool0olKo0:7o
ooooool0oggoooooo`3o^_l0FOl2ooooo`06o`3om_ooooooooooooooool0c?oo0?oB0_ooool00ol0
ROooooooo`1[o`06ooooo`;o0?lR4?ooool3o`3o8PCooooo0_l0oe84ooooo`03o`3oPooooooooooo
00;o0?oB1?ooool2o`3<o`;ooooo0ol0Jol?ooooo`;o05Wo1oooool6o`29o`Wo0>[o1Ol0ROlDoooo
o`03o`3foooooooooooo00;ooooo00Co06_oooooool0olKo0?o61?ooool00ol0FOooooooo`3oM`07
ooooo`05o`2^ooooooooooooooooool0C?l01_ooool01Ol0ob;ooooooooooooooooo0?ld00?ooooo
00?o013oooooooooool00_ooool00ol0;_ooooooooooo`03ooooo`03o`3om_oooooooooo00[ooooo
00Go0?o`ooooooooooooooooobH0o`03ooooo`03o`3oD_l0:?oooooo00Sooooo00?o03Cooooooooo
ool07?ooool00omG0?ooooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`3oooooobGooooo
00[o09_oo`3o`?l0ohoo0?o6o`2Qoooooooo0?mmooooool0ok[o05Wo0_ooool01Ol0ooKooooooooo
oooooooo0<co00;o0?oB00Coooooo`29ool0j_oo06_o1oooool7o`3o8P?ooooo1_l0ob84ooooo`?o
0?mB1?ooool2o`3oP`;ooooo00?o0?oBooooooooool00_ooool2o`3<o`05o`3oc?l0Jooo06_oo`1[
ool0ooH03oooool2o`1Io`;ooooo1ol0ROl00ol0j_oo0?o6o`3oaP02o`3oS`_ooooo1?l0j_l4o`29
oa7ooooo00?o0?Koooooooooool00_ooool01?l0Joooooooo`3oSol0olH4ooooo`03o`1Ioooooooo
0?mg00Kooooo00?o0:koooooooooool00_ooool00ol0C?ooooooooooo`04ooooo`04o`3o8_oooooo
ooooo`3o=0?ooooo00?o013oooooooooool00_ooool00ol0;_ooooooooooo`04ooooo`03o`3om_oo
oooooooo00[ooooo00Go0?o`ooooooooooooooooobH0o`03ooooo`03o`3oD_l0:?oooooo00Sooooo
00?o03Coooooooooool07?ooool00omG0?oo0?n3ooooo`0Dooooo`006_ooool00ol0003ooooooooo
o`3oooooobGooooo00Oo09_oo`3o`?oooooo0?n?o`3oa_l0XOoo0?mm00;ooooo00Go0?njo`1Ioooo
ooooooooo`3omP03ooooo`06o`3<ool0oh?o0?oBooooool0ROoo0>[o0_l0Jol;ooooo`Co0?lR1ooo
ool3o`3oDPGooooo0_l0oh<2ooooo`;o0?oB0oooool2o`3<o`03o`3oc?l0Jooo06_o00;o0?of3_oo
ool3o`1Io`Co08Wo0_l0j_l4ooooo`;o0?o60_l0ohlCooooo`;o0>[o0ol0ROl?ooooo`03o`3foooo
oooooooo00;ooooo00?o06_oooooooooool00_l0olH3ooooo`03o`1Iool0ogOooooo00Kooooo00Go
0:koooooooooooooooooo`1<o`06ooooo`05o`3o8_ooooooooooooooool0oc@00oooool00ol04?oo
ooooooooo`02ooooo`03o`0^oooooooooooo00Cooooo00?o0?ofooooooooool02Oooool01Ol0oo3o
oooooooooooooooo9P3o00Cooooo00?o02Soooooooooool02?ooool00ol0=?ooooooooooo`0Koooo
o`04oeL0oooooooo0?n3o`3oPa?ooooo000Jooooo`03o`000?oooooooooo0?oooooo9_ooool01ol0
Vooo0?o0ooooool0olKoooooo`2Qool0ogd00_ooool01_l0ok[o05Wooooooooooooo0?ofo`3oc0;o
oooo00Co0<coooooool0om;ooooo0_l0ROl00ol0oe;o06_oooooo`0Aooooo`?o0?mB1_ooool2o`3o
P`;ooooo0_l0om83ooooo`;o0<co0ol0Jol2o`3omPkooooo0_l0FOl3o`29o`?o0>[o1?ooool3o`3o
aP;o0?n?6?ooool2o`3Zo`;o08Wo3_ooool00ol0m_ooooooooooo`02ooooo`05o`1[oooooooooooo
o`3oSol0olH00oooool00ol0FOoo0?mgooooo`05ooooo`03o`2^oooooooooooo00;ooooo00?o04co
ooooooooool01?ooool01Ol0ob;ooooooooooooooooo0?ld00?ooooo00Go013ooooooooooooooooo
o`0^o`06ooooo`03o`3om_oooooooooo00[ooooo00Go0?o`ooooooooooooooooobH0o`04ooooo`03
o`0Xoooooooooooo00Sooooo00?o03Coooooooooool06oooool01?mG0?ooooooooooool0oh<Boooo
o`006_ooool00ol0003oooooooooo`3oooooobOooooo00Oo09_oo`3o`?oooooo0?o6o`2Qoooooooo
0?mm00;ooooo00Ko0?njo`1Iooooooooooooo`3om_l0ol`2ooooo`03o`3<oooooooo0?oB00;o0?oB
00Co08Woooooool0Jooo06_o0_l0oe8<ooooo`;o0?mB1oooool2o`3oP`;ooooo0_l0om82ooooo`?o
0<co0_l0Jol00ooooooo0?ofo`3omP0>ooooo`;o05Wo00?o08Woo`3Zool0j_l01oooool2o`3oaP?o
0?n?2_oooolBo`3oO@03o`3Zool0oggo08Wo00kooooo00?o0?Koooooooooool00_ooool01?l0Jooo
ooooooooooooool2o`3oaP;ooooo00?o05Woooooooooool01Oooool01Ol0[_oooooooooooooooooo
04co00Oooooo00Co0?lRoooooooooooo0?ld0oooool00ol04?ooooooooooo`02ooooo`03o`0^oooo
oooooooo00Cooooo00?o0?ofooooooooool02_ooool01?l0oo3ooooooooooolV0?l5ooooo`03o`0X
ool0oe;ooooo00Sooooo0_l0=?lLooooo`03oeL0oooooooooooo00;o0?n34?ooool001[ooooo00?o
0000ooooooooool0oooooolXooooo`07o`2Koooooooo0?n?o`3oa_l0XOooooooo`3oO@02ooooo`05
o`3o^_l0FOoo05Woooooool0ooH00_l0ol`01_oooooo0<coo`3<oooooooo0?n3o`3odP;o08Wo00?o
ooooo`1[ool0Jol03?l0oe87ooooo`;o0?n30_ooool2o`3odP;ooooo0_l0c?l01?oooooo06_oo`1[
ooooool2o`3omPgooooo0ol0FOl00ol0j_ooooooooooo`07ooooo`;o0?o60_l0ohl7ooooo`Ko0?mm
4oooool01?l0j_oo0?mmo`29ool0ogd<ooooo`03o`3foooooooooooo00;ooooo00?o06_ooooooooo
ool00_ooool01Ol0ohoo0?o6ooooool0FOoo0?mg00Kooooo00?o0:koooooooooool00_ooool00ol0
C?ooooooooooo`04ooooo`05o`3o8_ooooooooooooooool0oc@00oooool01Ol04?oooooooooooooo
oooo02ko00Oooooo00?o0?ofooooooooool02_ooool01?l0oo3ooooooooooolV0?l4ooooo`03o`0X
ool0oc[o0?mB00[ooooo00?o03Coooooooooool06_ooool01OmG0?oooooooooooooooooo0?n300oo
oooo000Jooooo`03o`000?oooooooooo0?oooooo:Oooool01ol0Voooooooo`3oa_oooooo0:7ooooo
ool0ogd00_ooool01ol0ok[oooooo`1Ioooooooo0?ofooooool0ol`00_ooool2o`3<o`;o0?n300Go
0?oBo`29ool0j_ooooooo`1[o`0@ooooo`;o0?n30_ooool2o`3odP;ooooo0_l0c?l3o`1[o`03oooo
ool0ooKo0?of00cooooo00Co08Woo`1Iool0FOoo0>[o2_ooool2o`3oaP;o0?n?1Oooool4o`3oOA[o
oooo00?o0>[oooooool0ROl01?l0ogd9ooooo`03o`3foooooooooooo00;ooooo00?o06_ooooooooo
ool00oooool01?l0olKoooooo`1Iool0ogL6ooooo`05o`2^ooooooooooooooooool0C?l01oooool0
1Ol0ob;ooooooooooooooooo0?ld00;ooooo00?o013oooooooooool00_ooool00ol0;_oooooooooo
o`05ooooo`03o`3om_oooooooooo00Wooooo00Co0?o`oooooooooooo9P3o1Oooool00ol0:?oo0?lj
o`3oDP0:ooooo`03o`0doooooooooooo01[ooooo00?oE`3oooooooooool04?ooool001[ooooo00?o
0000ooooooooool0oooooolYooooo`08o`2Kool0ol3oooooo`3oa_oooooo0:7oooooool0ogd2oooo
o`04o`3o^_oooooo05Woooooo`;o0?of0_l0ol`2ooooo`;o0<co00?oooooo`3od_l0ROl00_l0ROl4
o`1[o`Sooooo1?l0oh<2ooooo`;o0?oB0_ooool4o`1[o`04o`3oc?oooooo0?ofo`3omP[ooooo00?o
0>[oo`29ool0ROl00_l0FOl;ooooo`;o0?o60_l0ohl4ooooo`?o0?mm7oooool2o`3Zo`04o`29oooo
ooooooooooooo`;o0?mm2?ooool00ol0m_ooooooooooo`02ooooo`03o`1[oooooooooooo00?ooooo
00?o0?o6o`3oSol0FOl01_ooool00ol0[_ooooooooooo`02ooooo`03o`1<oooooooooooo00Gooooo
00Co0?lRoooooooooooo0?ld0oooool01Ol04?oooooooooooooooooo02ko00Sooooo00?o0?ofoooo
ooooool02Oooool01?l0oo3ooooooooooolV0?l4ooooo`04o`0Xoooooooo0?ljo`3oDP[ooooo00?o
03Coooooooooool06Oooool00omG0?ooooooooooo`0@ooooo`006_ooool3o`000?oooooo:_ooool0
2?l0Vooo0?o0ooooool0olKoooooo`2Qoooooooo0?mm0_ooool00ol0ok[oooooo`1Io`02ooooo`03
o`3om_oooooo0?o<00?ooooo0ol0c?l2o`3odP;o08Wo00?o0>[oo`3oPol0Jol01_l0Jol3o`3odPSo
06_o00Coooooo`3oc?l0olcooooo0_l0ooH9ooooo`04o`3Zool0ROoo08Woo`29o`;o05Wo2_ooool3
o`3oaP;o0?n?0oooool3o`3oO@Sooooo3ol0okX=ooooo`03o`3Zool0ROoo08Wo00?ooooo00?o0?mm
ooooooooool01Oooool00ol0m_ooooooooooo`02ooooo`03o`1[oooooooooooo00Cooooo00?o0?o6
o`3oSol0FOl01_ooool01Ol0[_oooooooooooooooooo04co00Oooooo00Go0?lRoooooooooooooooo
o`3o=002ooooo`03o`0@oooooooooooo00;ooooo00?o02koooooooooool01_ooool00ol0ooKooooo
ooooo`09ooooo`03o`3ol?oooooo9P3o00Gooooo00Co02Soooooool0oc[o0?mB2_ooool00ol0=?oo
ooooooooo`0Iooooo`03oeL0oooooooooooo00oooooo000Jooooo`03o`000?oooooooooo0?oooooo
:oooool00ol0Voooooooooooo`02o`3oaP03o`2Qoooooooo0?mm00;ooooo00?o0?njooooool0FOl0
0_ooool3o`3omP;o0?o<0oooool2o`3<o`;ooooo0ol0ROl5o`3odPCo06_o0oooool2o`3<o`05oooo
ool0olco0?o<o`3oc?ooool00_l0ooH6ooooo`03o`3Zool0ROoo08Wo00?o08Wo00?oooooo`1Iool0
FOl02_ooool2o`3oaP;o0?n?0oooool3o`3oO@Kooooo1Ol0okX?ooooo`Ko0?nj2?ooool2o`3Zo`04
o`29ooooooooooooooooo`;o0?mm1_ooool00ol0m_ooooooooooo`02ooooo`03o`1[oooooooooooo
00Cooooo00?o0?o6o`1Iooooool01Oooool00ol0[_ooooooooooo`02ooooo`03o`1<oooooooooooo
00Gooooo00Co0?lRoooooooooooo0?ld0oooool01Ol04?oooooooooooooooooo02ko00Wooooo00?o
0?ofooooooooool02Oooool00ol0oo3oooooobH0o`05ooooo`03o`0Xoooooooo0?lj00;o0?mB2Ooo
ool2o`0doa[ooooo00?oE`3oo`3ol?ooool03_ooool001[ooooo00?o0000ooooooooool0ooooool/
ooooo`07o`2Kooooooooooooo`3oSol0olKo0:7oooooo`02o`3oO@03ooooool0ok[ooooo00;o05Wo
0oooool2o`3omP03o`3oc?oooooooooo00;ooooo1Ol0c?l3o`29o`?ooooo1_l0c?l3o`3oc0;ooooo
0_l0ooH4ooooo`03o`3Zool0ROoo08Wo00;o08Wo1?ooool2o`1Io`[ooooo0_l0olH2o`3oS`;ooooo
0ol0ogd5ooooo`Co0?nj2ooooolEo`3o`0Cooooo00?o0>[oo`29ooooool00oooool00ol0oggooooo
ooooo`03ooooo`03o`3foooooooooooo00?ooooo00?o06_oooooooooool01?ooool00ol0olKo05Wo
ooooo`05ooooo`05o`2^ooooooooooooooooool0C?l02?ooool01?l0ob;oooooooooool0oc@2oooo
o`03o`0@oooooooooooo00;ooooo00?o02koooooooooool01oooool00ol0ooKoooooooooo`09oooo
o`03o`3ol?oooooo9P3o00Cooooo00Ko02Sooooooooooooo0?ljooooool0oe8:ooooo`03o`0doooo
oooooooo01Gooooo0_l0oo000oooooooE`3oooooo`0>ooooo`006_ooool00ol0003oooooooooo`3o
ooooobcooooo00Oo09_oo`3o`?ooooooooooo`3oSol0olKo0:7o00;ooooo00?o0?mmooooool0okX0
0_ooool00ol0FOooooooooooo`02ooooo`04o`3om_l0olco0?o<o`3oc0Gooooo1?l0c?l4o`29o`?o
0>[o0_l0ol`2ooooo`?o0>[o1ol0ROl6ooooo`;o05Wo2_ooool2o`3oaP;o0?n?00Coooooo`3oOOl0
oggo0?mm1?ooool4o`3o^P[ooooo1Ol0ol0Booooo`;o0?nj00Coooooo`3o`?l0ol3o0?o00_ooool0
0ol0j_oo08Woooooo`03ooooo`;o0?mm1?ooool00ol0m_ooooooooooo`02ooooo`03o`1[oooooooo
oooo00Gooooo00?o0?o6o`1Iooooool01?ooool00ol0[_ooooooooooo`02ooooo`03o`1<oooooooo
oooo00Kooooo00Co0?lRoooooooooooo0?ld0_ooool01Ol04?oooooooooooooooooo02ko00[ooooo
00?o0?ofooooooooool02Oooool00ol0oo3o9P3oooooo`04ooooo`06o`0Xooooooooooooo`3o>_oo
oooo0?mB2_ooool00ol0=?ooooooooooo`0Cooooo`03o`3ol?oooooooooo017ooooo000Jooooo`03
o`000?oooooooooo0?oooooo;Oooool01ol0Vooo0?o0oooooooooooo0?n?o`3oa_l0XOl00_ooool0
0ol0oggoooooo`3o^P02ooooo`;o05Wo0oooool3o`3omPgo0?o<2_l0ROl;ooooo`;o05Wo2_ooool2
o`3oaP03o`3oSooooooooooo00;o0?mm1?ooool3o`3o^PWooooo1Ol0ol0Iooooo`04o`3o^_oooooo
ooooooooo`;o0?o000?o0>[oooooool0ROl01Oooool00ol0oggoooooooooo`02ooooo`03o`3foooo
oooooooo00;ooooo00?o06_oooooooooool01Oooool00ol0olKo05Woooooo`04ooooo`05o`2^oooo
ooooooooooooool0C?l02?ooool01?l0ob;oooooooooool0oc@2ooooo`03o`0@oooooooooooo00;o
oooo00?o02koooooooooool01oooool00ol0ooKoooooooooo`0;ooooo`03obH0oooooooooooo00?o
oooo00Ko02Sooooooooooooo0?ljooooool0oe8:ooooo`03o`0doooooooooooo017ooooo00?o0?o`
ooooooooool04_ooool001[ooooo00?o0000ooooooooool0ooooool^ooooo`06o`2Kool0ol3ooooo
ooooool0ohoo0?o60_l0XOl00ooooooo0?mmooooo`02o`3o^P;ooooo00?o05Woooooooooool00ooo
ool5o`3omPKooooo1Ol0ooH@ooooo`;o05Wo2_ooool2o`3oaP03o`3oSooooooooooo00;o0?mm00?o
ooooo`3o^_l0okX00ol0okX8ooooo`Co0?o07oooool2o`3o^P?ooooo00Co0?o0o`3Zoooooooo08Wo
1Oooool01Ol0oggooooooooooooooooo0?Ko00Gooooo00?o06_oooooooooool01?ooool00ol0olKo
05Woooooo`04ooooo`03o`2^oooooooooooo00;ooooo00?o04coooooooooool01_ooool01?l0ob;o
ooooooooool0oc@2ooooo`05o`0@ooooooooooooooooool0;_l02_ooool00ol0ooKoooooooooo`0;
ooooo`03obH0oooooooooooo00;ooooo00Ko02Soooooooooooooooooo`3o>_ooool2o`3oDPWooooo
0_l0=?l@ooooo`03o`3ol?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo0?oooooo;ooo
ool01Ol0Vooo0?o0oooooooooooo0?n?00;o0?o600?o0:7oooooool0ogd00_ooool2o`3o^P03oooo
ool0FOoo05Wo00Sooooo1ol0ooHAooooo`?o05Wo2Oooool3o`3oaP04o`3oSooooooo0?mmo`3oO@Co
0?nj2_ooool3o`3o`2Gooooo00?o0?njooooooooool00_ooool00ol0j_oo08Woooooo`05ooooo`05
o`3oOOooooooooooooooool0m_l01?ooool00ol0Joooooooooooo`05ooooo`03o`3oa_l0FOoooooo
00Cooooo00Go0:koooooooooooooooooo`1<o`09ooooo`03o`3o8_oooooo0?ld00;ooooo00?o013o
ooooooooool00_ooool00ol0;_ooooooooooo`08ooooo`03o`3om_oooooooooo00[ooooo00?o9P3o
o`3ol?ooool00oooool01Ol0:?oooooooooooooooooo0?lj00;ooooo00?o0?mBooooooooool02?oo
ool00ol0=?ooooooooooo`0<ooooo`03o`3ol?oooooooooo01Cooooo000Jooooo`03o`000?oooooo
oooo0?oooooo<?ooool01?l0Vooo0?o0o`3o`?ooool2o`3oS`03o`3oa_l0XOoooooo00;o0?mm0_oo
ool00ol0ok[oooooooooo`03o`1IoaWooooo1?l0FOl:ooooo`;o0?o60_l0ohl00ooooooo0?mmo`3o
^P02o`3o^P[ooooo1?l0ol0Yooooo`;o0?nj0oooool00ol0j_oo08Woo`3o`005ooooo`05o`3oOOoo
ooooooooooooool0m_l01?ooool00ol0Joooooooooooo`05ooooo`03o`3oa_l0FOoooooo00Cooooo
00Go0:koooooooooooooooooo`1<o`08ooooo`04o`3o8_ooooooooooo`3o=0;ooooo00Go013ooooo
ooooooooooooo`0^o`0;ooooo`03o`3om_oooooooooo00[ooooo00?o9P3oo`3ol?ooool00oooool0
1Ol0:?oooooooooooooooooo0?lj00;ooooo00?o0?mBooooooooool02?ooool3o`0do`Wooooo0_l0
oo0Gooooo`006_ooool00ol0003oooooooooo`3ooooooc7ooooo00?o09_oooooool0ol000_ooool0
0ol0ohoo0?o6o`2Qo`02ooooo`03o`3oOOoooooooooo00;o0?nj0oooool00ol0FOooooooooooo`0B
ooooo`Co05Wo3?ooool2o`3oaP;o0?n?00Co0?mmo`3o^_l0ok[o0?nj2_ooool3o`3o`13ooooo4ol0
Vol<ooooo`06o`3o^_ooooooooooooooool0j_oo08Wo0_l0ol04ooooo`04o`3oOOooooooooooo`3f
o`Gooooo00?o06_oooooooooool01?ooool00ol0ogOo0?o6o`1Io`04ooooo`05o`2^oooooooooooo
ooooool0C?l02Oooool01?l0ob;oooooooooool0oc@2ooooo`05o`0@ooooooooooooooooool0;_l0
2oooool00ol0ooKoooooooooo`0:ooooo`06obH0ool0oo3o0?o`o`3ol?oooooo02So1?ooool2o`3o
>P03ooooool0oe;ooooo00_ooooo0ol0=?l4ooooo`;o0?o`1_ooool4o`0do`oooooo000Jooooo`03
o`000?oooooooooo0?oooooo<_ooool2o`2Ko`03o`3o`?oooooooooo00;o0?n?00?o0:7ooooooooo
ool00_l0ogd2ooooo`04o`3o^_ooooooooooooooo`Go05Wo3Oooool2o`1Io`kooooo0_l0olH2o`3o
S`?o0?nj2_ooool3o`3o`0gooooo1_l0VolCooooo`Go09_o2?ooool2o`3o^P;ooooo00Co0>[oo`29
oooooooo0?o00oooool01Ol0oggooooooooooooooooo0?Ko00Cooooo00?o06_oooooooooool01Ooo
ool00ol0ogOo05Woo`3oS`04ooooo`05o`2^ooooooooooooooooool0C?l02Oooool00ol0ob;ooooo
o`3o=002ooooo`03o`0@oooooooooooo00;ooooo00?o02koooooooooool02Oooool00ol0ooKooooo
ooooo`09ooooo`04obH0ooooooooooooooooo`;o0?o`00?o02Soooooooooool00oooool00ol0oc[o
ooooo`3oDP0>ooooo`co03Co4oooool001[ooooo00?o0000ooooooooool0ooooooldooooo`03o`2K
ool0ol3ooooo00;ooooo00?o0?n?o`2Qool0XOl00_ooool00ol0oggoooooooooo`03o`3o^PGooooo
3Ol0FOl=ooooo`?o0?o61?l0okX:ooooo`?o0?o02oooool5o`2Koakooooo0ol0Vol7ooooo`07o`3o
^_ooooooooooo`3Zool0ROooooooo`3o`003ooooo`04o`3oOOooooooooooo`3fo`Gooooo00?o06_o
ooooooooool01Oooool00ol0ogOo05Woo`3oS`03ooooo`05o`2^ooooooooooooooooool0C?l02Ooo
ool01?l0ob;oooooooooool0oc@2ooooo`05o`0@ooooooooooooooooool0;_l03?ooool00ol0ooKo
ooooooooo`09ooooo`03obH0oooooooooooo00;ooooo00?o0?o`o`0Xooooool01?ooool01?l0oc[o
ooooo`3oD_l0oe8<ooooo`;o0?o`7Oooool001[ooooo00?o0000ooooooooool0ooooooleooooo`;o
09_o00?o0?o0ooooooooool00_l0ohl00ol0XOooooooooooo`02o`3oO@?ooooo1?l0okXHooooo`?o
0?o60_l0okX00ol0ohoo0?mmooooo`09ooooo`?o0?o02_ooool4o`2KobKooooo0_l0Vol6ooooo`04
o`3o^_ooooooooooo`29o`;ooooo00Go0?o0ooooooooooooooooo`3oO@02ooooo`03o`3foooooooo
oooo00?ooooo00?o06_oooooooooool01?ooool01?l0ogOoooooo`1Iool0ohl3ooooo`05o`2^oooo
ooooooooooooool0C?l02Oooool01_l0ob;oooooooooool0ocCoooooo`0@o`Cooooo00?o02kooooo
ooooool02_ooool00ol0ooKoooooooooo`08ooooo`03obH0oooooooooooo00?ooooo00?o02Soo`3o
l?l0oo001?ooool2o`3o>P03ooooool0oe;ooooo00Oooooo0ol0oo0Oooooo`006_ooool00ol0003o
ooooooooo`3oooooocOooooo00?o09_oo`3o`?ooool00_ooool01Ol0ohoo0:7oo`2Qool0olKooooo
00?o0?mm1?ooool00ol0ok[oooooooooo`0Booooo`?o0?o600?o0?njo`3oSol0ohl03?ooool2o`3o
`0[ooooo0ol0Vol4oooooaKo0:7o4_ooool2o`2Ko`Gooooo00Co0?njooooool0j_oo08Wo0_ooool0
1Ol0ol3ooooooooooooooooo0?mm00;ooooo00?o0?Koooooooooool00_ooool00ol0Jooooooooooo
o`05ooooo`04o`3oMooooooo05Woo`3oS`;ooooo00Go0:koooooooooooooooooo`1<o`0:ooooo`03
o`3o8_oooooo0?ld00;ooooo00Go013oooooooooooooooooo`0^o`0=ooooo`03o`3om_oooooooooo
00Sooooo00?o9P3oooooooooool00oooool00ol0:?ooooooo`3ol002o`3ol0?ooooo00?o0?ljoooo
ool0oe801?ooool3o`3ol2;ooooo000Jooooo`03o`000?oooooooooo0?oooooo>?ooool00ol0Vooo
0?o0o`3o`002ooooo`;o0?n?00Ko0:7oo`3oa_l0olKo0?o6ooooool0ogd4ooooo`Wo0?nj0_ooool6
o`3o^P?o0?o600?o0?njo`3oSol0ohl03?ooool3o`3o`0Wooooo0ol0Vol7o`2QoaKooooo0_l0XOlB
ooooo`;o09_o1?ooool01?l0ok[oooooo`3Zool0ROl2ooooo`07o`3o`?ooooooooooooooool0oggo
ooooo`3fo`05ooooo`03o`1[oooooooooooo00Cooooo00Go0?mgooooool0FOoo0?o6o`3oS`02oooo
o`05o`2^ooooooooooooooooool0C?l02_ooool01Ol0ob;oooooo`3o=?oooooo013o00Cooooo00?o
02koooooooooool02_ooool00ol0ooKoooooooooo`09ooooo`03obH0oooooooooooo00?ooooo00Co
02Sooooooooooooooooo2_l0oo0Uooooo`006_ooool00ol0003oooooooooo`3oooooocWooooo00?o
09_oooooool0ol001?ooool00ol0XOoo0?n?ooooo`02o`3oaPCo0?mm2?ooool3o`3o^P;ooooo1?l0
olH3o`3oS`gooooo0_l0ol09ooooo`?o09_o0ol0XOlOooooo`?o0:7o4Oooool00ol0Vooooooooooo
o`02ooooo`04o`3o^_oooooo0>[oo`29o`;ooooo00Oo0?o0ooooooooooooooooo`3oOOoooooo0?Ko
00Gooooo00?o06_oooooooooool01?ooool01ol0ogOoooooo`1Iool0olKo0?n?ooooool0[_l00ooo
ool00ol0C?ooooooooooo`09ooooo`05o`3o8_l0ocCoooooooooool04?l01?ooool00ol0;_oooooo
ooooo`0:ooooo`03o`3om_oooooooooo00Sooooo00?o9P3oooooooooool00oooool00ol0:?oooooo
ooooo`06ooooo`;o0?lj00?o0?mBooooooooool09Oooool001[ooooo00?o0000ooooooooool0oooo
ooljooooo`;o09_o0ol0ol02ooooo`04o`2Qool0ohoo0?n?o`3oS`Oo0?o600?o0?mmo`3oa_l0olH0
1ol0olH4o`3oS`kooooo0_l0ol07ooooo`Co09_o00?o0:7oooooooooool09Oooool2o`2Qoa3ooooo
00Go09_oooooooooooooooooo`3o^P02ooooo`05o`29ooooooooooooooooool0ol000oooool00ol0
oggoooooo`3fo`04ooooo`03o`1[oooooooooooo00Gooooo00Oo0?mgooooool0FOoo0?o6o`3oSooo
oooo0:ko00?ooooo00?o04coooooooooool02?ooool01Ol0ob;oooooo`3o=?oooooo013o00Cooooo
00?o02koooooooooool02oooool00ol0ooKoooooooooo`08ooooo`03obH0oooooooooooo00?ooooo
00?o02Soooooooooool01oooool00ol0oc[o0?mBo`3oDP0Uooooo`006_ooool00ol0003ooooooooo
o`3ooooooccooooo00?o09_oooooooooool00_l0ol001?oooooo0:7oo`2Qool0XOl7o`3oS`;o0?o6
2?l0ohl?ooooo`?o0?o01?ooool00ol0XOoo09_oo`2Ko`02o`2Kobkooooo0ol0XOl>ooooo`05o`2K
ooooooooooooooooool0okX00_ooool01Ol0ROoooooooooooooooooo0?o000;ooooo00?o0?mmoooo
ool0m_l01Oooool00ol0Joooooooooooo`04ooooo`07o`3oMoooooooooooo`1Iool0olKo0?n?o`2^
o`03ooooo`03o`1<oooooooooooo00Wooooo00Go0?lRooooool0ocCoooooo`0@o`04ooooo`03o`0^
oooooooooooo00_ooooo00?o0?ofooooooooool02?ooool00olV0?ooooooooooo`03ooooo`03o`0X
oooooooooooo00Oooooo00?o0?ljooooool0oe809?ooool001[ooooo00?o0000ooooooooool0oooo
oolmooooo`?o09_o00?oooooo`3o`?ooool00_ooool4o`2QoaWooooo0ol0ol001?oooooo0:7oo`2Q
ool0XOl4o`2KocGooooo0_l0XOl=ooooo`05o`2Kooooooooooooooooool0okX00_ooool01Ol0ROoo
oooooooooooooooo0?o000;ooooo00?o0?mmooooool0m_l01?ooool00ol0Joooooooooooo`05oooo
o`07o`3oMooooooo05Woo`3oa_l0ohooooooo`2^o`03ooooo`03o`1<oooooooooooo00Wooooo00Go
0?lRo`3o=?ooooooooooo`0@o`03ooooo`03o`0^oooooooooooo00cooooo00?o0?ofooooooooool0
1oooool00olV0?ooooooooooo`03ooooo`03o`0Xoooooooooooo00Sooooo0_l0ocX2o`3oDR;ooooo
000Jooooo`?o0000oooooom0ooooo`?o09_o0_l0ol04ooooo`Go0:7o3oooool3o`3o`0Ko0:7o0ol0
Volkooooo`03o`2Qoooooooooooo00_ooooo00Go09_oooooooooooooooooo`3o^P02ooooo`05o`29
ooooooooooooooooool0ol000_ooool00ol0oggoooooo`3fo`04ooooo`03o`1[oooooooooooo00Co
oooo00So0?mgoooooooooooo05Woo`3oa_l0ohooooooo`2^o`;ooooo00?o04coooooooooool02_oo
ool01?l0ob;o0?ldooooool04?l4ooooo`03o`0^oooooooooooo00cooooo00?o0?ofooooooooool0
1oooool00olV0?ooooooooooo`03ooooo`03o`0Xoooooooooooo00Wooooo0_l0ocX2o`3oDR3ooooo
000Jooooo`03o`000?oooooooooo0?oooooo@oooool3o`2Ko`?o0?o01OoooolBo`2Qo`?ooooo0ol0
Voloooooo`;o0:7o3?ooool2o`2Ko`;ooooo00Co0?njooooool0j_oo08Wo0oooool01Ol0ol3ooooo
ooooool0oggo0?Ko00Gooooo00?o06_oooooooooool01?ooool01ol0ogOoooooooooool0FOoo0?o6
o`3oSol0[_l00oooool00ol0C?ooooooooooo`0:ooooo`04o`3o8_l0ocCoooooo`0@o`?ooooo00?o
02koooooooooool03Oooool00ol0ooKoooooooooo`07ooooo`03obH0oooooooooooo00?ooooo00?o
02Soooooooooool02_ooool2o`3o>P03o`3oD_oooooooooo01gooooo000Jooooo`03o`000?oooooo
oooo0?ooooooA_ooool2o`2Ko`03ooooool0ol3o0?o000co0?o01oooool5o`2KodCooooo00?o0:7o
ooooooooool02oooool01_l0Voooooooooooool0ok[oooooo`29o`Cooooo00Go0?o0oooooooooooo
0?mmo`3fo`04ooooo`03o`1[oooooooooooo00Gooooo00Oo0?mgooooool0FOooooooo`3oa_l0ohoo
0:ko00?ooooo00?o04coooooooooool02_ooool01?l0ob;o0?ldooooool04?l3ooooo`03o`0^oooo
oooooooo00gooooo00?o0?ofooooooooool01oooool00olV0?ooooooooooo`03ooooo`03o`0Xoooo
oooooooo00_ooooo00?o0?ljo`3oD_l0oe807Oooool001[ooooo00?o0000ooooooooool0oooooom8
ooooo`Go09_o2Oooool8o`2Kod[ooooo0_l0XOl<ooooo`;o09_o00Coooooo`3o^_oooooo08Wo1?oo
ool01?l0ol3oooooooooool0m_l5ooooo`03o`1[oooooooooooo00Cooooo00Oo0?mgoooooooooooo
05Woooooool0olKo0:ko00?ooooo00?o04coooooooooool02_ooool01?l0ob;oooooo`3o=?l04?l4
ooooo`03o`0^oooooooooooo00gooooo0_l0ooH8ooooo`03obH0oooooooooooo00?ooooo00?o02So
ooooooooool02oooool2o`3o>P03o`3oD_oooooooooo01[ooooo000Jooooo`03o`000?oooooooooo
0?ooooooCOooool9o`2KoeCooooo00?o0:7oooooooooool02oooool01Ol0Vooo0?njooooool0j_oo
08Wo00Cooooo00Co0?o0ooooool0oggo0?Ko1Oooool00ol0Joooooooooooo`04ooooo`07o`3oMooo
ooooooooo`1Iool0olKoooooo`2^o`03ooooo`03o`1<oooooooooooo00[ooooo00Co0?lRo`3o=?oo
oooo013o0oooool00ol0;_ooooooooooo`0?ooooo`03o`3om_oooooooooo00Kooooo00?o9P3ooooo
ooooool00oooool00ol0:?ooooooooooo`0<ooooo`03o`3o>_l0oe;o0?mB01[ooooo000Jooooo`03
o`000?oooooooooo0?ooooooZoooool2o`2Qo`cooooo00Co09_oo`3o^_oooooo08Wo1Oooool01?l0
ol3oooooo`3oOOl0m_l4ooooo`03o`1[oooooooooooo00Cooooo00So0?mgooooooooooooooooo`1I
ool0olKo0:koo`3oS`;ooooo00?o04coooooooooool02oooool01?l0ob;o0?ldooooool04?l3oooo
o`03o`0^oooooooooooo00oooooo00?o0?ofooooooooool01_ooool00olV0?ooooooooooo`03oooo
o`03o`0Xoooooooooooo00gooooo00?o0?ljo`3oD_l0oe806?ooool001[ooooo00?o0000oooooooo
ool0oooooon]ooooo`03o`2Qoooooooooooo00Wooooo00Go09_oooooool0ok[oooooo`29o`05oooo
o`03o`3o`?oooooo0?Ko00Gooooo00?o06_oooooooooool01?ooool02?l0ogOoooooooooool0FOoo
ooooo`3oa_l0[_oo0?n?0_ooool00ol0C?ooooooooooo`0;ooooo`03o`3o8_l0ocCo013o00?ooooo
00?o02koooooooooool04?ooool00ol0ooKoooooooooo`05ooooo`03obH0oooooooooooo00?ooooo
00?o02Soooooooooool03oooool00ol0oc[o0?mBo`3oDP0Fooooo`006_ooool00ol0003ooooooooo
o`3oooooojkooooo00?o0:7oooooooooool02Oooool01Ol0Voooooooo`3o^_l0j_oo08Wo00Gooooo
00?o0?o0ooooool0m_l01Oooool00ol0Joooooooooooo`04ooooo`08o`3oMoooooooooooo`1Ioooo
oooo0?o6o`2^ool0ohl2ooooo`03o`1<oooooooooooo00_ooooo00?o0?lRo`3o=?l04?l00oooool0
0ol0;_ooooooooooo`0@ooooo`03o`3om_oooooooooo00Gooooo00?o9P3oooooooooool00oooool0
0ol0:?ooooooooooo`0@ooooo`03o`3o>_l0oe;o0?mB01Cooooo000Jooooo`03o`000?oooooooooo
0?oooooo[oooool00ol0XOooooooooooo`09ooooo`04o`2Kool0ok[oooooo`29o`Gooooo00Co0?o0
oooooooooooo0?Ko1?ooool00ol0Joooooooooooo`04ooooo`0;o`3oMoooooooooooooooool0FOoo
ooooo`2^oooooooo0?n?ooooool0C?l03_ooool00ol0ocCo013oooooo`03ooooo`03o`0^oooooooo
oooo013ooooo00?o0?ofooooooooool01Oooool00olV0?ooooooooooo`03ooooo`03o`0Xoooooooo
oooo01;ooooo0_l0oe8Booooo`006_ooool00ol0003oooooooooo`3oooooojoooooo00?o0:7ooooo
ooooool02_ooool01?l0Vooo0?njooooool0ROl5ooooo`04o`3o`?oooooo0?Koo`3oO@Cooooo00?o
06_oooooooooool01?ooool01?l0ogOoooooooooool0FOl2ooooo`05o`2^oooooooo0?n?ooooool0
C?l03_ooool00ol0ocCo013oooooo`03ooooo`03o`0^oooooooooooo013ooooo00?o0?ofoooooooo
ool01Oooool00olV0?ooooooooooo`03ooooo`03o`0Xoooooooooooo01?ooooo0_l0oe8@ooooo`00
6_ooool00ol0003oooooooooo`3ooooook3ooooo00?o0:7oooooooooool02_ooool01?l0Vooo0?nj
ooooool0ROl5ooooo`04o`3o`?oooooo0?Koo`3oO@Cooooo00?o06_oooooooooool00oooool01ol0
ogOooooooooooooooooo05Woooooool0[_l00_ooool00ol0ohoo04coooooo`0>ooooo`03o`3o=?l0
4?oooooo00?ooooo00?o02koooooooooool04?ooool00ol0ooKoooooooooo`05ooooo`03obH0oooo
oooooooo00?ooooo00?o02Soooooooooool05?ooool00ol0oe;oooooooooo`0=ooooo`006_ooool0
0ol0003oooooooooo`3ooooook7ooooo00?o0:7oooooooooool02Oooool01?l0Voooooooo`3o^_l0
ROl6ooooo`03o`3o`?oooooo0?Ko00Cooooo00?o06_oooooooooool01?ooool01ol0ogOooooooooo
oooooooo05Woooooool0[_l00_ooool00ol0ohoo04coooooo`0>ooooo`03o`0@oooooooooooo00;o
oooo00?o02koooooooooool04Oooool00ol0ooKoooooooooo`05ooooo`03obH0oooooooooooo00?o
oooo0_l0:?lTooooo`006_ooool00ol0003oooooooooo`3ooooook;ooooo00?o0:7oooooooooool0
2Oooool01?l0Vooo0?njooooool0ROl6ooooo`03o`3o`?l0m_oo0?mm00Cooooo00?o06_ooooooooo
ool01?ooool01ol0ogOooooooooooooooooo05Woooooool0[_l00_ooool00ol0ohoo04coooooo`0>
ooooo`03o`0@ool0ocCooooo00;ooooo00?o02koooooooooool04Oooool00ol0ooKoooooooooo`05
ooooo`03obH0oooooooooooo00Cooooo00?o02Soooooooooool08Oooool001[ooooo00?o0000oooo
ooooool0ooooooncooooo`03o`2Qoooooooooooo00Wooooo00Co09_oo`3o^_l0ROoo0>[o1_ooool0
0ol0ol3o0?Koo`3oO@04ooooo`03o`1[oooooooooooo00?ooooo00So0?mgooooooooooooooooo`1I
oooooooo0:koo`3oaP;ooooo00?o04coooooooooool03_ooool00ol04?oo0?ldooooo`02ooooo`03
o`0^oooooooooooo017ooooo00?o0?ofooooooooool01Oooool00olV0?ooooooooooo`04ooooo`03
o`0Xoooooooooooo023ooooo000Jooooo`03o`000?oooooooooo0?oooooo]?ooool00ol0XOoooooo
ooooo`09ooooo`03o`2Kool0ok[o08Wo00Oooooo00?o0?o0o`3fool0ogd00oooool00ol0Jooooooo
ooooo`04ooooo`08o`3oMoooooooooooooooool0FOooooooo`2^ool0olH2ooooo`03o`1<oooooooo
oooo00gooooo00?o013oo`3o8_l0oc@00oooool00ol0;_ooooooooooo`0Aooooo`;o0?of1_ooool0
0olV0?ooooooooooo`04ooooo`03o`0Xoooooooooooo01oooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00002_ooool00ol0003oooooooooo`3ooooookGooooo00?o0:7ooooo
ooooool02Oooool00ol0Vooo0?njo`29o`06ooooo`04o`3o`?l0m_ooooooo`3oO@?ooooo00?o06_o
ooooooooool01?ooool01ol0ogOooooooooooooooooo05Woooooool0[_l00_ooool00ol0C?oo0?n?
ooooo`0>ooooo`03o`0@ool0ob;o0?ld00;ooooo00?o02koooooooooool04oooool00ol0ooKooooo
ooooo`04ooooo`03obH0oooooooooooo00Cooooo00?o02Soooooooooool07_ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool0ooooooneooooo`03o`2Qoooooooooooo00[ooooo00?o09_oo`29ool0j_l01_ooool01?l0ol3o
0?Koooooool0ogd3ooooo`03o`1[oooooooooooo00Cooooo00Oo0?mgoooooooooooo05Woooooool0
[_oo0?o600;ooooo00?o04coo`3oSoooool03_ooool00ol04?oo0?lRo`3o=002ooooo`03o`0^oooo
oooooooo01?ooooo00?o0?ofooooooooool01?ooool00olV0?ooooooooooo`04ooooo`03o`0Xoooo
oooooooo01gooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000009ooooo`03o`000?oooooooooo0?oooooo]_ooool00ol0XOooooooooooo`09ooooo`03o`2K
ool0ok[o08Wo00Oooooo00?o0?Koooooool0ogd00oooool00ol0Joooooooooooo`05ooooo`07o`3o
Moooooooooooo`1Ioooooooo0:koo`3oaP02ooooo`03o`1<ool0ohoooooo00gooooo00?o013ooooo
ool0ob800_l0oc@00ooooooo02koooooo`0Dooooo`;o0?of1Oooool00olV0?ooooooooooo`04oooo
o`03o`0Xoooooooooooo01cooooo00001Ooooooo0000oooooooooooo000000Sooooo0ol0000:oooo
o`Co0000oooooonfooooo`03o`2Qoooooooooooo00Wooooo00?o09_oo`3o^_l0ROl01oooool00ol0
m_ooooooo`3oO@03ooooo`03o`1[oooooooooooo00Cooooo00So0?mgooooooooooooooooo`1Iool0
[_ooooooo`3oaP;ooooo00?o04coo`3oSoooool03Oooool01ol04?ooooooo`3o8_oooooo0?ldoooo
ool0;_l05_ooool00ol0ooKoooooooooo`03ooooo`;o9P3o1Oooool00ol0:?ooooooooooo`0Koooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`3ooooookSooooo00?o0:7oooooooooool02Oooool00ol0Vooo08Woo`3Zo`07
ooooo`03o`3foooooooo0?mm00?ooooo00?o06_oooooooooool01?ooool02?l0ogOooooooooooooo
oooo05Woo`2^oooooooo0?o60_ooool00ol0C?oo0?n?ooooo`0=ooooo`04o`0@oooooooo0?lRo`3o
8P;o0?ld00?o02koooooooooool05?ooool2o`3omPGooooo00?o9P3oooooooooool00oooool00ol0
:?ooooooooooo`0Jooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`3ooooookWooooo00?o0:7oooooooooool02Oooool0
0ol0Vooo08Woooooo`06ooooo`04o`3fool0ol3oooooo`3oO@?ooooo00?o06_oooooooooool01?oo
ool02?l0ogOoooooooooool0FOooooooo`2^oooooooo0?o60_ooool00ol0C?oo0?n?ooooo`0=oooo
o`07o`0@ooooooooooooo`3o8_oooooo0?ldo`0^o`0Gooooo`03o`3om_oooooooooo00?ooooo00?o
9P3oooooooooool00oooool00ol0:?ooooooooooo`0Iooooo`000_ooool2o`0000Wooooo0ol0000:
ooooo`03o`000?oooooooooo0?oooooo^_ooool00ol0XOooooooooooo`09ooooo`03o`2Kool0ROoo
oooo00Kooooo00Co0?Koo`3o`?oooooo0?mm0_ooool00ol0Joooooooooooo`05ooooo`07o`3oMooo
ooooooooo`1Ioooooooo0:koo`3oaP03ooooo`03o`1<ool0ohoooooo00gooooo00Oo013ooooooooo
oooo0?lRooooool0ocCo02ko01Oooooo00?o0?ofooooooooool00oooool00olV0?ooooooooooo`03
ooooo`;o02So6Oooool001[ooooo00?o0000ooooooooool0oooooonkooooo`03o`2Qoooooooooooo
00Sooooo00?o09_oo`3o^_l0ROl01oooool01?l0m_ooooooooooool0ogd2ooooo`03o`1[oooooooo
oooo00Gooooo00Oo0?mgoooooooooooo05Woooooool0[_oo0?o600;ooooo00?o04coooooool0ohl0
3Oooool01?l04?ooooooooooooooool2o`3o8P03o`3o=?l0;_oooooo01Kooooo0_l0ooH4ooooo`03
obH0oooooooooooo00Cooooo00?o02Soooooooooool05_ooool001[ooooo00?o0000ooooooooool0
oooooonkooooo`03o`2Qoooooooooooo00Wooooo00?o09_oo`29ooooool01_ooool01Ol0m_oo0?o0
oooooooooooo0?mm00;ooooo00?o06_oooooooooool01?ooool01?l0ogOoooooooooool0FOl2oooo
o`07o`2^ool0olKoooooooooool0C?ooooooo`3oS`0=ooooo`03o`0@oooooooooooo00;ooooo00Co
0?lRooooool0;_oo0?ld5oooool2o`3omP?ooooo0_lV0?l5ooooo`03o`0Xoooooooooooo01Gooooo
000Jooooo`03o`000?oooooooooo0?oooooo_?ooool00ol0XOooooooooooo`09ooooo`03o`2Kool0
ROoooooo00Kooooo00Oo0?Koo`3o`?ooooooooooo`3oOOoooooo06_o00Oooooo00Co0?mgoooooooo
oooo05Wo0_ooool01ol0[_oo0?o6oooooooooooo04coooooool0ohl03Oooool00ol04?oooooooooo
o`02ooooo`;o0?lR00?o02koo`3o=?l0oc@05oooool00ol0ooKoooooooooo`02ooooo`;o9P3o1?oo
ool2o`0XoaGooooo000Jooooo`03o`000?oooooooooo0?oooooo_Oooool00ol0XOooooooooooo`09
ooooo`03o`2Kool0ROoooooo00Kooooo00Oo0?Koo`3o`?ooooooooooo`3oOOoooooo06_o00Oooooo
00Co0?mgoooooooooooo05Wo0_ooool01ol0[_oo0?o6o`3oa_oooooo04coooooool0ohl03Oooool0
0ol04?ooooooooooo`03ooooo`03o`3o8_l0;_oo02ko00;o0?ld5_ooool2o`3omPCooooo0_lV0?l4
ooooo`03o`0Xoooooooooooo01;ooooo000Jooooo`03o`000?oooooooooo0?oooooo__ooool00ol0
XOooooooooooo`09ooooo`03o`2Kool0ROoooooo00Kooooo00Oo0?Koo`3o`?ooooooooooo`3oOOoo
oooo06_o00Oooooo00Co0?mgoooooooooooo05Wo0_ooool01ol0[_ooooooo`3oa_oooooo04cooooo
ool0ohl03?ooool00ol04?ooooooooooo`04ooooo`04o`3o8_oooooo02koooooo`;o0?ld5_ooool2
o`3omPCooooo0_lV0?l3ooooo`;o02So4_ooool001[ooooo00?o0000ooooooooool0oooooonooooo
o`03o`2Qoooooooooooo00Wooooo00?o09_oo`29ooooool01_ooool01ol0m_oo0?o0oooooooooooo
0?mmooooool0Jol01oooool01?l0ogOoooooooooool0FOl2ooooo`07o`2^oooooooo0?o6ooooool0
C?ooooooo`3oS`0<ooooo`03o`0@oooooooooooo00Cooooo0_l0ob801?l0;_ooooooooooool0oc@G
ooooo`03o`3om_oooooooooo00?ooooo0_lV0?l3ooooo`03o`0Xoooooooooooo00oooooo000Joooo
o`03o`000?oooooooooo0?oooooo`?ooool00ol0XOooooooooooo`08ooooo`03o`2Kool0ROoooooo
00Oooooo00Ko0?Koo`3o`?ooooooooooo`3oOOl0Jol8ooooo`04o`3oMoooooooooooo`1Io`;ooooo
00Oo0:koooooool0olKoooooo`1<oooooooo0?n?00cooooo00?o013oooooooooool01Oooool01?l0
ob;o02koooooooooool3o`3o=1Gooooo0_l0ooH5ooooo`;o9P3o0_ooool00ol0:?oo0?ldooooo`0>
ooooo`006_ooool00ol0003oooooooooo`3ooooool7ooooo00?o0:7oooooooooool02?ooool00ol0
Vooo08Woooooo`07ooooo`06o`3fool0ol3oooooooooool0oggo06_o2?ooool01?l0ogOooooooooo
ool0FOl2ooooo`04o`2^oooooooo0?o6o`1<o`;ooooo00?o0?n?ooooooooool02_ooool00ol04?oo
ooooooooo`05ooooo`03o`3o8_l0;_oooooo00?ooooo0ol0oc@Dooooo`?o0?of0oooool01Ol0ocCo
9P3oobH0oooooooo02So00oooooo000Jooooo`03o`000?oooooooooo0?oooooo`Oooool00ol0XOoo
ooooooooo`09ooooo`03o`2Kool0ROoooooo00Kooooo00?o0?Koooooool0ol000oooool00ol0Jooo
ooooooooo`06ooooo`04o`3oMoooooooooooo`1Io`;ooooo00Co0:koooooool0olKo04co0_ooool0
0ol0ohooooooooooo`0:ooooo`;o013o1oooool2o`0^o`Gooooo1_l0oc@>ooooo`?o0?ld0_l0ooH0
1Ol0ocCooooooooooooooooo9P3o013ooooo000Jooooo`03o`000?oooooooooo0?oooooo`_ooool0
0ol0XOooooooooooo`09ooooo`03o`2Kool0ROoooooo00Kooooo00?o0?Koooooool0ol000_ooool0
0ol0Jooo0?mmooooo`07ooooo`04o`3oMoooooooooooo`1Io`;ooooo00Co0:kooooooooooooo04co
0_ooool00ol0ohooooooooooo`0;ooooo`03o`0@oooooooooooo00Gooooo00?o0?lRo`0^ool0;_l0
2Oooool>o`3o=0Gooooo0_l0ooH3ooooo`03obH0oooooooooooo00gooooo000Jooooo`03o`000?oo
oooooooo0?oooooo`oooool00ol0XOooooooooooo`09ooooo`03o`29ool0ok[ooooo00Kooooo00?o
0?Koooooool0ol000_ooool00ol0Jooo0?mmooooo`07ooooo`04o`3oMoooooooooooo`1Io`;ooooo
00Co0:kooooooooooooo04co0_ooool00ol0ohooooooooooo`0;ooooo`03o`0@oooooooooooo00Oo
oooo0_l0;_l00ol0ob;oooooooooo`0Iooooo`?o0?of4?ooool001[ooooo00?o0000ooooooooool0
ooooooo4ooooo`03o`2Qoooooooooooo00Sooooo00?o09_oo`29ool0okX01oooool00ol0m_oooooo
o`3o`002ooooo`03o`1[ool0oggooooo00Oooooo00Co0?mgoooooooooooo05Wo0_ooool01?l0[_oo
ooooooooool0C?l2ooooo`;o0?n?3?ooool00ol04?ooooooooooo`08ooooo`;o02ko00?o0?lRoooo
ooooool06_ooool00ol0ooKoooooooooo`0=ooooo`006_ooool00ol0003oooooooooo`3oooooolGo
oooo00?o0:7oooooooooool02?ooool00ol0Vooo08Woo`3o^P07ooooo`07o`3foooooooo0?o0o`3o
`?oooooo06_oo`3oO@08ooooo`04o`3oMoooooooooooo`1Io`;ooooo00Co0:kooooooooooooo04co
0oooool00ol0ohooooooooooo`0:ooooo`03o`0@oooooooooooo00Wooooo0_l0;_l2o`3o8RWooooo
000Jooooo`03o`000?oooooooooo0?ooooooa_ooool00ol0XOooooooooooo`08ooooo`03o`2Kool0
ROoo0?nj00Oooooo0_l0m_l01Ooooooo0?o0ooooool0Jooo0?mm00Sooooo00Co0?mgoooooooooooo
05Wo0_ooool00ol0[_ooooooooooo`02o`1<o`;ooooo0_l0ohl;ooooo`03o`0@oooooooooooo00[o
oooo00Co02koooooool0ob;o0?lR9oooool001[ooooo0ol0003oooooolOooooo00?o0:7ooooooooo
ool02?ooool00ol0Vooo08Woo`3o^P08ooooo`06o`3foooooooo0?o0ooooool0Jooo0?mm2?ooool0
1?l0ogOoooooooooool0FOl2ooooo`05o`2^ooooooooooooo`3oa_l0C?l00oooool00ol0ohoooooo
ooooo`09ooooo`03o`0@oooooooooooo00[ooooo0ol0;_l3o`3o8RCooooo000Jooooo`03o`000?oo
oooooooo0?oooooob?ooool00ol0XOooooooooooo`08ooooo`03o`2Kool0ROoo0?nj00Sooooo00Ko
0?Koooooool0ol3oooooo`1[ool0ogd8ooooo`04o`3oMoooooooooooo`1Io`;ooooo00Co0:kooooo
oooooooooooo0_l0C?l2ooooo`;o0?n?2_ooool00ol04?ooooooooooo`0<ooooo`?o02ko1Ol0ob8O
ooooo`006_ooool00ol0003oooooooooo`3oooooolWooooo00?o0:7oooooooooool02?ooool00ol0
Vooo08Woo`3o^P08ooooo`06o`3foooooooo0?o0ooooool0Jooo0?mm2?ooool2o`3oM`04ooooool0
FOoo05Woooooo`;o0:ko0_ooool00ol0olKo04coooooo`02ooooo`03o`3oSooooooooooo00Sooooo
00?o013oooooooooool03_ooool3o`0^o`;ooooo1ol0ob8Hooooo`006_ooool00ol0003ooooooooo
o`3ooooool[ooooo00?o0:7oooooooooool02?ooool00ol0Vooo08Woo`3o^P08ooooo`06o`3foooo
oooo0?o0ooooool0Jooo0?mm2Oooool2o`3oM`05ooooool0FOooooooooooool0[_l00_ooool00ol0
olKo04coo`1<o`02ooooo`03o`3oSooooooooooo00Sooooo00?o013oooooooooool04?ooool3o`0^
o`Kooooo2Ol0ob8?ooooo`006_ooool00ol0003oooooooooo`3ooooool_ooooo00?o0:7ooooooooo
ool02?ooool00ol0Vooo08Woo`3o^P08ooooo`;o0?Ko00?o0?o0ooooool0Jol00_l0ogd9ooooo`03
o`3oMooooooo05Wo00;ooooo0_l0[_l01?oooooo0?o6o`3oa_l0C?l2ooooo`;o0?n?2Oooool00ol0
4?ooooooooooo`0Booooo`?o02ko6oooool001[ooooo00?o0000ooooooooool0ooooooo<ooooo`03
o`2Qoooooooooooo00Sooooo00?o09_oo`29ool0okX02Oooool01_l0m_oo0?o0ooooool0Jooooooo
o`3oO@Wooooo0_l0ogL01Ol0FOoooooooooooooooooo0:ko00;ooooo00?o0?o6o`1<ool0C?l00_oo
ool00ol0ohooooooooooo`07ooooo`;o013o5Oooool8o`0^oa?ooooo000Jooooo`03o`000?oooooo
oooo0?oooooocOooool00ol0XOooooooooooo`08ooooo`03o`2Kool0ROoo0?nj00Wooooo00?o0?Ko
o`3o`?ooool00_l0Jol2o`3oO@Wooooo00?o0?mgo`1Iool0FOl00_ooool2o`2^o`04ooooool0olKo
ooooo`1<o`;ooooo0_l0ohl9ooooo`03o`0@oooooooooooo01[ooooo1?l0;_l?ooooo`006_ooool0
0ol0003oooooooooo`3oooooolkooooo00?o0:7oooooooooool02?ooool00ol0Vooo08Woo`3o^P09
ooooo`07o`3fool0ol3o0?o0ooooool0Joooooooo`3oO@0:ooooo`03o`3oMol0FOoooooo00;ooooo
0_l0[_l01?l0olKoooooo`1<ool0C?l2ooooo`;o0?n?2?ooool00ol04?ooooooooooo`0/ooooo`00
6_ooool00ol0003oooooooooo`3ooooooloooooo00?o0:7oooooooooool02?ooool01?l0Vooo08Wo
o`3o^_l0okX8ooooo`06o`3foooooooo0?o0ooooool0Jooooooo0_l0ogd:ooooo`03o`1Iool0ogOo
oooo00;ooooo0_l0[_l2ooooo`;o04co0_ooool00ol0ohooooooooooo`06ooooo`;o013o;?ooool0
01[ooooo00?o0000ooooooooool0ooooooo@ooooo`03o`2Qoooooooooooo00Sooooo00Co09_oo`29
ool0j_oo0?nj2?ooool2o`3fo`;o0?o00_l0Jol00ooooooo0?mmooooo`09ooooo`03o`1Iool0ogOo
0?mg00?ooooo0ol0[_l01?oooooo04coo`1<ooooool2o`3oS`Sooooo00?o013oooooooooool0:Ooo
ool001[ooooo00?o0000ooooooooool0oooooooAooooo`03o`2Qoooooooooooo00Wooooo00?o08Wo
o`3Zool0okX02Oooool01_l0m_ooooooo`3o`?oooooo06_oooooo`;o0?mm2Oooool01?l0FOoooooo
o`3oMol0ogL3ooooo`04o`3oa_l0[_oo0:koo`2^o`;o04co00?oooooo`3oSol0ohl01oooool2o`0@
oaSooooo0_l0[_l?ooooo`006_ooool00ol0003oooooooooo`3oooooom;ooooo00?o0:7ooooooooo
ool02Oooool2o`29o`;o0?nj2?ooool2o`3fo`;o0?o000Co06_ooooooooooooo0?mm2Oooool2o`1I
o`03ooooool0ogOo0?mg00?ooooo0_l0olH2o`2^o`?o04co00?o0?n?ooooooooool01_ooool00ol0
4?ooooooooooo`0Booooo`?o0:ko4Oooool001[ooooo00?o0000ooooooooool0oooooooCooooo`;o
0:7o2oooool00ol0ROooooooo`3o^P09ooooo`03o`3foooooooo0?o000;o06_o00?oooooo`3oOOl0
ogd02Oooool00ol0FOooooooooooo`03o`3oM`;ooooo0_l0olH3o`2^o`Co04co1_ooool00ol04?oo
ooooooooo`0;ooooo`Ko0:ko0_ooool3o`3oM`oooooo000Jooooo`03o`000?oooooooooo0?oooooo
eOooool00ol0XOooooooooooo`09ooooo`04o`29ool0Vooo0?njo`3o^PSooooo0_l0m_l2o`3o`003
o`1[oooooooooooo00?o0?mm1oooool00ol0FOooooooooooo`02ooooo`;o0?mg0_ooool2o`3oaPCo
oooo00?o0:koo`1<ool0C?l00_l0C?l3ooooo`;o013o1Oooool6o`2^o`?ooooo1Ol0ogL00ooooooo
04coo`1<o`0?ooooo`006_ooool00ol0003oooooooooo`3oooooomKooooo00?o0:7oooooooooool0
2Oooool2o`29o`03o`3Zool0ok[ooooo00Sooooo00Co0?Koooooool0ol3o06_o1?ooool2o`3oO@Ko
oooo0_l0FOl4ooooo`Co0?mg0_l0olH5ooooo`;o0?n?1Ol0C?l00ol04?oo04coo`2^o`02o`2^o`Go
oooo2_l0C?lAooooo`006_ooool00ol0003oooooooooo`3oooooomOooooo0_l0XOl;ooooo`03o`29
ool0Vooo0?nj00Wooooo0_l0m_l00ol0ol3o06_oo`1[o`04ooooo`;o0?mm1_ooool00ol0FOoooooo
ooooo`07ooooo`;o0?o61_l0ogL2o`3oS`;ooooo00?o0?mgo`0@ool04?l01ol0C?lKooooo`006_oo
ool00ol0003oooooooooo`3oooooomWooooo00?o0:7oooooooooool02Oooool2o`29o`03o`3Zool0
ok[ooooo00Sooooo00?o0?Koooooool0ol000_l0Jol4ooooo`?o0?mm1?ooool2o`1Io`Wooooo0_l0
olH4ooooo`;o0?mg0ol0ohl2ooooo`;o013o8?ooool001[ooooo00?o0000ooooooooool0oooooooJ
ooooo`03o`2Qoooooooooooo00[ooooo00Co08Woo`2Kool0j_oo0?nj2?ooool3o`3fo`03o`3o`?l0
Jooo06_o00Gooooo0_l0ogd4ooooo`03o`1Ioooooooooooo00Sooooo0ol0olH6ooooo`Co0?n?00?o
013oooooooooool07Oooool001[ooooo0ol0003oooooom_ooooo0_l0XOl;ooooo`03o`29ool0Vooo
09_o00;o0?nj2Oooool3o`3fo`03o`1[oooooooooooo00Cooooo0ol0ogd2ooooo`03o`1Ioooooooo
oooo00[ooooo0_l0olH8ooooo`04o`3oSol04?oo013oo`3oSacooooo000Jooooo`03o`000?oooooo
oooo0?oooooogOooool00ol0XOooooooooooo`09ooooo`;o08Wo00Co09_oo`3Zool0ok[o0?nj2_oo
ool00ol0m_oo06_oo`1[o`07ooooo`?o0?mm0_l0FOl<ooooo`;o0?o62Oooool01?l04?oo0?n?o`3o
Sol0ohlIooooo`006_ooool00ol0003oooooooooo`3oooooomkooooo00?o0:7oooooooooool02_oo
ool2o`29o`04o`2Koooooooo0?njo`3o^P_ooooo0_l0Jol00ol0m_ooooooooooo`05ooooo`;o0?mm
0_l0FOl<ooooo`Co0?o61_ooool2o`0@o`03ooooool0ohoo0?n?00Co0?n?00Coooooo`3fool0m_oo
0?Ko3oooool001[ooooo00?o0000ooooooooool0oooooooOooooo`;o0:7o3?ooool2o`29o`04o`2K
oooooooo0?njo`3o^P_ooooo0_l0Jol2o`3fo`Oooooo00?o0?mmo`1Iool0FOl01?l0ogd:ooooo`Co
0?o61?ooool3o`0@o`Go0?Ko0ol0ohl?ooooo`006_ooool00ol0003oooooooooo`3oooooon7ooooo
0_l0XOl<ooooo`;o08Wo0_l0j_l3o`3o^P[ooooo0_l0Jol6o`3fo`Cooooo0_l0FOl2ooooo`Ko0?mm
2?ooool2o`3oaPCo0?Ko00Coooooo`0@ool04?oo013o5?ooool001[ooooo00?o0000ooooooooool0
oooooooSooooo`;o0:7o3?ooool2o`29o`;o0>[o00Coooooo`3o^_l0ok[o0?nj2Oooool2o`1[o`04
ooooool0ol3o0?o0o`3o`0Ko0?Ko0_l0FOl@o`3fo`03o`3oOOl0olKo0?o600;o0?o60ol0ogd3o`0@
o`;o0?mm3oooool001[ooooo00?o0000ooooooooool0oooooooUooooo`03o`2Qoooooooooooo00_o
oooo0_l0ROl3o`3Zo`03ooooool0ok[o0?nj00;o0?nj1oooool3o`1[o`03ooooool0ol3o0?o000;o
0?o01?ooool2o`1Ioa?ooooo1Ol0olH00ooooooo013oo`0@o`0?ooooo`006_ooool00ol0003ooooo
ooooo`3oooooonKooooo0_l0XOl=ooooo`?o08Wo0ol0j_l2ooooo`Co0?nj1_ooool3o`1[o`;ooooo
0ol0ol03ooooo`?o05Wo5Oooool3o`3oaPoooooo000Jooooo`03o`000?oooooooooo0?ooooooj?oo
ool2o`2Qo`gooooo00Co09_oo`29ool0ROoo08Wo0ol0j_l3ooooo`?o0?nj1_ooool3o`1[o`;ooooo
1?l0ol02ooooo`Co05Wo8oooool001[ooooo00?o0000ooooooooool0oooooooZooooo`?o0:7o3Ooo
ool00ol0Vooo08Woo`29o`02o`29o`Go0>[o1_l0okX3ooooo`?o06_o0oooool6o`3o`0?o05Wo3Ooo
ool4o`3Zo`oooooo000Jooooo`03o`000?oooooooooo0?ooooookOooool3o`2Qo`cooooo0_l0Vol0
1?oooooo08Woo`29ool0ROl2ooooo`Go0>[o00?oooooo`3o^_l0okX01?l0okX3o`1[o`Ko0?nj0ol0
ol04o`1Io`Co0?o01Ol0j_lCooooo`006_ooool00ol0003oooooooooo`3ooooooo3ooooo0ol0XOl;
ooooo`?o09_o00Coooooo`29ool0ROoo08Wo1?ooool:o`3Zo`Go06_o2?l0j_l3o`1Io`03o`3Zool0
ol3o0?o000Oo0?o03oooool001[ooooo00?o0000ooooooooool0ooooooocooooo`?o0:7o2oooool3
o`2Ko`03ooooool0ROoo08Wo00Co08Wo3Oooool6o`1[o`Gooooo1?l0FOlEooooo`006_ooool00ol0
003oooooooooo`3oooooooKooooo1?l0XOl:ooooo`Co09_o0oooool=o`29o`Kooooo1_l0Jol00ooo
oooo08Woo`29o`06o`1Io`oooooo000Jooooo`03o`000?oooooooooo0?oooooon_ooool5o`2Qo`Wo
oooo1_l0Vol:ooooo`co08Wo2Ol0Jol?ooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo
1Ol0XOl:ooooo`Go09_o:Oooool001[ooooo00?o0000ooooooooool0ooooooooooooo`Gooooo1Ol0
XOl:ooooo`Go09_o9?ooool001[ooooo00?o0000ooooooooool0ooooooooooooo`[ooooo3ol0XOl=
o`2Ko`So0:7o3oooool001[ooooo00?o0000ooooooooool0ooooooooooooobKooooo2?l0Vol?oooo
o`006_ooool3o`000?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo
?Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooo
oooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo?Oooool001[o
oooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooo
oooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo?Oooool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {369.812, 0}} -> {-7.03945, -0.044894, \
0.268817, 0.00274944}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 600 370.82 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.0147145 0.613362 [
[.21429 .00221 -9 -9 ]
[.21429 .00221 9 0 ]
[.40476 .00221 -9 -9 ]
[.40476 .00221 9 0 ]
[.59524 .00221 -9 -9 ]
[.59524 .00221 9 0 ]
[.78571 .00221 -9 -9 ]
[.78571 .00221 9 0 ]
[.97619 .00221 -9 -9 ]
[.97619 .00221 9 0 ]
[.01131 .13739 -18 -4.5 ]
[.01131 .13739 0 4.5 ]
[.01131 .26006 -18 -4.5 ]
[.01131 .26006 0 4.5 ]
[.01131 .38273 -18 -4.5 ]
[.01131 .38273 0 4.5 ]
[.01131 .5054 -18 -4.5 ]
[.01131 .5054 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01471 m
.21429 .02096 L
s
[(100)] .21429 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(200)] .40476 .00221 0 1 Mshowa
.59524 .01471 m
.59524 .02096 L
s
[(300)] .59524 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(400)] .78571 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(500)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.0619 .01471 m
.0619 .01846 L
s
.1 .01471 m
.1 .01846 L
s
.1381 .01471 m
.1381 .01846 L
s
.17619 .01471 m
.17619 .01846 L
s
.25238 .01471 m
.25238 .01846 L
s
.29048 .01471 m
.29048 .01846 L
s
.32857 .01471 m
.32857 .01846 L
s
.36667 .01471 m
.36667 .01846 L
s
.44286 .01471 m
.44286 .01846 L
s
.48095 .01471 m
.48095 .01846 L
s
.51905 .01471 m
.51905 .01846 L
s
.55714 .01471 m
.55714 .01846 L
s
.63333 .01471 m
.63333 .01846 L
s
.67143 .01471 m
.67143 .01846 L
s
.70952 .01471 m
.70952 .01846 L
s
.74762 .01471 m
.74762 .01846 L
s
.82381 .01471 m
.82381 .01846 L
s
.8619 .01471 m
.8619 .01846 L
s
.9 .01471 m
.9 .01846 L
s
.9381 .01471 m
.9381 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13739 m
.03006 .13739 L
s
[(0.2)] .01131 .13739 1 0 Mshowa
.02381 .26006 m
.03006 .26006 L
s
[(0.4)] .01131 .26006 1 0 Mshowa
.02381 .38273 m
.03006 .38273 L
s
[(0.6)] .01131 .38273 1 0 Mshowa
.02381 .5054 m
.03006 .5054 L
s
[(0.8)] .01131 .5054 1 0 Mshowa
.125 Mabswid
.02381 .04538 m
.02756 .04538 L
s
.02381 .07605 m
.02756 .07605 L
s
.02381 .10672 m
.02756 .10672 L
s
.02381 .16806 m
.02756 .16806 L
s
.02381 .19872 m
.02756 .19872 L
s
.02381 .22939 m
.02756 .22939 L
s
.02381 .29073 m
.02756 .29073 L
s
.02381 .3214 m
.02756 .3214 L
s
.02381 .35206 m
.02756 .35206 L
s
.02381 .4134 m
.02756 .4134 L
s
.02381 .44407 m
.02756 .44407 L
s
.02381 .47474 m
.02756 .47474 L
s
.02381 .53607 m
.02756 .53607 L
s
.02381 .56674 m
.02756 .56674 L
s
.02381 .59741 m
.02756 .59741 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02104 L
.03279 .02006 L
.0379 .01898 L
.04262 .01816 L
.04714 .01752 L
.05212 .01697 L
.05713 .01653 L
.06244 .01617 L
.06792 .01588 L
.07293 .01568 L
.07871 .01551 L
.0842 .01538 L
.08925 .0153 L
.09394 .01523 L
.09909 .01518 L
.10458 .01513 L
.10994 .0151 L
.11487 .01508 L
.12028 .01506 L
.12599 .01504 L
.13096 .01503 L
.13561 .01503 L
.1407 .01502 L
.14616 .01502 L
.14872 .01501 L
.15145 .01501 L
.15634 .01501 L
.15905 .01501 L
.1616 .01501 L
.16439 .01501 L
.16596 .01501 L
.1674 .01501 L
.17244 .01501 L
.17521 .01501 L
.17783 .01501 L
.18026 .01501 L
.18291 .01501 L
.18752 .01501 L
.20645 .015 L
.21168 .015 L
.21722 .015 L
.22241 .015 L
.22715 .015 L
.23166 .015 L
.23658 .015 L
.23928 .015 L
Mistroke
.24178 .015 L
.24433 .015 L
.24672 .015 L
.24896 .015 L
.25138 .015 L
.25559 .015 L
.25799 .015 L
.26051 .015 L
.26503 .015 L
.26992 .015 L
.27454 .015 L
.27986 .015 L
.28471 .015 L
.30306 .015 L
.31274 .015 L
.32301 .015 L
.33178 .015 L
.33676 .015 L
.34144 .015 L
.34615 .015 L
.3513 .015 L
.35667 .015 L
.36166 .015 L
.36636 .015 L
.37062 .015 L
.37554 .015 L
.38018 .015 L
.4187 .015 L
.42812 .015 L
.43822 .015 L
.44402 .015 L
.44931 .015 L
.45463 .015 L
.45967 .015 L
.46442 .015 L
.46682 .015 L
.46948 .015 L
.47173 .015 L
.47416 .015 L
.47645 .015 L
.47856 .015 L
.47976 .015 L
.48103 .015 L
.48334 .015 L
.48475 .015 L
.48608 .015 L
.48728 .015 L
.48857 .015 L
.49402 .015 L
.49539 .015 L
Mistroke
.49669 .015 L
.49795 .015 L
.49912 .015 L
.5013 .015 L
.50368 .015 L
.50605 .015 L
.50857 .015 L
.51403 .015 L
.51898 .015 L
.52981 .015 L
.54001 .015 L
.57858 .015 L
.6196 .015 L
.65911 .015 L
.6971 .015 L
.73755 .015 L
.77648 .015 L
.81786 .015 L
.85772 .015 L
.89607 .015 L
.93687 .015 L
.97616 .015 L
.97619 .015 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .02121 L
.03053 .02077 L
.03279 .02026 L
.04262 .01834 L
.04762 .01762 L
.05293 .01703 L
.05746 .01663 L
.06244 .01628 L
.06792 .01599 L
.07293 .01578 L
.07871 .0156 L
.0842 .01547 L
.08925 .01538 L
.09394 .01531 L
.09909 .01525 L
.10458 .01521 L
.10994 .01517 L
.11487 .01515 L
.12028 .01513 L
.12599 .01511 L
.13096 .0151 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01508 L
.14867 .01508 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.16531 .01508 L
.16596 .01508 L
.1667 .01508 L
.1674 .01508 L
.16856 .01508 L
.16984 .01508 L
.17049 .01508 L
.17118 .01508 L
.17243 .01508 L
.17367 .01508 L
.17485 .01508 L
.1759 .01508 L
Mistroke
.17706 .01508 L
.17777 .01508 L
.17844 .01508 L
.17969 .01508 L
.18103 .01508 L
.18249 .01508 L
.18511 .01508 L
.18752 .01508 L
.20798 .01507 L
.21797 .01507 L
.22706 .01507 L
.23159 .01507 L
.2365 .01507 L
.24114 .01507 L
.24543 .01507 L
.24777 .01507 L
.24996 .01507 L
.25257 .01507 L
.25497 .01507 L
.25984 .01507 L
.26509 .01507 L
.26984 .01507 L
.27492 .01507 L
.28405 .01507 L
.30476 .01507 L
.31503 .01506 L
.32044 .01506 L
.32615 .01506 L
.33115 .01506 L
.33665 .01506 L
.34127 .01506 L
.34631 .01506 L
.35154 .01506 L
.3565 .01506 L
.36133 .01506 L
.3658 .01506 L
.37061 .01506 L
.37593 .01506 L
.38671 .01506 L
.40765 .01506 L
.42688 .01506 L
.43662 .01506 L
.4457 .01506 L
.45517 .01506 L
.46018 .01506 L
.46553 .01506 L
.47576 .01506 L
.48153 .01506 L
.48685 .01506 L
.507 .01506 L
Mistroke
.54637 .01506 L
.58422 .01506 L
.62453 .01506 L
.66332 .01506 L
.70457 .01506 L
.74429 .01506 L
.78251 .01506 L
.82317 .01506 L
.86232 .01506 L
.90392 .01506 L
.94401 .01506 L
.97619 .01506 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02121 L
.03053 .02078 L
.03279 .02027 L
.04262 .01836 L
.04762 .01764 L
.05293 .01705 L
.05746 .01665 L
.06244 .0163 L
.06792 .016 L
.07293 .01579 L
.07871 .01561 L
.0842 .01548 L
.08925 .01539 L
.09394 .01532 L
.09909 .01526 L
.10458 .01521 L
.10994 .01518 L
.11487 .01515 L
.12028 .01513 L
.12599 .01512 L
.13096 .01511 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01509 L
.14867 .01509 L
.15145 .01509 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.1653 .01508 L
.16596 .01508 L
.16671 .01508 L
.1674 .01508 L
.16856 .01508 L
.16984 .01508 L
.17049 .01508 L
.17118 .01508 L
.17243 .01508 L
.17367 .01508 L
.17485 .01508 L
.1759 .01508 L
Mistroke
.17706 .01508 L
.17777 .01508 L
.17844 .01508 L
.17969 .01508 L
.18103 .01508 L
.18249 .01508 L
.18511 .01508 L
.18752 .01508 L
.20798 .01508 L
.21797 .01507 L
.22706 .01507 L
.23159 .01507 L
.2365 .01507 L
.24114 .01507 L
.24543 .01507 L
.24996 .01507 L
.25255 .01507 L
.25497 .01507 L
.26509 .01507 L
.27494 .01507 L
.2799 .01507 L
.28531 .01507 L
.30383 .01507 L
.31413 .01507 L
.32348 .01507 L
.32866 .01507 L
.33427 .01507 L
.33953 .01507 L
.34444 .01507 L
.34902 .01507 L
.35393 .01507 L
.35938 .01507 L
.36435 .01507 L
.36953 .01507 L
.37516 .01507 L
.38048 .01507 L
.38541 .01507 L
.40564 .01507 L
.42464 .01507 L
.43348 .01507 L
.44279 .01507 L
.44766 .01507 L
.45024 .01507 L
.453 .01507 L
.45554 .01507 L
.45785 .01507 L
.46017 .01507 L
.46236 .01507 L
.46351 .01507 L
.46475 .01507 L
Mistroke
.46592 .01507 L
.46698 .01507 L
.46823 .01507 L
.46894 .01507 L
.46959 .01507 L
.47079 .01507 L
.47207 .01507 L
.47276 .01507 L
.4734 .01507 L
.47485 .01507 L
.47746 .01507 L
.48235 .01507 L
.5008 .01507 L
.5055 .01507 L
.51054 .01507 L
.5153 .01507 L
.51964 .01507 L
.52228 .01507 L
.52472 .01507 L
.5274 .01507 L
.52876 .01507 L
.52949 .01507 L
.53025 .01507 L
.53155 .01507 L
.53275 .01507 L
.53403 .01507 L
.53476 .01507 L
.53544 .01507 L
.53667 .01507 L
.53779 .01507 L
.53908 .01507 L
.5403 .01507 L
.54494 .01507 L
.55004 .01507 L
.56033 .01507 L
.57879 .01507 L
.59989 .01507 L
.61915 .01507 L
.62869 .01507 L
.63908 .01507 L
.65799 .01507 L
.69871 .01507 L
.73791 .01507 L
.77957 .01507 L
.81971 .01507 L
.85833 .01507 L
.8994 .01507 L
.93896 .01507 L
.97619 .01507 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .0214 L
.02846 .02122 L
.03053 .0208 L
.03279 .02029 L
.04262 .0184 L
.04762 .01769 L
.05293 .0171 L
.05746 .0167 L
.06244 .01635 L
.06792 .01606 L
.07293 .01585 L
.07871 .01566 L
.0842 .01553 L
.08925 .01544 L
.09394 .01537 L
.09909 .01532 L
.10458 .01527 L
.10994 .01524 L
.11487 .01521 L
.12028 .01519 L
.12599 .01517 L
.13096 .01516 L
.13561 .01516 L
.1407 .01515 L
.14335 .01515 L
.14616 .01515 L
.14867 .01514 L
.15145 .01514 L
.15397 .01514 L
.15634 .01514 L
.15769 .01514 L
.15911 .01514 L
.16033 .01514 L
.16102 .01514 L
.16166 .01514 L
.16241 .01514 L
.16312 .01514 L
.16444 .01514 L
.16518 .01514 L
.16586 .01514 L
.16661 .01514 L
.1674 .01514 L
.17202 .01514 L
.17324 .01514 L
.17457 .01514 L
.17582 .01514 L
.17698 .01514 L
Mistroke
.17771 .01514 L
.17836 .01514 L
.17912 .01514 L
.17983 .01514 L
.18108 .01514 L
.18178 .01514 L
.18243 .01514 L
.18491 .01514 L
.18752 .01514 L
.20742 .01513 L
.21611 .01513 L
.22555 .01513 L
.23077 .01513 L
.23559 .01513 L
.2402 .01513 L
.2451 .01513 L
.24757 .01513 L
.25023 .01513 L
.25505 .01513 L
.25784 .01513 L
.26078 .01513 L
.26602 .01513 L
.27104 .01513 L
.27559 .01513 L
.2858 .01513 L
.30418 .01513 L
.31353 .01513 L
.32341 .01513 L
.32857 .01513 L
.33424 .01513 L
.33902 .01513 L
.34422 .01513 L
.34945 .01513 L
.35441 .01513 L
.35923 .01513 L
.3637 .01513 L
.36852 .01513 L
.37384 .01513 L
.38461 .01513 L
.40556 .01513 L
.42478 .01513 L
.43453 .01513 L
.4436 .01513 L
.45307 .01513 L
.45808 .01513 L
.46344 .01513 L
.47366 .01513 L
.48476 .01513 L
.5049 .01513 L
.54579 .01513 L
Mistroke
.58516 .01513 L
.62301 .01513 L
.66332 .01513 L
.70211 .01513 L
.74336 .01513 L
.78309 .01513 L
.8213 .01513 L
.86196 .01513 L
.90111 .01513 L
.94272 .01513 L
.97619 .01513 L
Mfstroke
1 .119 0 r
.02381 .01472 m
.02499 .03248 L
.02605 .04448 L
.02729 .05204 L
.02846 .0547 L
.02954 .05509 L
.03053 .05457 L
.03163 .0535 L
.03279 .05207 L
.03786 .04512 L
.04262 .03926 L
.05205 .03061 L
.05706 .02736 L
.06244 .02465 L
.06784 .02258 L
.07373 .02087 L
.07929 .01966 L
.08445 .01881 L
.08956 .01816 L
.09419 .0177 L
.09954 .01729 L
.10458 .01699 L
.10923 .01678 L
.11434 .01659 L
.11968 .01645 L
.12466 .01635 L
.12932 .01627 L
.13357 .01622 L
.13848 .01617 L
.14313 .01614 L
.14772 .01611 L
.15033 .0161 L
.15278 .01609 L
.15536 .01608 L
.15772 .01608 L
.15896 .01608 L
.16031 .01608 L
.16099 .01607 L
.16172 .01607 L
.16304 .01607 L
.16428 .01607 L
.16542 .01607 L
.16668 .01607 L
.16731 .01607 L
.168 .01607 L
.16917 .01607 L
.17043 .01607 L
.17269 .01607 L
.17382 .01607 L
.17504 .01607 L
Mistroke
.1762 .01607 L
.17727 .01608 L
.17834 .01608 L
.1793 .01607 L
.18041 .01607 L
.18146 .01607 L
.18263 .01607 L
.18388 .01607 L
.18613 .01607 L
.19125 .01606 L
.20158 .01604 L
.21119 .01603 L
.22006 .01601 L
.22491 .01601 L
.23026 .016 L
.23564 .016 L
.23862 .016 L
.24134 .016 L
.24635 .016 L
.24897 .016 L
.25173 .01599 L
.25639 .01599 L
.25903 .01599 L
.26148 .01599 L
.26654 .01599 L
.27203 .01599 L
.28197 .01599 L
.30057 .01599 L
.31087 .01599 L
.32049 .01598 L
.33052 .01598 L
.33584 .01598 L
.34154 .01598 L
.3517 .01598 L
.35744 .01598 L
.36276 .01598 L
.37251 .01598 L
.37743 .01598 L
.38287 .01598 L
.40382 .01598 L
.42304 .01598 L
.44187 .01598 L
.45133 .01598 L
.4617 .01598 L
.48129 .01598 L
.50223 .01598 L
.54369 .01598 L
.58364 .01598 L
.62208 .01598 L
.66296 .01598 L
Mistroke
.70233 .01598 L
.74019 .01598 L
.7805 .01598 L
.81929 .01598 L
.86053 .01598 L
.90026 .01598 L
.93847 .01598 L
.97619 .01598 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.02499 .02095 L
.02605 .02152 L
.02729 .02155 L
.02846 .0214 L
.02954 .0212 L
.03053 .021 L
.03279 .0205 L
.03746 .01951 L
.04262 .01858 L
.05224 .0173 L
.05751 .01681 L
.06244 .01645 L
.06788 .01614 L
.07305 .01591 L
.07768 .01575 L
.08274 .01561 L
.08822 .0155 L
.09407 .01541 L
.09958 .01534 L
.10458 .0153 L
.10945 .01526 L
.1146 .01523 L
.119 .01522 L
.12383 .0152 L
.12902 .01519 L
.13459 .01518 L
.13985 .01517 L
.14465 .01516 L
.14945 .01516 L
.15188 .01516 L
.15456 .01516 L
.15684 .01516 L
.15803 .01516 L
.15929 .01516 L
.1604 .01515 L
.16161 .01515 L
.16271 .01515 L
.16373 .01515 L
.16503 .01515 L
.16576 .01515 L
.16644 .01515 L
.16768 .01515 L
.16899 .01515 L
.17129 .01515 L
.17377 .01515 L
.17448 .01515 L
.17515 .01516 L
.17641 .01516 L
.17759 .01516 L
Mistroke
.17887 .01516 L
.17962 .01516 L
.18029 .01515 L
.18106 .01515 L
.18179 .01515 L
.18309 .01515 L
.18449 .01515 L
.18687 .01515 L
.18942 .01515 L
.19402 .01515 L
.20447 .01515 L
.21542 .01515 L
.22555 .01514 L
.2305 .01514 L
.23575 .01514 L
.24102 .01514 L
.24402 .01514 L
.24683 .01514 L
.24929 .01514 L
.25189 .01514 L
.25652 .01514 L
.26199 .01514 L
.26696 .01514 L
.27653 .01514 L
.28674 .01514 L
.30512 .01514 L
.31513 .01514 L
.32434 .01514 L
.32916 .01514 L
.33446 .01514 L
.33999 .01514 L
.34516 .01514 L
.35015 .01514 L
.35279 .01514 L
.35559 .01514 L
.35803 .01514 L
.36073 .01514 L
.36321 .01514 L
.36548 .01514 L
.37008 .01514 L
.3725 .01514 L
.37505 .01514 L
.38403 .01514 L
.42211 .01514 L
.42694 .01514 L
.43218 .01514 L
.4368 .01514 L
.44169 .01514 L
.44441 .01514 L
.44585 .01514 L
Mistroke
.4474 .01514 L
.44882 .01514 L
.45012 .01514 L
.45142 .01514 L
.45266 .01514 L
.45386 .01514 L
.45514 .01514 L
.45634 .01514 L
.45743 .01514 L
.45872 .01514 L
.46011 .01514 L
.46264 .01514 L
.46501 .01514 L
.46756 .01514 L
.47215 .01514 L
.48259 .01514 L
.50366 .01514 L
.52491 .01514 L
.54504 .01514 L
.58339 .01514 L
.60279 .01514 L
.62419 .01514 L
.63395 .01514 L
.64446 .01514 L
.66348 .01514 L
.67306 .01514 L
.68353 .01514 L
.68882 .01514 L
.69447 .01514 L
.69721 .01514 L
.6998 .01514 L
.7023 .01514 L
.70464 .01514 L
.70579 .01514 L
.70687 .01514 L
.70813 .01514 L
.70927 .01514 L
.71054 .01514 L
.71171 .01514 L
.713 .01514 L
.71372 .01514 L
.71437 .01514 L
.7157 .01514 L
.71692 .01514 L
.71968 .01514 L
.72211 .01514 L
.72467 .01514 L
.72923 .01514 L
.73347 .01514 L
.74312 .01514 L
Mistroke
.75361 .01514 L
.76353 .01514 L
.78211 .01514 L
.82051 .01514 L
.86136 .01514 L
.9007 .01514 L
.93852 .01514 L
.97619 .01514 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05246 L
.02846 .05542 L
.02954 .05603 L
.03053 .05565 L
.03163 .05468 L
.03279 .05331 L
.04262 .04037 L
.05205 .03142 L
.05742 .02782 L
.06244 .0252 L
.06788 .02301 L
.07305 .02141 L
.07768 .02029 L
.08274 .01933 L
.08822 .01853 L
.09407 .01789 L
.09958 .01744 L
.10458 .01713 L
.10945 .01689 L
.1146 .0167 L
.119 .01657 L
.12383 .01646 L
.12902 .01637 L
.13459 .01629 L
.13985 .01624 L
.14465 .01621 L
.14945 .01618 L
.15188 .01617 L
.15456 .01616 L
.15684 .01616 L
.15803 .01615 L
.15929 .01615 L
.1604 .01615 L
.16161 .01615 L
.16271 .01615 L
.16373 .01615 L
.16503 .01615 L
.16576 .01615 L
.16644 .01615 L
.16768 .01615 L
.16899 .01615 L
.17017 .01615 L
.17127 .01615 L
.17377 .01615 L
.17443 .01615 L
.17515 .01615 L
.17647 .01615 L
Mistroke
.17775 .01615 L
.17894 .01615 L
.17967 .01615 L
.18035 .01615 L
.18163 .01615 L
.18235 .01615 L
.183 .01615 L
.18449 .01615 L
.18696 .01614 L
.18921 .01614 L
.19425 .01613 L
.20335 .01611 L
.2141 .01609 L
.21882 .01609 L
.22403 .01608 L
.2285 .01607 L
.23331 .01607 L
.23839 .01607 L
.24315 .01606 L
.24568 .01606 L
.24844 .01606 L
.25113 .01606 L
.254 .01606 L
.25915 .01606 L
.26393 .01606 L
.2742 .01606 L
.28532 .01606 L
.30548 .01605 L
.31577 .01605 L
.32539 .01605 L
.33543 .01605 L
.34074 .01605 L
.34645 .01605 L
.35137 .01605 L
.35661 .01605 L
.36235 .01605 L
.36766 .01605 L
.37722 .01605 L
.38778 .01605 L
.40873 .01605 L
.4179 .01605 L
.42795 .01605 L
.43705 .01605 L
.44677 .01605 L
.45215 .01605 L
.45704 .01605 L
.46196 .01605 L
.4666 .01605 L
.47122 .01605 L
.47385 .01605 L
Mistroke
.47631 .01605 L
.4789 .01605 L
.48127 .01605 L
.484 .01605 L
.48659 .01605 L
.48881 .01605 L
.49117 .01605 L
.49541 .01605 L
.5001 .01605 L
.50504 .01605 L
.5076 .01605 L
.5104 .01605 L
.51533 .01605 L
.52109 .01605 L
.52647 .01605 L
.54664 .01605 L
.58557 .01605 L
.62695 .01605 L
.66682 .01605 L
.70516 .01605 L
.74597 .01605 L
.78525 .01605 L
.82302 .01605 L
.86325 .01605 L
.90195 .01605 L
.94311 .01605 L
.97619 .01605 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.02499 .03213 L
.02605 .04274 L
.02729 .04842 L
.02846 .05001 L
.02954 .04998 L
.03053 .04934 L
.03163 .0483 L
.03279 .04701 L
.03786 .04096 L
.04262 .03594 L
.05205 .02852 L
.05706 .02573 L
.06244 .0234 L
.06784 .02162 L
.07373 .02014 L
.07929 .0191 L
.08445 .01836 L
.08956 .0178 L
.09419 .0174 L
.09954 .01705 L
.10458 .01679 L
.10923 .0166 L
.11434 .01644 L
.11968 .01632 L
.12466 .01623 L
.12932 .01616 L
.13357 .01612 L
.13848 .01607 L
.14313 .01604 L
.14772 .01602 L
.15033 .01601 L
.15278 .01601 L
.15536 .016 L
.15772 .016 L
.15896 .01599 L
.16031 .01599 L
.16099 .01599 L
.16172 .01599 L
.16304 .01599 L
.16428 .01599 L
.16542 .01599 L
.16668 .01599 L
.16731 .01599 L
.168 .01599 L
.16917 .01599 L
.17043 .01599 L
.17269 .01599 L
.17382 .01599 L
.17504 .01599 L
Mistroke
.1762 .01599 L
.17727 .01599 L
.17834 .01599 L
.1793 .01599 L
.18041 .01599 L
.18146 .01599 L
.18263 .01599 L
.18388 .01599 L
.18613 .01599 L
.18881 .01599 L
.19125 .01598 L
.20158 .01597 L
.21055 .01595 L
.22006 .01594 L
.22479 .01594 L
.23 .01593 L
.2348 .01593 L
.23919 .01592 L
.24435 .01592 L
.24706 .01592 L
.24991 .01592 L
.25471 .01592 L
.25743 .01592 L
.25996 .01592 L
.29906 .01592 L
.31901 .01591 L
.32951 .01591 L
.34061 .01591 L
.35054 .01591 L
.35618 .01591 L
.36145 .01591 L
.37071 .01591 L
.38064 .01591 L
.3908 .01591 L
.40186 .01591 L
.42197 .01591 L
.44172 .01591 L
.45182 .01591 L
.46272 .01591 L
.48217 .01591 L
.50044 .01591 L
.54155 .01591 L
.58114 .01591 L
.61921 .01591 L
.65974 .01591 L
.69876 .01591 L
.74022 .01591 L
.78017 .01591 L
.81861 .01591 L
.85949 .01591 L
Mistroke
.89886 .01591 L
.93672 .01591 L
.97619 .01591 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.02499 .03251 L
.02605 .04478 L
.02729 .05307 L
.02846 .05651 L
.02954 .05748 L
.03053 .05733 L
.03163 .05654 L
.03279 .05529 L
.04262 .04231 L
.05205 .03297 L
.05742 .02918 L
.06244 .02641 L
.06788 .02408 L
.07305 .02238 L
.07768 .02118 L
.08274 .02015 L
.08822 .01929 L
.09407 .01861 L
.09958 .01812 L
.10458 .01778 L
.10945 .01753 L
.1146 .01732 L
.119 .01718 L
.12383 .01706 L
.12902 .01696 L
.13459 .01688 L
.13985 .01683 L
.14465 .0168 L
.14693 .01678 L
.14945 .01677 L
.15072 .01677 L
.15209 .01676 L
.15327 .01676 L
.15456 .01676 L
.15577 .01676 L
.15689 .01675 L
.15808 .01675 L
.15934 .01675 L
.16053 .01675 L
.16164 .01675 L
.16264 .01675 L
.16373 .01676 L
.1685 .01676 L
.17362 .01678 L
.17512 .01678 L
.17655 .01678 L
.17784 .01678 L
.17856 .01678 L
.17924 .01679 L
Mistroke
.17992 .01679 L
.18057 .01679 L
.18178 .01679 L
.18308 .01679 L
.18382 .01678 L
.18449 .01678 L
.18564 .01678 L
.18688 .01678 L
.18911 .01678 L
.19416 .01676 L
.20437 .01673 L
.2153 .01669 L
.22541 .01667 L
.23036 .01666 L
.23561 .01665 L
.24088 .01665 L
.24388 .01665 L
.24669 .01664 L
.24916 .01664 L
.25175 .01664 L
.25639 .01664 L
.25897 .01664 L
.26137 .01664 L
.26682 .01664 L
.27737 .01663 L
.28732 .01663 L
.30592 .01662 L
.31567 .01662 L
.32597 .01662 L
.33477 .01662 L
.34444 .01662 L
.34967 .01662 L
.35463 .01662 L
.36393 .01661 L
.36912 .01661 L
.37393 .01661 L
.38483 .01661 L
.39444 .01661 L
.40347 .01661 L
.42407 .01661 L
.44422 .01661 L
.46272 .01661 L
.50231 .01661 L
.54039 .01661 L
.58092 .01661 L
.61993 .01661 L
.6614 .01661 L
.70135 .01661 L
.73978 .01661 L
.78067 .01661 L
Mistroke
.801 .01661 L
.82004 .01661 L
.83945 .01661 L
.85789 .01661 L
.87815 .01661 L
.89668 .01661 L
.90628 .01661 L
.9165 .01661 L
.92609 .01661 L
.9349 .01661 L
.94512 .01661 L
.95049 .01661 L
.95616 .01661 L
.9611 .01661 L
.96571 .01661 L
.96836 .01661 L
.97077 .01661 L
.97211 .01661 L
.97355 .01661 L
.97492 .01661 L
.97619 .01661 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.02499 .02095 L
.02605 .02153 L
.02729 .02157 L
.02846 .02143 L
.02954 .02123 L
.03053 .02103 L
.03279 .02055 L
.03746 .01959 L
.04262 .01869 L
.05224 .01744 L
.05751 .01696 L
.06244 .01661 L
.06788 .01631 L
.07305 .01608 L
.07768 .01593 L
.08274 .01579 L
.08822 .01568 L
.09407 .01559 L
.09958 .01552 L
.10458 .01548 L
.10945 .01544 L
.1146 .01542 L
.119 .0154 L
.12383 .01538 L
.12902 .01537 L
.13459 .01536 L
.13729 .01535 L
.13985 .01535 L
.14232 .01535 L
.14465 .01535 L
.14704 .01535 L
.14923 .01534 L
.15167 .01534 L
.15295 .01534 L
.15366 .01534 L
.1543 .01534 L
.15553 .01534 L
.15684 .01534 L
.15805 .01534 L
.1592 .01534 L
.15985 .01534 L
.16054 .01534 L
.16177 .01534 L
.1631 .01534 L
.16456 .01534 L
.16908 .01535 L
.17146 .01535 L
.17401 .01535 L
.17526 .01535 L
Mistroke
.17645 .01535 L
.1776 .01535 L
.17866 .01535 L
.17967 .01535 L
.18073 .01535 L
.1818 .01535 L
.18298 .01535 L
.18366 .01535 L
.18431 .01535 L
.18552 .01535 L
.18682 .01535 L
.18823 .01535 L
.19314 .01535 L
.20242 .01534 L
.21236 .01534 L
.21764 .01533 L
.22332 .01533 L
.22865 .01533 L
.23354 .01533 L
.23821 .01533 L
.24313 .01533 L
.24565 .01533 L
.24834 .01533 L
.25318 .01533 L
.25614 .01533 L
.25893 .01533 L
.26415 .01533 L
.2739 .01533 L
.27881 .01533 L
.2842 .01532 L
.30267 .01532 L
.31267 .01532 L
.32215 .01532 L
.32739 .01532 L
.33309 .01532 L
.33823 .01532 L
.34306 .01532 L
.34795 .01532 L
.35244 .01532 L
.35743 .01532 L
.36281 .01532 L
.36769 .01532 L
.37304 .01532 L
.37862 .01532 L
.38381 .01532 L
.39432 .01532 L
.40424 .01532 L
.41315 .01532 L
.42282 .01532 L
.43227 .01532 L
Mistroke
.43764 .01532 L
.44268 .01532 L
.44539 .01532 L
.44797 .01532 L
.45031 .01532 L
.45281 .01532 L
.45551 .01532 L
.45802 .01532 L
.45956 .01532 L
.46031 .01532 L
.46101 .01532 L
.46231 .01532 L
.46299 .01532 L
.46371 .01532 L
.46493 .01532 L
.46562 .01532 L
.46626 .01532 L
.46743 .01532 L
.46867 .01532 L
.46978 .01532 L
.47082 .01532 L
.4732 .01532 L
.48336 .01532 L
.48766 .01532 L
.49219 .01532 L
.49456 .01532 L
.4959 .01532 L
.49715 .01532 L
.49831 .01532 L
.49935 .01532 L
.50056 .01532 L
.5017 .01532 L
.50286 .01532 L
.5041 .01532 L
.50527 .01532 L
.50634 .01532 L
.50895 .01532 L
.51143 .01532 L
.51636 .01532 L
.52173 .01532 L
.53131 .01532 L
.54019 .01532 L
.57939 .01532 L
.59942 .01532 L
.62104 .01532 L
.6402 .01532 L
.65106 .01532 L
.66118 .01532 L
.67084 .01532 L
.67625 .01532 L
Mistroke
.68117 .01532 L
.68388 .01532 L
.68637 .01532 L
.68767 .01532 L
.68911 .01532 L
.68983 .01532 L
.69061 .01532 L
.69134 .01532 L
.69201 .01532 L
.69331 .01532 L
.69452 .01532 L
.69522 .01532 L
.69585 .01532 L
.69658 .01532 L
.69726 .01532 L
.69851 .01532 L
.69966 .01532 L
.70226 .01532 L
.70471 .01532 L
.70695 .01532 L
.71199 .01532 L
.71665 .01532 L
.72107 .01532 L
.73097 .01532 L
.74173 .01532 L
.7615 .01532 L
.7825 .01532 L
.82024 .01532 L
.86043 .01532 L
.89911 .01532 L
.94023 .01532 L
.97619 .01532 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.02499 .03292 L
.02605 .04713 L
.02729 .05956 L
.02846 .06726 L
.02954 .07143 L
.03053 .0734 L
.03163 .07412 L
.03279 .07377 L
.03395 .07268 L
.0352 .07101 L
.03746 .06729 L
.04262 .05812 L
.04793 .04961 L
.05297 .0429 L
.06244 .03362 L
.0675 .03009 L
.07289 .02715 L
.07798 .025 L
.08259 .02346 L
.08803 .02203 L
.09391 .02087 L
.09947 .02004 L
.10458 .01946 L
.10928 .01904 L
.11432 .01869 L
.11907 .01843 L
.1234 .01824 L
.12849 .01807 L
.13402 .01794 L
.13924 .01784 L
.14176 .0178 L
.14407 .01778 L
.1487 .01773 L
.15113 .01772 L
.15237 .01771 L
.15369 .0177 L
.15487 .0177 L
.15593 .0177 L
.157 .0177 L
.15801 .01769 L
.15919 .01769 L
.16028 .01769 L
.16147 .01769 L
.16273 .01769 L
.16401 .0177 L
.16518 .0177 L
.1678 .01771 L
.17254 .01773 L
.17519 .01774 L
Mistroke
.17659 .01774 L
.17736 .01775 L
.17808 .01775 L
.17877 .01775 L
.17951 .01775 L
.18081 .01775 L
.18212 .01775 L
.18333 .01775 L
.1846 .01775 L
.1858 .01775 L
.18688 .01774 L
.18805 .01774 L
.19309 .01772 L
.2022 .01766 L
.21203 .0176 L
.21725 .01758 L
.22287 .01755 L
.22821 .01753 L
.2331 .01752 L
.23777 .01751 L
.24269 .0175 L
.24521 .0175 L
.24789 .0175 L
.25273 .01749 L
.25569 .01749 L
.25849 .01749 L
.26371 .01749 L
.30223 .01747 L
.32214 .01746 L
.33217 .01745 L
.33783 .01745 L
.3432 .01745 L
.34808 .01745 L
.35339 .01745 L
.36268 .01745 L
.36794 .01745 L
.37354 .01745 L
.38359 .01745 L
.40304 .01745 L
.42131 .01745 L
.43112 .01744 L
.44147 .01744 L
.4503 .01744 L
.4553 .01744 L
.45996 .01744 L
.465 .01744 L
.46784 .01744 L
.47047 .01744 L
.47296 .01744 L
.47529 .01744 L
Mistroke
.47772 .01744 L
.479 .01744 L
.48039 .01744 L
.48164 .01744 L
.48279 .01744 L
.48399 .01744 L
.48507 .01744 L
.48614 .01744 L
.48714 .01744 L
.4882 .01744 L
.48935 .01744 L
.49051 .01744 L
.49179 .01744 L
.49243 .01744 L
.49312 .01744 L
.49436 .01744 L
.49678 .01744 L
.49898 .01744 L
.50375 .01744 L
.50824 .01744 L
.51049 .01744 L
.51165 .01744 L
.51292 .01744 L
.51423 .01744 L
.51494 .01744 L
.51561 .01744 L
.5168 .01744 L
.51808 .01744 L
.5188 .01744 L
.51947 .01744 L
.52021 .01744 L
.52098 .01744 L
.52229 .01744 L
.52373 .01744 L
.52638 .01744 L
.52886 .01744 L
.53367 .01744 L
.53884 .01744 L
.58014 .01744 L
.60078 .01744 L
.61083 .01744 L
.61992 .01744 L
.63846 .01744 L
.65818 .01744 L
.69832 .01744 L
.73694 .01744 L
.77802 .01744 L
.81758 .01744 L
.85562 .01744 L
.89612 .01744 L
Mistroke
.9351 .01744 L
.97619 .01744 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02006 L
.0379 .01897 L
.04262 .01815 L
.04714 .01751 L
.05212 .01694 L
.05713 .0165 L
.06244 .01614 L
.06792 .01585 L
.07293 .01565 L
.07871 .01548 L
.0842 .01535 L
.08925 .01526 L
.09394 .0152 L
.09909 .01514 L
.10458 .0151 L
.10994 .01507 L
.11487 .01504 L
.12028 .01502 L
.12599 .01501 L
.13096 .015 L
.13561 .01499 L
.1407 .01498 L
.14616 .01498 L
.15145 .01498 L
.15634 .01497 L
.15889 .01497 L
.1617 .01497 L
.16464 .01497 L
.1674 .01497 L
.17245 .01497 L
.17708 .01497 L
.18752 .01497 L
.19745 .01497 L
.20805 .01497 L
.2132 .01496 L
.21806 .01496 L
.22715 .01496 L
.23177 .01496 L
.23666 .01496 L
.24084 .01496 L
.24543 .01496 L
.24801 .01496 L
.25037 .01496 L
.25567 .01496 L
.26059 .01496 L
Mistroke
.26526 .01496 L
.2703 .01496 L
.27487 .01496 L
.2851 .01496 L
.3035 .01496 L
.31355 .01496 L
.32279 .01496 L
.32762 .01496 L
.33292 .01496 L
.33846 .01496 L
.34114 .01496 L
.34362 .01496 L
.34864 .01496 L
.35129 .01496 L
.3541 .01496 L
.35653 .01496 L
.35881 .01496 L
.36012 .01496 L
.36132 .01496 L
.36263 .01496 L
.36334 .01496 L
.36401 .01496 L
.36518 .01496 L
.36624 .01496 L
.36738 .01496 L
.36861 .01496 L
.36969 .01496 L
.37084 .01496 L
.37181 .01496 L
.37289 .01496 L
.3779 .01496 L
.38258 .01496 L
.38758 .01496 L
.39021 .01496 L
.39301 .01496 L
.39546 .01496 L
.39675 .01496 L
.39815 .01496 L
.39943 .01496 L
.4006 .01496 L
.40173 .01496 L
.40291 .01496 L
.40407 .01496 L
.40512 .01496 L
.40634 .01496 L
.40749 .01496 L
.40856 .01496 L
.40954 .01496 L
.41176 .01496 L
.42146 .01496 L
Mistroke
.42612 .01496 L
.42869 .01496 L
.42996 .01496 L
.43113 .01496 L
.43232 .01496 L
.4334 .01496 L
.43459 .01496 L
.43587 .01496 L
.43694 .01496 L
.4381 .01496 L
.43919 .01496 L
.4402 .01496 L
.44139 .01496 L
.44267 .01496 L
.44498 .01496 L
.44773 .01496 L
.45023 .01496 L
.45567 .01496 L
.46083 .01496 L
.48075 .01496 L
.49918 .01496 L
.51944 .01496 L
.53846 .01496 L
.57623 .01496 L
.61494 .01496 L
.6346 .01496 L
.6561 .01496 L
.67688 .01496 L
.69574 .01496 L
.71537 .01496 L
.72628 .01496 L
.73633 .01496 L
.74547 .01496 L
.75553 .01496 L
.76563 .01496 L
.77112 .01496 L
.77633 .01496 L
.7812 .01496 L
.7865 .01496 L
.78884 .01496 L
.79132 .01496 L
.79365 .01496 L
.79579 .01496 L
.79709 .01496 L
.79851 .01496 L
.79994 .01496 L
.80072 .01496 L
.80144 .01496 L
.80213 .01496 L
.80279 .01496 L
Mistroke
.80401 .01496 L
.80533 .01496 L
.80607 .01496 L
.80676 .01496 L
.80794 .01496 L
.80905 .01496 L
.81158 .01496 L
.81404 .01496 L
.81669 .01496 L
.82192 .01496 L
.82679 .01496 L
.83781 .01496 L
.8579 .01496 L
.87841 .01496 L
.89702 .01496 L
.93707 .01496 L
.97561 .01496 L
.97619 .01496 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.02605 .04932 L
.02729 .06599 L
.02846 .07923 L
.02954 .08891 L
.03072 .09638 L
.0318 .10063 L
.03279 .10272 L
.03396 .10345 L
.03506 .10285 L
.03626 .10122 L
.03756 .09871 L
.04262 .08601 L
.0521 .06348 L
.05746 .05367 L
.06244 .04638 L
.0679 .04007 L
.07373 .0349 L
.07935 .0311 L
.08445 .02843 L
.08943 .0264 L
.09481 .0247 L
.0999 .02345 L
.10458 .02256 L
.10928 .02184 L
.11432 .02125 L
.11907 .02081 L
.1234 .0205 L
.12849 .02021 L
.13402 .01998 L
.13924 .01982 L
.14176 .01976 L
.14407 .01971 L
.14628 .01968 L
.1487 .01965 L
.15113 .01962 L
.15246 .01961 L
.15369 .01961 L
.15487 .0196 L
.15598 .0196 L
.15698 .0196 L
.15806 .0196 L
.15924 .0196 L
.16049 .0196 L
.16156 .01961 L
.16273 .01961 L
.16541 .01963 L
.16786 .01966 L
.17338 .01973 L
.17582 .01975 L
Mistroke
.17711 .01977 L
.17848 .01978 L
.1798 .01979 L
.181 .01979 L
.1822 .01979 L
.18333 .01979 L
.1845 .01979 L
.18575 .01979 L
.18693 .01979 L
.188 .01978 L
.19063 .01976 L
.19312 .01974 L
.20345 .0196 L
.21224 .01949 L
.22194 .01939 L
.23162 .01931 L
.23692 .01929 L
.24189 .01927 L
.24652 .01925 L
.25076 .01924 L
.25299 .01924 L
.25542 .01924 L
.26032 .01923 L
.28161 .01922 L
.30093 .0192 L
.32129 .01918 L
.34003 .01916 L
.34937 .01916 L
.35925 .01915 L
.36917 .01915 L
.38006 .01914 L
.39025 .01914 L
.39955 .01914 L
.42046 .01914 L
.43952 .01913 L
.44938 .01913 L
.46027 .01913 L
.48002 .01913 L
.50102 .01913 L
.54119 .01913 L
.57984 .01913 L
.62095 .01913 L
.66054 .01913 L
.69862 .01913 L
.73915 .01913 L
.77816 .01913 L
.81963 .01913 L
.85958 .01912 L
.89801 .01912 L
.9389 .01912 L
Mistroke
.97619 .01912 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.02605 .04926 L
.02729 .06572 L
.02846 .07855 L
.02954 .08766 L
.03072 .09441 L
.0318 .09801 L
.03279 .09958 L
.03396 .09983 L
.03506 .09893 L
.03626 .0971 L
.03756 .0945 L
.04262 .0821 L
.0521 .06079 L
.05746 .05162 L
.06244 .04481 L
.0679 .03894 L
.07373 .03413 L
.07935 .03059 L
.08445 .02812 L
.08943 .02624 L
.09481 .02466 L
.0999 .02351 L
.10458 .02268 L
.10928 .02202 L
.11432 .02147 L
.11907 .02107 L
.1234 .02078 L
.12849 .02052 L
.13402 .0203 L
.13655 .02023 L
.13924 .02016 L
.14407 .02007 L
.14645 .02004 L
.14775 .02003 L
.14896 .02002 L
.15008 .02001 L
.1511 .02 L
.15223 .02 L
.15344 .01999 L
.15473 .01999 L
.15593 .01999 L
.15724 .01999 L
.15791 .02 L
.15863 .02 L
.15985 .02001 L
.16117 .02001 L
.16354 .02004 L
.16813 .0201 L
.17302 .02019 L
Mistroke
.1754 .02022 L
.17764 .02025 L
.17862 .02026 L
.17965 .02027 L
.18078 .02028 L
.18182 .02028 L
.18303 .02028 L
.18432 .02028 L
.18554 .02028 L
.18665 .02028 L
.18796 .02027 L
.18937 .02026 L
.19195 .02023 L
.19769 .02016 L
.20299 .02008 L
.21337 .01992 L
.22309 .01981 L
.2321 .01973 L
.23716 .0197 L
.2418 .01968 L
.2466 .01966 L
.24932 .01966 L
.25185 .01965 L
.25696 .01964 L
.25982 .01964 L
.26241 .01964 L
.30245 .0196 L
.3208 .01958 L
.33123 .01957 L
.34097 .01956 L
.35138 .01956 L
.36088 .01955 L
.37104 .01955 L
.37663 .01955 L
.38194 .01955 L
.39157 .01954 L
.39644 .01954 L
.40182 .01954 L
.42023 .01954 L
.4604 .01954 L
.49906 .01954 L
.54017 .01953 L
.57976 .01953 L
.61784 .01953 L
.65836 .01953 L
.69738 .01953 L
.73884 .01952 L
.77879 .01952 L
.81723 .01952 L
.85811 .01952 L
Mistroke
.89748 .01952 L
.93534 .01952 L
.97565 .01952 L
.97619 .01952 L
Mfstroke
1 .356 0 r
.02381 .01472 m
.02499 .02095 L
.02605 .02153 L
.02729 .02156 L
.02846 .02141 L
.02954 .02122 L
.03053 .02101 L
.03279 .02053 L
.03746 .01956 L
.04262 .01865 L
.05224 .0174 L
.05751 .01692 L
.06244 .01657 L
.06788 .01627 L
.07305 .01605 L
.07768 .01589 L
.08274 .01576 L
.08822 .01565 L
.09407 .01556 L
.09958 .01549 L
.10458 .01545 L
.10945 .01541 L
.1146 .01539 L
.119 .01537 L
.12383 .01535 L
.12902 .01534 L
.13459 .01533 L
.13985 .01532 L
.14465 .01532 L
.14693 .01532 L
.14945 .01531 L
.15072 .01531 L
.15209 .01531 L
.15338 .01531 L
.15456 .01531 L
.15566 .01531 L
.15669 .01531 L
.15782 .01531 L
.15903 .01531 L
.1603 .01531 L
.16149 .01531 L
.16257 .01531 L
.16373 .01531 L
.17362 .01532 L
.17633 .01532 L
.17782 .01532 L
.17924 .01532 L
.18055 .01532 L
.18129 .01532 L
.18198 .01532 L
Mistroke
.1832 .01532 L
.18449 .01532 L
.18515 .01532 L
.18584 .01532 L
.18708 .01532 L
.18776 .01532 L
.18841 .01532 L
.18987 .01532 L
.19231 .01532 L
.19492 .01532 L
.20437 .01531 L
.2153 .01531 L
.22541 .0153 L
.23036 .0153 L
.23561 .0153 L
.24088 .0153 L
.24391 .0153 L
.24669 .0153 L
.24908 .0153 L
.25169 .0153 L
.25432 .0153 L
.25577 .0153 L
.25708 .0153 L
.25952 .0153 L
.26087 .0153 L
.26213 .0153 L
.2633 .0153 L
.26438 .0153 L
.26557 .0153 L
.26682 .0153 L
.26795 .0153 L
.26915 .0153 L
.27046 .0153 L
.27168 .0153 L
.27405 .0153 L
.27522 .0153 L
.27629 .0153 L
.2775 .0153 L
.27881 .0153 L
.27946 .0153 L
.28016 .0153 L
.2809 .0153 L
.28159 .0153 L
.28282 .0153 L
.28393 .0153 L
.28522 .0153 L
.28644 .0153 L
.28866 .0153 L
.29101 .0153 L
.29523 .0153 L
Mistroke
.29977 .0153 L
.30476 .0153 L
.32582 .01529 L
.3358 .01529 L
.34507 .01529 L
.35458 .01529 L
.36496 .01529 L
.37411 .01529 L
.38386 .01529 L
.40529 .01529 L
.42546 .01529 L
.44556 .01529 L
.46404 .01529 L
.48287 .01529 L
.50354 .01529 L
.52307 .01529 L
.54399 .01529 L
.56524 .01529 L
.58537 .01529 L
.60529 .01529 L
.62372 .01529 L
.6424 .01529 L
.65303 .01529 L
.663 .01529 L
.67285 .01529 L
.6832 .01529 L
.69204 .01529 L
.69705 .01529 L
.70171 .01529 L
.70677 .01529 L
.70962 .01529 L
.71097 .01529 L
.71224 .01529 L
.71345 .01529 L
.71454 .01529 L
.71576 .01529 L
.71707 .01529 L
.71833 .01529 L
.71904 .01529 L
.7197 .01529 L
.7209 .01529 L
.72218 .01529 L
.72344 .01529 L
.7246 .01529 L
.72721 .01529 L
.72952 .01529 L
.73194 .01529 L
.74078 .01529 L
.74576 .01529 L
.75029 .01529 L
Mistroke
.76047 .01529 L
.77882 .01529 L
.81874 .01529 L
.85714 .01529 L
.89799 .01529 L
.93733 .01529 L
.97515 .01529 L
.97619 .01529 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.02499 .02075 L
.02605 .02116 L
.02729 .02108 L
.02846 .02086 L
.03279 .01986 L
.0379 .01877 L
.04262 .01796 L
.04714 .01733 L
.05212 .01679 L
.05713 .01636 L
.06244 .01601 L
.06792 .01573 L
.07293 .01554 L
.07871 .01537 L
.0842 .01525 L
.08925 .01517 L
.09394 .01511 L
.09909 .01505 L
.10458 .01501 L
.10994 .01498 L
.11487 .01496 L
.12028 .01494 L
.12599 .01493 L
.13096 .01492 L
.13561 .01491 L
.1407 .01491 L
.14616 .0149 L
.15145 .0149 L
.15634 .01489 L
.1617 .01489 L
.16441 .01489 L
.1674 .01489 L
.17778 .01489 L
.18752 .01489 L
.19735 .01489 L
.20771 .01489 L
.21654 .01489 L
.22155 .01489 L
.22621 .01489 L
.23126 .01489 L
.23673 .01489 L
.23924 .01489 L
.2419 .01489 L
.2442 .01489 L
.24667 .01489 L
.24906 .01489 L
.25124 .01489 L
.25552 .01489 L
.26526 .01489 L
Mistroke
.27004 .01489 L
.27513 .01489 L
.28428 .01489 L
.30502 .01488 L
.31533 .01488 L
.32113 .01488 L
.32647 .01488 L
.33115 .01488 L
.33629 .01488 L
.33888 .01488 L
.34165 .01488 L
.34427 .01488 L
.34665 .01488 L
.34894 .01488 L
.35025 .01488 L
.35147 .01488 L
.35276 .01488 L
.35394 .01488 L
.35523 .01488 L
.35588 .01488 L
.35659 .01488 L
.3578 .01488 L
.35889 .01488 L
.36016 .01488 L
.36135 .01488 L
.36347 .01488 L
.36577 .01488 L
.37659 .01488 L
.38655 .01488 L
.39124 .01488 L
.39627 .01488 L
.40062 .01488 L
.40535 .01488 L
.40823 .01488 L
.41089 .01488 L
.41615 .01488 L
.426 .01488 L
.43497 .01488 L
.44002 .01488 L
.44464 .01488 L
.45526 .01488 L
.46524 .01488 L
.50483 .01488 L
.54291 .01488 L
.58343 .01488 L
.62245 .01488 L
.64234 .01488 L
.66391 .01488 L
.70386 .01488 L
.72371 .01488 L
Mistroke
.74475 .01488 L
.7643 .01488 L
.7826 .01488 L
.79299 .01488 L
.80287 .01488 L
.81173 .01488 L
.8214 .01488 L
.82672 .01488 L
.82932 .01488 L
.83172 .01488 L
.83387 .01488 L
.83622 .01488 L
.83859 .01488 L
.83988 .01488 L
.84108 .01488 L
.84239 .01488 L
.84312 .01488 L
.84381 .01488 L
.84506 .01488 L
.84569 .01488 L
.84638 .01488 L
.84758 .01488 L
.84887 .01488 L
.85009 .01488 L
.85121 .01488 L
.85374 .01488 L
.8565 .01488 L
.86206 .01488 L
.86735 .01488 L
.87235 .01488 L
.88169 .01488 L
.90264 .01488 L
.94113 .01488 L
.97619 .01488 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.02605 .04952 L
.02846 .08166 L
.02962 .09437 L
.03072 .10431 L
.03171 .11145 L
.03279 .11733 L
.03397 .12172 L
.03527 .12434 L
.03592 .12492 L
.03663 .12509 L
.0379 .12436 L
.03916 .12264 L
.04036 .12032 L
.04262 .11486 L
.05221 .08796 L
.06244 .065 L
.06792 .05594 L
.07289 .04936 L
.07794 .04399 L
.08259 .04004 L
.08803 .03637 L
.09391 .03332 L
.0991 .03126 L
.10458 .02957 L
.10954 .02839 L
.11406 .02754 L
.11928 .02678 L
.12422 .02623 L
.12878 .02584 L
.133 .02556 L
.13763 .02533 L
.13997 .02525 L
.14255 .02517 L
.1449 .02512 L
.14623 .0251 L
.14747 .02509 L
.14878 .02508 L
.14997 .02507 L
.15063 .02507 L
.15135 .02507 L
.15264 .02507 L
.15376 .02508 L
.15498 .02509 L
.15626 .02511 L
.15746 .02514 L
.1596 .02519 L
.1619 .02528 L
.16457 .0254 L
.16749 .02556 L
Mistroke
.1728 .02591 L
.17758 .0262 L
.17889 .02626 L
.18028 .02632 L
.18146 .02635 L
.18275 .02638 L
.18345 .02639 L
.18409 .0264 L
.18482 .02641 L
.18551 .02641 L
.18675 .02641 L
.18744 .0264 L
.18808 .0264 L
.18924 .02638 L
.19052 .02636 L
.1931 .02629 L
.19793 .0261 L
.20247 .0259 L
.2127 .02542 L
.22345 .02501 L
.22813 .02487 L
.23312 .02474 L
.23859 .02464 L
.24103 .0246 L
.24367 .02457 L
.24628 .02454 L
.24867 .02452 L
.25092 .0245 L
.25338 .02449 L
.25445 .02448 L
.2556 .02448 L
.25659 .02448 L
.25766 .02447 L
.25888 .02447 L
.26003 .02447 L
.26115 .02447 L
.26219 .02447 L
.26337 .02447 L
.2646 .02447 L
.26566 .02447 L
.26682 .02447 L
.26806 .02447 L
.2694 .02448 L
.2718 .02448 L
.28083 .02451 L
.28638 .02453 L
.2891 .02454 L
.29162 .02455 L
.2939 .02455 L
.29505 .02455 L
Mistroke
.29632 .02455 L
.29759 .02455 L
.29831 .02455 L
.29896 .02455 L
.30022 .02455 L
.30143 .02455 L
.30267 .02455 L
.30402 .02455 L
.30646 .02454 L
.30884 .02454 L
.31102 .02453 L
.32125 .02448 L
.33964 .02438 L
.34873 .02433 L
.35848 .02429 L
.36917 .02425 L
.37915 .02423 L
.38933 .02421 L
.4004 .0242 L
.42053 .02418 L
.46133 .02415 L
.50062 .02413 L
.53839 .02412 L
.57861 .0241 L
.61732 .02409 L
.65848 .02408 L
.69812 .02407 L
.73625 .02407 L
.77683 .02406 L
.8159 .02406 L
.85741 .02405 L
.89741 .02405 L
.9359 .02405 L
.97619 .02404 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.02499 .03291 L
.02605 .04701 L
.02729 .05909 L
.02846 .06627 L
.02954 .06992 L
.03053 .07149 L
.03163 .07186 L
.03279 .07128 L
.03395 .07006 L
.0352 .06834 L
.03746 .06468 L
.04262 .05595 L
.04793 .04798 L
.05297 .04173 L
.06244 .03313 L
.0675 .02986 L
.07289 .02715 L
.07798 .02515 L
.08259 .02373 L
.08803 .02241 L
.09391 .02134 L
.09947 .02057 L
.10458 .02004 L
.10928 .01965 L
.11432 .01933 L
.11907 .01909 L
.1234 .01892 L
.12849 .01877 L
.13402 .01865 L
.13655 .01861 L
.13924 .01857 L
.14407 .01852 L
.14645 .0185 L
.14775 .01849 L
.14896 .01848 L
.15008 .01848 L
.1511 .01848 L
.15223 .01847 L
.15344 .01847 L
.15473 .01847 L
.15593 .01847 L
.15724 .01847 L
.15791 .01847 L
.15863 .01848 L
.15985 .01848 L
.16117 .01849 L
.16354 .0185 L
.16813 .01854 L
.17302 .01859 L
Mistroke
.1754 .01861 L
.17657 .01862 L
.17764 .01862 L
.1786 .01863 L
.17965 .01863 L
.1807 .01864 L
.18182 .01864 L
.1825 .01864 L
.18314 .01864 L
.18435 .01864 L
.18565 .01863 L
.18638 .01863 L
.18706 .01863 L
.18943 .01862 L
.19195 .0186 L
.20299 .01851 L
.21267 .01843 L
.21775 .01839 L
.22309 .01835 L
.22796 .01833 L
.23328 .01831 L
.23811 .01829 L
.2426 .01828 L
.24724 .01827 L
.25145 .01826 L
.25379 .01826 L
.25632 .01826 L
.2609 .01826 L
.27032 .01825 L
.28042 .01824 L
.29151 .01823 L
.30187 .01822 L
.31246 .01821 L
.3225 .01821 L
.33151 .0182 L
.33657 .0182 L
.34132 .0182 L
.35071 .0182 L
.35569 .0182 L
.36107 .0182 L
.36641 .0182 L
.37202 .0182 L
.37682 .01819 L
.38207 .01819 L
.3846 .01819 L
.38735 .01819 L
.38994 .01819 L
.39233 .01819 L
.39449 .01819 L
.39571 .01819 L
Mistroke
.39686 .01819 L
.39807 .01819 L
.39917 .01819 L
.40045 .01819 L
.40166 .01819 L
.40298 .01819 L
.40418 .01819 L
.40484 .01819 L
.40556 .01819 L
.40685 .01819 L
.40937 .01819 L
.41168 .01819 L
.4226 .01819 L
.43247 .01819 L
.44304 .01819 L
.45302 .01819 L
.46211 .01819 L
.46697 .01819 L
.47146 .01819 L
.47639 .01819 L
.47888 .01819 L
.48022 .01819 L
.48162 .01819 L
.48277 .01819 L
.48402 .01819 L
.48516 .01819 L
.48621 .01819 L
.48747 .01819 L
.4886 .01819 L
.48992 .01819 L
.49116 .01819 L
.49224 .01819 L
.49339 .01819 L
.49545 .01819 L
.49767 .01819 L
.5001 .01819 L
.50532 .01819 L
.51027 .01819 L
.51956 .01819 L
.52956 .01819 L
.54046 .01819 L
.58118 .01819 L
.62038 .01819 L
.66203 .01819 L
.68296 .01819 L
.70217 .01819 L
.72097 .01819 L
.73055 .01819 L
.7408 .01819 L
.75111 .01819 L
Mistroke
.76049 .01819 L
.76501 .01819 L
.76992 .01819 L
.77217 .01819 L
.77456 .01819 L
.7766 .01819 L
.77884 .01819 L
.78013 .01819 L
.78132 .01819 L
.78263 .01819 L
.78337 .01819 L
.78403 .01819 L
.78525 .01819 L
.78657 .01819 L
.78782 .01819 L
.78897 .01819 L
.79008 .01819 L
.79112 .01819 L
.79348 .01819 L
.79578 .01819 L
.79824 .01819 L
.80385 .01819 L
.80916 .01819 L
.81912 .01819 L
.82876 .01819 L
.83902 .01819 L
.85743 .01819 L
.89517 .01819 L
.93536 .01819 L
.97404 .01819 L
.97619 .01819 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.02499 .02102 L
.02605 .02166 L
.02729 .02174 L
.02846 .02163 L
.02954 .02145 L
.03053 .02127 L
.03279 .02081 L
.03746 .01986 L
.04262 .01896 L
.05224 .01771 L
.05751 .01722 L
.06244 .01686 L
.06788 .01655 L
.07305 .01632 L
.07768 .01615 L
.08274 .01601 L
.08822 .0159 L
.09407 .0158 L
.09958 .01573 L
.10458 .01569 L
.10945 .01565 L
.1146 .01562 L
.119 .0156 L
.12383 .01559 L
.12902 .01557 L
.13188 .01557 L
.13459 .01556 L
.13711 .01556 L
.13985 .01556 L
.14235 .01555 L
.14465 .01555 L
.14698 .01555 L
.1482 .01555 L
.14949 .01555 L
.15062 .01555 L
.15167 .01555 L
.15282 .01555 L
.15405 .01555 L
.15474 .01555 L
.15539 .01555 L
.15609 .01555 L
.15684 .01555 L
.1581 .01555 L
.15948 .01555 L
.16203 .01555 L
.16442 .01555 L
.16958 .01556 L
.1723 .01556 L
.1752 .01557 L
Mistroke
.17663 .01557 L
.17798 .01557 L
.1793 .01557 L
.18051 .01557 L
.18166 .01557 L
.18287 .01557 L
.18409 .01557 L
.18478 .01557 L
.18543 .01557 L
.18669 .01557 L
.1874 .01557 L
.18806 .01557 L
.19056 .01557 L
.19282 .01557 L
.19523 .01557 L
.20572 .01556 L
.21539 .01555 L
.22425 .01554 L
.23365 .01554 L
.23858 .01553 L
.24376 .01553 L
.24829 .01553 L
.2525 .01553 L
.25493 .01553 L
.25713 .01553 L
.26206 .01553 L
.30209 .01553 L
.31094 .01552 L
.32044 .01552 L
.33087 .01552 L
.34061 .01552 L
.34595 .01552 L
.35102 .01552 L
.36052 .01552 L
.36576 .01552 L
.3706 .01552 L
.37592 .01552 L
.38158 .01552 L
.38613 .01552 L
.39093 .01552 L
.3962 .01552 L
.40103 .01552 L
.40554 .01552 L
.40975 .01552 L
.41436 .01552 L
.41695 .01552 L
.4193 .01552 L
.4216 .01552 L
.42292 .01552 L
.42414 .01552 L
Mistroke
.42541 .01552 L
.42607 .01552 L
.42678 .01552 L
.42805 .01552 L
.42926 .01552 L
.43047 .01552 L
.43157 .01552 L
.43284 .01552 L
.43403 .01552 L
.43616 .01552 L
.43846 .01552 L
.44373 .01552 L
.44929 .01552 L
.45925 .01552 L
.49724 .01552 L
.53768 .01552 L
.57661 .01552 L
.61799 .01552 L
.65786 .01552 L
.69621 .01552 L
.73701 .01552 L
.7763 .01552 L
.81407 .01552 L
.85429 .01552 L
.893 .01552 L
.93416 .01552 L
.9738 .01552 L
.97619 .01552 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.02499 .02089 L
.02605 .02141 L
.02729 .02141 L
.02846 .02124 L
.03053 .02082 L
.03279 .02032 L
.04262 .01846 L
.04762 .01777 L
.05293 .01719 L
.05746 .01681 L
.06244 .01647 L
.06792 .01618 L
.07293 .01597 L
.07871 .01579 L
.0842 .01567 L
.08925 .01558 L
.09394 .01551 L
.09909 .01545 L
.10458 .01541 L
.10994 .01537 L
.11487 .01535 L
.12028 .01533 L
.12599 .01531 L
.13096 .0153 L
.13561 .0153 L
.1407 .01529 L
.14356 .01529 L
.14616 .01529 L
.14845 .01528 L
.15097 .01528 L
.15224 .01528 L
.1529 .01528 L
.1536 .01528 L
.15489 .01528 L
.15608 .01528 L
.15717 .01528 L
.15834 .01528 L
.15945 .01528 L
.16046 .01528 L
.16164 .01528 L
.16292 .01528 L
.16525 .01528 L
.17001 .01529 L
.17513 .01529 L
.17664 .01529 L
.17807 .01529 L
.17946 .01529 L
.18075 .01529 L
.18197 .01529 L
Mistroke
.18327 .01529 L
.18401 .01529 L
.1847 .01529 L
.18601 .01529 L
.18716 .01529 L
.18843 .01529 L
.18975 .01529 L
.19099 .01529 L
.19556 .01529 L
.20588 .01528 L
.2167 .01528 L
.22201 .01528 L
.22693 .01527 L
.23158 .01527 L
.2367 .01527 L
.24185 .01527 L
.24471 .01527 L
.24732 .01527 L
.25193 .01527 L
.25436 .01527 L
.2569 .01527 L
.25913 .01527 L
.2612 .01527 L
.26589 .01527 L
.27095 .01527 L
.27362 .01527 L
.27644 .01527 L
.28162 .01527 L
.28638 .01527 L
.29525 .01527 L
.30498 .01527 L
.31583 .01527 L
.3261 .01527 L
.33533 .01526 L
.34538 .01526 L
.35516 .01526 L
.3601 .01526 L
.36556 .01526 L
.3752 .01526 L
.38425 .01526 L
.40441 .01526 L
.42291 .01526 L
.44181 .01526 L
.45252 .01526 L
.4625 .01526 L
.47301 .01526 L
.48293 .01526 L
.50151 .01526 L
.51122 .01526 L
.5215 .01526 L
Mistroke
.53114 .01526 L
.53995 .01526 L
.54937 .01526 L
.55456 .01526 L
.55695 .01526 L
.5595 .01526 L
.56188 .01526 L
.56404 .01526 L
.56508 .01526 L
.56621 .01526 L
.56726 .01526 L
.56825 .01526 L
.5694 .01526 L
.57067 .01526 L
.5719 .01526 L
.57323 .01526 L
.57446 .01526 L
.57562 .01526 L
.57667 .01526 L
.5778 .01526 L
.58014 .01526 L
.58266 .01526 L
.58721 .01526 L
.59263 .01526 L
.59759 .01526 L
.60783 .01526 L
.6186 .01526 L
.65673 .01526 L
.69731 .01526 L
.73638 .01526 L
.7779 .01526 L
.8179 .01526 L
.85638 .01526 L
.89732 .01526 L
.93675 .01526 L
.97465 .01526 L
.97619 .01526 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .0214 L
.02846 .02122 L
.03053 .0208 L
.03279 .02029 L
.04262 .0184 L
.04762 .01769 L
.05293 .0171 L
.0579 .01666 L
.06244 .01635 L
.06743 .01608 L
.0728 .01585 L
.07777 .01569 L
.0825 .01557 L
.08797 .01546 L
.09305 .01538 L
.09863 .01532 L
.10458 .01527 L
.10994 .01523 L
.11487 .01521 L
.12028 .01519 L
.12599 .01517 L
.13096 .01516 L
.13561 .01515 L
.1407 .01514 L
.14335 .01514 L
.14616 .01514 L
.14867 .01514 L
.15145 .01514 L
.15397 .01514 L
.15634 .01513 L
.15769 .01513 L
.15911 .01513 L
.16033 .01513 L
.16101 .01513 L
.16166 .01513 L
.16241 .01513 L
.1631 .01513 L
.16384 .01513 L
.16463 .01513 L
.16533 .01513 L
.16607 .01513 L
.16671 .01513 L
.1674 .01513 L
.16875 .01513 L
.17002 .01513 L
.17241 .01513 L
.17377 .01513 L
Mistroke
.17521 .01513 L
.17654 .01513 L
.1778 .01513 L
.17897 .01513 L
.18024 .01513 L
.18139 .01513 L
.18245 .01513 L
.18363 .01513 L
.18492 .01513 L
.18752 .01513 L
.19004 .01513 L
.19278 .01513 L
.19775 .01513 L
.20707 .01513 L
.21703 .01513 L
.22231 .01512 L
.228 .01512 L
.23334 .01512 L
.23823 .01512 L
.2429 .01512 L
.24525 .01512 L
.24781 .01512 L
.25058 .01512 L
.25308 .01512 L
.25447 .01512 L
.25521 .01512 L
.25598 .01512 L
.25666 .01512 L
.2574 .01512 L
.25871 .01512 L
.26003 .01512 L
.26123 .01512 L
.2619 .01512 L
.26262 .01512 L
.26394 .01512 L
.26517 .01512 L
.26648 .01512 L
.26883 .01512 L
.27819 .01512 L
.28075 .01512 L
.28345 .01512 L
.28576 .01512 L
.28706 .01512 L
.28828 .01512 L
.28942 .01512 L
.29066 .01512 L
.29183 .01512 L
.29291 .01512 L
.29388 .01512 L
.29495 .01512 L
Mistroke
.29606 .01512 L
.29711 .01512 L
.29949 .01512 L
.30166 .01512 L
.30655 .01512 L
.32716 .01512 L
.33719 .01512 L
.34628 .01512 L
.35581 .01512 L
.36478 .01512 L
.37425 .01512 L
.38449 .01512 L
.40445 .01512 L
.42552 .01512 L
.44539 .01512 L
.46351 .01512 L
.48303 .01512 L
.50395 .01512 L
.54382 .01512 L
.58217 .01512 L
.60196 .01512 L
.62297 .01512 L
.66074 .01512 L
.70096 .01512 L
.73967 .01512 L
.78083 .01512 L
.82047 .01512 L
.8586 .01512 L
.89918 .01512 L
.93825 .01512 L
.97619 .01512 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.02499 .03251 L
.02605 .04472 L
.02729 .05287 L
.02846 .05615 L
.02954 .05699 L
.03053 .05676 L
.03163 .0559 L
.03279 .0546 L
.04262 .04155 L
.05205 .03228 L
.05742 .02853 L
.06244 .02579 L
.06788 .02349 L
.07305 .02181 L
.07768 .02063 L
.08274 .01962 L
.08822 .01877 L
.09407 .0181 L
.09958 .01762 L
.10458 .01729 L
.10945 .01704 L
.1146 .01683 L
.119 .01669 L
.12383 .01658 L
.12902 .01648 L
.13459 .0164 L
.13985 .01634 L
.14465 .01631 L
.14945 .01628 L
.15188 .01627 L
.15456 .01626 L
.15684 .01626 L
.15803 .01625 L
.15929 .01625 L
.1604 .01625 L
.16161 .01625 L
.16271 .01625 L
.16373 .01625 L
.16503 .01625 L
.16576 .01625 L
.16644 .01625 L
.16768 .01625 L
.16899 .01625 L
.17017 .01625 L
.17127 .01625 L
.17377 .01625 L
.17515 .01625 L
.17647 .01625 L
.17765 .01625 L
Mistroke
.17894 .01625 L
.17967 .01625 L
.18033 .01625 L
.1811 .01625 L
.18182 .01625 L
.1831 .01625 L
.18449 .01625 L
.18687 .01624 L
.18942 .01624 L
.19402 .01623 L
.20447 .01621 L
.21542 .01619 L
.22555 .01617 L
.2305 .01617 L
.23575 .01616 L
.24102 .01616 L
.24402 .01616 L
.24683 .01616 L
.24929 .01615 L
.25189 .01615 L
.25652 .01615 L
.26696 .01615 L
.28674 .01615 L
.30512 .01614 L
.31567 .01614 L
.32562 .01614 L
.33455 .01614 L
.33955 .01614 L
.34422 .01614 L
.35371 .01614 L
.35874 .01614 L
.36413 .01614 L
.36978 .01614 L
.37514 .01614 L
.38519 .01614 L
.40507 .01614 L
.42349 .01614 L
.4331 .01614 L
.43749 .01614 L
.44213 .01614 L
.44729 .01614 L
.45203 .01614 L
.45468 .01614 L
.45714 .01614 L
.45855 .01614 L
.45983 .01614 L
.46055 .01614 L
.46132 .01614 L
.46204 .01614 L
.46272 .01614 L
Mistroke
.46395 .01614 L
.46507 .01614 L
.46628 .01614 L
.4676 .01614 L
.46875 .01614 L
.46997 .01614 L
.47217 .01614 L
.47498 .01614 L
.47763 .01614 L
.48257 .01614 L
.50361 .01614 L
.54218 .01614 L
.5832 .01614 L
.60364 .01614 L
.62271 .01614 L
.64105 .01614 L
.6607 .01614 L
.67088 .01614 L
.68196 .01614 L
.68703 .01614 L
.69241 .01614 L
.69746 .01614 L
.70208 .01614 L
.70665 .01614 L
.70898 .01614 L
.71146 .01614 L
.71396 .01614 L
.71508 .01614 L
.71629 .01614 L
.71703 .01614 L
.71771 .01614 L
.71835 .01614 L
.71906 .01614 L
.72028 .01614 L
.72157 .01614 L
.72279 .01614 L
.72395 .01614 L
.72499 .01614 L
.72612 .01614 L
.72866 .01614 L
.73102 .01614 L
.7353 .01614 L
.73985 .01614 L
.75017 .01614 L
.76132 .01614 L
.78151 .01614 L
.82258 .01614 L
.86214 .01614 L
.90019 .01614 L
.94068 .01614 L
Mistroke
.97619 .01614 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.02846 .08404 L
.03068 .11191 L
.03279 .13383 L
.03398 .14406 L
.03527 .15327 L
.03635 .1594 L
.03754 .1646 L
.03882 .16847 L
.03952 .16988 L
.04018 .17077 L
.04135 .17142 L
.04262 .17095 L
.04393 .16938 L
.04516 .16713 L
.04793 .15998 L
.05297 .14334 L
.06244 .11188 L
.06795 .09662 L
.07314 .08465 L
.08284 .06783 L
.08828 .06099 L
.09328 .05598 L
.09878 .05163 L
.10458 .04809 L
.10954 .04575 L
.11406 .04406 L
.11928 .04254 L
.12422 .04144 L
.12878 .04069 L
.133 .04017 L
.1352 .03997 L
.13763 .03979 L
.13885 .03972 L
.14017 .03965 L
.14141 .0396 L
.14255 .03957 L
.14383 .03955 L
.14503 .03953 L
.14612 .03954 L
.14729 .03955 L
.14857 .03957 L
.14922 .03959 L
.14993 .03962 L
.15118 .03967 L
.15235 .03974 L
.15465 .03992 L
.15675 .04014 L
.15917 .04047 L
.16148 .04087 L
Mistroke
.16661 .04211 L
.17138 .04363 L
.17657 .04528 L
.17799 .04565 L
.17949 .04598 L
.18079 .04621 L
.1815 .04632 L
.18218 .0464 L
.18283 .04647 L
.18354 .04653 L
.18479 .0466 L
.18606 .04663 L
.18723 .04662 L
.18851 .04657 L
.18924 .04653 L
.18992 .04647 L
.19277 .04617 L
.19528 .0458 L
.19757 .0454 L
.20274 .0444 L
.21175 .04261 L
.22136 .04098 L
.22651 .04029 L
.23119 .03977 L
.23594 .03934 L
.24032 .03902 L
.24544 .03875 L
.24813 .03863 L
.25098 .03854 L
.25329 .03848 L
.25577 .03843 L
.25849 .03838 L
.26103 .03835 L
.26225 .03834 L
.26359 .03833 L
.26499 .03833 L
.26631 .03832 L
.26753 .03832 L
.26866 .03832 L
.26989 .03832 L
.27119 .03832 L
.27251 .03832 L
.27325 .03832 L
.27392 .03832 L
.27647 .03834 L
.27944 .03835 L
.28225 .03837 L
.28729 .03841 L
.29201 .03844 L
.29439 .03846 L
Mistroke
.29561 .03846 L
.29694 .03847 L
.29769 .03847 L
.29839 .03847 L
.29906 .03847 L
.29977 .03848 L
.30047 .03848 L
.30113 .03848 L
.30236 .03848 L
.30352 .03848 L
.3048 .03847 L
.30544 .03847 L
.30613 .03847 L
.30737 .03846 L
.30977 .03845 L
.31197 .03843 L
.3173 .03838 L
.32235 .03831 L
.3408 .03803 L
.35046 .03789 L
.36072 .03777 L
.36948 .03769 L
.37915 .03763 L
.38407 .0376 L
.38925 .03758 L
.39851 .03756 L
.40847 .03753 L
.41937 .03752 L
.45995 .03744 L
.49902 .03737 L
.54053 .0373 L
.58054 .03724 L
.61902 .03718 L
.65996 .03714 L
.69938 .03709 L
.73729 .03706 L
.77765 .03703 L
.81649 .03701 L
.85779 .037 L
.89757 .03698 L
.93584 .03697 L
.97619 .03696 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.02605 .04951 L
.02846 .0814 L
.02962 .09372 L
.03072 .10306 L
.03171 .10944 L
.03279 .1143 L
.03397 .1174 L
.03527 .11857 L
.03592 .11844 L
.03663 .11788 L
.0379 .11597 L
.03916 .11327 L
.04036 .11021 L
.04262 .10375 L
.05221 .07632 L
.06244 .05499 L
.06792 .04687 L
.07289 .04108 L
.07794 .03642 L
.08259 .03302 L
.08803 .0299 L
.09391 .02734 L
.0991 .02562 L
.10458 .02422 L
.10954 .02325 L
.11406 .02255 L
.11928 .02192 L
.12422 .02147 L
.12878 .02114 L
.133 .0209 L
.13763 .0207 L
.14003 .02062 L
.14255 .02054 L
.14489 .02048 L
.14744 .02043 L
.14976 .0204 L
.15192 .02037 L
.15324 .02036 L
.15448 .02035 L
.1556 .02034 L
.15681 .02034 L
.15812 .02034 L
.15879 .02034 L
.15952 .02034 L
.16081 .02034 L
.16202 .02035 L
.16315 .02035 L
.16438 .02036 L
.16663 .02039 L
Mistroke
.17083 .02044 L
.17539 .0205 L
.17663 .02051 L
.17795 .02052 L
.17907 .02053 L
.1803 .02054 L
.181 .02054 L
.18163 .02054 L
.18237 .02054 L
.18306 .02054 L
.18429 .02054 L
.18499 .02053 L
.18563 .02053 L
.18679 .02052 L
.18807 .02051 L
.19065 .02049 L
.19548 .02042 L
.20001 .02035 L
.21024 .02018 L
.21582 .0201 L
.221 .02004 L
.23066 .01995 L
.23577 .01992 L
.24122 .0199 L
.24622 .01988 L
.25093 .01987 L
.25516 .01986 L
.25974 .01985 L
.30071 .01979 L
.31055 .01978 L
.32111 .01977 L
.33023 .01976 L
.34017 .01975 L
.34545 .01975 L
.35035 .01975 L
.35494 .01975 L
.36 .01975 L
.36878 .01974 L
.37811 .01974 L
.38818 .01974 L
.39743 .01974 L
.40822 .01974 L
.41828 .01974 L
.42817 .01974 L
.43718 .01974 L
.44197 .01974 L
.44718 .01974 L
.45267 .01974 L
.45518 .01974 L
.45787 .01974 L
Mistroke
.46042 .01974 L
.46275 .01974 L
.46509 .01974 L
.46732 .01974 L
.46857 .01974 L
.4699 .01974 L
.47115 .01974 L
.47229 .01974 L
.47299 .01974 L
.47364 .01974 L
.47434 .01974 L
.47509 .01974 L
.47634 .01974 L
.47706 .01974 L
.47772 .01974 L
.47903 .01974 L
.48045 .01974 L
.48303 .01974 L
.48787 .01974 L
.49875 .01974 L
.51815 .01974 L
.53956 .01974 L
.57884 .01974 L
.59983 .01974 L
.60902 .01974 L
.61907 .01974 L
.62819 .01974 L
.63793 .01974 L
.64332 .01974 L
.64821 .01974 L
.65313 .01974 L
.65553 .01974 L
.65777 .01974 L
.6602 .01974 L
.66241 .01974 L
.66487 .01974 L
.66622 .01974 L
.6675 .01974 L
.66874 .01974 L
.67006 .01974 L
.67131 .01974 L
.67243 .01974 L
.67313 .01974 L
.67376 .01974 L
.67446 .01974 L
.6752 .01974 L
.67644 .01974 L
.6778 .01974 L
.68022 .01974 L
.68242 .01974 L
Mistroke
.68736 .01974 L
.69193 .01974 L
.69626 .01974 L
.70595 .01974 L
.71622 .01974 L
.73466 .01974 L
.77248 .01974 L
.81276 .01974 L
.85152 .01974 L
.89273 .01974 L
.93243 .01974 L
.97061 .01974 L
.97619 .01974 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.02605 .04964 L
.02846 .08316 L
.03053 .10722 L
.03163 .11758 L
.03279 .12661 L
.03344 .1308 L
.03416 .13464 L
.03543 .13953 L
.03672 .14223 L
.03793 .14297 L
.03911 .14233 L
.04019 .1408 L
.04143 .13818 L
.04262 .13506 L
.05221 .10288 L
.06244 .07396 L
.06792 .06252 L
.07289 .05423 L
.07794 .0475 L
.08259 .04255 L
.08803 .03797 L
.09391 .03418 L
.0991 .03162 L
.10458 .02954 L
.10954 .02808 L
.11406 .02703 L
.11928 .02609 L
.12422 .0254 L
.12878 .02491 L
.133 .02456 L
.13763 .02426 L
.14003 .02414 L
.14255 .02403 L
.14489 .02395 L
.14744 .02389 L
.14856 .02386 L
.14976 .02384 L
.15089 .02382 L
.15192 .02381 L
.15323 .0238 L
.15392 .0238 L
.15464 .0238 L
.15587 .0238 L
.15656 .0238 L
.15721 .0238 L
.15843 .02381 L
.15953 .02382 L
.16081 .02384 L
.16202 .02386 L
Mistroke
.16422 .02392 L
.16656 .02399 L
.17077 .02414 L
.17541 .02431 L
.17774 .02437 L
.17907 .0244 L
.1803 .02442 L
.181 .02443 L
.18166 .02444 L
.1829 .02445 L
.18359 .02445 L
.18423 .02445 L
.18493 .02445 L
.18568 .02444 L
.18689 .02443 L
.18802 .02442 L
.19061 .02437 L
.19341 .02429 L
.19598 .02421 L
.20175 .02401 L
.21222 .02365 L
.22194 .02338 L
.23111 .0232 L
.23624 .02313 L
.2409 .02308 L
.24602 .02304 L
.2489 .02302 L
.25156 .02301 L
.25645 .02299 L
.25891 .02298 L
.26161 .02298 L
.302 .02289 L
.32062 .02284 L
.34088 .02279 L
.3519 .02277 L
.3621 .02276 L
.37184 .02275 L
.38221 .02275 L
.39156 .02274 L
.40166 .02274 L
.41993 .02273 L
.42948 .02273 L
.43994 .02273 L
.45087 .02273 L
.46104 .02273 L
.47154 .02273 L
.48147 .02273 L
.49038 .02273 L
.50005 .02272 L
.54094 .02272 L
Mistroke
.58031 .02272 L
.61816 .02272 L
.65847 .02272 L
.69726 .02272 L
.7385 .02272 L
.77823 .02272 L
.81645 .02272 L
.85711 .02272 L
.89626 .02272 L
.93786 .02272 L
.97619 .02272 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.02605 .04964 L
.02846 .08317 L
.03053 .10727 L
.03163 .11768 L
.03279 .12679 L
.03344 .13103 L
.03416 .13495 L
.03543 .13999 L
.03672 .14286 L
.03793 .14377 L
.03911 .14327 L
.04019 .14187 L
.04143 .13938 L
.04262 .13636 L
.05221 .10442 L
.06244 .0753 L
.06792 .06372 L
.07289 .05531 L
.07794 .04848 L
.08259 .04344 L
.08803 .03877 L
.09391 .03491 L
.0991 .03231 L
.10458 .03018 L
.10954 .02869 L
.11406 .02762 L
.11928 .02665 L
.12422 .02595 L
.12878 .02545 L
.133 .02509 L
.13763 .02479 L
.14003 .02466 L
.14255 .02456 L
.14489 .02448 L
.14744 .02441 L
.14856 .02439 L
.14976 .02437 L
.15089 .02435 L
.15192 .02434 L
.15322 .02434 L
.15441 .02433 L
.15573 .02434 L
.15639 .02434 L
.15712 .02434 L
.15834 .02436 L
.15965 .02437 L
.16089 .0244 L
.16202 .02442 L
.16651 .02456 L
Mistroke
.1714 .02476 L
.17568 .02494 L
.17685 .02498 L
.17809 .02502 L
.17916 .02504 L
.1803 .02507 L
.18162 .02509 L
.18284 .0251 L
.18359 .0251 L
.1843 .0251 L
.18494 .0251 L
.18563 .02509 L
.1869 .02508 L
.18754 .02507 L
.18824 .02506 L
.19065 .02501 L
.19297 .02494 L
.19548 .02486 L
.20001 .02469 L
.21004 .0243 L
.21534 .02412 L
.221 .02395 L
.22646 .02382 L
.23141 .02372 L
.23639 .02364 L
.24108 .02359 L
.24364 .02356 L
.24636 .02354 L
.25122 .02351 L
.25392 .0235 L
.25645 .02349 L
.26219 .02348 L
.30107 .02338 L
.32086 .02333 L
.3313 .0233 L
.3424 .02327 L
.35222 .02326 L
.36307 .02324 L
.37294 .02323 L
.38221 .02323 L
.39203 .02322 L
.40237 .02322 L
.42087 .02321 L
.43039 .02321 L
.44058 .02321 L
.45013 .0232 L
.45894 .0232 L
.46917 .0232 L
.48026 .0232 L
.50041 .0232 L
Mistroke
.53978 .0232 L
.57763 .0232 L
.61794 .0232 L
.65673 .02319 L
.69798 .02319 L
.7377 .02319 L
.77592 .02319 L
.81658 .02319 L
.85573 .02319 L
.89733 .02319 L
.93742 .02319 L
.97599 .02319 L
.97619 .02319 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.02605 .0495 L
.02846 .08132 L
.02962 .09354 L
.03072 .10275 L
.03171 .109 L
.03279 .11372 L
.03397 .1167 L
.03527 .11781 L
.03592 .11768 L
.03663 .11713 L
.0379 .11529 L
.03916 .1127 L
.04036 .10976 L
.04262 .10358 L
.05221 .07719 L
.06244 .05651 L
.06792 .0486 L
.07289 .04295 L
.07794 .03839 L
.08259 .03505 L
.08803 .03199 L
.09391 .02946 L
.0991 .02777 L
.10458 .02639 L
.10954 .02543 L
.11406 .02474 L
.11928 .02413 L
.12422 .02368 L
.12878 .02337 L
.133 .02314 L
.13763 .02296 L
.13997 .02289 L
.14255 .02282 L
.1449 .02278 L
.14625 .02276 L
.14747 .02274 L
.14876 .02273 L
.14948 .02273 L
.15015 .02272 L
.15135 .02272 L
.15264 .02272 L
.15376 .02272 L
.15498 .02273 L
.15626 .02273 L
.15746 .02275 L
.1596 .02278 L
.1619 .02283 L
.16714 .02298 L
.17272 .02318 L
Mistroke
.17543 .02327 L
.17676 .02331 L
.17799 .02333 L
.17908 .02336 L
.18028 .02337 L
.18148 .02339 L
.18275 .0234 L
.18344 .0234 L
.18408 .0234 L
.18529 .02339 L
.18659 .02338 L
.18732 .02338 L
.188 .02337 L
.19037 .02333 L
.19289 .02328 L
.20393 .02297 L
.21361 .0227 L
.21869 .02258 L
.22403 .02247 L
.2289 .02239 L
.23422 .02232 L
.23905 .02227 L
.24354 .02223 L
.24818 .0222 L
.25239 .02219 L
.25473 .02218 L
.25725 .02217 L
.26183 .02216 L
.28136 .02212 L
.30281 .02207 L
.31265 .02205 L
.3232 .02203 L
.3331 .02202 L
.34226 .02201 L
.35242 .022 L
.35778 .022 L
.36348 .02199 L
.36807 .02199 L
.37303 .02199 L
.37847 .02199 L
.38095 .02199 L
.38359 .02199 L
.38618 .02199 L
.38854 .02199 L
.39093 .02199 L
.39314 .02199 L
.39572 .02199 L
.39708 .02199 L
.39852 .02199 L
.39969 .02199 L
Mistroke
.40094 .02199 L
.40166 .02199 L
.40232 .02199 L
.40361 .02199 L
.4049 .02199 L
.40563 .02199 L
.40629 .02199 L
.40757 .02199 L
.40878 .02199 L
.40946 .02199 L
.41019 .02199 L
.41149 .02199 L
.41442 .02199 L
.4198 .02199 L
.4247 .02199 L
.42703 .02199 L
.42957 .02199 L
.43073 .02199 L
.43197 .02199 L
.43312 .02199 L
.43418 .02199 L
.43538 .02199 L
.43668 .02199 L
.43782 .02199 L
.43902 .02199 L
.44034 .02199 L
.44156 .02199 L
.44291 .02199 L
.44435 .02199 L
.44672 .02199 L
.44929 .02199 L
.45396 .02199 L
.46269 .02199 L
.48258 .02199 L
.50363 .02199 L
.54153 .02198 L
.58189 .02198 L
.62074 .02198 L
.66203 .02198 L
.70182 .02197 L
.74008 .02197 L
.76145 .02197 L
.7808 .02197 L
.80123 .02197 L
.82 .02197 L
.8393 .02197 L
.85009 .02197 L
.86014 .02197 L
.87002 .02197 L
.87902 .02197 L
Mistroke
.88901 .02197 L
.8945 .02197 L
.8997 .02197 L
.90431 .02197 L
.90693 .02197 L
.90939 .02197 L
.91071 .02197 L
.91197 .02197 L
.9131 .02197 L
.91434 .02197 L
.91504 .02197 L
.91567 .02197 L
.91641 .02197 L
.9171 .02197 L
.91833 .02197 L
.91902 .02197 L
.91966 .02197 L
.92073 .02197 L
.92187 .02197 L
.92394 .02197 L
.92639 .02197 L
.92863 .02197 L
.93349 .02197 L
.9381 .02197 L
.94769 .02197 L
.95788 .02197 L
.97619 .02197 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.02499 .03253 L
.02605 .04496 L
.02729 .05377 L
.02846 .05783 L
.02954 .05932 L
.03053 .05957 L
.03163 .05912 L
.03279 .05814 L
.0352 .05531 L
.03746 .05231 L
.04262 .04563 L
.05217 .0358 L
.05754 .03176 L
.06244 .02884 L
.06744 .02648 L
.07277 .02451 L
.07862 .02286 L
.08405 .0217 L
.08959 .02079 L
.09482 .02013 L
.09951 .01967 L
.10458 .01928 L
.1095 .01898 L
.11408 .01877 L
.11912 .01859 L
.12452 .01844 L
.13018 .01832 L
.13296 .01828 L
.13554 .01824 L
.14035 .0182 L
.14289 .01818 L
.14417 .01817 L
.14558 .01816 L
.14673 .01816 L
.14796 .01815 L
.14926 .01815 L
.15047 .01815 L
.15168 .01815 L
.15282 .01815 L
.15384 .01815 L
.15495 .01815 L
.15617 .01815 L
.15686 .01815 L
.15751 .01815 L
.15892 .01816 L
.16021 .01816 L
.16254 .01818 L
.16505 .0182 L
.17391 .01828 L
Mistroke
.17646 .01831 L
.17771 .01832 L
.17885 .01832 L
.17988 .01833 L
.18101 .01833 L
.18214 .01833 L
.18333 .01834 L
.18462 .01834 L
.1858 .01833 L
.18645 .01833 L
.18716 .01833 L
.18844 .01833 L
.19092 .01832 L
.1932 .0183 L
.20236 .01823 L
.21306 .01815 L
.22309 .01808 L
.2321 .01804 L
.23716 .01802 L
.2418 .01801 L
.2466 .018 L
.24932 .018 L
.25185 .01799 L
.25696 .01799 L
.25982 .01799 L
.26241 .01799 L
.28326 .01797 L
.30245 .01796 L
.31213 .01795 L
.32117 .01794 L
.3306 .01794 L
.34097 .01794 L
.34596 .01793 L
.3514 .01793 L
.35654 .01793 L
.36129 .01793 L
.36556 .01793 L
.37028 .01793 L
.37265 .01793 L
.3739 .01793 L
.37521 .01793 L
.37636 .01793 L
.37763 .01793 L
.37877 .01793 L
.37984 .01793 L
.38111 .01793 L
.38176 .01793 L
.38246 .01793 L
.38371 .01793 L
.38488 .01793 L
Mistroke
.38559 .01793 L
.38626 .01793 L
.38752 .01793 L
.39035 .01793 L
.39281 .01793 L
.3951 .01793 L
.40027 .01793 L
.41885 .01793 L
.43767 .01793 L
.458 .01793 L
.47943 .01793 L
.49961 .01794 L
.51917 .01794 L
.54063 .01794 L
.56107 .01794 L
.58014 .01794 L
.61907 .01794 L
.66045 .01794 L
.70031 .01794 L
.73866 .01794 L
.77946 .01794 L
.81875 .01794 L
.85652 .01794 L
.89674 .01794 L
.93545 .01794 L
.97619 .01794 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.02499 .03251 L
.02605 .04478 L
.02729 .0531 L
.02846 .05657 L
.02954 .05757 L
.03053 .05746 L
.03163 .05669 L
.03279 .05548 L
.04262 .04257 L
.05205 .03321 L
.05742 .0294 L
.06244 .02661 L
.06788 .02425 L
.07305 .02253 L
.07768 .02131 L
.08274 .02027 L
.08822 .0194 L
.09407 .01869 L
.09958 .0182 L
.10458 .01785 L
.10945 .01759 L
.1146 .01738 L
.119 .01723 L
.12383 .01711 L
.12902 .01701 L
.13459 .01693 L
.13985 .01687 L
.14465 .01683 L
.14693 .01682 L
.14945 .01681 L
.15209 .0168 L
.15329 .0168 L
.15456 .01679 L
.15566 .01679 L
.15686 .01679 L
.15796 .01679 L
.15897 .01679 L
.16018 .01679 L
.16127 .01679 L
.16254 .01679 L
.16373 .01679 L
.16493 .01679 L
.16625 .0168 L
.16891 .0168 L
.17369 .01682 L
.17638 .01682 L
.17786 .01683 L
.17927 .01683 L
.18058 .01683 L
Mistroke
.18131 .01683 L
.182 .01683 L
.18321 .01683 L
.18449 .01683 L
.18574 .01683 L
.18645 .01683 L
.18711 .01683 L
.18844 .01683 L
.18987 .01682 L
.1948 .01681 L
.20594 .01677 L
.21643 .01674 L
.22613 .01671 L
.23107 .0167 L
.23633 .01669 L
.2416 .01669 L
.24463 .01668 L
.24741 .01668 L
.2498 .01668 L
.25241 .01668 L
.25504 .01668 L
.25647 .01668 L
.2578 .01668 L
.25907 .01668 L
.26027 .01668 L
.26134 .01668 L
.26251 .01668 L
.26378 .01668 L
.26442 .01668 L
.26513 .01668 L
.26637 .01668 L
.26754 .01668 L
.27253 .01668 L
.27797 .01668 L
.28046 .01668 L
.28183 .01668 L
.28311 .01668 L
.2842 .01668 L
.28537 .01668 L
.28667 .01668 L
.28787 .01668 L
.28895 .01668 L
.2901 .01668 L
.29119 .01668 L
.29218 .01668 L
.29461 .01668 L
.2969 .01668 L
.30146 .01668 L
.30642 .01668 L
.32588 .01667 L
Mistroke
.3362 .01666 L
.3473 .01666 L
.35792 .01665 L
.36763 .01665 L
.3774 .01665 L
.38667 .01665 L
.42489 .01665 L
.44457 .01665 L
.46555 .01665 L
.48698 .01664 L
.50715 .01664 L
.54572 .01664 L
.56568 .01664 L
.58675 .01664 L
.62474 .01664 L
.64426 .01664 L
.66518 .01664 L
.68501 .01664 L
.70656 .01664 L
.74643 .01664 L
.76622 .01664 L
.78723 .01664 L
.825 .01664 L
.84436 .01664 L
.86522 .01664 L
.88489 .01664 L
.90638 .01664 L
.94603 .01664 L
.97619 .01664 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02005 L
.0379 .01896 L
.04262 .01814 L
.04714 .01749 L
.05212 .01693 L
.05713 .01649 L
.06244 .01613 L
.06792 .01584 L
.07293 .01564 L
.07871 .01547 L
.0842 .01534 L
.08925 .01525 L
.09394 .01519 L
.09909 .01513 L
.10458 .01509 L
.10994 .01506 L
.11487 .01503 L
.12028 .01501 L
.12599 .015 L
.13096 .01499 L
.13561 .01498 L
.1407 .01498 L
.14616 .01497 L
.15145 .01497 L
.15634 .01497 L
.15889 .01496 L
.1617 .01496 L
.16464 .01496 L
.1674 .01496 L
.17245 .01496 L
.17708 .01496 L
.18752 .01496 L
.19745 .01496 L
.20805 .01496 L
.2132 .01496 L
.21806 .01496 L
.22715 .01496 L
.23177 .01496 L
.23666 .01496 L
.24084 .01496 L
.24543 .01495 L
.24801 .01495 L
.25037 .01495 L
.25567 .01495 L
.26526 .01495 L
Mistroke
.27513 .01495 L
.28428 .01495 L
.29496 .01495 L
.30502 .01495 L
.3149 .01495 L
.3201 .01495 L
.32558 .01495 L
.33021 .01495 L
.33528 .01495 L
.33956 .01495 L
.3442 .01495 L
.34946 .01495 L
.35187 .01495 L
.35443 .01495 L
.35673 .01495 L
.35927 .01495 L
.36375 .01495 L
.36646 .01495 L
.36895 .01495 L
.37168 .01495 L
.37455 .01495 L
.37706 .01495 L
.37939 .01495 L
.38467 .01495 L
.3938 .01495 L
.40345 .01495 L
.41403 .01495 L
.42377 .01495 L
.42904 .01495 L
.43157 .01495 L
.43396 .01495 L
.43532 .01495 L
.43679 .01495 L
.43744 .01495 L
.43813 .01495 L
.43936 .01495 L
.44005 .01495 L
.44078 .01495 L
.44148 .01495 L
.44212 .01495 L
.44282 .01495 L
.4436 .01495 L
.44441 .01495 L
.44516 .01495 L
.44642 .01495 L
.44778 .01495 L
.45026 .01495 L
.45268 .01495 L
.4549 .01495 L
.45996 .01495 L
Mistroke
.46532 .01495 L
.50318 .01495 L
.54348 .01495 L
.58228 .01495 L
.62352 .01495 L
.64413 .01495 L
.66325 .01495 L
.70146 .01495 L
.722 .01495 L
.74061 .01495 L
.75987 .01495 L
.77072 .01495 L
.7807 .01495 L
.79044 .01495 L
.79954 .01495 L
.80466 .01495 L
.80952 .01495 L
.81511 .01495 L
.81774 .01495 L
.82021 .01495 L
.8226 .01495 L
.8248 .01495 L
.82597 .01495 L
.82724 .01495 L
.82852 .01495 L
.82921 .01495 L
.82987 .01495 L
.83052 .01495 L
.83122 .01495 L
.83244 .01495 L
.83313 .01495 L
.83387 .01495 L
.83519 .01495 L
.8364 .01495 L
.83754 .01495 L
.84013 .01495 L
.84251 .01495 L
.84477 .01495 L
.84902 .01495 L
.85856 .01495 L
.86818 .01495 L
.87842 .01495 L
.89682 .01495 L
.93847 .01495 L
.97619 .01495 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.02605 .04952 L
.02846 .08165 L
.02962 .09434 L
.03072 .10428 L
.03171 .11142 L
.03279 .11733 L
.03397 .12175 L
.03527 .12446 L
.03592 .12509 L
.03663 .12531 L
.0379 .12471 L
.03916 .12311 L
.04036 .12093 L
.04262 .11568 L
.05221 .08947 L
.06244 .06687 L
.06792 .0579 L
.07289 .05138 L
.08259 .04213 L
.08803 .03848 L
.09391 .03544 L
.09947 .03327 L
.10458 .03172 L
.10928 .0306 L
.11432 .02966 L
.11907 .02898 L
.1234 .02849 L
.12849 .02805 L
.13117 .02788 L
.13402 .02772 L
.1365 .02761 L
.13924 .02752 L
.14044 .02748 L
.14173 .02745 L
.14293 .02743 L
.14407 .02741 L
.14532 .0274 L
.14646 .02739 L
.14769 .02739 L
.14839 .02739 L
.14903 .02739 L
.15009 .0274 L
.15127 .02741 L
.15249 .02743 L
.15364 .02745 L
.15499 .02749 L
.15628 .02753 L
.15869 .02763 L
.16128 .02777 L
Mistroke
.16411 .02796 L
.16981 .02848 L
.17261 .02876 L
.17518 .02899 L
.17748 .02917 L
.1787 .02925 L
.18 .02932 L
.18131 .02937 L
.18253 .0294 L
.18325 .02942 L
.18393 .02942 L
.18521 .02943 L
.18634 .02942 L
.18759 .02941 L
.18889 .02938 L
.19012 .02934 L
.1923 .02925 L
.19466 .02914 L
.20492 .0285 L
.21495 .02788 L
.22025 .02761 L
.2259 .02736 L
.23136 .02716 L
.23631 .02702 L
.24129 .02691 L
.24598 .02684 L
.24855 .0268 L
.25126 .02677 L
.25612 .02673 L
.25883 .02672 L
.26135 .0267 L
.2671 .02668 L
.28571 .0266 L
.30597 .02653 L
.31699 .0265 L
.32719 .02648 L
.33756 .02646 L
.3473 .02644 L
.35167 .02644 L
.35627 .02643 L
.35868 .02643 L
.36131 .02643 L
.36369 .02643 L
.36594 .02643 L
.36724 .02643 L
.36864 .02643 L
.36981 .02642 L
.3711 .02642 L
.37177 .02642 L
.37249 .02642 L
Mistroke
.37325 .02642 L
.37396 .02642 L
.37467 .02642 L
.37534 .02642 L
.37661 .02642 L
.3778 .02642 L
.37907 .02642 L
.38027 .02642 L
.38136 .02642 L
.38402 .02643 L
.38654 .02643 L
.3912 .02643 L
.39631 .02643 L
.40663 .02644 L
.42511 .02645 L
.43514 .02646 L
.44463 .02646 L
.44988 .02647 L
.45558 .02647 L
.46072 .02647 L
.46555 .02647 L
.47496 .02647 L
.47996 .02647 L
.48534 .02647 L
.49068 .02647 L
.4963 .02647 L
.5011 .02647 L
.50635 .02647 L
.50889 .02647 L
.51023 .02647 L
.51164 .02647 L
.51288 .02647 L
.51424 .02647 L
.51548 .02647 L
.51664 .02647 L
.51785 .02647 L
.51899 .02647 L
.52002 .02647 L
.52114 .02647 L
.52236 .02647 L
.52365 .02647 L
.52598 .02647 L
.5287 .02647 L
.53165 .02647 L
.53698 .02647 L
.54217 .02647 L
.54693 .02647 L
.56581 .02647 L
.58649 .02647 L
.62699 .02646 L
Mistroke
.66597 .02646 L
.68584 .02646 L
.7074 .02645 L
.71748 .02645 L
.72816 .02645 L
.73816 .02645 L
.74732 .02645 L
.75182 .02645 L
.75673 .02645 L
.75942 .02645 L
.76191 .02645 L
.76445 .02645 L
.76685 .02645 L
.76908 .02645 L
.77025 .02645 L
.77149 .02645 L
.77254 .02645 L
.77368 .02645 L
.77473 .02645 L
.7757 .02645 L
.77693 .02645 L
.77808 .02645 L
.77913 .02645 L
.78026 .02645 L
.78149 .02645 L
.7828 .02645 L
.78514 .02645 L
.78752 .02645 L
.79003 .02645 L
.79451 .02645 L
.79933 .02645 L
.80461 .02645 L
.82288 .02645 L
.83315 .02645 L
.84248 .02645 L
.86343 .02645 L
.9034 .02646 L
.94185 .02646 L
.97619 .02646 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.02499 .03291 L
.02605 .04707 L
.02729 .05935 L
.02846 .06685 L
.02954 .07085 L
.03053 .07272 L
.03163 .07338 L
.03279 .07304 L
.03395 .07201 L
.0352 .07044 L
.03746 .06695 L
.04262 .05833 L
.04793 .0503 L
.05297 .04394 L
.06244 .03511 L
.0675 .03173 L
.07289 .02891 L
.07798 .02683 L
.08259 .02534 L
.08803 .02396 L
.09391 .02283 L
.09947 .02202 L
.10458 .02145 L
.10928 .02104 L
.11432 .0207 L
.11907 .02045 L
.1234 .02028 L
.12849 .02012 L
.13117 .02005 L
.13402 .01999 L
.1365 .01995 L
.13924 .01991 L
.14173 .01988 L
.14407 .01987 L
.14524 .01986 L
.1465 .01985 L
.14769 .01985 L
.14876 .01984 L
.15003 .01984 L
.15075 .01984 L
.1514 .01984 L
.15262 .01985 L
.1539 .01985 L
.15513 .01985 L
.15645 .01986 L
.15883 .01988 L
.16166 .01992 L
.16425 .01996 L
.17321 .02014 L
Mistroke
.17579 .02019 L
.17822 .02023 L
.17928 .02024 L
.1804 .02025 L
.18163 .02026 L
.18275 .02027 L
.18393 .02027 L
.18519 .02027 L
.18638 .02027 L
.18746 .02027 L
.18874 .02026 L
.19012 .02025 L
.19263 .02023 L
.19738 .02017 L
.20178 .0201 L
.21248 .01994 L
.22252 .01981 L
.23152 .01972 L
.23658 .01969 L
.24122 .01966 L
.24602 .01964 L
.25127 .01963 L
.25392 .01962 L
.25674 .01962 L
.26183 .01961 L
.27153 .0196 L
.28178 .01959 L
.29303 .01956 L
.30338 .01955 L
.31259 .01953 L
.32246 .01952 L
.32813 .01951 L
.3333 .01951 L
.3382 .01951 L
.34342 .0195 L
.34812 .0195 L
.35332 .0195 L
.35804 .0195 L
.36248 .0195 L
.36501 .0195 L
.36769 .0195 L
.36999 .0195 L
.37246 .0195 L
.37386 .0195 L
.37512 .0195 L
.37641 .0195 L
.3776 .0195 L
.37899 .0195 L
.37972 .0195 L
.3805 .0195 L
Mistroke
.3818 .0195 L
.38254 .0195 L
.38323 .0195 L
.38448 .0195 L
.38518 .0195 L
.38581 .0195 L
.38704 .0195 L
.3882 .0195 L
.39081 .0195 L
.39362 .0195 L
.39876 .0195 L
.40349 .0195 L
.42202 .0195 L
.46153 .0195 L
.49952 .01951 L
.53997 .01951 L
.57889 .01951 L
.62028 .01951 L
.66014 .01951 L
.69849 .01951 L
.73929 .01952 L
.77858 .01952 L
.81635 .01952 L
.85657 .01952 L
.89528 .01952 L
.93644 .01953 L
.97608 .01953 L
.97619 .01953 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.02846 .08392 L
.03068 .11137 L
.03279 .13236 L
.03398 .14182 L
.03527 .14999 L
.03645 .15554 L
.03754 .15916 L
.03871 .16157 L
.04 .16265 L
.04065 .16263 L
.04135 .16226 L
.04262 .16077 L
.04393 .1583 L
.04516 .15537 L
.04793 .14722 L
.05297 .13017 L
.06244 .10033 L
.06795 .08639 L
.07314 .07562 L
.08284 .06071 L
.08828 .0547 L
.09328 .05033 L
.09878 .04656 L
.10458 .0435 L
.10954 .04149 L
.11406 .04004 L
.11928 .03873 L
.12422 .0378 L
.12878 .03715 L
.133 .03671 L
.1352 .03653 L
.13763 .03638 L
.13885 .03632 L
.14017 .03626 L
.14139 .03622 L
.14255 .03619 L
.14381 .03616 L
.14495 .03615 L
.14618 .03615 L
.14687 .03615 L
.14751 .03615 L
.14858 .03617 L
.14975 .0362 L
.15098 .03624 L
.15212 .03629 L
.15348 .03636 L
.15476 .03644 L
.15717 .03664 L
.15976 .03694 L
Mistroke
.16259 .03735 L
.1683 .03853 L
.17366 .03987 L
.17601 .0404 L
.17848 .04086 L
.17978 .04104 L
.1812 .04121 L
.18249 .04131 L
.18369 .04138 L
.18492 .04141 L
.18561 .04142 L
.18625 .04142 L
.18743 .04139 L
.18867 .04134 L
.18979 .04127 L
.19083 .04119 L
.19321 .04095 L
.19812 .04032 L
.2034 .03952 L
.21343 .03801 L
.21873 .03733 L
.22439 .0367 L
.22985 .03621 L
.2348 .03585 L
.23978 .03557 L
.24447 .03537 L
.24703 .03528 L
.24975 .0352 L
.25461 .0351 L
.25731 .03506 L
.25984 .03502 L
.26558 .03497 L
.27058 .03494 L
.27602 .03491 L
.28115 .03489 L
.28591 .03488 L
.29018 .03487 L
.2949 .03486 L
.29946 .03485 L
.30446 .03484 L
.30936 .03483 L
.31453 .03481 L
.32378 .03476 L
.34463 .03462 L
.3547 .03457 L
.36422 .03453 L
.36948 .03451 L
.37225 .03451 L
.37518 .0345 L
.37765 .0345 L
Mistroke
.38037 .03449 L
.38156 .03449 L
.38284 .03449 L
.38403 .03449 L
.38516 .03449 L
.3858 .03449 L
.38649 .03449 L
.3877 .03449 L
.38838 .03449 L
.38911 .03449 L
.3904 .03449 L
.3916 .03449 L
.39272 .03449 L
.39395 .03449 L
.39527 .03449 L
.39824 .03449 L
.40105 .03449 L
.40631 .0345 L
.41605 .0345 L
.42139 .03451 L
.4264 .03451 L
.42862 .03451 L
.43096 .03451 L
.43219 .03451 L
.43353 .03451 L
.43473 .03451 L
.43587 .03451 L
.43653 .03451 L
.43725 .03451 L
.43849 .03451 L
.4392 .03451 L
.43995 .03451 L
.44059 .03451 L
.44129 .03451 L
.44254 .03451 L
.44325 .03451 L
.44389 .03451 L
.44514 .03451 L
.44633 .03451 L
.44854 .03451 L
.4509 .03451 L
.45514 .03451 L
.46475 .03451 L
.50641 .03448 L
.54654 .03445 L
.58517 .03442 L
.62624 .03438 L
.6658 .03435 L
.70385 .03433 L
.74434 .0343 L
Mistroke
.78332 .03429 L
.80319 .03428 L
.82476 .03428 L
.86467 .03427 L
.8845 .03427 L
.90553 .03427 L
.92505 .03426 L
.94335 .03426 L
.9605 .03426 L
.97619 .03426 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.02499 .03253 L
.02605 .04491 L
.02729 .05357 L
.02846 .05746 L
.02954 .05882 L
.03053 .05898 L
.03163 .05845 L
.03279 .05742 L
.03746 .05154 L
.04262 .04494 L
.04755 .03952 L
.05285 .03477 L
.05783 .03121 L
.06244 .02856 L
.06784 .02611 L
.07373 .02406 L
.07892 .02268 L
.08445 .02154 L
.08988 .02069 L
.09501 .02007 L
.09961 .01963 L
.10458 .01926 L
.1095 .01897 L
.11408 .01876 L
.11912 .01858 L
.12452 .01843 L
.13018 .01832 L
.13296 .01827 L
.13554 .01824 L
.14035 .01819 L
.14289 .01817 L
.14417 .01817 L
.14558 .01816 L
.14673 .01815 L
.14796 .01815 L
.14926 .01815 L
.15047 .01815 L
.15168 .01814 L
.15282 .01814 L
.15384 .01814 L
.15495 .01815 L
.15617 .01815 L
.15686 .01815 L
.15751 .01815 L
.15892 .01816 L
.16021 .01816 L
.16254 .01818 L
.16505 .0182 L
.17391 .0183 L
Mistroke
.17646 .01833 L
.17885 .01835 L
.18101 .01836 L
.18222 .01837 L
.18333 .01837 L
.18452 .01837 L
.18563 .01837 L
.18684 .01837 L
.18814 .01837 L
.18879 .01837 L
.1895 .01837 L
.19079 .01837 L
.1932 .01835 L
.19796 .01832 L
.20236 .01829 L
.21306 .0182 L
.22309 .01813 L
.2321 .01808 L
.23716 .01805 L
.2418 .01804 L
.2466 .01803 L
.25185 .01802 L
.2545 .01801 L
.25732 .01801 L
.25999 .01801 L
.26241 .018 L
.27254 .018 L
.27808 .018 L
.28326 .018 L
.28767 .01799 L
.2924 .01799 L
.30245 .01798 L
.32089 .01795 L
.33062 .01794 L
.34097 .01794 L
.3462 .01793 L
.35198 .01793 L
.36218 .01793 L
.36717 .01792 L
.37255 .01792 L
.38229 .01792 L
.39185 .01792 L
.40231 .01792 L
.41336 .01792 L
.4234 .01792 L
.4328 .01792 L
.44299 .01791 L
.45376 .01791 L
.46393 .01791 L
.47338 .01791 L
Mistroke
.47875 .01791 L
.48378 .01791 L
.48898 .01791 L
.49392 .01791 L
.49961 .01791 L
.50229 .01791 L
.50482 .01791 L
.50724 .01791 L
.50985 .01791 L
.51223 .01791 L
.51441 .01791 L
.51564 .01791 L
.51678 .01791 L
.51804 .01791 L
.51874 .01791 L
.51939 .01791 L
.52068 .01791 L
.52141 .01791 L
.52208 .01791 L
.52332 .01791 L
.52464 .01791 L
.52681 .01791 L
.52915 .01791 L
.53338 .01791 L
.53842 .01791 L
.54303 .01791 L
.55284 .01791 L
.56197 .01791 L
.58267 .01791 L
.62174 .01791 L
.66326 .01791 L
.70326 .01792 L
.74175 .01792 L
.78268 .01792 L
.82211 .01792 L
.86001 .01792 L
.90037 .01792 L
.93922 .01792 L
.97619 .01792 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.02499 .03291 L
.02605 .04708 L
.02729 .05937 L
.02846 .06689 L
.02954 .07093 L
.03053 .07282 L
.03163 .07352 L
.03279 .0732 L
.03395 .07219 L
.0352 .07063 L
.03746 .06714 L
.04262 .05847 L
.0521 .04494 L
.05746 .03919 L
.06244 .03493 L
.0679 .03124 L
.07373 .02822 L
.07935 .02598 L
.08445 .02442 L
.08943 .02322 L
.09481 .02221 L
.0999 .02147 L
.10458 .02094 L
.10928 .02051 L
.11432 .02016 L
.11907 .0199 L
.1234 .01971 L
.12849 .01954 L
.13117 .01947 L
.13402 .01941 L
.1365 .01936 L
.13924 .01932 L
.14174 .01928 L
.14407 .01926 L
.14642 .01924 L
.14766 .01923 L
.14898 .01923 L
.14965 .01923 L
.15038 .01922 L
.1517 .01922 L
.15298 .01922 L
.15416 .01922 L
.15527 .01922 L
.1563 .01922 L
.15744 .01923 L
.15866 .01924 L
.16114 .01925 L
.16341 .01928 L
.16866 .01935 L
Mistroke
.17424 .01944 L
.17695 .01948 L
.1795 .01952 L
.18062 .01953 L
.18179 .01954 L
.18308 .01954 L
.18427 .01955 L
.18546 .01955 L
.18654 .01955 L
.18779 .01955 L
.18897 .01955 L
.19006 .01954 L
.19107 .01954 L
.19335 .01952 L
.19817 .01947 L
.20329 .01941 L
.21328 .01928 L
.22403 .01917 L
.229 .01912 L
.23422 .01909 L
.23905 .01906 L
.24354 .01904 L
.24777 .01902 L
.25228 .01901 L
.25486 .01901 L
.25729 .019 L
.25947 .019 L
.26183 .019 L
.2642 .019 L
.26553 .019 L
.26674 .019 L
.26787 .019 L
.26909 .019 L
.27132 .01899 L
.27628 .01899 L
.27763 .01899 L
.2791 .01899 L
.28175 .01899 L
.28309 .01899 L
.28451 .01899 L
.28705 .01899 L
.28974 .01899 L
.29268 .01899 L
.29792 .01898 L
.30281 .01897 L
.32152 .01894 L
.33137 .01892 L
.34182 .01891 L
.35291 .0189 L
.36314 .01889 L
Mistroke
.37273 .01889 L
.38328 .01888 L
.40271 .01888 L
.42359 .01887 L
.44474 .01887 L
.45447 .01887 L
.46484 .01887 L
.48466 .01887 L
.50305 .01887 L
.52448 .01886 L
.54465 .01886 L
.56474 .01886 L
.58322 .01886 L
.59297 .01886 L
.60206 .01886 L
.61204 .01886 L
.62273 .01886 L
.63291 .01886 L
.63866 .01886 L
.64398 .01886 L
.64862 .01886 L
.65127 .01886 L
.65374 .01886 L
.65501 .01886 L
.65635 .01886 L
.6575 .01886 L
.65873 .01886 L
.65943 .01886 L
.66006 .01886 L
.6613 .01886 L
.662 .01886 L
.66275 .01886 L
.66346 .01886 L
.66411 .01886 L
.66536 .01886 L
.66656 .01886 L
.66762 .01886 L
.66879 .01886 L
.6714 .01886 L
.67381 .01886 L
.67821 .01886 L
.68289 .01886 L
.69372 .01886 L
.70353 .01886 L
.72283 .01886 L
.74367 .01886 L
.78475 .01886 L
.82431 .01886 L
.86235 .01886 L
.90285 .01886 L
Mistroke
.94183 .01886 L
.97619 .01886 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .0212 L
.03053 .02077 L
.03279 .02026 L
.04262 .01833 L
.04762 .01762 L
.05293 .01702 L
.05746 .01662 L
.06244 .01627 L
.06792 .01598 L
.07293 .01577 L
.07871 .01558 L
.0842 .01545 L
.08925 .01536 L
.09394 .01529 L
.09909 .01524 L
.10458 .01519 L
.10994 .01515 L
.11487 .01513 L
.12028 .01511 L
.12599 .01509 L
.13096 .01508 L
.13561 .01507 L
.1407 .01507 L
.14616 .01506 L
.14872 .01506 L
.15145 .01506 L
.1538 .01506 L
.15634 .01506 L
.15905 .01506 L
.1616 .01506 L
.16307 .01506 L
.16462 .01506 L
.16595 .01506 L
.1674 .01506 L
.17282 .01506 L
.17412 .01506 L
.17549 .01506 L
.17666 .01506 L
.17794 .01506 L
.17909 .01506 L
.18032 .01506 L
.18254 .01506 L
.18514 .01505 L
.18752 .01505 L
.20713 .01505 L
.2124 .01505 L
Mistroke
.218 .01505 L
.2232 .01505 L
.22808 .01505 L
.23288 .01505 L
.23807 .01505 L
.24036 .01505 L
.24278 .01505 L
.24504 .01505 L
.24711 .01505 L
.24958 .01505 L
.25094 .01505 L
.25223 .01505 L
.25342 .01505 L
.25451 .01505 L
.25572 .01505 L
.257 .01505 L
.25828 .01505 L
.259 .01505 L
.25966 .01505 L
.26088 .01505 L
.26216 .01505 L
.26488 .01505 L
.26784 .01505 L
.27796 .01505 L
.28292 .01505 L
.28749 .01505 L
.29006 .01505 L
.29135 .01505 L
.29277 .01505 L
.29352 .01505 L
.2942 .01505 L
.29498 .01505 L
.29572 .01505 L
.29705 .01505 L
.29779 .01505 L
.29848 .01505 L
.29967 .01505 L
.30078 .01505 L
.302 .01505 L
.30332 .01505 L
.306 .01505 L
.30846 .01505 L
.31825 .01505 L
.32736 .01505 L
.338 .01505 L
.34805 .01505 L
.35785 .01505 L
.36848 .01504 L
.37815 .01504 L
.38706 .01504 L
Mistroke
.4074 .01504 L
.42643 .01504 L
.44585 .01504 L
.46429 .01504 L
.48455 .01504 L
.50308 .01504 L
.54129 .01504 L
.58196 .01504 L
.62111 .01504 L
.66271 .01504 L
.7028 .01504 L
.74137 .01504 L
.78239 .01504 L
.8219 .01504 L
.85989 .01504 L
.90033 .01504 L
.93926 .01504 L
.97619 .01504 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.02605 .04945 L
.02729 .06658 L
.02846 .08075 L
.02954 .09177 L
.03072 .10109 L
.0318 .10718 L
.03279 .11091 L
.03396 .1133 L
.03506 .11393 L
.03626 .11325 L
.03756 .11138 L
.03821 .11012 L
.03891 .10857 L
.0402 .10539 L
.04262 .09874 L
.05302 .07097 L
.06244 .05286 L
.06789 .0453 L
.07302 .03971 L
.07844 .03509 L
.08429 .03128 L
.08943 .02872 L
.09486 .02662 L
.09949 .02523 L
.10458 .02402 L
.10982 .02306 L
.11478 .02236 L
.11924 .02186 L
.12409 .02144 L
.12936 .02109 L
.13495 .02081 L
.13973 .02064 L
.14225 .02057 L
.145 .02051 L
.14738 .02047 L
.14992 .02043 L
.15133 .02042 L
.1526 .0204 L
.15389 .0204 L
.1551 .02039 L
.15622 .02039 L
.15741 .02039 L
.15842 .02039 L
.15954 .02039 L
.16074 .02039 L
.16202 .0204 L
.16324 .02041 L
.16435 .02042 L
.16959 .02049 L
Mistroke
.17247 .02054 L
.17517 .02058 L
.1777 .02061 L
.17913 .02062 L
.18044 .02063 L
.18155 .02064 L
.18276 .02064 L
.18403 .02064 L
.18521 .02064 L
.18639 .02064 L
.18768 .02063 L
.18889 .02062 L
.19002 .02061 L
.19439 .02055 L
.20423 .02039 L
.21493 .02022 L
.22017 .02015 L
.22497 .0201 L
.23397 .02002 L
.2387 .01999 L
.24367 .01997 L
.24614 .01996 L
.24878 .01995 L
.25352 .01994 L
.25643 .01994 L
.25917 .01994 L
.26429 .01993 L
.28264 .01992 L
.30281 .0199 L
.32272 .01987 L
.33373 .01985 L
.34378 .01984 L
.35311 .01983 L
.36326 .01982 L
.37399 .01982 L
.38417 .01982 L
.39355 .01981 L
.40392 .01981 L
.41487 .01981 L
.42492 .01981 L
.43414 .0198 L
.44424 .0198 L
.45439 .0198 L
.46509 .0198 L
.47535 .0198 L
.48468 .0198 L
.49544 .0198 L
.50562 .0198 L
.54405 .0198 L
.5639 .0198 L
Mistroke
.58494 .0198 L
.62279 .0198 L
.6631 .0198 L
.70189 .0198 L
.74314 .0198 L
.78287 .0198 L
.82108 .0198 L
.86174 .0198 L
.90089 .0198 L
.9425 .0198 L
.97619 .0198 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.02499 .03293 L
.02605 .0472 L
.02729 .05989 L
.02846 .06807 L
.02954 .07283 L
.03053 .07539 L
.03163 .07672 L
.03279 .07696 L
.03395 .07638 L
.0352 .07517 L
.03746 .07207 L
.04262 .06362 L
.0521 .04962 L
.05746 .04351 L
.06244 .03893 L
.0679 .03493 L
.07373 .03162 L
.07935 .02917 L
.08445 .02744 L
.08943 .02611 L
.09481 .02499 L
.0999 .02417 L
.10458 .02357 L
.10928 .0231 L
.11432 .02271 L
.11907 .02242 L
.1234 .02221 L
.12849 .02203 L
.13136 .02195 L
.13402 .02189 L
.13653 .02184 L
.13889 .02181 L
.14135 .02178 L
.14266 .02177 L
.14338 .02177 L
.14407 .02176 L
.14532 .02176 L
.14646 .02176 L
.14769 .02176 L
.14839 .02176 L
.14903 .02176 L
.15009 .02176 L
.15127 .02177 L
.15249 .02177 L
.15364 .02178 L
.15628 .02182 L
.15869 .02186 L
.16147 .02193 L
.16411 .022 L
Mistroke
.17433 .02242 L
.17727 .02252 L
.17871 .02256 L
.18004 .02259 L
.18125 .02262 L
.18252 .02264 L
.1838 .02265 L
.18453 .02265 L
.18521 .02266 L
.18644 .02266 L
.18714 .02265 L
.18778 .02265 L
.18897 .02264 L
.19022 .02263 L
.1924 .0226 L
.19479 .02255 L
.20505 .0223 L
.21402 .02206 L
.22345 .02186 L
.22829 .02177 L
.23357 .02169 L
.23843 .02164 L
.24284 .0216 L
.24807 .02156 L
.25095 .02154 L
.25366 .02153 L
.25848 .02151 L
.26371 .0215 L
.28323 .02145 L
.30468 .02138 L
.31452 .02135 L
.32508 .02133 L
.33019 .02132 L
.33504 .02132 L
.34413 .02131 L
.34871 .0213 L
.35377 .0213 L
.35905 .0213 L
.36402 .02129 L
.36627 .02129 L
.36864 .02129 L
.37069 .02129 L
.37288 .02129 L
.37411 .02129 L
.37524 .02129 L
.37638 .02129 L
.37744 .02129 L
.37867 .02129 L
.37932 .02129 L
.38001 .02129 L
Mistroke
.38116 .02129 L
.38243 .02129 L
.38372 .02129 L
.38492 .02129 L
.38623 .02129 L
.38763 .02129 L
.39023 .02129 L
.39258 .02129 L
.39736 .02129 L
.40185 .02129 L
.42274 .0213 L
.46131 .02131 L
.50233 .02132 L
.54184 .02132 L
.57983 .02133 L
.62028 .02134 L
.6592 .02134 L
.70059 .02135 L
.74045 .02136 L
.7788 .02136 L
.8196 .02137 L
.85889 .02138 L
.89666 .02138 L
.93688 .02139 L
.97559 .0214 L
.97619 .0214 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.02846 .08381 L
.03068 .11084 L
.03279 .13099 L
.03398 .13975 L
.03527 .14699 L
.03645 .15158 L
.03754 .15425 L
.03871 .15561 L
.04 .15555 L
.04065 .15499 L
.04135 .15406 L
.04262 .15164 L
.04516 .14475 L
.04793 .13551 L
.05297 .11757 L
.06244 .08806 L
.07302 .06484 L
.07893 .0557 L
.08429 .04924 L
.08931 .04446 L
.09474 .04041 L
.09986 .03742 L
.10458 .03525 L
.10928 .03353 L
.11432 .03208 L
.11907 .03101 L
.1234 .03025 L
.12849 .02955 L
.13117 .02926 L
.13402 .029 L
.1365 .02881 L
.13924 .02864 L
.14174 .02851 L
.14407 .02842 L
.14642 .02836 L
.14766 .02833 L
.14835 .02832 L
.14898 .02831 L
.14965 .02831 L
.15038 .0283 L
.1517 .0283 L
.15289 .0283 L
.15416 .02832 L
.15526 .02833 L
.15644 .02836 L
.15857 .02842 L
.15987 .02848 L
.1611 .02854 L
.16341 .02867 L
Mistroke
.17352 .02958 L
.17642 .02985 L
.17785 .02996 L
.17916 .03005 L
.18033 .03012 L
.18162 .03018 L
.18291 .03022 L
.18361 .03024 L
.18427 .03025 L
.18551 .03026 L
.1862 .03026 L
.18685 .03026 L
.18803 .03024 L
.18929 .03022 L
.19041 .03018 L
.19146 .03015 L
.19385 .03003 L
.20412 .02936 L
.21291 .02875 L
.22252 .02819 L
.23237 .02779 L
.23775 .02763 L
.24274 .02752 L
.24516 .02748 L
.24743 .02745 L
.24951 .02742 L
.2517 .0274 L
.25284 .0274 L
.25409 .02739 L
.25524 .02738 L
.25629 .02738 L
.25753 .02737 L
.25821 .02737 L
.25886 .02737 L
.26 .02737 L
.26126 .02737 L
.26247 .02737 L
.26358 .02737 L
.26481 .02738 L
.26609 .02738 L
.26826 .02739 L
.27064 .0274 L
.28101 .02747 L
.28626 .02751 L
.28777 .02751 L
.2892 .02752 L
.2905 .02753 L
.29188 .02753 L
.29308 .02753 L
.29377 .02753 L
Mistroke
.29441 .02753 L
.29553 .02753 L
.29674 .02753 L
.29741 .02753 L
.29815 .02753 L
.29884 .02753 L
.29949 .02753 L
.30071 .02753 L
.302 .02752 L
.30461 .02751 L
.30737 .0275 L
.3123 .02746 L
.32343 .02735 L
.34361 .02714 L
.35309 .02706 L
.36326 .027 L
.37285 .02695 L
.3816 .02692 L
.39152 .02688 L
.4007 .02686 L
.42146 .02683 L
.44014 .0268 L
.46075 .02678 L
.48011 .02677 L
.50097 .02676 L
.54213 .02674 L
.58178 .02673 L
.61991 .02672 L
.66049 .02672 L
.69955 .02671 L
.74107 .0267 L
.78107 .0267 L
.81956 .0267 L
.8605 .02669 L
.89992 .02669 L
.93783 .02669 L
.97619 .02669 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.02499 .03252 L
.02605 .04485 L
.02729 .05338 L
.02846 .05712 L
.02954 .05836 L
.03053 .05843 L
.03163 .05783 L
.03279 .05676 L
.04262 .04432 L
.05205 .03499 L
.05742 .03114 L
.06244 .0283 L
.06788 .0259 L
.07305 .02413 L
.07768 .02288 L
.08274 .0218 L
.08822 .0209 L
.09407 .02017 L
.09958 .01965 L
.10458 .01929 L
.10945 .01901 L
.1146 .01879 L
.119 .01864 L
.12383 .01851 L
.12902 .01841 L
.13188 .01836 L
.13459 .01833 L
.13711 .0183 L
.13985 .01827 L
.14234 .01826 L
.14465 .01825 L
.14582 .01824 L
.14706 .01824 L
.14812 .01823 L
.14928 .01823 L
.15053 .01823 L
.15123 .01823 L
.15187 .01823 L
.1531 .01823 L
.15427 .01823 L
.15537 .01823 L
.15653 .01824 L
.15861 .01825 L
.16085 .01826 L
.16331 .01828 L
.16883 .01834 L
.17408 .0184 L
.17636 .01843 L
.17878 .01845 L
Mistroke
.18018 .01846 L
.18144 .01847 L
.18272 .01847 L
.18391 .01848 L
.18504 .01848 L
.18628 .01848 L
.18758 .01848 L
.18878 .01848 L
.18992 .01847 L
.19095 .01847 L
.19326 .01846 L
.19845 .01842 L
.20336 .01838 L
.2135 .01829 L
.22425 .01821 L
.23374 .01816 L
.23914 .01814 L
.2442 .01812 L
.24884 .01811 L
.25308 .0181 L
.25774 .0181 L
.26008 .0181 L
.26263 .01809 L
.30325 .01805 L
.32202 .01803 L
.3326 .01802 L
.34234 .01802 L
.3473 .01802 L
.35274 .01801 L
.35804 .01801 L
.36373 .01801 L
.36918 .01801 L
.37416 .01801 L
.38389 .01801 L
.38869 .01801 L
.39379 .01801 L
.40296 .01801 L
.40804 .01801 L
.41282 .01801 L
.41806 .01801 L
.421 .01801 L
.42371 .01801 L
.42619 .01801 L
.42844 .01801 L
.42968 .01801 L
.43104 .01801 L
.43232 .01801 L
.43349 .01801 L
.43458 .01801 L
.4356 .01801 L
Mistroke
.43672 .01801 L
.43792 .01801 L
.43918 .01801 L
.44037 .01801 L
.44261 .01801 L
.44509 .01801 L
.44774 .01801 L
.4525 .01801 L
.4633 .01801 L
.4736 .01801 L
.48473 .01801 L
.5049 .01801 L
.54592 .01801 L
.58543 .01801 L
.62342 .01801 L
.66387 .01801 L
.7028 .01801 L
.74418 .01802 L
.78404 .01802 L
.82239 .01802 L
.86319 .01802 L
.90248 .01802 L
.94025 .01802 L
.97619 .01803 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.02605 .04951 L
.02846 .08158 L
.02962 .09417 L
.03072 .10396 L
.03171 .11093 L
.03279 .1166 L
.03397 .12075 L
.03527 .12315 L
.03592 .12365 L
.03663 .12373 L
.0379 .12291 L
.03916 .12115 L
.04036 .11884 L
.04262 .11348 L
.05221 .08753 L
.06244 .06547 L
.06792 .05675 L
.07289 .0504 L
.08259 .04139 L
.08803 .03783 L
.09391 .03486 L
.09947 .03273 L
.10458 .0312 L
.10928 .0301 L
.11432 .02917 L
.11907 .02849 L
.1234 .02801 L
.12849 .02757 L
.13117 .02739 L
.13402 .02724 L
.1365 .02712 L
.13924 .02703 L
.14044 .02699 L
.14173 .02696 L
.14293 .02693 L
.14407 .02692 L
.14532 .0269 L
.14646 .02689 L
.14769 .02688 L
.14839 .02688 L
.14903 .02688 L
.15009 .02689 L
.15127 .0269 L
.15249 .02691 L
.15364 .02693 L
.15499 .02696 L
.15628 .027 L
.15869 .02709 L
.16128 .02722 L
Mistroke
.16411 .0274 L
.16981 .02791 L
.17518 .02845 L
.17753 .02866 L
.18 .02883 L
.18129 .0289 L
.18271 .02896 L
.184 .029 L
.18521 .02903 L
.18643 .02904 L
.18713 .02904 L
.18777 .02904 L
.18894 .02903 L
.19019 .02901 L
.1913 .02898 L
.19235 .02895 L
.19473 .02886 L
.19964 .02861 L
.20492 .02829 L
.21495 .02766 L
.2259 .02709 L
.23094 .02688 L
.23631 .0267 L
.24096 .02658 L
.24598 .02647 L
.24895 .02642 L
.25168 .02638 L
.25424 .02635 L
.25705 .02633 L
.25941 .02631 L
.26194 .0263 L
.2646 .02628 L
.2671 .02627 L
.30843 .02606 L
.31844 .02597 L
.3291 .02589 L
.33819 .02584 L
.34824 .02579 L
.35774 .02576 L
.36798 .02573 L
.37766 .02572 L
.38654 .02571 L
.40544 .02569 L
.42613 .02567 L
.44571 .02566 L
.45668 .02566 L
.46666 .02565 L
.48582 .02565 L
.49663 .02565 L
.50661 .02565 L
Mistroke
.52535 .02564 L
.536 .02564 L
.54598 .02564 L
.55095 .02564 L
.55637 .02564 L
.56115 .02564 L
.56624 .02564 L
.56884 .02564 L
.57128 .02564 L
.57366 .02564 L
.57585 .02564 L
.57794 .02564 L
.579 .02564 L
.58014 .02564 L
.58128 .02564 L
.58235 .02564 L
.58361 .02564 L
.58477 .02564 L
.58595 .02564 L
.58706 .02564 L
.58827 .02564 L
.58958 .02564 L
.59088 .02564 L
.59225 .02564 L
.59469 .02564 L
.59908 .02564 L
.60387 .02564 L
.61463 .02564 L
.62463 .02564 L
.64511 .02564 L
.6637 .02564 L
.7037 .02565 L
.74219 .02565 L
.78313 .02565 L
.82255 .02565 L
.86046 .02566 L
.90082 .02566 L
.93966 .02566 L
.97619 .02566 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02006 L
.0379 .01898 L
.04262 .01815 L
.04714 .01751 L
.05212 .01695 L
.05713 .01651 L
.06244 .01615 L
.06792 .01586 L
.07293 .01566 L
.07871 .01548 L
.0842 .01536 L
.08925 .01527 L
.09394 .01521 L
.09909 .01515 L
.10458 .01511 L
.10994 .01508 L
.11487 .01505 L
.12028 .01503 L
.12599 .01502 L
.13096 .01501 L
.13561 .015 L
.1407 .01499 L
.14616 .01499 L
.15145 .01499 L
.15634 .01498 L
.15889 .01498 L
.1617 .01498 L
.16464 .01498 L
.1674 .01498 L
.18752 .01498 L
.206 .01498 L
.21106 .01498 L
.21647 .01497 L
.22114 .01497 L
.22621 .01497 L
.23161 .01497 L
.23671 .01497 L
.23912 .01497 L
.24167 .01497 L
.24407 .01497 L
.24625 .01497 L
.24875 .01497 L
.25013 .01497 L
.25144 .01497 L
.25265 .01497 L
Mistroke
.25377 .01497 L
.25499 .01497 L
.2563 .01497 L
.25705 .01497 L
.25773 .01497 L
.25849 .01497 L
.25929 .01497 L
.26063 .01497 L
.2621 .01497 L
.26735 .01497 L
.2774 .01497 L
.28233 .01497 L
.2869 .01497 L
.28945 .01497 L
.29215 .01497 L
.29355 .01497 L
.29486 .01497 L
.29561 .01497 L
.2963 .01497 L
.29706 .01497 L
.29785 .01497 L
.29905 .01497 L
.30032 .01497 L
.30153 .01497 L
.30262 .01497 L
.30391 .01497 L
.3053 .01497 L
.30783 .01497 L
.31273 .01497 L
.31732 .01497 L
.32774 .01497 L
.33855 .01497 L
.3488 .01497 L
.35853 .01497 L
.36913 .01497 L
.37876 .01497 L
.38767 .01497 L
.42691 .01497 L
.44658 .01497 L
.46463 .01497 L
.48395 .01497 L
.5048 .01497 L
.54439 .01497 L
.58247 .01497 L
.62299 .01497 L
.66201 .01497 L
.70347 .01497 L
.74342 .01497 L
.78186 .01497 L
.82274 .01497 L
Mistroke
.86211 .01497 L
.89997 .01497 L
.94028 .01497 L
.97619 .01497 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.02499 .03251 L
.02605 .04471 L
.02729 .05284 L
.02846 .05608 L
.02954 .05689 L
.03053 .05663 L
.03163 .05574 L
.03279 .05443 L
.04262 .04133 L
.05205 .03211 L
.05742 .02838 L
.06244 .02566 L
.06788 .02338 L
.07305 .02172 L
.07768 .02055 L
.08274 .01955 L
.08822 .01871 L
.09407 .01805 L
.09958 .01757 L
.10458 .01725 L
.10945 .017 L
.1146 .01679 L
.119 .01666 L
.12383 .01654 L
.12902 .01645 L
.13459 .01637 L
.13985 .01631 L
.14465 .01628 L
.14945 .01625 L
.15188 .01624 L
.15456 .01623 L
.15684 .01623 L
.15803 .01622 L
.15929 .01622 L
.1604 .01622 L
.16161 .01622 L
.16271 .01622 L
.16373 .01622 L
.16503 .01622 L
.16576 .01622 L
.16644 .01622 L
.16768 .01622 L
.16899 .01622 L
.17017 .01622 L
.17127 .01622 L
.17377 .01622 L
.17515 .01622 L
.17647 .01622 L
.17765 .01622 L
Mistroke
.17894 .01622 L
.17967 .01622 L
.18033 .01622 L
.1811 .01622 L
.18182 .01622 L
.1831 .01622 L
.18383 .01622 L
.18449 .01622 L
.18696 .01622 L
.18921 .01622 L
.19425 .01621 L
.20335 .01619 L
.2141 .01617 L
.21882 .01616 L
.22403 .01615 L
.2285 .01614 L
.23331 .01614 L
.23839 .01614 L
.24315 .01613 L
.24844 .01613 L
.2511 .01613 L
.254 .01613 L
.25915 .01613 L
.26393 .01613 L
.30303 .01612 L
.32298 .01612 L
.33348 .01612 L
.34458 .01611 L
.35451 .01611 L
.36542 .01611 L
.37534 .01611 L
.38461 .01611 L
.39504 .01611 L
.40494 .01611 L
.42349 .01611 L
.43312 .01611 L
.44337 .01611 L
.45212 .01611 L
.4571 .01611 L
.46178 .01611 L
.46647 .01611 L
.4716 .01611 L
.47419 .01611 L
.47695 .01611 L
.47935 .01611 L
.48194 .01611 L
.48453 .01611 L
.48692 .01611 L
.48921 .01611 L
.49036 .01611 L
Mistroke
.49163 .01611 L
.49277 .01611 L
.49382 .01611 L
.49503 .01611 L
.49618 .01611 L
.49724 .01611 L
.49822 .01611 L
.49929 .01611 L
.50044 .01611 L
.50168 .01611 L
.50305 .01611 L
.5058 .01611 L
.51073 .01611 L
.52187 .01611 L
.54204 .01611 L
.58249 .01611 L
.62141 .01611 L
.64267 .01611 L
.65243 .01611 L
.66279 .01611 L
.67227 .01611 L
.68272 .01611 L
.69223 .01611 L
.70114 .01611 L
.70585 .01611 L
.71099 .01611 L
.71358 .01611 L
.71501 .01611 L
.71635 .01611 L
.71761 .01611 L
.71827 .01611 L
.71897 .01611 L
.7202 .01611 L
.72134 .01611 L
.72249 .01611 L
.72354 .01611 L
.72475 .01611 L
.7259 .01611 L
.72696 .01611 L
.72794 .01611 L
.73016 .01611 L
.73262 .01611 L
.73485 .01611 L
.73985 .01611 L
.74475 .01611 L
.74991 .01611 L
.75915 .01611 L
.77999 .01611 L
.79968 .01611 L
.81803 .01611 L
Mistroke
.85701 .01611 L
.89845 .01611 L
.93837 .01611 L
.97619 .01611 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.02605 .04947 L
.02846 .08122 L
.02962 .09363 L
.03072 .10332 L
.0317 .11027 L
.03279 .11618 L
.03398 .12076 L
.03524 .12372 L
.03641 .12503 L
.0375 .12524 L
.03879 .12451 L
.03997 .12313 L
.04132 .1209 L
.04262 .11834 L
.05221 .09504 L
.06244 .07343 L
.06792 .06456 L
.07289 .05801 L
.08259 .04854 L
.08803 .04475 L
.09391 .04156 L
.09947 .03925 L
.10458 .0376 L
.10928 .0364 L
.11432 .0354 L
.11907 .03467 L
.1234 .03416 L
.12849 .03371 L
.13136 .03352 L
.13402 .03339 L
.13633 .0333 L
.13765 .03326 L
.13889 .03323 L
.14019 .03321 L
.14138 .03319 L
.14269 .03318 L
.14335 .03318 L
.14407 .03319 L
.14539 .0332 L
.1466 .03321 L
.14724 .03322 L
.14794 .03324 L
.14935 .03328 L
.1506 .03333 L
.15193 .03339 L
.15434 .03353 L
.15684 .03372 L
.15922 .03396 L
.16368 .03458 L
Mistroke
.17383 .03676 L
.17675 .03736 L
.17818 .0376 L
.17949 .03779 L
.18067 .03793 L
.18196 .03806 L
.18326 .03815 L
.18397 .03818 L
.18463 .03821 L
.18586 .03823 L
.18656 .03823 L
.18721 .03822 L
.18839 .0382 L
.18964 .03815 L
.19077 .03808 L
.19182 .03801 L
.19421 .03781 L
.20447 .03659 L
.21327 .03548 L
.22287 .03446 L
.23273 .03369 L
.2381 .03338 L
.2431 .03316 L
.24779 .03301 L
.25205 .0329 L
.25697 .03281 L
.26161 .03275 L
.27136 .03266 L
.28167 .03258 L
.29132 .03251 L
.30013 .03246 L
.30959 .03242 L
.31974 .03239 L
.33807 .03234 L
.34287 .03233 L
.34797 .03232 L
.35232 .03231 L
.35352 .03231 L
.3548 .03231 L
.35593 .03231 L
.35713 .03231 L
.35843 .03231 L
.35965 .03231 L
.36039 .03231 L
.36109 .03231 L
.3624 .03231 L
.36307 .03231 L
.36379 .03231 L
.36506 .03231 L
.36644 .03231 L
Mistroke
.36795 .03231 L
.37043 .03232 L
.37308 .03232 L
.37788 .03233 L
.38313 .03234 L
.388 .03236 L
.39903 .0324 L
.41913 .03249 L
.43794 .03256 L
.45828 .03261 L
.4797 .03266 L
.49988 .03269 L
.51944 .03272 L
.5409 .03275 L
.58041 .03279 L
.62085 .03282 L
.65978 .03285 L
.70116 .03288 L
.74103 .03291 L
.77938 .03295 L
.82018 .03299 L
.85947 .03303 L
.89724 .03307 L
.93746 .03312 L
.97617 .03316 L
.97619 .03316 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.02846 .08439 L
.03279 .13821 L
.03523 .16282 L
.03754 .18179 L
.03881 .19042 L
.0402 .19828 L
.04145 .20404 L
.04262 .20833 L
.04376 .21154 L
.045 .21395 L
.0457 .21487 L
.04637 .21546 L
.04762 .21586 L
.04894 .21539 L
.05016 .21423 L
.05086 .21329 L
.0515 .21227 L
.05293 .20951 L
.05783 .19639 L
.06244 .18145 L
.07229 .14992 L
.08269 .12315 L
.08812 .11231 L
.09409 .10265 L
.09948 .09569 L
.10458 .09041 L
.10947 .08637 L
.11478 .08292 L
.11962 .08053 L
.12409 .07885 L
.12641 .07817 L
.12891 .07756 L
.13165 .07705 L
.13423 .07671 L
.13554 .07659 L
.13628 .07653 L
.13697 .07649 L
.1377 .07646 L
.13836 .07644 L
.13913 .07643 L
.13985 .07643 L
.14114 .07646 L
.14232 .07652 L
.14363 .07663 L
.145 .07678 L
.14621 .07696 L
.14753 .0772 L
.14994 .07777 L
.15227 .07852 L
Mistroke
.15444 .07942 L
.15702 .08079 L
.15935 .0824 L
.16204 .08477 L
.16458 .08762 L
.17331 .10177 L
.17794 .10922 L
.17927 .11091 L
.18053 .11226 L
.18168 .11328 L
.18289 .11412 L
.18415 .11476 L
.18532 .11514 L
.18657 .11533 L
.18729 .11534 L
.18796 .1153 L
.18914 .11509 L
.19023 .11477 L
.19143 .11428 L
.19268 .11364 L
.19762 .11015 L
.20301 .10534 L
.21252 .09663 L
.22149 .08967 L
.22644 .08657 L
.2318 .08381 L
.23625 .08197 L
.24114 .08038 L
.24645 .07913 L
.24935 .07863 L
.25206 .07827 L
.25336 .07814 L
.25459 .07803 L
.25571 .07794 L
.25691 .07787 L
.2582 .07781 L
.2594 .07778 L
.26068 .07775 L
.26142 .07774 L
.26211 .07774 L
.26328 .07775 L
.26453 .07777 L
.26572 .0778 L
.26679 .07784 L
.26943 .07798 L
.27192 .07816 L
.27688 .07863 L
.28227 .07928 L
.29182 .08051 L
.29649 .08102 L
Mistroke
.30076 .08138 L
.3031 .08152 L
.30532 .08163 L
.30653 .08167 L
.30766 .0817 L
.30889 .08172 L
.31021 .08173 L
.31092 .08173 L
.31156 .08173 L
.31227 .08173 L
.31302 .08172 L
.31428 .0817 L
.315 .08168 L
.31567 .08167 L
.31806 .08159 L
.32061 .08147 L
.32627 .08112 L
.33162 .08072 L
.34165 .0799 L
.35131 .07916 L
.36157 .07854 L
.37033 .07816 L
.37532 .07801 L
.38 .0779 L
.3847 .07783 L
.38736 .07779 L
.38984 .07777 L
.39242 .07775 L
.39485 .07774 L
.39765 .07772 L
.4002 .07771 L
.40901 .07769 L
.41369 .07768 L
.41871 .07766 L
.42373 .07764 L
.42844 .07761 L
.43873 .07753 L
.45719 .07731 L
.49849 .07675 L
.53827 .07625 L
.57653 .07578 L
.61725 .0753 L
.65645 .0749 L
.69811 .07455 L
.73825 .07427 L
.77687 .07405 L
.81795 .07388 L
.8575 .07374 L
.89555 .07364 L
.93605 .07356 L
Mistroke
.97503 .07349 L
.97619 .07349 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.02846 .08417 L
.03279 .13578 L
.03527 .15805 L
.03754 .17328 L
.03879 .17969 L
.04015 .18511 L
.04143 .18884 L
.04262 .19119 L
.04376 .19255 L
.04498 .19313 L
.04614 .19293 L
.0472 .1922 L
.04843 .19076 L
.04978 .1886 L
.05224 .1834 L
.06244 .1544 L
.07302 .1257 L
.07883 .11293 L
.08429 .10295 L
.08941 .09525 L
.09493 .08847 L
.09992 .08355 L
.10458 .07982 L
.10955 .07663 L
.11408 .07433 L
.11912 .07235 L
.12192 .07149 L
.12452 .07082 L
.12698 .0703 L
.1297 .06985 L
.13243 .06952 L
.13393 .06939 L
.1346 .06935 L
.13534 .0693 L
.13659 .06925 L
.13791 .06923 L
.13913 .06923 L
.14027 .06926 L
.14096 .06929 L
.14161 .06932 L
.14284 .06941 L
.14415 .06953 L
.14558 .06971 L
.14794 .0701 L
.15047 .07069 L
.15286 .07142 L
.15505 .07227 L
.1576 .07355 L
.16039 .07537 L
Mistroke
.16302 .07761 L
.16546 .0802 L
.17067 .08738 L
.17341 .0916 L
.1763 .09575 L
.17884 .09874 L
.18018 .1 L
.18162 .10108 L
.1823 .1015 L
.18294 .10183 L
.18414 .10231 L
.18527 .10259 L
.1865 .10272 L
.18777 .10269 L
.18897 .10251 L
.19028 .10217 L
.19169 .10165 L
.19456 .10021 L
.19719 .09854 L
.20706 .09107 L
.21607 .08451 L
.22568 .07892 L
.23084 .0766 L
.23551 .07489 L
.24027 .0735 L
.24465 .07251 L
.24977 .07167 L
.25246 .07134 L
.25531 .07108 L
.25778 .07091 L
.2601 .07079 L
.26143 .07074 L
.26264 .0707 L
.26403 .07066 L
.26473 .07065 L
.26536 .07064 L
.2665 .07063 L
.26772 .07062 L
.2688 .07062 L
.26994 .07062 L
.27119 .07064 L
.27235 .07066 L
.27363 .07068 L
.275 .07072 L
.27776 .07082 L
.28036 .07095 L
.28524 .07126 L
.30366 .07278 L
.30867 .07312 L
.31336 .07336 L
Mistroke
.31572 .07345 L
.31826 .07353 L
.3197 .07356 L
.32107 .07359 L
.32242 .07361 L
.32365 .07363 L
.32479 .07364 L
.32586 .07364 L
.327 .07365 L
.32822 .07365 L
.3293 .07365 L
.33043 .07364 L
.3314 .07364 L
.33247 .07363 L
.33487 .0736 L
.33745 .07357 L
.34209 .0735 L
.34703 .07342 L
.35227 .07334 L
.35501 .07331 L
.35646 .0733 L
.35803 .07329 L
.35873 .07329 L
.35946 .07328 L
.36077 .07328 L
.362 .07328 L
.3627 .07328 L
.36335 .07328 L
.36461 .07328 L
.36532 .07328 L
.36597 .07329 L
.36717 .07329 L
.36845 .0733 L
.37065 .07333 L
.37308 .07336 L
.37845 .07346 L
.38347 .07359 L
.40206 .07422 L
.42232 .07491 L
.42764 .07504 L
.43331 .07517 L
.44351 .07534 L
.44895 .0754 L
.45406 .07545 L
.45865 .07548 L
.46361 .0755 L
.466 .07551 L
.46855 .07552 L
.47315 .07553 L
.47597 .07554 L
Mistroke
.47863 .07554 L
.48101 .07554 L
.48236 .07554 L
.48361 .07554 L
.48482 .07554 L
.48612 .07554 L
.48735 .07555 L
.48847 .07555 L
.48979 .07555 L
.49053 .07554 L
.49122 .07554 L
.49249 .07554 L
.49384 .07554 L
.49524 .07554 L
.49677 .07554 L
.49953 .07554 L
.50469 .07553 L
.5096 .07552 L
.51419 .07551 L
.52462 .07548 L
.53478 .07543 L
.54568 .07537 L
.58703 .07505 L
.62686 .07472 L
.66518 .07442 L
.70595 .07416 L
.72619 .07406 L
.7452 .07398 L
.76358 .07391 L
.78294 .07386 L
.80311 .07381 L
.82162 .07379 L
.83115 .07378 L
.84135 .07377 L
.8463 .07376 L
.85097 .07376 L
.85548 .07376 L
.85971 .07376 L
.86213 .07376 L
.86434 .07376 L
.86679 .07376 L
.86814 .07376 L
.86943 .07376 L
.87066 .07376 L
.87198 .07376 L
.87322 .07376 L
.87435 .07376 L
.87504 .07376 L
.87568 .07376 L
.87638 .07376 L
Mistroke
.87711 .07376 L
.87835 .07376 L
.87972 .07376 L
.88213 .07376 L
.88433 .07376 L
.88926 .07376 L
.89384 .07376 L
.89817 .07376 L
.90784 .07377 L
.91811 .07377 L
.93653 .07379 L
.97433 .07383 L
.97619 .07383 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05246 L
.02846 .05541 L
.02954 .05601 L
.03053 .05563 L
.03163 .05465 L
.03279 .05328 L
.04262 .04032 L
.05205 .03137 L
.05742 .02777 L
.06244 .02516 L
.06788 .02297 L
.07305 .02137 L
.07768 .02025 L
.08274 .01929 L
.08822 .0185 L
.09407 .01786 L
.09958 .01741 L
.10458 .0171 L
.10945 .01686 L
.1146 .01667 L
.119 .01654 L
.12383 .01643 L
.12902 .01634 L
.13459 .01626 L
.13985 .01621 L
.14465 .01618 L
.14945 .01615 L
.15188 .01614 L
.15456 .01613 L
.15684 .01613 L
.15803 .01612 L
.15929 .01612 L
.1604 .01612 L
.16161 .01612 L
.16271 .01612 L
.16373 .01612 L
.16503 .01612 L
.16576 .01612 L
.16644 .01612 L
.16768 .01612 L
.16899 .01612 L
.17017 .01612 L
.17127 .01612 L
.17377 .01612 L
.17515 .01612 L
.17647 .01612 L
.17765 .01612 L
Mistroke
.17894 .01612 L
.17967 .01612 L
.18033 .01612 L
.1811 .01612 L
.18182 .01612 L
.1831 .01612 L
.18449 .01612 L
.18687 .01612 L
.18942 .01611 L
.19402 .0161 L
.20447 .01608 L
.21542 .01607 L
.22555 .01605 L
.2305 .01605 L
.23575 .01604 L
.24102 .01604 L
.24402 .01604 L
.24683 .01604 L
.24929 .01604 L
.25064 .01604 L
.25189 .01604 L
.2541 .01604 L
.25527 .01604 L
.25652 .01604 L
.25723 .01604 L
.25787 .01604 L
.25859 .01604 L
.25934 .01604 L
.2606 .01604 L
.26132 .01604 L
.26199 .01604 L
.26325 .01604 L
.26439 .01604 L
.26696 .01604 L
.2762 .01604 L
.28126 .01604 L
.28374 .01604 L
.28602 .01604 L
.28848 .01604 L
.28978 .01604 L
.29049 .01604 L
.29114 .01604 L
.29182 .01604 L
.29254 .01604 L
.29384 .01604 L
.29457 .01604 L
.29536 .01604 L
.29611 .01604 L
.2968 .01604 L
.29799 .01604 L
Mistroke
.2991 .01604 L
.30164 .01604 L
.30411 .01604 L
.30677 .01604 L
.31689 .01604 L
.32792 .01603 L
.33846 .01603 L
.34802 .01603 L
.35816 .01603 L
.36771 .01603 L
.37779 .01603 L
.38868 .01603 L
.40824 .01602 L
.42971 .01602 L
.45038 .01602 L
.46921 .01602 L
.48874 .01602 L
.50966 .01602 L
.54952 .01602 L
.58787 .01602 L
.62867 .01602 L
.66796 .01602 L
.70573 .01602 L
.74595 .01602 L
.78466 .01602 L
.82582 .01602 L
.86547 .01602 L
.90359 .01602 L
.94418 .01602 L
.97619 .01602 L
Mfstroke
.862 1 0 r
.02381 .01472 m
.02499 .0321 L
.02605 .04254 L
.02729 .04785 L
.02846 .04913 L
.02954 .0489 L
.03053 .04815 L
.03163 .04703 L
.03279 .04569 L
.03786 .03966 L
.04262 .03475 L
.04754 .03061 L
.05205 .02758 L
.05706 .02491 L
.06244 .02268 L
.0678 .02099 L
.07277 .01977 L
.07823 .01875 L
.08405 .01794 L
.08959 .01735 L
.09482 .01693 L
.09951 .01664 L
.10458 .0164 L
.1095 .01622 L
.11408 .01608 L
.11912 .01597 L
.12452 .01587 L
.13018 .0158 L
.13554 .01575 L
.14035 .01571 L
.14558 .01569 L
.15043 .01567 L
.15498 .01565 L
.15759 .01565 L
.15998 .01564 L
.1626 .01564 L
.16404 .01564 L
.16536 .01564 L
.16787 .01563 L
.16925 .01563 L
.17055 .01563 L
.17539 .01563 L
.17795 .01563 L
.18066 .01563 L
.18363 .01563 L
.18637 .01563 L
.20616 .01561 L
.21482 .0156 L
.22425 .01559 L
.22943 .01559 L
Mistroke
.23423 .01559 L
.23882 .01559 L
.2437 .01558 L
.24642 .01558 L
.24784 .01558 L
.24935 .01558 L
.25067 .01558 L
.25212 .01558 L
.25344 .01558 L
.25466 .01558 L
.25595 .01558 L
.25717 .01558 L
.25827 .01558 L
.25946 .01558 L
.26075 .01558 L
.26141 .01558 L
.26213 .01558 L
.26459 .01558 L
.27484 .01558 L
.28042 .01559 L
.28561 .01559 L
.2879 .01559 L
.29005 .01559 L
.29125 .01559 L
.29254 .01559 L
.29372 .01559 L
.2948 .01559 L
.296 .01559 L
.29713 .01559 L
.29836 .01559 L
.29905 .01559 L
.29968 .01559 L
.30095 .01559 L
.30233 .01559 L
.30485 .01559 L
.30724 .01559 L
.30948 .01559 L
.3146 .01559 L
.32496 .01558 L
.34359 .01558 L
.3534 .01558 L
.36374 .01558 L
.37258 .01558 L
.38224 .01558 L
.40183 .01558 L
.42277 .01558 L
.44266 .01558 L
.46424 .01558 L
.48501 .01558 L
.50419 .01558 L
Mistroke
.54356 .01558 L
.58141 .01558 L
.62172 .01558 L
.66051 .01558 L
.70176 .01558 L
.74148 .01558 L
.7797 .01558 L
.82036 .01558 L
.85951 .01558 L
.90111 .01558 L
.9412 .01558 L
.97619 .01558 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.02605 .04944 L
.02729 .06651 L
.02846 .0805 L
.02954 .0912 L
.03072 .09998 L
.0318 .10542 L
.03279 .10848 L
.03396 .11008 L
.03506 .11004 L
.03626 .10875 L
.03756 .10638 L
.0402 .09982 L
.04262 .09301 L
.04759 .07922 L
.0529 .06646 L
.06244 .04931 L
.06786 .04237 L
.07277 .03743 L
.07858 .03291 L
.08405 .02966 L
.08918 .02731 L
.09391 .02561 L
.0991 .02416 L
.10458 .02297 L
.10954 .02215 L
.11406 .02156 L
.11928 .02103 L
.12422 .02065 L
.12878 .02037 L
.133 .02017 L
.13763 .02 L
.14003 .01993 L
.14255 .01987 L
.14489 .01982 L
.14744 .01978 L
.14976 .01975 L
.15192 .01973 L
.15324 .01972 L
.15448 .01971 L
.1556 .0197 L
.15681 .0197 L
.15812 .0197 L
.15879 .0197 L
.15952 .0197 L
.16081 .0197 L
.16202 .01971 L
.16315 .01971 L
.16438 .01972 L
.16663 .01974 L
Mistroke
.17083 .01979 L
.17539 .01985 L
.17663 .01986 L
.17795 .01987 L
.17908 .01988 L
.1803 .01989 L
.18162 .0199 L
.18284 .0199 L
.18359 .0199 L
.1843 .0199 L
.18494 .0199 L
.18563 .0199 L
.1869 .01989 L
.18754 .01989 L
.18824 .01989 L
.19065 .01987 L
.19297 .01985 L
.19548 .01982 L
.20001 .01976 L
.21004 .01963 L
.221 .0195 L
.22604 .01946 L
.23141 .01942 L
.23605 .01939 L
.24108 .01936 L
.24405 .01935 L
.24678 .01935 L
.24934 .01934 L
.25215 .01933 L
.25337 .01933 L
.25467 .01933 L
.2558 .01933 L
.25703 .01933 L
.25842 .01933 L
.25973 .01933 L
.26101 .01933 L
.26219 .01933 L
.26337 .01933 L
.2646 .01933 L
.26566 .01933 L
.26682 .01933 L
.26806 .01933 L
.2694 .01933 L
.2718 .01933 L
.28083 .01934 L
.28349 .01934 L
.28489 .01934 L
.28638 .01934 L
.28768 .01934 L
.28841 .01934 L
Mistroke
.2891 .01934 L
.29032 .01934 L
.29162 .01934 L
.29287 .01934 L
.29359 .01934 L
.29425 .01934 L
.29545 .01934 L
.29674 .01934 L
.2992 .01934 L
.30143 .01933 L
.30631 .01933 L
.31146 .01932 L
.32069 .01931 L
.33074 .01929 L
.34151 .01927 L
.35179 .01926 L
.36117 .01925 L
.37059 .01924 L
.3795 .01924 L
.39943 .01923 L
.41785 .01923 L
.43812 .01922 L
.45714 .01922 L
.47532 .01921 L
.49491 .01921 L
.51497 .01921 L
.53607 .01921 L
.5742 .01921 L
.59382 .0192 L
.61478 .0192 L
.6563 .0192 L
.6963 .0192 L
.73479 .0192 L
.77572 .0192 L
.81515 .0192 L
.85305 .0192 L
.89341 .0192 L
.93226 .0192 L
.97355 .0192 L
.97619 .0192 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02121 L
.03053 .02078 L
.03279 .02027 L
.04262 .01835 L
.04762 .01763 L
.05293 .01704 L
.05746 .01664 L
.06244 .01629 L
.06792 .01599 L
.07293 .01578 L
.07871 .01559 L
.0842 .01546 L
.08925 .01537 L
.09394 .0153 L
.09909 .01524 L
.10458 .0152 L
.10994 .01516 L
.11487 .01514 L
.12028 .01512 L
.12599 .0151 L
.13096 .01509 L
.13561 .01508 L
.1407 .01508 L
.14616 .01507 L
.14872 .01507 L
.15145 .01507 L
.1538 .01507 L
.15634 .01506 L
.15905 .01506 L
.1616 .01506 L
.16307 .01506 L
.16462 .01506 L
.16595 .01506 L
.1674 .01506 L
.17282 .01506 L
.17412 .01506 L
.17549 .01506 L
.17666 .01506 L
.17794 .01506 L
.17909 .01506 L
.18032 .01506 L
.18254 .01506 L
.18514 .01506 L
.18752 .01506 L
.20713 .01506 L
.218 .01506 L
Mistroke
.22329 .01505 L
.22808 .01505 L
.23251 .01505 L
.2373 .01505 L
.24235 .01505 L
.24711 .01505 L
.24962 .01505 L
.25237 .01505 L
.25791 .01505 L
.26784 .01505 L
.27808 .01505 L
.28739 .01505 L
.29827 .01505 L
.30832 .01505 L
.31742 .01505 L
.32744 .01505 L
.33752 .01505 L
.34304 .01505 L
.34822 .01505 L
.35808 .01505 L
.36303 .01505 L
.36844 .01505 L
.37804 .01505 L
.38696 .01505 L
.40746 .01505 L
.4165 .01505 L
.42606 .01505 L
.43082 .01505 L
.43335 .01505 L
.43606 .01505 L
.43855 .01505 L
.44083 .01505 L
.44311 .01505 L
.44528 .01505 L
.44647 .01505 L
.44779 .01505 L
.44845 .01505 L
.44916 .01505 L
.45045 .01505 L
.45167 .01505 L
.45295 .01505 L
.45404 .01505 L
.45524 .01505 L
.45796 .01505 L
.46086 .01505 L
.46609 .01505 L
.47632 .01505 L
.48741 .01505 L
.50756 .01505 L
.54844 .01505 L
Mistroke
.58781 .01505 L
.62567 .01505 L
.64672 .01505 L
.66598 .01505 L
.70477 .01505 L
.72377 .01505 L
.7445 .01505 L
.76418 .01505 L
.78516 .01505 L
.79546 .01505 L
.80659 .01505 L
.8171 .01505 L
.82676 .01505 L
.83147 .01505 L
.83651 .01505 L
.84127 .01505 L
.8456 .01505 L
.84824 .01505 L
.85069 .01505 L
.85207 .01505 L
.85337 .01505 L
.85472 .01505 L
.85544 .01505 L
.85622 .01505 L
.85744 .01505 L
.85813 .01505 L
.85877 .01505 L
.86008 .01505 L
.8608 .01505 L
.86146 .01505 L
.86265 .01505 L
.86394 .01505 L
.86627 .01505 L
.86863 .01505 L
.87117 .01505 L
.87574 .01505 L
.88119 .01505 L
.88616 .01505 L
.90721 .01505 L
.92625 .01505 L
.94699 .01505 L
.97619 .01505 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.02605 .04946 L
.02846 .08115 L
.02962 .09347 L
.03072 .10304 L
.03171 .1099 L
.03279 .11561 L
.03397 .11999 L
.03527 .12287 L
.03592 .12366 L
.03663 .1241 L
.0379 .12399 L
.03916 .12295 L
.04036 .12134 L
.04262 .11718 L
.05221 .09436 L
.06244 .07326 L
.06792 .06458 L
.07289 .05815 L
.08259 .04882 L
.08803 .04505 L
.09391 .04188 L
.09947 .03958 L
.10458 .03792 L
.10928 .03672 L
.11432 .03571 L
.11907 .03497 L
.1234 .03445 L
.12849 .03399 L
.13136 .0338 L
.13402 .03366 L
.13633 .03357 L
.13765 .03353 L
.13889 .0335 L
.14019 .03348 L
.14138 .03346 L
.14269 .03345 L
.14335 .03345 L
.14407 .03345 L
.14539 .03346 L
.1466 .03348 L
.14724 .03349 L
.14794 .03351 L
.14935 .03355 L
.1506 .0336 L
.15193 .03366 L
.15434 .0338 L
.15684 .034 L
.15922 .03425 L
.16368 .0349 L
Mistroke
.17383 .03727 L
.1765 .03792 L
.17939 .0385 L
.18072 .03871 L
.18212 .03889 L
.18332 .03901 L
.18463 .03911 L
.18533 .03915 L
.18599 .03918 L
.18723 .03921 L
.18793 .03921 L
.18857 .03921 L
.18927 .03919 L
.19002 .03917 L
.19125 .03912 L
.19241 .03905 L
.19504 .03885 L
.19958 .03836 L
.20447 .03772 L
.22287 .03536 L
.23247 .03446 L
.2379 .03406 L
.24295 .03377 L
.24831 .03353 L
.25317 .03337 L
.25878 .03323 L
.26407 .03313 L
.30258 .03251 L
.312 .03234 L
.32211 .03218 L
.3332 .03205 L
.34355 .03196 L
.34863 .03193 L
.35414 .0319 L
.35901 .03188 L
.36418 .03187 L
.36883 .03185 L
.37396 .03184 L
.37863 .03184 L
.38301 .03183 L
.3877 .03183 L
.39035 .03183 L
.39283 .03182 L
.39417 .03182 L
.39544 .03182 L
.3966 .03182 L
.39782 .03182 L
.39846 .03182 L
.39916 .03182 L
.40039 .03182 L
Mistroke
.40108 .03182 L
.40182 .03182 L
.40253 .03182 L
.40317 .03182 L
.40431 .03182 L
.40552 .03182 L
.40667 .03182 L
.4077 .03182 L
.41025 .03182 L
.41265 .03183 L
.41698 .03183 L
.42167 .03183 L
.44162 .03184 L
.46269 .03186 L
.50068 .0319 L
.54112 .03195 L
.58005 .032 L
.62143 .03205 L
.6613 .03209 L
.69965 .03214 L
.74045 .03218 L
.77974 .03223 L
.81751 .03227 L
.85773 .03231 L
.89644 .03235 L
.9376 .0324 L
.97619 .03244 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.02605 .04958 L
.02846 .08245 L
.03072 .10702 L
.03172 .1155 L
.03279 .12285 L
.03405 .12945 L
.03521 .13365 L
.03646 .13639 L
.03717 .13722 L
.03784 .1376 L
.03904 .13742 L
.04014 .13645 L
.04141 .13459 L
.04262 .13226 L
.05221 .10656 L
.06244 .0814 L
.06792 .07096 L
.07289 .06321 L
.08259 .05197 L
.08803 .04745 L
.09391 .04364 L
.09947 .04087 L
.10458 .03889 L
.10928 .03744 L
.11432 .03623 L
.11907 .03533 L
.1234 .0347 L
.12849 .03414 L
.13136 .0339 L
.13402 .03372 L
.13633 .03359 L
.13889 .03349 L
.14017 .03345 L
.14085 .03343 L
.14156 .03342 L
.14287 .0334 L
.14407 .03339 L
.1453 .03338 L
.146 .03338 L
.14664 .03339 L
.14782 .0334 L
.14907 .03342 L
.15019 .03345 L
.15123 .03349 L
.15361 .03359 L
.15493 .03367 L
.15618 .03376 L
.15853 .03396 L
.16105 .03425 L
Mistroke
.16381 .03464 L
.17327 .03667 L
.17553 .03719 L
.17791 .03767 L
.18012 .03804 L
.18218 .0383 L
.18332 .03841 L
.18455 .0385 L
.18525 .03853 L
.18591 .03856 L
.18715 .03859 L
.1878 .03859 L
.18849 .03859 L
.18972 .03857 L
.19041 .03854 L
.19105 .03852 L
.19252 .03843 L
.19488 .03825 L
.19703 .03805 L
.20189 .03748 L
.21277 .03605 L
.22287 .03486 L
.23205 .03403 L
.23675 .03369 L
.24184 .0334 L
.24742 .03315 L
.2527 .03297 L
.25519 .03291 L
.25783 .03285 L
.26255 .03278 L
.30049 .03232 L
.32161 .03195 L
.33162 .03182 L
.34088 .03172 L
.35044 .03164 L
.35548 .03161 L
.36084 .03159 L
.36983 .03155 L
.37976 .03153 L
.38983 .03151 L
.39908 .03149 L
.40988 .03148 L
.41993 .03147 L
.42983 .03146 L
.43883 .03146 L
.44883 .03145 L
.45433 .03145 L
.45952 .03145 L
.46414 .03145 L
.46677 .03145 L
Mistroke
.46923 .03145 L
.47181 .03145 L
.47418 .03145 L
.47549 .03145 L
.47618 .03145 L
.47691 .03145 L
.47762 .03145 L
.47826 .03145 L
.47951 .03145 L
.48067 .03145 L
.48189 .03145 L
.48293 .03145 L
.48407 .03145 L
.48531 .03145 L
.48663 .03145 L
.48901 .03145 L
.49141 .03145 L
.49369 .03145 L
.49795 .03145 L
.50762 .03145 L
.51788 .03145 L
.5363 .03146 L
.57407 .03147 L
.6143 .03148 L
.653 .03149 L
.69416 .03151 L
.73381 .03152 L
.77194 .03154 L
.81252 .03155 L
.85158 .03157 L
.8931 .03158 L
.9331 .0316 L
.97159 .03161 L
.97619 .03161 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.02846 .08429 L
.03279 .13708 L
.03527 .16077 L
.03754 .17763 L
.03879 .18502 L
.04015 .19148 L
.04143 .19615 L
.04262 .19929 L
.04376 .20132 L
.04498 .20249 L
.04614 .20274 L
.0472 .2023 L
.04843 .20107 L
.04913 .20008 L
.04978 .19899 L
.05224 .19358 L
.05718 .17881 L
.06244 .16091 L
.07382 .12532 L
.07941 .1113 L
.08454 .10052 L
.09417 .08512 L
.09923 .07912 L
.10458 .07405 L
.10945 .07038 L
.11406 .06761 L
.11937 .06512 L
.12422 .06341 L
.12878 .06221 L
.133 .06144 L
.1352 .06115 L
.13647 .06101 L
.13763 .06092 L
.13885 .06084 L
.14017 .06077 L
.14133 .06074 L
.14255 .06074 L
.14379 .06075 L
.14448 .06078 L
.14512 .0608 L
.1463 .06088 L
.14755 .06098 L
.14867 .0611 L
.14972 .06124 L
.1521 .06164 L
.15466 .06226 L
.15701 .06301 L
.15972 .06415 L
.16229 .06557 L
Mistroke
.16685 .0691 L
.17108 .07354 L
.17607 .07929 L
.17826 .08151 L
.18066 .0835 L
.18186 .08429 L
.18314 .08498 L
.18385 .08529 L
.18449 .08552 L
.18575 .08587 L
.18646 .086 L
.18711 .08608 L
.18782 .08613 L
.18858 .08613 L
.18985 .08603 L
.19058 .08593 L
.19125 .0858 L
.19248 .08549 L
.19376 .08508 L
.19605 .08415 L
.20122 .08146 L
.21984 .07084 L
.22941 .06687 L
.23477 .06524 L
.23962 .06411 L
.24417 .06334 L
.24673 .06303 L
.24794 .06291 L
.24908 .06282 L
.25016 .06275 L
.25115 .0627 L
.25224 .06266 L
.25342 .06264 L
.25455 .06264 L
.25577 .06265 L
.25693 .06269 L
.258 .06274 L
.25918 .06282 L
.26041 .06292 L
.26263 .06316 L
.26501 .0635 L
.26761 .06398 L
.27664 .06626 L
.28219 .06787 L
.28743 .06924 L
.28971 .06973 L
.29213 .07017 L
.2934 .07036 L
.29479 .07054 L
.29596 .07067 L
Mistroke
.29724 .07078 L
.29854 .07086 L
.29978 .07091 L
.30099 .07094 L
.30211 .07094 L
.3028 .07093 L
.30344 .07092 L
.30465 .07088 L
.30595 .07081 L
.30735 .07071 L
.30975 .07049 L
.31229 .07019 L
.31682 .06952 L
.33777 .06567 L
.34725 .06412 L
.35742 .06277 L
.36701 .06178 L
.37576 .06109 L
.38568 .06049 L
.39486 .06007 L
.41562 .0594 L
.4343 .05895 L
.45491 .05853 L
.4759 .05819 L
.49513 .05794 L
.53384 .05756 L
.57348 .05727 L
.61161 .05703 L
.65219 .05683 L
.69126 .05667 L
.73278 .05653 L
.77278 .05642 L
.81126 .05633 L
.8522 .05626 L
.89163 .0562 L
.92953 .05615 L
.96989 .0561 L
.97619 .05609 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.02846 .0843 L
.03279 .13731 L
.03523 .16099 L
.03754 .17884 L
.03881 .18679 L
.0402 .1939 L
.04145 .19898 L
.04262 .20266 L
.04376 .2053 L
.045 .20714 L
.0457 .20777 L
.04637 .20809 L
.04762 .20804 L
.04894 .20716 L
.05016 .20568 L
.0515 .20344 L
.05293 .20045 L
.06244 .1722 L
.07382 .13724 L
.08454 .11201 L
.09417 .09605 L
.09959 .08938 L
.10458 .08445 L
.10928 .0807 L
.11432 .07752 L
.11907 .07519 L
.1234 .07355 L
.12849 .07215 L
.13136 .07159 L
.13273 .07138 L
.13402 .07121 L
.13522 .07108 L
.13633 .07099 L
.13756 .07091 L
.13821 .07088 L
.13889 .07086 L
.14017 .07084 L
.14136 .07085 L
.14267 .07089 L
.1434 .07094 L
.14407 .07098 L
.14526 .07109 L
.14638 .07123 L
.1477 .07143 L
.14892 .07165 L
.15139 .07224 L
.15405 .07311 L
.15631 .07408 L
.15877 .07544 L
Mistroke
.1611 .07708 L
.16325 .07898 L
.16854 .08542 L
.17333 .09296 L
.17854 .10062 L
.18117 .10338 L
.18266 .10452 L
.18333 .10493 L
.18405 .10531 L
.18535 .10581 L
.18659 .10607 L
.18779 .10615 L
.1889 .10609 L
.1901 .10587 L
.19142 .10548 L
.19281 .10492 L
.1941 .10428 L
.19855 .10139 L
.20333 .09762 L
.21329 .0895 L
.21855 .08569 L
.22417 .08219 L
.22962 .07939 L
.23458 .07735 L
.23955 .07576 L
.24425 .07466 L
.24681 .07421 L
.24822 .07401 L
.24953 .07386 L
.25074 .07374 L
.25184 .07365 L
.25307 .07357 L
.25439 .07352 L
.25506 .0735 L
.25579 .07349 L
.25708 .07349 L
.2578 .0735 L
.25848 .07352 L
.25922 .07355 L
.26002 .07359 L
.26138 .07368 L
.2628 .07381 L
.26536 .0741 L
.26793 .0745 L
.27035 .07495 L
.27489 .07598 L
.28508 .07871 L
.28935 .07977 L
.29388 .08069 L
.29625 .08106 L
Mistroke
.2975 .08123 L
.29885 .08138 L
.30009 .0815 L
.30122 .08158 L
.30236 .08165 L
.30344 .0817 L
.30468 .08173 L
.30538 .08175 L
.30603 .08175 L
.30722 .08174 L
.30847 .08171 L
.3096 .08167 L
.31065 .08162 L
.31303 .08146 L
.31561 .08123 L
.31797 .08097 L
.32326 .08027 L
.34165 .07736 L
.35091 .07605 L
.36075 .07494 L
.36588 .07447 L
.37154 .07404 L
.38151 .07346 L
.38644 .07325 L
.39162 .07306 L
.40088 .07278 L
.42174 .07229 L
.45987 .07141 L
.50045 .0706 L
.53951 .06999 L
.58103 .06943 L
.62103 .06896 L
.65952 .06858 L
.70046 .06824 L
.73988 .06797 L
.77779 .06776 L
.81815 .06758 L
.85699 .06743 L
.89829 .06731 L
.93807 .06721 L
.97619 .06713 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.02846 .08428 L
.03279 .13721 L
.03523 .161 L
.03754 .17926 L
.0402 .19534 L
.04135 .20074 L
.04262 .20567 L
.04377 .20927 L
.04502 .21228 L
.04633 .21456 L
.04756 .21592 L
.04878 .21661 L
.04994 .21672 L
.05099 .21641 L
.05212 .21568 L
.05282 .21505 L
.05348 .21434 L
.05471 .21274 L
.05748 .20809 L
.06244 .19738 L
.07312 .17169 L
.08439 .14831 L
.09401 .13342 L
.09948 .12695 L
.10458 .12206 L
.10958 .11823 L
.11431 .11539 L
.11856 .11343 L
.12319 .11187 L
.12557 .11129 L
.12821 .11083 L
.12953 .11067 L
.13023 .1106 L
.13096 .11054 L
.13161 .1105 L
.13231 .11047 L
.13355 .11045 L
.1348 .11047 L
.13595 .11052 L
.13727 .11064 L
.13851 .11079 L
.13966 .11098 L
.14073 .11119 L
.14313 .11181 L
.14557 .11268 L
.1478 .11371 L
.15038 .11524 L
.15282 .1171 L
.15716 .12172 L
Mistroke
.15962 .12534 L
.16189 .12957 L
.16714 .14328 L
.17189 .15995 L
.17707 .17789 L
.17968 .18484 L
.18115 .18791 L
.18253 .19016 L
.18384 .19177 L
.18507 .19283 L
.18618 .19341 L
.18739 .19369 L
.1887 .19359 L
.18936 .19339 L
.19009 .19307 L
.19138 .19225 L
.19258 .19123 L
.19491 .18867 L
.19703 .18578 L
.20182 .17807 L
.21262 .15918 L
.22265 .14411 L
.23183 .1338 L
.23696 .12946 L
.24161 .12635 L
.24673 .12373 L
.24962 .12259 L
.25228 .12174 L
.25716 .12059 L
.25962 .12018 L
.26233 .11983 L
.26483 .11959 L
.26615 .11949 L
.26756 .11941 L
.26878 .11935 L
.26943 .11932 L
.27013 .1193 L
.27136 .11927 L
.27252 .11925 L
.27364 .11925 L
.27488 .11927 L
.27617 .1193 L
.27737 .11935 L
.27849 .1194 L
.27952 .11947 L
.28181 .11965 L
.2845 .11994 L
.28697 .12027 L
.29256 .12122 L
.30272 .1233 L
Mistroke
.31175 .12507 L
.31673 .12586 L
.32146 .12646 L
.32412 .12674 L
.32703 .12699 L
.33212 .12733 L
.33462 .12746 L
.33729 .12757 L
.34209 .12772 L
.35239 .12803 L
.35819 .12828 L
.36352 .1286 L
.3682 .12896 L
.37333 .12947 L
.38369 .13082 L
.40485 .13445 L
.42414 .13776 L
.43372 .13913 L
.44413 .14037 L
.46307 .14209 L
.48286 .14343 L
.50387 .14459 L
.52358 .14548 L
.54164 .14611 L
.561 .14659 L
.57117 .14678 L
.58186 .14695 L
.61999 .14738 L
.66057 .14774 L
.69964 .14811 L
.74115 .14863 L
.78116 .14927 L
.81964 .15003 L
.86058 .15096 L
.9 .15195 L
.93791 .15295 L
.97619 .15399 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.02605 .04952 L
.02846 .08178 L
.02962 .09468 L
.03072 .10495 L
.0317 .11249 L
.03279 .11907 L
.03398 .12438 L
.03524 .12805 L
.03641 .12992 L
.0375 .13058 L
.03879 .13027 L
.03997 .12919 L
.04062 .12833 L
.04132 .12722 L
.04262 .12482 L
.05302 .09944 L
.06244 .07891 L
.07302 .06245 L
.07883 .05595 L
.08429 .05113 L
.09404 .04494 L
.09953 .04248 L
.10458 .04072 L
.10928 .03942 L
.11432 .03833 L
.11907 .03753 L
.1234 .03698 L
.12849 .0365 L
.13136 .0363 L
.13402 .03616 L
.13633 .03607 L
.13765 .03603 L
.13889 .036 L
.14019 .03598 L
.14138 .03597 L
.14269 .03597 L
.14335 .03597 L
.14407 .03598 L
.14539 .036 L
.1466 .03603 L
.14794 .03607 L
.14935 .03613 L
.15173 .03625 L
.15434 .03645 L
.15667 .03669 L
.15917 .03701 L
.16368 .03783 L
.16894 .03921 L
.17455 .04094 L
Mistroke
.17727 .04168 L
.17861 .04198 L
.17984 .04222 L
.18094 .0424 L
.18214 .04257 L
.18335 .04269 L
.18463 .04278 L
.18531 .04281 L
.18595 .04283 L
.18716 .04284 L
.18846 .04282 L
.18919 .0428 L
.18987 .04276 L
.191 .04269 L
.19224 .04259 L
.19476 .04232 L
.20046 .04151 L
.2058 .04064 L
.21541 .03909 L
.2259 .0377 L
.23576 .03676 L
.24114 .03639 L
.24613 .03612 L
.25082 .03593 L
.25509 .03579 L
.26001 .03568 L
.26464 .0356 L
.30316 .03485 L
.31346 .03465 L
.32308 .03451 L
.33311 .03439 L
.33843 .03435 L
.34413 .03431 L
.34906 .03428 L
.35429 .03426 L
.36003 .03424 L
.36535 .03423 L
.36772 .03423 L
.37028 .03422 L
.37249 .03422 L
.37491 .03422 L
.37759 .03421 L
.37905 .03421 L
.38041 .03421 L
.38169 .03421 L
.38285 .03421 L
.3835 .03421 L
.38419 .03421 L
.38546 .03421 L
.38669 .03421 L
Mistroke
.38781 .03421 L
.38911 .03421 L
.39034 .03421 L
.39253 .03421 L
.39491 .03421 L
.40031 .03422 L
.40531 .03422 L
.42635 .03425 L
.4655 .03432 L
.5071 .03439 L
.54719 .03445 L
.58576 .03451 L
.62678 .03458 L
.66629 .03464 L
.70428 .0347 L
.74472 .03476 L
.78365 .03482 L
.82503 .03488 L
.8649 .03494 L
.90325 .035 L
.94405 .03507 L
.97619 .03512 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.02605 .04952 L
.02846 .08173 L
.02962 .09453 L
.03072 .10462 L
.0317 .11189 L
.03279 .11805 L
.03398 .12273 L
.03524 .12559 L
.03641 .12661 L
.0375 .12644 L
.03879 .12515 L
.03997 .12319 L
.04262 .11704 L
.0529 .08802 L
.06244 .06629 L
.06744 .05768 L
.07277 .05029 L
.07869 .04389 L
.08405 .03939 L
.08912 .03605 L
.09462 .03322 L
.09981 .03115 L
.10458 .02965 L
.10928 .02848 L
.11432 .02749 L
.11907 .02677 L
.1234 .02625 L
.12849 .02577 L
.13117 .02558 L
.13402 .0254 L
.1365 .02527 L
.13924 .02515 L
.14174 .02507 L
.14407 .025 L
.14642 .02496 L
.14766 .02494 L
.14898 .02493 L
.14965 .02492 L
.15038 .02492 L
.1517 .02492 L
.15298 .02492 L
.15416 .02493 L
.15527 .02494 L
.1563 .02495 L
.15744 .02497 L
.15866 .025 L
.16114 .02507 L
.16341 .02516 L
.17424 .0258 L
Mistroke
.17695 .02597 L
.1795 .0261 L
.18179 .02618 L
.18308 .02621 L
.18427 .02624 L
.18538 .02625 L
.18641 .02626 L
.18754 .02625 L
.18875 .02625 L
.19003 .02623 L
.19123 .02621 L
.19348 .02615 L
.19819 .02599 L
.20329 .02577 L
.21316 .02531 L
.22403 .02488 L
.22896 .02473 L
.23426 .02459 L
.23884 .0245 L
.24384 .02441 L
.24919 .02435 L
.25211 .02432 L
.25482 .0243 L
.25737 .02429 L
.25968 .02428 L
.26096 .02427 L
.26235 .02427 L
.26487 .02426 L
.26599 .02426 L
.26718 .02426 L
.26849 .02426 L
.2697 .02426 L
.27082 .02426 L
.27188 .02426 L
.27304 .02426 L
.27428 .02426 L
.27492 .02426 L
.27563 .02426 L
.27704 .02426 L
.27835 .02426 L
.27957 .02426 L
.28079 .02426 L
.2819 .02426 L
.28318 .02426 L
.28439 .02426 L
.28503 .02426 L
.28573 .02425 L
.28715 .02425 L
.28847 .02425 L
.28971 .02425 L
Mistroke
.29249 .02424 L
.29548 .02424 L
.30089 .02422 L
.30584 .02419 L
.3263 .02407 L
.33626 .02402 L
.34529 .02398 L
.35449 .02395 L
.36429 .02393 L
.37497 .02391 L
.38502 .02389 L
.40511 .02387 L
.42359 .02386 L
.44403 .02385 L
.4631 .02384 L
.48144 .02383 L
.50109 .02383 L
.52235 .02382 L
.54247 .02382 L
.5607 .02382 L
.58082 .02382 L
.60061 .02382 L
.62162 .02381 L
.64098 .02381 L
.66185 .02381 L
.6819 .02381 L
.69198 .02381 L
.70301 .02381 L
.71329 .02381 L
.72263 .02381 L
.72781 .02381 L
.73341 .02381 L
.73871 .02381 L
.74126 .02381 L
.74359 .02381 L
.74583 .02381 L
.74827 .02381 L
.7496 .02381 L
.75084 .02381 L
.7521 .02381 L
.75329 .02381 L
.7544 .02381 L
.7556 .02381 L
.75669 .02381 L
.75769 .02381 L
.75877 .02381 L
.75996 .02381 L
.76121 .02381 L
.76236 .02381 L
.76365 .02381 L
Mistroke
.76505 .02381 L
.76759 .02381 L
.77234 .02381 L
.77789 .02381 L
.78301 .02381 L
.80173 .02381 L
.82235 .02381 L
.86262 .02381 L
.90138 .02381 L
.94259 .02381 L
.97619 .02381 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .02139 L
.02729 .02137 L
.02846 .02119 L
.03053 .02075 L
.03279 .02023 L
.04262 .0183 L
.04762 .01758 L
.05293 .01698 L
.05746 .01658 L
.06244 .01623 L
.06792 .01594 L
.07293 .01573 L
.07871 .01554 L
.0842 .01541 L
.08925 .01532 L
.09394 .01525 L
.09909 .0152 L
.10458 .01515 L
.10994 .01511 L
.11487 .01509 L
.12028 .01507 L
.12599 .01505 L
.13096 .01504 L
.13561 .01504 L
.1407 .01503 L
.14616 .01502 L
.14872 .01502 L
.15145 .01502 L
.15634 .01502 L
.15905 .01502 L
.1616 .01502 L
.16439 .01502 L
.1674 .01502 L
.18752 .01501 L
.20717 .01501 L
.21255 .01501 L
.2183 .01501 L
.22369 .01501 L
.22866 .01501 L
.23379 .01501 L
.23643 .01501 L
.23934 .01501 L
.2417 .01501 L
.24424 .01501 L
.24564 .01501 L
.24692 .01501 L
.24813 .01501 L
.24942 .01501 L
Mistroke
.25068 .01501 L
.25183 .01501 L
.25297 .01501 L
.25405 .01501 L
.25532 .01501 L
.25648 .01501 L
.25775 .01501 L
.2584 .01501 L
.2591 .01501 L
.2614 .01501 L
.26385 .01501 L
.26829 .01501 L
.27849 .01501 L
.28386 .01501 L
.28681 .01501 L
.28957 .01501 L
.29196 .01501 L
.2932 .01501 L
.29454 .01501 L
.29594 .01501 L
.2967 .01501 L
.29741 .01501 L
.29868 .01501 L
.29939 .01501 L
.30003 .01501 L
.30128 .01501 L
.30242 .01501 L
.30368 .01501 L
.30501 .01501 L
.30724 .01501 L
.3097 .01501 L
.31493 .01501 L
.31989 .01501 L
.32919 .01501 L
.33932 .01501 L
.35009 .01501 L
.35954 .01501 L
.36998 .01501 L
.37947 .01501 L
.38839 .01501 L
.42704 .01501 L
.44706 .01501 L
.46815 .01501 L
.48787 .01501 L
.50623 .01501 L
.54524 .01501 L
.58671 .01501 L
.62666 .01501 L
.66509 .01501 L
.70598 .01501 L
Mistroke
.74535 .01501 L
.7832 .01501 L
.82351 .01501 L
.8623 .01501 L
.90355 .01501 L
.94328 .01501 L
.97619 .01501 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.02605 .04958 L
.02846 .08238 L
.02962 .09577 L
.03072 .10658 L
.0317 .11458 L
.03279 .12157 L
.03398 .12711 L
.03524 .13073 L
.03641 .1323 L
.0375 .13246 L
.03879 .13139 L
.03997 .12949 L
.04132 .1265 L
.04262 .12312 L
.05221 .09385 L
.06244 .0684 L
.06792 .05835 L
.07289 .05106 L
.07794 .04513 L
.08259 .04077 L
.08803 .03672 L
.09391 .03337 L
.0991 .0311 L
.10458 .02925 L
.10954 .02795 L
.11406 .02702 L
.11928 .02618 L
.12422 .02557 L
.12878 .02513 L
.133 .02482 L
.13763 .02456 L
.13997 .02446 L
.14255 .02437 L
.1449 .02431 L
.14747 .02425 L
.14876 .02423 L
.14948 .02422 L
.15015 .02422 L
.15146 .02421 L
.15264 .0242 L
.15377 .0242 L
.15495 .02421 L
.15597 .02422 L
.15708 .02423 L
.15828 .02424 L
.15957 .02427 L
.1619 .02432 L
.16457 .02441 L
.16749 .02454 L
Mistroke
.1728 .02481 L
.17758 .02505 L
.17889 .0251 L
.18028 .02514 L
.18147 .02517 L
.18275 .0252 L
.18407 .02522 L
.1853 .02523 L
.18605 .02523 L
.18676 .02523 L
.18739 .02522 L
.18808 .02522 L
.18935 .02521 L
.18999 .0252 L
.19069 .02518 L
.1931 .02513 L
.19793 .02498 L
.20247 .02481 L
.2127 .0244 L
.22345 .02404 L
.23312 .02382 L
.23859 .02373 L
.24121 .02369 L
.24367 .02367 L
.24593 .02364 L
.24837 .02363 L
.2504 .02361 L
.25263 .0236 L
.25505 .02359 L
.25637 .02359 L
.25761 .02359 L
.25877 .02359 L
.25982 .02359 L
.26104 .02359 L
.26219 .02359 L
.26333 .02359 L
.26455 .02359 L
.26571 .02359 L
.26677 .02359 L
.26923 .0236 L
.27183 .02361 L
.28208 .02366 L
.28632 .02367 L
.28866 .02368 L
.29087 .02369 L
.29212 .02369 L
.29278 .02369 L
.29348 .02369 L
.29471 .02369 L
.29585 .02369 L
Mistroke
.29699 .02369 L
.29806 .02369 L
.29923 .02369 L
.30049 .02369 L
.30182 .02369 L
.30303 .02368 L
.30574 .02367 L
.3106 .02365 L
.32164 .02358 L
.34173 .02344 L
.3511 .02339 L
.36099 .02334 L
.37184 .0233 L
.38182 .02328 L
.39131 .02326 L
.40147 .02324 L
.41981 .02322 L
.43 .02321 L
.44107 .0232 L
.45064 .02319 L
.46119 .02319 L
.48098 .02318 L
.49182 .02318 L
.50199 .02318 L
.52049 .02317 L
.5407 .02317 L
.56076 .02317 L
.58186 .02317 L
.62244 .02316 L
.66151 .02316 L
.70303 .02316 L
.74303 .02316 L
.78151 .02316 L
.82245 .02316 L
.86188 .02316 L
.89978 .02316 L
.94014 .02315 L
.97619 .02315 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.02846 .08325 L
.03068 .10933 L
.03279 .12848 L
.03398 .1368 L
.03527 .14378 L
.03645 .14838 L
.03754 .15126 L
.03871 .15308 L
.04 .15373 L
.04065 .1536 L
.04135 .15316 L
.04262 .15168 L
.04393 .14939 L
.04516 .14673 L
.04793 .13945 L
.05297 .12426 L
.06244 .09735 L
.06795 .08458 L
.07314 .07461 L
.08284 .06062 L
.08828 .05491 L
.09328 .05073 L
.09878 .04709 L
.10458 .04412 L
.10954 .04216 L
.11406 .04073 L
.11928 .03945 L
.12422 .03852 L
.12878 .03788 L
.133 .03744 L
.1352 .03726 L
.13763 .03711 L
.13885 .03705 L
.14017 .03699 L
.14141 .03695 L
.14255 .03692 L
.14383 .0369 L
.14503 .03689 L
.14612 .03689 L
.14729 .0369 L
.14857 .03692 L
.14922 .03694 L
.14993 .03696 L
.15118 .03701 L
.15235 .03707 L
.15465 .03722 L
.15675 .0374 L
.15917 .03769 L
.16148 .03803 L
Mistroke
.16661 .03913 L
.17138 .04053 L
.17657 .04216 L
.1793 .04287 L
.18079 .04319 L
.18218 .04343 L
.18345 .04361 L
.18481 .04375 L
.18559 .04381 L
.18632 .04386 L
.18698 .04388 L
.1877 .0439 L
.18898 .0439 L
.18962 .04389 L
.19033 .04387 L
.19159 .0438 L
.19277 .04372 L
.19528 .04347 L
.19757 .04317 L
.20274 .04236 L
.22136 .03918 L
.23119 .0379 L
.24032 .03706 L
.24557 .0367 L
.25034 .03646 L
.25298 .03635 L
.25585 .03625 L
.25835 .03618 L
.26103 .03611 L
.2636 .03607 L
.26594 .03603 L
.27052 .03597 L
.28095 .03588 L
.28612 .03582 L
.29176 .03574 L
.302 .03554 L
.32137 .03511 L
.33165 .03492 L
.34275 .03475 L
.34789 .0347 L
.3533 .03464 L
.36298 .03457 L
.37206 .03453 L
.38199 .03449 L
.39225 .03446 L
.40158 .03444 L
.41247 .03442 L
.42252 .0344 L
.44168 .03438 L
.45177 .03437 L
Mistroke
.46247 .03436 L
.47189 .03436 L
.47718 .03435 L
.48202 .03435 L
.48651 .03435 L
.4914 .03435 L
.49603 .03435 L
.50032 .03435 L
.5054 .03435 L
.50827 .03435 L
.5109 .03435 L
.51321 .03435 L
.51452 .03435 L
.51574 .03435 L
.51704 .03435 L
.51821 .03435 L
.51887 .03435 L
.51957 .03435 L
.52086 .03435 L
.52201 .03435 L
.52309 .03435 L
.52427 .03435 L
.52555 .03435 L
.52815 .03435 L
.53053 .03435 L
.53489 .03435 L
.53947 .03435 L
.54903 .03435 L
.55923 .03435 L
.5776 .03435 L
.61912 .03436 L
.65912 .03438 L
.69761 .03439 L
.73854 .0344 L
.77797 .03441 L
.81588 .03442 L
.85623 .03443 L
.89508 .03444 L
.93638 .03445 L
.97616 .03446 L
.97619 .03446 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05244 L
.02846 .05537 L
.02954 .05595 L
.03053 .05555 L
.03163 .05455 L
.03279 .05317 L
.04262 .04019 L
.05205 .03126 L
.05742 .02767 L
.06244 .02507 L
.06788 .02289 L
.07305 .0213 L
.07768 .02018 L
.08274 .01923 L
.08822 .01844 L
.09407 .0178 L
.09958 .01735 L
.10458 .01704 L
.10945 .01681 L
.1146 .01662 L
.119 .01649 L
.12383 .01638 L
.12902 .01629 L
.13459 .01621 L
.13985 .01616 L
.14465 .01613 L
.14945 .0161 L
.15188 .01609 L
.15456 .01608 L
.15684 .01608 L
.15803 .01607 L
.15929 .01607 L
.1604 .01607 L
.16161 .01607 L
.16263 .01607 L
.16373 .01607 L
.16446 .01607 L
.16513 .01607 L
.16578 .01607 L
.16646 .01607 L
.16763 .01607 L
.16893 .01607 L
.16965 .01607 L
.17031 .01607 L
.1718 .01607 L
.17319 .01607 L
.17449 .01607 L
Mistroke
.17568 .01607 L
.17694 .01607 L
.17767 .01607 L
.17835 .01607 L
.17962 .01607 L
.18084 .01607 L
.18196 .01607 L
.18319 .01607 L
.18449 .01607 L
.18705 .01606 L
.18947 .01606 L
.19399 .01605 L
.20417 .01603 L
.2129 .01602 L
.22252 .01601 L
.22751 .016 L
.2322 .016 L
.23714 .01599 L
.24246 .01599 L
.24716 .01599 L
.25209 .01599 L
.2563 .01599 L
.2609 .01599 L
.30151 .01598 L
.32028 .01598 L
.34061 .01598 L
.35174 .01597 L
.36199 .01597 L
.3718 .01597 L
.38216 .01597 L
.39162 .01597 L
.40177 .01597 L
.41129 .01597 L
.4201 .01597 L
.43025 .01597 L
.43561 .01597 L
.44131 .01597 L
.44624 .01597 L
.45087 .01597 L
.45595 .01597 L
.4588 .01597 L
.46143 .01597 L
.4627 .01597 L
.4639 .01597 L
.465 .01597 L
.46616 .01597 L
.46742 .01597 L
.46858 .01597 L
.46983 .01597 L
.47055 .01597 L
Mistroke
.47121 .01597 L
.47239 .01597 L
.47351 .01597 L
.47451 .01597 L
.4756 .01597 L
.47805 .01597 L
.48033 .01597 L
.48558 .01597 L
.49034 .01597 L
.50102 .01597 L
.5411 .01597 L
.57968 .01597 L
.6207 .01597 L
.66021 .01597 L
.6982 .01597 L
.71772 .01597 L
.73864 .01597 L
.7599 .01597 L
.78002 .01597 L
.78969 .01597 L
.79995 .01597 L
.80956 .01597 L
.81837 .01597 L
.82775 .01597 L
.83258 .01597 L
.83786 .01597 L
.84217 .01597 L
.84677 .01597 L
.85163 .01597 L
.85378 .01597 L
.85614 .01597 L
.85874 .01597 L
.86015 .01597 L
.86148 .01597 L
.86272 .01597 L
.86385 .01597 L
.86516 .01597 L
.8664 .01597 L
.8671 .01597 L
.86773 .01597 L
.86847 .01597 L
.86915 .01597 L
.87038 .01597 L
.87171 .01597 L
.87318 .01597 L
.87473 .01597 L
.8775 .01597 L
.88248 .01597 L
.88712 .01597 L
.89766 .01597 L
Mistroke
.90815 .01597 L
.91807 .01597 L
.93664 .01597 L
.97504 .01597 L
.97619 .01597 L
Mfstroke
.53 1 0 r
.02381 .01472 m
.02846 .08426 L
.03279 .13673 L
.03527 .16006 L
.03754 .1766 L
.03879 .18385 L
.04015 .19024 L
.04143 .19494 L
.04262 .19819 L
.04376 .20041 L
.04498 .20189 L
.04614 .20253 L
.0472 .20252 L
.04843 .20189 L
.04913 .20127 L
.04978 .20054 L
.05224 .19665 L
.05483 .19111 L
.05718 .18525 L
.06244 .17084 L
.07287 .14328 L
.07835 .13103 L
.08414 .12008 L
.08922 .1121 L
.09479 .1049 L
.10458 .09557 L
.10982 .09202 L
.11478 .08941 L
.11924 .08762 L
.12409 .08619 L
.12659 .08565 L
.12936 .08521 L
.13075 .08504 L
.13148 .08497 L
.13224 .08491 L
.13292 .08486 L
.13366 .08482 L
.13495 .08477 L
.13627 .08477 L
.13747 .08479 L
.13813 .08482 L
.13885 .08486 L
.14016 .08496 L
.14138 .08509 L
.14268 .08527 L
.145 .0857 L
.14753 .08636 L
.14994 .0872 L
.15209 .08815 L
.15444 .08946 L
Mistroke
.15699 .09128 L
.1597 .0938 L
.16226 .09688 L
.16458 .10037 L
.17349 .11959 L
.17584 .1249 L
.17835 .12977 L
.17958 .13173 L
.18073 .13332 L
.18178 .13452 L
.18289 .13555 L
.18409 .13638 L
.18519 .13691 L
.18638 .13723 L
.18769 .13731 L
.18899 .13713 L
.18973 .13692 L
.1904 .13667 L
.19164 .13607 L
.19294 .13526 L
.19736 .13152 L
.20218 .12636 L
.2131 .11398 L
.22301 .10444 L
.22787 .10066 L
.23312 .09722 L
.23767 .09478 L
.24266 .0926 L
.24796 .0908 L
.25357 .0894 L
.25877 .08844 L
.26362 .08776 L
.3025 .08278 L
.31266 .0817 L
.31802 .08124 L
.32371 .08083 L
.32868 .08054 L
.33416 .08027 L
.34383 .07993 L
.34873 .0798 L
.3539 .07971 L
.35832 .07965 L
.36082 .07962 L
.36315 .0796 L
.36445 .07959 L
.36586 .07958 L
.3672 .07958 L
.36843 .07957 L
.36954 .07957 L
.37076 .07957 L
Mistroke
.37203 .07957 L
.37323 .07957 L
.37389 .07957 L
.37462 .07957 L
.37594 .07957 L
.37722 .07958 L
.37842 .07958 L
.38112 .0796 L
.384 .07962 L
.38936 .07967 L
.39429 .07973 L
.40543 .0799 L
.4256 .0803 L
.46511 .08111 L
.5031 .08184 L
.54354 .08262 L
.58247 .08334 L
.62385 .08409 L
.66372 .0848 L
.70207 .08547 L
.74287 .08618 L
.78216 .08686 L
.81993 .08753 L
.86015 .08824 L
.89886 .08894 L
.94002 .08969 L
.97619 .09035 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.02605 .04936 L
.02729 .06616 L
.02846 .07956 L
.02954 .08934 L
.03072 .09679 L
.0318 .10086 L
.03279 .10268 L
.03396 .103 L
.03506 .102 L
.03626 .09995 L
.03756 .09705 L
.04262 .08339 L
.0521 .06052 L
.05746 .05085 L
.06244 .04374 L
.0679 .03765 L
.07373 .0327 L
.07935 .02908 L
.08445 .02656 L
.08943 .02465 L
.09481 .02305 L
.0999 .02189 L
.10458 .02105 L
.10928 .02039 L
.11432 .01984 L
.11907 .01944 L
.1234 .01914 L
.12849 .01888 L
.13402 .01866 L
.13924 .01851 L
.14407 .01841 L
.1487 .01833 L
.15131 .01831 L
.15369 .01828 L
.1558 .01827 L
.15699 .01826 L
.1581 .01826 L
.15927 .01826 L
.16034 .01825 L
.16157 .01825 L
.16273 .01825 L
.16392 .01825 L
.16523 .01826 L
.16589 .01826 L
.1666 .01826 L
.16788 .01826 L
.17262 .01828 L
.17549 .0183 L
.17691 .0183 L
Mistroke
.17822 .01831 L
.1794 .01831 L
.18067 .01831 L
.18139 .01831 L
.18207 .01831 L
.18333 .01831 L
.1845 .01831 L
.18575 .0183 L
.18693 .0183 L
.188 .0183 L
.19312 .01827 L
.20345 .01819 L
.21242 .01812 L
.22194 .01807 L
.22666 .01804 L
.23188 .01802 L
.23662 .01801 L
.24106 .018 L
.24361 .01799 L
.24628 .01799 L
.2486 .01799 L
.25106 .01798 L
.25246 .01798 L
.25373 .01798 L
.25502 .01798 L
.25621 .01798 L
.25687 .01798 L
.2576 .01798 L
.25833 .01798 L
.25911 .01798 L
.25979 .01798 L
.26052 .01798 L
.26183 .01798 L
.26305 .01798 L
.26374 .01798 L
.26439 .01798 L
.26711 .01798 L
.26946 .01798 L
.27199 .01798 L
.27738 .01799 L
.28305 .01799 L
.28547 .01799 L
.28806 .01799 L
.28954 .01799 L
.29089 .01799 L
.29155 .01799 L
.29225 .01799 L
.29354 .01799 L
.29469 .01799 L
.29597 .01799 L
Mistroke
.29661 .01799 L
.2973 .01799 L
.29854 .01799 L
.29978 .01799 L
.30096 .01799 L
.30316 .01799 L
.3082 .01799 L
.31276 .01799 L
.32298 .01798 L
.34138 .01796 L
.35074 .01795 L
.36064 .01795 L
.37149 .01794 L
.38146 .01794 L
.40112 .01793 L
.41945 .01793 L
.4381 .01793 L
.45838 .01792 L
.47964 .01792 L
.49976 .01792 L
.51916 .01792 L
.54057 .01792 L
.57985 .01792 L
.59921 .01792 L
.62007 .01792 L
.66123 .01791 L
.70088 .01791 L
.73901 .01791 L
.77959 .01791 L
.81865 .01791 L
.86017 .01791 L
.90017 .01791 L
.93866 .01791 L
.97619 .01791 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.02605 .04937 L
.02729 .06619 L
.02846 .07968 L
.02954 .08964 L
.03072 .09737 L
.0318 .10177 L
.03279 .10392 L
.03396 .1046 L
.03506 .10391 L
.03626 .10212 L
.03756 .09944 L
.04262 .08613 L
.0521 .06301 L
.05746 .05309 L
.06244 .04574 L
.0679 .03942 L
.07373 .03425 L
.07935 .03047 L
.08445 .02782 L
.08943 .02581 L
.09481 .02412 L
.0999 .02289 L
.10458 .02201 L
.10928 .02131 L
.11432 .02072 L
.11907 .02029 L
.1234 .01998 L
.12849 .0197 L
.13402 .01947 L
.13924 .01931 L
.14176 .01925 L
.14407 .0192 L
.1487 .01913 L
.15113 .01911 L
.15237 .0191 L
.15369 .01909 L
.15487 .01908 L
.15593 .01908 L
.157 .01907 L
.15801 .01907 L
.15919 .01907 L
.16028 .01907 L
.16147 .01907 L
.16273 .01908 L
.16401 .01908 L
.16518 .01909 L
.1678 .01911 L
.17254 .01915 L
.17519 .01918 L
Mistroke
.17659 .01919 L
.17808 .0192 L
.17951 .01921 L
.18081 .01921 L
.18211 .01922 L
.18333 .01922 L
.1845 .01922 L
.18575 .01922 L
.18693 .01921 L
.188 .01921 L
.19063 .01919 L
.19312 .01918 L
.20345 .01907 L
.21224 .01897 L
.22194 .01889 L
.23162 .01882 L
.23692 .0188 L
.24189 .01878 L
.24652 .01877 L
.25076 .01876 L
.25299 .01876 L
.25542 .01875 L
.26032 .01875 L
.26286 .01875 L
.26562 .01875 L
.26805 .01875 L
.27062 .01874 L
.27549 .01874 L
.27997 .01874 L
.28479 .01874 L
.28744 .01874 L
.28996 .01874 L
.29292 .01874 L
.29563 .01874 L
.30093 .01874 L
.30551 .01873 L
.31057 .01873 L
.32082 .01871 L
.33923 .01869 L
.34864 .01868 L
.35855 .01867 L
.36942 .01867 L
.3794 .01866 L
.38893 .01866 L
.39912 .01866 L
.41748 .01865 L
.4277 .01865 L
.4388 .01865 L
.44927 .01865 L
.45894 .01865 L
Mistroke
.46862 .01865 L
.47768 .01865 L
.48762 .01865 L
.49831 .01865 L
.50843 .01865 L
.51946 .01865 L
.52988 .01865 L
.53956 .01865 L
.55013 .01865 L
.56009 .01865 L
.56904 .01865 L
.57407 .01865 L
.57871 .01865 L
.58341 .01865 L
.586 .01865 L
.58845 .01865 L
.59073 .01865 L
.59321 .01865 L
.59545 .01865 L
.59755 .01865 L
.60002 .01865 L
.60134 .01865 L
.60275 .01865 L
.60416 .01865 L
.60487 .01865 L
.60564 .01865 L
.6063 .01865 L
.60701 .01865 L
.60828 .01865 L
.60957 .01865 L
.61029 .01865 L
.61096 .01865 L
.61219 .01865 L
.61349 .01865 L
.61574 .01865 L
.61821 .01865 L
.63931 .01865 L
.64931 .01865 L
.65857 .01865 L
.66319 .01865 L
.66811 .01865 L
.67092 .01865 L
.6723 .01865 L
.67357 .01865 L
.67472 .01865 L
.67594 .01865 L
.67716 .01865 L
.67786 .01865 L
.6785 .01865 L
.67968 .01865 L
Mistroke
.68096 .01865 L
.68217 .01865 L
.68329 .01865 L
.6854 .01865 L
.68764 .01865 L
.69004 .01865 L
.69229 .01865 L
.69742 .01865 L
.70238 .01865 L
.70779 .01865 L
.71766 .01865 L
.72726 .01865 L
.73618 .01865 L
.75669 .01865 L
.77529 .01865 L
.81535 .01865 L
.85389 .01864 L
.89488 .01864 L
.93435 .01864 L
.97231 .01864 L
.97619 .01864 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.02846 .08431 L
.03279 .13727 L
.03527 .16104 L
.03754 .17789 L
.03879 .18521 L
.04015 .19153 L
.04143 .196 L
.04262 .19891 L
.04376 .20066 L
.04498 .2015 L
.04614 .2014 L
.0472 .20062 L
.04843 .199 L
.04913 .19778 L
.04978 .19647 L
.05224 .19028 L
.06244 .15531 L
.07295 .12134 L
.08284 .09744 L
.08832 .08746 L
.09424 .07883 L
.09959 .07269 L
.10458 .0681 L
.10955 .06446 L
.11408 .06181 L
.11912 .05949 L
.12452 .05761 L
.1297 .05632 L
.13263 .05578 L
.13534 .05539 L
.1377 .05515 L
.13904 .05504 L
.1403 .05496 L
.14095 .05493 L
.14163 .05491 L
.14284 .05488 L
.14415 .05487 L
.14489 .05488 L
.14558 .05489 L
.14686 .05494 L
.1475 .05497 L
.14821 .05502 L
.14946 .05512 L
.15063 .05524 L
.15327 .05562 L
.15475 .05591 L
.15611 .05622 L
.15854 .05692 L
.1612 .05794 L
Mistroke
.16371 .05918 L
.16604 .06061 L
.17498 .06821 L
.17967 .07198 L
.18204 .07335 L
.18338 .07394 L
.18463 .07435 L
.18535 .07454 L
.18602 .07468 L
.18729 .07485 L
.18801 .0749 L
.18866 .07492 L
.18938 .0749 L
.19015 .07485 L
.1914 .0747 L
.19256 .07449 L
.19384 .07419 L
.19522 .07379 L
.20043 .07181 L
.20519 .06962 L
.2142 .0654 L
.22381 .06159 L
.22896 .05998 L
.23364 .05879 L
.23834 .05786 L
.24277 .05721 L
.24529 .05696 L
.24656 .05685 L
.24795 .05677 L
.24914 .05671 L
.25042 .05668 L
.25162 .05666 L
.25272 .05667 L
.25338 .05668 L
.25409 .0567 L
.25536 .05676 L
.25607 .0568 L
.25673 .05685 L
.25825 .05699 L
.26077 .05731 L
.26349 .05778 L
.27297 .06036 L
.28311 .06367 L
.28611 .06447 L
.28894 .06509 L
.29148 .06551 L
.29291 .06569 L
.29424 .06582 L
.29547 .06591 L
.29663 .06596 L
Mistroke
.2979 .06599 L
.29861 .06599 L
.29926 .06599 L
.30057 .06595 L
.30131 .06592 L
.302 .06588 L
.30325 .06579 L
.30459 .06567 L
.30727 .06535 L
.30973 .06499 L
.31529 .06398 L
.32536 .06181 L
.34419 .05802 L
.35393 .0565 L
.36303 .05539 L
.373 .05444 L
.38369 .05368 L
.39388 .05313 L
.40495 .05269 L
.41452 .05238 L
.42507 .05211 L
.44486 .05172 L
.46588 .05142 L
.48524 .05122 L
.5061 .05105 L
.52616 .05094 L
.54726 .05084 L
.58539 .0507 L
.62597 .05059 L
.66503 .05051 L
.70655 .05044 L
.74655 .05039 L
.78504 .05035 L
.82598 .05031 L
.8654 .05028 L
.90331 .05026 L
.94367 .05024 L
.97619 .05022 L
Mfstroke
.435 1 0 r
.02381 .01472 m
.02846 .08425 L
.03279 .13688 L
.03523 .1603 L
.03754 .1781 L
.03881 .18618 L
.0402 .19358 L
.04145 .19911 L
.04262 .20334 L
.04386 .20692 L
.045 .20941 L
.04626 .21139 L
.04696 .21216 L
.04762 .21268 L
.04894 .21318 L
.05016 .21307 L
.05086 .21278 L
.0515 .21239 L
.05223 .2118 L
.05293 .21111 L
.05531 .20794 L
.0575 .20415 L
.06244 .19369 L
.07214 .17113 L
.08253 .14984 L
.0885 .13995 L
.09393 .13244 L
.09946 .12617 L
.10458 .12149 L
.1092 .11809 L
.11429 .11514 L
.11942 .11296 L
.12222 .11206 L
.12486 .11141 L
.12721 .11098 L
.12839 .11082 L
.12968 .11068 L
.13079 .1106 L
.13197 .11054 L
.13309 .11052 L
.1341 .11054 L
.13538 .11059 L
.13656 .11069 L
.13786 .11083 L
.13923 .11105 L
.14153 .11154 L
.14407 .1123 L
.14656 .11332 L
.14928 .11477 L
.15185 .11657 L
Mistroke
.15423 .11868 L
.15873 .1243 L
.16124 .1287 L
.16351 .1337 L
.1744 .17041 L
.17671 .17832 L
.17918 .18543 L
.18059 .18872 L
.18188 .19119 L
.18318 .19315 L
.18441 .19453 L
.18554 .19543 L
.18674 .19598 L
.18777 .19616 L
.1889 .19607 L
.19012 .19566 L
.19143 .19489 L
.19266 .19389 L
.19379 .19277 L
.19862 .18632 L
.20369 .17784 L
.21377 .16027 L
.22453 .14446 L
.22986 .13827 L
.2349 .13344 L
.2398 .12962 L
.24431 .12682 L
.2486 .12472 L
.25313 .12304 L
.25768 .12179 L
.26269 .12079 L
.26792 .12001 L
.27288 .11943 L
.27733 .11902 L
.27984 .11883 L
.28217 .1187 L
.28337 .11865 L
.28465 .1186 L
.28587 .11857 L
.28699 .11854 L
.28822 .11853 L
.28892 .11852 L
.28958 .11852 L
.2909 .11853 L
.29163 .11854 L
.2923 .11855 L
.29369 .11858 L
.29496 .11861 L
.29784 .11872 L
.30308 .119 L
Mistroke
.34245 .12082 L
.3473 .12095 L
.35259 .12113 L
.35759 .12134 L
.36222 .1216 L
.37098 .12227 L
.3803 .12327 L
.39973 .12617 L
.42061 .12976 L
.46221 .13558 L
.5023 .13984 L
.54087 .14346 L
.58189 .14672 L
.6214 .14951 L
.65939 .15204 L
.69984 .15467 L
.73877 .15722 L
.78015 .15998 L
.82001 .16273 L
.85836 .16546 L
.89916 .16844 L
.93845 .17135 L
.97619 .17415 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.02846 .08334 L
.03068 .10976 L
.03279 .12967 L
.03398 .13866 L
.03527 .14656 L
.03645 .15216 L
.03754 .15607 L
.03871 .15908 L
.04 .16108 L
.04065 .16163 L
.04135 .16191 L
.04262 .16171 L
.04393 .16068 L
.04516 .1591 L
.0465 .15683 L
.04793 .15393 L
.05297 .14141 L
.06244 .11652 L
.06791 .10401 L
.07382 .09258 L
.07904 .08426 L
.08454 .07708 L
.08952 .07181 L
.09498 .06715 L
.10458 .06122 L
.10982 .05894 L
.11478 .05728 L
.11924 .05612 L
.12409 .05518 L
.12659 .05481 L
.12936 .05449 L
.13075 .05435 L
.13224 .05424 L
.13354 .05416 L
.13422 .05412 L
.13495 .05409 L
.13565 .05406 L
.13628 .05404 L
.13751 .05402 L
.13817 .05401 L
.13889 .05401 L
.1402 .05402 L
.14141 .05405 L
.1427 .0541 L
.1438 .05416 L
.145 .05425 L
.1475 .05448 L
.14891 .05466 L
.15022 .05486 L
Mistroke
.15261 .0553 L
.15517 .05592 L
.15768 .05671 L
.16004 .05766 L
.16445 .06009 L
.17462 .0688 L
.17709 .07083 L
.17973 .07255 L
.18125 .07329 L
.18264 .0738 L
.1833 .07399 L
.18403 .07416 L
.18534 .07437 L
.18659 .07446 L
.18776 .07444 L
.18904 .07434 L
.18976 .07424 L
.19042 .07413 L
.19304 .07349 L
.1958 .07257 L
.20546 .06834 L
.21515 .064 L
.22395 .06073 L
.23352 .05806 L
.23877 .05698 L
.24373 .05617 L
.24832 .05559 L
.25255 .05518 L
.2572 .05483 L
.26211 .05456 L
.28194 .05367 L
.30005 .05285 L
.31005 .05251 L
.31953 .05226 L
.32954 .05207 L
.3352 .05199 L
.34044 .05193 L
.34506 .05189 L
.34749 .05187 L
.35005 .05185 L
.3523 .05184 L
.35476 .05183 L
.357 .05182 L
.35808 .05182 L
.35908 .05182 L
.36037 .05182 L
.36104 .05182 L
.36176 .05181 L
.36297 .05181 L
.36365 .05181 L
Mistroke
.36429 .05181 L
.36549 .05181 L
.36658 .05182 L
.36784 .05182 L
.36903 .05182 L
.37167 .05183 L
.37412 .05184 L
.37967 .05186 L
.38476 .0519 L
.39025 .05195 L
.40021 .05205 L
.41882 .05229 L
.45985 .05278 L
.49935 .05317 L
.53735 .05352 L
.57779 .05386 L
.61672 .05417 L
.6581 .05448 L
.69796 .05477 L
.73631 .05505 L
.77712 .05536 L
.8164 .05565 L
.85417 .05594 L
.8944 .05626 L
.9331 .05656 L
.97426 .05689 L
.97619 .0569 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.02846 .08442 L
.03279 .13911 L
.03754 .18708 L
.04262 .22468 L
.04518 .23859 L
.04795 .25019 L
.04923 .25438 L
.05058 .25811 L
.05174 .26078 L
.053 .2631 L
.05421 .26484 L
.05532 .26603 L
.05643 .26686 L
.05749 .26734 L
.05872 .26755 L
.05986 .26744 L
.06111 .26701 L
.06181 .26663 L
.06244 .26622 L
.06508 .26382 L
.06787 .26033 L
.07287 .25244 L
.08414 .23203 L
.09401 .21582 L
.09944 .20842 L
.10458 .20253 L
.1095 .19794 L
.11485 .19407 L
.11721 .19273 L
.11972 .19155 L
.12188 .19073 L
.12422 .19005 L
.12536 .1898 L
.12656 .18959 L
.12759 .18945 L
.12871 .18936 L
.12977 .18932 L
.1309 .18933 L
.13196 .18938 L
.13293 .18948 L
.13417 .18967 L
.13531 .1899 L
.13656 .19024 L
.13788 .19068 L
.1401 .19163 L
.14255 .19303 L
.14505 .19489 L
.14776 .19749 L
.15033 .20062 L
Mistroke
.15271 .20425 L
.15721 .2136 L
.15972 .22068 L
.162 .22856 L
.17289 .28439 L
.17766 .30918 L
.18037 .3202 L
.18166 .3245 L
.18289 .32797 L
.18403 .33065 L
.18526 .33299 L
.18639 .33462 L
.18742 .3357 L
.18854 .33644 L
.18978 .33677 L
.19107 .33659 L
.19228 .33598 L
.19349 .33497 L
.19476 .3335 L
.19704 .33 L
.20218 .31895 L
.21226 .29146 L
.22301 .26346 L
.22835 .252 L
.23338 .24301 L
.23828 .23602 L
.24279 .23113 L
.24501 .22926 L
.24708 .22783 L
.24924 .22667 L
.25039 .22619 L
.25162 .22578 L
.25284 .22547 L
.25354 .22535 L
.25418 .22526 L
.25536 .22517 L
.25661 .22518 L
.25773 .22527 L
.25878 .22544 L
.25993 .2257 L
.26117 .22608 L
.26356 .2271 L
.26612 .22862 L
.26853 .23047 L
.27073 .23251 L
.27611 .23899 L
.28119 .24681 L
.29143 .26529 L
.29703 .27519 L
.30228 .28333 L
Mistroke
.30725 .28962 L
.31179 .29403 L
.31438 .29597 L
.31684 .29744 L
.31944 .29864 L
.3209 .29916 L
.32227 .29956 L
.32343 .29983 L
.32468 .30005 L
.32586 .30021 L
.32695 .30031 L
.32794 .30037 L
.32902 .3004 L
.33014 .30039 L
.3312 .30035 L
.33243 .30027 L
.3336 .30017 L
.33579 .2999 L
.34071 .29909 L
.35038 .29733 L
.35272 .29698 L
.35525 .29667 L
.3567 .29653 L
.35803 .29643 L
.3593 .29635 L
.35994 .29632 L
.36064 .2963 L
.36188 .29627 L
.36306 .29627 L
.36411 .29629 L
.36525 .29633 L
.3665 .29639 L
.36782 .29649 L
.37018 .29673 L
.37237 .29703 L
.37441 .29737 L
.37906 .29836 L
.39765 .30402 L
.40746 .30711 L
.41791 .30975 L
.42368 .31082 L
.4289 .31153 L
.43143 .31178 L
.43416 .312 L
.43541 .31208 L
.43673 .31215 L
.43795 .31221 L
.4391 .31225 L
.44035 .31228 L
.44149 .3123 L
Mistroke
.44273 .31232 L
.44342 .31232 L
.44406 .31232 L
.44513 .31232 L
.44631 .31231 L
.44754 .31229 L
.44869 .31226 L
.45133 .31218 L
.45375 .31207 L
.4592 .31175 L
.46904 .31097 L
.47818 .31009 L
.4989 .30783 L
.53802 .30263 L
.57959 .2959 L
.61964 .28939 L
.65818 .28373 L
.69917 .27859 L
.73864 .27454 L
.7766 .27142 L
.81702 .26882 L
.85591 .26688 L
.89726 .26528 L
.93709 .26406 L
.97541 .2631 L
.97619 .26308 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.02846 .08442 L
.03279 .139 L
.03754 .18655 L
.04262 .22332 L
.04518 .23671 L
.04795 .24776 L
.04923 .25171 L
.05058 .2552 L
.05174 .25767 L
.053 .2598 L
.05421 .26137 L
.05532 .26243 L
.05643 .26315 L
.05749 .26354 L
.05872 .26367 L
.05986 .2635 L
.06111 .26302 L
.06181 .26263 L
.06244 .26222 L
.06508 .25985 L
.06787 .25647 L
.07287 .24896 L
.08414 .22976 L
.09401 .21464 L
.09944 .20775 L
.10458 .20229 L
.1095 .19804 L
.11485 .1945 L
.11721 .19328 L
.11972 .19223 L
.12186 .19151 L
.12422 .19093 L
.12537 .19072 L
.12659 .19055 L
.12763 .19046 L
.12877 .19041 L
.13 .19041 L
.13131 .19048 L
.13255 .19062 L
.13367 .1908 L
.13481 .19105 L
.13587 .19133 L
.13824 .19217 L
.14033 .19316 L
.14255 .19451 L
.14508 .19647 L
.14748 .19881 L
.15199 .20482 L
.1545 .20938 L
Mistroke
.15684 .21461 L
.15956 .22224 L
.16213 .23123 L
.16678 .25256 L
.171 .27615 L
.17588 .30327 L
.18044 .32303 L
.18269 .32997 L
.18396 .33298 L
.18511 .33518 L
.18637 .33701 L
.18708 .33779 L
.18774 .33834 L
.18895 .33897 L
.19023 .33912 L
.19145 .33879 L
.19276 .33797 L
.194 .33678 L
.19514 .33537 L
.19778 .33108 L
.20056 .32535 L
.21904 .27667 L
.22861 .2553 L
.23387 .24612 L
.23882 .23923 L
.24345 .23435 L
.24606 .23225 L
.24846 .23074 L
.25048 .22978 L
.25163 .22935 L
.25271 .22904 L
.25384 .22879 L
.25488 .22863 L
.25607 .22854 L
.2572 .22854 L
.25834 .22862 L
.25956 .22879 L
.26072 .22905 L
.26178 .22935 L
.26424 .23034 L
.26684 .23182 L
.26937 .2337 L
.27173 .23587 L
.27709 .24224 L
.28599 .25661 L
.2955 .27411 L
.30573 .29059 L
.3115 .29764 L
.31682 .30254 L
.32148 .30567 L
Mistroke
.32412 .30703 L
.3266 .30806 L
.32916 .30892 L
.3316 .30957 L
.3344 .31016 L
.33697 .31058 L
.34656 .31177 L
.35183 .31252 L
.35679 .31348 L
.36142 .31469 L
.36643 .3164 L
.37518 .32032 L
.39474 .33197 L
.4051 .33828 L
.4162 .34412 L
.42689 .34849 L
.43664 .3514 L
.44133 .35248 L
.44643 .35345 L
.45571 .35479 L
.46056 .35532 L
.46512 .35574 L
.4755 .35648 L
.48561 .357 L
.4913 .35722 L
.49651 .35738 L
.50126 .35749 L
.50391 .35753 L
.50632 .35756 L
.50742 .35758 L
.50858 .35759 L
.50985 .35759 L
.51102 .3576 L
.51211 .3576 L
.51313 .3576 L
.51425 .3576 L
.51545 .3576 L
.51612 .35759 L
.51683 .35759 L
.51811 .35758 L
.51963 .35756 L
.521 .35754 L
.52372 .3575 L
.52627 .35744 L
.53102 .35731 L
.53615 .35712 L
.54569 .35665 L
.55615 .356 L
.57723 .35436 L
.61773 .35072 L
Mistroke
.65671 .34727 L
.69814 .34404 L
.73806 .34158 L
.77646 .33986 L
.79629 .3392 L
.81731 .33866 L
.83684 .33828 L
.85514 .33803 L
.86551 .33792 L
.87537 .33784 L
.88423 .33779 L
.88887 .33776 L
.8939 .33775 L
.89921 .33773 L
.90164 .33772 L
.90421 .33772 L
.90653 .33772 L
.90908 .33771 L
.9102 .33771 L
.9114 .33771 L
.91253 .33771 L
.91356 .33771 L
.91486 .33771 L
.91551 .33771 L
.91624 .33771 L
.91752 .33771 L
.91872 .33771 L
.9194 .33771 L
.92012 .33771 L
.92142 .33771 L
.92281 .33771 L
.92433 .33771 L
.92688 .33772 L
.92961 .33772 L
.93453 .33773 L
.94477 .33776 L
.95587 .33779 L
.97601 .33789 L
.97619 .33789 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.02846 .08442 L
.03279 .13908 L
.03754 .18668 L
.04018 .20736 L
.04262 .22279 L
.04518 .23528 L
.04652 .2404 L
.04795 .24479 L
.04919 .24776 L
.05035 .24989 L
.05163 .25153 L
.05234 .25214 L
.053 .25253 L
.0542 .25282 L
.05531 .25263 L
.05654 .25195 L
.05784 .25075 L
.05908 .2492 L
.06026 .24741 L
.06244 .24334 L
.08439 .18623 L
.09401 .16546 L
.09911 .15663 L
.10458 .14879 L
.10965 .14289 L
.11427 .13857 L
.11892 .13515 L
.12333 .1327 L
.12572 .13168 L
.12825 .13082 L
.13042 .13027 L
.13165 .13003 L
.13281 .12985 L
.13407 .12972 L
.13471 .12968 L
.1354 .12964 L
.13663 .12963 L
.13778 .12968 L
.13847 .12973 L
.13913 .12979 L
.14037 .12997 L
.14169 .13023 L
.14313 .13061 L
.14549 .13146 L
.14802 .13272 L
.15041 .13432 L
.1526 .13619 L
.15515 .13899 L
.15794 .14301 L
Mistroke
.16057 .148 L
.16301 .15395 L
.16836 .17247 L
.1732 .19468 L
.17848 .21843 L
.18114 .2279 L
.18266 .23229 L
.18405 .23558 L
.18525 .23789 L
.18656 .23982 L
.18728 .24064 L
.18794 .24125 L
.18925 .24204 L
.19037 .24231 L
.1916 .24221 L
.19289 .24168 L
.1941 .24084 L
.19523 .23978 L
.19642 .2384 L
.19855 .23536 L
.20333 .22657 L
.21341 .20468 L
.22417 .18365 L
.22951 .17546 L
.23454 .16936 L
.23906 .16532 L
.2403 .16447 L
.2416 .16369 L
.24283 .16308 L
.24395 .16263 L
.24507 .16229 L
.24613 .16207 L
.24726 .16196 L
.24848 .16197 L
.24954 .16211 L
.25067 .16241 L
.25164 .16278 L
.25271 .16333 L
.25395 .16417 L
.25509 .16513 L
.25767 .16807 L
.25994 .17159 L
.26233 .17632 L
.27258 .20736 L
.27762 .22585 L
.28227 .24178 L
.28641 .25357 L
.28861 .25859 L
.29097 .26294 L
.2922 .26477 L
Mistroke
.29333 .26617 L
.29448 .26733 L
.29555 .26817 L
.29674 .26885 L
.29804 .26928 L
.29918 .2694 L
.3004 .26927 L
.30105 .2691 L
.30173 .26885 L
.30295 .26821 L
.30426 .26728 L
.3057 .26599 L
.31068 .25966 L
.31999 .24293 L
.33095 .22104 L
.34093 .20299 L
.35029 .18903 L
.36046 .17717 L
.3712 .16784 L
.38138 .16135 L
.39079 .15682 L
.40117 .15296 L
.42218 .1473 L
.44154 .14346 L
.4624 .14023 L
.48246 .13785 L
.50356 .13596 L
.54169 .13352 L
.58227 .13163 L
.62134 .13023 L
.66285 .12906 L
.70286 .12816 L
.74134 .12747 L
.78228 .12688 L
.8217 .12641 L
.85961 .12604 L
.89997 .1257 L
.93882 .12542 L
.97619 .12519 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.02846 .08416 L
.03279 .13571 L
.03527 .15792 L
.03754 .17313 L
.03879 .17957 L
.04015 .18506 L
.04143 .1889 L
.04262 .19139 L
.04376 .19292 L
.04498 .19373 L
.04614 .19377 L
.0472 .19328 L
.04843 .19216 L
.04913 .19129 L
.04978 .19035 L
.05224 .18584 L
.06244 .15951 L
.07295 .13277 L
.08284 .11317 L
.08832 .10476 L
.09424 .09738 L
.09959 .09206 L
.10458 .08807 L
.10955 .08489 L
.11408 .0826 L
.11912 .08065 L
.12192 .0798 L
.12452 .07915 L
.12703 .07865 L
.1297 .07825 L
.13108 .07809 L
.13238 .07797 L
.13307 .07792 L
.1338 .07788 L
.1346 .07784 L
.13534 .07782 L
.13656 .0778 L
.13787 .07782 L
.13911 .07786 L
.14023 .07793 L
.14155 .07804 L
.14298 .07821 L
.14558 .07863 L
.14794 .07918 L
.15047 .07996 L
.15286 .08092 L
.15505 .08204 L
.1576 .0837 L
.16039 .08606 L
Mistroke
.16302 .08898 L
.16546 .09239 L
.17067 .102 L
.1763 .11358 L
.17889 .11796 L
.1803 .1199 L
.18162 .12139 L
.18284 .1225 L
.18395 .12329 L
.18518 .12391 L
.1865 .12431 L
.18778 .12444 L
.18842 .12442 L
.18913 .12434 L
.19039 .12405 L
.19157 .12362 L
.19295 .12295 L
.19422 .12219 L
.19707 .12009 L
.20706 .11058 L
.21607 .10188 L
.22568 .09416 L
.23084 .09084 L
.23551 .08831 L
.24465 .08457 L
.24977 .08309 L
.25531 .08189 L
.26054 .08105 L
.26536 .08044 L
.28576 .07814 L
.30482 .07583 L
.31421 .07491 L
.32312 .07422 L
.32803 .07392 L
.33339 .07364 L
.34275 .07328 L
.34759 .07314 L
.35214 .07304 L
.35713 .07296 L
.35969 .07292 L
.36251 .07289 L
.36527 .07287 L
.36784 .07285 L
.36926 .07284 L
.37055 .07284 L
.37127 .07284 L
.37205 .07283 L
.37277 .07283 L
.37346 .07283 L
.37466 .07283 L
Mistroke
.3753 .07283 L
.37599 .07283 L
.37671 .07283 L
.3774 .07283 L
.37868 .07283 L
.37988 .07283 L
.38099 .07284 L
.3835 .07285 L
.38615 .07286 L
.38859 .07288 L
.39408 .07292 L
.40404 .07303 L
.42265 .07331 L
.46216 .07396 L
.50015 .07458 L
.5406 .07526 L
.57953 .0759 L
.62091 .07657 L
.66077 .0772 L
.69912 .07779 L
.73992 .07841 L
.77921 .079 L
.81698 .07956 L
.8572 .08017 L
.89591 .08076 L
.93707 .08138 L
.97619 .08198 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.02846 .08416 L
.03279 .13565 L
.03527 .15774 L
.03754 .17277 L
.03879 .17906 L
.04015 .18436 L
.04143 .18799 L
.04262 .19026 L
.04376 .19156 L
.04498 .1921 L
.04614 .19188 L
.0472 .19114 L
.04843 .18971 L
.04978 .18756 L
.05224 .18243 L
.06244 .1538 L
.07302 .12519 L
.07883 .11235 L
.08429 .10224 L
.08941 .0944 L
.09493 .08745 L
.09992 .08238 L
.10458 .07851 L
.10955 .07518 L
.11408 .07276 L
.11912 .07066 L
.12192 .06972 L
.12452 .069 L
.12698 .06842 L
.1297 .06791 L
.13243 .06752 L
.13393 .06736 L
.13534 .06724 L
.13659 .06716 L
.13791 .06711 L
.13903 .06709 L
.14027 .06709 L
.14096 .0671 L
.1416 .06712 L
.14233 .06715 L
.14302 .06719 L
.14425 .06728 L
.14558 .06741 L
.14794 .06774 L
.14926 .06798 L
.15047 .06824 L
.15282 .06888 L
.15505 .06967 L
.15763 .07085 L
Mistroke
.16003 .07227 L
.16266 .07428 L
.16546 .07706 L
.1708 .08432 L
.17643 .09332 L
.17875 .09658 L
.18123 .09941 L
.18266 .10069 L
.18396 .10161 L
.18527 .10231 L
.1865 .10278 L
.18775 .10307 L
.18907 .10319 L
.1902 .10314 L
.19144 .10296 L
.19214 .1028 L
.19278 .10262 L
.19422 .10211 L
.19681 .10086 L
.20224 .09732 L
.20795 .09295 L
.21772 .0855 L
.22814 .07885 L
.23347 .07612 L
.23851 .07399 L
.24341 .07228 L
.24792 .07101 L
.25212 .07005 L
.25674 .06923 L
.26139 .06859 L
.2663 .06808 L
.30669 .06461 L
.3253 .06308 L
.33582 .06247 L
.34557 .06206 L
.35045 .0619 L
.35585 .06176 L
.36111 .06165 L
.36678 .06156 L
.37219 .06149 L
.37715 .06144 L
.38189 .0614 L
.38689 .06137 L
.39188 .06135 L
.39642 .06134 L
.39894 .06133 L
.40166 .06133 L
.40291 .06133 L
.40424 .06132 L
.40548 .06132 L
Mistroke
.40661 .06132 L
.40765 .06132 L
.40879 .06132 L
.40998 .06132 L
.41112 .06132 L
.41219 .06132 L
.41332 .06132 L
.41438 .06132 L
.41535 .06132 L
.41659 .06132 L
.41773 .06132 L
.4203 .06132 L
.42257 .06133 L
.42497 .06133 L
.43446 .06134 L
.44462 .06137 L
.46296 .06143 L
.50434 .0616 L
.54421 .0618 L
.58256 .062 L
.62336 .06221 L
.66265 .06241 L
.70042 .06259 L
.74064 .06277 L
.77935 .06293 L
.82051 .0631 L
.86015 .06326 L
.89828 .06341 L
.93886 .06356 L
.97619 .0637 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.02605 .04931 L
.02729 .06589 L
.02846 .0789 L
.02954 .08815 L
.03072 .09493 L
.0318 .09839 L
.03279 .09975 L
.03396 .09967 L
.03506 .09842 L
.03626 .09623 L
.03756 .09327 L
.04262 .0799 L
.0521 .05801 L
.05746 .04881 L
.06244 .04207 L
.0679 .03629 L
.07373 .0316 L
.07935 .02818 L
.08445 .0258 L
.08943 .02399 L
.09481 .02248 L
.0999 .02138 L
.10458 .0206 L
.10928 .01997 L
.11432 .01945 L
.11907 .01907 L
.1234 .01879 L
.12849 .01854 L
.13402 .01834 L
.13924 .01819 L
.14407 .01809 L
.1487 .01803 L
.15131 .018 L
.15369 .01798 L
.1558 .01796 L
.1581 .01795 L
.15926 .01795 L
.1605 .01795 L
.16167 .01794 L
.16273 .01794 L
.16402 .01794 L
.16466 .01794 L
.16538 .01794 L
.16664 .01795 L
.16782 .01795 L
.17333 .01797 L
.1758 .01797 L
.17702 .01798 L
.17815 .01798 L
Mistroke
.17945 .01798 L
.18013 .01798 L
.18086 .01798 L
.18216 .01798 L
.18333 .01798 L
.18454 .01798 L
.18567 .01798 L
.1869 .01797 L
.18822 .01797 L
.19338 .01794 L
.20262 .01788 L
.21345 .01781 L
.22345 .01776 L
.2284 .01774 L
.23365 .01773 L
.23892 .01772 L
.24196 .01771 L
.24473 .01771 L
.24712 .0177 L
.24974 .0177 L
.25236 .0177 L
.25379 .0177 L
.25512 .0177 L
.2564 .0177 L
.25759 .0177 L
.25867 .0177 L
.25984 .0177 L
.26111 .0177 L
.26175 .0177 L
.26245 .0177 L
.2637 .0177 L
.26487 .0177 L
.27389 .0177 L
.28348 .01771 L
.28588 .01771 L
.28848 .01771 L
.28996 .01771 L
.29132 .01771 L
.29263 .01771 L
.29328 .01771 L
.294 .01771 L
.29528 .01771 L
.29644 .01771 L
.29708 .01771 L
.29778 .01771 L
.29904 .01771 L
.30023 .01771 L
.30149 .01771 L
.30374 .01771 L
.30625 .01771 L
Mistroke
.30896 .0177 L
.31384 .0177 L
.32496 .01769 L
.34507 .01768 L
.35519 .01767 L
.36622 .01766 L
.37664 .01766 L
.38631 .01766 L
.40685 .01765 L
.42546 .01765 L
.44635 .01765 L
.46555 .01765 L
.48431 .01764 L
.50412 .01764 L
.54211 .01764 L
.56327 .01764 L
.58256 .01764 L
.62149 .01764 L
.66135 .01764 L
.6997 .01764 L
.7405 .01764 L
.77979 .01764 L
.81756 .01764 L
.85778 .01764 L
.89649 .01764 L
.93765 .01764 L
.97619 .01764 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.02846 .08442 L
.03279 .1391 L
.03754 .18693 L
.04262 .22389 L
.04518 .23714 L
.04652 .24277 L
.04795 .24775 L
.0492 .25132 L
.05058 .25446 L
.05183 .25662 L
.053 .25809 L
.05422 .25909 L
.05538 .25956 L
.05641 .25964 L
.05755 .25935 L
.05878 .25866 L
.06009 .25753 L
.06132 .25612 L
.06244 .25459 L
.06787 .24464 L
.07287 .23326 L
.08414 .20653 L
.09471 .18534 L
.09987 .17702 L
.10458 .17062 L
.10893 .16566 L
.11366 .16127 L
.11867 .15768 L
.1234 .15523 L
.12588 .1543 L
.12861 .15356 L
.12998 .15329 L
.1307 .15318 L
.13146 .15309 L
.13213 .15302 L
.13286 .15298 L
.13414 .15294 L
.13544 .15298 L
.13662 .15308 L
.13728 .15316 L
.13799 .15328 L
.13928 .15354 L
.14049 .15386 L
.14177 .15428 L
.14407 .15527 L
.1466 .15675 L
.149 .1586 L
.15115 .1607 L
.1535 .16356 L
Mistroke
.15605 .1675 L
.15876 .17293 L
.16132 .17954 L
.16364 .18703 L
.16818 .20634 L
.17308 .23222 L
.17736 .25426 L
.17972 .26446 L
.18195 .27235 L
.18319 .27591 L
.18454 .27912 L
.18565 .28127 L
.18689 .28309 L
.18805 .28432 L
.18928 .28511 L
.19042 .28541 L
.19148 .28533 L
.19277 .28481 L
.19341 .28439 L
.19411 .28381 L
.19652 .281 L
.19932 .27638 L
.20193 .27111 L
.21278 .24487 L
.22301 .22159 L
.22779 .2127 L
.23285 .20504 L
.2355 .2018 L
.2384 .19887 L
.23967 .19781 L
.24104 .19683 L
.24232 .19606 L
.24351 .19549 L
.24467 .19507 L
.2459 .19477 L
.24713 .19464 L
.24784 .19464 L
.2485 .1947 L
.24969 .19494 L
.25078 .19533 L
.25197 .19595 L
.25323 .19683 L
.25543 .19897 L
.25747 .20172 L
.25971 .20561 L
.26211 .21082 L
.282 .27967 L
.28744 .29631 L
.29019 .30293 L
.29322 .30869 L
Mistroke
.29579 .3123 L
.29724 .31381 L
.29857 .31487 L
.29979 .31559 L
.30049 .31589 L
.30113 .3161 L
.30231 .31631 L
.30357 .3163 L
.30489 .31605 L
.30555 .31583 L
.30627 .31553 L
.30756 .31482 L
.30876 .31399 L
.31147 .31154 L
.31437 .30815 L
.32453 .29233 L
.34352 .26 L
.35371 .24605 L
.36478 .2345 L
.37523 .22661 L
.3849 .22125 L
.40358 .21393 L
.42419 .2076 L
.46441 .19679 L
.50312 .1893 L
.54428 .18365 L
.58392 .17927 L
.62205 .1758 L
.66263 .17277 L
.7017 .1704 L
.74322 .16836 L
.78322 .16678 L
.8217 .16554 L
.86264 .16446 L
.90207 .16359 L
.93997 .16288 L
.97619 .16229 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.02846 .08443 L
.03279 .13917 L
.03754 .18728 L
.04262 .2249 L
.04518 .23865 L
.04652 .24457 L
.04795 .2499 L
.0492 .2538 L
.05058 .25733 L
.05184 .25989 L
.053 .2617 L
.0542 .26307 L
.05535 .26394 L
.05656 .26441 L
.05788 .26445 L
.05902 .26413 L
.06025 .26344 L
.0614 .26251 L
.06244 .26144 L
.06508 .25796 L
.06787 .25332 L
.07287 .24345 L
.08414 .21933 L
.09401 .20085 L
.09944 .19251 L
.10458 .1859 L
.1095 .18072 L
.11485 .1763 L
.11721 .17474 L
.11972 .17333 L
.12188 .17231 L
.12422 .17143 L
.12536 .17108 L
.12656 .17077 L
.12768 .17053 L
.12871 .17035 L
.12969 .17022 L
.13073 .17013 L
.13188 .17008 L
.13293 .17009 L
.13417 .17015 L
.13531 .17028 L
.13656 .17048 L
.13788 .17078 L
.1401 .17148 L
.14255 .17258 L
.14505 .17409 L
.14776 .17627 L
.15033 .17894 L
Mistroke
.15271 .18208 L
.15721 .1903 L
.15972 .19663 L
.162 .20375 L
.16717 .22566 L
.17276 .2561 L
.17529 .26987 L
.178 .28306 L
.18035 .29258 L
.18289 .30058 L
.18422 .30376 L
.18545 .30608 L
.18663 .30777 L
.18788 .30899 L
.18899 .30963 L
.19004 .30985 L
.19119 .3097 L
.19242 .30911 L
.19369 .30808 L
.19508 .30651 L
.19788 .30213 L
.20287 .2914 L
.21392 .26256 L
.22395 .2387 L
.2288 .22931 L
.23406 .22105 L
.23647 .21794 L
.23902 .21515 L
.24141 .21299 L
.2436 .21143 L
.24479 .21074 L
.24609 .21014 L
.2468 .20987 L
.24746 .20967 L
.24876 .20938 L
.24987 .20926 L
.2511 .20927 L
.25238 .20945 L
.25359 .20978 L
.25423 .21001 L
.25493 .21033 L
.25634 .21112 L
.25886 .21312 L
.26181 .21642 L
.26456 .22045 L
.2696 .23016 L
.27507 .24351 L
.28499 .27059 L
.28968 .28228 L
.29466 .29263 L
Mistroke
.2989 .29942 L
.30131 .30239 L
.30357 .30459 L
.30482 .30557 L
.30615 .30643 L
.3073 .30703 L
.30854 .30754 L
.30931 .30778 L
.31001 .30795 L
.31068 .30807 L
.31139 .30816 L
.31261 .30821 L
.31331 .30819 L
.31396 .30813 L
.31524 .30793 L
.31646 .30764 L
.31755 .30729 L
.31873 .30683 L
.32384 .30405 L
.3285 .30065 L
.33346 .29657 L
.34236 .289 L
.35174 .28195 L
.35667 .27892 L
.36185 .2763 L
.36641 .27447 L
.37139 .27295 L
.37592 .27195 L
.38014 .27129 L
.38277 .27098 L
.38519 .27076 L
.38785 .27057 L
.39067 .27042 L
.3954 .27024 L
.40061 .27006 L
.40524 .26988 L
.41022 .26962 L
.41491 .26928 L
.4192 .26887 L
.42908 .26757 L
.43824 .26598 L
.45898 .26161 L
.49818 .25345 L
.53984 .24588 L
.57998 .23896 L
.6186 .23297 L
.65967 .2275 L
.69923 .2231 L
.73728 .21963 L
.77777 .21663 L
Mistroke
.81675 .21432 L
.85819 .21233 L
.89811 .21077 L
.93651 .20952 L
.97619 .20841 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.02605 .04969 L
.02846 .0836 L
.03053 .10822 L
.03163 .11886 L
.03279 .1281 L
.03344 .13235 L
.03416 .13621 L
.03543 .14099 L
.03672 .14344 L
.03793 .14387 L
.03911 .14288 L
.04019 .14104 L
.04143 .13808 L
.04262 .13467 L
.05221 .10147 L
.06244 .07263 L
.06792 .06134 L
.07289 .0532 L
.07794 .04661 L
.08259 .04177 L
.08803 .0373 L
.09391 .03361 L
.0991 .03112 L
.10458 .0291 L
.10954 .02768 L
.11406 .02667 L
.11928 .02575 L
.12422 .02508 L
.12878 .0246 L
.133 .02426 L
.13763 .02397 L
.14003 .02385 L
.14255 .02375 L
.14489 .02367 L
.14744 .02361 L
.14856 .02358 L
.14976 .02356 L
.15089 .02355 L
.15192 .02354 L
.15323 .02353 L
.15392 .02352 L
.15464 .02352 L
.15587 .02352 L
.15656 .02352 L
.15721 .02353 L
.15843 .02353 L
.15953 .02355 L
.16081 .02356 L
.16202 .02359 L
Mistroke
.16422 .02364 L
.16656 .02371 L
.17077 .02387 L
.17541 .02406 L
.17794 .02414 L
.1803 .02421 L
.18154 .02423 L
.18218 .02424 L
.18287 .02425 L
.18362 .02426 L
.18434 .02426 L
.18503 .02426 L
.18568 .02426 L
.18682 .02426 L
.18807 .02425 L
.18938 .02424 L
.19061 .02422 L
.19341 .02416 L
.19598 .0241 L
.20175 .02391 L
.21222 .02356 L
.22194 .02328 L
.23111 .02308 L
.23624 .02299 L
.2409 .02293 L
.24602 .02288 L
.2489 .02286 L
.25156 .02285 L
.25389 .02283 L
.25645 .02282 L
.25774 .02282 L
.25912 .02282 L
.26042 .02282 L
.26161 .02281 L
.26279 .02281 L
.26389 .02281 L
.2651 .02281 L
.26641 .02281 L
.2677 .02281 L
.26836 .02281 L
.26907 .02281 L
.27151 .02281 L
.2738 .02282 L
.27626 .02282 L
.28067 .02283 L
.28335 .02283 L
.28477 .02283 L
.28554 .02283 L
.28626 .02283 L
.28757 .02283 L
Mistroke
.28826 .02283 L
.28901 .02283 L
.28969 .02283 L
.29033 .02283 L
.29154 .02283 L
.29273 .02283 L
.29399 .02283 L
.29519 .02283 L
.29627 .02283 L
.29893 .02282 L
.30143 .02282 L
.30609 .02281 L
.3112 .02279 L
.32152 .02274 L
.34 .02267 L
.35021 .02264 L
.35952 .02261 L
.37027 .02259 L
.38044 .02258 L
.40037 .02256 L
.41879 .02255 L
.43906 .02254 L
.45808 .02253 L
.47626 .02252 L
.49585 .02252 L
.5159 .02251 L
.53701 .02251 L
.57514 .0225 L
.59476 .0225 L
.61572 .0225 L
.63564 .0225 L
.65723 .0225 L
.69724 .0225 L
.73817 .0225 L
.7776 .0225 L
.8155 .02249 L
.85586 .02249 L
.89471 .02249 L
.93601 .02249 L
.97579 .02249 L
.97619 .02249 L
Mfstroke
.174 1 0 r
.02381 .01472 m
.02499 .03212 L
.02605 .04264 L
.02729 .04813 L
.02846 .04955 L
.02954 .04942 L
.03053 .04871 L
.03163 .04763 L
.03279 .0463 L
.03786 .04024 L
.04262 .03526 L
.05205 .02794 L
.05706 .02521 L
.06244 .02292 L
.06784 .02118 L
.07373 .01974 L
.07929 .01872 L
.08445 .018 L
.08956 .01746 L
.09419 .01707 L
.09954 .01672 L
.10458 .01647 L
.10923 .01629 L
.11434 .01614 L
.11968 .01601 L
.12466 .01593 L
.12932 .01586 L
.13357 .01582 L
.13848 .01578 L
.14313 .01575 L
.14772 .01572 L
.15278 .01571 L
.15533 .0157 L
.15807 .01569 L
.16066 .01569 L
.16304 .01569 L
.16526 .01568 L
.16733 .01568 L
.16851 .01568 L
.16959 .01568 L
.17201 .01568 L
.17651 .01568 L
.17907 .01568 L
.18146 .01568 L
.1838 .01568 L
.18631 .01567 L
.19144 .01567 L
.20064 .01566 L
.21144 .01565 L
.22144 .01564 L
Mistroke
.22635 .01564 L
.23157 .01563 L
.23737 .01563 L
.2401 .01563 L
.24262 .01563 L
.24499 .01563 L
.2476 .01563 L
.25021 .01563 L
.25164 .01563 L
.25297 .01563 L
.25424 .01563 L
.25544 .01563 L
.25651 .01563 L
.25768 .01563 L
.25895 .01563 L
.25959 .01563 L
.2603 .01563 L
.26155 .01563 L
.26272 .01563 L
.26516 .01563 L
.26743 .01563 L
.27258 .01563 L
.27801 .01563 L
.28294 .01563 L
.28516 .01563 L
.28755 .01563 L
.28962 .01563 L
.2919 .01563 L
.29315 .01563 L
.29432 .01563 L
.29555 .01563 L
.29624 .01563 L
.29688 .01563 L
.298 .01563 L
.29923 .01563 L
.30039 .01563 L
.30146 .01563 L
.30263 .01563 L
.30387 .01563 L
.30608 .01563 L
.31107 .01563 L
.3201 .01563 L
.34069 .01563 L
.35022 .01563 L
.36041 .01563 L
.37002 .01562 L
.37877 .01562 L
.39793 .01562 L
.41872 .01562 L
.43818 .01562 L
Mistroke
.4596 .01562 L
.47994 .01562 L
.49898 .01562 L
.53777 .01562 L
.55749 .01562 L
.57901 .01562 L
.61874 .01562 L
.65941 .01562 L
.69856 .01562 L
.74016 .01562 L
.78024 .01562 L
.81881 .01562 L
.85984 .01562 L
.89935 .01562 L
.93734 .01562 L
.97619 .01562 L
Mfstroke
.15 1 0 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02124 L
.02846 .02104 L
.03279 .02007 L
.0379 .01899 L
.04262 .01816 L
.04714 .01752 L
.05212 .01696 L
.05713 .01652 L
.06244 .01616 L
.06792 .01587 L
.07293 .01567 L
.07871 .01549 L
.0842 .01537 L
.08925 .01528 L
.09394 .01521 L
.09909 .01516 L
.10458 .01511 L
.10994 .01508 L
.11487 .01506 L
.12028 .01504 L
.12599 .01502 L
.13096 .01501 L
.13561 .015 L
.1407 .015 L
.14616 .01499 L
.15145 .01499 L
.15634 .01499 L
.15889 .01499 L
.1617 .01499 L
.16464 .01499 L
.1674 .01498 L
.16986 .01498 L
.17245 .01498 L
.17708 .01498 L
.18752 .01498 L
.19779 .01498 L
.20749 .01498 L
.21619 .01498 L
.22563 .01498 L
.23059 .01498 L
.23583 .01498 L
.24031 .01498 L
.24286 .01498 L
.24524 .01498 L
.24654 .01498 L
.24795 .01498 L
.24919 .01498 L
Mistroke
.25052 .01498 L
.25183 .01498 L
.25302 .01498 L
.25422 .01498 L
.25534 .01498 L
.25666 .01498 L
.25733 .01498 L
.25806 .01498 L
.25935 .01498 L
.26056 .01498 L
.26328 .01498 L
.26619 .01498 L
.27582 .01498 L
.2811 .01498 L
.28604 .01498 L
.28882 .01498 L
.29137 .01498 L
.29273 .01498 L
.2942 .01498 L
.29569 .01498 L
.2965 .01498 L
.29725 .01498 L
.2979 .01498 L
.2986 .01498 L
.29988 .01498 L
.30112 .01498 L
.30226 .01498 L
.3035 .01498 L
.30486 .01498 L
.30761 .01498 L
.31028 .01498 L
.31281 .01498 L
.31756 .01498 L
.32823 .01498 L
.3475 .01498 L
.35714 .01498 L
.36739 .01498 L
.37614 .01498 L
.3858 .01498 L
.40675 .01498 L
.42597 .01498 L
.44599 .01498 L
.46463 .01498 L
.48353 .01498 L
.50422 .01498 L
.54323 .01498 L
.5847 .01498 L
.62465 .01498 L
.66308 .01498 L
.70397 .01498 L
Mistroke
.74334 .01498 L
.78119 .01498 L
.8215 .01498 L
.86029 .01498 L
.90154 .01498 L
.94127 .01498 L
.97619 .01498 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.02846 .08437 L
.03279 .1382 L
.03754 .18284 L
.0402 .20105 L
.04262 .21361 L
.04385 .21864 L
.04516 .22304 L
.04629 .22611 L
.0475 .22871 L
.04881 .23075 L
.05003 .23203 L
.05077 .23253 L
.05148 .23282 L
.05212 .23294 L
.05281 .23293 L
.05408 .23255 L
.05523 .23184 L
.05587 .23132 L
.05656 .23065 L
.05781 .2292 L
.06244 .2218 L
.08293 .17924 L
.09325 .16224 L
.09918 .15466 L
.10458 .14906 L
.10948 .14498 L
.11481 .14155 L
.11774 .14008 L
.12045 .13897 L
.12304 .13812 L
.12447 .13775 L
.12579 .13746 L
.1269 .13725 L
.12812 .13708 L
.12935 .13694 L
.13064 .13686 L
.13178 .13683 L
.133 .13684 L
.13415 .1369 L
.1352 .137 L
.13584 .13707 L
.13653 .13717 L
.13776 .13739 L
.13908 .1377 L
.14054 .13812 L
.14314 .13911 L
.14558 .14036 L
.14817 .14207 L
.15056 .1441 L
Mistroke
.15319 .14694 L
.15599 .15085 L
.15866 .15571 L
.16118 .16156 L
.16587 .17677 L
.17471 .21767 L
.17714 .22833 L
.17973 .23791 L
.18099 .24172 L
.18218 .2448 L
.18324 .2471 L
.18441 .24916 L
.18559 .25076 L
.18685 .25192 L
.18801 .25255 L
.1891 .25276 L
.19038 .25259 L
.19155 .25206 L
.19284 .25111 L
.1942 .24973 L
.19676 .24626 L
.19913 .24222 L
.20452 .23125 L
.22301 .19203 L
.22808 .18337 L
.23356 .17537 L
.2384 .1695 L
.24351 .16443 L
.24812 .16077 L
.25319 .15765 L
.2578 .15547 L
.26211 .15386 L
.28243 .14823 L
.29142 .14619 L
.30098 .14449 L
.30569 .14385 L
.31088 .14326 L
.32005 .1425 L
.32519 .14217 L
.33074 .1419 L
.33599 .1417 L
.33851 .14162 L
.3408 .14157 L
.34196 .14154 L
.34323 .14152 L
.34432 .14151 L
.34553 .14149 L
.3468 .14148 L
.3475 .14148 L
.34816 .14148 L
Mistroke
.34933 .14147 L
.35058 .14148 L
.35175 .14148 L
.35302 .1415 L
.35423 .14151 L
.35534 .14153 L
.35745 .14158 L
.3597 .14164 L
.36238 .14174 L
.36529 .14188 L
.37055 .1422 L
.37568 .14262 L
.38039 .14308 L
.39923 .14559 L
.4199 .14907 L
.46034 .15568 L
.49927 .16153 L
.54065 .16778 L
.58052 .17361 L
.61886 .17906 L
.65967 .18475 L
.69895 .19015 L
.73672 .19528 L
.77695 .20074 L
.81565 .20602 L
.85681 .21168 L
.89646 .21718 L
.93459 .22251 L
.97517 .22817 L
.97619 .22831 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.02846 .08437 L
.03279 .13824 L
.03754 .18277 L
.0402 .20062 L
.04262 .21249 L
.04385 .21702 L
.04516 .22076 L
.04627 .22314 L
.0475 .22494 L
.04882 .22599 L
.04957 .22622 L
.05024 .2262 L
.05156 .22562 L
.05281 .22447 L
.05397 .22293 L
.0552 .22087 L
.05742 .21623 L
.06244 .20273 L
.07287 .17086 L
.08414 .14092 L
.08932 .12992 L
.09479 .12016 L
.10458 .10694 L
.10953 .10203 L
.11483 .09786 L
.11984 .09484 L
.1244 .09275 L
.12718 .09177 L
.12975 .09105 L
.13258 .09045 L
.134 .09022 L
.13477 .09012 L
.13558 .09004 L
.13623 .08998 L
.13695 .08992 L
.1382 .08986 L
.13891 .08985 L
.13967 .08985 L
.14039 .08986 L
.14104 .08988 L
.1423 .08997 L
.14302 .09003 L
.14367 .09011 L
.14488 .09029 L
.14616 .09053 L
.14869 .09118 L
.15109 .09205 L
.15325 .09307 L
.1556 .09452 L
Mistroke
.15815 .09656 L
.16086 .09944 L
.16342 .10299 L
.16574 .10708 L
.17465 .13021 L
.177 .13691 L
.17951 .14333 L
.18184 .14824 L
.18405 .15177 L
.18525 .15323 L
.18656 .15444 L
.18775 .15522 L
.18884 .15569 L
.19006 .15592 L
.19075 .15594 L
.19139 .15588 L
.1927 .15554 L
.19343 .15525 L
.1941 .15491 L
.19625 .15343 L
.1986 .15127 L
.20333 .14565 L
.21426 .13028 L
.22417 .11733 L
.23428 .10698 L
.24382 .10006 L
.24906 .09731 L
.25388 .09533 L
.25918 .0937 L
.26478 .09244 L
.26973 .09162 L
.27424 .09101 L
.28439 .08977 L
.30272 .08709 L
.31274 .08551 L
.32339 .08401 L
.33326 .08289 L
.34253 .08208 L
.35129 .08152 L
.36073 .08109 L
.36583 .08091 L
.37121 .08076 L
.37625 .08065 L
.38083 .08056 L
.39036 .08043 L
.3956 .08037 L
.40055 .08033 L
.40935 .08027 L
.41429 .08024 L
.41891 .08022 L
Mistroke
.42384 .0802 L
.42836 .08019 L
.43337 .08018 L
.43613 .08017 L
.43876 .08017 L
.44129 .08017 L
.4427 .08017 L
.44398 .08016 L
.44518 .08016 L
.44647 .08016 L
.44769 .08016 L
.44882 .08016 L
.45014 .08016 L
.45136 .08016 L
.45207 .08016 L
.45271 .08016 L
.45416 .08017 L
.45705 .08017 L
.45979 .08017 L
.46439 .08018 L
.46946 .08019 L
.47972 .08021 L
.49814 .08027 L
.53837 .08044 L
.57707 .08062 L
.61823 .08082 L
.65788 .081 L
.69601 .08116 L
.73659 .08132 L
.77565 .08146 L
.81717 .0816 L
.85717 .08172 L
.89566 .08183 L
.9366 .08195 L
.97602 .08206 L
.97619 .08206 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.02846 .08427 L
.03279 .1365 L
.03527 .15902 L
.03754 .17395 L
.03879 .17985 L
.03945 .1823 L
.04015 .1844 L
.04143 .187 L
.04262 .18806 L
.04384 .18795 L
.04496 .18691 L
.04626 .18475 L
.04749 .18192 L
.05205 .16712 L
.06244 .12741 L
.0675 .11048 L
.07289 .0952 L
.08259 .07441 L
.08853 .06522 L
.09412 .05847 L
.09915 .05369 L
.10458 .04963 L
.10917 .04691 L
.11408 .0446 L
.11948 .04263 L
.12452 .04124 L
.12723 .04063 L
.13018 .04008 L
.13278 .03967 L
.13554 .03932 L
.13802 .03906 L
.14076 .03884 L
.14195 .03876 L
.14325 .0387 L
.14446 .03864 L
.14558 .03861 L
.14686 .03858 L
.14807 .03857 L
.14915 .03857 L
.15032 .03858 L
.1516 .03861 L
.15225 .03863 L
.15296 .03866 L
.15421 .03873 L
.15539 .0388 L
.15768 .039 L
.15978 .03924 L
.16221 .0396 L
.16451 .04004 L
Mistroke
.17453 .04285 L
.17718 .04362 L
.18003 .04431 L
.18135 .04456 L
.18273 .04477 L
.18391 .04492 L
.18521 .04503 L
.18591 .04507 L
.18657 .0451 L
.18781 .04512 L
.1885 .04511 L
.18915 .0451 L
.18985 .04507 L
.1906 .04503 L
.19183 .04495 L
.19299 .04484 L
.19562 .04452 L
.20016 .04379 L
.20505 .04288 L
.21459 .04107 L
.22345 .03963 L
.23305 .03846 L
.23812 .038 L
.24353 .03761 L
.24627 .03745 L
.24923 .03731 L
.25184 .03721 L
.2546 .03711 L
.25709 .03705 L
.25983 .03699 L
.26232 .03695 L
.26464 .03693 L
.2659 .03691 L
.26724 .03691 L
.26838 .0369 L
.26964 .03689 L
.27099 .03689 L
.27175 .03689 L
.27244 .03689 L
.27373 .03688 L
.27437 .03688 L
.27508 .03688 L
.27626 .03688 L
.27754 .03688 L
.27866 .03688 L
.27986 .03688 L
.28052 .03688 L
.28125 .03688 L
.28254 .03688 L
.28379 .03688 L
Mistroke
.28497 .03688 L
.28621 .03687 L
.28739 .03687 L
.2896 .03686 L
.29198 .03684 L
.29458 .03682 L
.29922 .03677 L
.30352 .0367 L
.32233 .03632 L
.33222 .03611 L
.34267 .03593 L
.35383 .03579 L
.3641 .03569 L
.37372 .03563 L
.38427 .03558 L
.4038 .03551 L
.42472 .03545 L
.44597 .0354 L
.4661 .03537 L
.48602 .03535 L
.50445 .03533 L
.52472 .03532 L
.54373 .03531 L
.56214 .0353 L
.5815 .03529 L
.6017 .03529 L
.62021 .03529 L
.65834 .03528 L
.67797 .03528 L
.69892 .03528 L
.72028 .03527 L
.74044 .03527 L
.76047 .03527 L
.77892 .03527 L
.7977 .03527 L
.81835 .03527 L
.83781 .03527 L
.84873 .03527 L
.85871 .03527 L
.86793 .03527 L
.87775 .03527 L
.88851 .03527 L
.89849 .03527 L
.90387 .03527 L
.90881 .03527 L
.91423 .03527 L
.91696 .03527 L
.91996 .03527 L
.92131 .03527 L
.9226 .03527 L
Mistroke
.92377 .03527 L
.925 .03527 L
.92564 .03527 L
.92635 .03527 L
.92759 .03527 L
.92829 .03527 L
.92904 .03527 L
.92975 .03527 L
.9304 .03527 L
.93164 .03527 L
.93279 .03527 L
.93405 .03527 L
.9354 .03527 L
.93789 .03527 L
.94014 .03527 L
.94453 .03527 L
.94916 .03527 L
.95746 .03527 L
.96639 .03527 L
.97619 .03527 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .0214 L
.02846 .02122 L
.03053 .02079 L
.03279 .02029 L
.04262 .01839 L
.04762 .01768 L
.05293 .01708 L
.0579 .01665 L
.06244 .01633 L
.06743 .01606 L
.0728 .01583 L
.07777 .01567 L
.0825 .01554 L
.08797 .01543 L
.09305 .01536 L
.09863 .01529 L
.10458 .01524 L
.10994 .0152 L
.11487 .01518 L
.12028 .01516 L
.12599 .01514 L
.13096 .01513 L
.13561 .01512 L
.1407 .01512 L
.14335 .01511 L
.14616 .01511 L
.14867 .01511 L
.15145 .01511 L
.154 .01511 L
.15634 .01511 L
.15908 .01511 L
.16052 .0151 L
.16204 .0151 L
.16268 .0151 L
.16337 .0151 L
.1646 .0151 L
.16536 .0151 L
.16607 .0151 L
.16671 .0151 L
.1674 .0151 L
.16865 .0151 L
.16982 .0151 L
.17111 .0151 L
.17249 .0151 L
.17393 .0151 L
.17464 .0151 L
.1753 .0151 L
Mistroke
.17653 .0151 L
.17718 .0151 L
.17787 .0151 L
.17913 .0151 L
.17983 .0151 L
.18048 .0151 L
.18168 .0151 L
.18294 .0151 L
.18512 .0151 L
.18752 .0151 L
.20871 .0151 L
.21874 .0151 L
.228 .01509 L
.23266 .01509 L
.2376 .01509 L
.24255 .01509 L
.24541 .01509 L
.24802 .01509 L
.25273 .01509 L
.2578 .01509 L
.26696 .01509 L
.28753 .01509 L
.29755 .01509 L
.30664 .01509 L
.3251 .01509 L
.33524 .01509 L
.3448 .01509 L
.35454 .01509 L
.35946 .01509 L
.36485 .01509 L
.3744 .01509 L
.38332 .01509 L
.39375 .01509 L
.40364 .01509 L
.41246 .01509 L
.42219 .01509 L
.42683 .01509 L
.43183 .01509 L
.43458 .01509 L
.43711 .01509 L
.43968 .01509 L
.44208 .01509 L
.44415 .01509 L
.44636 .01509 L
.44762 .01509 L
.44881 .01509 L
.44988 .01509 L
.45104 .01509 L
.45218 .01509 L
.45343 .01509 L
Mistroke
.45473 .01509 L
.45596 .01509 L
.4571 .01509 L
.45814 .01509 L
.46049 .01509 L
.46299 .01509 L
.46526 .01509 L
.47034 .01509 L
.47949 .01509 L
.50022 .01509 L
.5403 .01509 L
.57887 .01509 L
.6199 .01509 L
.65941 .01509 L
.6974 .01509 L
.71856 .01509 L
.73784 .01509 L
.77677 .01509 L
.79587 .01509 L
.81664 .01509 L
.83642 .01509 L
.85744 .01509 L
.86682 .01509 L
.87692 .01509 L
.89521 .01509 L
.90479 .01509 L
.91526 .01509 L
.9262 .01509 L
.93637 .01509 L
.94142 .01509 L
.9469 .01509 L
.95207 .01509 L
.95684 .01509 L
.96114 .01509 L
.96359 .01509 L
.96587 .01509 L
.96711 .01509 L
.96828 .01509 L
.96935 .01509 L
.97048 .01509 L
.97171 .01509 L
.97285 .01509 L
.97355 .01509 L
.97421 .01509 L
.97543 .01509 L
.97619 .01509 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.02605 .04964 L
.02846 .08305 L
.03053 .1068 L
.03163 .11689 L
.03279 .1256 L
.03344 .12958 L
.03416 .13321 L
.03543 .13776 L
.03672 .1402 L
.03793 .14079 L
.03911 .1401 L
.04019 .13861 L
.04143 .1361 L
.04262 .13313 L
.05221 .10266 L
.06244 .07497 L
.06792 .0639 L
.07289 .05584 L
.08259 .0444 L
.08803 .03988 L
.09391 .03613 L
.09947 .03343 L
.10458 .03151 L
.10928 .03012 L
.11432 .02894 L
.11907 .02808 L
.1234 .02746 L
.12849 .0269 L
.13117 .02666 L
.13402 .02645 L
.1365 .0263 L
.13924 .02616 L
.14174 .02605 L
.14407 .02598 L
.14642 .02592 L
.14766 .0259 L
.14898 .02588 L
.14965 .02588 L
.15038 .02587 L
.1517 .02587 L
.15298 .02587 L
.15416 .02587 L
.15527 .02588 L
.1563 .0259 L
.15744 .02592 L
.15866 .02595 L
.16114 .02603 L
.16341 .02612 L
.17424 .02685 L
Mistroke
.17695 .02704 L
.1795 .02719 L
.18179 .02729 L
.18308 .02733 L
.18427 .02735 L
.18538 .02737 L
.18641 .02737 L
.18754 .02737 L
.18875 .02737 L
.19003 .02735 L
.19123 .02732 L
.19348 .02726 L
.19593 .02717 L
.19819 .02708 L
.20329 .02683 L
.214 .02627 L
.22403 .02584 L
.23304 .02556 L
.2381 .02544 L
.24273 .02536 L
.24506 .02533 L
.24754 .0253 L
.24896 .02529 L
.25026 .02528 L
.25148 .02527 L
.25278 .02526 L
.25414 .02526 L
.25539 .02525 L
.25609 .02525 L
.25674 .02525 L
.25746 .02525 L
.25822 .02525 L
.25888 .02525 L
.2596 .02525 L
.2609 .02525 L
.26217 .02526 L
.26335 .02526 L
.26576 .02528 L
.26797 .02529 L
.27296 .02534 L
.28199 .02543 L
.2845 .02546 L
.28718 .02548 L
.28967 .0255 L
.29202 .02552 L
.29329 .02552 L
.29395 .02552 L
.29466 .02553 L
.29591 .02553 L
.29706 .02553 L
Mistroke
.29772 .02553 L
.29842 .02553 L
.29969 .02553 L
.30047 .02553 L
.3012 .02552 L
.30258 .02552 L
.30383 .02552 L
.30518 .02551 L
.30762 .02549 L
.31218 .02545 L
.3224 .02534 L
.3408 .02511 L
.36075 .02493 L
.3708 .02486 L
.38182 .0248 L
.39204 .02476 L
.40134 .02474 L
.41209 .02471 L
.42226 .02469 L
.43193 .02468 L
.44219 .02467 L
.46061 .02465 L
.46999 .02464 L
.4801 .02464 L
.49838 .02463 L
.50796 .02463 L
.51844 .02463 L
.53954 .02462 L
.55917 .02462 L
.58013 .02462 L
.60149 .02462 L
.62164 .02462 L
.66013 .02461 L
.68002 .02461 L
.70107 .02461 L
.73897 .02461 L
.77933 .02461 L
.81818 .02461 L
.85948 .02461 L
.89926 .02461 L
.93752 .02461 L
.97619 .02461 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.02846 .08428 L
.03279 .13727 L
.03523 .16118 L
.03754 .17965 L
.0402 .19609 L
.04135 .20169 L
.04262 .20686 L
.04377 .21071 L
.04502 .21401 L
.04633 .2166 L
.04756 .21828 L
.04878 .21928 L
.04994 .21969 L
.05099 .21965 L
.05212 .2192 L
.05282 .21873 L
.05348 .21818 L
.05471 .21685 L
.05748 .21277 L
.06244 .20279 L
.07312 .1776 L
.08439 .1537 L
.09401 .13805 L
.09954 .13106 L
.10458 .12585 L
.10919 .12197 L
.1142 .1186 L
.11695 .11711 L
.1195 .11593 L
.12209 .11493 L
.12452 .11417 L
.12658 .11365 L
.12881 .11322 L
.13001 .11304 L
.13128 .1129 L
.13236 .11282 L
.13354 .11276 L
.1348 .11275 L
.13594 .11278 L
.13726 .11286 L
.13851 .11299 L
.13966 .11315 L
.14073 .11334 L
.14313 .11392 L
.14557 .11476 L
.1478 .11577 L
.15038 .11729 L
.15282 .11915 L
.15716 .12383 L
Mistroke
.15962 .12753 L
.16189 .13188 L
.1646 .13846 L
.16714 .14624 L
.17189 .16438 L
.17697 .18478 L
.17966 .19378 L
.18113 .19786 L
.18253 .20111 L
.1838 .20352 L
.18519 .20557 L
.18644 .20693 L
.1876 .20779 L
.18869 .20826 L
.18989 .20843 L
.19115 .20826 L
.19232 .20778 L
.19359 .20698 L
.19492 .20584 L
.1973 .20316 L
.20265 .19501 L
.22114 .16157 L
.23071 .14742 L
.23596 .14117 L
.24092 .13624 L
.24554 .13244 L
.25055 .12912 L
.2593 .12498 L
.2642 .12332 L
.26879 .12202 L
.27921 .11936 L
.30027 .11404 L
.3107 .11179 L
.3206 .1101 L
.32948 .10895 L
.33446 .10844 L
.33914 .10805 L
.34404 .10771 L
.34853 .10746 L
.35351 .10725 L
.3563 .10715 L
.35889 .10708 L
.36125 .10703 L
.36378 .10699 L
.36522 .10697 L
.36657 .10696 L
.3678 .10695 L
.36848 .10695 L
.36912 .10694 L
.37041 .10694 L
Mistroke
.37161 .10694 L
.37293 .10694 L
.37367 .10695 L
.37435 .10695 L
.37571 .10696 L
.37719 .10697 L
.37989 .10701 L
.38245 .10705 L
.38521 .1071 L
.39022 .10723 L
.39958 .10754 L
.42056 .10847 L
.46158 .11054 L
.50109 .11257 L
.53908 .11459 L
.57953 .11672 L
.61845 .11872 L
.65984 .12076 L
.6997 .12264 L
.73805 .12438 L
.77885 .12617 L
.81814 .12785 L
.85591 .12944 L
.89613 .13112 L
.93484 .13273 L
.976 .13443 L
.97619 .13444 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.02846 .08426 L
.03279 .13671 L
.03527 .15988 L
.03754 .17601 L
.03879 .18286 L
.04015 .18866 L
.04143 .19263 L
.04262 .19506 L
.04376 .19637 L
.04498 .19676 L
.04614 .19626 L
.0472 .19515 L
.04843 .19317 L
.04978 .1903 L
.05224 .18363 L
.06244 .14809 L
.07302 .1145 L
.07883 .09997 L
.08429 .08878 L
.08941 .08025 L
.09493 .07281 L
.09992 .06744 L
.10458 .06339 L
.10955 .05991 L
.11408 .05737 L
.11912 .05515 L
.12452 .05335 L
.1297 .0521 L
.13263 .05156 L
.13534 .05118 L
.1377 .05092 L
.13906 .0508 L
.1403 .05072 L
.14161 .05065 L
.1423 .05062 L
.14303 .0506 L
.14425 .05058 L
.14494 .05057 L
.14558 .05057 L
.14686 .0506 L
.1475 .05062 L
.14821 .05065 L
.14946 .05072 L
.15063 .05081 L
.15201 .05094 L
.15327 .0511 L
.15611 .05156 L
.15854 .05212 L
.1612 .05293 L
Mistroke
.16371 .05392 L
.16604 .05507 L
.17498 .06122 L
.17967 .06435 L
.18204 .06552 L
.18338 .06603 L
.18463 .0664 L
.18535 .06657 L
.18602 .0667 L
.18729 .06687 L
.18801 .06693 L
.18866 .06695 L
.18938 .06696 L
.19015 .06693 L
.1914 .06683 L
.19256 .06667 L
.19384 .06644 L
.19522 .06612 L
.20043 .0645 L
.20519 .06264 L
.22381 .05552 L
.22857 .0541 L
.23364 .05282 L
.24277 .05108 L
.24836 .05033 L
.25363 .0498 L
.25836 .04946 L
.26103 .04932 L
.26349 .04921 L
.26818 .04906 L
.27081 .04899 L
.27321 .04895 L
.28229 .0488 L
.28736 .0487 L
.29289 .04856 L
.30294 .0482 L
.3223 .04735 L
.33259 .04695 L
.34369 .04661 L
.35424 .04637 L
.36392 .04622 L
.37317 .04611 L
.38293 .04603 L
.39245 .04597 L
.40264 .04591 L
.421 .04584 L
.43123 .0458 L
.44232 .04577 L
.45191 .04574 L
.46247 .04572 L
Mistroke
.47272 .04571 L
.48232 .0457 L
.49246 .04569 L
.50335 .04568 L
.51347 .04568 L
.5245 .04567 L
.53493 .04567 L
.5446 .04567 L
.54968 .04566 L
.55518 .04566 L
.5577 .04566 L
.56036 .04566 L
.56267 .04566 L
.56514 .04566 L
.56754 .04566 L
.56973 .04566 L
.57078 .04566 L
.57193 .04566 L
.57301 .04566 L
.57401 .04566 L
.57517 .04566 L
.57626 .04566 L
.57745 .04566 L
.57873 .04566 L
.58001 .04566 L
.58135 .04566 L
.58375 .04566 L
.58875 .04566 L
.5933 .04566 L
.6035 .04566 L
.62188 .04567 L
.66188 .04568 L
.70036 .04569 L
.7413 .0457 L
.78073 .04571 L
.81863 .04572 L
.85899 .04572 L
.89784 .04573 L
.93913 .04574 L
.97619 .04575 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.02846 .08442 L
.03279 .13907 L
.03754 .18694 L
.04262 .22455 L
.04518 .2386 L
.04795 .25053 L
.05058 .25894 L
.05183 .26207 L
.053 .26453 L
.05518 .26801 L
.05634 .26932 L
.05758 .27036 L
.05889 .27106 L
.06012 .27139 L
.06123 .27145 L
.06244 .27126 L
.06316 .27104 L
.06382 .27077 L
.0653 .26995 L
.06661 .269 L
.06799 .2678 L
.07302 .26217 L
.08429 .24634 L
.09408 .23322 L
.09947 .22711 L
.10458 .22222 L
.1095 .2184 L
.11209 .21674 L
.11485 .21524 L
.11716 .2142 L
.11972 .21329 L
.12083 .21296 L
.12204 .21267 L
.12309 .21245 L
.12422 .21227 L
.12537 .21214 L
.12644 .21206 L
.12772 .21203 L
.12888 .21206 L
.13009 .21216 L
.1314 .21233 L
.13264 .21256 L
.13378 .21284 L
.13581 .2135 L
.13804 .21447 L
.14037 .21579 L
.14255 .21735 L
.14753 .22233 L
.15035 .22626 L
Mistroke
.15296 .23084 L
.15774 .24237 L
.16042 .25112 L
.16284 .26079 L
.17186 .30952 L
.17678 .33637 L
.17919 .34711 L
.18138 .3551 L
.18369 .3616 L
.18496 .36432 L
.18617 .36633 L
.18748 .36793 L
.18869 .36889 L
.18932 .3692 L
.19002 .36939 L
.19074 .36944 L
.19143 .36934 L
.19256 .36889 L
.19375 .36805 L
.19476 .36707 L
.19587 .36572 L
.19835 .36184 L
.20066 .35733 L
.22149 .30337 L
.22656 .29162 L
.23204 .28065 L
.23688 .27265 L
.24199 .26591 L
.24661 .26136 L
.24923 .2594 L
.25168 .25797 L
.25392 .25698 L
.25598 .25633 L
.25711 .25607 L
.25835 .25587 L
.25951 .25574 L
.26059 .25569 L
.26177 .2557 L
.263 .25578 L
.26406 .25591 L
.26521 .25611 L
.26646 .2564 L
.2678 .2568 L
.2702 .25774 L
.27263 .259 L
.27493 .26049 L
.27923 .26405 L
.28911 .27549 L
.29983 .29023 L
.31008 .30286 L
Mistroke
.31968 .31156 L
.3245 .31474 L
.32969 .31744 L
.34071 .32154 L
.35026 .32457 L
.36044 .32856 L
.3716 .33465 L
.38196 .34198 L
.40105 .35767 L
.42169 .37328 L
.44311 .38515 L
.46329 .39306 L
.50431 .40491 L
.52475 .4095 L
.54382 .41297 L
.58181 .41807 L
.62074 .42192 L
.66212 .42532 L
.70198 .42831 L
.74033 .43116 L
.78114 .4343 L
.82042 .43743 L
.85819 .44052 L
.89842 .44383 L
.93712 .44697 L
.97619 .45002 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.02846 .08427 L
.03279 .13665 L
.03527 .15946 L
.03754 .17487 L
.03879 .18114 L
.03945 .1838 L
.04015 .18615 L
.04143 .18925 L
.04262 .19081 L
.04384 .19123 L
.04496 .19066 L
.04626 .18904 L
.04749 .18669 L
.04967 .18101 L
.05205 .17329 L
.06244 .13469 L
.07302 .10178 L
.07893 .08783 L
.08429 .07766 L
.08931 .06997 L
.09474 .06331 L
.09983 .05835 L
.10458 .05465 L
.10955 .05156 L
.11408 .04932 L
.11912 .04735 L
.12452 .04576 L
.1297 .04463 L
.13263 .04415 L
.13534 .04379 L
.1377 .04354 L
.1403 .04333 L
.14161 .04325 L
.1423 .04322 L
.14303 .04318 L
.14366 .04316 L
.14436 .04314 L
.14558 .04312 L
.1469 .04311 L
.14812 .04312 L
.14875 .04313 L
.14945 .04315 L
.15018 .04318 L
.15087 .04321 L
.15213 .04328 L
.15327 .04336 L
.15586 .04361 L
.15815 .04393 L
.16065 .04439 L
Mistroke
.16301 .04495 L
.16519 .04559 L
.17038 .04759 L
.17599 .05008 L
.17856 .05108 L
.17997 .05155 L
.18128 .05192 L
.1825 .0522 L
.1836 .05241 L
.18483 .05258 L
.18614 .0527 L
.18742 .05276 L
.18807 .05277 L
.18878 .05277 L
.19003 .05272 L
.19121 .05263 L
.19188 .05256 L
.19259 .05248 L
.19386 .0523 L
.19671 .0518 L
.20671 .04937 L
.21647 .04693 L
.22533 .04512 L
.22992 .04438 L
.2349 .04372 L
.24015 .04318 L
.24251 .04299 L
.24511 .04282 L
.24735 .04269 L
.24976 .04259 L
.25109 .04255 L
.2523 .04252 L
.25352 .04249 L
.25468 .04247 L
.25574 .04246 L
.25687 .04246 L
.25783 .04246 L
.25889 .04247 L
.26003 .04248 L
.26126 .04251 L
.26242 .04253 L
.26349 .04256 L
.26596 .04266 L
.26822 .04277 L
.27327 .04309 L
.28239 .0438 L
.28749 .04415 L
.29037 .0443 L
.29174 .04436 L
.29303 .04441 L
Mistroke
.29424 .04445 L
.29535 .04447 L
.29658 .04449 L
.29726 .0445 L
.29791 .04451 L
.29919 .04451 L
.30038 .04451 L
.30169 .0445 L
.30242 .04449 L
.30308 .04448 L
.30541 .04442 L
.30673 .04438 L
.30796 .04433 L
.31311 .04408 L
.32234 .04348 L
.34316 .04205 L
.35363 .04147 L
.36353 .04104 L
.37242 .04073 L
.38209 .04047 L
.3915 .04028 L
.40188 .04011 L
.41272 .03998 L
.4229 .03988 L
.43274 .03981 L
.44309 .03974 L
.4616 .03966 L
.47116 .03962 L
.48136 .03959 L
.49973 .03955 L
.52109 .03952 L
.54125 .03949 L
.57973 .03946 L
.59963 .03945 L
.62067 .03944 L
.65858 .03942 L
.69894 .03941 L
.73778 .0394 L
.77908 .03939 L
.81886 .03939 L
.85713 .03938 L
.89784 .03938 L
.93705 .03937 L
.97619 .03937 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.02846 .08442 L
.03279 .13889 L
.03754 .18546 L
.0402 .20503 L
.04262 .21869 L
.04385 .22414 L
.04516 .22883 L
.04627 .23199 L
.0475 .2346 L
.04882 .23643 L
.04957 .23705 L
.05024 .23737 L
.05156 .23735 L
.05281 .23662 L
.05397 .23539 L
.0552 .23355 L
.05742 .22908 L
.06244 .21504 L
.07287 .17998 L
.08414 .14628 L
.08932 .13384 L
.09479 .12281 L
.10458 .10786 L
.10953 .1023 L
.11483 .09756 L
.11984 .0941 L
.1244 .09169 L
.127 .0906 L
.12975 .08966 L
.13119 .08925 L
.13278 .08887 L
.13424 .08857 L
.13558 .08835 L
.13686 .08819 L
.1382 .08806 L
.1389 .08801 L
.13956 .08798 L
.14027 .08796 L
.14104 .08796 L
.1417 .08796 L
.14242 .08799 L
.14372 .08807 L
.14499 .0882 L
.14616 .08837 L
.14741 .08861 L
.1486 .08889 L
.15084 .08957 L
.15324 .09057 L
.15586 .09204 L
Mistroke
.15814 .09372 L
.16056 .09604 L
.16285 .09884 L
.16493 .102 L
.17004 .11272 L
.17556 .12776 L
.17806 .13447 L
.18074 .14071 L
.18326 .14533 L
.18438 .14693 L
.18557 .14833 L
.18679 .14945 L
.18791 .1502 L
.18913 .15072 L
.18982 .15088 L
.19046 .15096 L
.19163 .15091 L
.19269 .15067 L
.19386 .15021 L
.1951 .14952 L
.19768 .14748 L
.20009 .14502 L
.20554 .13814 L
.21639 .1229 L
.22662 .11032 L
.23646 .10119 L
.24201 .09733 L
.24712 .09452 L
.25143 .09263 L
.25616 .09101 L
.2611 .08975 L
.26572 .08888 L
.27071 .08818 L
.27615 .0876 L
.28605 .08666 L
.30459 .08434 L
.32396 .08167 L
.33498 .08047 L
.34534 .07962 L
.35519 .07904 L
.36422 .07866 L
.37413 .07837 L
.37912 .07825 L
.38458 .07815 L
.39484 .078 L
.40416 .0779 L
.41493 .07781 L
.42511 .07774 L
.43481 .07769 L
.44012 .07767 L
Mistroke
.4451 .07765 L
.45388 .07763 L
.45853 .07762 L
.46354 .07761 L
.46608 .07761 L
.46747 .07761 L
.46879 .07761 L
.47001 .07761 L
.47134 .07761 L
.47255 .07761 L
.47366 .07761 L
.47429 .07761 L
.47498 .07761 L
.47621 .07761 L
.47697 .07761 L
.47768 .07761 L
.47833 .07761 L
.47902 .07761 L
.4797 .07761 L
.48045 .07761 L
.48197 .07761 L
.48469 .07761 L
.48729 .07761 L
.48968 .07761 L
.49506 .07762 L
.50479 .07763 L
.52372 .07766 L
.54443 .0777 L
.58501 .0778 L
.62408 .0779 L
.66559 .07799 L
.70559 .07808 L
.74408 .07815 L
.78502 .07821 L
.82444 .07826 L
.86235 .07831 L
.90271 .07836 L
.94155 .0784 L
.97619 .07843 L
Mfstroke
0 1 .111 r
.02381 .01472 m
.02499 .03249 L
.02605 .04454 L
.02729 .05223 L
.02846 .055 L
.02954 .05548 L
.03053 .055 L
.03163 .05396 L
.03279 .05255 L
.04262 .03964 L
.04716 .03494 L
.05205 .03085 L
.05742 .02734 L
.06244 .02479 L
.06784 .02267 L
.07373 .02093 L
.07929 .0197 L
.08445 .01882 L
.08956 .01816 L
.09419 .01769 L
.09954 .01726 L
.10458 .01696 L
.10923 .01674 L
.11434 .01655 L
.11968 .0164 L
.12466 .01629 L
.12932 .01622 L
.13357 .01616 L
.13848 .01611 L
.14313 .01608 L
.14772 .01605 L
.15278 .01603 L
.15533 .01602 L
.15807 .01602 L
.15934 .01601 L
.16066 .01601 L
.16191 .01601 L
.16304 .01601 L
.16417 .01601 L
.16524 .01601 L
.16637 .01601 L
.1676 .01601 L
.16867 .01601 L
.1698 .01601 L
.17077 .01601 L
.17184 .01601 L
.17423 .01601 L
.17492 .01601 L
.17558 .01601 L
.17681 .01601 L
Mistroke
.17796 .01601 L
.17903 .01601 L
.18021 .01601 L
.18146 .01601 L
.18271 .01601 L
.18408 .016 L
.18683 .016 L
.19177 .016 L
.20291 .01598 L
.21348 .01596 L
.22309 .01595 L
.22791 .01594 L
.23314 .01594 L
.23808 .01594 L
.24264 .01593 L
.24747 .01593 L
.2528 .01593 L
.25836 .01593 L
.26357 .01593 L
.30231 .01592 L
.322 .01592 L
.3324 .01592 L
.3435 .01592 L
.35429 .01592 L
.36407 .01592 L
.37391 .01592 L
.38318 .01592 L
.39293 .01592 L
.40323 .01592 L
.41289 .01592 L
.4217 .01592 L
.43116 .01592 L
.43637 .01592 L
.44131 .01592 L
.44587 .01592 L
.45009 .01592 L
.45228 .01592 L
.45471 .01592 L
.45594 .01592 L
.45725 .01592 L
.45848 .01592 L
.45964 .01592 L
.46089 .01592 L
.46203 .01592 L
.46325 .01592 L
.46395 .01592 L
.46459 .01592 L
.46565 .01592 L
.46682 .01592 L
.46805 .01592 L
Mistroke
.46919 .01592 L
.47183 .01592 L
.47423 .01592 L
.47965 .01592 L
.49047 .01592 L
.50074 .01592 L
.53896 .01592 L
.57962 .01592 L
.61877 .01592 L
.66037 .01592 L
.70046 .01592 L
.73903 .01592 L
.75899 .01592 L
.78005 .01592 L
.79993 .01592 L
.81805 .01592 L
.83757 .01592 L
.85849 .01592 L
.87759 .01592 L
.89836 .01592 L
.91815 .01592 L
.92826 .01592 L
.93916 .01592 L
.95826 .01592 L
.97619 .01592 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.02846 .08443 L
.03279 .13936 L
.03793 .19225 L
.04262 .22964 L
.04754 .25917 L
.0522 .27905 L
.05475 .28707 L
.05711 .29285 L
.0597 .29761 L
.06101 .29944 L
.06244 .30104 L
.06379 .30219 L
.0645 .30266 L
.06525 .30307 L
.06598 .30338 L
.06663 .30359 L
.06792 .30382 L
.06916 .30384 L
.06985 .30376 L
.0705 .30364 L
.07168 .3033 L
.07293 .30279 L
.07427 .30208 L
.07571 .30116 L
.0783 .29916 L
.0842 .29345 L
.09479 .28191 L
.10458 .27247 L
.10951 .26871 L
.11475 .2656 L
.11747 .26439 L
.12001 .2635 L
.12147 .2631 L
.12281 .26282 L
.12357 .26269 L
.12427 .26259 L
.12501 .26251 L
.12582 .26245 L
.12708 .26241 L
.12779 .26242 L
.12844 .26245 L
.12964 .26255 L
.13092 .26274 L
.13206 .26297 L
.13312 .26326 L
.13555 .26412 L
.13817 .26545 L
.14056 .26705 L
.14332 .26943 L
Mistroke
.14594 .27231 L
.14854 .27586 L
.15099 .27997 L
.15555 .2902 L
.15812 .29779 L
.16047 .3062 L
.16579 .33075 L
.17467 .38132 L
.17956 .40493 L
.18196 .41404 L
.18419 .42086 L
.18663 .42661 L
.18793 .42893 L
.1893 .43087 L
.19044 .43211 L
.19151 .43295 L
.19268 .43356 L
.19395 .43385 L
.19505 .43381 L
.19626 .43349 L
.19753 .43285 L
.1987 .43201 L
.2008 .42996 L
.20305 .42711 L
.21389 .4076 L
.22373 .38859 L
.22859 .38085 L
.23125 .3774 L
.23373 .37481 L
.23585 .37314 L
.23704 .37244 L
.23812 .37198 L
.23931 .37167 L
.2406 .37157 L
.24182 .37174 L
.24295 .37214 L
.24414 .37282 L
.24542 .37388 L
.24663 .37521 L
.24774 .37674 L
.25032 .38148 L
.25304 .38839 L
.25816 .40653 L
.26376 .4316 L
.27383 .47709 L
.27878 .49557 L
.28335 .50955 L
.28861 .52204 L
.29138 .52715 L
.29431 .53156 L
Mistroke
.2966 .53432 L
.29906 .53668 L
.30047 .53776 L
.30176 .53859 L
.30306 .53928 L
.30429 .53981 L
.30549 .5402 L
.30679 .5405 L
.30797 .54067 L
.30906 .54074 L
.31024 .54073 L
.31153 .54062 L
.31218 .54053 L
.31288 .54041 L
.31414 .54011 L
.3166 .53932 L
.31893 .53833 L
.32329 .53596 L
.34402 .52103 L
.35368 .51483 L
.36394 .50984 L
.3727 .50677 L
.38237 .50424 L
.40336 .49935 L
.42259 .49332 L
.4613 .47734 L
.50094 .4623 L
.53907 .44987 L
.57965 .43755 L
.61872 .42677 L
.66023 .41665 L
.70024 .4082 L
.73872 .40126 L
.77966 .39505 L
.81908 .39004 L
.85699 .38596 L
.89735 .38225 L
.93619 .37916 L
.97619 .37637 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.02846 .08442 L
.03279 .13915 L
.03754 .18734 L
.04262 .22574 L
.04518 .24035 L
.04795 .25301 L
.05058 .26221 L
.053 .26858 L
.05518 .27279 L
.05642 .27461 L
.05758 .27596 L
.05881 .27705 L
.05993 .27777 L
.06122 .27829 L
.06244 .27851 L
.0631 .27853 L
.06381 .27847 L
.0651 .27819 L
.06635 .2777 L
.0675 .2771 L
.07012 .27522 L
.07289 .27265 L
.08259 .26109 L
.0932 .24793 L
.09905 .24163 L
.10458 .23661 L
.1095 .23299 L
.11209 .23142 L
.11485 .23001 L
.11716 .22905 L
.11972 .22821 L
.12083 .22792 L
.12204 .22766 L
.12318 .22746 L
.12422 .22733 L
.12529 .22724 L
.12643 .22719 L
.1275 .22719 L
.12848 .22724 L
.12963 .22735 L
.13088 .22753 L
.13206 .22776 L
.13315 .22804 L
.13532 .22877 L
.13772 .22987 L
.14021 .23138 L
.14255 .23317 L
.14753 .2385 L
.15035 .24266 L
Mistroke
.15296 .24749 L
.15774 .25955 L
.16042 .26863 L
.16284 .27859 L
.17186 .32792 L
.17678 .35488 L
.18138 .37394 L
.18369 .38073 L
.18488 .38346 L
.18617 .38587 L
.1869 .38698 L
.18758 .38785 L
.18822 .38852 L
.18892 .38912 L
.19014 .38979 L
.19143 .39002 L
.19262 .38983 L
.19372 .38933 L
.19493 .38845 L
.19619 .38718 L
.19833 .38432 L
.20066 .38032 L
.21146 .35481 L
.22149 .32876 L
.23204 .30535 L
.23722 .29618 L
.24199 .28922 L
.24625 .28422 L
.25092 .27999 L
.25562 .27694 L
.25819 .27571 L
.26059 .27479 L
.26319 .27401 L
.26559 .27348 L
.26684 .27326 L
.26822 .27307 L
.26892 .273 L
.26967 .27293 L
.27038 .27289 L
.27103 .27286 L
.27222 .27284 L
.27333 .27286 L
.27454 .27292 L
.27584 .27305 L
.2765 .27313 L
.27721 .27324 L
.2785 .27347 L
.28092 .27407 L
.28315 .2748 L
.2856 .27579 L
Mistroke
.29057 .27833 L
.29947 .28413 L
.33978 .30422 L
.34876 .30679 L
.35833 .31005 L
.36883 .31489 L
.37857 .3208 L
.39972 .33726 L
.41981 .35382 L
.46141 .38087 L
.5015 .40078 L
.54007 .41713 L
.58109 .4314 L
.6206 .44301 L
.65859 .4528 L
.69904 .46207 L
.73797 .47014 L
.77935 .47801 L
.81921 .48503 L
.85756 .49131 L
.89836 .49753 L
.93765 .50306 L
.97542 .50795 L
.97619 .50804 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.02605 .04944 L
.02729 .06655 L
.02846 .08065 L
.02954 .09154 L
.03072 .10063 L
.0318 .1064 L
.03279 .1098 L
.03396 .11177 L
.03506 .11202 L
.03626 .11098 L
.03756 .10878 L
.03891 .10571 L
.0402 .10235 L
.04262 .0955 L
.05221 .06981 L
.05748 .05881 L
.06244 .05046 L
.06792 .04318 L
.07289 .038 L
.07761 .0341 L
.08259 .03083 L
.08809 .02803 L
.09315 .02605 L
.0986 .0244 L
.10458 .02304 L
.10982 .02213 L
.11478 .02147 L
.11924 .02101 L
.12409 .02061 L
.12936 .02028 L
.13495 .02002 L
.13973 .01986 L
.14225 .01979 L
.145 .01973 L
.14738 .01969 L
.14992 .01965 L
.15133 .01963 L
.1526 .01962 L
.1539 .01961 L
.1551 .0196 L
.15621 .0196 L
.15738 .0196 L
.15856 .01959 L
.15986 .01959 L
.16098 .0196 L
.16218 .0196 L
.16331 .0196 L
.16435 .01961 L
.16959 .01966 L
Mistroke
.17517 .01973 L
.17789 .01975 L
.17922 .01976 L
.18044 .01977 L
.18155 .01978 L
.18273 .01978 L
.18391 .01978 L
.18521 .01978 L
.18649 .01978 L
.1877 .01978 L
.18878 .01977 L
.18996 .01976 L
.19261 .01974 L
.19505 .01972 L
.20423 .0196 L
.21493 .01946 L
.22497 .01936 L
.23397 .0193 L
.23904 .01927 L
.24367 .01925 L
.24847 .01924 L
.25119 .01923 L
.25372 .01923 L
.2551 .01922 L
.2564 .01922 L
.25758 .01922 L
.25883 .01922 L
.25948 .01922 L
.2602 .01922 L
.26145 .01922 L
.26216 .01922 L
.26292 .01922 L
.26363 .01922 L
.26429 .01922 L
.26546 .01922 L
.26657 .01922 L
.26778 .01922 L
.26908 .01922 L
.27418 .01922 L
.27856 .01923 L
.28335 .01923 L
.28608 .01923 L
.28738 .01923 L
.28862 .01923 L
.28929 .01923 L
.29002 .01923 L
.2913 .01923 L
.29203 .01923 L
.29279 .01923 L
.29345 .01923 L
Mistroke
.29417 .01923 L
.29546 .01923 L
.29664 .01923 L
.298 .01923 L
.2993 .01923 L
.30159 .01923 L
.3041 .01923 L
.30942 .01922 L
.31443 .01922 L
.32379 .0192 L
.33399 .01918 L
.34477 .01917 L
.35435 .01915 L
.36486 .01914 L
.37442 .01914 L
.38334 .01913 L
.4037 .01913 L
.42226 .01912 L
.44298 .01911 L
.46213 .01911 L
.48073 .01911 L
.50048 .01911 L
.53825 .0191 L
.55761 .0191 L
.57847 .0191 L
.59814 .0191 L
.61963 .0191 L
.65928 .0191 L
.69986 .0191 L
.73892 .0191 L
.78044 .0191 L
.82044 .0191 L
.85893 .0191 L
.89987 .0191 L
.93929 .0191 L
.97619 .0191 L
Mfstroke
0 1 .206 r
.02381 .01472 m
.02846 .08443 L
.03279 .13934 L
.03793 .19201 L
.04262 .22877 L
.04498 .24357 L
.04754 .257 L
.04976 .26653 L
.0522 .27497 L
.05478 .28174 L
.0562 .28459 L
.05753 .28675 L
.05874 .28831 L
.0599 .28946 L
.06053 .28997 L
.06123 .29041 L
.06244 .29094 L
.06316 .29112 L
.06382 .29119 L
.06454 .29119 L
.0653 .29108 L
.06658 .2907 L
.06731 .29037 L
.06799 .29 L
.07042 .2882 L
.07302 .28558 L
.08429 .26971 L
.09483 .25379 L
.10458 .24153 L
.10951 .23666 L
.11475 .23256 L
.11728 .23099 L
.12001 .22959 L
.12158 .22894 L
.12301 .22843 L
.12437 .22803 L
.12582 .22769 L
.12709 .22748 L
.12824 .22735 L
.12941 .22728 L
.1305 .22727 L
.13178 .22734 L
.13296 .22748 L
.13425 .22771 L
.13562 .22806 L
.13685 .22846 L
.13816 .22899 L
.14054 .23023 L
.14336 .23223 L
.14594 .23465 L
Mistroke
.15072 .24098 L
.15339 .24587 L
.15581 .2514 L
.15808 .25773 L
.16053 .26608 L
.16496 .28583 L
.17486 .34458 L
.18009 .37183 L
.18303 .3834 L
.1857 .39138 L
.18825 .39678 L
.18969 .39893 L
.19037 .39974 L
.19101 .40037 L
.19217 .40122 L
.19345 .40174 L
.1947 .40186 L
.1954 .40176 L
.19604 .40158 L
.1972 .40103 L
.19829 .40028 L
.19947 .39921 L
.20074 .39781 L
.20568 .39031 L
.21665 .36787 L
.22676 .34863 L
.22934 .34485 L
.23175 .34192 L
.23426 .33959 L
.2356 .3387 L
.23634 .33831 L
.23703 .33804 L
.23771 .33784 L
.23844 .33772 L
.23976 .33774 L
.24049 .3379 L
.24117 .33815 L
.24192 .33854 L
.24273 .33911 L
.24411 .34045 L
.24555 .34242 L
.24679 .34459 L
.24814 .34754 L
.25079 .35515 L
.25319 .36431 L
.25858 .39157 L
.26831 .4474 L
.27315 .47116 L
.27827 .49154 L
.28265 .50496 L
Mistroke
.28747 .51576 L
.29017 .52013 L
.29264 .52315 L
.29401 .52443 L
.29549 .52554 L
.29617 .52595 L
.2969 .52631 L
.2982 .5268 L
.29951 .52708 L
.30024 .52715 L
.30092 .52715 L
.30216 .52702 L
.30348 .5267 L
.30466 .52626 L
.30576 .52572 L
.30826 .52406 L
.31086 .52174 L
.31327 .51911 L
.31872 .51171 L
.32862 .49472 L
.34719 .45977 L
.36745 .4284 L
.38647 .40744 L
.42424 .37686 L
.46295 .35109 L
.483 .34086 L
.50411 .33236 L
.54224 .3208 L
.58282 .31145 L
.62188 .30441 L
.6634 .29849 L
.7034 .29392 L
.74189 .29038 L
.78283 .28731 L
.82225 .2849 L
.86016 .28296 L
.90052 .28119 L
.93936 .27972 L
.97619 .2785 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.02846 .08443 L
.03279 .13934 L
.03793 .19207 L
.04262 .22907 L
.04498 .24411 L
.04754 .25793 L
.0522 .27698 L
.05478 .28459 L
.05753 .29064 L
.05987 .29436 L
.0612 .29594 L
.06244 .29711 L
.0631 .2976 L
.06379 .29804 L
.06504 .29864 L
.06581 .29889 L
.06653 .29904 L
.06718 .29911 L
.06788 .29913 L
.06919 .299 L
.06985 .29886 L
.07057 .29866 L
.07185 .29816 L
.07305 .29757 L
.07549 .29601 L
.07773 .29425 L
.08274 .28953 L
.09409 .27759 L
.09907 .27273 L
.10458 .26804 L
.10903 .26489 L
.11383 .26222 L
.11648 .26109 L
.1189 .26028 L
.12122 .25972 L
.12239 .25951 L
.12366 .25935 L
.12434 .25929 L
.12507 .25924 L
.12575 .25922 L
.12639 .25922 L
.12759 .25927 L
.12886 .25939 L
.12952 .25947 L
.13023 .25959 L
.13151 .25987 L
.13303 .2603 L
.13442 .2608 L
.13688 .26195 L
Mistroke
.13955 .26361 L
.14208 .26564 L
.14443 .26798 L
.14952 .27492 L
.15239 .28027 L
.15502 .28637 L
.15987 .30147 L
.16499 .324 L
.17473 .37795 L
.17899 .39789 L
.18123 .40626 L
.18361 .41335 L
.18481 .41624 L
.18615 .41889 L
.18737 .42084 L
.18849 .42222 L
.18964 .42326 L
.19087 .42397 L
.19196 .42426 L
.19311 .42425 L
.19433 .42389 L
.19563 .42314 L
.19686 .42212 L
.19797 .42095 L
.20071 .41721 L
.20328 .41273 L
.22163 .37067 L
.23138 .35145 L
.23629 .34436 L
.23908 .34129 L
.24033 .34017 L
.24168 .33912 L
.24293 .33834 L
.24408 .33778 L
.24517 .33738 L
.24634 .33713 L
.24738 .33705 L
.24836 .3371 L
.24943 .33731 L
.25059 .33773 L
.25175 .33834 L
.25302 .33925 L
.25434 .34048 L
.25558 .34187 L
.25779 .34502 L
.26015 .34932 L
.26547 .36252 L
.27038 .37853 L
.28147 .42111 L
.28648 .43944 L
Mistroke
.29187 .45668 L
.29653 .4691 L
.30161 .47995 L
.30663 .48808 L
.30894 .49103 L
.3114 .49369 L
.31384 .49588 L
.31605 .49751 L
.31814 .49878 L
.32035 .49986 L
.32301 .50086 L
.32546 .50153 L
.32682 .50181 L
.32809 .50203 L
.32958 .50223 L
.33098 .50238 L
.33219 .50248 L
.33351 .50256 L
.3347 .50262 L
.33581 .50266 L
.337 .5027 L
.33832 .50273 L
.34099 .50278 L
.34334 .50283 L
.34467 .50287 L
.34591 .50292 L
.34841 .50305 L
.34982 .50315 L
.35109 .50326 L
.35338 .50351 L
.35585 .50385 L
.36035 .50467 L
.36562 .50595 L
.3712 .50762 L
.38121 .51108 L
.39138 .51462 L
.40102 .51749 L
.40968 .51943 L
.41458 .52022 L
.41912 .52077 L
.42167 .521 L
.42407 .52117 L
.42622 .52129 L
.42854 .52138 L
.42976 .52142 L
.43046 .52143 L
.43109 .52144 L
.43176 .52145 L
.43248 .52146 L
.43377 .52146 L
Mistroke
.43496 .52146 L
.43624 .52145 L
.43746 .52143 L
.43858 .52141 L
.44107 .52134 L
.4434 .52125 L
.44872 .52098 L
.45948 .52024 L
.49824 .51674 L
.53945 .51182 L
.57914 .50583 L
.61732 .49977 L
.65796 .49352 L
.69707 .48796 L
.73864 .48276 L
.7787 .4785 L
.81724 .47504 L
.85823 .47197 L
.8977 .46948 L
.93566 .46743 L
.97607 .46551 L
.97619 .4655 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.02846 .08418 L
.03279 .13542 L
.03406 .14714 L
.03527 .15657 L
.03637 .1637 L
.03754 .16977 L
.0388 .17464 L
.03997 .17762 L
.04123 .17933 L
.04195 .17966 L
.04262 .1796 L
.04384 .17864 L
.04453 .17767 L
.04517 .17652 L
.04761 .1705 L
.05217 .1549 L
.06244 .11716 L
.06795 .10011 L
.07314 .08673 L
.08284 .06791 L
.08828 .06026 L
.09328 .05466 L
.09878 .0498 L
.10458 .04584 L
.10954 .04322 L
.11406 .04131 L
.11928 .03959 L
.12422 .03834 L
.12878 .03745 L
.133 .03683 L
.13763 .03633 L
.13997 .03614 L
.14131 .03605 L
.14255 .03598 L
.14378 .03593 L
.1449 .03588 L
.14614 .03585 L
.14682 .03583 L
.14747 .03582 L
.14876 .03581 L
.14995 .03581 L
.15126 .03583 L
.15192 .03584 L
.15264 .03586 L
.15385 .0359 L
.15495 .03595 L
.15613 .03602 L
.15743 .03611 L
.15972 .03632 L
Mistroke
.1619 .03658 L
.16465 .037 L
.16714 .03748 L
.17272 .03884 L
.17751 .04005 L
.18022 .04061 L
.18155 .04083 L
.18275 .04099 L
.18389 .04112 L
.18512 .04123 L
.18642 .0413 L
.18765 .04134 L
.18895 .04134 L
.1896 .04133 L
.19033 .04131 L
.19161 .04125 L
.19281 .04118 L
.19513 .04098 L
.19725 .04074 L
.20204 .04007 L
.21284 .03835 L
.22287 .03692 L
.23205 .03591 L
.23718 .03547 L
.24184 .03516 L
.24695 .03489 L
.24965 .03477 L
.2525 .03467 L
.25499 .0346 L
.25773 .03453 L
.26023 .03448 L
.26255 .03445 L
.26505 .03442 L
.26635 .03441 L
.26778 .0344 L
.27018 .03439 L
.2715 .03438 L
.27274 .03438 L
.27507 .03437 L
.27721 .03437 L
.27954 .03437 L
.28204 .03436 L
.28335 .03436 L
.28455 .03436 L
.2869 .03435 L
.28963 .03433 L
.29222 .03432 L
.29736 .03427 L
.30294 .0342 L
.3224 .03386 L
Mistroke
.33273 .03368 L
.34383 .03352 L
.35445 .03341 L
.36416 .03333 L
.37392 .03327 L
.3832 .03323 L
.40302 .03317 L
.42141 .03313 L
.44195 .03309 L
.46056 .03307 L
.4706 .03306 L
.47982 .03305 L
.50065 .03304 L
.51949 .03303 L
.54016 .03302 L
.55968 .03302 L
.5806 .03301 L
.59078 .03301 L
.60185 .03301 L
.61142 .03301 L
.62198 .03301 L
.64177 .03301 L
.65261 .03301 L
.66278 .03301 L
.67262 .03301 L
.68298 .03301 L
.69182 .03301 L
.70149 .03301 L
.70678 .03301 L
.71177 .03301 L
.71631 .03301 L
.72112 .03301 L
.72361 .03301 L
.72635 .03301 L
.72887 .03301 L
.73117 .03301 L
.73389 .03301 L
.73539 .03301 L
.7368 .03301 L
.73811 .03301 L
.73932 .03301 L
.74002 .03301 L
.74066 .03301 L
.74138 .03301 L
.74207 .03301 L
.74324 .03301 L
.74449 .03301 L
.74567 .03301 L
.74675 .03301 L
.74938 .03301 L
Mistroke
.75187 .03301 L
.75682 .03301 L
.7622 .03301 L
.77182 .03301 L
.78069 .03301 L
.82003 .03301 L
.85785 .03301 L
.89813 .03301 L
.93689 .03301 L
.97619 .03301 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.02499 .03291 L
.02605 .047 L
.02729 .059 L
.02846 .06603 L
.02954 .06949 L
.03053 .07085 L
.03163 .07102 L
.03279 .07024 L
.03395 .06886 L
.0352 .06699 L
.03746 .06314 L
.04262 .05423 L
.04793 .04625 L
.05297 .04006 L
.06244 .03162 L
.0675 .02844 L
.07289 .0258 L
.07798 .02387 L
.08259 .02249 L
.08803 .02122 L
.09391 .02019 L
.09947 .01945 L
.10458 .01894 L
.10928 .01856 L
.11432 .01825 L
.11907 .01803 L
.1234 .01786 L
.12849 .01771 L
.13402 .01759 L
.13924 .01751 L
.14176 .01748 L
.14407 .01745 L
.1487 .01741 L
.15113 .0174 L
.15237 .01739 L
.15369 .01739 L
.15487 .01738 L
.15593 .01738 L
.157 .01738 L
.15801 .01738 L
.15919 .01738 L
.16028 .01738 L
.16147 .01738 L
.16273 .01738 L
.16401 .01738 L
.16518 .01738 L
.1678 .01739 L
.17254 .01741 L
.17519 .01742 L
Mistroke
.17659 .01743 L
.17808 .01743 L
.17951 .01743 L
.18081 .01744 L
.18211 .01744 L
.18333 .01744 L
.1845 .01744 L
.18575 .01744 L
.18693 .01743 L
.188 .01743 L
.19063 .01743 L
.19312 .01742 L
.20345 .01737 L
.21224 .01732 L
.22194 .01728 L
.23162 .01725 L
.23692 .01724 L
.24189 .01723 L
.24652 .01722 L
.25076 .01722 L
.25299 .01722 L
.25542 .01722 L
.25796 .01722 L
.26032 .01722 L
.26296 .01722 L
.26538 .01721 L
.26805 .01721 L
.26939 .01721 L
.27087 .01721 L
.27217 .01721 L
.27335 .01721 L
.274 .01721 L
.27472 .01721 L
.27601 .01721 L
.27722 .01721 L
.27851 .01721 L
.2796 .01721 L
.28082 .01721 L
.28199 .01721 L
.28322 .01721 L
.28428 .01721 L
.28543 .01721 L
.28667 .01721 L
.28737 .01721 L
.28801 .01721 L
.28924 .01721 L
.29041 .01721 L
.2915 .01721 L
.29265 .01721 L
.29473 .01721 L
Mistroke
.29696 .01721 L
.29942 .01721 L
.30462 .01721 L
.30956 .01721 L
.31884 .0172 L
.33972 .01719 L
.34932 .01718 L
.35954 .01718 L
.36913 .01718 L
.37794 .01717 L
.38823 .01717 L
.39936 .01717 L
.40918 .01717 L
.41954 .01717 L
.42903 .01717 L
.43919 .01716 L
.44879 .01716 L
.45753 .01716 L
.46745 .01716 L
.47663 .01716 L
.4867 .01716 L
.4974 .01716 L
.50677 .01716 L
.51688 .01716 L
.52642 .01716 L
.53517 .01716 L
.53991 .01716 L
.54498 .01716 L
.54976 .01716 L
.5541 .01716 L
.55677 .01716 L
.55922 .01716 L
.5605 .01716 L
.56191 .01716 L
.56262 .01716 L
.56338 .01716 L
.5641 .01716 L
.56476 .01716 L
.56605 .01716 L
.56673 .01716 L
.56745 .01716 L
.56815 .01716 L
.5688 .01716 L
.57001 .01716 L
.57121 .01716 L
.57232 .01716 L
.57481 .01716 L
.57728 .01716 L
.57953 .01716 L
.58458 .01716 L
Mistroke
.59369 .01716 L
.61437 .01716 L
.65429 .01716 L
.69269 .01716 L
.73354 .01716 L
.75385 .01716 L
.77288 .01716 L
.8107 .01716 L
.83094 .01716 L
.84946 .01716 L
.86844 .01716 L
.87931 .01716 L
.88916 .01716 L
.90882 .01716 L
.91962 .01716 L
.92979 .01716 L
.93955 .01716 L
.94488 .01716 L
.94986 .01716 L
.95867 .01716 L
.96333 .01716 L
.96833 .01716 L
.97237 .01716 L
.97619 .01716 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.02846 .08442 L
.03279 .13901 L
.03754 .18638 L
.04018 .20687 L
.04262 .22212 L
.04518 .23444 L
.04652 .2395 L
.04795 .24383 L
.04919 .24678 L
.05035 .2489 L
.05163 .25054 L
.05234 .25118 L
.053 .25158 L
.0542 .25192 L
.05531 .25179 L
.05654 .2512 L
.05784 .2501 L
.05908 .24866 L
.06026 .24698 L
.06244 .24315 L
.08439 .18826 L
.09401 .16799 L
.09911 .15933 L
.10458 .1516 L
.10965 .14578 L
.11427 .14151 L
.11892 .13813 L
.12333 .13571 L
.12572 .1347 L
.12825 .13386 L
.13042 .13333 L
.13165 .1331 L
.13281 .13294 L
.13407 .13282 L
.13471 .13278 L
.1354 .13275 L
.13663 .13276 L
.13778 .13281 L
.13847 .13288 L
.13913 .13295 L
.14037 .13314 L
.14169 .13343 L
.14313 .13383 L
.14549 .13473 L
.14802 .13606 L
.15041 .13773 L
.1526 .13968 L
.15515 .14261 L
.15794 .14681 L
Mistroke
.16057 .15204 L
.16301 .15829 L
.16576 .1673 L
.16836 .17783 L
.1732 .20147 L
.17837 .22664 L
.18112 .23747 L
.18262 .24238 L
.18405 .24628 L
.18532 .24915 L
.1867 .25162 L
.18796 .25331 L
.18912 .25441 L
.19021 .25507 L
.19141 .25539 L
.19266 .25532 L
.19384 .25489 L
.1951 .25409 L
.19644 .25289 L
.19881 .24998 L
.20417 .24083 L
.22265 .20331 L
.22758 .19538 L
.23222 .18938 L
.23479 .18678 L
.23615 .18563 L
.23758 .18461 L
.23878 .18389 L
.23942 .18358 L
.2401 .18329 L
.24131 .18291 L
.24243 .18271 L
.24366 .18269 L
.2448 .18286 L
.24604 .18328 L
.24667 .1836 L
.24737 .18404 L
.24853 .18499 L
.24978 .18635 L
.25086 .18784 L
.25204 .18984 L
.25427 .19479 L
.25662 .2019 L
.26081 .21991 L
.27173 .28832 L
.27709 .32134 L
.28204 .34583 L
.28436 .35485 L
.28653 .36176 L
.2888 .36739 L
Mistroke
.29 .36973 L
.2913 .37174 L
.29258 .37324 L
.29331 .37387 L
.29399 .37432 L
.29523 .3748 L
.29654 .37485 L
.29784 .37444 L
.29906 .37367 L
.30016 .37267 L
.30134 .37128 L
.30378 .36746 L
.30606 .36288 L
.31123 .34951 L
.32167 .31543 L
.34035 .25496 L
.35082 .22851 L
.36072 .20895 L
.36961 .19533 L
.37928 .18391 L
.38869 .17543 L
.39907 .16828 L
.40991 .16256 L
.42009 .15831 L
.44028 .15194 L
.45879 .14773 L
.47773 .14457 L
.49844 .14209 L
.51806 .14038 L
.53902 .13898 L
.55894 .13792 L
.58054 .13698 L
.62054 .13564 L
.66148 .13465 L
.7009 .13393 L
.73881 .1334 L
.77917 .13296 L
.81801 .13262 L
.85931 .13232 L
.89909 .13208 L
.93735 .13187 L
.97619 .13169 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.02846 .08443 L
.03279 .13935 L
.03793 .19215 L
.04262 .22939 L
.04754 .25878 L
.0522 .27866 L
.05475 .28676 L
.05711 .2927 L
.0597 .2977 L
.06111 .29983 L
.06244 .30149 L
.06369 .30275 L
.06505 .30384 L
.06628 .30458 L
.06743 .30507 L
.06813 .30529 L
.06879 .30544 L
.07003 .30559 L
.07072 .3056 L
.07136 .30556 L
.07206 .30548 L
.0728 .30534 L
.07395 .30503 L
.07519 .30459 L
.07742 .30353 L
.0825 .3002 L
.09307 .29144 L
.09865 .2869 L
.10458 .28266 L
.10982 .27963 L
.11261 .27835 L
.11561 .27723 L
.11695 .27683 L
.11836 .27648 L
.11966 .27621 L
.12088 .27602 L
.12202 .27589 L
.12324 .2758 L
.12393 .27578 L
.12459 .27577 L
.12582 .27581 L
.12698 .2759 L
.12826 .27607 L
.1289 .27618 L
.12959 .27632 L
.13084 .27663 L
.13326 .27744 L
.13547 .27844 L
.13804 .27996 L
Mistroke
.14084 .2821 L
.14594 .28757 L
.1485 .29127 L
.15127 .29618 L
.15371 .30146 L
.15629 .3082 L
.16117 .32504 L
.16565 .34576 L
.17579 .39998 L
.17871 .41285 L
.18147 .42278 L
.18395 .4297 L
.18534 .43276 L
.18664 .43511 L
.18787 .43688 L
.189 .43812 L
.19025 .43911 L
.19091 .43947 L
.1916 .43973 L
.19291 .4399 L
.19412 .43973 L
.19481 .43948 L
.19545 .43918 L
.19687 .43821 L
.19808 .4371 L
.1992 .43586 L
.20173 .4324 L
.20632 .42427 L
.22466 .38411 L
.22935 .37508 L
.23438 .36688 L
.23682 .36355 L
.23913 .36084 L
.24119 .35881 L
.24346 .35701 L
.24475 .35622 L
.24595 .35563 L
.24722 .35518 L
.24794 .355 L
.2486 .35489 L
.2497 .35481 L
.25091 .3549 L
.25218 .35518 L
.25335 .35563 L
.25402 .35597 L
.25475 .3564 L
.25608 .35738 L
.25855 .35987 L
.26145 .36393 L
.26412 .36879 L
Mistroke
.26878 .37982 L
.2738 .3947 L
.28286 .4255 L
.29356 .45916 L
.30349 .4822 L
.30839 .49043 L
.3136 .49719 L
.31939 .50269 L
.32464 .50627 L
.32961 .50879 L
.33499 .51091 L
.34473 .51412 L
.38576 .53318 L
.39562 .53799 L
.40619 .54229 L
.41617 .54543 L
.42526 .54756 L
.43461 .54918 L
.44478 .55047 L
.45438 .55138 L
.46326 .55206 L
.48352 .55332 L
.49345 .55382 L
.50254 .5542 L
.5114 .55451 L
.52072 .55474 L
.52557 .55483 L
.53008 .5549 L
.53263 .55492 L
.53503 .55495 L
.53636 .55496 L
.5378 .55497 L
.53911 .55497 L
.54031 .55498 L
.54152 .55498 L
.54267 .55498 L
.54389 .55499 L
.54521 .55499 L
.54636 .55499 L
.54758 .55499 L
.54874 .55498 L
.54979 .55498 L
.55113 .55498 L
.55237 .55497 L
.55515 .55496 L
.5602 .55493 L
.56509 .55488 L
.57045 .55482 L
.58125 .55468 L
.62175 .55393 L
Mistroke
.66073 .55308 L
.70216 .55218 L
.74208 .55144 L
.78048 .55088 L
.79992 .55065 L
.82133 .55044 L
.86067 .55016 L
.88007 .55006 L
.90095 .54998 L
.94216 .54986 L
.97619 .54978 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.02846 .08443 L
.03279 .13929 L
.03793 .19172 L
.04262 .2281 L
.04498 .24272 L
.04754 .256 L
.04976 .26549 L
.0522 .274 L
.05478 .28102 L
.0561 .28388 L
.05753 .28646 L
.05885 .28844 L
.06007 .28992 L
.06129 .2911 L
.06244 .29196 L
.0631 .29234 L
.0638 .29267 L
.06504 .29306 L
.06574 .29318 L
.06648 .29323 L
.06711 .29322 L
.0678 .29315 L
.06904 .29289 L
.06974 .29267 L
.07037 .29243 L
.07277 .29118 L
.07555 .2892 L
.07856 .28657 L
.08405 .281 L
.09381 .27055 L
.09899 .26548 L
.10458 .26074 L
.1099 .25708 L
.11223 .25577 L
.11478 .25455 L
.11703 .25366 L
.11944 .25292 L
.12078 .2526 L
.12199 .25237 L
.1232 .25219 L
.12435 .25208 L
.12557 .25202 L
.12626 .25202 L
.1269 .25203 L
.1282 .25211 L
.12893 .25219 L
.1296 .25228 L
.13079 .25249 L
.13208 .2528 L
Mistroke
.13443 .25358 L
.13718 .25487 L
.1401 .25674 L
.14286 .25907 L
.14536 .26171 L
.15025 .26876 L
.15271 .2735 L
.15541 .27989 L
.16019 .29512 L
.16465 .3148 L
.16978 .34314 L
.17535 .3746 L
.17791 .38707 L
.18062 .39821 L
.18293 .40585 L
.18548 .41222 L
.18677 .41464 L
.18813 .41664 L
.18928 .41791 L
.19055 .41886 L
.19127 .41921 L
.19192 .41941 L
.19267 .41951 L
.19338 .41947 L
.19464 .41912 L
.19535 .41877 L
.19601 .41836 L
.19719 .41739 L
.19829 .41626 L
.2008 .41294 L
.20587 .40376 L
.22444 .3596 L
.23488 .33735 L
.24001 .32839 L
.24477 .32143 L
.24899 .31635 L
.25365 .31187 L
.25834 .30836 L
.26332 .30543 L
.26822 .30307 L
.27339 .30097 L
.27786 .29948 L
.28032 .29882 L
.28264 .2983 L
.28394 .29806 L
.28534 .29784 L
.28651 .29769 L
.28779 .29756 L
.28901 .29747 L
.29029 .29741 L
Mistroke
.29148 .29738 L
.29259 .29738 L
.29327 .29739 L
.294 .29742 L
.29469 .29745 L
.29534 .29748 L
.29655 .29757 L
.29784 .29769 L
.3008 .29804 L
.30349 .29845 L
.32437 .30236 L
.33353 .30383 L
.34357 .30539 L
.35328 .30727 L
.36234 .30974 L
.3719 .31338 L
.38215 .31857 L
.42353 .34746 L
.46339 .37375 L
.50174 .39602 L
.54254 .41796 L
.58183 .43656 L
.6196 .4523 L
.65982 .46703 L
.69853 .47943 L
.73969 .491 L
.77933 .50085 L
.81746 .50931 L
.85804 .51739 L
.89711 .52439 L
.93863 .53106 L
.97619 .53646 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.02846 .08419 L
.03279 .13585 L
.03527 .158 L
.03754 .17287 L
.03879 .17895 L
.03945 .18156 L
.04015 .18389 L
.04143 .18706 L
.04262 .18881 L
.04384 .18954 L
.04496 .18936 L
.04626 .18827 L
.04749 .18649 L
.04862 .18431 L
.04967 .1819 L
.05205 .17539 L
.06244 .14083 L
.07295 .10983 L
.08284 .08847 L
.08832 .07962 L
.09424 .072 L
.09959 .06658 L
.10458 .06254 L
.10955 .05933 L
.11408 .057 L
.11912 .05496 L
.12452 .05331 L
.1297 .05217 L
.13263 .05169 L
.13534 .05135 L
.1377 .05113 L
.13904 .05103 L
.1403 .05097 L
.14095 .05094 L
.14163 .05091 L
.14284 .05089 L
.14415 .05088 L
.14489 .05088 L
.14558 .05089 L
.14686 .05093 L
.1475 .05096 L
.14821 .051 L
.14946 .05109 L
.15063 .05119 L
.15327 .05152 L
.15475 .05176 L
.15611 .05203 L
.15854 .05263 L
.1612 .05351 L
Mistroke
.16371 .05458 L
.16604 .05582 L
.17498 .06254 L
.17967 .06598 L
.18204 .06728 L
.18338 .06785 L
.18463 .06828 L
.18535 .06848 L
.18602 .06863 L
.18729 .06885 L
.18801 .06893 L
.18866 .06897 L
.18938 .069 L
.19015 .06899 L
.1914 .06892 L
.19256 .06879 L
.19384 .06858 L
.19522 .06829 L
.19776 .06762 L
.20043 .06674 L
.20519 .06494 L
.21495 .06107 L
.22381 .05803 L
.22841 .05675 L
.23338 .05562 L
.23612 .05511 L
.23864 .05472 L
.2412 .05441 L
.24245 .05428 L
.24359 .05418 L
.24457 .05411 L
.24564 .05405 L
.24678 .05401 L
.24785 .05398 L
.24903 .05397 L
.25028 .05399 L
.25134 .05403 L
.25252 .0541 L
.25375 .05421 L
.25487 .05433 L
.25739 .05472 L
.25962 .0552 L
.26197 .05586 L
.27222 .06034 L
.27726 .06305 L
.28191 .06538 L
.28614 .06709 L
.28827 .06776 L
.29061 .06832 L
.29184 .06854 L
Mistroke
.29296 .0687 L
.29425 .06883 L
.29548 .06891 L
.29662 .06894 L
.29767 .06894 L
.29882 .0689 L
.30005 .06882 L
.30069 .06876 L
.30137 .06869 L
.30259 .06853 L
.30534 .06806 L
.31032 .06689 L
.31963 .06407 L
.32974 .06082 L
.34058 .05771 L
.35086 .05531 L
.36023 .05359 L
.36965 .05225 L
.37857 .05127 L
.38823 .05046 L
.39849 .04981 L
.40725 .04938 L
.41692 .049 L
.43628 .04846 L
.44716 .04824 L
.45714 .04807 L
.47608 .04783 L
.48681 .04772 L
.49678 .04764 L
.51726 .04752 L
.53585 .04743 L
.55505 .04737 L
.57585 .04731 L
.59574 .04727 L
.61679 .04723 L
.6547 .04719 L
.67416 .04717 L
.69506 .04716 L
.71482 .04715 L
.73635 .04714 L
.77613 .04712 L
.79586 .04712 L
.81685 .04711 L
.85851 .04711 L
.89864 .0471 L
.93727 .0471 L
.97619 .04709 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.02846 .08443 L
.03279 .13917 L
.03754 .1875 L
.04262 .22616 L
.04518 .24094 L
.04795 .25377 L
.05058 .26309 L
.053 .26954 L
.05518 .27377 L
.05642 .27557 L
.05758 .2769 L
.05881 .27794 L
.05993 .2786 L
.06122 .27905 L
.06244 .27917 L
.0631 .27913 L
.06381 .27901 L
.0651 .27859 L
.06635 .27796 L
.0675 .2772 L
.07012 .27495 L
.07289 .27193 L
.08259 .25856 L
.0932 .24339 L
.09905 .2361 L
.10458 .23022 L
.1095 .22594 L
.11485 .22232 L
.11721 .22108 L
.11972 .21999 L
.12186 .21927 L
.12422 .21868 L
.12537 .21848 L
.12659 .21832 L
.12763 .21824 L
.12877 .21821 L
.13 .21823 L
.13131 .21834 L
.13255 .21851 L
.13367 .21874 L
.13481 .21903 L
.13587 .21936 L
.13824 .22033 L
.14033 .22147 L
.14255 .223 L
.14508 .22522 L
.14748 .22785 L
.15199 .23458 L
.1545 .23965 L
Mistroke
.15684 .24543 L
.15956 .25379 L
.16213 .26355 L
.16678 .28636 L
.171 .31128 L
.17588 .34007 L
.18044 .36197 L
.18269 .37024 L
.18511 .37708 L
.18649 .38006 L
.18779 .38229 L
.18896 .38381 L
.19023 .38498 L
.19147 .38565 L
.19217 .38584 L
.19283 .38589 L
.19353 .38583 L
.19416 .38566 L
.19486 .38536 L
.1956 .38493 L
.19683 .38394 L
.19797 .38274 L
.20056 .37915 L
.20525 .37021 L
.2095 .36023 L
.21904 .33519 L
.22839 .31136 L
.23826 .29018 L
.24343 .28128 L
.2491 .27331 L
.25908 .26335 L
.26431 .25959 L
.26926 .25648 L
.27856 .25116 L
.28869 .24595 L
.29425 .24352 L
.29947 .24158 L
.30892 .2389 L
.31394 .23785 L
.31935 .23694 L
.32403 .23633 L
.32895 .23582 L
.33316 .23548 L
.33556 .23533 L
.33777 .23522 L
.3403 .23513 L
.34163 .23509 L
.34231 .23508 L
.34304 .23507 L
.34426 .23505 L
Mistroke
.34541 .23504 L
.34611 .23504 L
.34678 .23505 L
.34802 .23506 L
.34914 .23508 L
.35034 .23511 L
.35146 .23515 L
.35248 .23519 L
.35499 .23532 L
.35735 .23548 L
.36259 .23599 L
.36741 .23664 L
.37271 .23757 L
.37829 .2388 L
.39795 .24492 L
.41629 .25231 L
.45521 .26864 L
.4966 .28533 L
.53646 .30161 L
.57481 .31669 L
.61561 .33174 L
.6549 .3452 L
.69267 .3571 L
.73289 .36872 L
.7716 .37902 L
.81276 .38918 L
.8524 .39833 L
.89053 .40663 L
.93111 .41499 L
.97018 .42257 L
.97619 .4237 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.02846 .08442 L
.03279 .13895 L
.03754 .18619 L
.04018 .20667 L
.04262 .222 L
.04518 .23458 L
.0465 .23974 L
.04795 .24445 L
.04913 .24754 L
.0504 .25019 L
.0511 .25137 L
.05174 .25228 L
.053 .25361 L
.0542 .25437 L
.05531 .25465 L
.05654 .25453 L
.05784 .25395 L
.05908 .25301 L
.06026 .2518 L
.06244 .24885 L
.06757 .23929 L
.07299 .22692 L
.08269 .20386 L
.09325 .18209 L
.09907 .17241 L
.10458 .16481 L
.1095 .15927 L
.11485 .15449 L
.11972 .15118 L
.12204 .14994 L
.12422 .14896 L
.12642 .14816 L
.12844 .14758 L
.12952 .14734 L
.13069 .14713 L
.13187 .14697 L
.13311 .14686 L
.13435 .14681 L
.13547 .14682 L
.13677 .14689 L
.138 .14704 L
.13914 .14723 L
.14018 .14746 L
.14255 .14818 L
.1438 .14869 L
.14499 .14925 L
.14722 .15057 L
.14963 .1524 L
.15225 .155 L
Mistroke
.15452 .1579 L
.15695 .16179 L
.16131 .17164 L
.164 .18008 L
.1669 .19166 L
.17215 .21836 L
.17722 .24562 L
.1797 .25714 L
.18195 .26593 L
.18432 .27319 L
.18656 .27816 L
.18778 .28011 L
.18892 .28146 L
.19016 .28245 L
.19148 .28298 L
.19272 .28301 L
.19341 .28284 L
.19405 .28257 L
.19522 .28183 L
.19645 .28071 L
.19781 .27911 L
.19907 .27731 L
.20193 .27231 L
.22301 .22013 L
.23356 .19708 L
.23874 .18797 L
.24351 .18092 L
.25244 .17093 L
.25714 .16714 L
.26211 .16399 L
.27157 .15959 L
.28172 .15574 L
.30005 .1486 L
.3102 .14486 L
.32126 .14146 L
.33171 .13902 L
.33636 .13817 L
.34138 .1374 L
.34639 .13676 L
.35099 .13628 L
.35566 .13589 L
.36002 .13559 L
.3648 .13534 L
.36755 .13522 L
.37004 .13514 L
.37249 .13507 L
.37515 .13501 L
.37661 .13498 L
.37796 .13496 L
.37932 .13494 L
Mistroke
.38061 .13493 L
.38177 .13492 L
.38305 .13491 L
.3842 .1349 L
.38527 .1349 L
.38655 .1349 L
.3877 .1349 L
.38834 .1349 L
.38903 .13491 L
.39029 .13491 L
.39138 .13492 L
.39258 .13493 L
.39501 .13495 L
.39935 .13501 L
.4045 .13511 L
.41002 .13524 L
.41998 .13551 L
.46136 .13696 L
.50123 .13853 L
.53958 .14014 L
.58038 .1418 L
.61966 .14331 L
.65744 .14466 L
.69766 .14596 L
.73637 .14709 L
.77753 .14819 L
.81717 .14916 L
.8553 .15004 L
.89588 .15093 L
.93494 .15175 L
.97619 .1526 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.02499 .0329 L
.02605 .04687 L
.02729 .05846 L
.02846 .06484 L
.02954 .06766 L
.03053 .06851 L
.03163 .06823 L
.03279 .06712 L
.03395 .06551 L
.0352 .0635 L
.03746 .05956 L
.04262 .05083 L
.04793 .04323 L
.05297 .03742 L
.05794 .03287 L
.06244 .02958 L
.0675 .02665 L
.07289 .02423 L
.07789 .0225 L
.08259 .02122 L
.08809 .02005 L
.09315 .01924 L
.09871 .01855 L
.10458 .018 L
.10954 .01766 L
.11406 .01741 L
.11928 .01718 L
.12422 .01702 L
.12878 .0169 L
.133 .01682 L
.13763 .01675 L
.14255 .01669 L
.14744 .01664 L
.15192 .01661 L
.15427 .0166 L
.15684 .01659 L
.15814 .01659 L
.15953 .01659 L
.16083 .01658 L
.16202 .01658 L
.16316 .01658 L
.16437 .01658 L
.1654 .01658 L
.16653 .01658 L
.16775 .01658 L
.16906 .01658 L
.1703 .01658 L
.17143 .01658 L
.17383 .01659 L
Mistroke
.17608 .01659 L
.17707 .01659 L
.17811 .01659 L
.17925 .01659 L
.1803 .01659 L
.18148 .01659 L
.18258 .01659 L
.18379 .01659 L
.18508 .01659 L
.18645 .01659 L
.18775 .01658 L
.19017 .01658 L
.19933 .01656 L
.20939 .01653 L
.22006 .0165 L
.22955 .01648 L
.23495 .01647 L
.24001 .01647 L
.24465 .01647 L
.24889 .01646 L
.25111 .01646 L
.25355 .01646 L
.25478 .01646 L
.25609 .01646 L
.25732 .01646 L
.25844 .01646 L
.25964 .01646 L
.26076 .01646 L
.26199 .01646 L
.26331 .01646 L
.26397 .01646 L
.26469 .01646 L
.266 .01646 L
.26845 .01646 L
.27324 .01646 L
.27767 .01646 L
.28287 .01647 L
.28542 .01647 L
.28775 .01647 L
.29021 .01647 L
.29149 .01647 L
.2922 .01647 L
.29285 .01647 L
.29352 .01647 L
.29424 .01647 L
.29554 .01647 L
.29626 .01647 L
.29705 .01647 L
.29779 .01647 L
.29848 .01647 L
Mistroke
.29973 .01647 L
.30092 .01647 L
.30314 .01647 L
.30554 .01647 L
.30816 .01647 L
.31722 .01646 L
.33785 .01645 L
.34799 .01645 L
.35754 .01645 L
.36854 .01645 L
.37852 .01645 L
.39861 .01644 L
.41709 .01644 L
.43752 .01644 L
.45659 .01644 L
.47493 .01644 L
.49458 .01644 L
.51584 .01644 L
.53597 .01644 L
.57432 .01644 L
.5941 .01644 L
.61512 .01644 L
.65289 .01644 L
.69311 .01644 L
.73182 .01644 L
.77298 .01644 L
.81262 .01644 L
.85075 .01644 L
.89133 .01644 L
.9304 .01644 L
.97191 .01644 L
.97619 .01644 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.02846 .08443 L
.03279 .13934 L
.03793 .19207 L
.04262 .22901 L
.04498 .24397 L
.04754 .25763 L
.04976 .26742 L
.0522 .27619 L
.05478 .28338 L
.0561 .28628 L
.05753 .28886 L
.05885 .2908 L
.06007 .29219 L
.06129 .29326 L
.06244 .29398 L
.0631 .29427 L
.06381 .29449 L
.0651 .29466 L
.06635 .29456 L
.0675 .29425 L
.06875 .29371 L
.07012 .29289 L
.07289 .29061 L
.07791 .2849 L
.08259 .27846 L
.09388 .26201 L
.10458 .24868 L
.10931 .24404 L
.11433 .24006 L
.11695 .23839 L
.11984 .23689 L
.12246 .23582 L
.12364 .23545 L
.12493 .2351 L
.12611 .23485 L
.1272 .23468 L
.12836 .23456 L
.12959 .2345 L
.13074 .23451 L
.13183 .23458 L
.1328 .23469 L
.13386 .23487 L
.13502 .23514 L
.13629 .23553 L
.13887 .23661 L
.14126 .238 L
.14349 .2397 L
.14607 .2422 L
.14847 .24513 L
Mistroke
.1511 .24915 L
.1539 .25458 L
.15657 .26115 L
.15908 .26886 L
.16378 .28815 L
.17262 .34002 L
.1773 .36774 L
.18231 .39126 L
.18496 .4005 L
.18738 .40697 L
.18854 .40946 L
.18981 .41172 L
.19099 .41344 L
.1921 .41472 L
.19334 .41579 L
.194 .4162 L
.19471 .41654 L
.19541 .41678 L
.19615 .41691 L
.19747 .41688 L
.1987 .41657 L
.19984 .41606 L
.20109 .41527 L
.20243 .4142 L
.20742 .40852 L
.21212 .40162 L
.22092 .38809 L
.22556 .38212 L
.2282 .37949 L
.22938 .37855 L
.23066 .37771 L
.23136 .37735 L
.232 .37707 L
.23326 .37671 L
.23441 .3766 L
.23563 .37674 L
.23694 .37721 L
.23817 .37798 L
.23887 .37858 L
.23952 .37924 L
.24097 .38114 L
.24319 .38525 L
.24526 .39056 L
.24753 .39821 L
.24996 .40856 L
.25943 .4621 L
.2644 .48926 L
.26966 .51308 L
.27543 .53299 L
.278 .5399 L
Mistroke
.28075 .54612 L
.28334 .55089 L
.28571 .55443 L
.28808 .55724 L
.29034 .55926 L
.29161 .56014 L
.29296 .56087 L
.29424 .56139 L
.29539 .56171 L
.2961 .56184 L
.29675 .56192 L
.29747 .56196 L
.29823 .56194 L
.2995 .5618 L
.30022 .56166 L
.3009 .56148 L
.30216 .56105 L
.3035 .56044 L
.30591 .559 L
.3085 .55697 L
.31136 .55419 L
.32127 .54087 L
.33983 .50592 L
.36082 .4626 L
.38005 .42803 L
.41876 .37849 L
.4377 .36085 L
.4584 .3454 L
.47803 .33426 L
.49898 .32554 L
.52034 .31907 L
.5405 .31441 L
.57899 .30791 L
.59888 .30542 L
.61993 .30327 L
.65783 .30034 L
.69819 .29812 L
.73704 .29657 L
.77833 .29535 L
.81811 .29443 L
.85638 .29369 L
.8971 .29302 L
.9363 .29244 L
.97619 .2919 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19252 L
.04262 .23063 L
.04754 .26169 L
.0522 .2838 L
.05711 .30066 L
.05988 .30765 L
.06244 .3127 L
.06487 .31637 L
.0662 .31798 L
.06747 .31925 L
.06865 .32023 L
.06993 .32109 L
.07109 .32169 L
.07218 .32212 L
.07285 .32231 L
.07358 .32247 L
.0749 .32264 L
.07618 .32265 L
.07737 .32254 L
.07865 .3223 L
.07938 .32212 L
.08006 .32192 L
.0829 .32082 L
.08571 .31938 L
.08837 .31778 L
.09336 .31445 L
.10458 .307 L
.10956 .30431 L
.11423 .30235 L
.11658 .30161 L
.11911 .301 L
.12048 .30076 L
.12122 .30066 L
.12192 .30059 L
.12314 .3005 L
.12379 .30047 L
.12449 .30046 L
.12573 .30049 L
.12687 .30058 L
.12813 .30074 L
.12876 .30084 L
.12945 .30098 L
.13062 .30126 L
.13187 .30163 L
.13414 .3025 L
.13649 .3037 L
.13872 .30515 L
Mistroke
.14291 .30879 L
.14551 .31178 L
.14795 .31521 L
.15252 .3236 L
.15508 .32974 L
.15744 .3365 L
.16275 .35645 L
.17164 .40215 L
.17653 .42687 L
.18115 .44554 L
.1836 .45318 L
.18626 .4597 L
.18868 .46412 L
.18983 .46574 L
.19092 .46701 L
.19201 .46804 L
.19302 .46878 L
.19413 .46938 L
.19533 .46978 L
.19642 .46993 L
.19762 .4699 L
.19886 .46965 L
.20002 .46923 L
.20131 .46858 L
.20272 .46767 L
.20526 .46557 L
.21002 .4605 L
.22069 .44734 L
.22527 .44246 L
.22779 .44029 L
.23018 .4387 L
.23153 .43804 L
.2323 .43774 L
.233 .43753 L
.23425 .4373 L
.23488 .43726 L
.23557 .43728 L
.23682 .43747 L
.23752 .43769 L
.23817 .43795 L
.23936 .43862 L
.24061 .4396 L
.24193 .44096 L
.24312 .44249 L
.24581 .44711 L
.24831 .4529 L
.25066 .45973 L
.26167 .50189 L
.27137 .53544 L
.27627 .54805 L
Mistroke
.28165 .55864 L
.28624 .56523 L
.28882 .56808 L
.29118 .5702 L
.29337 .57178 L
.29575 .57312 L
.29684 .5736 L
.29801 .57404 L
.29909 .57438 L
.3001 .57464 L
.30134 .57488 L
.302 .57497 L
.30271 .57505 L
.30345 .57511 L
.30415 .57514 L
.30546 .57513 L
.30669 .57506 L
.30783 .57495 L
.30907 .57476 L
.31039 .57451 L
.31313 .5738 L
.31569 .57295 L
.32153 .57048 L
.3417 .55953 L
.38041 .54378 L
.42157 .53003 L
.46121 .51266 L
.49934 .49792 L
.53992 .4854 L
.57899 .47496 L
.6205 .46534 L
.66051 .45738 L
.69899 .45078 L
.73993 .44481 L
.77935 .43996 L
.81726 .43599 L
.85762 .43238 L
.89647 .42938 L
.93776 .42659 L
.97619 .42429 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.02846 .08443 L
.03279 .13936 L
.03793 .19221 L
.04262 .22958 L
.04754 .25921 L
.0522 .27942 L
.05475 .28774 L
.05711 .29389 L
.0597 .29915 L
.06111 .30141 L
.06244 .30321 L
.06369 .30461 L
.06505 .30583 L
.06628 .30671 L
.06743 .30732 L
.06813 .30762 L
.06879 .30784 L
.07003 .30811 L
.07072 .30819 L
.07136 .30822 L
.07206 .30821 L
.0728 .30815 L
.07395 .30796 L
.07519 .30765 L
.07636 .30725 L
.07742 .30681 L
.0825 .30394 L
.09397 .29529 L
.09901 .29151 L
.10458 .28783 L
.10903 .28539 L
.11383 .28337 L
.11648 .28257 L
.11764 .28229 L
.1189 .28203 L
.12011 .28184 L
.12122 .2817 L
.1224 .28161 L
.12366 .28158 L
.12434 .28158 L
.12506 .2816 L
.12635 .2817 L
.12707 .28178 L
.12774 .28188 L
.12926 .28217 L
.13059 .28251 L
.13181 .28289 L
.13454 .28402 L
.13697 .28536 L
Mistroke
.13961 .28722 L
.14443 .29192 L
.14699 .29525 L
.14976 .29967 L
.1522 .30441 L
.15477 .31045 L
.15965 .32557 L
.16414 .34453 L
.17427 .39812 L
.17719 .4119 L
.17995 .42289 L
.18246 .43095 L
.18383 .43455 L
.18512 .43742 L
.18745 .44139 L
.18869 .44289 L
.18933 .4435 L
.19002 .44404 L
.19118 .44468 L
.19239 .44501 L
.19351 .44501 L
.19455 .44478 L
.1952 .44453 L
.19589 .44416 L
.19715 .44327 L
.19838 .44215 L
.19951 .4409 L
.2048 .43287 L
.22315 .39323 L
.23222 .37538 L
.23721 .36741 L
.24195 .36135 L
.24462 .35863 L
.24753 .35628 L
.24881 .35544 L
.25018 .3547 L
.25135 .35417 L
.25263 .35373 L
.2539 .35341 L
.25507 .35322 L
.25619 .35315 L
.25737 .35318 L
.25866 .35333 L
.25987 .3536 L
.26119 .35402 L
.2626 .35464 L
.26518 .35619 L
.26792 .35849 L
.27026 .36099 L
.27283 .36435 L
Mistroke
.27856 .37397 L
.28392 .38514 L
.30407 .42954 L
.30904 .43815 L
.31446 .44597 L
.31924 .4516 L
.32433 .45645 L
.33394 .46326 L
.34286 .46814 L
.38446 .49638 L
.40534 .51251 L
.4145 .51838 L
.42455 .52381 L
.44331 .53151 L
.46312 .53741 L
.48428 .54242 L
.50356 .54627 L
.54249 .55218 L
.56159 .55433 L
.58236 .5563 L
.62316 .55944 L
.66244 .56184 L
.70022 .56377 L
.74044 .56558 L
.77915 .56715 L
.82031 .56869 L
.85995 .57007 L
.89808 .57129 L
.93866 .57248 L
.97619 .57347 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.02499 .02095 L
.02605 .02151 L
.02729 .02153 L
.02846 .02138 L
.02954 .02117 L
.03053 .02096 L
.03279 .02045 L
.03746 .01944 L
.04262 .01849 L
.04725 .0178 L
.05224 .0172 L
.05751 .01671 L
.06244 .01635 L
.06784 .01604 L
.07373 .01579 L
.07929 .01561 L
.08445 .01548 L
.08956 .01539 L
.09419 .01532 L
.09954 .01525 L
.10458 .01521 L
.10923 .01518 L
.11434 .01515 L
.11968 .01513 L
.12466 .01511 L
.12932 .0151 L
.13357 .01509 L
.13848 .01508 L
.14313 .01508 L
.14772 .01508 L
.15278 .01507 L
.15533 .01507 L
.15807 .01507 L
.16066 .01507 L
.16304 .01507 L
.16411 .01507 L
.16526 .01507 L
.16733 .01507 L
.16859 .01507 L
.16978 .01507 L
.17201 .01507 L
.17437 .01507 L
.17566 .01507 L
.17689 .01507 L
.17928 .01507 L
.18146 .01507 L
.18367 .01507 L
.18609 .01507 L
.19118 .01507 L
Mistroke
.20147 .01506 L
.21098 .01506 L
.21993 .01506 L
.2249 .01506 L
.23027 .01506 L
.23515 .01506 L
.23964 .01506 L
.24216 .01506 L
.24451 .01506 L
.24709 .01506 L
.24985 .01506 L
.25124 .01506 L
.25197 .01506 L
.25275 .01506 L
.25343 .01506 L
.25417 .01506 L
.25549 .01506 L
.25677 .01506 L
.25748 .01506 L
.25814 .01506 L
.25935 .01506 L
.26062 .01506 L
.26186 .01506 L
.26321 .01506 L
.26564 .01506 L
.27019 .01506 L
.28041 .01506 L
.28506 .01506 L
.2876 .01506 L
.28997 .01506 L
.292 .01506 L
.29304 .01506 L
.29417 .01506 L
.29541 .01506 L
.29658 .01506 L
.29773 .01506 L
.29878 .01506 L
.29996 .01506 L
.3012 .01506 L
.30225 .01506 L
.30341 .01506 L
.30599 .01506 L
.3084 .01506 L
.31276 .01506 L
.31743 .01506 L
.33802 .01506 L
.34824 .01506 L
.35934 .01506 L
.36982 .01506 L
.37948 .01506 L
Mistroke
.39822 .01506 L
.41885 .01506 L
.43991 .01506 L
.45916 .01506 L
.47905 .01506 L
.49795 .01506 L
.53617 .01506 L
.5575 .01506 L
.57683 .01506 L
.61598 .01506 L
.65607 .01506 L
.69464 .01506 L
.73566 .01506 L
.77517 .01506 L
.81316 .01506 L
.85361 .01506 L
.89253 .01506 L
.93392 .01506 L
.97378 .01506 L
.97619 .01506 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19252 L
.04262 .23066 L
.04754 .26181 L
.0522 .2841 L
.05711 .30129 L
.05988 .30853 L
.06244 .31385 L
.06487 .31782 L
.06747 .32105 L
.06873 .32227 L
.06993 .32325 L
.07111 .32404 L
.07218 .32462 L
.07346 .32517 L
.07417 .3254 L
.07484 .32557 L
.07602 .32579 L
.0773 .3259 L
.07798 .32591 L
.07872 .32589 L
.07949 .32582 L
.08022 .32573 L
.08151 .32549 L
.0829 .32514 L
.08569 .32419 L
.08872 .32288 L
.09424 .32006 L
.10458 .31469 L
.1091 .31277 L
.11148 .31193 L
.11398 .3112 L
.11531 .31088 L
.11677 .31058 L
.1181 .31037 L
.11933 .31022 L
.1206 .31012 L
.12176 .31007 L
.1224 .31006 L
.12309 .31007 L
.12435 .31013 L
.12566 .31026 L
.12688 .31043 L
.12822 .3107 L
.12966 .31106 L
.1326 .3121 L
.13528 .31342 L
.13776 .31499 L
Mistroke
.14045 .31713 L
.14536 .32243 L
.14792 .32609 L
.15069 .33089 L
.15571 .34245 L
.16059 .35838 L
.16507 .37774 L
.17032 .40441 L
.17593 .43201 L
.17866 .44327 L
.18123 .45223 L
.18358 .45887 L
.18606 .46436 L
.18829 .46801 L
.18957 .46956 L
.19076 .4707 L
.19185 .47148 L
.19285 .47198 L
.19395 .47232 L
.1951 .47245 L
.19628 .47235 L
.19753 .47201 L
.19872 .47148 L
.19979 .47083 L
.20243 .46868 L
.20492 .46603 L
.21497 .45168 L
.22047 .44316 L
.2256 .43588 L
.23021 .43046 L
.2328 .42808 L
.23516 .42641 L
.23649 .4257 L
.23773 .42522 L
.23838 .42504 L
.2391 .4249 L
.23984 .42482 L
.24054 .42481 L
.24183 .42497 L
.243 .42533 L
.24429 .42597 L
.24494 .42639 L
.24565 .42693 L
.24807 .42946 L
.25027 .43273 L
.25281 .43769 L
.25521 .44353 L
.26412 .47263 L
.27293 .50487 L
.28241 .53381 L
Mistroke
.28784 .54635 L
.29281 .55532 L
.29781 .56219 L
.30255 .56701 L
.30494 .56889 L
.30748 .57055 L
.30967 .57173 L
.31205 .57277 L
.31484 .57372 L
.31748 .57438 L
.31873 .57462 L
.32004 .57484 L
.3224 .57512 L
.32371 .57524 L
.32491 .57532 L
.32557 .57535 L
.32629 .57538 L
.32759 .57542 L
.32881 .57544 L
.33011 .57545 L
.33121 .57544 L
.33243 .57543 L
.33313 .57542 L
.33386 .5754 L
.33517 .57537 L
.33811 .57529 L
.34085 .57521 L
.3422 .57518 L
.34344 .57515 L
.34461 .57513 L
.34584 .57512 L
.34708 .57511 L
.34779 .57511 L
.34845 .57511 L
.34959 .57511 L
.35064 .57512 L
.35185 .57514 L
.35299 .57517 L
.35422 .5752 L
.35553 .57525 L
.35788 .57536 L
.36319 .57569 L
.37284 .57655 L
.38157 .57741 L
.38646 .57785 L
.39163 .57825 L
.39604 .57851 L
.39854 .57863 L
.40087 .57871 L
.40216 .57875 L
Mistroke
.40357 .57878 L
.40422 .57879 L
.40491 .5788 L
.40614 .57881 L
.40731 .57882 L
.40842 .57882 L
.40963 .57881 L
.41093 .5788 L
.41165 .57879 L
.41231 .57878 L
.41382 .57875 L
.41656 .57867 L
.41905 .57857 L
.42171 .57844 L
.43198 .57774 L
.44311 .57673 L
.46328 .57458 L
.50427 .57001 L
.54374 .56506 L
.5817 .55969 L
.62211 .55375 L
.66101 .54809 L
.70236 .54237 L
.74219 .53732 L
.78051 .53298 L
.82128 .52892 L
.86053 .52548 L
.89827 .52256 L
.93846 .51979 L
.97619 .51744 L
Mfstroke
0 1 .585 r
.02381 .01472 m
.02846 .08443 L
.03279 .13921 L
.03754 .18769 L
.04262 .22661 L
.04518 .24151 L
.04795 .25441 L
.05058 .26372 L
.053 .27007 L
.05518 .27412 L
.05642 .27579 L
.05758 .27696 L
.05881 .27782 L
.05993 .27829 L
.06122 .27849 L
.06244 .27836 L
.0631 .27817 L
.06381 .27788 L
.0651 .27715 L
.06635 .27619 L
.0675 .27513 L
.07289 .26829 L
.08259 .25197 L
.09396 .23278 L
.09952 .22475 L
.10458 .21847 L
.10893 .21392 L
.11366 .20988 L
.11626 .20807 L
.11867 .20664 L
.12095 .20551 L
.1234 .20454 L
.12469 .20414 L
.12586 .20384 L
.12706 .20358 L
.12817 .20341 L
.12939 .20328 L
.13004 .20324 L
.13073 .20322 L
.13145 .20322 L
.13214 .20324 L
.13342 .20335 L
.13471 .20353 L
.13536 .20366 L
.13608 .20383 L
.13853 .20462 L
.13991 .20522 L
.14139 .206 L
.14407 .20781 L
.14661 .21007 L
Mistroke
.14932 .21318 L
.15188 .21691 L
.1542 .22112 L
.15693 .22737 L
.15989 .23607 L
.16524 .25839 L
.17483 .31501 L
.17991 .34198 L
.18275 .35353 L
.1841 .35798 L
.18534 .36151 L
.18656 .36441 L
.18789 .36702 L
.18923 .36904 L
.18997 .3699 L
.19066 .37055 L
.19192 .37136 L
.19308 .37171 L
.19435 .37166 L
.19499 .37148 L
.19568 .37117 L
.19695 .37032 L
.1981 .36924 L
.20068 .36588 L
.20307 .36176 L
.20532 .35716 L
.2264 .30032 L
.23615 .27625 L
.24147 .26535 L
.24645 .25678 L
.25525 .24527 L
.25991 .24077 L
.26492 .23682 L
.2847 .22441 L
.29515 .2183 L
.30625 .21259 L
.31607 .20855 L
.32129 .20682 L
.32692 .20525 L
.33206 .20407 L
.33679 .20318 L
.34164 .20244 L
.34606 .20192 L
.35079 .20151 L
.35339 .20134 L
.35585 .20123 L
.35695 .20118 L
.35812 .20115 L
.35912 .20112 L
.36022 .2011 L
Mistroke
.3614 .20109 L
.36267 .20108 L
.36386 .20109 L
.36496 .20109 L
.36623 .20111 L
.36695 .20113 L
.36759 .20114 L
.37003 .20122 L
.3714 .20128 L
.37289 .20135 L
.37557 .20151 L
.38082 .20192 L
.38565 .20241 L
.40449 .20511 L
.42516 .20891 L
.4656 .21666 L
.50453 .22412 L
.54591 .2321 L
.58578 .23938 L
.62413 .24586 L
.66493 .25214 L
.70422 .25755 L
.74199 .26224 L
.78221 .26675 L
.82092 .27074 L
.86208 .27469 L
.90172 .27829 L
.93985 .28162 L
.97619 .28468 L
Mfstroke
0 1 .609 r
.02381 .01472 m
.02846 .08443 L
.03279 .13926 L
.03754 .18778 L
.04262 .22631 L
.04518 .24061 L
.04652 .24682 L
.04795 .25245 L
.0492 .25658 L
.05058 .26031 L
.05183 .263 L
.053 .26493 L
.05422 .26638 L
.05538 .26725 L
.05641 .26763 L
.05755 .26766 L
.05878 .26725 L
.06009 .26636 L
.06132 .26513 L
.06244 .26372 L
.06508 .25944 L
.06787 .25376 L
.07287 .24171 L
.08414 .21226 L
.09401 .18969 L
.09944 .17948 L
.10458 .17133 L
.1095 .16488 L
.11485 .15926 L
.11972 .15533 L
.12204 .15382 L
.12422 .15262 L
.12642 .15161 L
.12844 .15086 L
.13069 .15023 L
.13187 .14998 L
.13311 .14978 L
.13424 .14966 L
.13544 .14959 L
.13658 .14959 L
.13762 .14964 L
.13884 .14976 L
.14016 .14997 L
.1414 .15026 L
.14255 .15059 L
.14499 .15157 L
.14722 .1528 L
.1498 .15471 L
.15225 .15709 L
.1545 .15989 L
Mistroke
.15658 .16312 L
.15886 .16751 L
.16131 .17352 L
.16402 .18199 L
.16656 .19203 L
.17131 .21586 L
.17682 .24668 L
.17951 .26018 L
.18195 .27061 L
.18416 .27822 L
.18656 .28445 L
.18787 .28697 L
.18909 .28875 L
.19025 .28998 L
.19148 .2908 L
.19272 .29114 L
.19341 .29113 L
.19405 .291 L
.19522 .29048 L
.19645 .28955 L
.19781 .28811 L
.19907 .28642 L
.20193 .2815 L
.20728 .26926 L
.21213 .25612 L
.22301 .22563 L
.23235 .20295 L
.24223 .18473 L
.2474 .17758 L
.25307 .17141 L
.25823 .16714 L
.26304 .16407 L
.26804 .1616 L
.27348 .15944 L
.28337 .15602 L
.30192 .14914 L
.32128 .14236 L
.33231 .1395 L
.33735 .13847 L
.34267 .13755 L
.34737 .13687 L
.35251 .13625 L
.36154 .13544 L
.36664 .13511 L
.37209 .13483 L
.37723 .13463 L
.3819 .1345 L
.38674 .13439 L
.38918 .13435 L
.39187 .13431 L
Mistroke
.39416 .13428 L
.39662 .13426 L
.39894 .13425 L
.40107 .13424 L
.40235 .13423 L
.40305 .13423 L
.40371 .13423 L
.405 .13423 L
.40616 .13423 L
.40684 .13423 L
.40756 .13423 L
.40884 .13423 L
.40955 .13423 L
.41021 .13423 L
.41173 .13424 L
.41428 .13425 L
.41662 .13426 L
.42185 .13429 L
.43178 .13439 L
.44095 .1345 L
.46172 .13482 L
.50101 .13558 L
.53878 .13639 L
.579 .13725 L
.61771 .13802 L
.65887 .13876 L
.69851 .13937 L
.73664 .13989 L
.77722 .14035 L
.81629 .14075 L
.8578 .14112 L
.8978 .14144 L
.93629 .14173 L
.97619 .14202 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.02605 .04963 L
.02846 .08294 L
.02962 .09681 L
.03072 .10818 L
.0317 .11672 L
.03279 .12429 L
.03398 .13041 L
.03524 .13449 L
.03641 .13631 L
.0375 .13659 L
.03879 .1355 L
.03997 .13348 L
.04132 .13029 L
.04262 .12665 L
.05221 .09541 L
.06244 .06865 L
.06792 .05818 L
.07289 .05062 L
.07794 .04449 L
.08259 .03999 L
.08803 .03583 L
.09391 .0324 L
.0991 .03008 L
.10458 .02819 L
.10954 .02687 L
.11406 .02592 L
.11928 .02506 L
.12422 .02444 L
.12878 .02399 L
.133 .02367 L
.13763 .0234 L
.14003 .02329 L
.14255 .02319 L
.14489 .02312 L
.14744 .02305 L
.14856 .02303 L
.14976 .02301 L
.15089 .02299 L
.15192 .02298 L
.15323 .02297 L
.15392 .02297 L
.15464 .02297 L
.15587 .02297 L
.15656 .02297 L
.15721 .02297 L
.15843 .02298 L
.15953 .02299 L
.16081 .023 L
.16202 .02302 L
Mistroke
.16422 .02307 L
.16656 .02313 L
.17077 .02328 L
.17541 .02345 L
.17794 .02354 L
.1803 .0236 L
.18154 .02362 L
.18287 .02364 L
.18362 .02365 L
.18434 .02366 L
.18498 .02366 L
.18568 .02367 L
.18692 .02367 L
.18824 .02366 L
.18937 .02365 L
.19061 .02364 L
.19206 .02361 L
.19338 .02359 L
.19636 .02352 L
.20175 .02337 L
.21222 .02303 L
.22194 .02277 L
.23111 .02257 L
.23624 .02249 L
.2409 .02243 L
.24602 .02239 L
.2489 .02237 L
.25156 .02235 L
.25409 .02234 L
.25645 .02233 L
.25891 .02232 L
.26021 .02232 L
.26161 .02232 L
.26283 .02232 L
.26352 .02232 L
.26417 .02232 L
.26548 .02231 L
.26621 .02231 L
.26689 .02231 L
.26802 .02231 L
.26926 .02232 L
.27056 .02232 L
.27177 .02232 L
.27756 .02232 L
.28009 .02233 L
.28283 .02233 L
.28409 .02233 L
.28543 .02233 L
.28657 .02233 L
.28783 .02233 L
Mistroke
.289 .02233 L
.29026 .02233 L
.29146 .02233 L
.29255 .02233 L
.29387 .02233 L
.2951 .02233 L
.29644 .02233 L
.29788 .02233 L
.30053 .02232 L
.30294 .02232 L
.30782 .0223 L
.31298 .02229 L
.3222 .02225 L
.33226 .02221 L
.34303 .02217 L
.35331 .02214 L
.36268 .02212 L
.3721 .02211 L
.38102 .0221 L
.40094 .02208 L
.41937 .02207 L
.43964 .02206 L
.45866 .02205 L
.47684 .02204 L
.49643 .02204 L
.51648 .02204 L
.53759 .02203 L
.57571 .02203 L
.59534 .02203 L
.6163 .02203 L
.65781 .02202 L
.69781 .02202 L
.7363 .02202 L
.77724 .02202 L
.81666 .02202 L
.85457 .02202 L
.89493 .02202 L
.93377 .02202 L
.97507 .02202 L
.97619 .02202 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.02846 .08443 L
.03279 .13924 L
.03754 .18752 L
.04262 .22508 L
.04518 .23847 L
.04652 .24407 L
.04795 .24895 L
.0492 .25235 L
.04986 .25384 L
.05058 .25521 L
.05183 .25703 L
.053 .25811 L
.05421 .25863 L
.05553 .25854 L
.05677 .25789 L
.05793 .25684 L
.05908 .2554 L
.06012 .2538 L
.06244 .24931 L
.08269 .19111 L
.09333 .1646 L
.09915 .15319 L
.10458 .14443 L
.10978 .13762 L
.11453 .13262 L
.1198 .12829 L
.12273 .12639 L
.12545 .12493 L
.12769 .12394 L
.13017 .12307 L
.13266 .12241 L
.13403 .12215 L
.13531 .12197 L
.13645 .12186 L
.13765 .1218 L
.13868 .12179 L
.1398 .12183 L
.14101 .12193 L
.14231 .12211 L
.14353 .12235 L
.14465 .12263 L
.14696 .12342 L
.14949 .12465 L
.15215 .12642 L
.15463 .12863 L
.15695 .1313 L
.15906 .13439 L
.16151 .13891 L
.16383 .14437 L
Mistroke
.16899 .1615 L
.17378 .18267 L
.179 .20589 L
.18174 .21585 L
.18323 .22032 L
.18463 .22382 L
.18601 .22664 L
.18726 .22866 L
.18866 .23029 L
.18942 .23093 L
.19015 .23138 L
.19141 .23178 L
.19258 .23177 L
.19386 .23136 L
.19451 .231 L
.19522 .2305 L
.19652 .22932 L
.1977 .22797 L
.20037 .22407 L
.20519 .21486 L
.22381 .17308 L
.23364 .15545 L
.24277 .14345 L
.24803 .13832 L
.25279 .13465 L
.2583 .13142 L
.26349 .12916 L
.26813 .12763 L
.27323 .12628 L
.28354 .12398 L
.302 .11944 L
.31285 .11664 L
.32312 .1143 L
.33313 .11247 L
.3424 .11119 L
.35142 .11028 L
.35598 .10993 L
.36101 .10961 L
.36604 .10935 L
.37146 .10914 L
.37658 .10898 L
.38127 .10887 L
.386 .10879 L
.3886 .10875 L
.39106 .10872 L
.39335 .1087 L
.39583 .10868 L
.39809 .10867 L
.40017 .10866 L
.40136 .10866 L
Mistroke
.40264 .10865 L
.40385 .10865 L
.40496 .10865 L
.40625 .10865 L
.40698 .10865 L
.40766 .10865 L
.4089 .10865 L
.40959 .10865 L
.41022 .10865 L
.41159 .10865 L
.41285 .10865 L
.4157 .10866 L
.41821 .10867 L
.42087 .10868 L
.43035 .10874 L
.44052 .10883 L
.45886 .10902 L
.50024 .10959 L
.5401 .11019 L
.57845 .11075 L
.61925 .11129 L
.65854 .11172 L
.69631 .11207 L
.73653 .11237 L
.77524 .1126 L
.8164 .1128 L
.85605 .11295 L
.89417 .11307 L
.93476 .11318 L
.97382 .11328 L
.97619 .11329 L
Mfstroke
0 1 .68 r
.02381 .01472 m
.02499 .02095 L
.02605 .02153 L
.02729 .02156 L
.02846 .02142 L
.02954 .02122 L
.03053 .02102 L
.03279 .02053 L
.03746 .01956 L
.04262 .01864 L
.05224 .01738 L
.05751 .01689 L
.06244 .01653 L
.06788 .01622 L
.07305 .01599 L
.07768 .01583 L
.08274 .0157 L
.08822 .01558 L
.09407 .01549 L
.09958 .01542 L
.10458 .01538 L
.10945 .01534 L
.1146 .01531 L
.119 .01529 L
.12383 .01528 L
.12902 .01526 L
.13459 .01525 L
.13985 .01525 L
.14465 .01524 L
.14693 .01524 L
.14945 .01524 L
.15209 .01524 L
.15329 .01524 L
.15456 .01524 L
.15566 .01524 L
.15686 .01524 L
.15796 .01523 L
.15897 .01523 L
.16018 .01523 L
.16127 .01523 L
.16254 .01523 L
.16373 .01523 L
.16493 .01523 L
.16625 .01524 L
.16891 .01524 L
.17369 .01524 L
.17638 .01524 L
.17789 .01524 L
.17861 .01524 L
.17927 .01524 L
Mistroke
.18055 .01524 L
.18123 .01524 L
.18195 .01524 L
.18264 .01524 L
.18328 .01524 L
.18449 .01524 L
.18566 .01524 L
.18691 .01524 L
.18916 .01524 L
.19184 .01524 L
.19428 .01524 L
.20461 .01523 L
.21358 .01523 L
.22309 .01522 L
.22782 .01522 L
.23303 .01522 L
.23777 .01522 L
.24222 .01522 L
.24744 .01522 L
.25222 .01522 L
.25747 .01522 L
.26299 .01522 L
.30115 .01522 L
.32244 .01522 L
.34177 .01522 L
.35143 .01522 L
.36189 .01522 L
.37177 .01522 L
.38086 .01522 L
.39966 .01522 L
.41034 .01522 L
.42032 .01522 L
.43075 .01522 L
.43589 .01522 L
.44065 .01522 L
.44953 .01522 L
.45421 .01522 L
.45919 .01522 L
.46407 .01522 L
.46855 .01522 L
.4709 .01522 L
.47346 .01522 L
.47614 .01522 L
.47734 .01522 L
.47864 .01522 L
.47988 .01522 L
.48102 .01522 L
.48211 .01522 L
.48327 .01522 L
.4843 .01522 L
Mistroke
.48527 .01522 L
.48633 .01522 L
.48747 .01522 L
.48868 .01522 L
.49 .01522 L
.4924 .01522 L
.49474 .01522 L
.49691 .01522 L
.50749 .01522 L
.51745 .01522 L
.53606 .01522 L
.57463 .01522 L
.61566 .01522 L
.65516 .01522 L
.69316 .01522 L
.7336 .01522 L
.77253 .01522 L
.81391 .01522 L
.85377 .01522 L
.89212 .01522 L
.93293 .01522 L
.97221 .01522 L
.97619 .01522 L
Mfstroke
0 1 .704 r
.02381 .01472 m
.02846 .08437 L
.03279 .13817 L
.03523 .16292 L
.03754 .18229 L
.0402 .19963 L
.04135 .20551 L
.04262 .21087 L
.04386 .21502 L
.04502 .21799 L
.04624 .22021 L
.04756 .22163 L
.04878 .22212 L
.04994 .22192 L
.05099 .22124 L
.05212 .22001 L
.05348 .21797 L
.05471 .21565 L
.05748 .20914 L
.06244 .19464 L
.07229 .16358 L
.08269 .13549 L
.08812 .12373 L
.09409 .11307 L
.09958 .10514 L
.10458 .09927 L
.10937 .0947 L
.11458 .09075 L
.12009 .08756 L
.12256 .08642 L
.1253 .08536 L
.12765 .08459 L
.13017 .08392 L
.13157 .08362 L
.13284 .08338 L
.13414 .08318 L
.13535 .08302 L
.1364 .08292 L
.13751 .08283 L
.13875 .08277 L
.13988 .08275 L
.14106 .08276 L
.14233 .08281 L
.14354 .0829 L
.14465 .08302 L
.1459 .0832 L
.14709 .08341 L
.14932 .08395 L
.15172 .08474 L
.15434 .08591 L
Mistroke
.15662 .08726 L
.15905 .08912 L
.16134 .09138 L
.16341 .09395 L
.16852 .10292 L
.17404 .11653 L
.17922 .12945 L
.18175 .13448 L
.18405 .138 L
.18518 .13935 L
.18641 .14052 L
.18758 .14137 L
.18865 .14192 L
.18979 .14229 L
.19104 .14245 L
.19235 .14236 L
.19358 .14207 L
.19486 .14156 L
.19621 .14084 L
.19861 .13913 L
.20403 .13391 L
.21422 .12222 L
.21982 .11612 L
.2251 .11105 L
.23008 .10703 L
.2327 .10524 L
.23548 .10361 L
.23781 .10246 L
.24037 .10143 L
.2415 .10107 L
.24271 .10075 L
.24376 .10052 L
.24489 .10033 L
.24611 .1002 L
.24725 .10016 L
.24847 .1002 L
.24917 .10026 L
.24982 .10036 L
.25099 .1006 L
.25207 .10092 L
.25325 .10138 L
.2545 .10201 L
.25666 .10348 L
.25868 .10536 L
.2609 .10805 L
.26327 .11174 L
.27292 .13594 L
.28315 .16863 L
.28573 .17549 L
.2885 .18158 L
Mistroke
.29008 .18438 L
.29153 .1865 L
.29299 .18817 L
.29372 .18884 L
.29438 .18935 L
.29562 .19006 L
.2963 .19032 L
.29694 .19048 L
.29809 .19057 L
.29933 .1904 L
.29998 .1902 L
.3007 .18989 L
.30214 .18903 L
.30348 .18795 L
.30473 .18672 L
.30991 .1798 L
.31482 .17142 L
.32402 .15412 L
.33404 .13645 L
.34468 .12112 L
.35415 .11062 L
.36461 .10197 L
.37411 .09622 L
.38303 .0922 L
.39287 .08891 L
.40323 .08639 L
.41207 .08477 L
.42174 .0834 L
.44136 .08143 L
.45234 .08064 L
.46232 .08006 L
.48152 .07923 L
.49234 .07889 L
.50232 .07863 L
.5211 .07827 L
.53177 .07811 L
.54174 .07799 L
.56205 .07779 L
.58059 .07766 L
.59963 .07756 L
.61051 .07752 L
.62037 .07748 L
.64009 .07743 L
.65091 .07741 L
.66109 .0774 L
.67088 .07739 L
.68122 .07738 L
.69004 .07737 L
.69505 .07737 L
.69971 .07737 L
Mistroke
.70474 .07737 L
.70758 .07737 L
.7102 .07737 L
.71249 .07737 L
.71379 .07737 L
.71501 .07737 L
.7163 .07736 L
.71747 .07736 L
.71812 .07736 L
.71883 .07736 L
.72012 .07736 L
.72137 .07737 L
.72256 .07737 L
.72362 .07737 L
.72478 .07737 L
.72736 .07737 L
.72975 .07737 L
.73409 .07737 L
.73869 .07737 L
.74816 .07737 L
.75832 .07737 L
.77665 .07738 L
.818 .07741 L
.85783 .07743 L
.89615 .07745 L
.93692 .07747 L
.97617 .07749 L
.97619 .07749 L
Mfstroke
0 1 .727 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19249 L
.04262 .23053 L
.04754 .26142 L
.0522 .28326 L
.05711 .29972 L
.05988 .30643 L
.06244 .3112 L
.06487 .31459 L
.06623 .31605 L
.06747 .31715 L
.06862 .31796 L
.06988 .31865 L
.07107 .31911 L
.07218 .3194 L
.07285 .31951 L
.07358 .31957 L
.0749 .31956 L
.07618 .3194 L
.07737 .31913 L
.07865 .31873 L
.08006 .31816 L
.0829 .31669 L
.09411 .30849 L
.10458 .3006 L
.10959 .29751 L
.11223 .29615 L
.11503 .29493 L
.11748 .29408 L
.11877 .29371 L
.12017 .29338 L
.12145 .29314 L
.12263 .29297 L
.12375 .29286 L
.12493 .2928 L
.12609 .2928 L
.12715 .29284 L
.12837 .29296 L
.12952 .29313 L
.13059 .29334 L
.13157 .29359 L
.13379 .29432 L
.13604 .29534 L
.1385 .2968 L
.14108 .29877 L
.14349 .30107 L
.14847 .30756 L
.15128 .31253 L
Mistroke
.1539 .3182 L
.15868 .33202 L
.16378 .35277 L
.17344 .40477 L
.17767 .42592 L
.18231 .44421 L
.18491 .45195 L
.18733 .4576 L
.18989 .46205 L
.19132 .4639 L
.19262 .46523 L
.19332 .4658 L
.19405 .4663 L
.19537 .46698 L
.1961 .46723 L
.19679 .46739 L
.19754 .46749 L
.19835 .46751 L
.19901 .46746 L
.19973 .46734 L
.20048 .46715 L
.20118 .46692 L
.20243 .46638 L
.20376 .46565 L
.20638 .46381 L
.20921 .46138 L
.21435 .45634 L
.21931 .45147 L
.22173 .44933 L
.22395 .44764 L
.22507 .44689 L
.2263 .44618 L
.22736 .44567 L
.22852 .44521 L
.22976 .44488 L
.23108 .44471 L
.23229 .44474 L
.23344 .44495 L
.23471 .4454 L
.23535 .44572 L
.23605 .44615 L
.23729 .44713 L
.23845 .4483 L
.24107 .45198 L
.24253 .45472 L
.24386 .45768 L
.24905 .47356 L
.25469 .49677 L
.25997 .51916 L
.26492 .53732 L
Mistroke
.26985 .5519 L
.27437 .56228 L
.27938 .5709 L
.28214 .57452 L
.28477 .5773 L
.2873 .57942 L
.28999 .58115 L
.2913 .58181 L
.29253 .58232 L
.29363 .5827 L
.29483 .58304 L
.29617 .58332 L
.2969 .58343 L
.29758 .58352 L
.2988 .5836 L
.3001 .58362 L
.30084 .5836 L
.30163 .58355 L
.30239 .58347 L
.30309 .58339 L
.3044 .58317 L
.3058 .58288 L
.30819 .58224 L
.3107 .58139 L
.31518 .57951 L
.32529 .57419 L
.34357 .56382 L
.3817 .54803 L
.42228 .53196 L
.46135 .51432 L
.50287 .49995 L
.54287 .49014 L
.58136 .48275 L
.62229 .47663 L
.66172 .47202 L
.69962 .46844 L
.73998 .46535 L
.77883 .46289 L
.82012 .4607 L
.85991 .45889 L
.89817 .45734 L
.93889 .45586 L
.97619 .45464 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19255 L
.04262 .23078 L
.04754 .26215 L
.0522 .28476 L
.05711 .30237 L
.05988 .30989 L
.06244 .31547 L
.06487 .31968 L
.06747 .32317 L
.06993 .3256 L
.07218 .32718 L
.07354 .32787 L
.07481 .32834 L
.07553 .32855 L
.07619 .3287 L
.07696 .32883 L
.07767 .32891 L
.07898 .32895 L
.08018 .3289 L
.0815 .32873 L
.08217 .32862 L
.0829 .32846 L
.08573 .32763 L
.08831 .32663 L
.09411 .32386 L
.10458 .31856 L
.10939 .31654 L
.11202 .31563 L
.11449 .31493 L
.11659 .31447 L
.11767 .31428 L
.11885 .31411 L
.12008 .31398 L
.12136 .3139 L
.12256 .31388 L
.12366 .3139 L
.12496 .31398 L
.12569 .31406 L
.12637 .31414 L
.12761 .31435 L
.12892 .31464 L
.1312 .31531 L
.1337 .31634 L
.13637 .31779 L
.13924 .31981 L
.14443 .32493 L
.14697 .3283 L
Mistroke
.14968 .33266 L
.15456 .34303 L
.15754 .35142 L
.16035 .36104 L
.1656 .38379 L
.17519 .43222 L
.17782 .44367 L
.18063 .45413 L
.18306 .46158 L
.1857 .46799 L
.18707 .47065 L
.18833 .47273 L
.18952 .47436 L
.19083 .47582 L
.19199 .47684 L
.19309 .47756 L
.19425 .4781 L
.19549 .47843 L
.19675 .47853 L
.19746 .47848 L
.19812 .47838 L
.19882 .47821 L
.19946 .478 L
.20088 .47738 L
.2021 .47667 L
.20342 .47575 L
.20582 .47375 L
.21538 .46316 L
.2243 .45327 L
.22665 .45119 L
.22888 .44956 L
.23011 .44882 L
.23145 .44816 L
.23267 .44771 L
.23379 .44744 L
.23503 .4473 L
.2362 .44734 L
.23747 .44758 L
.23819 .44783 L
.23885 .44812 L
.2401 .44886 L
.24146 .44997 L
.24289 .4515 L
.24422 .45328 L
.24696 .45814 L
.24955 .46428 L
.2544 .47956 L
.26528 .5206 L
.27498 .54983 L
.27988 .56047 L
Mistroke
.28526 .56936 L
.28985 .57492 L
.29239 .57731 L
.29479 .57919 L
.29702 .58063 L
.29945 .58189 L
.30166 .58279 L
.30371 .58344 L
.305 .58377 L
.30636 .58404 L
.30752 .58423 L
.30879 .58439 L
.30951 .58446 L
.31016 .58451 L
.31092 .58456 L
.31163 .58459 L
.31291 .58462 L
.31362 .58461 L
.31429 .5846 L
.31547 .58457 L
.31658 .58451 L
.3178 .58442 L
.31912 .58431 L
.32425 .5837 L
.33389 .58226 L
.33859 .58161 L
.34286 .58111 L
.34749 .58069 L
.35004 .58052 L
.35244 .5804 L
.35371 .58035 L
.35506 .5803 L
.3562 .58027 L
.35747 .58025 L
.35818 .58024 L
.35882 .58023 L
.35957 .58023 L
.36028 .58022 L
.36154 .58022 L
.36225 .58023 L
.36291 .58023 L
.36361 .58023 L
.36424 .58024 L
.36568 .58026 L
.36828 .58031 L
.37314 .58042 L
.37839 .58054 L
.38129 .5806 L
.38271 .58062 L
.38402 .58064 L
Mistroke
.38521 .58065 L
.38647 .58066 L
.38774 .58066 L
.38846 .58066 L
.38913 .58066 L
.39031 .58065 L
.39138 .58064 L
.39261 .58063 L
.39379 .5806 L
.39605 .58055 L
.39814 .58048 L
.4029 .58027 L
.40814 .57994 L
.41291 .57956 L
.42358 .57846 L
.46363 .57317 L
.50217 .5686 L
.54316 .56403 L
.58264 .55961 L
.6206 .55555 L
.66101 .55147 L
.6999 .54782 L
.74125 .54432 L
.78109 .54131 L
.8194 .53874 L
.86017 .53631 L
.89943 .53422 L
.93717 .53239 L
.97619 .53067 L
Mfstroke
0 1 .775 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .1925 L
.04262 .23059 L
.04754 .26163 L
.0522 .28376 L
.05711 .30074 L
.05988 .30785 L
.06244 .31305 L
.06487 .3169 L
.06747 .32001 L
.06873 .32117 L
.06993 .32209 L
.07111 .32283 L
.07218 .32336 L
.07346 .32385 L
.07417 .32405 L
.07484 .3242 L
.07602 .32437 L
.0773 .32443 L
.07798 .32441 L
.07872 .32436 L
.07949 .32426 L
.08022 .32414 L
.08151 .32386 L
.0829 .32346 L
.08569 .32242 L
.08872 .32102 L
.09424 .31807 L
.10458 .31252 L
.1091 .31055 L
.11148 .30968 L
.11398 .30893 L
.11531 .3086 L
.11677 .30829 L
.11811 .30806 L
.11933 .30791 L
.12059 .3078 L
.12128 .30776 L
.12193 .30774 L
.12309 .30773 L
.12435 .30779 L
.12566 .30791 L
.12688 .30808 L
.12822 .30833 L
.12966 .30869 L
.1326 .30972 L
.13528 .31103 L
.13776 .31258 L
Mistroke
.14045 .31472 L
.14536 .32001 L
.14792 .32366 L
.15069 .32846 L
.15571 .34004 L
.16059 .356 L
.16507 .37544 L
.17032 .40228 L
.17593 .43009 L
.17866 .44145 L
.18123 .45048 L
.18358 .45718 L
.18606 .46272 L
.18829 .46639 L
.18957 .46796 L
.19076 .46911 L
.19185 .46989 L
.19285 .4704 L
.19395 .47075 L
.1951 .47088 L
.19628 .47078 L
.19753 .47044 L
.19872 .46991 L
.19979 .46927 L
.20243 .46712 L
.20492 .46447 L
.21497 .45017 L
.22047 .44168 L
.2256 .43441 L
.23021 .42897 L
.2328 .42657 L
.23516 .42487 L
.23649 .42415 L
.23773 .42366 L
.23838 .42348 L
.2391 .42333 L
.23984 .42325 L
.24054 .42324 L
.24183 .4234 L
.243 .42377 L
.24429 .42443 L
.24494 .42487 L
.24565 .42544 L
.2469 .42668 L
.24807 .42812 L
.25027 .43164 L
.25264 .43666 L
.25521 .44357 L
.26412 .47637 L
.27437 .51648 L
Mistroke
.28397 .54479 L
.28879 .5551 L
.29398 .56363 L
.29693 .56746 L
.29974 .57051 L
.30245 .57296 L
.305 .57489 L
.30742 .57642 L
.31004 .57777 L
.3146 .57955 L
.31719 .58029 L
.31993 .58091 L
.32229 .58134 L
.32482 .58171 L
.32936 .58223 L
.3336 .58262 L
.34322 .58352 L
.3534 .58479 L
.36447 .58655 L
.37404 .58812 L
.3846 .58963 L
.38951 .59019 L
.39481 .59068 L
.39981 .59103 L
.40439 .59127 L
.40692 .59137 L
.40928 .59143 L
.41186 .59149 L
.41331 .59151 L
.41463 .59153 L
.4153 .59153 L
.41601 .59154 L
.41729 .59154 L
.418 .59154 L
.41866 .59154 L
.41939 .59154 L
.42017 .59154 L
.42084 .59154 L
.42157 .59153 L
.4229 .59152 L
.4242 .59151 L
.4254 .5915 L
.4305 .59141 L
.43601 .59129 L
.44598 .59102 L
.4646 .59053 L
.50568 .58961 L
.54524 .58846 L
.58328 .58715 L
.62378 .58574 L
Mistroke
.66276 .5844 L
.70419 .58304 L
.74411 .58182 L
.78251 .58076 L
.82336 .57974 L
.8627 .57886 L
.90053 .57809 L
.9408 .57733 L
.97619 .57671 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19233 L
.04262 .22996 L
.04754 .26007 L
.0522 .28087 L
.05475 .28956 L
.05711 .29607 L
.0597 .30172 L
.06244 .30619 L
.06378 .30787 L
.06505 .30918 L
.0662 .31016 L
.06743 .311 L
.06813 .31138 L
.06876 .31167 L
.07 .3121 L
.07069 .31226 L
.07144 .31238 L
.07215 .31245 L
.0728 .31246 L
.07396 .31239 L
.07505 .31222 L
.07624 .31193 L
.07751 .31152 L
.08012 .31038 L
.0825 .30906 L
.09397 .30087 L
.09901 .29719 L
.10458 .29355 L
.10903 .29112 L
.11383 .2891 L
.11648 .28829 L
.11764 .288 L
.1189 .28774 L
.12011 .28754 L
.12122 .28741 L
.1224 .28731 L
.12366 .28727 L
.12434 .28727 L
.12506 .28729 L
.12635 .28738 L
.12707 .28746 L
.12774 .28756 L
.12926 .28784 L
.13059 .28818 L
.13181 .28856 L
.13454 .28968 L
.13697 .29101 L
Mistroke
.13961 .29288 L
.14443 .29758 L
.14699 .30092 L
.14976 .30534 L
.1522 .31008 L
.15477 .31611 L
.15965 .33122 L
.16414 .35011 L
.17427 .40351 L
.17719 .41732 L
.17995 .42841 L
.18246 .43662 L
.18512 .44334 L
.18745 .44758 L
.18878 .44934 L
.19002 .45059 L
.19116 .4514 L
.19221 .45188 L
.19335 .45213 L
.19455 .45209 L
.19578 .45177 L
.19709 .45112 L
.19833 .45025 L
.19945 .44925 L
.2022 .44606 L
.2048 .44224 L
.22315 .40509 L
.23289 .38591 L
.23822 .37716 L
.2432 .37044 L
.24744 .36595 L
.24963 .3641 L
.252 .36245 L
.25335 .36169 L
.25459 .36108 L
.25576 .36061 L
.25705 .36018 L
.25821 .3599 L
.25929 .3597 L
.26043 .35957 L
.26167 .35953 L
.26292 .35958 L
.26406 .35971 L
.26537 .35996 L
.26661 .3603 L
.26882 .36116 L
.27122 .36247 L
.27386 .36436 L
.27666 .36687 L
.28168 .37255 L
Mistroke
.30277 .40327 L
.31219 .41474 L
.32232 .42375 L
.33188 .42977 L
.34063 .43422 L
.38036 .46119 L
.41857 .49418 L
.43826 .50673 L
.45923 .51711 L
.50084 .53302 L
.54092 .54445 L
.57949 .55256 L
.62052 .55916 L
.66002 .56414 L
.69802 .56799 L
.73846 .57137 L
.77739 .5741 L
.81877 .57659 L
.85864 .57866 L
.89698 .58042 L
.93779 .58207 L
.97619 .58344 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19231 L
.04262 .22987 L
.04754 .25981 L
.0522 .28032 L
.05475 .28878 L
.05711 .29504 L
.0597 .30037 L
.06111 .30266 L
.06244 .30447 L
.06369 .30586 L
.06505 .30707 L
.06628 .30791 L
.06743 .30849 L
.06813 .30876 L
.06879 .30895 L
.07003 .30917 L
.07072 .30921 L
.07136 .30921 L
.07206 .30915 L
.0728 .30904 L
.07395 .30877 L
.07519 .30835 L
.07742 .30732 L
.08007 .3057 L
.0825 .30394 L
.09397 .29397 L
.10458 .28534 L
.10935 .28229 L
.11383 .28003 L
.11608 .27915 L
.11851 .27839 L
.11982 .27807 L
.1212 .2778 L
.12238 .27763 L
.12366 .2775 L
.12434 .27746 L
.12507 .27744 L
.12575 .27744 L
.12639 .27745 L
.12759 .27753 L
.12886 .27769 L
.12952 .27779 L
.13023 .27793 L
.13151 .27825 L
.13303 .27872 L
.13442 .27926 L
.13688 .28048 L
Mistroke
.13955 .28224 L
.14208 .28436 L
.14443 .28678 L
.14952 .29393 L
.15239 .2994 L
.15502 .30561 L
.15987 .32083 L
.16499 .34327 L
.17473 .39642 L
.17899 .41629 L
.18123 .42479 L
.18361 .43218 L
.18615 .43824 L
.18736 .44048 L
.18849 .44221 L
.18964 .44362 L
.19069 .44461 L
.19185 .44541 L
.19311 .44591 L
.19434 .44606 L
.19548 .44593 L
.19673 .4455 L
.19743 .44513 L
.19807 .44473 L
.20075 .44232 L
.20328 .43914 L
.20787 .43162 L
.21209 .42329 L
.22163 .40218 L
.2307 .38232 L
.24043 .36414 L
.24602 .35587 L
.25111 .34984 L
.25623 .34517 L
.26109 .3418 L
.26567 .33932 L
.27072 .3372 L
.27327 .33637 L
.27601 .33565 L
.27727 .33539 L
.2786 .33516 L
.27973 .33501 L
.28097 .33488 L
.28221 .33479 L
.28338 .33475 L
.28444 .33475 L
.28558 .33479 L
.28682 .33486 L
.28814 .33499 L
.28927 .33514 L
Mistroke
.29051 .33534 L
.29509 .33636 L
.29938 .33765 L
.33818 .34987 L
.34829 .35265 L
.35932 .35667 L
.36975 .36202 L
.37942 .36847 L
.41857 .40295 L
.46017 .43591 L
.50026 .46165 L
.53883 .48268 L
.57985 .50063 L
.61936 .51437 L
.65735 .525 L
.6978 .53409 L
.73672 .5412 L
.7781 .54744 L
.81797 .55248 L
.85632 .55664 L
.89712 .56049 L
.93641 .56374 L
.97418 .56649 L
.97619 .56662 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.02846 .08441 L
.03279 .13876 L
.03754 .1846 L
.0402 .20327 L
.04262 .21572 L
.04385 .22041 L
.04516 .2242 L
.04627 .22651 L
.0475 .22813 L
.04882 .22884 L
.04957 .22881 L
.05024 .22853 L
.05156 .22734 L
.05281 .2255 L
.05397 .22327 L
.0552 .22039 L
.05742 .21419 L
.06244 .197 L
.07287 .15888 L
.07835 .14115 L
.08414 .12512 L
.08922 .11336 L
.09479 .10271 L
.10458 .08881 L
.11001 .08326 L
.11496 .07927 L
.12067 .07573 L
.12608 .07327 L
.12851 .07241 L
.13108 .07165 L
.1333 .07111 L
.1357 .07065 L
.13704 .07044 L
.13827 .07029 L
.13944 .07017 L
.14067 .07008 L
.14133 .07005 L
.14203 .07002 L
.14329 .07 L
.14407 .07 L
.1448 .07002 L
.14545 .07004 L
.14616 .07008 L
.14739 .07018 L
.14852 .07031 L
.14982 .0705 L
.15105 .07072 L
.15324 .07125 L
.15563 .07203 L
Mistroke
.15824 .0732 L
.16103 .07488 L
.16366 .07698 L
.16604 .07942 L
.17137 .08684 L
.177 .09631 L
.17933 .09987 L
.18181 .10305 L
.18324 .10451 L
.18454 .1056 L
.18584 .10645 L
.18708 .10703 L
.18819 .10739 L
.18941 .10759 L
.19069 .10761 L
.19189 .10747 L
.193 .10721 L
.19402 .10687 L
.19632 .1058 L
.19866 .10435 L
.20122 .10245 L
.20637 .09805 L
.21729 .08832 L
.2272 .08092 L
.23206 .07802 L
.23731 .07541 L
.24186 .07356 L
.24685 .07193 L
.25215 .07061 L
.25486 .07007 L
.25776 .0696 L
.26048 .06922 L
.26296 .06894 L
.26526 .06873 L
.26781 .06853 L
.27261 .06824 L
.27771 .06801 L
.28687 .06762 L
.29757 .06699 L
.30763 .06618 L
.32608 .06462 L
.33654 .0639 L
.34628 .06337 L
.35595 .06299 L
.3663 .0627 L
.37198 .06258 L
.37734 .06249 L
.38739 .06235 L
.39709 .06225 L
.40738 .06217 L
Mistroke
.42582 .06205 L
.43524 .06201 L
.44537 .06197 L
.45493 .06194 L
.46368 .06192 L
.46845 .06192 L
.47353 .06191 L
.47793 .0619 L
.48268 .0619 L
.48559 .0619 L
.48828 .0619 L
.49079 .06189 L
.49355 .06189 L
.49587 .06189 L
.49834 .06189 L
.49971 .06189 L
.50096 .06189 L
.50222 .06189 L
.50341 .06189 L
.50451 .06189 L
.50569 .06189 L
.50701 .06189 L
.50822 .06189 L
.50941 .06189 L
.51071 .06189 L
.51137 .06189 L
.51207 .06189 L
.51333 .06189 L
.5158 .06189 L
.51814 .06189 L
.52251 .06189 L
.52769 .06189 L
.53247 .0619 L
.54327 .0619 L
.56205 .06191 L
.58269 .06192 L
.62305 .06196 L
.6619 .06198 L
.70319 .06201 L
.74298 .06203 L
.78124 .06205 L
.82196 .06206 L
.86116 .06207 L
.90281 .06208 L
.94295 .06209 L
.97619 .06209 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.02846 .08411 L
.03279 .13473 L
.03406 .14612 L
.03527 .15522 L
.03637 .16203 L
.03754 .16774 L
.0388 .17225 L
.03997 .17491 L
.04123 .17632 L
.04195 .1765 L
.04262 .17631 L
.04384 .17516 L
.04453 .1741 L
.04517 .17288 L
.04761 .1667 L
.05217 .1511 L
.06244 .11394 L
.06795 .09726 L
.07314 .08418 L
.08284 .06583 L
.08828 .05837 L
.09328 .05291 L
.09878 .04818 L
.10458 .04433 L
.10954 .04177 L
.11406 .03992 L
.11928 .03824 L
.12422 .03702 L
.12878 .03615 L
.133 .03554 L
.13763 .03504 L
.13997 .03485 L
.14255 .03469 L
.1449 .03459 L
.14623 .03455 L
.14747 .03452 L
.14878 .0345 L
.14997 .0345 L
.15063 .0345 L
.15135 .03451 L
.15264 .03453 L
.15376 .03456 L
.15498 .0346 L
.15626 .03467 L
.15746 .03474 L
.1596 .0349 L
.1619 .03514 L
.16457 .0355 L
.16749 .03599 L
Mistroke
.1728 .03714 L
.17758 .0382 L
.1801 .03866 L
.18275 .03902 L
.18408 .03915 L
.18478 .03921 L
.18553 .03925 L
.18685 .03931 L
.18808 .03933 L
.18873 .03933 L
.18943 .03933 L
.19071 .03929 L
.19195 .03924 L
.1931 .03917 L
.19526 .03899 L
.19764 .03874 L
.20247 .03812 L
.21342 .03653 L
.22345 .03525 L
.2329 .03434 L
.23765 .03399 L
.24284 .03369 L
.24807 .03346 L
.25095 .03336 L
.25366 .03328 L
.25619 .03322 L
.25893 .03317 L
.26142 .03314 L
.26371 .03311 L
.26497 .0331 L
.26616 .03309 L
.2684 .03308 L
.26965 .03308 L
.27081 .03307 L
.27208 .03307 L
.27272 .03307 L
.27343 .03307 L
.2746 .03307 L
.27568 .03307 L
.27686 .03307 L
.27811 .03307 L
.27912 .03307 L
.28021 .03307 L
.2814 .03307 L
.28251 .03307 L
.28318 .03307 L
.2839 .03307 L
.28518 .03306 L
.28589 .03306 L
.28655 .03306 L
Mistroke
.28807 .03306 L
.28939 .03305 L
.2906 .03305 L
.29333 .03303 L
.29574 .03302 L
.29837 .03299 L
.30316 .03294 L
.3245 .03261 L
.34383 .03233 L
.35352 .03224 L
.36399 .03216 L
.37388 .03211 L
.38298 .03207 L
.40182 .03202 L
.42249 .03197 L
.44201 .03194 L
.46293 .03191 L
.47311 .0319 L
.48418 .0319 L
.50431 .03189 L
.5241 .03188 L
.54511 .03187 L
.5646 .03186 L
.58288 .03186 L
.60308 .03186 L
.62159 .03186 L
.64213 .03185 L
.66123 .03185 L
.69936 .03185 L
.73843 .03185 L
.77995 .03185 L
.81995 .03185 L
.85843 .03184 L
.89937 .03184 L
.9388 .03184 L
.97619 .03184 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02005 L
.0379 .01896 L
.04262 .01814 L
.04714 .01749 L
.05212 .01693 L
.05713 .01649 L
.06244 .01613 L
.06792 .01584 L
.07293 .01564 L
.07871 .01546 L
.0842 .01534 L
.08925 .01525 L
.09394 .01519 L
.09909 .01513 L
.10458 .01509 L
.10994 .01505 L
.11487 .01503 L
.12028 .01501 L
.12599 .015 L
.13096 .01499 L
.13561 .01498 L
.1407 .01497 L
.14616 .01497 L
.15145 .01496 L
.15634 .01496 L
.15889 .01496 L
.1617 .01496 L
.16468 .01496 L
.1674 .01496 L
.1724 .01496 L
.17778 .01496 L
.18752 .01496 L
.19745 .01496 L
.20805 .01495 L
.2132 .01495 L
.21806 .01495 L
.22715 .01495 L
.23177 .01495 L
.23666 .01495 L
.24084 .01495 L
.24321 .01495 L
.24543 .01495 L
.24666 .01495 L
.24799 .01495 L
.24917 .01495 L
Mistroke
.25043 .01495 L
.25167 .01495 L
.25279 .01495 L
.25393 .01495 L
.25499 .01495 L
.25624 .01495 L
.25756 .01495 L
.25869 .01495 L
.25992 .01495 L
.26126 .01495 L
.26268 .01495 L
.26526 .01495 L
.27489 .01495 L
.28511 .01495 L
.28767 .01495 L
.29044 .01495 L
.29202 .01495 L
.29347 .01495 L
.29486 .01495 L
.29555 .01495 L
.29631 .01495 L
.29701 .01495 L
.29767 .01495 L
.29891 .01495 L
.2996 .01495 L
.30024 .01495 L
.30094 .01495 L
.30168 .01495 L
.30291 .01495 L
.30406 .01495 L
.30667 .01495 L
.30914 .01495 L
.31183 .01495 L
.31673 .01495 L
.32592 .01495 L
.33573 .01495 L
.34657 .01495 L
.35607 .01495 L
.36632 .01495 L
.37714 .01495 L
.38732 .01495 L
.40694 .01495 L
.42842 .01495 L
.44916 .01495 L
.46802 .01495 L
.4876 .01495 L
.50854 .01495 L
.54849 .01495 L
.58693 .01495 L
.62781 .01495 L
Mistroke
.66719 .01495 L
.70504 .01495 L
.74535 .01495 L
.78414 .01495 L
.82538 .01495 L
.86511 .01495 L
.90333 .01495 L
.94399 .01495 L
.97619 .01495 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.02605 .04945 L
.02729 .0666 L
.02846 .08081 L
.02954 .09192 L
.03072 .10144 L
.0318 .10778 L
.03279 .11181 L
.03396 .11461 L
.03506 .11563 L
.03626 .11539 L
.03756 .11394 L
.03821 .11288 L
.03891 .11153 L
.0402 .10866 L
.04262 .10245 L
.05302 .07523 L
.06244 .05683 L
.06789 .04902 L
.07302 .0432 L
.07844 .03837 L
.08429 .03434 L
.08943 .03161 L
.09486 .02937 L
.09949 .02787 L
.10458 .02657 L
.10982 .02553 L
.11478 .02476 L
.11924 .02423 L
.12409 .02377 L
.12936 .02339 L
.13495 .0231 L
.13973 .02292 L
.14245 .02285 L
.145 .02279 L
.14618 .02277 L
.14744 .02276 L
.14852 .02274 L
.1497 .02273 L
.15042 .02273 L
.15108 .02272 L
.15239 .02272 L
.15358 .02272 L
.15484 .02272 L
.15606 .02273 L
.15738 .02274 L
.15863 .02276 L
.15976 .02278 L
.16255 .02284 L
.16519 .02291 L
Mistroke
.1749 .02332 L
.17912 .02348 L
.18028 .02351 L
.1815 .02354 L
.18256 .02356 L
.18369 .02358 L
.18491 .02359 L
.18605 .0236 L
.18675 .0236 L
.18741 .0236 L
.18864 .0236 L
.1898 .02359 L
.19088 .02358 L
.19205 .02357 L
.1933 .02355 L
.19817 .02344 L
.20354 .02329 L
.22194 .02276 L
.22687 .02265 L
.23206 .02255 L
.23654 .02248 L
.24132 .02243 L
.24403 .0224 L
.24649 .02239 L
.24896 .02237 L
.25008 .02237 L
.2513 .02236 L
.25262 .02236 L
.25334 .02236 L
.25402 .02236 L
.25523 .02236 L
.25653 .02236 L
.25726 .02236 L
.25805 .02236 L
.2588 .02236 L
.25949 .02236 L
.2608 .02236 L
.26219 .02237 L
.26457 .02238 L
.26707 .02239 L
.27155 .02243 L
.28164 .02253 L
.28585 .02257 L
.29036 .0226 L
.29169 .02261 L
.29295 .02262 L
.29418 .02262 L
.29531 .02263 L
.29638 .02263 L
.29751 .02263 L
Mistroke
.29865 .02263 L
.29991 .02263 L
.3012 .02263 L
.3024 .02263 L
.30371 .02262 L
.30511 .02262 L
.30771 .02261 L
.31006 .02259 L
.31933 .02252 L
.34022 .02233 L
.35948 .02218 L
.37033 .02212 L
.3803 .02208 L
.39005 .02205 L
.39914 .02203 L
.40912 .02201 L
.41981 .02199 L
.43 .02198 L
.44107 .02197 L
.45064 .02196 L
.46119 .02196 L
.48098 .02195 L
.49182 .02195 L
.50199 .02194 L
.51184 .02194 L
.52219 .02194 L
.5407 .02194 L
.56046 .02193 L
.57883 .02193 L
.58936 .02193 L
.5993 .02193 L
.6179 .02193 L
.62763 .02193 L
.63792 .02193 L
.64757 .02193 L
.65638 .02193 L
.66583 .02193 L
.67068 .02193 L
.67597 .02193 L
.68085 .02193 L
.68537 .02193 L
.69002 .02193 L
.69429 .02193 L
.69672 .02193 L
.69939 .02193 L
.70207 .02193 L
.70353 .02193 L
.70489 .02193 L
.70619 .02193 L
.70742 .02193 L
Mistroke
.70852 .02193 L
.70971 .02193 L
.71101 .02193 L
.71167 .02193 L
.71239 .02193 L
.71367 .02193 L
.71487 .02193 L
.71601 .02193 L
.71727 .02193 L
.71955 .02193 L
.72384 .02193 L
.72884 .02193 L
.73349 .02193 L
.754 .02193 L
.77261 .02193 L
.81266 .02193 L
.8512 .02193 L
.89219 .02193 L
.93167 .02193 L
.96963 .02193 L
.97619 .02193 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.02846 .08442 L
.03279 .13897 L
.03754 .18621 L
.04018 .20665 L
.04262 .22189 L
.04518 .2343 L
.0465 .23935 L
.04795 .2439 L
.04913 .24685 L
.0504 .24934 L
.0511 .25041 L
.05174 .25123 L
.053 .25236 L
.0542 .25292 L
.05531 .25301 L
.05654 .25267 L
.05784 .25186 L
.05908 .25069 L
.06026 .24928 L
.06244 .24594 L
.08439 .19456 L
.09401 .17483 L
.09911 .16631 L
.10458 .15868 L
.10965 .1529 L
.11427 .14865 L
.11892 .14529 L
.12333 .1429 L
.12572 .14191 L
.12825 .1411 L
.13042 .14059 L
.13165 .14038 L
.13281 .14024 L
.13407 .14014 L
.13471 .14011 L
.1354 .1401 L
.13663 .14013 L
.13778 .14022 L
.13847 .1403 L
.13913 .14039 L
.14037 .14062 L
.14169 .14095 L
.14313 .14141 L
.14549 .14241 L
.14802 .14388 L
.15041 .14571 L
.1526 .14785 L
.15515 .15104 L
.15794 .15561 L
Mistroke
.16057 .1613 L
.16301 .1681 L
.16576 .17791 L
.16836 .18936 L
.1732 .21509 L
.17837 .24273 L
.18112 .25487 L
.18405 .26508 L
.18541 .26877 L
.1867 .27166 L
.18796 .27391 L
.18912 .27553 L
.19021 .27667 L
.19138 .27748 L
.19255 .27791 L
.19384 .27796 L
.19449 .27783 L
.19518 .2776 L
.19641 .27692 L
.19773 .27586 L
.19917 .27435 L
.20417 .26698 L
.21368 .24841 L
.22265 .23129 L
.2276 .2236 L
.2302 .2203 L
.23295 .21747 L
.23527 .21572 L
.23659 .21501 L
.23782 .21457 L
.23895 .21435 L
.23998 .21434 L
.24117 .21457 L
.2423 .21505 L
.2435 .21587 L
.24419 .2165 L
.24483 .2172 L
.24612 .219 L
.24751 .22156 L
.24874 .22443 L
.25003 .22818 L
.25234 .23697 L
.25504 .25104 L
.25755 .26777 L
.26327 .31416 L
.2683 .35642 L
.27377 .39642 L
.27893 .42607 L
.28139 .43725 L
.2837 .44602 L
Mistroke
.28594 .45301 L
.28799 .45809 L
.29027 .46232 L
.29153 .46403 L
.29272 .46526 L
.29387 .46607 L
.29509 .46657 L
.29624 .46668 L
.29729 .46649 L
.29853 .46592 L
.29922 .46544 L
.29986 .4649 L
.30228 .46201 L
.30354 .45999 L
.30474 .45778 L
.30698 .45287 L
.31202 .43865 L
.32112 .40492 L
.34179 .31886 L
.35145 .28425 L
.36171 .25399 L
.37132 .23155 L
.38014 .21538 L
.38951 .20194 L
.39962 .19084 L
.40853 .18324 L
.41791 .17686 L
.42746 .17162 L
.43766 .16707 L
.45603 .16088 L
.46629 .15827 L
.4774 .15597 L
.487 .15435 L
.49755 .15289 L
.51744 .15083 L
.52832 .14997 L
.53849 .1493 L
.55708 .1483 L
.57733 .14746 L
.59852 .1468 L
.61863 .14633 L
.63836 .14598 L
.65935 .14571 L
.68082 .1455 L
.701 .14536 L
.72114 .14526 L
.73963 .14519 L
.7585 .14514 L
.76921 .14512 L
.77919 .14511 L
Mistroke
.78967 .1451 L
.79959 .14509 L
.81817 .14507 L
.82786 .14507 L
.83813 .14506 L
.85657 .14506 L
.89439 .14505 L
.93467 .14504 L
.97343 .14502 L
.97619 .14502 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19237 L
.04262 .23011 L
.04754 .26042 L
.0522 .28147 L
.05475 .29031 L
.05711 .29696 L
.0597 .30275 L
.06244 .30737 L
.06378 .30911 L
.06505 .31048 L
.0662 .3115 L
.06743 .31238 L
.06813 .31279 L
.06876 .3131 L
.07 .31357 L
.07069 .31375 L
.07144 .31389 L
.07215 .31397 L
.0728 .314 L
.07396 .31395 L
.07505 .3138 L
.07624 .31353 L
.07751 .31312 L
.08012 .31199 L
.0825 .31067 L
.09397 .30234 L
.10458 .29479 L
.10935 .29211 L
.11383 .29015 L
.11608 .2894 L
.11851 .28877 L
.11982 .28852 L
.12053 .2884 L
.1212 .28831 L
.12238 .2882 L
.12366 .28813 L
.12496 .28813 L
.12569 .28816 L
.12637 .2882 L
.12761 .28834 L
.12892 .28855 L
.1301 .28881 L
.1312 .28911 L
.1337 .29001 L
.1364 .29136 L
.13887 .29297 L
.14172 .29534 L
Mistroke
.14443 .29818 L
.14702 .30155 L
.14947 .3054 L
.15404 .31481 L
.1566 .3217 L
.15896 .32926 L
.16427 .35131 L
.17316 .39855 L
.17805 .42195 L
.18267 .43845 L
.18512 .44471 L
.18641 .44734 L
.18778 .44963 L
.18893 .45117 L
.1902 .45249 L
.19135 .45335 L
.19243 .45389 L
.19355 .45418 L
.19472 .45421 L
.19572 .45403 L
.19681 .45362 L
.198 .45295 L
.19926 .452 L
.20153 .44971 L
.20421 .44622 L
.20711 .44168 L
.21237 .43206 L
.22221 .41243 L
.22718 .40306 L
.23251 .39421 L
.23753 .38747 L
.23992 .38495 L
.24212 .38306 L
.2433 .38225 L
.24459 .38152 L
.24589 .38097 L
.2466 .38075 L
.24728 .3806 L
.2485 .38048 L
.24962 .38053 L
.25086 .3808 L
.25216 .38132 L
.25348 .38211 L
.25488 .38328 L
.25742 .38624 L
.25897 .38863 L
.26044 .39131 L
.26318 .39742 L
.28147 .46172 L
.29188 .49618 L
Mistroke
.29696 .50927 L
.30161 .51904 L
.30619 .5268 L
.31118 .53347 L
.31646 .53885 L
.32147 .54276 L
.32675 .54596 L
.33238 .54871 L
.3425 .55292 L
.36249 .56146 L
.3841 .57083 L
.39426 .57438 L
.40499 .5773 L
.41414 .57917 L
.42419 .5807 L
.43441 .58187 L
.44371 .58272 L
.46463 .58427 L
.48535 .58559 L
.5045 .58663 L
.5231 .58743 L
.54285 .58807 L
.56233 .58856 L
.58062 .58893 L
.61933 .58952 L
.63938 .58974 L
.66049 .58992 L
.68024 .59004 L
.69862 .59013 L
.71909 .59021 L
.73768 .59025 L
.74767 .59028 L
.75688 .59029 L
.76699 .5903 L
.77768 .59031 L
.78713 .59032 L
.79243 .59032 L
.79727 .59033 L
.79945 .59033 L
.80177 .59033 L
.8031 .59033 L
.80431 .59033 L
.80554 .59033 L
.80667 .59033 L
.80775 .59033 L
.80888 .59033 L
.81002 .59033 L
.81127 .59033 L
.81235 .59033 L
.8135 .59033 L
Mistroke
.8146 .59033 L
.81559 .59033 L
.81678 .59033 L
.81789 .59033 L
.82042 .59033 L
.82288 .59033 L
.82554 .59033 L
.83034 .59032 L
.83473 .59032 L
.84538 .59032 L
.85551 .59031 L
.8753 .59029 L
.89369 .59027 L
.9328 .5902 L
.97437 .59011 L
.97619 .59011 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.02846 .08441 L
.03279 .1387 L
.03754 .18417 L
.0402 .20237 L
.04262 .21415 L
.04385 .21843 L
.04516 .22173 L
.04627 .22359 L
.0475 .22467 L
.04882 .22478 L
.04957 .2244 L
.05024 .22381 L
.05156 .22201 L
.05281 .2196 L
.0552 .21348 L
.05742 .20644 L
.06244 .18785 L
.07295 .14835 L
.08284 .11847 L
.08832 .10562 L
.09424 .09438 L
.09959 .08627 L
.10458 .08018 L
.10955 .0753 L
.11408 .07172 L
.11912 .06858 L
.12452 .06601 L
.1297 .06421 L
.13263 .06345 L
.13534 .0629 L
.1377 .06253 L
.13906 .06236 L
.1403 .06224 L
.14161 .06214 L
.1423 .0621 L
.14303 .06207 L
.14425 .06204 L
.14494 .06204 L
.14558 .06204 L
.14686 .06208 L
.1475 .06211 L
.14821 .06215 L
.14946 .06226 L
.15063 .06239 L
.15201 .06259 L
.15327 .06282 L
.15611 .06352 L
.15854 .06436 L
.1612 .06558 L
Mistroke
.16371 .0671 L
.16604 .06887 L
.17498 .07877 L
.17967 .08416 L
.18204 .08627 L
.18339 .08722 L
.18463 .08793 L
.18601 .08853 L
.18677 .08877 L
.18749 .08895 L
.18876 .08914 L
.18948 .08918 L
.19015 .08918 L
.19132 .08909 L
.19261 .08886 L
.19326 .0887 L
.19396 .08849 L
.19522 .08805 L
.19776 .08691 L
.20043 .08542 L
.20519 .08234 L
.22381 .07035 L
.23338 .066 L
.23873 .06417 L
.24359 .06285 L
.24813 .06188 L
.25305 .06107 L
.25769 .06051 L
.26197 .06014 L
.26442 .05999 L
.26666 .05987 L
.26907 .05977 L
.27169 .05968 L
.27635 .05957 L
.28077 .05948 L
.28597 .05936 L
.2915 .0592 L
.29621 .05901 L
.30143 .05875 L
.32237 .05743 L
.33155 .05689 L
.3416 .0564 L
.35134 .05604 L
.36042 .05579 L
.37 .0556 L
.38025 .05545 L
.39048 .05534 L
.40157 .05524 L
.42172 .05511 L
.44157 .05502 L
Mistroke
.45158 .05498 L
.4626 .05495 L
.47275 .05493 L
.48203 .05491 L
.49274 .0549 L
.50291 .05489 L
.51251 .05488 L
.52273 .05487 L
.54112 .05487 L
.55142 .05486 L
.55683 .05486 L
.56255 .05486 L
.56756 .05486 L
.57306 .05486 L
.57769 .05486 L
.58273 .05486 L
.58797 .05486 L
.59038 .05486 L
.59294 .05485 L
.59524 .05485 L
.59778 .05485 L
.60009 .05485 L
.60225 .05485 L
.60347 .05485 L
.60417 .05485 L
.60481 .05485 L
.60549 .05485 L
.60621 .05485 L
.60751 .05485 L
.60869 .05485 L
.60998 .05485 L
.6112 .05485 L
.61232 .05485 L
.61483 .05485 L
.61759 .05485 L
.62317 .05485 L
.63334 .05486 L
.64263 .05486 L
.66353 .05486 L
.70331 .05486 L
.7234 .05486 L
.74158 .05486 L
.75174 .05486 L
.7613 .05486 L
.76656 .05486 L
.7714 .05486 L
.7767 .05486 L
.77937 .05486 L
.78089 .05486 L
.78229 .05486 L
Mistroke
.78349 .05486 L
.78482 .05486 L
.78615 .05486 L
.78688 .05486 L
.78756 .05486 L
.78881 .05486 L
.78996 .05486 L
.79128 .05486 L
.79254 .05486 L
.79365 .05486 L
.79485 .05486 L
.79699 .05486 L
.79954 .05486 L
.80186 .05486 L
.80703 .05486 L
.81263 .05486 L
.82279 .05486 L
.83229 .05486 L
.84272 .05486 L
.86378 .05486 L
.90419 .05486 L
.94309 .05486 L
.97619 .05485 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.02499 .03251 L
.02605 .04478 L
.02729 .05312 L
.02846 .05662 L
.02954 .05764 L
.03053 .05754 L
.03163 .0568 L
.03279 .05559 L
.04262 .04272 L
.05205 .03334 L
.05742 .02952 L
.06244 .0267 L
.06788 .02434 L
.07305 .0226 L
.07768 .02137 L
.08274 .02032 L
.08822 .01944 L
.09407 .01873 L
.09958 .01823 L
.10458 .01788 L
.10945 .01762 L
.1146 .0174 L
.119 .01725 L
.12383 .01713 L
.12902 .01703 L
.13459 .01694 L
.13985 .01689 L
.14465 .01685 L
.14693 .01684 L
.14945 .01682 L
.15209 .01681 L
.15329 .01681 L
.15456 .01681 L
.15566 .01681 L
.15686 .0168 L
.15796 .0168 L
.15897 .0168 L
.16018 .0168 L
.16127 .0168 L
.16254 .0168 L
.16373 .01681 L
.16493 .01681 L
.16625 .01681 L
.16891 .01682 L
.17369 .01683 L
.17638 .01684 L
.17786 .01684 L
.17927 .01685 L
.18058 .01685 L
Mistroke
.18131 .01685 L
.182 .01685 L
.18321 .01685 L
.18449 .01685 L
.18574 .01685 L
.18645 .01685 L
.18711 .01685 L
.18844 .01685 L
.18987 .01684 L
.19245 .01684 L
.1948 .01683 L
.20594 .01679 L
.21643 .01676 L
.22613 .01673 L
.2354 .01671 L
.24009 .01671 L
.24525 .0167 L
.24794 .0167 L
.25041 .0167 L
.25307 .0167 L
.25597 .01669 L
.25851 .01669 L
.26087 .01669 L
.26336 .01669 L
.26476 .01669 L
.26602 .01669 L
.26722 .01669 L
.26834 .01669 L
.26957 .01669 L
.27089 .01669 L
.27155 .01669 L
.27227 .01669 L
.27358 .01669 L
.27485 .01669 L
.27603 .01669 L
.2805 .01669 L
.28525 .01669 L
.2877 .01669 L
.28908 .01669 L
.29034 .01669 L
.29146 .01669 L
.29268 .01669 L
.29395 .01669 L
.29513 .01669 L
.29582 .01669 L
.29656 .01669 L
.2979 .01669 L
.29921 .01669 L
.30041 .01669 L
.30315 .01669 L
Mistroke
.30606 .01669 L
.31098 .01669 L
.31548 .01669 L
.32561 .01668 L
.34391 .01667 L
.36291 .01667 L
.37366 .01666 L
.38364 .01666 L
.39422 .01666 L
.40418 .01666 L
.42279 .01666 L
.43256 .01666 L
.44288 .01666 L
.4517 .01666 L
.46136 .01666 L
.47158 .01665 L
.48089 .01665 L
.49163 .01665 L
.50181 .01665 L
.51147 .01665 L
.52173 .01665 L
.53049 .01665 L
.54016 .01665 L
.54508 .01665 L
.55026 .01665 L
.55468 .01665 L
.55952 .01665 L
.56226 .01665 L
.56474 .01665 L
.56612 .01665 L
.56762 .01665 L
.5683 .01665 L
.56903 .01665 L
.57033 .01665 L
.57152 .01665 L
.5728 .01665 L
.57401 .01665 L
.57511 .01665 L
.57641 .01665 L
.57782 .01665 L
.58038 .01665 L
.58294 .01665 L
.58572 .01665 L
.59073 .01665 L
.6001 .01665 L
.6211 .01665 L
.66217 .01665 L
.70173 .01665 L
.73977 .01665 L
.78027 .01665 L
Mistroke
.81925 .01665 L
.86069 .01665 L
.9006 .01665 L
.939 .01665 L
.97619 .01665 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13935 L
.03793 .19216 L
.04262 .22933 L
.04498 .24448 L
.04754 .25841 L
.0522 .27761 L
.05478 .28522 L
.0562 .28855 L
.05753 .29118 L
.05987 .29474 L
.06111 .29611 L
.06244 .29722 L
.06315 .29766 L
.0638 .29798 L
.06454 .29825 L
.06524 .29841 L
.06649 .29851 L
.06719 .29846 L
.06784 .29835 L
.06854 .29816 L
.0692 .29792 L
.0707 .29719 L
.07216 .29623 L
.07373 .29496 L
.07933 .28894 L
.08445 .28221 L
.09491 .26776 L
.10458 .25616 L
.10935 .25156 L
.11383 .24803 L
.11851 .2452 L
.12099 .24407 L
.12238 .24355 L
.12366 .24315 L
.12498 .24281 L
.12618 .24257 L
.12682 .24247 L
.12752 .24238 L
.12825 .24231 L
.12894 .24227 L
.12961 .24226 L
.13034 .24226 L
.13111 .2423 L
.13183 .24236 L
.13312 .24254 L
.13384 .24267 L
.1345 .24283 L
.13693 .24361 L
Mistroke
.13831 .24421 L
.13959 .24488 L
.14193 .24641 L
.14443 .24853 L
.14704 .25137 L
.1498 .2552 L
.15474 .26482 L
.15749 .27224 L
.16005 .28087 L
.16588 .30784 L
.17555 .36685 L
.1782 .38158 L
.18101 .39514 L
.18362 .40557 L
.18606 .41347 L
.18846 .41953 L
.19104 .4243 L
.19244 .42618 L
.19391 .42768 L
.19517 .4286 L
.19588 .42898 L
.19654 .42925 L
.19783 .42955 L
.19905 .42959 L
.20015 .42943 L
.20133 .42908 L
.20263 .42849 L
.204 .42768 L
.20645 .42579 L
.21616 .41546 L
.2204 .41088 L
.22264 .40875 L
.22502 .40683 L
.22622 .40604 L
.22754 .40533 L
.22875 .40484 L
.22988 .40454 L
.23103 .40441 L
.23209 .40446 L
.23326 .40473 L
.23448 .40527 L
.2357 .40608 L
.23699 .40731 L
.23822 .40883 L
.23933 .41054 L
.24206 .41623 L
.24463 .42379 L
.24921 .44266 L
.25342 .46467 L
.26296 .51325 L
Mistroke
.26762 .53167 L
.27264 .54716 L
.27737 .55813 L
.2817 .56548 L
.28432 .56882 L
.28676 .57126 L
.28943 .57324 L
.29093 .57405 L
.29228 .57461 L
.29357 .575 L
.29477 .57524 L
.29607 .57537 L
.29673 .57539 L
.29746 .57537 L
.29867 .57525 L
.29998 .575 L
.30121 .57466 L
.30233 .57427 L
.30462 .5732 L
.30714 .57165 L
.31225 .56741 L
.31699 .56226 L
.32143 .55644 L
.3422 .51836 L
.3809 .42768 L
.40096 .39104 L
.42206 .36284 L
.44182 .34333 L
.46019 .32969 L
.47072 .32352 L
.48066 .31865 L
.49926 .3116 L
.51929 .30623 L
.53774 .30263 L
.55652 .29986 L
.57717 .29753 L
.59663 .29588 L
.61753 .29457 L
.63872 .29361 L
.65882 .29296 L
.67868 .2925 L
.69709 .2922 L
.70769 .29208 L
.71766 .29198 L
.72655 .29191 L
.73629 .29185 L
.74609 .29181 L
.75108 .29179 L
.75642 .29177 L
.76143 .29176 L
Mistroke
.76599 .29175 L
.77024 .29174 L
.77491 .29173 L
.77974 .29173 L
.78238 .29173 L
.78486 .29173 L
.78713 .29173 L
.78929 .29172 L
.79048 .29172 L
.79177 .29172 L
.79295 .29172 L
.79405 .29172 L
.79535 .29172 L
.79609 .29172 L
.79676 .29172 L
.79801 .29172 L
.79932 .29172 L
.8005 .29172 L
.8016 .29172 L
.80411 .29172 L
.80681 .29172 L
.80928 .29173 L
.81483 .29173 L
.82474 .29173 L
.83391 .29174 L
.85466 .29176 L
.87491 .29177 L
.88482 .29178 L
.89392 .29179 L
.90259 .29179 L
.91207 .29179 L
.91701 .29179 L
.92161 .2918 L
.92411 .2918 L
.92647 .2918 L
.92777 .2918 L
.92918 .2918 L
.93047 .2918 L
.93165 .2918 L
.93286 .2918 L
.93401 .2918 L
.93522 .2918 L
.93654 .2918 L
.93769 .2918 L
.93891 .2918 L
.94007 .2918 L
.94111 .2918 L
.94246 .2918 L
.94369 .2918 L
.94648 .2918 L
Mistroke
.94893 .2918 L
.95152 .2918 L
.96156 .29179 L
.97256 .29179 L
.97619 .29179 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13931 L
.03793 .19171 L
.04262 .22769 L
.04498 .24179 L
.04754 .25421 L
.04996 .26331 L
.0522 .2696 L
.05342 .27225 L
.05456 .27424 L
.05582 .27593 L
.05653 .27665 L
.05717 .27718 L
.05846 .27787 L
.0592 .27806 L
.05987 .27811 L
.06112 .2779 L
.06181 .27763 L
.06244 .27729 L
.0637 .27637 L
.06508 .27503 L
.06787 .27139 L
.07287 .2626 L
.08414 .23838 L
.09483 .21679 L
.10458 .20132 L
.10938 .1954 L
.1146 .19022 L
.11953 .18648 L
.12409 .18401 L
.12658 .18305 L
.12771 .1827 L
.12891 .1824 L
.12955 .18227 L
.13025 .18214 L
.13147 .18198 L
.13216 .18192 L
.1329 .18188 L
.1336 .18186 L
.13423 .18187 L
.1349 .1819 L
.13561 .18196 L
.13689 .18212 L
.1376 .18225 L
.13826 .1824 L
.13977 .18283 L
.14109 .18331 L
.14229 .18386 L
.145 .18544 L
Mistroke
.14751 .18744 L
.14979 .18976 L
.15241 .19318 L
.15488 .19729 L
.15927 .2075 L
.16175 .21538 L
.16403 .22429 L
.17476 .28472 L
.18 .31339 L
.18228 .3233 L
.18476 .33191 L
.18595 .3352 L
.1872 .33813 L
.18836 .34034 L
.18945 .34199 L
.19046 .34316 L
.19155 .34406 L
.19276 .34461 L
.19387 .34473 L
.19505 .34449 L
.19615 .34394 L
.19735 .34299 L
.19863 .34162 L
.20125 .33777 L
.20363 .33324 L
.21427 .30545 L
.2243 .27586 L
.23405 .2503 L
.23938 .23869 L
.24436 .22953 L
.25316 .21718 L
.25782 .21239 L
.26282 .20832 L
.27298 .20217 L
.28404 .19659 L
.30415 .18671 L
.31433 .18243 L
.3239 .17919 L
.33388 .17665 L
.33918 .17563 L
.3449 .17475 L
.34985 .17417 L
.35446 .17376 L
.3571 .17357 L
.35951 .17344 L
.36085 .17338 L
.36229 .17332 L
.36365 .17328 L
.36492 .17324 L
.36614 .17322 L
Mistroke
.36745 .17319 L
.3682 .17319 L
.36891 .17318 L
.36955 .17318 L
.37024 .17318 L
.37099 .17318 L
.37166 .17318 L
.37244 .17318 L
.37317 .17319 L
.37448 .17321 L
.37589 .17323 L
.37845 .1733 L
.38116 .17339 L
.38601 .17362 L
.39097 .17392 L
.3955 .17424 L
.40566 .17512 L
.424 .17702 L
.46387 .18146 L
.50222 .18576 L
.54302 .19028 L
.5823 .19428 L
.62007 .19769 L
.6603 .20083 L
.69901 .20335 L
.74017 .20557 L
.77981 .20733 L
.81794 .20876 L
.85852 .21005 L
.89758 .21115 L
.9391 .2122 L
.97619 .21307 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19233 L
.04262 .22994 L
.04754 .25995 L
.0522 .28051 L
.05475 .28896 L
.05711 .29517 L
.0597 .3004 L
.06111 .30261 L
.06244 .30432 L
.06369 .30561 L
.06505 .30669 L
.06628 .30741 L
.06743 .30786 L
.06813 .30804 L
.06879 .30814 L
.07003 .30819 L
.07072 .30813 L
.07136 .30802 L
.07206 .30786 L
.0728 .30762 L
.07395 .30716 L
.07519 .30652 L
.07742 .30506 L
.0825 .30064 L
.09307 .28914 L
.09865 .2831 L
.10458 .27735 L
.10982 .27308 L
.11261 .27118 L
.11561 .26944 L
.11836 .26815 L
.12088 .26722 L
.12328 .26658 L
.1245 .26635 L
.12518 .26625 L
.12582 .26617 L
.12647 .26611 L
.12718 .26607 L
.12846 .26605 L
.12963 .2661 L
.13086 .26623 L
.1315 .26633 L
.13218 .26645 L
.13342 .26675 L
.1349 .26721 L
.13624 .26774 L
.13862 .26895 L
Mistroke
.14122 .27071 L
.14367 .27286 L
.14594 .27534 L
.15103 .28301 L
.1539 .28898 L
.15654 .29584 L
.16139 .31288 L
.1665 .338 L
.17625 .39502 L
.1805 .41563 L
.18512 .43232 L
.18766 .43895 L
.19001 .4436 L
.19225 .44683 L
.19338 .44805 L
.19463 .44911 L
.19595 .44991 L
.19715 .45039 L
.19779 .45055 L
.19848 .45065 L
.1992 .45069 L
.19988 .45066 L
.20113 .45046 L
.20226 .45012 L
.20357 .44958 L
.2048 .44892 L
.20939 .44559 L
.21361 .44179 L
.2186 .43724 L
.22315 .43374 L
.2243 .43305 L
.22555 .4324 L
.22674 .43191 L
.22784 .43158 L
.22899 .43136 L
.23027 .43131 L
.23092 .43137 L
.23161 .43149 L
.23287 .43189 L
.23397 .43246 L
.23517 .43332 L
.23643 .43452 L
.2376 .43593 L
.2397 .43927 L
.24195 .4441 L
.24462 .45171 L
.24751 .46231 L
.25277 .48626 L
.25785 .51055 L
.2626 .53056 L
Mistroke
.26754 .54742 L
.27205 .55947 L
.27706 .56956 L
.27983 .57383 L
.28245 .57713 L
.28498 .57969 L
.28767 .58179 L
.28898 .5826 L
.29021 .58325 L
.29131 .58373 L
.29251 .58417 L
.29385 .58454 L
.29458 .5847 L
.29526 .58482 L
.29648 .58496 L
.29779 .58503 L
.29852 .58502 L
.29932 .58499 L
.30007 .58493 L
.30077 .58484 L
.30209 .58463 L
.30349 .58432 L
.30587 .58362 L
.30838 .58266 L
.31287 .58046 L
.32297 .57389 L
.34126 .55933 L
.37939 .52932 L
.41997 .49954 L
.45903 .47265 L
.48039 .46146 L
.50055 .45354 L
.52058 .44763 L
.53904 .44338 L
.55941 .43968 L
.57846 .43698 L
.59674 .435 L
.61637 .43342 L
.62651 .43279 L
.63756 .43223 L
.64811 .43179 L
.65766 .43146 L
.66715 .4312 L
.67739 .43097 L
.68821 .43079 L
.69347 .43072 L
.69838 .43067 L
.70792 .43058 L
.71297 .43055 L
.71837 .43053 L
Mistroke
.72109 .43052 L
.72405 .43051 L
.72684 .4305 L
.72817 .4305 L
.72941 .4305 L
.73062 .4305 L
.73173 .4305 L
.73296 .4305 L
.73364 .4305 L
.73429 .4305 L
.73557 .4305 L
.73676 .4305 L
.73806 .4305 L
.73879 .4305 L
.73946 .4305 L
.74178 .4305 L
.7431 .4305 L
.74433 .4305 L
.74947 .43051 L
.75392 .43052 L
.75869 .43054 L
.77951 .43063 L
.82086 .43088 L
.86069 .43111 L
.89901 .43128 L
.91878 .43135 L
.93978 .43141 L
.97619 .43148 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13931 L
.03793 .19181 L
.04262 .22828 L
.04498 .24289 L
.04754 .25609 L
.04976 .26543 L
.0522 .27365 L
.05478 .28021 L
.0562 .28295 L
.05753 .285 L
.05876 .28651 L
.0599 .28756 L
.0612 .28841 L
.06244 .28889 L
.0631 .28902 L
.06381 .28907 L
.0651 .28893 L
.06635 .28855 L
.0675 .28799 L
.06875 .28718 L
.07012 .28608 L
.07289 .28329 L
.08259 .26984 L
.09409 .25244 L
.09912 .24569 L
.10458 .2393 L
.10978 .23428 L
.1146 .23059 L
.1192 .22797 L
.12152 .22698 L
.12409 .22616 L
.12541 .22584 L
.12613 .22571 L
.1268 .2256 L
.12798 .22546 L
.12928 .22538 L
.13001 .22538 L
.1307 .22539 L
.13199 .22548 L
.13271 .22557 L
.13337 .22568 L
.13488 .226 L
.13609 .22635 L
.13722 .22675 L
.1398 .22797 L
.14231 .22959 L
.145 .23188 L
.14755 .23466 L
Mistroke
.15026 .23841 L
.15513 .24786 L
.15812 .25594 L
.16093 .26563 L
.16618 .29009 L
.17577 .34717 L
.1784 .36106 L
.18121 .37363 L
.18386 .38304 L
.18512 .38665 L
.18628 .38951 L
.18743 .39189 L
.18869 .39401 L
.18996 .39564 L
.19066 .39633 L
.19131 .39685 L
.19251 .39748 L
.1936 .39773 L
.19481 .39764 L
.19607 .39719 L
.19731 .39639 L
.19863 .3952 L
.20101 .39224 L
.20383 .38756 L
.2064 .38242 L
.22488 .33467 L
.23423 .31162 L
.24411 .29222 L
.24927 .28448 L
.25494 .2778 L
.2601 .27316 L
.26492 .26975 L
.26991 .26687 L
.27535 .26428 L
.28015 .26239 L
.28525 .26076 L
.28982 .25961 L
.29225 .25912 L
.29488 .25868 L
.29727 .25835 L
.29947 .2581 L
.3017 .2579 L
.30379 .25776 L
.30498 .25769 L
.30627 .25763 L
.30852 .25754 L
.3098 .25751 L
.31115 .25748 L
.31231 .25747 L
.31358 .25746 L
Mistroke
.31477 .25745 L
.31585 .25745 L
.3171 .25745 L
.31829 .25746 L
.31938 .25747 L
.3204 .25749 L
.32269 .25753 L
.3254 .25759 L
.32795 .25767 L
.33271 .25787 L
.33538 .25803 L
.33784 .25819 L
.34339 .2587 L
.34809 .2593 L
.35313 .26015 L
.35789 .26119 L
.36222 .26235 L
.37284 .26615 L
.38289 .27101 L
.42124 .29622 L
.46204 .32257 L
.50133 .34522 L
.5391 .36486 L
.57932 .3823 L
.61803 .39585 L
.65919 .40717 L
.69884 .41553 L
.73696 .4217 L
.77755 .42677 L
.81661 .43058 L
.85813 .4338 L
.89813 .43636 L
.93662 .43845 L
.97619 .44033 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.02846 .08325 L
.03068 .10932 L
.03279 .12843 L
.03398 .13671 L
.03527 .14363 L
.03645 .14815 L
.03754 .15097 L
.03871 .15269 L
.04 .15323 L
.04065 .15303 L
.04135 .15252 L
.04262 .15093 L
.04393 .14851 L
.04516 .14574 L
.04793 .13822 L
.05297 .12268 L
.06244 .09539 L
.06795 .08251 L
.07314 .07249 L
.08284 .05847 L
.08828 .05277 L
.09328 .0486 L
.09878 .04498 L
.10458 .04203 L
.10954 .04007 L
.11406 .03865 L
.11928 .03737 L
.12422 .03644 L
.12878 .03579 L
.133 .03534 L
.13539 .03514 L
.13763 .03499 L
.13997 .03487 L
.14121 .03482 L
.14255 .03477 L
.14381 .03474 L
.14495 .03472 L
.14627 .03471 L
.14751 .03471 L
.14866 .03472 L
.14972 .03473 L
.15089 .03476 L
.15212 .0348 L
.15336 .03485 L
.1547 .03492 L
.15711 .03509 L
.15997 .03538 L
.16259 .03574 L
.16528 .03621 L
Mistroke
.16777 .03675 L
.17342 .03825 L
.17602 .03897 L
.17877 .03966 L
.18132 .04018 L
.18369 .04054 L
.18486 .04067 L
.18612 .04078 L
.18684 .04082 L
.18752 .04085 L
.18878 .04089 L
.18945 .0409 L
.19015 .0409 L
.19142 .04087 L
.19212 .04085 L
.19278 .04082 L
.19429 .04073 L
.19679 .04052 L
.19909 .04027 L
.20425 .03959 L
.22287 .037 L
.22763 .03648 L
.2327 .03602 L
.23749 .03568 L
.24184 .03546 L
.24313 .0354 L
.2445 .03536 L
.24568 .03532 L
.24695 .03529 L
.24767 .03528 L
.24832 .03527 L
.2496 .03526 L
.25031 .03526 L
.25109 .03526 L
.25182 .03526 L
.2525 .03527 L
.25369 .03529 L
.25481 .03531 L
.25604 .03535 L
.25737 .03541 L
.26007 .03556 L
.26255 .03575 L
.27246 .03701 L
.27791 .03793 L
.28305 .03877 L
.28785 .03942 L
.29055 .03969 L
.29184 .0398 L
.29305 .03988 L
.29415 .03995 L
Mistroke
.29515 .03999 L
.29627 .04003 L
.29746 .04006 L
.29861 .04008 L
.29986 .04008 L
.30104 .04007 L
.30214 .04005 L
.30339 .04002 L
.30453 .03997 L
.30712 .03984 L
.31181 .03951 L
.32058 .03867 L
.34022 .03666 L
.34931 .0359 L
.35906 .03523 L
.36975 .03466 L
.37973 .03427 L
.38991 .03396 L
.40098 .03372 L
.41144 .03354 L
.42111 .03341 L
.43979 .03323 L
.45042 .03315 L
.46039 .03309 L
.47023 .03304 L
.48059 .03299 L
.4991 .03293 L
.50865 .03291 L
.51886 .03289 L
.53723 .03286 L
.55859 .03284 L
.56838 .03283 L
.57875 .03283 L
.58829 .03282 L
.59877 .03282 L
.61723 .03281 L
.6274 .03281 L
.63669 .0328 L
.64183 .0328 L
.64742 .0328 L
.65759 .0328 L
.66293 .0328 L
.66795 .0328 L
.67245 .0328 L
.67499 .0328 L
.67732 .0328 L
.67854 .0328 L
.67984 .0328 L
.68097 .0328 L
.68219 .0328 L
Mistroke
.68294 .0328 L
.68363 .0328 L
.68429 .0328 L
.68499 .0328 L
.6862 .0328 L
.68689 .0328 L
.68754 .0328 L
.6882 .0328 L
.68892 .0328 L
.69025 .0328 L
.69153 .0328 L
.69273 .0328 L
.69543 .0328 L
.69831 .0328 L
.70366 .0328 L
.70859 .0328 L
.71971 .0328 L
.73988 .0328 L
.77935 .03281 L
.81731 .03281 L
.85773 .03282 L
.89662 .03282 L
.93797 .03282 L
.97619 .03283 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13933 L
.03793 .19186 L
.04262 .22822 L
.04498 .24265 L
.04754 .25552 L
.04976 .26444 L
.0522 .27204 L
.05344 .27509 L
.05478 .27777 L
.0562 .27998 L
.05683 .28077 L
.05753 .28149 L
.05884 .2825 L
.06009 .28304 L
.06131 .2832 L
.06244 .28305 L
.06311 .28283 L
.06382 .28251 L
.06509 .28169 L
.06645 .28051 L
.06795 .2789 L
.07314 .27128 L
.08284 .25276 L
.09421 .23111 L
.09918 .22297 L
.10458 .21534 L
.10978 .20924 L
.1146 .20472 L
.1192 .20138 L
.12175 .19995 L
.12409 .19889 L
.12656 .19803 L
.12785 .1977 L
.12851 .19756 L
.12922 .19743 L
.13041 .19727 L
.13152 .19718 L
.13283 .19715 L
.13403 .19719 L
.13472 .19726 L
.13544 .19735 L
.13674 .19758 L
.13814 .19794 L
.13968 .19847 L
.14243 .1998 L
.145 .20155 L
.14759 .20387 L
.14998 .20664 L
Mistroke
.15261 .21049 L
.15541 .21578 L
.15808 .22228 L
.1606 .23001 L
.16529 .24966 L
.17413 .30198 L
.17882 .32874 L
.18139 .34083 L
.18383 .35013 L
.1851 .35413 L
.18648 .35782 L
.18763 .36037 L
.18889 .36265 L
.19009 .3643 L
.19135 .36556 L
.19252 .3663 L
.19362 .36662 L
.19488 .36658 L
.19552 .36641 L
.19621 .3661 L
.19745 .36527 L
.19859 .3642 L
.20118 .36081 L
.20395 .35591 L
.21364 .33194 L
.22243 .30646 L
.23177 .28078 L
.24165 .25848 L
.24682 .24928 L
.25249 .2411 L
.26247 .23086 L
.2677 .22694 L
.27265 .22369 L
.28195 .21803 L
.30286 .20608 L
.31249 .20166 L
.32274 .19804 L
.33149 .19578 L
.33647 .1948 L
.34115 .19406 L
.34584 .19349 L
.35097 .19303 L
.35356 .19287 L
.35498 .19279 L
.35633 .19273 L
.35758 .19269 L
.35894 .19265 L
.36017 .19263 L
.36131 .19261 L
.36238 .1926 L
Mistroke
.36352 .1926 L
.3646 .19261 L
.36559 .19262 L
.36674 .19264 L
.368 .19266 L
.37029 .19274 L
.37268 .19284 L
.37523 .19298 L
.37981 .19331 L
.38517 .19381 L
.39011 .19438 L
.40124 .19594 L
.42141 .19946 L
.46092 .20688 L
.49891 .21385 L
.53936 .22109 L
.57828 .22741 L
.61966 .23317 L
.65953 .23775 L
.69788 .24124 L
.73868 .2441 L
.77797 .24617 L
.81574 .24767 L
.85596 .24888 L
.89467 .24977 L
.93583 .25053 L
.97547 .25114 L
.97619 .25115 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.02499 .02095 L
.02605 .02153 L
.02729 .02156 L
.02846 .02142 L
.02954 .02122 L
.03053 .02102 L
.03279 .02054 L
.03746 .01957 L
.04262 .01866 L
.05224 .0174 L
.05751 .01692 L
.06244 .01656 L
.06788 .01625 L
.07305 .01603 L
.07768 .01587 L
.08274 .01573 L
.08822 .01562 L
.09407 .01553 L
.09958 .01546 L
.10458 .01541 L
.10945 .01538 L
.1146 .01535 L
.119 .01533 L
.12383 .01531 L
.12902 .0153 L
.13459 .01529 L
.13985 .01528 L
.14465 .01528 L
.14693 .01528 L
.14945 .01527 L
.15209 .01527 L
.15329 .01527 L
.15456 .01527 L
.15566 .01527 L
.15686 .01527 L
.15796 .01527 L
.15897 .01527 L
.16018 .01527 L
.16127 .01527 L
.16254 .01527 L
.16373 .01527 L
.16493 .01527 L
.16625 .01527 L
.16891 .01527 L
.17369 .01528 L
.17638 .01528 L
.17786 .01528 L
.17927 .01528 L
.18058 .01528 L
Mistroke
.18131 .01528 L
.182 .01528 L
.18321 .01528 L
.18449 .01528 L
.18574 .01528 L
.18645 .01528 L
.18711 .01528 L
.18844 .01528 L
.18987 .01528 L
.19245 .01528 L
.1948 .01528 L
.20594 .01527 L
.21643 .01527 L
.22613 .01526 L
.2354 .01526 L
.24009 .01526 L
.24525 .01526 L
.25041 .01526 L
.25331 .01526 L
.25597 .01526 L
.26087 .01526 L
.26333 .01526 L
.26602 .01526 L
.26857 .01526 L
.27133 .01526 L
.27376 .01526 L
.27632 .01526 L
.27864 .01526 L
.28119 .01526 L
.28567 .01526 L
.28836 .01526 L
.2909 .01526 L
.29383 .01526 L
.29651 .01526 L
.29903 .01526 L
.30136 .01526 L
.30664 .01526 L
.31625 .01526 L
.32528 .01525 L
.34587 .01525 L
.35569 .01525 L
.36603 .01525 L
.37572 .01525 L
.38453 .01525 L
.39405 .01525 L
.40424 .01525 L
.4226 .01525 L
.43257 .01525 L
.44176 .01525 L
.45186 .01525 L
Mistroke
.46255 .01525 L
.47197 .01525 L
.4821 .01525 L
.49166 .01525 L
.50041 .01525 L
.50518 .01525 L
.51026 .01525 L
.51466 .01525 L
.51941 .01525 L
.52501 .01525 L
.52757 .01525 L
.53028 .01525 L
.53273 .01525 L
.53541 .01525 L
.53659 .01525 L
.53786 .01525 L
.53903 .01525 L
.54014 .01525 L
.54136 .01525 L
.542 .01525 L
.5427 .01525 L
.54339 .01525 L
.54412 .01525 L
.54543 .01525 L
.54664 .01525 L
.54776 .01525 L
.549 .01525 L
.55032 .01525 L
.5533 .01525 L
.55612 .01525 L
.56139 .01525 L
.56642 .01525 L
.57105 .01525 L
.58152 .01525 L
.62094 .01525 L
.65885 .01525 L
.69921 .01525 L
.73805 .01525 L
.77935 .01525 L
.81913 .01525 L
.85739 .01525 L
.89811 .01525 L
.93731 .01525 L
.97619 .01525 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19236 L
.04262 .23006 L
.04754 .26026 L
.0522 .2811 L
.05475 .28977 L
.05711 .29623 L
.0597 .30179 L
.06111 .30419 L
.06244 .30611 L
.06369 .3076 L
.06505 .30892 L
.06628 .30986 L
.06743 .31053 L
.06813 .31084 L
.06879 .31108 L
.07003 .31138 L
.07072 .31147 L
.07136 .3115 L
.07206 .31149 L
.0728 .31142 L
.07395 .31121 L
.07519 .31086 L
.07636 .31042 L
.07742 .30993 L
.0825 .30674 L
.09397 .297 L
.10458 .28842 L
.10935 .28537 L
.11383 .2831 L
.11608 .28221 L
.11851 .28145 L
.11982 .28113 L
.1212 .28085 L
.12238 .28068 L
.12366 .28055 L
.12434 .28051 L
.12507 .28048 L
.12575 .28048 L
.12639 .2805 L
.12759 .28057 L
.12886 .28073 L
.12952 .28083 L
.13023 .28097 L
.13151 .28128 L
.13303 .28176 L
.13442 .2823 L
.13688 .28352 L
Mistroke
.13955 .28527 L
.14208 .28739 L
.14443 .28982 L
.14952 .29697 L
.15239 .30245 L
.15502 .30867 L
.15987 .32389 L
.16499 .3463 L
.17473 .39929 L
.17899 .41911 L
.18123 .42761 L
.18361 .43502 L
.18615 .44112 L
.18736 .44338 L
.18849 .44515 L
.18964 .44659 L
.19069 .44762 L
.19185 .44845 L
.19311 .449 L
.19434 .44921 L
.19548 .44913 L
.19673 .44875 L
.19743 .44842 L
.19807 .44804 L
.19936 .44708 L
.20075 .44576 L
.20328 .4427 L
.20793 .43531 L
.21284 .42577 L
.22163 .40669 L
.23109 .3867 L
.2363 .37702 L
.24124 .36914 L
.24583 .36315 L
.24825 .36055 L
.25083 .35824 L
.25298 .35666 L
.25537 .35528 L
.25641 .35481 L
.25753 .35438 L
.25858 .35405 L
.25957 .35382 L
.26082 .35361 L
.26196 .35352 L
.26319 .35352 L
.26388 .35357 L
.26452 .35365 L
.26558 .35384 L
.26676 .35414 L
.26798 .35457 L
Mistroke
.26913 .35507 L
.27176 .35662 L
.27417 .3585 L
.27959 .3643 L
.2904 .38072 L
.30068 .39806 L
.31027 .41216 L
.3205 .4236 L
.33015 .43152 L
.33889 .43739 L
.37898 .47097 L
.39737 .4906 L
.41755 .50922 L
.4375 .5231 L
.45857 .53408 L
.47973 .54288 L
.49902 .54957 L
.53794 .55986 L
.55704 .56359 L
.57781 .56694 L
.59721 .56953 L
.61861 .57191 L
.6579 .57525 L
.67726 .57651 L
.69812 .57765 L
.73928 .57938 L
.77892 .58057 L
.81705 .5814 L
.85763 .58206 L
.8967 .58253 L
.93822 .5829 L
.97619 .58316 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.02605 .04926 L
.02729 .06572 L
.02846 .07857 L
.02954 .08772 L
.03072 .0945 L
.0318 .09812 L
.03279 .09971 L
.03396 .09996 L
.03506 .09904 L
.03626 .09717 L
.03756 .09453 L
.04262 .08192 L
.0521 .06028 L
.05746 .05097 L
.06244 .04408 L
.0679 .03812 L
.07373 .03325 L
.07935 .02967 L
.08445 .02717 L
.08943 .02527 L
.09481 .02367 L
.0999 .0225 L
.10458 .02166 L
.10928 .021 L
.11432 .02044 L
.11907 .02003 L
.1234 .01973 L
.12849 .01946 L
.13402 .01924 L
.13924 .01909 L
.14176 .01903 L
.14407 .01899 L
.1487 .01892 L
.15113 .01889 L
.15237 .01888 L
.15369 .01887 L
.15487 .01887 L
.15593 .01886 L
.157 .01886 L
.15801 .01886 L
.15919 .01886 L
.16028 .01886 L
.16147 .01886 L
.16273 .01886 L
.16401 .01887 L
.16518 .01887 L
.1678 .01889 L
.17254 .01893 L
.17524 .01896 L
Mistroke
.17777 .01898 L
.17917 .01899 L
.18069 .019 L
.18136 .019 L
.18207 .019 L
.18333 .019 L
.18451 .01901 L
.18577 .01901 L
.18696 .019 L
.18804 .019 L
.18931 .019 L
.1907 .01899 L
.1932 .01897 L
.19796 .01893 L
.20236 .01889 L
.21306 .01878 L
.22309 .01869 L
.2321 .01863 L
.23716 .01861 L
.2418 .01859 L
.2466 .01858 L
.24932 .01857 L
.25185 .01857 L
.25453 .01856 L
.25696 .01856 L
.25831 .01856 L
.25977 .01856 L
.26044 .01856 L
.26114 .01856 L
.26241 .01856 L
.26363 .01856 L
.26432 .01856 L
.26495 .01856 L
.26612 .01856 L
.26736 .01856 L
.26847 .01856 L
.26951 .01856 L
.27188 .01856 L
.27717 .01856 L
.28203 .01856 L
.28425 .01856 L
.28632 .01857 L
.28736 .01857 L
.28848 .01857 L
.28972 .01857 L
.29084 .01857 L
.29206 .01857 L
.29319 .01857 L
.29442 .01857 L
.29573 .01857 L
Mistroke
.29687 .01857 L
.29793 .01856 L
.30035 .01856 L
.30293 .01856 L
.30532 .01856 L
.31074 .01855 L
.32062 .01854 L
.33914 .01852 L
.34972 .01851 L
.35968 .0185 L
.36862 .01849 L
.37829 .01849 L
.39825 .01848 L
.41932 .01848 L
.43919 .01847 L
.45731 .01847 L
.47683 .01847 L
.49775 .01846 L
.51685 .01846 L
.53762 .01846 L
.55702 .01846 L
.57842 .01846 L
.61771 .01846 L
.65793 .01846 L
.69664 .01846 L
.7378 .01846 L
.77744 .01846 L
.81557 .01846 L
.85615 .01846 L
.89522 .01846 L
.93673 .01846 L
.97619 .01846 L
Mfstroke
0 .751 1 r
.02381 .01472 m
.02499 .03172 L
.02605 .04073 L
.02729 .04436 L
.02846 .04482 L
.02954 .04428 L
.03053 .04343 L
.03279 .04108 L
.03746 .03614 L
.04262 .03153 L
.04725 .0282 L
.05224 .02535 L
.05751 .02302 L
.06244 .02132 L
.06784 .01989 L
.07373 .01871 L
.07929 .01789 L
.08445 .0173 L
.08956 .01686 L
.09419 .01654 L
.09954 .01626 L
.10458 .01606 L
.10923 .01592 L
.11434 .01579 L
.11968 .01569 L
.12466 .01562 L
.12932 .01557 L
.13357 .01553 L
.13848 .0155 L
.14313 .01548 L
.14772 .01546 L
.15278 .01544 L
.15533 .01544 L
.15807 .01543 L
.16045 .01543 L
.16304 .01543 L
.16546 .01542 L
.16772 .01542 L
.1701 .01542 L
.17265 .01542 L
.18146 .01542 L
.18679 .01541 L
.1917 .01541 L
.20281 .0154 L
.21322 .01539 L
.21831 .01539 L
.22296 .01539 L
.22729 .01539 L
.232 .01539 L
.23699 .01539 L
Mistroke
.24172 .01538 L
.24444 .01538 L
.24691 .01538 L
.24828 .01538 L
.24975 .01538 L
.25103 .01538 L
.25243 .01538 L
.25373 .01538 L
.25495 .01538 L
.25623 .01538 L
.25695 .01538 L
.25761 .01538 L
.25878 .01538 L
.26005 .01538 L
.26125 .01538 L
.26236 .01538 L
.26354 .01538 L
.26479 .01538 L
.26701 .01538 L
.27201 .01538 L
.28106 .01538 L
.28583 .01538 L
.2885 .01538 L
.29092 .01538 L
.29229 .01538 L
.29307 .01538 L
.29379 .01538 L
.2951 .01538 L
.29577 .01538 L
.2965 .01538 L
.29779 .01538 L
.29851 .01538 L
.29918 .01538 L
.30046 .01538 L
.30168 .01538 L
.30404 .01538 L
.30626 .01538 L
.31132 .01538 L
.32156 .01538 L
.33998 .01538 L
.34979 .01538 L
.36013 .01538 L
.36896 .01538 L
.37863 .01538 L
.39822 .01538 L
.41916 .01538 L
.43905 .01538 L
.46063 .01538 L
.4814 .01538 L
.50058 .01538 L
Mistroke
.53995 .01538 L
.5778 .01538 L
.61811 .01538 L
.6569 .01538 L
.69815 .01538 L
.73787 .01538 L
.77609 .01538 L
.81675 .01538 L
.8559 .01538 L
.8975 .01538 L
.93759 .01538 L
.97616 .01538 L
.97619 .01538 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.02846 .08415 L
.03279 .13505 L
.03406 .14656 L
.03527 .15576 L
.03637 .16265 L
.03754 .16842 L
.0388 .17297 L
.03997 .17564 L
.04123 .17703 L
.04195 .17719 L
.04262 .17698 L
.04384 .17576 L
.04453 .17467 L
.04517 .17341 L
.04761 .16708 L
.05217 .15125 L
.06244 .11381 L
.06795 .09709 L
.07314 .08399 L
.08284 .06565 L
.08828 .05821 L
.09328 .05277 L
.09878 .04805 L
.10458 .04421 L
.10954 .04167 L
.11406 .03982 L
.11928 .03815 L
.12422 .03694 L
.12878 .03608 L
.133 .03547 L
.13763 .03497 L
.13997 .03479 L
.14255 .03463 L
.1449 .03453 L
.14623 .03449 L
.14747 .03446 L
.14878 .03444 L
.14997 .03444 L
.15063 .03444 L
.15135 .03445 L
.15264 .03447 L
.15376 .0345 L
.15498 .03454 L
.15626 .0346 L
.15746 .03468 L
.1596 .03484 L
.1619 .03507 L
.16457 .03543 L
.16749 .03592 L
Mistroke
.1728 .03704 L
.17758 .03808 L
.1801 .03852 L
.18147 .03872 L
.18275 .03887 L
.18408 .03899 L
.18478 .03904 L
.18553 .03908 L
.18622 .03911 L
.18687 .03913 L
.18808 .03915 L
.18933 .03914 L
.19049 .03911 L
.19176 .03905 L
.1931 .03897 L
.1954 .03878 L
.19755 .03855 L
.20247 .03793 L
.2127 .03648 L
.22345 .03513 L
.23312 .03423 L
.23859 .03385 L
.24367 .03358 L
.24837 .03338 L
.25263 .03325 L
.255 .03319 L
.25755 .03314 L
.25998 .0331 L
.26219 .03308 L
.26456 .03305 L
.26577 .03305 L
.2671 .03304 L
.26832 .03303 L
.26945 .03303 L
.27052 .03302 L
.27168 .03302 L
.27292 .03302 L
.27408 .03302 L
.27547 .03301 L
.27673 .03301 L
.27952 .03301 L
.28087 .03301 L
.28211 .03301 L
.28447 .033 L
.28577 .033 L
.287 .033 L
.28957 .03298 L
.29236 .03297 L
.29509 .03295 L
.29798 .03292 L
Mistroke
.30316 .03286 L
.32294 .03255 L
.34102 .03229 L
.35098 .03219 L
.36044 .03212 L
.37043 .03206 L
.38133 .03202 L
.39165 .03199 L
.40101 .03196 L
.42199 .03192 L
.44125 .0319 L
.4521 .03188 L
.46208 .03187 L
.48092 .03186 L
.49161 .03186 L
.50158 .03185 L
.52195 .03185 L
.54051 .03184 L
.55961 .03184 L
.58038 .03184 L
.60017 .03184 L
.62118 .03183 L
.64067 .03183 L
.65895 .03183 L
.69766 .03183 L
.73882 .03183 L
.77846 .03183 L
.81659 .03183 L
.85717 .03183 L
.89624 .03183 L
.93775 .03182 L
.97619 .03182 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.02846 .08405 L
.03068 .11194 L
.03279 .13376 L
.03398 .14384 L
.03527 .15278 L
.03645 .15904 L
.03754 .16328 L
.03871 .16628 L
.04 .16785 L
.04065 .16803 L
.04135 .1678 L
.04262 .16643 L
.04393 .16393 L
.04516 .16084 L
.04793 .15199 L
.05297 .13314 L
.06244 .10003 L
.06795 .08467 L
.07314 .07287 L
.08284 .05663 L
.08828 .05014 L
.09328 .04542 L
.09878 .04137 L
.10458 .03808 L
.10954 .03591 L
.11406 .03434 L
.11928 .03293 L
.12422 .03189 L
.12878 .03116 L
.133 .03063 L
.13763 .0302 L
.13997 .03003 L
.14255 .02988 L
.1449 .02977 L
.14625 .02972 L
.14747 .02969 L
.14876 .02966 L
.14948 .02965 L
.15015 .02964 L
.15135 .02963 L
.15264 .02963 L
.15376 .02964 L
.15498 .02965 L
.15626 .02968 L
.15746 .02971 L
.1596 .0298 L
.1619 .02992 L
.16457 .03012 L
.16749 .03039 L
Mistroke
.1728 .03101 L
.17758 .03156 L
.18028 .03181 L
.18156 .0319 L
.18275 .03197 L
.18399 .03202 L
.18465 .03204 L
.18535 .03206 L
.18608 .03207 L
.18678 .03208 L
.18808 .03208 L
.18933 .03206 L
.19049 .03203 L
.19176 .03199 L
.1931 .03193 L
.19755 .03166 L
.20247 .03127 L
.21342 .03033 L
.22345 .02959 L
.2329 .02908 L
.23765 .02888 L
.24284 .02872 L
.24807 .0286 L
.251 .02854 L
.25366 .02851 L
.25614 .02848 L
.25883 .02846 L
.26006 .02845 L
.26137 .02844 L
.26258 .02843 L
.26371 .02843 L
.26492 .02843 L
.26555 .02842 L
.26625 .02842 L
.26741 .02842 L
.26866 .02842 L
.26977 .02842 L
.27098 .02842 L
.27212 .02842 L
.27317 .02842 L
.27553 .02843 L
.27811 .02843 L
.28084 .02844 L
.28203 .02844 L
.28332 .02844 L
.28455 .02844 L
.28568 .02844 L
.28676 .02844 L
.28791 .02844 L
.28911 .02844 L
Mistroke
.29024 .02844 L
.29148 .02844 L
.29281 .02844 L
.29394 .02844 L
.29518 .02843 L
.29743 .02842 L
.30165 .0284 L
.30697 .02836 L
.31198 .02832 L
.32133 .02822 L
.33154 .02812 L
.34231 .02803 L
.35189 .02796 L
.36241 .02791 L
.37196 .02788 L
.38088 .02785 L
.40125 .02781 L
.41981 .02778 L
.44052 .02776 L
.45968 .02774 L
.47828 .02773 L
.49803 .02772 L
.51751 .02771 L
.5358 .0277 L
.5745 .02769 L
.59456 .02769 L
.61566 .02769 L
.65379 .02768 L
.69437 .02768 L
.73344 .02768 L
.77496 .02768 L
.81496 .02767 L
.85344 .02767 L
.89438 .02767 L
.93381 .02767 L
.97171 .02767 L
.97619 .02767 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13921 L
.03754 .18771 L
.04262 .22669 L
.04518 .24164 L
.04795 .25459 L
.05058 .26395 L
.053 .27034 L
.05518 .27442 L
.05642 .2761 L
.05758 .27727 L
.05881 .27813 L
.05993 .27859 L
.06122 .27878 L
.06244 .27863 L
.0631 .27843 L
.06381 .27813 L
.0651 .27736 L
.06635 .27637 L
.0675 .27526 L
.07289 .26817 L
.08259 .2512 L
.09396 .23111 L
.10458 .21602 L
.10925 .21086 L
.11366 .20684 L
.11611 .20498 L
.11876 .20325 L
.12116 .20195 L
.1234 .20096 L
.12588 .20012 L
.12719 .19978 L
.12787 .19964 L
.12861 .19951 L
.12929 .19941 L
.13001 .19933 L
.13078 .19927 L
.13149 .19923 L
.13221 .19923 L
.13288 .19924 L
.13414 .19933 L
.13534 .1995 L
.13662 .19975 L
.1377 .20004 L
.1389 .20044 L
.14157 .20166 L
.14407 .20325 L
.14665 .20543 L
.14905 .20803 L
Mistroke
.15168 .21166 L
.15447 .21664 L
.15715 .22278 L
.15966 .2301 L
.16435 .24896 L
.169 .27485 L
.17327 .30242 L
.1783 .33325 L
.18289 .35533 L
.18531 .36412 L
.18761 .3706 L
.19002 .37561 L
.19139 .37767 L
.19265 .37911 L
.19374 .38001 L
.19475 .38059 L
.19587 .38096 L
.19707 .38106 L
.19826 .38087 L
.19951 .3804 L
.20058 .3798 L
.20175 .37894 L
.20447 .37628 L
.20694 .37321 L
.21247 .36493 L
.22243 .34945 L
.2273 .34361 L
.22975 .34153 L
.23042 .34109 L
.23114 .34068 L
.23244 .34014 L
.23362 .33988 L
.23491 .33988 L
.23613 .34019 L
.23726 .34076 L
.23827 .34154 L
.23939 .34271 L
.24056 .34433 L
.24165 .34624 L
.2442 .35237 L
.24547 .35645 L
.24687 .36176 L
.25166 .38672 L
.26247 .46011 L
.26774 .49053 L
.27272 .51337 L
.2772 .52925 L
.28205 .54208 L
.28457 .54713 L
.28734 .55153 L
Mistroke
.28873 .55332 L
.29023 .55494 L
.29153 .5561 L
.29294 .55712 L
.29434 .55789 L
.29564 .55839 L
.29687 .55869 L
.29819 .55883 L
.29949 .55877 L
.30071 .55857 L
.30181 .55825 L
.30299 .55778 L
.30537 .55643 L
.30792 .55442 L
.31251 .54943 L
.31797 .54141 L
.32295 .53236 L
.34402 .48049 L
.36473 .42188 L
.38388 .3755 L
.40248 .34174 L
.42223 .3154 L
.44172 .29603 L
.46 .28243 L
.46984 .27668 L
.4802 .27165 L
.49871 .26481 L
.50826 .26213 L
.51847 .25975 L
.53684 .25641 L
.5582 .25359 L
.57836 .25167 L
.58809 .25094 L
.59838 .2503 L
.61684 .24943 L
.62629 .2491 L
.63643 .24882 L
.64601 .24861 L
.65475 .24846 L
.65954 .2484 L
.66463 .24834 L
.66903 .2483 L
.67379 .24826 L
.67671 .24825 L
.6794 .24823 L
.68192 .24822 L
.68468 .24821 L
.68716 .2482 L
.68947 .2482 L
.69075 .2482 L
Mistroke
.69192 .2482 L
.69256 .2482 L
.69326 .2482 L
.69453 .24819 L
.69575 .24819 L
.69688 .24819 L
.69817 .2482 L
.6994 .2482 L
.70053 .2482 L
.70158 .2482 L
.70396 .2482 L
.7066 .24821 L
.70899 .24822 L
.71436 .24824 L
.72518 .24829 L
.73538 .24836 L
.77392 .24872 L
.81491 .24917 L
.85439 .2496 L
.89235 .24998 L
.93276 .25032 L
.97166 .2506 L
.97619 .25063 L
Mfstroke
0 .656 1 r
.02381 .01472 m
.02499 .03291 L
.02605 .04707 L
.02729 .05935 L
.02846 .06683 L
.02954 .07081 L
.03053 .07265 L
.03163 .07327 L
.03279 .07289 L
.03395 .07181 L
.0352 .07019 L
.03746 .0666 L
.04262 .0578 L
.04793 .04962 L
.05297 .04314 L
.06244 .03415 L
.0675 .03071 L
.07289 .02784 L
.07798 .02572 L
.08259 .0242 L
.08803 .0228 L
.09391 .02164 L
.09947 .02082 L
.10458 .02024 L
.10928 .01982 L
.11432 .01947 L
.11907 .01921 L
.1234 .01902 L
.12849 .01885 L
.13402 .01872 L
.13655 .01867 L
.13924 .01862 L
.14407 .01856 L
.14645 .01854 L
.14896 .01853 L
.1511 .01852 L
.15231 .01851 L
.15344 .01851 L
.15475 .01851 L
.156 .01851 L
.15711 .01851 L
.15832 .01851 L
.15964 .01851 L
.1603 .01852 L
.16104 .01852 L
.16354 .01853 L
.16592 .01855 L
.16809 .01857 L
.17298 .01863 L
.17537 .01866 L
Mistroke
.17762 .01868 L
.17981 .0187 L
.18182 .01871 L
.18294 .01872 L
.18412 .01872 L
.1853 .01872 L
.1866 .01872 L
.18787 .01872 L
.18858 .01872 L
.18923 .01872 L
.1905 .01872 L
.19169 .01871 L
.19397 .0187 L
.19608 .01869 L
.20084 .01865 L
.21154 .01855 L
.22158 .01846 L
.23058 .0184 L
.23565 .01838 L
.24028 .01836 L
.24508 .01835 L
.2478 .01834 L
.25033 .01834 L
.25171 .01834 L
.25301 .01834 L
.25418 .01834 L
.25544 .01833 L
.2561 .01833 L
.25682 .01833 L
.25758 .01833 L
.25828 .01833 L
.25954 .01833 L
.26025 .01833 L
.2609 .01833 L
.26207 .01834 L
.26318 .01834 L
.26569 .01834 L
.26815 .01834 L
.27079 .01835 L
.27996 .01837 L
.28523 .01838 L
.2881 .01839 L
.29078 .01839 L
.29307 .0184 L
.29425 .0184 L
.29552 .0184 L
.29625 .0184 L
.29692 .0184 L
.29824 .0184 L
.29944 .0184 L
Mistroke
.30071 .0184 L
.30192 .0184 L
.30323 .0184 L
.30448 .0184 L
.30563 .0184 L
.30781 .0184 L
.31013 .01839 L
.31544 .01838 L
.32026 .01837 L
.33857 .01833 L
.35783 .01828 L
.36868 .01827 L
.37865 .01826 L
.3884 .01825 L
.39749 .01824 L
.40747 .01823 L
.41816 .01823 L
.42834 .01823 L
.43941 .01822 L
.44898 .01822 L
.45954 .01822 L
.47933 .01822 L
.49017 .01821 L
.50034 .01821 L
.51018 .01821 L
.52054 .01821 L
.53905 .01821 L
.5486 .01821 L
.55881 .01821 L
.56837 .01821 L
.57718 .01821 L
.58743 .01821 L
.59272 .01821 L
.59854 .01821 L
.60833 .01821 L
.61369 .01821 L
.6187 .01821 L
.62111 .01821 L
.62368 .01821 L
.6265 .01821 L
.62911 .01821 L
.6304 .01821 L
.63107 .01821 L
.63179 .01821 L
.6331 .01821 L
.6343 .01821 L
.63546 .01821 L
.63654 .01821 L
.63773 .01821 L
.639 .01821 L
Mistroke
.64024 .01821 L
.64139 .01821 L
.64399 .01821 L
.64628 .01821 L
.64871 .01821 L
.65754 .01821 L
.66694 .01821 L
.67707 .01821 L
.69536 .01821 L
.73657 .01821 L
.77627 .01821 L
.81445 .01821 L
.85508 .01821 L
.8942 .01821 L
.93577 .01821 L
.97583 .01821 L
.97619 .01821 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19253 L
.04262 .2307 L
.04754 .26191 L
.0522 .28425 L
.05711 .30143 L
.05988 .30863 L
.06244 .31388 L
.06487 .31773 L
.0662 .31944 L
.06747 .32082 L
.06865 .32188 L
.06993 .32283 L
.07109 .32351 L
.07218 .324 L
.07286 .32424 L
.07359 .32445 L
.07487 .32469 L
.07559 .32475 L
.07636 .32477 L
.07702 .32475 L
.07774 .32469 L
.07902 .32448 L
.07975 .32431 L
.08041 .32413 L
.0829 .32323 L
.08567 .3219 L
.08823 .32043 L
.09403 .31662 L
.10458 .30963 L
.10921 .30707 L
.11165 .30593 L
.11421 .30489 L
.11646 .30415 L
.11765 .30382 L
.11892 .30351 L
.12009 .30328 L
.12116 .30312 L
.12223 .30299 L
.12324 .30291 L
.12443 .30287 L
.12574 .30288 L
.1264 .30292 L
.12711 .30298 L
.12839 .30314 L
.12966 .30337 L
.13087 .30365 L
.13313 .30438 L
Mistroke
.13579 .30559 L
.13826 .30707 L
.14096 .30916 L
.14385 .31201 L
.14646 .31523 L
.14922 .31942 L
.15416 .32953 L
.15691 .33701 L
.15947 .34546 L
.1653 .37061 L
.17497 .42214 L
.18043 .44625 L
.18548 .46197 L
.1879 .4673 L
.19056 .47168 L
.19191 .47335 L
.19335 .47477 L
.19471 .47578 L
.19596 .47646 L
.19716 .4769 L
.19827 .47714 L
.19949 .47724 L
.20079 .47717 L
.20145 .47707 L
.20216 .47691 L
.20346 .47653 L
.20471 .47605 L
.20587 .47551 L
.21483 .4699 L
.21719 .46836 L
.21976 .46685 L
.22203 .46574 L
.22327 .46525 L
.22444 .46488 L
.2257 .46459 L
.22636 .46448 L
.22708 .46442 L
.22835 .46442 L
.22952 .46456 L
.2306 .46483 L
.23178 .46529 L
.23301 .46596 L
.23416 .46679 L
.23646 .46909 L
.23855 .47202 L
.24096 .47653 L
.24324 .482 L
.24839 .49867 L
.25315 .51758 L
.25833 .53779 L
Mistroke
.2639 .55591 L
.26895 .56862 L
.27357 .57748 L
.27822 .58413 L
.28264 .5887 L
.28511 .59063 L
.28775 .59224 L
.29025 .59341 L
.2925 .59418 L
.29389 .59455 L
.29517 .59481 L
.29657 .59503 L
.29727 .59511 L
.29805 .59518 L
.29935 .59526 L
.30008 .59527 L
.30075 .59528 L
.30204 .59525 L
.30327 .59519 L
.30441 .5951 L
.30564 .59498 L
.30786 .59469 L
.31293 .59377 L
.32319 .5915 L
.32781 .59052 L
.33274 .58963 L
.33739 .58895 L
.34162 .58849 L
.34398 .5883 L
.34655 .58814 L
.34772 .58808 L
.34897 .58803 L
.35013 .58799 L
.3512 .58796 L
.35244 .58794 L
.35313 .58793 L
.35378 .58792 L
.35493 .58791 L
.35619 .58791 L
.35691 .58791 L
.35757 .58791 L
.35832 .58792 L
.35903 .58792 L
.3603 .58794 L
.36167 .58795 L
.36654 .58804 L
.37174 .58813 L
.37328 .58816 L
.37473 .58817 L
.37604 .58818 L
Mistroke
.37677 .58819 L
.37745 .58819 L
.37868 .58819 L
.37938 .58819 L
.38004 .58819 L
.38136 .58818 L
.3821 .58817 L
.38278 .58816 L
.38401 .58814 L
.38532 .58811 L
.38768 .58805 L
.39048 .58794 L
.39302 .58781 L
.39804 .58749 L
.40277 .58709 L
.4129 .58598 L
.42385 .58449 L
.44339 .58153 L
.46484 .57856 L
.50432 .57468 L
.52382 .57331 L
.54473 .57208 L
.56453 .57114 L
.58608 .57037 L
.59611 .57009 L
.60677 .56985 L
.62591 .56951 L
.63528 .56939 L
.64537 .56929 L
.65484 .56921 L
.66365 .56915 L
.67322 .5691 L
.6787 .56907 L
.68368 .56906 L
.68857 .56904 L
.69388 .56903 L
.69948 .56902 L
.70204 .56902 L
.70478 .56901 L
.70733 .56901 L
.70966 .56901 L
.71201 .56901 L
.71424 .56901 L
.71549 .56901 L
.71617 .56901 L
.71682 .56901 L
.71808 .56901 L
.71922 .56901 L
.71988 .56901 L
.72057 .56901 L
Mistroke
.72182 .56901 L
.72252 .56901 L
.72317 .56901 L
.72388 .56901 L
.72464 .56901 L
.72605 .56901 L
.72736 .56901 L
.7303 .56901 L
.73566 .56901 L
.74052 .56902 L
.74568 .56902 L
.78347 .56906 L
.79371 .56907 L
.80448 .56908 L
.81445 .56909 L
.81931 .56909 L
.82372 .56909 L
.82802 .5691 L
.83267 .5691 L
.83523 .5691 L
.83759 .5691 L
.83984 .5691 L
.84222 .5691 L
.84348 .5691 L
.84463 .5691 L
.84526 .5691 L
.84595 .5691 L
.8472 .5691 L
.84837 .5691 L
.84962 .5691 L
.85068 .5691 L
.85186 .5691 L
.85323 .5691 L
.85448 .5691 L
.85732 .5691 L
.85981 .5691 L
.86244 .5691 L
.86743 .5691 L
.87197 .56909 L
.88215 .56909 L
.89159 .56908 L
.90051 .56907 L
.93893 .56902 L
.97619 .56894 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13939 L
.03793 .19255 L
.04262 .2308 L
.04754 .26222 L
.0522 .28491 L
.05711 .30266 L
.05988 .31026 L
.06244 .31593 L
.06487 .32023 L
.06747 .32381 L
.06993 .32633 L
.07218 .32799 L
.07354 .32872 L
.07481 .32924 L
.07552 .32946 L
.07619 .32964 L
.07697 .32979 L
.07767 .32989 L
.07898 .32997 L
.08018 .32995 L
.0815 .32982 L
.08217 .32972 L
.0829 .32958 L
.08435 .32923 L
.08573 .32882 L
.08831 .32787 L
.09411 .32519 L
.10458 .31998 L
.10956 .31791 L
.11423 .31645 L
.11658 .31593 L
.1179 .3157 L
.11911 .31554 L
.12036 .31542 L
.12107 .31538 L
.12173 .31535 L
.12243 .31534 L
.12306 .31534 L
.1238 .31536 L
.12449 .3154 L
.12555 .3155 L
.12672 .31565 L
.12794 .31587 L
.12909 .31613 L
.13113 .31674 L
.13333 .31762 L
.1359 .31895 L
.13833 .32056 L
Mistroke
.14291 .32466 L
.14551 .32773 L
.14795 .33122 L
.15252 .33968 L
.15744 .35252 L
.16275 .37213 L
.17228 .41947 L
.17692 .44148 L
.18115 .45752 L
.18336 .46413 L
.18576 .46997 L
.18829 .47468 L
.19068 .47787 L
.19194 .47909 L
.19332 .48011 L
.19401 .4805 L
.19476 .48083 L
.19547 .48106 L
.19611 .48121 L
.19728 .48133 L
.19856 .48127 L
.19921 .48116 L
.19989 .48099 L
.20113 .48057 L
.20255 .4799 L
.20386 .47914 L
.20682 .477 L
.21218 .47214 L
.21702 .4674 L
.22221 .46271 L
.22482 .46075 L
.22729 .45925 L
.22837 .45874 L
.22951 .4583 L
.23077 .45794 L
.23193 .45775 L
.233 .4577 L
.23415 .4578 L
.23524 .45804 L
.23624 .45841 L
.23735 .45898 L
.23857 .45983 L
.23983 .46098 L
.24101 .46231 L
.2437 .46641 L
.24624 .47175 L
.25099 .48578 L
.26167 .52731 L
.27137 .55831 L
.27627 .5695 L
Mistroke
.28165 .57882 L
.28624 .58469 L
.28878 .58725 L
.29118 .58929 L
.29341 .59088 L
.29584 .59232 L
.3001 .5942 L
.30266 .59501 L
.30542 .59567 L
.30669 .5959 L
.30803 .5961 L
.30919 .59625 L
.31043 .59638 L
.31164 .59649 L
.31274 .59657 L
.31386 .59663 L
.31489 .59667 L
.3161 .59671 L
.31741 .59674 L
.31856 .59675 L
.31979 .59676 L
.32108 .59676 L
.32226 .59675 L
.32356 .59674 L
.32493 .59674 L
.32605 .59673 L
.32724 .59672 L
.32855 .59671 L
.32976 .59671 L
.3305 .59671 L
.33118 .59672 L
.33193 .59672 L
.33273 .59673 L
.33342 .59674 L
.33406 .59675 L
.33553 .59678 L
.33685 .59681 L
.33805 .59685 L
.34076 .59696 L
.34328 .5971 L
.34555 .59724 L
.35065 .59765 L
.3598 .59855 L
.37062 .59965 L
.37535 .60007 L
.38055 .60046 L
.38541 .60075 L
.38994 .60095 L
.39244 .60102 L
.39472 .60108 L
Mistroke
.39599 .6011 L
.39736 .60112 L
.39865 .60113 L
.39984 .60114 L
.40104 .60115 L
.40233 .60115 L
.40354 .60114 L
.40466 .60113 L
.40596 .60112 L
.40737 .60111 L
.40996 .60106 L
.41265 .60101 L
.41552 .60093 L
.42068 .60078 L
.44065 .60004 L
.45115 .59968 L
.46225 .59937 L
.48311 .59893 L
.50231 .59861 L
.54027 .59795 L
.58068 .5973 L
.61958 .59679 L
.66092 .59631 L
.70076 .59589 L
.73907 .59552 L
.77984 .59514 L
.8191 .59479 L
.85684 .59447 L
.89703 .59414 L
.9357 .59383 L
.97619 .59353 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.02846 .08441 L
.03279 .13881 L
.03754 .18526 L
.0402 .20486 L
.04262 .2187 L
.04385 .22432 L
.04516 .22927 L
.04629 .23274 L
.0475 .23567 L
.04881 .23794 L
.05003 .2393 L
.05077 .23979 L
.05148 .24002 L
.05212 .24006 L
.05281 .23991 L
.05408 .23919 L
.05523 .23806 L
.05656 .23626 L
.05781 .23414 L
.06244 .22354 L
.07312 .1921 L
.08439 .16096 L
.09401 .14038 L
.09954 .13118 L
.10458 .12429 L
.10919 .11912 L
.1142 .11458 L
.1195 .11088 L
.12188 .10955 L
.12452 .1083 L
.12677 .10741 L
.12921 .10662 L
.13055 .10627 L
.13177 .10599 L
.13302 .10576 L
.13419 .10559 L
.13519 .10547 L
.13627 .10538 L
.13746 .10532 L
.13854 .10531 L
.13968 .10533 L
.1409 .10541 L
.14206 .10553 L
.14313 .10569 L
.14438 .10593 L
.14557 .10622 L
.1478 .10693 L
.15021 .10798 L
.15282 .10953 L
Mistroke
.1551 .11129 L
.15753 .11371 L
.15982 .11665 L
.16189 .11998 L
.16456 .12542 L
.16701 .13175 L
.17253 .15054 L
.17736 .16862 L
.18002 .17722 L
.18253 .18375 L
.18498 .18839 L
.18637 .19025 L
.18764 .19149 L
.18872 .1922 L
.1899 .19265 L
.19114 .19278 L
.19229 .19259 L
.19341 .19216 L
.19458 .19146 L
.19558 .19069 L
.19668 .18967 L
.2014 .18369 L
.22207 .14819 L
.23219 .13393 L
.24172 .12402 L
.247 .11993 L
.25271 .11648 L
.25791 .11411 L
.26269 .11244 L
.27241 .10997 L
.28149 .1081 L
.30214 .10366 L
.31258 .10158 L
.32247 .09994 L
.33135 .09879 L
.33633 .09828 L
.34102 .09788 L
.34591 .09753 L
.3504 .09727 L
.35539 .09704 L
.35817 .09694 L
.36077 .09686 L
.36565 .09675 L
.36823 .09671 L
.37099 .09667 L
.37239 .09666 L
.37312 .09666 L
.37389 .09665 L
.37457 .09665 L
.37532 .09665 L
Mistroke
.37664 .09664 L
.37791 .09664 L
.37863 .09665 L
.37929 .09665 L
.38056 .09665 L
.38177 .09666 L
.38301 .09666 L
.38436 .09667 L
.3868 .0967 L
.39136 .09676 L
.39669 .09685 L
.40159 .09696 L
.41998 .09749 L
.45949 .09884 L
.49748 .10016 L
.53792 .10151 L
.57685 .10266 L
.61823 .10368 L
.6581 .10446 L
.69645 .10503 L
.71585 .10525 L
.73725 .10546 L
.77654 .10574 L
.7959 .10583 L
.81676 .10592 L
.83682 .10598 L
.85792 .10603 L
.87768 .10606 L
.89605 .10608 L
.90658 .10609 L
.91652 .1061 L
.93511 .10611 L
.94484 .10612 L
.95514 .10612 L
.9736 .10612 L
.97619 .10613 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.02846 .08428 L
.03279 .13715 L
.03523 .1608 L
.03754 .17878 L
.03881 .18689 L
.0402 .19427 L
.04145 .19969 L
.04262 .20375 L
.04376 .20683 L
.045 .20921 L
.0457 .21016 L
.04637 .21081 L
.04762 .2114 L
.04894 .21122 L
.05016 .21041 L
.05086 .20968 L
.0515 .20888 L
.05293 .20663 L
.05528 .20179 L
.05783 .19539 L
.06244 .18207 L
.07304 .15066 L
.08293 .12628 L
.09325 .10753 L
.09872 .10008 L
.10458 .0937 L
.10986 .08917 L
.11559 .08535 L
.12101 .08264 L
.1236 .08163 L
.12603 .08082 L
.12838 .08017 L
.13053 .07968 L
.13293 .07925 L
.13419 .07908 L
.13551 .07893 L
.13671 .07883 L
.138 .07875 L
.13922 .07872 L
.14032 .07871 L
.14162 .07875 L
.14235 .07878 L
.14303 .07883 L
.14427 .07894 L
.14558 .0791 L
.14679 .0793 L
.14811 .07956 L
.15051 .08019 L
.15285 .08103 L
Mistroke
.15502 .08204 L
.1576 .0836 L
.15993 .08545 L
.16262 .08825 L
.16516 .0917 L
.16974 .10034 L
.17396 .11057 L
.17894 .12269 L
.18111 .12709 L
.18347 .13092 L
.18473 .13254 L
.18589 .13376 L
.187 .1347 L
.18818 .13546 L
.18942 .13599 L
.19059 .13628 L
.19186 .13637 L
.19258 .13632 L
.19323 .13622 L
.19433 .13594 L
.19535 .13556 L
.19767 .13434 L
.19992 .13275 L
.20233 .13075 L
.2131 .12 L
.22301 .11066 L
.2279 .10692 L
.23328 .1037 L
.23607 .10246 L
.23741 .10198 L
.23868 .1016 L
.23937 .10143 L
.24012 .10127 L
.24144 .10106 L
.24218 .10099 L
.24297 .10096 L
.24365 .10096 L
.2444 .10101 L
.24567 .10118 L
.2463 .10132 L
.247 .10152 L
.24824 .10199 L
.2494 .10259 L
.25076 .10353 L
.252 .10464 L
.25344 .10626 L
.25479 .10819 L
.25723 .11279 L
.25948 .11856 L
.26195 .12679 L
Mistroke
.26456 .13774 L
.2747 .19422 L
.2797 .22126 L
.28213 .23237 L
.28433 .24095 L
.28634 .24743 L
.28852 .25296 L
.28972 .25534 L
.29082 .25712 L
.29187 .25847 L
.29298 .25952 L
.2941 .26021 L
.29531 .26054 L
.29644 .26049 L
.29748 .26015 L
.29869 .25942 L
.30001 .25823 L
.30126 .25677 L
.30241 .25515 L
.30689 .24676 L
.31184 .23477 L
.32184 .2069 L
.33274 .17778 L
.34272 .15549 L
.35216 .13884 L
.36208 .12545 L
.37205 .11547 L
.38295 .10757 L
.39323 .10217 L
.40257 .09847 L
.41335 .09516 L
.42353 .0927 L
.43326 .09076 L
.44356 .08906 L
.46201 .08671 L
.47146 .08579 L
.4816 .08497 L
.49992 .08387 L
.51006 .08341 L
.52111 .08301 L
.54122 .08246 L
.56094 .08207 L
.58193 .08178 L
.59226 .08167 L
.6034 .08157 L
.61392 .08151 L
.62359 .08146 L
.63336 .08142 L
.64247 .0814 L
.6477 .08138 L
Mistroke
.65246 .08138 L
.65509 .08137 L
.65795 .08137 L
.66045 .08137 L
.66315 .08137 L
.66445 .08137 L
.66569 .08137 L
.6669 .08137 L
.66802 .08137 L
.66907 .08137 L
.6702 .08136 L
.67145 .08136 L
.67258 .08137 L
.67323 .08137 L
.67392 .08137 L
.67515 .08137 L
.67648 .08137 L
.67793 .08137 L
.68054 .08137 L
.68298 .08137 L
.68828 .08137 L
.69312 .08138 L
.704 .08139 L
.72308 .08143 L
.74384 .08148 L
.78461 .0816 L
.82386 .08173 L
.8616 .08184 L
.90179 .08195 L
.94046 .08205 L
.97619 .08213 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19235 L
.04262 .23002 L
.04754 .26014 L
.0522 .28081 L
.05475 .28933 L
.05711 .29561 L
.0597 .3009 L
.06111 .30314 L
.06244 .30489 L
.06369 .3062 L
.06505 .30731 L
.06628 .30804 L
.06743 .30851 L
.06813 .3087 L
.06879 .30882 L
.07003 .30888 L
.07072 .30882 L
.07136 .30873 L
.07206 .30857 L
.0728 .30835 L
.07395 .30789 L
.07519 .30726 L
.07742 .30582 L
.0825 .30142 L
.09307 .28993 L
.09865 .28388 L
.10458 .27813 L
.10982 .27386 L
.11261 .27196 L
.11561 .27022 L
.11836 .26893 L
.12088 .268 L
.12328 .26736 L
.1245 .26713 L
.12518 .26703 L
.12582 .26696 L
.12647 .2669 L
.12718 .26686 L
.12846 .26684 L
.12963 .26689 L
.13086 .26702 L
.1315 .26712 L
.13218 .26725 L
.13342 .26754 L
.1349 .268 L
.13624 .26853 L
.13862 .26975 L
Mistroke
.14122 .27152 L
.14367 .27367 L
.14594 .27615 L
.15103 .28383 L
.1539 .28981 L
.15654 .29668 L
.16139 .31371 L
.1665 .33881 L
.17625 .39572 L
.1805 .41628 L
.18512 .43291 L
.18766 .43951 L
.19001 .44412 L
.19225 .44732 L
.19338 .44852 L
.19463 .44955 L
.19595 .45032 L
.19715 .45077 L
.19779 .45092 L
.19848 .45101 L
.1992 .45103 L
.19988 .45098 L
.20113 .45075 L
.20226 .45038 L
.20357 .44979 L
.2048 .4491 L
.20939 .4456 L
.21361 .44162 L
.2186 .43682 L
.22315 .43305 L
.2243 .43228 L
.22555 .43155 L
.22664 .43102 L
.22784 .43056 L
.2291 .43024 L
.2298 .43015 L
.23045 .43011 L
.23161 .43018 L
.23287 .43049 L
.23397 .43096 L
.23517 .43171 L
.23643 .4328 L
.2376 .43411 L
.2397 .43726 L
.24195 .4419 L
.24462 .44933 L
.24751 .45984 L
.25277 .48408 L
.25785 .5091 L
.2626 .52987 L
Mistroke
.26754 .54744 L
.27205 .56006 L
.27706 .57071 L
.27986 .57533 L
.28245 .57886 L
.28516 .58187 L
.28761 .58406 L
.29034 .58595 L
.29185 .58679 L
.29324 .58742 L
.29578 .5883 L
.29711 .58863 L
.29779 .58876 L
.29852 .58888 L
.29974 .58903 L
.30089 .58911 L
.30159 .58914 L
.30225 .58914 L
.30349 .58912 L
.30463 .58905 L
.30586 .58893 L
.30702 .58878 L
.30808 .58862 L
.31315 .5875 L
.32341 .58432 L
.33232 .58141 L
.34184 .57876 L
.34698 .57761 L
.35165 .57674 L
.36078 .57542 L
.37155 .57422 L
.38148 .57308 L
.39081 .57173 L
.40068 .56984 L
.42148 .56429 L
.45939 .55204 L
.48049 .54636 L
.49975 .54235 L
.51968 .53916 L
.5386 .53679 L
.55846 .53485 L
.57686 .53352 L
.58747 .53295 L
.59744 .53254 L
.60639 .53226 L
.6114 .53213 L
.61606 .53204 L
.62106 .53196 L
.6256 .5319 L
.63065 .53185 L
Mistroke
.63343 .53183 L
.63468 .53183 L
.63605 .53182 L
.63728 .53182 L
.6386 .53181 L
.63933 .53181 L
.64 .53181 L
.64131 .53181 L
.6425 .53181 L
.6438 .53181 L
.64502 .53181 L
.64616 .53181 L
.64685 .53181 L
.6476 .53182 L
.64895 .53182 L
.65147 .53183 L
.65442 .53185 L
.65714 .53186 L
.66687 .53195 L
.67595 .53207 L
.69661 .53243 L
.73551 .53333 L
.77686 .5344 L
.81669 .53539 L
.85501 .53624 L
.89578 .53703 L
.93503 .53767 L
.97277 .53819 L
.97619 .53824 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13929 L
.03793 .19173 L
.04262 .22819 L
.04498 .24285 L
.04754 .25617 L
.04976 .26568 L
.0522 .27416 L
.05478 .28109 L
.0561 .28388 L
.05753 .28636 L
.05885 .28822 L
.06007 .28957 L
.06129 .2906 L
.06244 .29131 L
.0631 .2916 L
.06381 .29182 L
.0651 .29201 L
.06635 .29194 L
.0675 .29168 L
.06875 .29121 L
.07012 .29048 L
.07289 .28843 L
.07791 .28326 L
.08259 .27743 L
.09388 .26261 L
.09944 .25601 L
.10458 .25071 L
.10921 .2467 L
.11433 .24319 L
.1168 .24185 L
.11947 .24068 L
.12094 .24015 L
.12229 .23975 L
.12357 .23944 L
.12493 .23918 L
.1261 .23903 L
.12717 .23894 L
.12824 .2389 L
.12925 .23892 L
.13043 .23899 L
.13151 .23912 L
.13271 .23933 L
.13397 .23963 L
.13631 .24043 L
.1385 .24146 L
.14091 .24295 L
.14349 .24503 L
.14603 .24764 L
Mistroke
.14875 .25115 L
.15362 .2599 L
.15661 .26731 L
.15941 .27616 L
.16466 .29864 L
.17425 .35426 L
.17688 .36865 L
.17969 .38202 L
.18212 .39155 L
.18476 .39965 L
.18613 .40294 L
.1874 .40543 L
.18858 .40731 L
.18989 .40889 L
.19106 .40988 L
.19215 .41047 L
.19331 .41075 L
.19455 .41068 L
.19581 .41025 L
.19652 .40985 L
.19718 .40939 L
.19852 .4082 L
.19995 .40656 L
.20488 .39858 L
.21457 .37638 L
.22337 .35399 L
.23271 .33208 L
.24259 .31365 L
.24775 .3064 L
.25343 .30035 L
.25591 .29829 L
.25858 .29642 L
.2634 .29389 L
.26596 .29293 L
.26736 .29251 L
.26868 .29219 L
.26979 .29198 L
.271 .2918 L
.27165 .29173 L
.27233 .29168 L
.27356 .29164 L
.27488 .29167 L
.27562 .29172 L
.27629 .29179 L
.2776 .29199 L
.27884 .29226 L
.28028 .29267 L
.28161 .29313 L
.28462 .29451 L
.28927 .29747 L
Mistroke
.29438 .30172 L
.30473 .31213 L
.34504 .34614 L
.38383 .38668 L
.40355 .41538 L
.42507 .4443 L
.4648 .48278 L
.48449 .49671 L
.50547 .50903 L
.52546 .5186 L
.54707 .52679 L
.56795 .53296 L
.58716 .53744 L
.60759 .54121 L
.62666 .54396 L
.645 .54601 L
.66466 .54767 L
.67484 .54835 L
.68591 .54895 L
.69548 .54938 L
.70604 .54976 L
.71625 .55003 L
.72583 .55022 L
.7311 .5503 L
.73594 .55036 L
.74125 .55041 L
.74392 .55042 L
.74544 .55043 L
.74684 .55044 L
.74805 .55044 L
.74938 .55044 L
.75072 .55045 L
.75145 .55045 L
.75213 .55045 L
.75339 .55045 L
.75454 .55045 L
.75517 .55045 L
.75587 .55045 L
.75712 .55045 L
.75836 .55044 L
.75947 .55044 L
.76197 .55043 L
.76429 .55042 L
.76646 .55041 L
.77172 .55037 L
.77654 .55032 L
.78742 .55018 L
.79719 .55002 L
.8063 .54983 L
.82698 .54932 L
Mistroke
.86596 .54806 L
.90739 .54641 L
.94731 .54464 L
.97619 .54329 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.02846 .08442 L
.03279 .13899 L
.03754 .18637 L
.04018 .20694 L
.04262 .22236 L
.04518 .23499 L
.0465 .24017 L
.04795 .24488 L
.04913 .24796 L
.0504 .25059 L
.0511 .25175 L
.05174 .25263 L
.053 .25392 L
.0542 .25462 L
.05531 .25485 L
.05654 .25466 L
.05784 .254 L
.05908 .25297 L
.06026 .25169 L
.06244 .24859 L
.06757 .23869 L
.07299 .22601 L
.08269 .2026 L
.09325 .18068 L
.09907 .17099 L
.10458 .1634 L
.1095 .15787 L
.11485 .1531 L
.11972 .14981 L
.12204 .14857 L
.12422 .1476 L
.12642 .14681 L
.12844 .14623 L
.12952 .14599 L
.13069 .14578 L
.13187 .14562 L
.13311 .14551 L
.13435 .14546 L
.13547 .14547 L
.13677 .14555 L
.138 .14569 L
.13914 .14588 L
.14018 .1461 L
.14255 .14682 L
.1438 .14732 L
.14499 .14788 L
.14722 .14918 L
.14963 .151 L
.15225 .15357 L
Mistroke
.15452 .15644 L
.15695 .1603 L
.16131 .17006 L
.164 .17844 L
.1669 .18994 L
.17215 .21635 L
.17722 .24311 L
.1797 .25428 L
.18195 .26271 L
.18432 .26955 L
.18541 .272 L
.18656 .27412 L
.18778 .27586 L
.18892 .27701 L
.19014 .27778 L
.19083 .27801 L
.19148 .2781 L
.19277 .27793 L
.19341 .27768 L
.19411 .27729 L
.19536 .27632 L
.19652 .27512 L
.19914 .2715 L
.20193 .26651 L
.22301 .21688 L
.23328 .19619 L
.23868 .18743 L
.2444 .17981 L
.2494 .17444 L
.25489 .1698 L
.25989 .16653 L
.26456 .16407 L
.28489 .15593 L
.30344 .14972 L
.31333 .14729 L
.3225 .14566 L
.32728 .14501 L
.33256 .14445 L
.33521 .14422 L
.33807 .14402 L
.34057 .14386 L
.34325 .14373 L
.34584 .14364 L
.3482 .14358 L
.34933 .14356 L
.35057 .14354 L
.35173 .14353 L
.3528 .14352 L
.35405 .14352 L
.35522 .14353 L
Mistroke
.3565 .14354 L
.35723 .14355 L
.35788 .14357 L
.3592 .14359 L
.36064 .14363 L
.36327 .14373 L
.36604 .14385 L
.36856 .144 L
.37421 .14441 L
.38436 .14547 L
.39439 .14686 L
.40362 .14839 L
.42444 .15234 L
.46395 .15996 L
.50194 .16686 L
.54239 .17375 L
.58132 .17944 L
.6227 .1843 L
.64341 .18627 L
.66256 .18782 L
.70091 .19018 L
.71959 .19101 L
.7402 .19173 L
.75956 .19222 L
.77044 .19244 L
.78042 .1926 L
.78958 .19271 L
.79936 .19281 L
.80498 .19286 L
.81009 .19289 L
.81484 .19292 L
.82006 .19294 L
.82492 .19295 L
.82757 .19296 L
.83006 .19296 L
.83125 .19297 L
.83238 .19297 L
.8334 .19297 L
.8345 .19297 L
.83568 .19297 L
.83678 .19297 L
.83808 .19297 L
.83926 .19297 L
.84057 .19297 L
.84123 .19297 L
.84195 .19297 L
.84323 .19297 L
.84442 .19297 L
.84711 .19296 L
.84998 .19296 L
Mistroke
.85526 .19294 L
.86007 .19293 L
.87002 .19289 L
.8792 .19284 L
.89998 .1927 L
.93932 .19234 L
.97619 .19195 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.02846 .0844 L
.03279 .13844 L
.03523 .16339 L
.03754 .18287 L
.03881 .19183 L
.0402 .20009 L
.04145 .20622 L
.04262 .21085 L
.04376 .21437 L
.045 .21707 L
.0457 .21814 L
.04637 .21884 L
.04762 .21941 L
.04894 .21903 L
.05016 .21787 L
.05086 .21689 L
.0515 .21582 L
.05293 .21287 L
.05783 .19853 L
.06244 .18196 L
.07229 .14675 L
.08269 .1169 L
.08812 .10485 L
.09409 .09415 L
.09948 .08643 L
.10458 .08056 L
.10947 .07604 L
.11478 .07216 L
.11962 .06942 L
.12409 .06744 L
.12891 .06584 L
.13165 .06514 L
.13423 .06462 L
.13555 .0644 L
.13694 .06421 L
.13813 .06407 L
.13942 .06395 L
.14014 .06389 L
.1408 .06385 L
.14208 .0638 L
.1428 .06378 L
.14359 .06377 L
.14432 .06377 L
.145 .06378 L
.14626 .06383 L
.14745 .06391 L
.14851 .064 L
.14968 .06414 L
.15094 .06433 L
Mistroke
.15228 .06457 L
.1547 .06515 L
.15715 .06596 L
.15946 .06695 L
.16153 .06809 L
.16377 .06962 L
.169 .07466 L
.17452 .08187 L
.17718 .08541 L
.1797 .08838 L
.18195 .09055 L
.18312 .09146 L
.18441 .09228 L
.18564 .0929 L
.1868 .09332 L
.18803 .09361 L
.18935 .09375 L
.19051 .09374 L
.19173 .0936 L
.19277 .0934 L
.19391 .09308 L
.19646 .09207 L
.19918 .09065 L
.20408 .0875 L
.22243 .07498 L
.2327 .06977 L
.23849 .06757 L
.24382 .06596 L
.24849 .06485 L
.25362 .06392 L
.2562 .06354 L
.25898 .06321 L
.26398 .06274 L
.26654 .06256 L
.26925 .0624 L
.27414 .06217 L
.2852 .06172 L
.29475 .06121 L
.30531 .06049 L
.31551 .05974 L
.32626 .05902 L
.33621 .05847 L
.34548 .05808 L
.3544 .0578 L
.36393 .05758 L
.36937 .05749 L
.37451 .05742 L
.38414 .05732 L
.38876 .05729 L
.39384 .05726 L
Mistroke
.3988 .05723 L
.40412 .05721 L
.4091 .05719 L
.41365 .05718 L
.41833 .05716 L
.42257 .05716 L
.42734 .05715 L
.42978 .05715 L
.43242 .05714 L
.43488 .05714 L
.43713 .05714 L
.43929 .05714 L
.44038 .05714 L
.44157 .05714 L
.44224 .05714 L
.44296 .05714 L
.44428 .05714 L
.44556 .05714 L
.44675 .05714 L
.44803 .05714 L
.44875 .05714 L
.44944 .05714 L
.45081 .05714 L
.45229 .05714 L
.45484 .05714 L
.45751 .05714 L
.4623 .05715 L
.47185 .05716 L
.48205 .05717 L
.50043 .0572 L
.54194 .05729 L
.58195 .05737 L
.62043 .05744 L
.66137 .0575 L
.70079 .05755 L
.7387 .05758 L
.75816 .05759 L
.77906 .0576 L
.80025 .05761 L
.82036 .05761 L
.82998 .05761 L
.84022 .05762 L
.85862 .05762 L
.86894 .05762 L
.87437 .05762 L
.88009 .05762 L
.88511 .05762 L
.89061 .05762 L
.89525 .05762 L
.90028 .05762 L
Mistroke
.90301 .05762 L
.90554 .05762 L
.90791 .05762 L
.91052 .05762 L
.91285 .05762 L
.91504 .05762 L
.91625 .05762 L
.91735 .05762 L
.91863 .05762 L
.91984 .05762 L
.92116 .05762 L
.92235 .05762 L
.92301 .05762 L
.92373 .05762 L
.92503 .05762 L
.92754 .05762 L
.92985 .05762 L
.93516 .05762 L
.94077 .05762 L
.94961 .05762 L
.95909 .05762 L
.97619 .05762 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.02499 .02081 L
.02605 .02127 L
.02729 .02122 L
.02846 .02102 L
.03279 .02004 L
.0379 .01895 L
.04262 .01813 L
.04714 .01748 L
.05212 .01692 L
.05713 .01648 L
.06244 .01612 L
.06792 .01583 L
.07293 .01563 L
.07871 .01546 L
.0842 .01533 L
.08925 .01524 L
.09394 .01518 L
.09909 .01512 L
.10458 .01508 L
.10994 .01505 L
.11487 .01503 L
.12028 .01501 L
.12599 .01499 L
.13096 .01498 L
.13561 .01497 L
.1407 .01497 L
.14616 .01496 L
.15145 .01496 L
.15634 .01496 L
.15889 .01496 L
.1617 .01495 L
.16468 .01495 L
.1674 .01495 L
.1724 .01495 L
.17778 .01495 L
.18752 .01495 L
.19745 .01495 L
.20805 .01495 L
.2132 .01495 L
.21806 .01495 L
.22715 .01495 L
.23177 .01495 L
.23666 .01495 L
.24084 .01495 L
.24321 .01495 L
.24543 .01495 L
.24666 .01495 L
.24799 .01495 L
.24917 .01495 L
Mistroke
.25043 .01495 L
.25167 .01495 L
.25279 .01495 L
.25393 .01495 L
.25499 .01495 L
.25624 .01495 L
.25756 .01495 L
.25869 .01495 L
.25992 .01495 L
.26126 .01495 L
.26268 .01495 L
.26526 .01495 L
.27489 .01495 L
.28016 .01495 L
.28511 .01495 L
.28789 .01495 L
.29044 .01495 L
.29179 .01495 L
.29327 .01495 L
.29475 .01495 L
.29556 .01495 L
.29631 .01495 L
.29696 .01495 L
.29767 .01495 L
.29894 .01495 L
.30018 .01495 L
.30132 .01495 L
.30256 .01495 L
.30392 .01495 L
.30667 .01495 L
.30934 .01495 L
.31187 .01495 L
.31662 .01495 L
.32729 .01495 L
.34657 .01495 L
.3562 .01495 L
.36645 .01495 L
.3752 .01495 L
.38486 .01495 L
.40581 .01495 L
.42503 .01495 L
.44505 .01495 L
.46369 .01495 L
.48259 .01495 L
.50328 .01495 L
.54229 .01495 L
.56218 .01495 L
.58376 .01495 L
.62371 .01495 L
.6646 .01495 L
Mistroke
.70397 .01495 L
.74182 .01495 L
.78213 .01495 L
.82092 .01495 L
.86217 .01495 L
.90189 .01495 L
.94011 .01495 L
.97619 .01495 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13937 L
.03793 .19231 L
.04262 .22988 L
.04754 .2598 L
.0522 .28022 L
.05475 .28858 L
.05711 .29472 L
.0597 .29986 L
.06111 .30203 L
.06244 .30371 L
.06369 .30496 L
.06505 .30601 L
.06628 .3067 L
.06743 .30713 L
.06813 .30729 L
.06879 .30739 L
.07003 .30741 L
.07072 .30735 L
.07136 .30724 L
.07206 .30707 L
.0728 .30683 L
.07395 .30636 L
.07519 .30572 L
.07742 .30428 L
.0825 .29992 L
.09307 .28871 L
.09865 .28287 L
.10458 .27734 L
.10982 .27326 L
.11261 .27146 L
.11561 .26982 L
.11836 .26862 L
.12088 .26777 L
.12212 .26744 L
.12328 .2672 L
.1245 .267 L
.12514 .26693 L
.12582 .26686 L
.12648 .26682 L
.12717 .2668 L
.12842 .26681 L
.12912 .26685 L
.12976 .26691 L
.13048 .267 L
.13124 .26712 L
.13261 .26741 L
.13392 .26778 L
.13636 .26874 L
Mistroke
.13874 .27002 L
.14094 .27155 L
.14594 .27648 L
.14859 .28011 L
.15103 .28422 L
.15366 .28967 L
.15654 .29712 L
.16139 .31415 L
.1665 .33911 L
.17109 .36583 L
.17607 .39423 L
.18046 .41494 L
.18287 .42397 L
.18512 .43089 L
.18765 .43693 L
.189 .43943 L
.19044 .4416 L
.19169 .44307 L
.19301 .44424 L
.19413 .44494 L
.19535 .44542 L
.19658 .44562 L
.19769 .44558 L
.19897 .44528 L
.20018 .44478 L
.20131 .44415 L
.20234 .44343 L
.20467 .44138 L
.20952 .43576 L
.21484 .42842 L
.22036 .42073 L
.22308 .41726 L
.2256 .41441 L
.22792 .41218 L
.23048 .41027 L
.2318 .40955 L
.23305 .40908 L
.23437 .40881 L
.23511 .40876 L
.23579 .4088 L
.23691 .40904 L
.23795 .40946 L
.23909 .41017 L
.24031 .41124 L
.2416 .41274 L
.24281 .41455 L
.24509 .41906 L
.24762 .42602 L
.2503 .43576 L
.25511 .45845 L
Mistroke
.26599 .51379 L
.27082 .53332 L
.27541 .5483 L
.2807 .56171 L
.28554 .57093 L
.29008 .57741 L
.2943 .5819 L
.29892 .58545 L
.3015 .58692 L
.30385 .58798 L
.30617 .58882 L
.30873 .58953 L
.31001 .58981 L
.31139 .59007 L
.31258 .59025 L
.31388 .59042 L
.31517 .59056 L
.31636 .59066 L
.31748 .59074 L
.31871 .59081 L
.31981 .59085 L
.32084 .59089 L
.32193 .59091 L
.32311 .59094 L
.32792 .59097 L
.32919 .59097 L
.32986 .59097 L
.33056 .59097 L
.33186 .59098 L
.33306 .59099 L
.33378 .591 L
.33446 .59101 L
.33601 .59103 L
.3373 .59106 L
.33869 .5911 L
.34143 .59121 L
.34393 .59134 L
.34886 .59167 L
.35422 .59215 L
.36399 .59316 L
.3697 .59375 L
.37507 .59424 L
.38029 .59462 L
.38258 .59476 L
.38509 .59488 L
.38748 .59498 L
.38971 .59504 L
.39094 .59507 L
.39206 .59509 L
.39335 .5951 L
Mistroke
.39458 .59511 L
.39582 .59511 L
.39713 .5951 L
.39825 .59509 L
.39949 .59508 L
.40081 .59505 L
.40224 .59502 L
.40482 .59494 L
.41044 .59469 L
.41578 .59437 L
.42581 .59364 L
.44583 .59202 L
.46399 .59074 L
.48365 .58972 L
.50462 .58889 L
.52548 .58821 L
.54468 .58765 L
.56461 .58719 L
.58322 .58686 L
.5923 .58674 L
.60203 .58663 L
.61284 .58653 L
.62269 .58647 L
.6326 .58642 L
.64177 .58638 L
.64655 .58637 L
.65183 .58636 L
.65448 .58635 L
.65735 .58635 L
.65985 .58634 L
.66252 .58634 L
.66512 .58634 L
.66748 .58634 L
.66862 .58634 L
.66985 .58634 L
.67102 .58634 L
.67209 .58634 L
.67334 .58634 L
.67451 .58634 L
.67579 .58634 L
.67651 .58634 L
.67717 .58634 L
.67849 .58634 L
.67993 .58634 L
.68256 .58634 L
.68534 .58634 L
.68786 .58634 L
.6935 .58635 L
.70365 .58637 L
.72293 .58641 L
Mistroke
.74376 .58647 L
.7848 .58661 L
.82433 .58673 L
.86234 .58682 L
.9028 .58691 L
.94175 .58696 L
.97619 .587 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .0214 L
.02846 .02122 L
.03053 .0208 L
.03279 .02029 L
.04262 .0184 L
.04762 .01769 L
.05293 .0171 L
.0579 .01667 L
.06244 .01636 L
.06743 .01608 L
.0728 .01586 L
.07777 .01569 L
.0825 .01557 L
.08797 .01546 L
.09305 .01539 L
.09863 .01532 L
.10458 .01527 L
.10994 .01523 L
.11487 .01521 L
.12028 .01519 L
.12599 .01517 L
.13096 .01516 L
.13561 .01515 L
.1407 .01515 L
.14335 .01514 L
.14616 .01514 L
.14867 .01514 L
.15145 .01514 L
.15397 .01514 L
.15634 .01514 L
.15769 .01514 L
.15911 .01514 L
.16033 .01514 L
.16102 .01514 L
.16166 .01514 L
.16241 .01514 L
.16312 .01514 L
.16444 .01514 L
.16518 .01514 L
.16586 .01514 L
.16661 .01514 L
.1674 .01514 L
.16865 .01514 L
.16979 .01514 L
.17235 .01514 L
.17476 .01514 L
.17698 .01514 L
Mistroke
.17824 .01514 L
.17894 .01514 L
.17957 .01514 L
.18027 .01514 L
.18102 .01514 L
.18174 .01514 L
.18239 .01514 L
.18358 .01514 L
.18489 .01514 L
.18625 .01514 L
.18752 .01514 L
.19013 .01514 L
.19255 .01514 L
.198 .01513 L
.20792 .01513 L
.21686 .01513 L
.22648 .01513 L
.23152 .01513 L
.23614 .01513 L
.24055 .01512 L
.24519 .01512 L
.24766 .01512 L
.25029 .01512 L
.25504 .01512 L
.26068 .01512 L
.2658 .01512 L
.30584 .01512 L
.32419 .01512 L
.33462 .01512 L
.34436 .01512 L
.35477 .01512 L
.36427 .01512 L
.37443 .01512 L
.38533 .01512 L
.40439 .01512 L
.41516 .01512 L
.42514 .01512 L
.43475 .01512 L
.44378 .01512 L
.45369 .01512 L
.45926 .01512 L
.46437 .01512 L
.4691 .01512 L
.47416 .01512 L
.47661 .01512 L
.47893 .01512 L
.481 .01512 L
.48327 .01512 L
.48578 .01512 L
.48706 .01512 L
Mistroke
.48844 .01512 L
.48972 .01512 L
.49089 .01512 L
.49208 .01512 L
.4932 .01512 L
.49449 .01512 L
.49521 .01512 L
.49587 .01512 L
.49715 .01512 L
.49835 .01512 L
.49975 .01512 L
.50105 .01512 L
.50397 .01512 L
.50867 .01512 L
.51371 .01512 L
.5228 .01512 L
.54347 .01512 L
.58485 .01512 L
.62472 .01512 L
.66307 .01512 L
.70387 .01512 L
.74316 .01512 L
.78093 .01512 L
.82115 .01512 L
.85986 .01512 L
.90102 .01512 L
.94066 .01512 L
.97619 .01512 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.02499 .03251 L
.02605 .04478 L
.02729 .05309 L
.02846 .05654 L
.02954 .05752 L
.03053 .05739 L
.03163 .05661 L
.03279 .05537 L
.04262 .04241 L
.05205 .03305 L
.05742 .02924 L
.06244 .02645 L
.06788 .02411 L
.07305 .02239 L
.07768 .02118 L
.08274 .02014 L
.08822 .01927 L
.09407 .01857 L
.09958 .01808 L
.10458 .01773 L
.10945 .01747 L
.1146 .01726 L
.119 .01712 L
.12383 .01699 L
.12902 .01689 L
.13459 .01681 L
.13985 .01675 L
.14465 .01672 L
.14693 .0167 L
.14945 .01669 L
.15209 .01668 L
.15329 .01668 L
.15456 .01668 L
.15566 .01667 L
.15686 .01667 L
.15796 .01667 L
.15897 .01667 L
.16018 .01667 L
.16127 .01667 L
.16254 .01667 L
.16373 .01667 L
.16493 .01667 L
.16625 .01667 L
.16891 .01668 L
.17369 .01669 L
.17638 .0167 L
.17786 .0167 L
.17927 .0167 L
.18058 .0167 L
Mistroke
.18131 .01671 L
.182 .01671 L
.18321 .01671 L
.18449 .01671 L
.18574 .01671 L
.18645 .01671 L
.18711 .01671 L
.18844 .0167 L
.18987 .0167 L
.19245 .0167 L
.1948 .01669 L
.20594 .01666 L
.21643 .01662 L
.22613 .0166 L
.2354 .01658 L
.24009 .01658 L
.24525 .01657 L
.24794 .01657 L
.25041 .01657 L
.25312 .01657 L
.2545 .01657 L
.25597 .01657 L
.25728 .01657 L
.25846 .01657 L
.25965 .01657 L
.26078 .01657 L
.26209 .01657 L
.2633 .01657 L
.26393 .01657 L
.26462 .01657 L
.26535 .01657 L
.26602 .01657 L
.26728 .01657 L
.26862 .01657 L
.27102 .01657 L
.27646 .01657 L
.28156 .01657 L
.28635 .01657 L
.28842 .01657 L
.29059 .01657 L
.29173 .01657 L
.29298 .01657 L
.29411 .01657 L
.29516 .01657 L
.29643 .01657 L
.29763 .01657 L
.2987 .01657 L
.29987 .01657 L
.30114 .01657 L
.30249 .01657 L
Mistroke
.3049 .01657 L
.30742 .01657 L
.30982 .01657 L
.31432 .01657 L
.32445 .01656 L
.34275 .01655 L
.35235 .01655 L
.36258 .01655 L
.37216 .01654 L
.38097 .01654 L
.39126 .01654 L
.40239 .01654 L
.41221 .01654 L
.42257 .01654 L
.43206 .01653 L
.44222 .01653 L
.46056 .01653 L
.47074 .01653 L
.48182 .01653 L
.49227 .01653 L
.50194 .01653 L
.51158 .01653 L
.52062 .01653 L
.53054 .01653 L
.54123 .01653 L
.55081 .01653 L
.56128 .01653 L
.56657 .01653 L
.57222 .01653 L
.57496 .01653 L
.57755 .01653 L
.58005 .01653 L
.58239 .01653 L
.58462 .01653 L
.58702 .01653 L
.58839 .01653 L
.58969 .01653 L
.59085 .01653 L
.59212 .01653 L
.59282 .01653 L
.59348 .01653 L
.59471 .01653 L
.5954 .01653 L
.59603 .01653 L
.59746 .01653 L
.59861 .01653 L
.59988 .01653 L
.60242 .01653 L
.60703 .01653 L
.61197 .01653 L
Mistroke
.62087 .01653 L
.63108 .01653 L
.64217 .01653 L
.66231 .01653 L
.70316 .01653 L
.7425 .01653 L
.78032 .01653 L
.8206 .01653 L
.85936 .01653 L
.90057 .01653 L
.94027 .01653 L
.97619 .01653 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13938 L
.03793 .19244 L
.04262 .23035 L
.04754 .26099 L
.0522 .28251 L
.05711 .29858 L
.05988 .30508 L
.06244 .30967 L
.06487 .31289 L
.06623 .31427 L
.06747 .3153 L
.06862 .31605 L
.06988 .31668 L
.07107 .31709 L
.07218 .31734 L
.07285 .31742 L
.07358 .31747 L
.0749 .31742 L
.07618 .31723 L
.07737 .31695 L
.07865 .31654 L
.08006 .31596 L
.0829 .3145 L
.09424 .30647 L
.10458 .29909 L
.10938 .29633 L
.11191 .29511 L
.1146 .29403 L
.11694 .29327 L
.11819 .29294 L
.11953 .29264 L
.12076 .29242 L
.12188 .29227 L
.12296 .29218 L
.12409 .29212 L
.1254 .29212 L
.12659 .29218 L
.12725 .29224 L
.12797 .29233 L
.12926 .29254 L
.13048 .29281 L
.13177 .29317 L
.13408 .29403 L
.13677 .29539 L
.13928 .29707 L
.14204 .29942 L
.145 .30262 L
.14755 .30605 L
Mistroke
.15026 .31053 L
.15513 .32131 L
.15812 .33014 L
.16093 .34034 L
.16618 .3646 L
.17577 .41583 L
.1784 .42774 L
.18121 .43852 L
.18364 .44608 L
.18628 .45246 L
.18765 .45504 L
.18891 .45702 L
.1901 .45852 L
.1914 .4598 L
.19257 .46064 L
.19367 .46118 L
.19482 .46149 L
.19607 .46156 L
.19733 .46136 L
.19804 .46114 L
.1987 .46087 L
.20004 .46014 L
.20146 .45912 L
.20405 .45668 L
.2064 .45395 L
.21538 .44083 L
.22488 .4265 L
.22965 .42065 L
.23236 .41804 L
.23366 .41701 L
.23489 .41619 L
.236 .41559 L
.23722 .4151 L
.23832 .41481 L
.23934 .4147 L
.24044 .41474 L
.24165 .415 L
.24292 .41555 L
.24411 .41633 L
.24532 .41742 L
.24665 .41898 L
.24933 .4234 L
.25181 .42919 L
.25412 .43612 L
.25934 .45664 L
.26492 .48273 L
.27514 .5269 L
.28091 .54593 L
.28624 .55959 L
.29089 .56885 L
Mistroke
.29602 .57664 L
.30137 .5826 L
.30638 .58662 L
.31135 .58949 L
.31677 .59169 L
.32189 .59316 L
.32665 .5942 L
.34518 .59724 L
.36399 .60019 L
.37388 .6015 L
.37928 .60208 L
.38432 .60251 L
.38965 .60286 L
.39247 .603 L
.39549 .60312 L
.39825 .6032 L
.3996 .60324 L
.40086 .60326 L
.40197 .60328 L
.4032 .60329 L
.40444 .60331 L
.40575 .60331 L
.40703 .60332 L
.40767 .60332 L
.40837 .60332 L
.40961 .60332 L
.41076 .60331 L
.41147 .60331 L
.41213 .6033 L
.41337 .60329 L
.41616 .60326 L
.42085 .60318 L
.42593 .60307 L
.44543 .60263 L
.45077 .60253 L
.45651 .60244 L
.46687 .60231 L
.47193 .60227 L
.47744 .60223 L
.48747 .60216 L
.50629 .60205 L
.54701 .60171 L
.58621 .6014 L
.62786 .60114 L
.668 .60092 L
.70662 .60072 L
.7477 .60052 L
.78726 .60034 L
.8253 .60016 L
.8658 .59998 L
Mistroke
.90478 .5998 L
.94621 .59962 L
.97619 .59949 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13928 L
.03793 .19171 L
.04262 .22815 L
.04498 .2428 L
.04754 .25613 L
.04976 .26565 L
.0522 .27417 L
.05478 .28115 L
.0561 .28397 L
.05753 .2865 L
.05885 .28841 L
.06007 .28981 L
.06129 .2909 L
.06244 .29166 L
.0631 .29198 L
.06381 .29225 L
.0651 .29251 L
.06635 .29252 L
.0675 .29233 L
.06875 .29194 L
.06946 .29164 L
.07012 .2913 L
.07289 .28945 L
.07757 .28503 L
.08259 .27919 L
.09312 .26606 L
.09868 .25971 L
.10458 .25386 L
.10982 .24961 L
.11261 .24776 L
.11561 .24608 L
.11836 .24484 L
.12088 .24397 L
.12212 .24363 L
.12328 .24337 L
.1245 .24316 L
.12514 .24308 L
.12582 .24301 L
.12648 .24296 L
.12717 .24292 L
.12842 .24292 L
.12912 .24295 L
.12976 .243 L
.13048 .24307 L
.13124 .24318 L
.13261 .24344 L
.13392 .24379 L
.13636 .24468 L
Mistroke
.13874 .24588 L
.14094 .24733 L
.14336 .24933 L
.14594 .25202 L
.14856 .25543 L
.15131 .25995 L
.15625 .27113 L
.159 .2796 L
.16157 .28932 L
.16739 .31836 L
.17707 .3739 L
.17972 .38614 L
.18253 .39667 L
.18493 .40355 L
.18631 .40665 L
.18758 .40895 L
.18884 .41075 L
.19018 .41213 L
.19087 .41265 L
.19152 .41301 L
.19223 .41327 L
.19298 .41342 L
.19364 .41343 L
.19435 .41332 L
.19564 .41283 L
.1969 .41201 L
.19805 .41098 L
.20035 .40823 L
.20287 .40429 L
.20797 .39413 L
.22654 .34945 L
.23177 .33829 L
.23672 .32914 L
.24123 .32224 L
.24602 .31656 L
.24849 .31433 L
.2498 .31336 L
.25122 .31246 L
.25251 .3118 L
.2537 .31132 L
.25484 .31098 L
.25603 .31074 L
.25733 .31064 L
.25806 .31065 L
.25872 .3107 L
.26001 .31092 L
.26123 .31129 L
.26192 .31157 L
.26265 .31192 L
.26396 .3127 L
Mistroke
.26538 .31376 L
.26693 .3152 L
.26942 .31816 L
.27213 .32235 L
.27707 .33254 L
.28635 .35911 L
.29731 .39495 L
.30724 .42343 L
.31738 .44541 L
.32692 .46032 L
.3479 .48368 L
.38647 .52598 L
.40643 .54346 L
.41647 .54991 L
.42749 .55544 L
.44702 .56242 L
.45796 .56534 L
.46794 .56761 L
.48865 .57151 L
.5078 .5743 L
.5264 .57638 L
.54615 .57802 L
.56564 .57922 L
.58392 .58007 L
.60412 .58077 L
.62263 .58122 L
.63244 .5814 L
.64157 .58153 L
.65158 .58164 L
.65719 .58169 L
.66228 .58172 L
.66713 .58174 L
.66958 .58175 L
.67227 .58176 L
.67456 .58176 L
.67585 .58176 L
.67703 .58177 L
.67812 .58177 L
.67931 .58177 L
.68043 .58177 L
.68148 .58177 L
.68279 .58177 L
.68352 .58177 L
.6842 .58177 L
.68545 .58177 L
.68677 .58176 L
.68905 .58176 L
.69155 .58175 L
.6971 .58174 L
.70228 .58171 L
Mistroke
.71277 .58165 L
.72269 .58157 L
.74126 .58137 L
.77966 .58078 L
.82051 .57997 L
.85985 .57904 L
.89768 .57805 L
.93795 .57692 L
.97619 .57581 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13922 L
.03793 .19128 L
.04262 .22684 L
.04498 .24079 L
.04754 .25313 L
.04996 .2623 L
.0522 .26878 L
.05456 .27375 L
.05591 .27579 L
.05717 .27721 L
.05785 .2778 L
.0585 .27825 L
.05971 .2788 L
.06102 .27901 L
.06176 .27897 L
.06244 .27883 L
.06311 .2786 L
.06382 .27827 L
.06509 .27747 L
.06645 .27632 L
.06795 .27476 L
.07314 .26749 L
.08284 .24993 L
.09421 .2294 L
.09918 .22166 L
.10458 .21439 L
.10978 .20858 L
.1146 .20426 L
.1192 .20109 L
.12152 .19983 L
.12409 .19872 L
.12541 .19826 L
.1268 .19786 L
.12798 .19759 L
.12928 .19737 L
.13002 .19727 L
.13068 .19721 L
.13145 .19716 L
.13218 .19715 L
.13347 .19718 L
.1342 .19724 L
.13488 .19731 L
.13609 .19751 L
.13722 .19776 L
.13846 .19813 L
.1398 .19862 L
.14252 .19999 L
.145 .20172 L
Mistroke
.14751 .204 L
.14979 .20662 L
.15241 .21045 L
.15488 .21502 L
.15927 .22629 L
.16175 .23493 L
.16403 .24465 L
.17476 .30907 L
.18 .33925 L
.18228 .34988 L
.18476 .35938 L
.1872 .36664 L
.18827 .3692 L
.18945 .37161 L
.19048 .37336 L
.19159 .3749 L
.19277 .37615 L
.19387 .37699 L
.19506 .37756 L
.19636 .37781 L
.19701 .37779 L
.19771 .37768 L
.19897 .37725 L
.20022 .37653 L
.20141 .37563 L
.20363 .37341 L
.2088 .36623 L
.21356 .35817 L
.21874 .34904 L
.2243 .34011 L
.22691 .3366 L
.22939 .33386 L
.23161 .332 L
.23286 .33125 L
.23402 .33077 L
.2351 .33053 L
.23612 .3305 L
.23723 .33072 L
.23843 .33126 L
.23961 .33215 L
.24087 .33352 L
.24194 .33508 L
.24311 .33723 L
.2445 .34046 L
.24581 .34426 L
.24827 .35352 L
.25093 .36683 L
.2538 .38482 L
.26376 .45555 L
.26831 .48314 L
Mistroke
.27321 .5073 L
.27858 .52758 L
.28361 .54139 L
.28631 .547 L
.28925 .55185 L
.29202 .55534 L
.29335 .55666 L
.2946 .5577 L
.29583 .55856 L
.29715 .55929 L
.29836 .5598 L
.29946 .56014 L
.30067 .56037 L
.30198 .56047 L
.30265 .56047 L
.30336 .56042 L
.30465 .56022 L
.30587 .55991 L
.30721 .55943 L
.30994 .55807 L
.31246 .55637 L
.31483 .55443 L
.3259 .5418 L
.34603 .51051 L
.38473 .4531 L
.42589 .40497 L
.44644 .38361 L
.46554 .36716 L
.48398 .35505 L
.50367 .34573 L
.51392 .34201 L
.52503 .33863 L
.54518 .33383 L
.56508 .33036 L
.5751 .329 L
.58612 .32778 L
.59611 .32689 L
.60559 .32622 L
.61651 .32564 L
.62174 .32542 L
.62648 .32526 L
.63111 .32513 L
.6361 .32502 L
.63886 .32497 L
.64138 .32493 L
.64395 .32489 L
.64634 .32487 L
.64858 .32485 L
.65062 .32483 L
.6517 .32483 L
Mistroke
.65288 .32482 L
.65412 .32482 L
.6553 .32482 L
.65644 .32481 L
.65769 .32481 L
.65899 .32482 L
.66021 .32482 L
.66135 .32482 L
.6624 .32482 L
.66475 .32483 L
.66725 .32485 L
.66951 .32487 L
.67459 .32492 L
.68372 .32505 L
.69439 .32527 L
.70444 .32551 L
.74298 .32675 L
.78397 .32832 L
.82345 .32986 L
.86141 .33124 L
.90182 .33255 L
.94072 .33367 L
.97619 .33458 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.02605 .04957 L
.02846 .08218 L
.02962 .09529 L
.03072 .10566 L
.0317 .11311 L
.03279 .11935 L
.03398 .12394 L
.03524 .1265 L
.03641 .12713 L
.0375 .12651 L
.03879 .12465 L
.03997 .12218 L
.04262 .115 L
.0529 .08398 L
.06244 .062 L
.06744 .05348 L
.07277 .04626 L
.07869 .04006 L
.08405 .03574 L
.08912 .03255 L
.09462 .02987 L
.09981 .02792 L
.10458 .02651 L
.10928 .02542 L
.11432 .0245 L
.11907 .02382 L
.1234 .02333 L
.12849 .02288 L
.13402 .02252 L
.13655 .02239 L
.13924 .02228 L
.14407 .02212 L
.14645 .02206 L
.14896 .02202 L
.1511 .02199 L
.15231 .02197 L
.15344 .02197 L
.15475 .02196 L
.156 .02196 L
.15711 .02196 L
.15832 .02196 L
.15964 .02197 L
.1603 .02198 L
.16104 .02199 L
.16354 .02202 L
.16592 .02207 L
.16809 .02212 L
.17298 .02226 L
.17537 .02233 L
Mistroke
.17762 .02239 L
.17981 .02243 L
.18077 .02245 L
.18182 .02246 L
.18294 .02248 L
.18412 .02248 L
.1854 .02249 L
.1866 .02249 L
.18789 .02248 L
.18906 .02248 L
.18971 .02247 L
.19041 .02246 L
.19169 .02245 L
.19645 .02236 L
.20084 .02226 L
.21154 .02199 L
.22158 .02176 L
.23058 .02161 L
.23565 .02154 L
.24028 .0215 L
.24508 .02146 L
.25033 .02143 L
.25298 .02142 L
.25581 .02141 L
.25718 .02141 L
.25848 .0214 L
.25964 .0214 L
.2609 .0214 L
.26215 .0214 L
.2633 .0214 L
.26445 .0214 L
.26554 .0214 L
.26681 .0214 L
.26799 .0214 L
.26927 .0214 L
.26993 .0214 L
.27064 .0214 L
.27596 .0214 L
.27839 .02141 L
.28095 .02141 L
.28316 .02141 L
.28433 .02141 L
.28558 .02141 L
.28674 .02141 L
.28778 .02141 L
.28884 .02141 L
.28983 .02141 L
.29099 .02141 L
.29222 .02141 L
.29327 .02141 L
Mistroke
.29443 .02141 L
.297 .02141 L
.29942 .0214 L
.30438 .02139 L
.30981 .02138 L
.31968 .02135 L
.33821 .02129 L
.34854 .02126 L
.3579 .02125 L
.3687 .02123 L
.37887 .02122 L
.39897 .02121 L
.41744 .0212 L
.43788 .02119 L
.45695 .02118 L
.47529 .02118 L
.49494 .02117 L
.5162 .02117 L
.53632 .02117 L
.57467 .02117 L
.59446 .02117 L
.61548 .02116 L
.65325 .02116 L
.69347 .02116 L
.73218 .02116 L
.77334 .02116 L
.81298 .02116 L
.85111 .02116 L
.89169 .02116 L
.93075 .02116 L
.97227 .02116 L
.97619 .02116 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.02846 .08439 L
.03279 .13867 L
.03754 .18535 L
.04018 .2055 L
.04262 .22058 L
.04518 .23301 L
.0465 .23815 L
.04795 .24287 L
.04913 .24601 L
.0504 .24876 L
.05174 .25098 L
.053 .25248 L
.05421 .25343 L
.05553 .25397 L
.05677 .25402 L
.05793 .25373 L
.05908 .25313 L
.06012 .25235 L
.06244 .24989 L
.06508 .24613 L
.06787 .24132 L
.07287 .2314 L
.08414 .20775 L
.09401 .18981 L
.09944 .18172 L
.10458 .1753 L
.1095 .17025 L
.11485 .16592 L
.11721 .16438 L
.11972 .16298 L
.12188 .16197 L
.12422 .16108 L
.12656 .16039 L
.12759 .16015 L
.12871 .15994 L
.12978 .15979 L
.13077 .15968 L
.13181 .15962 L
.13293 .15959 L
.13418 .15963 L
.13488 .15968 L
.13552 .15974 L
.13671 .15991 L
.13797 .16015 L
.1391 .16044 L
.14015 .16076 L
.14255 .16172 L
.14514 .16315 L
.14753 .16489 L
Mistroke
.15016 .16736 L
.15296 .17079 L
.15563 .17505 L
.15814 .18019 L
.16043 .18607 L
.16284 .1938 L
.16748 .21377 L
.17175 .2371 L
.17679 .26516 L
.18138 .28542 L
.18372 .29283 L
.18495 .29588 L
.18626 .29849 L
.1874 .30025 L
.18866 .30166 L
.18981 .30247 L
.19088 .30286 L
.19213 .30287 L
.19344 .30242 L
.19456 .30169 L
.19578 .30055 L
.1971 .29897 L
.19851 .29693 L
.20105 .29245 L
.2194 .2478 L
.22967 .22462 L
.23507 .21452 L
.24079 .20558 L
.24579 .19919 L
.25128 .19363 L
.25628 .18973 L
.26095 .18688 L
.27138 .18221 L
.27652 .18042 L
.28128 .179 L
.2855 .17795 L
.29016 .17706 L
.29257 .17671 L
.29484 .17645 L
.29724 .17626 L
.29859 .17618 L
.29983 .17612 L
.3011 .17609 L
.3023 .17607 L
.30338 .17606 L
.30456 .17607 L
.30583 .1761 L
.30648 .17611 L
.30719 .17614 L
.30961 .17625 L
Mistroke
.31188 .17639 L
.31432 .17657 L
.31873 .17696 L
.33942 .1795 L
.34953 .18121 L
.36057 .18378 L
.37099 .18717 L
.38066 .1913 L
.4012 .20298 L
.41981 .21552 L
.4599 .24158 L
.49847 .26377 L
.53949 .28445 L
.579 .29991 L
.61699 .31066 L
.63652 .31476 L
.65744 .31815 L
.66762 .31946 L
.67869 .32065 L
.68826 .32149 L
.69882 .32222 L
.70903 .32277 L
.71861 .32313 L
.72388 .32328 L
.72872 .32338 L
.73126 .32342 L
.73403 .32346 L
.73543 .32347 L
.73693 .32349 L
.73821 .32349 L
.73889 .3235 L
.73962 .3235 L
.74032 .3235 L
.74096 .32351 L
.74221 .32351 L
.74288 .32351 L
.74362 .32351 L
.74431 .32351 L
.74495 .32351 L
.7462 .32351 L
.74734 .3235 L
.74864 .3235 L
.74987 .32349 L
.75266 .32347 L
.75521 .32344 L
.76098 .32335 L
.76566 .32325 L
.77079 .32313 L
.78114 .3228 L
.8007 .32196 L
Mistroke
.82163 .3208 L
.86307 .3179 L
.90298 .31466 L
.94138 .31136 L
.97619 .30835 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.02499 .0325 L
.02605 .04466 L
.02729 .05265 L
.02846 .05574 L
.02954 .05644 L
.03053 .05611 L
.03163 .05518 L
.03279 .05383 L
.04262 .04078 L
.05205 .03168 L
.05742 .02802 L
.06244 .02535 L
.06788 .02311 L
.07305 .02148 L
.07768 .02034 L
.08274 .01935 L
.08822 .01854 L
.09407 .01789 L
.09958 .01743 L
.10458 .01711 L
.10945 .01686 L
.1146 .01666 L
.119 .01653 L
.12383 .01642 L
.12902 .01632 L
.13459 .01625 L
.13985 .0162 L
.14465 .01616 L
.14945 .01613 L
.15188 .01612 L
.15456 .01611 L
.15684 .01611 L
.15929 .0161 L
.16042 .0161 L
.16161 .0161 L
.1627 .0161 L
.16373 .0161 L
.16503 .0161 L
.16621 .0161 L
.16749 .0161 L
.16821 .0161 L
.16887 .0161 L
.16997 .0161 L
.17119 .0161 L
.17365 .0161 L
.17503 .0161 L
.17635 .0161 L
.17707 .0161 L
.17786 .0161 L
Mistroke
.17858 .0161 L
.17925 .0161 L
.17994 .0161 L
.18058 .0161 L
.18179 .0161 L
.18309 .0161 L
.18449 .0161 L
.18687 .01609 L
.18942 .01609 L
.19402 .01608 L
.20447 .01607 L
.21542 .01605 L
.22555 .01603 L
.2305 .01603 L
.23575 .01602 L
.24102 .01602 L
.24402 .01602 L
.24683 .01602 L
.24929 .01602 L
.25189 .01602 L
.2541 .01602 L
.25536 .01602 L
.25652 .01602 L
.25718 .01602 L
.25789 .01602 L
.25917 .01602 L
.26042 .01602 L
.26157 .01602 L
.26282 .01602 L
.26353 .01602 L
.26419 .01602 L
.26553 .01602 L
.26696 .01602 L
.27712 .01602 L
.28248 .01602 L
.28518 .01602 L
.28673 .01602 L
.28818 .01602 L
.28945 .01602 L
.29009 .01602 L
.29079 .01602 L
.29204 .01602 L
.2932 .01602 L
.2939 .01602 L
.29457 .01602 L
.29582 .01602 L
.29716 .01602 L
.29862 .01602 L
.30106 .01602 L
.30365 .01602 L
Mistroke
.30829 .01602 L
.32806 .01601 L
.34614 .01601 L
.3561 .01601 L
.36557 .01601 L
.37556 .01601 L
.38645 .016 L
.40614 .016 L
.42712 .016 L
.44854 .016 L
.46872 .016 L
.48881 .016 L
.50729 .016 L
.52773 .016 L
.5468 .016 L
.58479 .016 L
.60516 .016 L
.62372 .016 L
.66358 .016 L
.70193 .016 L
.74273 .016 L
.78202 .016 L
.81979 .016 L
.86001 .016 L
.89872 .016 L
.93988 .016 L
.97619 .016 L
Mfstroke
0 .206 1 r
.02381 .01472 m
.02846 .08442 L
.03279 .13905 L
.03754 .1866 L
.04018 .20729 L
.04262 .22277 L
.04518 .23537 L
.0465 .24049 L
.04795 .24507 L
.04922 .24821 L
.0504 .25047 L
.05165 .25218 L
.05236 .25285 L
.053 .2533 L
.0542 .25371 L
.05531 .25363 L
.05654 .25309 L
.05784 .25202 L
.05908 .25059 L
.06026 .2489 L
.06244 .24501 L
.08439 .18809 L
.09401 .1669 L
.09911 .15784 L
.10458 .14974 L
.10965 .14363 L
.11427 .13913 L
.11892 .13555 L
.12333 .13296 L
.12572 .13186 L
.12825 .13093 L
.13042 .13033 L
.13165 .13006 L
.13281 .12985 L
.13407 .12969 L
.13471 .12963 L
.1354 .12958 L
.13663 .12955 L
.13778 .12956 L
.13847 .1296 L
.13913 .12965 L
.14037 .1298 L
.14106 .12992 L
.14169 .13004 L
.14313 .13039 L
.14557 .13123 L
.1478 .13229 L
.15038 .13395 L
.15282 .13603 L
.15508 .13849 L
Mistroke
.15716 .14136 L
.15945 .14531 L
.16189 .15069 L
.16458 .15834 L
.16747 .169 L
.17273 .19407 L
.1778 .22017 L
.18028 .23132 L
.18253 .23991 L
.1849 .24709 L
.18714 .25211 L
.18836 .25415 L
.1895 .2556 L
.19074 .25674 L
.19206 .25745 L
.1933 .25769 L
.19399 .25766 L
.19463 .25752 L
.1958 .25704 L
.19703 .25622 L
.19839 .25498 L
.19965 .25355 L
.20251 .24948 L
.21336 .2282 L
.22359 .20752 L
.22837 .1994 L
.23343 .19246 L
.23607 .18965 L
.23748 .18842 L
.23898 .18731 L
.24036 .18651 L
.24162 .18598 L
.24289 .18565 L
.24409 .18555 L
.24515 .18565 L
.24633 .18598 L
.24756 .18662 L
.24871 .18751 L
.24978 .18863 L
.25077 .18993 L
.25299 .19396 L
.25416 .19679 L
.25525 .19992 L
.25771 .20901 L
.26012 .2208 L
.26269 .23668 L
.27234 .31569 L
.28257 .39357 L
.28792 .42259 L
.29095 .43521 L
Mistroke
.2938 .44455 L
.2964 .45109 L
.29879 .45546 L
.3001 .45724 L
.3008 .458 L
.30154 .45868 L
.30225 .45921 L
.30289 .45959 L
.30415 .46003 L
.30535 .46013 L
.30666 .45986 L
.30732 .45959 L
.30803 .4592 L
.3093 .45823 L
.31058 .45695 L
.31178 .45545 L
.31404 .45195 L
.31916 .44104 L
.32473 .42549 L
.3441 .35934 L
.36389 .30168 L
.37388 .28069 L
.3849 .26287 L
.40427 .24022 L
.42513 .22193 L
.44479 .20804 L
.45519 .20197 L
.46629 .19649 L
.47705 .19212 L
.48683 .18886 L
.50593 .18408 L
.51592 .18221 L
.52513 .18077 L
.54593 .17824 L
.56471 .17659 L
.5755 .17587 L
.58536 .17532 L
.59467 .1749 L
.60482 .17454 L
.61038 .17438 L
.61554 .17426 L
.62572 .17407 L
.63081 .174 L
.63632 .17394 L
.63885 .17392 L
.64152 .1739 L
.64383 .17389 L
.64629 .17388 L
.64753 .17387 L
.6487 .17387 L
Mistroke
.64984 .17387 L
.65089 .17387 L
.65189 .17387 L
.65295 .17386 L
.65401 .17386 L
.65518 .17386 L
.65644 .17386 L
.6576 .17387 L
.65824 .17387 L
.65894 .17387 L
.66021 .17387 L
.66265 .17388 L
.66492 .17389 L
.66999 .17391 L
.67548 .17395 L
.68543 .17404 L
.70403 .17428 L
.74503 .17504 L
.7845 .17592 L
.82246 .1768 L
.86287 .17769 L
.90177 .17849 L
.94312 .17927 L
.97619 .17983 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13924 L
.03754 .18779 L
.04262 .22671 L
.04518 .24146 L
.04795 .25405 L
.04923 .25869 L
.05058 .26287 L
.05174 .26591 L
.053 .2686 L
.05421 .27067 L
.05532 .27213 L
.05643 .2732 L
.05749 .27387 L
.05872 .27425 L
.05986 .27426 L
.06111 .27391 L
.06181 .27356 L
.06244 .27315 L
.0637 .27212 L
.06508 .27066 L
.06787 .26686 L
.07287 .25794 L
.08414 .23396 L
.09483 .21289 L
.10458 .19789 L
.10938 .19216 L
.1146 .18715 L
.11953 .18355 L
.12409 .18117 L
.12658 .18026 L
.12771 .17993 L
.12891 .17964 L
.12955 .17952 L
.13025 .1794 L
.13147 .17925 L
.13216 .17919 L
.1329 .17916 L
.1336 .17915 L
.13423 .17916 L
.1349 .1792 L
.13561 .17926 L
.13689 .17943 L
.1376 .17957 L
.13826 .17972 L
.13977 .18015 L
.14109 .18064 L
.14229 .18118 L
.145 .18277 L
Mistroke
.14751 .18475 L
.14979 .18706 L
.15241 .19047 L
.15488 .19457 L
.15927 .20478 L
.16175 .2127 L
.16403 .2217 L
.17476 .28335 L
.18 .31278 L
.18228 .32303 L
.18476 .33204 L
.18595 .33554 L
.1872 .33869 L
.18836 .34113 L
.18945 .34299 L
.19046 .34439 L
.19155 .34552 L
.19276 .34637 L
.19387 .34678 L
.19505 .34686 L
.19615 .34663 L
.19735 .34606 L
.19863 .34512 L
.19998 .34379 L
.20125 .34226 L
.20363 .33875 L
.21368 .31839 L
.21917 .30619 L
.2243 .29566 L
.2293 .28706 L
.23148 .284 L
.23386 .28128 L
.23521 .28005 L
.23646 .27914 L
.23765 .2785 L
.23892 .27808 L
.23956 .27798 L
.24026 .27797 L
.24151 .27821 L
.24223 .27851 L
.24299 .27897 L
.24364 .27949 L
.24436 .28019 L
.2456 .2818 L
.24678 .28382 L
.24898 .28909 L
.25021 .293 L
.25135 .2973 L
.25392 .30961 L
.25824 .33801 L
Mistroke
.26282 .37442 L
.27224 .44548 L
.27753 .47645 L
.28237 .49862 L
.28686 .51449 L
.28923 .52124 L
.29176 .52733 L
.29419 .53218 L
.29639 .53582 L
.29861 .53881 L
.30068 .54104 L
.30301 .54294 L
.30424 .54372 L
.30556 .54438 L
.30622 .54464 L
.30694 .54489 L
.30826 .54522 L
.30953 .5454 L
.31071 .54546 L
.31181 .54541 L
.31284 .5453 L
.31397 .54509 L
.31519 .54477 L
.31767 .54387 L
.31994 .54278 L
.32479 .53976 L
.33009 .53572 L
.34076 .52678 L
.35086 .51904 L
.36039 .51328 L
.37137 .5084 L
.38135 .50487 L
.39968 .4979 L
.41009 .49269 L
.41983 .48688 L
.43972 .47331 L
.46077 .45925 L
.47936 .44903 L
.49961 .44057 L
.5208 .43397 L
.54091 .42911 L
.56064 .42538 L
.58163 .42244 L
.59195 .42137 L
.6031 .42046 L
.61362 .41981 L
.62328 .41937 L
.628 .41921 L
.63305 .41907 L
.63782 .41896 L
Mistroke
.64216 .41889 L
.64481 .41885 L
.64726 .41883 L
.64994 .41881 L
.6513 .4188 L
.65206 .4188 L
.65279 .4188 L
.6541 .41879 L
.65529 .41879 L
.65658 .41879 L
.6573 .41879 L
.65798 .41879 L
.65921 .41879 L
.66033 .4188 L
.66162 .4188 L
.66284 .41881 L
.66525 .41882 L
.66749 .41884 L
.6726 .4189 L
.67758 .41898 L
.68291 .41907 L
.70138 .41954 L
.72261 .42028 L
.74273 .42111 L
.78105 .42287 L
.82182 .42478 L
.86107 .42653 L
.89881 .42806 L
.939 .42951 L
.97619 .43071 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13925 L
.03793 .19145 L
.04262 .22732 L
.04498 .24153 L
.04754 .25423 L
.04976 .2631 L
.0522 .2708 L
.05478 .27681 L
.0562 .27926 L
.05753 .28106 L
.05876 .28233 L
.0599 .28318 L
.0612 .28382 L
.06244 .28411 L
.0631 .28414 L
.06381 .2841 L
.0651 .2838 L
.06635 .28327 L
.0675 .2826 L
.07012 .28049 L
.07289 .27756 L
.08259 .2641 L
.0932 .24848 L
.09905 .2409 L
.10458 .23477 L
.1095 .23027 L
.11485 .22645 L
.11721 .22513 L
.11972 .22397 L
.12186 .22319 L
.12422 .22254 L
.12537 .22231 L
.12659 .22213 L
.12763 .22203 L
.12877 .22197 L
.13 .22198 L
.13131 .22206 L
.13255 .22222 L
.13367 .22243 L
.13481 .2227 L
.13587 .22302 L
.13824 .22397 L
.14033 .2251 L
.14255 .22662 L
.14508 .22883 L
.14748 .23147 L
.15199 .23823 L
.1545 .24333 L
Mistroke
.15684 .24915 L
.15956 .25758 L
.16213 .2674 L
.16678 .29038 L
.171 .31545 L
.17588 .34439 L
.18044 .36642 L
.18269 .37476 L
.18511 .38169 L
.18649 .38471 L
.18779 .38698 L
.18896 .38854 L
.19023 .38975 L
.19147 .39047 L
.19217 .39068 L
.19283 .39075 L
.19353 .39071 L
.19416 .39056 L
.19486 .39028 L
.1956 .38986 L
.19683 .38891 L
.19797 .38774 L
.20056 .38423 L
.20525 .37547 L
.2095 .36579 L
.21904 .34213 L
.22839 .32108 L
.23349 .31177 L
.23826 .30494 L
.24076 .3022 L
.24343 .29996 L
.24416 .29949 L
.24495 .29905 L
.24565 .29872 L
.24639 .29844 L
.24706 .29825 L
.2478 .29812 L
.2491 .29806 L
.25039 .29826 L
.25157 .29867 L
.25287 .29941 L
.25353 .29989 L
.25424 .30052 L
.25545 .30182 L
.25675 .30355 L
.25908 .30767 L
.26166 .31387 L
.26439 .32249 L
.2693 .34331 L
.2804 .40635 L
Mistroke
.2901 .45905 L
.29546 .48238 L
.30054 .50045 L
.30543 .51439 L
.31075 .52632 L
.3156 .53477 L
.32009 .54099 L
.32895 .55009 L
.3384 .55711 L
.35839 .56893 L
.3689 .57433 L
.38 .57912 L
.38996 .5824 L
.39561 .58383 L
.40088 .5849 L
.40564 .58567 L
.41015 .58624 L
.41535 .58675 L
.42009 .58709 L
.42468 .58733 L
.42729 .58743 L
.42975 .58751 L
.43469 .58763 L
.43746 .58768 L
.44001 .58771 L
.4443 .58776 L
.44899 .58779 L
.45843 .58784 L
.46938 .58789 L
.4797 .58794 L
.48421 .58796 L
.48897 .58798 L
.49146 .58799 L
.49278 .58799 L
.4942 .588 L
.4955 .588 L
.49669 .588 L
.49788 .588 L
.49902 .588 L
.50029 .588 L
.50148 .588 L
.50256 .588 L
.50372 .588 L
.50499 .588 L
.50632 .58799 L
.50872 .58799 L
.51094 .58798 L
.51301 .58797 L
.51771 .58794 L
.52286 .5879 L
Mistroke
.52755 .58786 L
.53808 .58774 L
.578 .58716 L
.6164 .58658 L
.65725 .58595 L
.69659 .58534 L
.73442 .58475 L
.77469 .58411 L
.81345 .58349 L
.85466 .58282 L
.89436 .58215 L
.93254 .5815 L
.97317 .5808 L
.97619 .58075 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.02846 .08399 L
.03068 .11166 L
.03279 .13307 L
.03398 .14285 L
.03527 .1514 L
.03645 .15731 L
.03754 .16124 L
.03871 .16393 L
.04 .16523 L
.04065 .1653 L
.04135 .16499 L
.04262 .16353 L
.04393 .16101 L
.04516 .15796 L
.04793 .14938 L
.05297 .13127 L
.06244 .09953 L
.06795 .08475 L
.07314 .07336 L
.08284 .05763 L
.08828 .05132 L
.09328 .04673 L
.09878 .04277 L
.10458 .03955 L
.10954 .03743 L
.11406 .0359 L
.11928 .03451 L
.12422 .03351 L
.12878 .03279 L
.133 .03229 L
.13763 .03188 L
.13997 .03172 L
.14255 .03159 L
.1449 .0315 L
.14623 .03146 L
.14747 .03144 L
.14878 .03142 L
.14997 .03142 L
.15063 .03142 L
.15135 .03142 L
.15264 .03143 L
.15376 .03145 L
.15498 .03149 L
.15626 .03153 L
.15746 .03159 L
.1596 .03171 L
.1619 .03189 L
.16457 .03215 L
.16749 .03252 L
Mistroke
.1728 .03336 L
.17758 .0341 L
.18028 .03444 L
.18156 .03456 L
.18275 .03466 L
.18399 .03473 L
.18465 .03476 L
.18535 .03479 L
.18608 .03481 L
.18678 .03483 L
.18808 .03483 L
.18933 .03482 L
.19049 .03479 L
.19176 .03475 L
.1931 .03468 L
.1954 .03454 L
.19755 .03437 L
.20247 .03391 L
.2127 .03284 L
.22345 .03185 L
.23312 .03119 L
.23859 .03091 L
.24367 .03071 L
.24837 .03056 L
.25263 .03046 L
.255 .03042 L
.25755 .03038 L
.25998 .03035 L
.26219 .03033 L
.26456 .03032 L
.2671 .0303 L
.26945 .03029 L
.27168 .03029 L
.27709 .03027 L
.27948 .03027 L
.28211 .03026 L
.28463 .03025 L
.28699 .03024 L
.29219 .03021 L
.29747 .03016 L
.30316 .0301 L
.32279 .02985 L
.33317 .02973 L
.34427 .02963 L
.35501 .02956 L
.36477 .02952 L
.37459 .02948 L
.38386 .02946 L
.39357 .02945 L
.40385 .02943 L
Mistroke
.4223 .02941 L
.43172 .0294 L
.44185 .0294 L
.45141 .02939 L
.46015 .02939 L
.46492 .02939 L
.47001 .02939 L
.4744 .02939 L
.47915 .02939 L
.48207 .02939 L
.48475 .02939 L
.48727 .02939 L
.49003 .02939 L
.49234 .02939 L
.49482 .02939 L
.49619 .02939 L
.49744 .02939 L
.4987 .02939 L
.49988 .02939 L
.50098 .02939 L
.50217 .02939 L
.50349 .02939 L
.50469 .02939 L
.50588 .02939 L
.50718 .02939 L
.50784 .02939 L
.50854 .02939 L
.5098 .02939 L
.51228 .02939 L
.51461 .02939 L
.51898 .02939 L
.52895 .02939 L
.53975 .02939 L
.58068 .02939 L
.62011 .02939 L
.63992 .02939 L
.65801 .0294 L
.67748 .0294 L
.6882 .0294 L
.69837 .0294 L
.708 .0294 L
.71337 .0294 L
.71591 .0294 L
.71823 .0294 L
.72041 .0294 L
.7228 .0294 L
.72519 .0294 L
.7265 .0294 L
.72772 .0294 L
.72888 .0294 L
Mistroke
.72998 .0294 L
.73096 .0294 L
.73203 .0294 L
.73319 .0294 L
.73443 .0294 L
.73548 .0294 L
.73664 .0294 L
.73912 .0294 L
.74183 .0294 L
.74677 .0294 L
.75158 .0294 L
.75604 .0294 L
.76614 .0294 L
.77691 .0294 L
.79832 .0294 L
.81848 .0294 L
.85702 .02939 L
.89801 .02939 L
.93749 .02939 L
.97545 .02939 L
.97619 .02939 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.02605 .04952 L
.02846 .08167 L
.02962 .09438 L
.03072 .10434 L
.03171 .1115 L
.03279 .1174 L
.03397 .12182 L
.03527 .12448 L
.03592 .12508 L
.03663 .12526 L
.0379 .12456 L
.03916 .12285 L
.04036 .12056 L
.04262 .11511 L
.05221 .08818 L
.06244 .06513 L
.06792 .05601 L
.07289 .04939 L
.08259 .04 L
.08803 .03629 L
.09391 .03321 L
.09947 .031 L
.10458 .02942 L
.10928 .02827 L
.11432 .02731 L
.11907 .0266 L
.1234 .02609 L
.12849 .02563 L
.13117 .02544 L
.13402 .02526 L
.1365 .02514 L
.13924 .02502 L
.14174 .02494 L
.14407 .02488 L
.14642 .02483 L
.14766 .02482 L
.14835 .02481 L
.14898 .0248 L
.14965 .0248 L
.15038 .0248 L
.1517 .02479 L
.15289 .0248 L
.15416 .0248 L
.15526 .02482 L
.15644 .02483 L
.15755 .02485 L
.15857 .02487 L
.16105 .02495 L
.16341 .02504 L
Mistroke
.16859 .02533 L
.17339 .02567 L
.17862 .02603 L
.18005 .02611 L
.18157 .02618 L
.18287 .02623 L
.18427 .02627 L
.18497 .02629 L
.18564 .0263 L
.18689 .02632 L
.18805 .02633 L
.18932 .02633 L
.18999 .02632 L
.19072 .02632 L
.19149 .02631 L
.1922 .0263 L
.19349 .02627 L
.19487 .02624 L
.20007 .02606 L
.20483 .02586 L
.21384 .02545 L
.22345 .02507 L
.22861 .0249 L
.23328 .02478 L
.23798 .02468 L
.24241 .02461 L
.24493 .02458 L
.24631 .02457 L
.24759 .02456 L
.24869 .02455 L
.24986 .02455 L
.25117 .02454 L
.25236 .02454 L
.25303 .02455 L
.25373 .02455 L
.25501 .02455 L
.25571 .02456 L
.25638 .02456 L
.25789 .02457 L
.2592 .02459 L
.26041 .02461 L
.26313 .02465 L
.27304 .02494 L
.27848 .02513 L
.28363 .02531 L
.28843 .02544 L
.29113 .0255 L
.29363 .02554 L
.29573 .02557 L
.29692 .02558 L
Mistroke
.29804 .02559 L
.29922 .02559 L
.3003 .02559 L
.30154 .02559 L
.30272 .02559 L
.30396 .02559 L
.30512 .02558 L
.30729 .02556 L
.30963 .02553 L
.31217 .0255 L
.32093 .02533 L
.3408 .02489 L
.36075 .02454 L
.3708 .02441 L
.38182 .02431 L
.39204 .02423 L
.40134 .02418 L
.42226 .0241 L
.44136 .02404 L
.46213 .024 L
.48192 .02397 L
.49191 .02396 L
.50293 .02395 L
.52229 .02394 L
.53318 .02393 L
.54315 .02393 L
.56209 .02392 L
.57282 .02392 L
.5828 .02392 L
.59333 .02392 L
.60327 .02392 L
.61219 .02391 L
.61719 .02391 L
.62186 .02391 L
.62682 .02391 L
.63134 .02391 L
.63636 .02391 L
.63916 .02391 L
.64175 .02391 L
.64426 .02391 L
.64692 .02391 L
.64845 .02391 L
.64988 .02391 L
.65117 .02391 L
.65189 .02391 L
.65255 .02391 L
.65379 .02391 L
.65493 .02391 L
.65619 .02391 L
.6569 .02391 L
Mistroke
.65754 .02391 L
.65884 .02391 L
.66025 .02391 L
.6628 .02391 L
.66515 .02391 L
.66767 .02391 L
.67224 .02391 L
.68263 .02391 L
.69361 .02391 L
.70366 .02391 L
.74335 .02392 L
.78153 .02392 L
.82217 .02392 L
.86128 .02393 L
.90285 .02393 L
.94291 .02393 L
.97619 .02393 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.02846 .08413 L
.03279 .13497 L
.03406 .14651 L
.03527 .15577 L
.03637 .16276 L
.03754 .1687 L
.0388 .1735 L
.03997 .17646 L
.04123 .17822 L
.04195 .17861 L
.04262 .17863 L
.04384 .17784 L
.04453 .17699 L
.04517 .17597 L
.04761 .17049 L
.05217 .15597 L
.06244 .12002 L
.06795 .10351 L
.07314 .09043 L
.08284 .07187 L
.08828 .06426 L
.09328 .05867 L
.09878 .0538 L
.10458 .04981 L
.10954 .04717 L
.11406 .04525 L
.11928 .04351 L
.12422 .04226 L
.12878 .04138 L
.133 .04077 L
.1352 .04053 L
.13763 .0403 L
.13885 .04021 L
.14017 .04013 L
.14139 .04006 L
.14255 .04001 L
.14381 .03997 L
.14495 .03995 L
.14618 .03994 L
.14687 .03993 L
.14751 .03994 L
.14858 .03995 L
.14975 .03998 L
.15098 .04002 L
.15212 .04007 L
.15348 .04016 L
.15476 .04025 L
.15717 .0405 L
.15976 .04086 L
Mistroke
.16259 .0414 L
.16538 .04208 L
.16789 .04285 L
.17354 .04493 L
.17848 .04668 L
.18097 .04736 L
.18238 .04766 L
.18369 .04788 L
.185 .04804 L
.18623 .04814 L
.18734 .0482 L
.18855 .04822 L
.18986 .04819 L
.19052 .04817 L
.19125 .04813 L
.19253 .04802 L
.19374 .0479 L
.19819 .04725 L
.20298 .04634 L
.21293 .04423 L
.22381 .04218 L
.22885 .0414 L
.23422 .04071 L
.23886 .04021 L
.24389 .03978 L
.24959 .0394 L
.2522 .03926 L
.25496 .03914 L
.25745 .03905 L
.26019 .03897 L
.265 .03886 L
.30539 .03808 L
.32401 .03762 L
.33453 .03742 L
.34427 .03728 L
.34916 .03723 L
.35455 .03718 L
.35981 .03715 L
.36549 .03711 L
.37089 .03709 L
.37586 .03708 L
.3806 .03706 L
.38317 .03706 L
.3856 .03706 L
.38799 .03705 L
.39059 .03705 L
.39295 .03705 L
.39513 .03705 L
.39634 .03705 L
.39748 .03705 L
Mistroke
.39873 .03705 L
.39943 .03705 L
.40007 .03705 L
.40136 .03705 L
.40209 .03705 L
.40276 .03705 L
.404 .03705 L
.40532 .03705 L
.40656 .03705 L
.4077 .03705 L
.41028 .03705 L
.41495 .03705 L
.42368 .03706 L
.44251 .03709 L
.46318 .03712 L
.50363 .03719 L
.54256 .03725 L
.58394 .03731 L
.6238 .03735 L
.66215 .03738 L
.68194 .03739 L
.69206 .0374 L
.70295 .0374 L
.71312 .0374 L
.72244 .03741 L
.73135 .03741 L
.74072 .03741 L
.74573 .03741 L
.75028 .03741 L
.7528 .03741 L
.75553 .03741 L
.75789 .03741 L
.76048 .03741 L
.76288 .03741 L
.76513 .03741 L
.76636 .03741 L
.7675 .03741 L
.7688 .03741 L
.77004 .03741 L
.7711 .03741 L
.77223 .03741 L
.77329 .03741 L
.77426 .03741 L
.7754 .03741 L
.77663 .03741 L
.77885 .03741 L
.78124 .03741 L
.78379 .03741 L
.78839 .03741 L
.79386 .03741 L
Mistroke
.79884 .03741 L
.81993 .03741 L
.83907 .0374 L
.85985 .0374 L
.9007 .03739 L
.94004 .03738 L
.97619 .03737 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.02846 .08443 L
.03279 .13935 L
.03793 .19209 L
.04262 .22909 L
.04498 .2441 L
.04754 .25784 L
.04976 .2677 L
.0522 .27658 L
.05478 .28389 L
.0561 .28686 L
.05753 .28953 L
.05885 .29155 L
.06007 .29303 L
.06129 .29419 L
.06244 .295 L
.0631 .29534 L
.06381 .29562 L
.0651 .2959 L
.06635 .29591 L
.0675 .29571 L
.06875 .29529 L
.06946 .29497 L
.07012 .29461 L
.07289 .29261 L
.07757 .28784 L
.08259 .28152 L
.09312 .26727 L
.09868 .26034 L
.10458 .25394 L
.10982 .24925 L
.11261 .24718 L
.11561 .24529 L
.11836 .24387 L
.12088 .24285 L
.12328 .24211 L
.1245 .24184 L
.12582 .24161 L
.12647 .24153 L
.12718 .24146 L
.12846 .2414 L
.12971 .24141 L
.13086 .24149 L
.1321 .24164 L
.13281 .24177 L
.13347 .24191 L
.13481 .24227 L
.13624 .24276 L
.13884 .24398 L
.14131 .24555 L
Mistroke
.14353 .24735 L
.14594 .2498 L
.1485 .25306 L
.15127 .25749 L
.15371 .26235 L
.15629 .26869 L
.16117 .28507 L
.16565 .30622 L
.17579 .36589 L
.17871 .3809 L
.18147 .39278 L
.18395 .40133 L
.18534 .40524 L
.18664 .40834 L
.189 .41261 L
.19025 .41421 L
.1909 .41486 L
.1916 .41544 L
.1923 .41588 L
.19294 .41619 L
.19362 .41639 L
.19435 .4165 L
.19567 .41637 L
.19687 .41594 L
.19808 .41522 L
.1992 .41431 L
.20173 .41153 L
.20632 .40441 L
.22466 .36673 L
.22935 .35847 L
.23193 .35461 L
.23438 .35152 L
.23666 .34922 L
.23786 .34825 L
.23913 .34742 L
.2402 .34691 L
.24138 .34654 L
.24245 .3464 L
.24346 .34645 L
.24467 .34676 L
.24599 .34744 L
.24665 .34793 L
.24736 .34856 L
.24864 .35003 L
.24992 .35193 L
.25113 .35416 L
.2534 .35959 L
.25607 .36826 L
.25854 .37851 L
.26412 .40837 L
Mistroke
.27392 .46809 L
.27932 .49685 L
.28445 .51945 L
.28921 .53636 L
.29439 .55088 L
.29911 .56109 L
.30349 .56847 L
.30844 .57487 L
.3131 .57941 L
.31729 .58255 L
.32182 .5852 L
.32676 .58746 L
.33199 .58935 L
.34134 .59207 L
.35083 .59441 L
.361 .59661 L
.37052 .59834 L
.37934 .59954 L
.38427 .60004 L
.38952 .60043 L
.39223 .60058 L
.39478 .60069 L
.39758 .60078 L
.39915 .60082 L
.39991 .60083 L
.40059 .60084 L
.40176 .60085 L
.40302 .60086 L
.40418 .60086 L
.40528 .60086 L
.40655 .60086 L
.40773 .60085 L
.40903 .60083 L
.4104 .60081 L
.41294 .60076 L
.41531 .6007 L
.42072 .60053 L
.43931 .59976 L
.45956 .59901 L
.47056 .5987 L
.48075 .59846 L
.50086 .59808 L
.54006 .59734 L
.56009 .597 L
.58171 .59669 L
.60264 .59646 L
.62185 .59629 L
.64233 .59614 L
.66141 .59604 L
.67979 .59596 L
Mistroke
.69946 .59589 L
.72075 .59584 L
.74089 .5958 L
.76085 .59578 L
.77929 .59576 L
.81863 .59573 L
.85645 .59571 L
.89673 .59568 L
.93549 .59565 L
.97619 .59561 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.02846 .08438 L
.03279 .13857 L
.03754 .18483 L
.0402 .2047 L
.04262 .2192 L
.04516 .231 L
.0475 .23906 L
.04873 .24228 L
.05008 .24511 L
.05076 .24626 L
.05149 .24731 L
.05281 .24873 L
.05404 .24955 L
.05474 .24981 L
.05539 .24992 L
.05658 .24985 L
.05784 .2494 L
.05908 .24861 L
.06026 .2476 L
.06244 .24508 L
.06757 .23687 L
.07299 .22622 L
.08269 .20628 L
.09325 .18738 L
.09907 .17896 L
.10458 .17237 L
.1095 .16758 L
.11485 .16349 L
.11721 .16205 L
.11972 .16074 L
.12188 .1598 L
.12422 .15898 L
.12536 .15866 L
.12656 .15836 L
.12768 .15814 L
.12871 .15797 L
.12969 .15785 L
.13073 .15776 L
.13188 .15771 L
.13293 .15771 L
.13417 .15777 L
.13531 .15788 L
.13656 .15806 L
.13788 .15833 L
.1401 .15897 L
.14137 .15944 L
.14255 .15997 L
.14514 .16141 L
.14753 .16316 L
Mistroke
.15016 .16564 L
.15296 .16907 L
.15563 .17332 L
.15814 .17845 L
.16043 .1843 L
.16284 .19198 L
.16748 .21182 L
.17175 .23489 L
.17679 .26238 L
.17917 .27343 L
.18138 .2819 L
.18372 .28887 L
.18495 .29169 L
.18626 .29405 L
.18739 .29559 L
.18846 .29661 L
.18962 .2973 L
.19088 .29756 L
.19212 .29736 L
.19282 .29707 L
.19347 .29668 L
.19478 .29557 L
.19619 .29398 L
.19874 .29014 L
.20105 .2858 L
.2194 .24134 L
.22874 .22111 L
.23862 .20477 L
.24379 .19839 L
.24946 .19302 L
.25195 .19116 L
.25461 .18948 L
.25943 .18717 L
.26199 .18627 L
.26471 .18554 L
.26703 .1851 L
.26835 .18491 L
.26959 .18478 L
.27024 .18474 L
.27094 .1847 L
.27168 .18468 L
.27236 .18468 L
.27359 .18471 L
.27491 .1848 L
.27565 .18488 L
.27646 .18499 L
.27792 .18524 L
.27934 .18557 L
.28065 .18594 L
.2853 .18779 L
Mistroke
.28794 .18922 L
.29041 .19078 L
.30076 .19921 L
.33955 .23226 L
.35928 .24838 L
.37044 .26062 L
.3808 .27457 L
.42053 .33719 L
.45968 .38343 L
.4811 .40166 L
.50128 .41581 L
.51967 .42637 L
.53985 .43551 L
.5598 .44234 L
.58087 .44764 L
.6004 .45115 L
.61134 .45262 L
.62132 .45369 L
.63124 .4545 L
.64042 .45505 L
.64521 .45527 L
.65049 .45545 L
.65314 .45552 L
.65601 .45559 L
.65871 .45563 L
.66118 .45566 L
.66246 .45567 L
.66367 .45568 L
.66475 .45568 L
.66593 .45568 L
.66721 .45568 L
.66786 .45568 L
.66857 .45568 L
.66982 .45567 L
.671 .45566 L
.67218 .45565 L
.6733 .45564 L
.6754 .45562 L
.68012 .45553 L
.68526 .45539 L
.69003 .45524 L
.70083 .45476 L
.71143 .45415 L
.7214 .45345 L
.74003 .45188 L
.77865 .44765 L
.81973 .4421 L
.85929 .43607 L
.89733 .42989 L
.93783 .42311 L
Mistroke
.97619 .41669 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.02846 .08438 L
.03279 .13837 L
.03754 .18355 L
.0402 .20214 L
.04262 .21496 L
.04385 .22007 L
.04516 .22449 L
.04627 .2275 L
.0475 .23004 L
.04882 .23192 L
.04957 .23263 L
.05024 .23306 L
.05156 .23336 L
.05281 .23305 L
.05397 .2323 L
.0552 .23106 L
.05636 .22952 L
.05742 .22785 L
.06244 .21724 L
.08269 .16466 L
.08823 .15286 L
.09409 .14231 L
.09915 .13473 L
.10458 .12804 L
.10975 .12293 L
.11446 .11923 L
.11919 .11633 L
.12368 .11427 L
.12621 .11339 L
.1289 .11267 L
.13119 .11223 L
.1325 .11204 L
.13372 .11192 L
.13436 .11187 L
.13506 .11183 L
.13579 .11181 L
.13646 .11181 L
.13768 .11183 L
.13898 .11192 L
.13971 .11199 L
.14051 .11209 L
.14195 .11233 L
.14335 .11264 L
.14465 .113 L
.14709 .11388 L
.14932 .11496 L
.1519 .1166 L
.15434 .11863 L
.15659 .121 L
Mistroke
.15868 .12376 L
.16097 .12754 L
.16341 .13264 L
.16609 .13977 L
.16899 .14936 L
.17424 .17 L
.17669 .1795 L
.17932 .18844 L
.18179 .19519 L
.18405 .19971 L
.18527 .2015 L
.1864 .20276 L
.18763 .20373 L
.18895 .2043 L
.19008 .20444 L
.19115 .2043 L
.19232 .20386 L
.19358 .2031 L
.19485 .20205 L
.19624 .20062 L
.19903 .19701 L
.20403 .18891 L
.21508 .16869 L
.2251 .15225 L
.23522 .1394 L
.24475 .13082 L
.24999 .12741 L
.25482 .12495 L
.26012 .12287 L
.26572 .12114 L
.28556 .11619 L
.29422 .1142 L
.30366 .11238 L
.30885 .11159 L
.31366 .11098 L
.31855 .11049 L
.32314 .11012 L
.32796 .10983 L
.33073 .1097 L
.33328 .10961 L
.3358 .10953 L
.33846 .10947 L
.33984 .10945 L
.34113 .10943 L
.34254 .10942 L
.34333 .10941 L
.34405 .10941 L
.34524 .1094 L
.34635 .1094 L
.34757 .10941 L
Mistroke
.34889 .10942 L
.34954 .10942 L
.35026 .10943 L
.35157 .10945 L
.35401 .10949 L
.35632 .10955 L
.35878 .10962 L
.36321 .10979 L
.36883 .11009 L
.37412 .11044 L
.384 .11129 L
.40409 .11375 L
.42257 .11651 L
.46208 .12242 L
.50007 .12747 L
.54051 .13223 L
.57944 .13589 L
.59927 .13737 L
.62082 .1387 L
.64153 .13971 L
.66069 .14043 L
.67937 .14093 L
.69 .14113 L
.69997 .14128 L
.70982 .14138 L
.71476 .14142 L
.7176 .14144 L
.72017 .14145 L
.7224 .14146 L
.72481 .14146 L
.72614 .14147 L
.72736 .14147 L
.72853 .14147 L
.72976 .14147 L
.73082 .14147 L
.73196 .14147 L
.73303 .14147 L
.73401 .14147 L
.73516 .14147 L
.73641 .14147 L
.73759 .14147 L
.73868 .14147 L
.74134 .14146 L
.74378 .14145 L
.74929 .14143 L
.75414 .1414 L
.75926 .14136 L
.77788 .14117 L
.79758 .14088 L
.81593 .14056 L
Mistroke
.85491 .13973 L
.89634 .13873 L
.93626 .13772 L
.97466 .13676 L
.97619 .13673 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.02846 .08412 L
.03279 .1351 L
.03527 .15634 L
.03754 .17011 L
.03879 .17551 L
.03945 .17774 L
.04015 .17968 L
.04143 .18214 L
.04262 .18326 L
.04384 .1834 L
.04496 .18273 L
.04626 .18115 L
.04749 .17898 L
.04967 .17391 L
.05205 .16713 L
.06244 .13334 L
.07302 .10399 L
.07893 .09133 L
.08429 .08201 L
.08931 .0749 L
.09474 .06869 L
.09983 .06404 L
.10458 .06055 L
.10955 .05763 L
.11408 .05551 L
.11912 .05366 L
.12452 .05217 L
.1297 .05115 L
.13263 .05074 L
.13534 .05044 L
.1377 .05025 L
.13904 .05017 L
.1403 .05012 L
.14095 .0501 L
.14163 .05008 L
.14284 .05007 L
.14415 .05007 L
.14489 .05008 L
.14558 .0501 L
.14686 .05015 L
.1475 .05018 L
.14821 .05023 L
.15063 .05043 L
.152 .05059 L
.15346 .0508 L
.15611 .05128 L
.15877 .05195 L
.1613 .05279 L
.16357 .05374 L
Mistroke
.16604 .05502 L
.17064 .05808 L
.17562 .06184 L
.1779 .0634 L
.18031 .06477 L
.18237 .06567 L
.18354 .06605 L
.18463 .06634 L
.18527 .06647 L
.18597 .06659 L
.18724 .06673 L
.18848 .06678 L
.18962 .06676 L
.19086 .06667 L
.19156 .06659 L
.19222 .0665 L
.19497 .06595 L
.19733 .06532 L
.19948 .06464 L
.20434 .06291 L
.21522 .05881 L
.22533 .05554 L
.2345 .05327 L
.23963 .05229 L
.24429 .05157 L
.24941 .05095 L
.25495 .05044 L
.26018 .05008 L
.265 .04984 L
.2854 .04903 L
.30446 .0482 L
.31385 .04784 L
.32276 .04757 L
.32768 .04745 L
.33303 .04735 L
.33753 .04728 L
.3424 .04722 L
.34492 .04719 L
.34724 .04717 L
.34959 .04715 L
.35178 .04714 L
.35419 .04713 L
.35547 .04713 L
.35683 .04712 L
.35752 .04712 L
.35826 .04712 L
.35892 .04712 L
.35961 .04712 L
.36093 .04712 L
.36215 .04712 L
Mistroke
.36345 .04712 L
.36463 .04712 L
.36529 .04712 L
.36601 .04712 L
.36731 .04712 L
.36982 .04713 L
.37214 .04714 L
.37747 .04717 L
.38315 .04721 L
.39344 .04732 L
.40457 .04747 L
.42475 .04778 L
.46577 .0484 L
.50528 .0489 L
.54327 .0493 L
.56443 .04949 L
.58372 .04963 L
.62264 .04985 L
.64174 .04993 L
.65162 .04996 L
.66251 .04999 L
.67203 .05001 L
.6823 .05003 L
.69314 .05005 L
.69841 .05005 L
.70331 .05006 L
.70833 .05006 L
.71289 .05006 L
.71532 .05006 L
.71796 .05007 L
.72074 .05007 L
.7221 .05007 L
.72337 .05007 L
.72459 .05007 L
.72591 .05007 L
.72666 .05007 L
.72737 .05007 L
.72801 .05007 L
.7287 .05007 L
.72945 .05007 L
.73012 .05007 L
.7309 .05007 L
.73163 .05007 L
.73294 .05007 L
.73435 .05007 L
.73692 .05007 L
.73963 .05007 L
.74447 .05006 L
.74945 .05006 L
.75398 .05006 L
Mistroke
.76416 .05005 L
.78252 .05003 L
.80165 .05 L
.82243 .04997 L
.86329 .04989 L
.90263 .0498 L
.94045 .04972 L
.97619 .04964 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.02605 .04944 L
.02729 .06652 L
.02846 .08056 L
.02954 .09133 L
.03072 .10026 L
.0318 .10587 L
.03279 .10912 L
.03396 .11096 L
.03506 .11113 L
.03626 .11004 L
.03756 .10784 L
.0402 .1015 L
.04262 .09479 L
.0529 .06808 L
.06244 .05059 L
.06744 .04396 L
.07277 .03839 L
.07869 .03365 L
.08405 .03037 L
.08912 .02796 L
.09462 .02595 L
.09981 .02449 L
.10458 .02344 L
.10928 .02262 L
.11432 .02193 L
.11907 .02143 L
.1234 .02107 L
.12849 .02074 L
.13402 .02047 L
.13924 .02029 L
.14176 .02022 L
.14407 .02016 L
.14628 .02012 L
.1487 .02009 L
.15113 .02006 L
.15246 .02005 L
.15369 .02004 L
.15487 .02003 L
.15598 .02003 L
.15698 .02003 L
.15806 .02003 L
.15924 .02003 L
.16049 .02003 L
.16156 .02004 L
.16273 .02005 L
.16541 .02007 L
.16786 .0201 L
.17338 .02019 L
.17582 .02023 L
Mistroke
.17848 .02026 L
.1797 .02027 L
.181 .02028 L
.18222 .02029 L
.18333 .02029 L
.18454 .0203 L
.18567 .0203 L
.1869 .0203 L
.18822 .02029 L
.18889 .02029 L
.18961 .02028 L
.19092 .02027 L
.19338 .02025 L
.19818 .02019 L
.20262 .02013 L
.21337 .01996 L
.22345 .01983 L
.23246 .01975 L
.23752 .01971 L
.24215 .01969 L
.24696 .01967 L
.24968 .01966 L
.2522 .01965 L
.25488 .01965 L
.25732 .01965 L
.25866 .01964 L
.26012 .01964 L
.2615 .01964 L
.26277 .01964 L
.26403 .01964 L
.26522 .01964 L
.26629 .01964 L
.26746 .01964 L
.26873 .01964 L
.26937 .01964 L
.27007 .01964 L
.27249 .01964 L
.27723 .01964 L
.2793 .01964 L
.2804 .01964 L
.28157 .01965 L
.28286 .01965 L
.28407 .01965 L
.28477 .01965 L
.28544 .01965 L
.28669 .01965 L
.28736 .01965 L
.28807 .01965 L
.28935 .01964 L
.29071 .01964 L
Mistroke
.29222 .01964 L
.29471 .01964 L
.29739 .01964 L
.30223 .01963 L
.32195 .01959 L
.33237 .01957 L
.34347 .01956 L
.35428 .01954 L
.36408 .01953 L
.37393 .01953 L
.3832 .01952 L
.40329 .01952 L
.42177 .01951 L
.44061 .01951 L
.45142 .0195 L
.46128 .0195 L
.4808 .0195 L
.49155 .0195 L
.50172 .0195 L
.54007 .0195 L
.55986 .0195 L
.58087 .0195 L
.61864 .0195 L
.65887 .01949 L
.69757 .01949 L
.73873 .01949 L
.77838 .01949 L
.81651 .01949 L
.85709 .01949 L
.89615 .01949 L
.93767 .01949 L
.97619 .01949 L
Mfstroke
.055 0 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .02139 L
.02729 .02138 L
.02846 .0212 L
.03053 .02076 L
.03279 .02024 L
.04262 .01831 L
.04762 .0176 L
.05293 .017 L
.05746 .0166 L
.06244 .01625 L
.06792 .01595 L
.07293 .01574 L
.07871 .01556 L
.0842 .01542 L
.08925 .01533 L
.09394 .01526 L
.09909 .01521 L
.10458 .01516 L
.10994 .01512 L
.11487 .0151 L
.12028 .01508 L
.12599 .01506 L
.13096 .01505 L
.13561 .01504 L
.1407 .01504 L
.14616 .01503 L
.14872 .01503 L
.15145 .01503 L
.15634 .01503 L
.15905 .01503 L
.1616 .01503 L
.16439 .01503 L
.16596 .01503 L
.1674 .01503 L
.17244 .01502 L
.17521 .01502 L
.17783 .01502 L
.18026 .01502 L
.18291 .01502 L
.18752 .01502 L
.20645 .01502 L
.2163 .01502 L
.22153 .01502 L
.22715 .01502 L
.23251 .01502 L
.23742 .01502 L
.23977 .01502 L
.24234 .01502 L
Mistroke
.24476 .01502 L
.24702 .01502 L
.24836 .01502 L
.2498 .01502 L
.251 .01502 L
.25231 .01502 L
.25305 .01502 L
.25374 .01502 L
.25447 .01502 L
.25525 .01502 L
.25597 .01502 L
.25666 .01502 L
.25794 .01502 L
.25917 .01502 L
.26046 .01502 L
.26157 .01502 L
.26279 .01502 L
.26807 .01502 L
.27752 .01502 L
.28267 .01502 L
.28517 .01502 L
.28745 .01502 L
.28997 .01502 L
.29135 .01502 L
.29266 .01502 L
.29335 .01502 L
.29408 .01502 L
.29539 .01502 L
.29612 .01502 L
.2968 .01502 L
.29754 .01502 L
.29835 .01502 L
.29963 .01502 L
.30102 .01502 L
.30356 .01502 L
.30603 .01502 L
.30832 .01502 L
.31793 .01502 L
.32696 .01502 L
.33699 .01502 L
.34756 .01502 L
.35718 .01502 L
.36771 .01501 L
.37729 .01501 L
.38621 .01501 L
.42522 .01501 L
.44654 .01501 L
.46669 .01501 L
.48668 .01501 L
.50512 .01501 L
Mistroke
.54449 .01501 L
.58235 .01501 L
.62266 .01501 L
.66145 .01501 L
.70269 .01501 L
.74242 .01501 L
.78063 .01501 L
.8213 .01501 L
.86045 .01501 L
.90205 .01501 L
.94214 .01501 L
.97619 .01501 L
Mfstroke
.079 0 1 r
.02381 .01472 m
.02499 .03249 L
.02605 .04454 L
.02729 .05224 L
.02846 .05503 L
.02954 .05552 L
.03053 .05506 L
.03163 .05403 L
.03279 .05263 L
.04262 .03975 L
.04716 .03505 L
.05205 .03096 L
.05742 .02744 L
.06244 .02489 L
.06784 .02277 L
.07373 .02102 L
.07929 .01978 L
.08445 .01891 L
.08956 .01824 L
.09419 .01776 L
.09954 .01734 L
.10458 .01703 L
.10923 .01681 L
.11434 .01662 L
.11968 .01647 L
.12466 .01637 L
.12932 .01629 L
.13357 .01623 L
.13848 .01618 L
.14313 .01615 L
.14772 .01612 L
.15278 .0161 L
.15533 .01609 L
.15667 .01609 L
.15807 .01608 L
.15931 .01608 L
.16066 .01608 L
.1619 .01608 L
.16304 .01608 L
.16419 .01608 L
.16544 .01608 L
.16662 .01608 L
.16771 .01608 L
.16869 .01608 L
.16977 .01608 L
.17195 .01608 L
.17432 .01608 L
.17562 .01608 L
.17686 .01608 L
.17801 .01608 L
Mistroke
.17926 .01608 L
.1804 .01608 L
.18146 .01608 L
.18275 .01608 L
.1834 .01608 L
.18411 .01608 L
.18538 .01608 L
.18655 .01608 L
.18921 .01608 L
.19205 .01607 L
.20202 .01606 L
.2117 .01604 L
.22064 .01602 L
.23084 .01601 L
.23622 .01601 L
.24192 .016 L
.24686 .016 L
.2515 .016 L
.25415 .016 L
.25658 .016 L
.26206 .016 L
.30173 .01599 L
.33989 .01599 L
.35001 .01599 L
.35954 .01599 L
.37053 .01599 L
.38051 .01598 L
.39025 .01598 L
.40056 .01598 L
.41902 .01598 L
.42849 .01598 L
.43864 .01598 L
.44822 .01598 L
.45696 .01598 L
.46176 .01598 L
.46686 .01598 L
.47127 .01598 L
.47602 .01598 L
.48111 .01598 L
.48588 .01598 L
.48865 .01598 L
.49156 .01598 L
.49424 .01598 L
.49678 .01598 L
.49917 .01598 L
.50177 .01598 L
.50291 .01598 L
.50413 .01598 L
.50526 .01598 L
.50631 .01598 L
Mistroke
.50751 .01598 L
.50881 .01598 L
.51001 .01598 L
.51115 .01598 L
.5118 .01598 L
.51248 .01598 L
.51371 .01598 L
.51446 .01598 L
.51517 .01598 L
.51649 .01598 L
.51873 .01598 L
.52109 .01598 L
.52531 .01598 L
.53485 .01598 L
.54434 .01598 L
.55451 .01598 L
.57284 .01598 L
.61423 .01598 L
.65409 .01598 L
.69244 .01598 L
.73324 .01598 L
.77253 .01598 L
.8103 .01598 L
.85052 .01598 L
.88923 .01598 L
.93039 .01598 L
.97003 .01598 L
.97619 .01598 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.02846 .08439 L
.03279 .1386 L
.03754 .1849 L
.0402 .20478 L
.04262 .21923 L
.04516 .23094 L
.0475 .23884 L
.04873 .24196 L
.05008 .24465 L
.05076 .24573 L
.05149 .2467 L
.05281 .24796 L
.05404 .24861 L
.05474 .24878 L
.05539 .24881 L
.05658 .24857 L
.05784 .24793 L
.05908 .24696 L
.06026 .24577 L
.06244 .24293 L
.08439 .19854 L
.09401 .18139 L
.09911 .17399 L
.10458 .16738 L
.10965 .16241 L
.11427 .15881 L
.11892 .15603 L
.12333 .15414 L
.12572 .15341 L
.12702 .1531 L
.12825 .15286 L
.1293 .15271 L
.13042 .15258 L
.13167 .1525 L
.13281 .15247 L
.13406 .15251 L
.13521 .15259 L
.13648 .15275 L
.13719 .15287 L
.13784 .153 L
.13914 .15331 L
.14056 .15375 L
.14313 .1548 L
.14549 .15611 L
.14802 .15795 L
.15041 .16017 L
.1526 .16271 L
.15515 .16644 L
.15794 .1717 L
Mistroke
.16057 .17814 L
.16301 .18571 L
.16836 .20852 L
.1732 .23447 L
.17848 .26082 L
.18114 .27101 L
.18266 .27566 L
.18405 .27912 L
.18534 .28166 L
.18656 .2835 L
.18785 .28485 L
.18858 .28536 L
.18925 .28568 L
.19037 .28589 L
.1916 .28569 L
.19289 .28504 L
.1941 .28406 L
.19523 .28284 L
.19642 .28128 L
.19855 .27788 L
.20333 .26808 L
.21341 .24343 L
.22417 .21884 L
.22951 .20872 L
.23454 .20068 L
.23944 .19429 L
.24395 .18962 L
.24824 .18627 L
.2504 .18497 L
.25277 .18383 L
.25516 .183 L
.25649 .18267 L
.25771 .18246 L
.25885 .18233 L
.26008 .18227 L
.26125 .18229 L
.26233 .18239 L
.2635 .18257 L
.26474 .18286 L
.2658 .18318 L
.26695 .18363 L
.26953 .18498 L
.27194 .18673 L
.27423 .18887 L
.2763 .19125 L
.28097 .19816 L
.28605 .20812 L
.29156 .22133 L
.30156 .24859 L
.34245 .33136 L
Mistroke
.38182 .40291 L
.40159 .43884 L
.41967 .4625 L
.42964 .47174 L
.4391 .47855 L
.44909 .4842 L
.45998 .48906 L
.47967 .49565 L
.49068 .49846 L
.50065 .50055 L
.51002 .50215 L
.51991 .50349 L
.52508 .50405 L
.53076 .50456 L
.53554 .50492 L
.54073 .50523 L
.54598 .50548 L
.55095 .50566 L
.5533 .50572 L
.55579 .50578 L
.55812 .50582 L
.56026 .50585 L
.56144 .50586 L
.56273 .50587 L
.56403 .50588 L
.56473 .50589 L
.56539 .50589 L
.56661 .50589 L
.56772 .50589 L
.569 .50589 L
.57021 .50589 L
.57084 .50589 L
.57154 .50588 L
.57295 .50587 L
.57547 .50585 L
.57842 .50581 L
.58118 .50576 L
.58616 .50566 L
.5916 .50551 L
.60148 .50517 L
.62002 .50428 L
.63975 .50303 L
.66074 .50141 L
.70239 .4975 L
.74253 .49306 L
.78116 .48834 L
.82223 .48296 L
.86179 .47751 L
.89983 .47211 L
.94033 .46627 L
Mistroke
.97619 .4611 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.02846 .08427 L
.03279 .13706 L
.03523 .16058 L
.03754 .17844 L
.03881 .18649 L
.0402 .19383 L
.04145 .19924 L
.04262 .20333 L
.04376 .20647 L
.045 .20896 L
.0457 .20999 L
.04637 .21073 L
.04762 .21153 L
.04894 .21162 L
.05016 .21109 L
.05086 .21055 L
.0515 .20992 L
.05293 .20808 L
.05528 .204 L
.05783 .19848 L
.06244 .18676 L
.07304 .15851 L
.08293 .13614 L
.09325 .11871 L
.09872 .11174 L
.10458 .10576 L
.10986 .10153 L
.11559 .098 L
.11822 .09671 L
.12101 .09555 L
.12343 .09472 L
.12603 .09398 L
.12853 .09342 L
.12962 .09322 L
.13082 .09304 L
.13188 .0929 L
.13301 .09279 L
.13421 .0927 L
.13532 .09265 L
.13601 .09263 L
.13665 .09262 L
.13735 .09263 L
.13809 .09265 L
.13933 .09271 L
.14004 .09277 L
.1407 .09283 L
.14193 .09298 L
.14305 .09316 L
.14558 .09371 L
Mistroke
.14809 .09448 L
.15036 .0954 L
.15299 .0968 L
.15545 .09853 L
.15775 .10057 L
.15985 .10292 L
.16461 .11045 L
.1671 .11591 L
.16942 .12194 L
.1747 .13746 L
.17734 .14475 L
.17984 .15051 L
.18122 .15309 L
.18272 .15537 L
.18408 .15697 L
.18534 .15805 L
.18653 .15873 L
.18777 .15913 L
.18883 .15922 L
.18999 .15909 L
.19125 .15869 L
.19195 .15836 L
.19259 .158 L
.195 .15619 L
.19723 .15399 L
.19965 .15118 L
.20405 .1454 L
.21387 .13184 L
.22466 .11905 L
.22963 .11433 L
.23496 .11011 L
.23956 .10713 L
.24458 .10453 L
.25023 .10232 L
.25283 .10154 L
.25559 .10084 L
.25807 .10032 L
.2608 .09985 L
.26563 .09922 L
.26798 .099 L
.27054 .09881 L
.27183 .09874 L
.27255 .09871 L
.27322 .09868 L
.27452 .09864 L
.27571 .09863 L
.27683 .09862 L
.27802 .09863 L
.27903 .09865 L
.28015 .09869 L
Mistroke
.28134 .09875 L
.28263 .09883 L
.28496 .09904 L
.28763 .09936 L
.29054 .09981 L
.29585 .10091 L
.3058 .10368 L
.32714 .11043 L
.34647 .11601 L
.35616 .11909 L
.36663 .12314 L
.38562 .13309 L
.42664 .1608 L
.44708 .17248 L
.46615 .1812 L
.48566 .1885 L
.50414 .19418 L
.52451 .19906 L
.54307 .20221 L
.55273 .20339 L
.56299 .20433 L
.57175 .20491 L
.57674 .20516 L
.58142 .20534 L
.58612 .20548 L
.58878 .20553 L
.59126 .20558 L
.59261 .20559 L
.59389 .20561 L
.59503 .20562 L
.59627 .20562 L
.59691 .20563 L
.59762 .20563 L
.59836 .20563 L
.59905 .20563 L
.60029 .20563 L
.60098 .20563 L
.60162 .20563 L
.60276 .20562 L
.60398 .20561 L
.60616 .20559 L
.60876 .20555 L
.61111 .20551 L
.61576 .20541 L
.62013 .20528 L
.62993 .2049 L
.64026 .20436 L
.65875 .20311 L
.69679 .19962 L
.73729 .19505 L
Mistroke
.77627 .19023 L
.8177 .18497 L
.85762 .17997 L
.89602 .17536 L
.93688 .17074 L
.97619 .16662 L
Mfstroke
.15 0 1 r
.02381 .01472 m
.02846 .08442 L
.03279 .13913 L
.03754 .18713 L
.04262 .22465 L
.04518 .23838 L
.04652 .2443 L
.04795 .24965 L
.0492 .25356 L
.05058 .25709 L
.05184 .25966 L
.053 .26148 L
.0542 .26286 L
.05535 .26371 L
.05656 .26418 L
.05788 .2642 L
.05902 .26385 L
.06025 .26313 L
.0614 .26215 L
.06244 .26103 L
.06508 .25739 L
.06787 .25254 L
.07287 .24218 L
.08414 .21668 L
.09401 .19698 L
.09944 .18804 L
.10458 .1809 L
.1095 .17527 L
.11485 .1704 L
.11972 .16706 L
.12204 .16582 L
.12422 .16485 L
.12642 .16407 L
.12844 .16353 L
.12954 .1633 L
.13069 .16312 L
.13184 .16299 L
.13311 .16292 L
.13435 .16292 L
.13547 .16297 L
.13677 .16311 L
.138 .16331 L
.13914 .16357 L
.14018 .16386 L
.14255 .16476 L
.14499 .16605 L
.14722 .1676 L
.1498 .16992 L
.15225 .17275 L
.15658 .17981 L
Mistroke
.15904 .18534 L
.16131 .19177 L
.16656 .21265 L
.17131 .2386 L
.17649 .26881 L
.17932 .28324 L
.18195 .29434 L
.18427 .30197 L
.18546 .3051 L
.18675 .30789 L
.18816 .31025 L
.18881 .3111 L
.1895 .31184 L
.1908 .31283 L
.192 .31327 L
.1931 .3133 L
.19427 .31298 L
.19538 .31236 L
.1964 .31154 L
.19753 .31038 L
.19876 .30883 L
.20124 .30494 L
.21204 .28119 L
.22207 .25776 L
.22714 .24763 L
.23262 .23874 L
.23514 .23551 L
.2378 .23279 L
.24007 .23108 L
.24136 .2304 L
.24257 .22996 L
.24372 .22975 L
.24498 .22976 L
.24616 .23003 L
.24726 .23052 L
.24825 .23118 L
.24934 .23219 L
.25047 .23357 L
.25154 .23521 L
.25272 .23743 L
.25396 .24032 L
.25617 .24701 L
.25856 .25671 L
.26117 .27048 L
.27208 .35375 L
.27745 .39658 L
.2824 .43113 L
.2868 .45692 L
.29165 .47997 L
.29653 .49802 L
Mistroke
.3017 .51236 L
.3043 .51798 L
.30677 .52247 L
.31141 .52898 L
.314 .5317 L
.3164 .53373 L
.31904 .53551 L
.32185 .53697 L
.3243 .53795 L
.32694 .53877 L
.33174 .53983 L
.34071 .54125 L
.35023 .54309 L
.35563 .54448 L
.36067 .54599 L
.37149 .54948 L
.37681 .55109 L
.38174 .55241 L
.38637 .55343 L
.39149 .55427 L
.39415 .55459 L
.39664 .5548 L
.39801 .55488 L
.39927 .55494 L
.39993 .55496 L
.40065 .55498 L
.4014 .55499 L
.4021 .555 L
.40326 .55499 L
.40452 .55497 L
.40571 .55493 L
.40681 .55488 L
.40888 .55475 L
.41108 .55456 L
.41564 .55403 L
.42066 .55323 L
.44013 .54883 L
.46102 .5436 L
.50232 .53576 L
.5421 .53024 L
.58037 .52613 L
.60009 .52463 L
.62108 .52345 L
.63141 .52301 L
.64255 .52261 L
.65218 .52234 L
.66274 .5221 L
.67309 .52191 L
.68273 .52179 L
.68806 .52174 L
Mistroke
.69292 .52171 L
.6956 .52169 L
.69852 .52168 L
.70127 .52167 L
.70257 .52167 L
.70381 .52166 L
.70498 .52166 L
.70624 .52166 L
.7074 .52166 L
.70847 .52166 L
.70974 .52166 L
.71089 .52165 L
.71153 .52165 L
.71222 .52166 L
.71348 .52166 L
.71457 .52166 L
.71577 .52166 L
.71819 .52166 L
.72043 .52167 L
.72253 .52167 L
.72773 .5217 L
.73248 .52172 L
.74315 .52179 L
.76223 .52197 L
.78298 .52221 L
.82375 .52277 L
.86301 .52333 L
.90075 .52384 L
.94094 .52433 L
.97619 .52471 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.02605 .04931 L
.02729 .0659 L
.02846 .07894 L
.02954 .08825 L
.03072 .09515 L
.0318 .09878 L
.03279 .10031 L
.03396 .10041 L
.03506 .09934 L
.03626 .09731 L
.03756 .0945 L
.04262 .08145 L
.0521 .05961 L
.05746 .05033 L
.06244 .04349 L
.0679 .0376 L
.07373 .03281 L
.07935 .02929 L
.08445 .02685 L
.08943 .02498 L
.09481 .02342 L
.0999 .02228 L
.10458 .02146 L
.10928 .02082 L
.11432 .02027 L
.11907 .01987 L
.1234 .01959 L
.12849 .01932 L
.13402 .01911 L
.13924 .01896 L
.14176 .01891 L
.14407 .01887 L
.1487 .0188 L
.15113 .01877 L
.15237 .01876 L
.15369 .01876 L
.15487 .01875 L
.15593 .01874 L
.157 .01874 L
.15801 .01874 L
.15919 .01874 L
.16028 .01874 L
.16147 .01874 L
.16273 .01874 L
.16401 .01875 L
.16518 .01875 L
.1678 .01877 L
.17254 .01881 L
.17524 .01884 L
Mistroke
.17777 .01886 L
.17917 .01886 L
.18069 .01887 L
.18136 .01887 L
.18207 .01888 L
.18333 .01888 L
.18451 .01888 L
.18577 .01888 L
.18696 .01888 L
.18804 .01888 L
.18931 .01887 L
.1907 .01886 L
.1932 .01885 L
.19796 .01881 L
.20236 .01877 L
.21306 .01866 L
.22309 .01858 L
.2321 .01853 L
.23716 .01851 L
.2418 .01849 L
.2466 .01848 L
.24932 .01847 L
.25185 .01847 L
.25323 .01847 L
.25453 .01847 L
.25571 .01847 L
.25696 .01847 L
.25832 .01846 L
.25958 .01846 L
.26028 .01846 L
.26093 .01846 L
.26164 .01846 L
.26241 .01846 L
.26363 .01846 L
.26432 .01846 L
.26497 .01846 L
.26628 .01846 L
.26769 .01846 L
.27023 .01847 L
.27257 .01847 L
.28363 .01848 L
.28608 .01848 L
.2887 .01848 L
.28997 .01848 L
.29117 .01848 L
.29226 .01848 L
.29342 .01848 L
.29465 .01848 L
.29578 .01848 L
.29701 .01848 L
Mistroke
.2977 .01848 L
.29835 .01848 L
.29904 .01848 L
.29971 .01848 L
.30095 .01848 L
.30228 .01848 L
.30374 .01848 L
.3063 .01848 L
.30906 .01848 L
.31407 .01847 L
.32343 .01846 L
.34441 .01843 L
.36436 .01841 L
.37441 .0184 L
.38543 .01839 L
.39565 .01839 L
.40495 .01838 L
.41582 .01838 L
.42587 .01838 L
.44497 .01837 L
.45505 .01837 L
.46574 .01837 L
.47512 .01837 L
.48523 .01837 L
.50351 .01837 L
.51309 .01837 L
.52357 .01837 L
.5345 .01837 L
.54467 .01837 L
.5552 .01837 L
.56514 .01837 L
.57407 .01837 L
.5791 .01837 L
.58374 .01837 L
.58841 .01837 L
.59104 .01837 L
.59344 .01837 L
.59567 .01837 L
.59693 .01837 L
.5981 .01837 L
.59922 .01837 L
.60024 .01837 L
.60141 .01837 L
.60251 .01837 L
.60372 .01837 L
.60503 .01837 L
.60641 .01837 L
.60769 .01837 L
.60998 .01837 L
.61244 .01837 L
Mistroke
.61805 .01837 L
.62316 .01837 L
.63311 .01837 L
.6423 .01837 L
.66308 .01837 L
.70241 .01837 L
.74024 .01837 L
.78051 .01837 L
.81927 .01837 L
.86048 .01837 L
.90018 .01837 L
.93836 .01837 L
.97619 .01837 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.02846 .08384 L
.03068 .11092 L
.03279 .13108 L
.03398 .13979 L
.03527 .14693 L
.03645 .15137 L
.03754 .15387 L
.03871 .15504 L
.04 .15475 L
.04065 .15409 L
.04135 .15305 L
.04262 .15045 L
.04516 .14329 L
.04793 .13389 L
.05297 .11595 L
.06244 .08684 L
.06799 .07373 L
.07302 .06415 L
.07844 .05591 L
.08429 .04897 L
.08973 .04399 L
.09474 .04041 L
.09949 .0377 L
.10458 .03541 L
.10967 .03362 L
.11432 .03234 L
.11904 .03132 L
.1234 .03057 L
.12849 .0299 L
.13111 .02963 L
.13402 .02937 L
.13889 .02905 L
.14156 .02892 L
.14277 .02888 L
.14407 .02884 L
.14534 .0288 L
.1465 .02878 L
.14766 .02876 L
.14876 .02875 L
.15004 .02874 L
.15123 .02874 L
.15252 .02875 L
.15318 .02875 L
.1539 .02876 L
.15525 .02879 L
.15648 .02883 L
.1579 .02887 L
.15925 .02893 L
.16164 .02906 L
Mistroke
.16425 .02925 L
.17378 .03025 L
.17606 .03049 L
.17846 .03071 L
.18051 .03086 L
.18167 .03092 L
.18275 .03097 L
.18401 .03101 L
.18516 .03103 L
.18648 .03104 L
.18773 .03104 L
.18838 .03103 L
.18907 .03102 L
.1903 .03099 L
.19163 .03095 L
.1931 .03089 L
.19793 .03062 L
.20247 .0303 L
.2127 .02956 L
.22345 .02889 L
.23312 .02845 L
.23859 .02826 L
.24367 .02813 L
.24837 .02803 L
.25263 .02797 L
.255 .02794 L
.25755 .02792 L
.26219 .02788 L
.30316 .02763 L
.313 .02753 L
.32356 .02744 L
.33352 .02737 L
.34262 .02732 L
.35194 .02729 L
.35721 .02727 L
.36209 .02726 L
.36671 .02726 L
.37104 .02725 L
.37556 .02725 L
.37815 .02724 L
.38056 .02724 L
.38301 .02724 L
.38524 .02724 L
.38772 .02724 L
.3891 .02724 L
.39037 .02724 L
.39161 .02724 L
.39292 .02724 L
.39424 .02724 L
.39499 .02724 L
Mistroke
.39569 .02724 L
.39696 .02724 L
.39811 .02724 L
.39875 .02724 L
.39945 .02724 L
.40072 .02724 L
.40197 .02724 L
.40315 .02724 L
.40536 .02724 L
.41031 .02724 L
.41459 .02724 L
.41921 .02724 L
.46024 .02727 L
.49974 .0273 L
.53774 .02732 L
.5589 .02733 L
.57818 .02734 L
.5984 .02735 L
.61711 .02735 L
.63621 .02736 L
.64692 .02736 L
.65697 .02736 L
.66672 .02736 L
.67565 .02736 L
.68557 .02736 L
.69078 .02736 L
.6936 .02736 L
.69626 .02736 L
.69866 .02736 L
.69993 .02736 L
.70127 .02736 L
.70239 .02736 L
.70363 .02736 L
.70476 .02736 L
.70581 .02736 L
.70713 .02736 L
.70839 .02736 L
.70951 .02736 L
.71073 .02736 L
.71143 .02736 L
.71206 .02736 L
.71348 .02736 L
.71478 .02736 L
.71602 .02736 L
.71826 .02736 L
.72062 .02736 L
.72485 .02736 L
.7294 .02736 L
.73439 .02736 L
.74463 .02736 L
Mistroke
.75395 .02736 L
.77488 .02736 L
.8148 .02735 L
.8532 .02735 L
.89406 .02734 L
.9334 .02733 L
.97122 .02733 L
.97619 .02733 L
Mfstroke
.221 0 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02079 L
.03279 .02028 L
.04262 .01837 L
.04762 .01766 L
.05293 .01707 L
.05746 .01667 L
.06244 .01632 L
.06792 .01603 L
.07293 .01582 L
.07871 .01563 L
.0842 .0155 L
.08925 .01541 L
.09394 .01534 L
.09909 .01528 L
.10458 .01523 L
.10994 .0152 L
.11487 .01517 L
.12028 .01515 L
.12599 .01514 L
.13096 .01513 L
.13561 .01512 L
.1407 .01511 L
.14335 .01511 L
.14616 .01511 L
.14867 .01511 L
.15145 .0151 L
.154 .0151 L
.15634 .0151 L
.15908 .0151 L
.16052 .0151 L
.16204 .0151 L
.16268 .0151 L
.16337 .0151 L
.1646 .0151 L
.16536 .0151 L
.16607 .0151 L
.16671 .0151 L
.1674 .0151 L
.16865 .0151 L
.16982 .0151 L
.17111 .0151 L
.17249 .0151 L
.17381 .0151 L
.17525 .0151 L
.17591 .0151 L
Mistroke
.17661 .0151 L
.17787 .0151 L
.17853 .0151 L
.17923 .0151 L
.18052 .0151 L
.18177 .0151 L
.18291 .0151 L
.18398 .0151 L
.18516 .0151 L
.18752 .0151 L
.19278 .0151 L
.19775 .0151 L
.20707 .0151 L
.21723 .01509 L
.22279 .01509 L
.228 .01509 L
.23295 .01509 L
.23749 .01509 L
.24253 .01509 L
.24795 .01509 L
.25224 .01509 L
.25693 .01509 L
.26638 .01509 L
.28767 .01509 L
.30699 .01509 L
.31666 .01509 L
.32712 .01509 L
.33693 .01509 L
.34609 .01509 L
.35558 .01509 L
.36601 .01509 L
.37616 .01509 L
.38706 .01509 L
.39722 .01509 L
.40828 .01509 L
.41872 .01509 L
.42337 .01509 L
.42839 .01509 L
.4334 .01509 L
.438 .01509 L
.4424 .01509 L
.44703 .01509 L
.44949 .01509 L
.45212 .01509 L
.4534 .01509 L
.45461 .01509 L
.45568 .01509 L
.45686 .01509 L
.45817 .01509 L
.45888 .01509 L
Mistroke
.45955 .01509 L
.46074 .01509 L
.46203 .01509 L
.46274 .01509 L
.46353 .01509 L
.46426 .01509 L
.46495 .01509 L
.46625 .01509 L
.46763 .01509 L
.47023 .01509 L
.47299 .01509 L
.47792 .01509 L
.48905 .01509 L
.50923 .01509 L
.54722 .01509 L
.58766 .01509 L
.62659 .01509 L
.66797 .01509 L
.70784 .01509 L
.74619 .01509 L
.78699 .01509 L
.82628 .01509 L
.86405 .01509 L
.90427 .01509 L
.94298 .01509 L
.97619 .01509 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.02846 .08341 L
.03068 .11012 L
.03279 .13062 L
.03398 .1401 L
.03527 .14866 L
.03635 .15445 L
.03754 .15951 L
.03882 .16355 L
.03952 .16518 L
.04018 .16636 L
.04135 .16772 L
.04262 .16821 L
.04393 .16781 L
.04516 .16675 L
.04586 .16587 L
.0465 .16494 L
.04793 .16242 L
.05297 .15047 L
.06244 .1246 L
.07287 .10029 L
.07835 .09022 L
.08414 .08149 L
.08922 .07527 L
.09479 .06975 L
.10458 .06269 L
.10982 .06002 L
.11478 .05804 L
.11924 .05665 L
.12409 .0555 L
.12936 .05461 L
.13202 .0543 L
.13355 .05416 L
.13495 .05405 L
.13617 .05398 L
.13745 .05392 L
.13873 .05388 L
.13946 .05386 L
.14014 .05386 L
.14137 .05386 L
.14249 .05388 L
.14378 .05392 L
.145 .05398 L
.14616 .05405 L
.1474 .05416 L
.14963 .05441 L
.15229 .05483 L
.15473 .05534 L
.15725 .05606 L
.16001 .05708 L
Mistroke
.16261 .05835 L
.16502 .05983 L
.17389 .06774 L
.17855 .07193 L
.1809 .07353 L
.18224 .07424 L
.18347 .07476 L
.18485 .07521 L
.18561 .07538 L
.18633 .07551 L
.1876 .07565 L
.18833 .07568 L
.18899 .07568 L
.19016 .07561 L
.19145 .07545 L
.1921 .07534 L
.1928 .07519 L
.19407 .07488 L
.19927 .07307 L
.20403 .07096 L
.22265 .06271 L
.23248 .05952 L
.24161 .05741 L
.24687 .05653 L
.25164 .05591 L
.25714 .05539 L
.26233 .05502 L
.27208 .05453 L
.28238 .05413 L
.28663 .054 L
.29118 .05389 L
.29379 .05384 L
.29618 .0538 L
.29733 .05378 L
.29857 .05377 L
.29968 .05376 L
.30085 .05375 L
.30206 .05375 L
.30317 .05375 L
.30437 .05374 L
.30569 .05374 L
.30682 .05375 L
.30804 .05375 L
.30919 .05376 L
.31023 .05376 L
.31279 .05378 L
.31556 .05381 L
.3206 .05388 L
.33152 .05407 L
.3416 .05428 L
Mistroke
.35063 .05452 L
.36034 .05485 L
.37099 .05532 L
.38097 .05588 L
.42221 .05908 L
.46194 .0619 L
.50015 .06397 L
.52149 .06493 L
.54082 .06565 L
.56121 .06626 L
.57997 .06669 L
.59923 .06702 L
.60936 .06715 L
.62005 .06727 L
.62954 .06734 L
.63476 .06738 L
.63971 .0674 L
.6443 .06742 L
.6493 .06744 L
.65151 .06744 L
.65385 .06745 L
.65584 .06745 L
.65805 .06746 L
.65927 .06746 L
.6604 .06746 L
.66164 .06746 L
.66234 .06746 L
.66297 .06746 L
.66425 .06746 L
.66497 .06746 L
.66563 .06746 L
.66686 .06746 L
.66815 .06746 L
.66925 .06746 L
.67043 .06745 L
.67256 .06745 L
.67509 .06745 L
.67741 .06744 L
.68253 .06743 L
.68811 .06741 L
.69827 .06736 L
.718 .06723 L
.73899 .06705 L
.78064 .06657 L
.82078 .06604 L
.8594 .06549 L
.90048 .0649 L
.94004 .06434 L
.97619 .06386 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.02605 .04925 L
.02729 .06568 L
.02846 .07841 L
.02954 .08737 L
.03072 .09387 L
.0318 .09719 L
.03279 .09852 L
.03396 .0985 L
.03506 .09738 L
.03626 .09535 L
.03756 .09259 L
.04262 .07991 L
.0521 .05871 L
.05746 .04968 L
.06244 .04302 L
.0679 .03729 L
.07373 .03261 L
.07935 .02918 L
.08445 .02679 L
.08943 .02497 L
.09481 .02345 L
.0999 .02234 L
.10458 .02154 L
.10928 .0209 L
.11432 .02037 L
.11907 .01998 L
.1234 .0197 L
.12849 .01945 L
.13402 .01924 L
.13924 .0191 L
.14176 .01905 L
.14407 .019 L
.14628 .01897 L
.1487 .01894 L
.15113 .01892 L
.15246 .01891 L
.15369 .0189 L
.15487 .0189 L
.15598 .01889 L
.15698 .01889 L
.15806 .01889 L
.15924 .01889 L
.16049 .01889 L
.16156 .0189 L
.16273 .0189 L
.16411 .01891 L
.16541 .01892 L
.16786 .01894 L
.17338 .01899 L
Mistroke
.17568 .01901 L
.17814 .01903 L
.17955 .01904 L
.18083 .01905 L
.18212 .01905 L
.18333 .01905 L
.1845 .01905 L
.18575 .01905 L
.18693 .01905 L
.188 .01905 L
.18926 .01904 L
.19063 .01903 L
.19312 .01902 L
.20345 .01892 L
.21299 .01883 L
.22194 .01875 L
.23136 .01869 L
.23636 .01866 L
.24175 .01864 L
.2471 .01863 L
.24979 .01862 L
.25272 .01862 L
.25524 .01862 L
.25663 .01861 L
.25793 .01861 L
.25915 .01861 L
.26047 .01861 L
.26277 .01861 L
.27219 .01861 L
.27339 .01861 L
.27467 .01861 L
.27534 .01861 L
.27608 .01861 L
.27738 .01861 L
.2786 .01861 L
.27991 .01861 L
.28115 .01861 L
.28229 .01861 L
.28364 .01861 L
.28512 .01861 L
.28809 .01861 L
.29083 .0186 L
.29338 .0186 L
.30374 .01859 L
.32441 .01856 L
.33418 .01855 L
.3432 .01854 L
.35282 .01853 L
.35779 .01853 L
.36326 .01853 L
Mistroke
.37246 .01852 L
.38221 .01852 L
.39236 .01852 L
.40163 .01852 L
.41247 .01852 L
.42252 .01852 L
.43172 .01852 L
.44152 .01852 L
.44712 .01852 L
.45239 .01852 L
.45709 .01851 L
.46225 .01851 L
.4673 .01851 L
.47202 .01851 L
.47463 .01851 L
.477 .01851 L
.47832 .01851 L
.47974 .01851 L
.48108 .01851 L
.48234 .01851 L
.4834 .01851 L
.48455 .01851 L
.48583 .01851 L
.487 .01851 L
.48815 .01851 L
.4894 .01851 L
.49072 .01851 L
.49194 .01851 L
.49419 .01851 L
.49623 .01851 L
.50082 .01851 L
.51081 .01851 L
.52002 .01851 L
.54082 .01851 L
.58024 .01852 L
.60005 .01852 L
.61815 .01852 L
.62293 .01852 L
.62814 .01852 L
.63311 .01852 L
.63761 .01852 L
.64287 .01852 L
.64575 .01852 L
.64707 .01852 L
.64846 .01852 L
.64966 .01852 L
.65098 .01852 L
.65217 .01852 L
.65329 .01852 L
.65461 .01852 L
Mistroke
.65581 .01852 L
.65648 .01852 L
.6572 .01852 L
.65851 .01852 L
.65973 .01852 L
.66085 .01852 L
.66338 .01852 L
.66572 .01852 L
.66794 .01852 L
.67291 .01852 L
.67834 .01852 L
.68924 .01852 L
.69936 .01852 L
.71988 .01852 L
.73848 .01852 L
.77853 .01851 L
.81707 .01851 L
.85806 .01851 L
.89754 .01851 L
.9355 .01851 L
.97591 .01851 L
.97619 .01851 L
Mfstroke
.292 0 1 r
.02381 .01472 m
.02499 .0325 L
.02605 .04459 L
.02729 .05241 L
.02846 .05531 L
.02954 .05587 L
.03053 .05544 L
.03163 .05443 L
.03279 .05303 L
.04262 .04 L
.05205 .03108 L
.05742 .02751 L
.06244 .02491 L
.06788 .02274 L
.07305 .02116 L
.07768 .02005 L
.08274 .0191 L
.08822 .01832 L
.09407 .01769 L
.09958 .01724 L
.10458 .01694 L
.10945 .0167 L
.1146 .01651 L
.119 .01639 L
.12383 .01628 L
.12902 .01619 L
.13459 .01611 L
.13985 .01606 L
.14465 .01603 L
.14945 .016 L
.15188 .01599 L
.15456 .01598 L
.15684 .01598 L
.15929 .01597 L
.16042 .01597 L
.16161 .01597 L
.16373 .01597 L
.16503 .01597 L
.16621 .01597 L
.16687 .01597 L
.16758 .01597 L
.16887 .01596 L
.17008 .01596 L
.17135 .01596 L
.17245 .01596 L
.17365 .01596 L
.17437 .01596 L
.17506 .01596 L
.17635 .01596 L
.17707 .01596 L
Mistroke
.17774 .01596 L
.17847 .01596 L
.17925 .01596 L
.17993 .01596 L
.18067 .01596 L
.182 .01596 L
.18449 .01596 L
.18687 .01596 L
.18942 .01596 L
.19402 .01595 L
.20447 .01593 L
.21542 .01592 L
.22555 .01591 L
.2305 .0159 L
.23575 .0159 L
.24102 .0159 L
.24402 .0159 L
.24683 .0159 L
.24929 .01589 L
.25189 .01589 L
.2541 .01589 L
.25536 .01589 L
.25652 .01589 L
.25718 .01589 L
.25789 .01589 L
.25917 .01589 L
.26042 .01589 L
.26157 .01589 L
.26282 .01589 L
.26353 .01589 L
.26419 .01589 L
.26696 .01589 L
.27196 .01589 L
.27739 .01589 L
.27988 .01589 L
.28125 .01589 L
.28253 .01589 L
.28371 .01589 L
.28479 .0159 L
.28599 .0159 L
.28729 .0159 L
.28837 .0159 L
.28952 .0159 L
.29061 .0159 L
.2916 .0159 L
.29276 .01589 L
.29403 .01589 L
.29632 .01589 L
.29872 .01589 L
.30127 .01589 L
Mistroke
.30584 .01589 L
.32561 .01589 L
.34369 .01589 L
.35365 .01589 L
.36312 .01588 L
.3731 .01588 L
.384 .01588 L
.40369 .01588 L
.42466 .01588 L
.44609 .01588 L
.4559 .01588 L
.46627 .01588 L
.48636 .01588 L
.50484 .01588 L
.54283 .01588 L
.56235 .01588 L
.58327 .01588 L
.62465 .01588 L
.66452 .01588 L
.70287 .01588 L
.74367 .01588 L
.78296 .01588 L
.82073 .01588 L
.86095 .01588 L
.89966 .01588 L
.94082 .01588 L
.97619 .01588 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02078 L
.03279 .02028 L
.04262 .01836 L
.04762 .01764 L
.05293 .01705 L
.0579 .01661 L
.06244 .01629 L
.06743 .01602 L
.0728 .01579 L
.07777 .01562 L
.0825 .0155 L
.08797 .01539 L
.09305 .01531 L
.09863 .01525 L
.10458 .0152 L
.10994 .01516 L
.11487 .01514 L
.12028 .01512 L
.12599 .0151 L
.13096 .01509 L
.13561 .01508 L
.1407 .01507 L
.14616 .01507 L
.14872 .01507 L
.15145 .01507 L
.1538 .01506 L
.15634 .01506 L
.15905 .01506 L
.1616 .01506 L
.16307 .01506 L
.16462 .01506 L
.16595 .01506 L
.1674 .01506 L
.17282 .01506 L
.17412 .01506 L
.17549 .01506 L
.17676 .01506 L
.17794 .01506 L
.18013 .01506 L
.18254 .01506 L
.18494 .01506 L
.18752 .01506 L
.20713 .01506 L
.2124 .01505 L
.218 .01505 L
Mistroke
.2232 .01505 L
.22808 .01505 L
.2334 .01505 L
.23821 .01505 L
.2408 .01505 L
.24352 .01505 L
.24651 .01505 L
.24795 .01505 L
.24926 .01505 L
.25041 .01505 L
.25166 .01505 L
.25297 .01505 L
.25422 .01505 L
.25539 .01505 L
.25663 .01505 L
.25768 .01505 L
.25885 .01505 L
.25951 .01505 L
.26021 .01505 L
.26146 .01505 L
.26281 .01505 L
.26427 .01505 L
.26936 .01505 L
.27422 .01505 L
.27947 .01505 L
.28189 .01505 L
.28444 .01505 L
.28662 .01505 L
.28785 .01505 L
.28901 .01505 L
.28969 .01505 L
.29043 .01505 L
.29113 .01505 L
.29178 .01505 L
.29301 .01505 L
.29431 .01505 L
.29498 .01505 L
.29571 .01505 L
.29701 .01505 L
.29857 .01505 L
.3 .01505 L
.30486 .01505 L
.30997 .01505 L
.32992 .01505 L
.34805 .01505 L
.35812 .01505 L
.36764 .01505 L
.37768 .01505 L
.38858 .01505 L
.40804 .01505 L
Mistroke
.42947 .01505 L
.4498 .01505 L
.46884 .01505 L
.4891 .01505 L
.50763 .01505 L
.54736 .01505 L
.58557 .01505 L
.60526 .01505 L
.62623 .01505 L
.66784 .01505 L
.70792 .01505 L
.74649 .01505 L
.78752 .01505 L
.82702 .01505 L
.86502 .01505 L
.90546 .01505 L
.94439 .01505 L
.97619 .01505 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.02846 .08442 L
.03279 .13901 L
.03754 .1864 L
.04018 .20695 L
.04262 .22228 L
.04518 .23477 L
.0465 .23985 L
.04795 .24443 L
.04913 .2474 L
.0504 .24989 L
.0511 .25098 L
.05174 .2518 L
.053 .25294 L
.0542 .2535 L
.05531 .2536 L
.05654 .25327 L
.05784 .25247 L
.05908 .25131 L
.06026 .24991 L
.06244 .24661 L
.08439 .19629 L
.09401 .17719 L
.09911 .169 L
.10458 .16168 L
.10965 .15618 L
.11427 .15216 L
.11892 .14903 L
.12333 .14683 L
.12572 .14594 L
.12702 .14555 L
.12825 .14524 L
.12938 .145 L
.13042 .14482 L
.13157 .14467 L
.13281 .14457 L
.13406 .14452 L
.13521 .14453 L
.13648 .14461 L
.13719 .14468 L
.13784 .14477 L
.13914 .145 L
.14056 .14533 L
.14313 .1462 L
.14549 .14732 L
.14802 .14893 L
.15041 .15091 L
.1526 .15319 L
.15515 .15657 L
.15794 .16138 L
Mistroke
.16057 .1673 L
.16301 .17431 L
.16836 .19576 L
.1732 .22077 L
.17848 .24684 L
.18114 .25712 L
.18266 .26187 L
.18405 .26544 L
.18525 .26795 L
.18656 .27007 L
.18728 .27097 L
.18794 .27165 L
.18925 .27255 L
.19037 .2729 L
.1916 .27285 L
.19289 .27236 L
.1941 .27153 L
.19523 .27045 L
.19642 .26904 L
.19855 .26591 L
.20333 .25671 L
.21341 .2333 L
.22417 .21008 L
.22951 .20074 L
.23454 .19356 L
.23906 .18855 L
.2416 .18636 L
.24395 .18478 L
.24501 .18421 L
.24615 .18371 L
.24722 .18333 L
.24821 .18308 L
.24936 .1829 L
.25061 .18286 L
.25179 .18298 L
.25288 .18323 L
.254 .18364 L
.25506 .18418 L
.25621 .18496 L
.25746 .18603 L
.2587 .18736 L
.26 .18907 L
.26233 .19304 L
.26489 .19899 L
.26732 .20637 L
.27186 .22546 L
.27674 .2537 L
.28205 .29074 L
.29153 .35871 L
.3004 .41044 L
Mistroke
.30496 .43093 L
.30985 .44869 L
.31529 .46397 L
.32026 .47466 L
.32542 .48328 L
.33104 .49068 L
.34129 .50134 L
.36262 .52122 L
.3727 .53002 L
.38196 .53693 L
.39165 .54243 L
.39674 .54457 L
.40212 .54626 L
.40438 .54681 L
.4068 .54731 L
.4089 .54765 L
.41117 .54795 L
.41256 .54809 L
.41384 .5482 L
.41507 .54828 L
.41637 .54835 L
.41753 .54839 L
.41862 .54841 L
.41982 .54842 L
.42111 .54841 L
.42236 .54839 L
.42351 .54835 L
.42483 .5483 L
.42607 .54823 L
.42829 .54808 L
.43069 .54788 L
.44116 .54662 L
.46227 .54339 L
.5032 .53775 L
.54263 .53256 L
.58054 .52779 L
.62089 .52373 L
.65974 .52072 L
.70104 .51829 L
.74082 .51651 L
.77908 .51515 L
.8198 .51392 L
.859 .51286 L
.90065 .51179 L
.94079 .51078 L
.97619 .50989 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.02846 .08435 L
.03279 .1381 L
.03754 .18265 L
.0402 .20077 L
.04262 .21312 L
.04385 .21798 L
.04516 .22215 L
.04627 .22494 L
.0475 .22725 L
.04882 .2289 L
.04957 .22948 L
.05024 .2298 L
.05156 .22991 L
.05281 .22943 L
.05397 .22854 L
.0552 .22717 L
.05742 .22377 L
.06244 .21296 L
.07287 .18542 L
.08414 .15817 L
.08932 .14791 L
.09479 .13872 L
.10458 .12615 L
.10953 .12147 L
.11483 .11753 L
.11984 .11472 L
.1244 .11286 L
.12718 .11204 L
.12975 .11148 L
.1311 .11126 L
.13258 .11108 L
.13332 .11101 L
.13412 .11096 L
.13488 .11093 L
.13558 .11092 L
.13685 .11093 L
.13804 .11099 L
.13934 .1111 L
.14007 .11119 L
.14073 .11129 L
.14207 .11154 L
.14353 .11189 L
.14616 .11274 L
.14852 .11379 L
.15105 .11527 L
.15344 .11709 L
.15563 .11919 L
.15818 .12232 L
.16097 .1268 L
Mistroke
.1636 .13233 L
.16604 .1388 L
.17125 .15683 L
.17688 .17819 L
.17947 .18632 L
.18088 .18999 L
.1822 .19287 L
.18342 .19506 L
.18453 .19666 L
.18576 .19799 L
.18708 .19894 L
.18836 .19941 L
.189 .19949 L
.18971 .19946 L
.19097 .19913 L
.19215 .19853 L
.19282 .19807 L
.19353 .1975 L
.19479 .19629 L
.19765 .19278 L
.20764 .17592 L
.2174 .15883 L
.22626 .14595 L
.23583 .13573 L
.24109 .13174 L
.2435 .13028 L
.24604 .12899 L
.24823 .12809 L
.25064 .1273 L
.25169 .12703 L
.25283 .12679 L
.25389 .12661 L
.25487 .12648 L
.2561 .12638 L
.25674 .12635 L
.25743 .12634 L
.25859 .12636 L
.25986 .12646 L
.261 .12661 L
.26221 .12685 L
.26337 .12714 L
.26442 .12747 L
.2669 .12853 L
.26915 .12985 L
.27175 .13187 L
.27421 .13434 L
.27858 .14022 L
.28332 .14893 L
.29409 .17673 L
.30402 .20659 L
Mistroke
.31305 .23121 L
.32276 .25235 L
.33341 .27037 L
.34339 .28534 L
.36311 .3191 L
.38463 .36279 L
.39461 .38092 L
.40524 .39638 L
.4104 .40229 L
.41527 .40693 L
.42436 .41338 L
.42902 .41573 L
.43413 .41768 L
.43671 .41845 L
.43947 .41914 L
.44186 .41963 L
.44445 .42007 L
.44703 .42042 L
.44942 .42068 L
.4517 .42087 L
.45412 .42102 L
.45516 .42107 L
.45628 .42111 L
.45725 .42114 L
.45831 .42117 L
.45948 .42119 L
.46072 .42121 L
.46186 .42122 L
.46293 .42122 L
.46421 .42121 L
.46485 .4212 L
.46556 .42119 L
.46681 .42117 L
.46799 .42115 L
.47063 .42107 L
.47346 .42097 L
.47866 .42071 L
.4834 .42043 L
.49294 .41968 L
.50199 .41878 L
.52186 .41607 L
.54026 .41275 L
.57946 .40434 L
.62112 .39545 L
.66125 .3875 L
.69988 .38044 L
.74095 .37352 L
.78051 .36729 L
.81856 .3616 L
.85905 .35577 L
Mistroke
.89803 .35035 L
.93947 .34478 L
.97619 .34 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.02499 .0325 L
.02605 .04465 L
.02729 .05263 L
.02846 .05571 L
.02954 .05639 L
.03053 .05605 L
.03163 .0551 L
.03279 .05375 L
.04262 .04071 L
.05205 .03164 L
.05742 .02799 L
.06244 .02534 L
.06788 .02312 L
.07305 .02149 L
.07768 .02035 L
.08274 .01938 L
.08822 .01857 L
.09407 .01792 L
.09958 .01746 L
.10458 .01714 L
.10945 .0169 L
.1146 .0167 L
.119 .01657 L
.12383 .01646 L
.12902 .01636 L
.13459 .01629 L
.13985 .01624 L
.14465 .0162 L
.14945 .01617 L
.15188 .01616 L
.15456 .01616 L
.15684 .01615 L
.15803 .01615 L
.15929 .01615 L
.1604 .01614 L
.16161 .01614 L
.16271 .01614 L
.16373 .01614 L
.16503 .01614 L
.16576 .01614 L
.16644 .01614 L
.16768 .01614 L
.16899 .01614 L
.17017 .01614 L
.17127 .01614 L
.17377 .01614 L
.17504 .01614 L
.17642 .01614 L
.17773 .01614 L
Mistroke
.17894 .01614 L
.17968 .01614 L
.18034 .01614 L
.18111 .01614 L
.18184 .01614 L
.18311 .01614 L
.18383 .01614 L
.18449 .01614 L
.18696 .01614 L
.18921 .01614 L
.19425 .01613 L
.20335 .01611 L
.2141 .01609 L
.21882 .01608 L
.22403 .01608 L
.23331 .01607 L
.23839 .01606 L
.24315 .01606 L
.2457 .01606 L
.24838 .01606 L
.25316 .01606 L
.25583 .01606 L
.25831 .01606 L
.26393 .01606 L
.30303 .01605 L
.32298 .01605 L
.33348 .01604 L
.34458 .01604 L
.35451 .01604 L
.36542 .01604 L
.37534 .01604 L
.38461 .01604 L
.39504 .01604 L
.40494 .01604 L
.42349 .01604 L
.43312 .01604 L
.44337 .01604 L
.45212 .01604 L
.4571 .01604 L
.46178 .01604 L
.46647 .01604 L
.4716 .01604 L
.47419 .01604 L
.47695 .01604 L
.47957 .01604 L
.48194 .01604 L
.48309 .01604 L
.48431 .01604 L
.48537 .01604 L
.4865 .01604 L
Mistroke
.48772 .01604 L
.48886 .01604 L
.48955 .01604 L
.49021 .01604 L
.49145 .01604 L
.49253 .01604 L
.49368 .01604 L
.49477 .01604 L
.49575 .01604 L
.49817 .01604 L
.50044 .01604 L
.5051 .01604 L
.51021 .01604 L
.52053 .01604 L
.53901 .01604 L
.57945 .01604 L
.61838 .01604 L
.65976 .01604 L
.69963 .01604 L
.73798 .01604 L
.77878 .01604 L
.81807 .01604 L
.85584 .01604 L
.89606 .01604 L
.93477 .01604 L
.97593 .01604 L
.97619 .01604 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.02846 .08442 L
.03279 .13899 L
.03754 .18614 L
.0402 .20643 L
.04262 .22104 L
.04385 .22708 L
.04516 .23249 L
.04629 .23635 L
.0475 .23969 L
.04881 .24238 L
.05003 .24411 L
.05077 .24481 L
.05148 .24523 L
.05212 .24543 L
.05281 .24544 L
.05408 .24498 L
.05523 .24404 L
.05587 .24333 L
.05656 .24242 L
.05781 .24043 L
.06244 .22996 L
.08293 .1687 L
.09325 .14467 L
.09911 .13415 L
.10458 .12618 L
.1099 .11996 L
.11493 .11529 L
.11945 .11199 L
.12437 .10927 L
.12691 .10819 L
.12971 .10724 L
.13112 .10685 L
.13264 .10651 L
.13407 .10625 L
.13539 .10607 L
.13662 .10595 L
.13776 .10589 L
.13901 .10587 L
.13972 .10588 L
.14035 .1059 L
.14164 .106 L
.14237 .10608 L
.14304 .10617 L
.14428 .10638 L
.14558 .10668 L
.14811 .10747 L
.15051 .10854 L
.15267 .1098 L
.15502 .11158 L
Mistroke
.15757 .1141 L
.16028 .11767 L
.16284 .1221 L
.16516 .12724 L
.16969 .14087 L
.17459 .15974 L
.17888 .17608 L
.18124 .18366 L
.18347 .18948 L
.18471 .19209 L
.18605 .19442 L
.18727 .1961 L
.1884 .19727 L
.18946 .19806 L
.19063 .1986 L
.19186 .19881 L
.193 .19871 L
.19428 .19828 L
.19492 .19795 L
.19563 .1975 L
.19803 .19538 L
.20084 .19196 L
.20345 .18811 L
.2143 .16914 L
.22453 .15237 L
.22931 .14595 L
.23437 .14039 L
.23701 .13803 L
.23992 .13589 L
.24119 .13511 L
.24256 .13439 L
.24384 .13383 L
.24502 .13342 L
.24618 .13311 L
.24741 .13291 L
.24865 .13283 L
.24935 .13285 L
.25002 .13291 L
.2512 .13314 L
.25229 .13349 L
.25349 .13404 L
.25475 .13483 L
.25581 .13569 L
.25694 .13681 L
.25899 .13943 L
.26141 .14373 L
.26362 .14895 L
.26593 .1559 L
.26846 .16549 L
.27359 .19088 L
Mistroke
.28278 .24757 L
.28796 .27764 L
.29081 .29192 L
.29352 .30357 L
.29603 .31257 L
.29877 .32034 L
.29998 .32309 L
.30126 .32557 L
.30246 .32748 L
.30357 .3289 L
.30482 .33011 L
.30548 .33059 L
.30618 .33098 L
.30692 .33126 L
.30762 .3314 L
.30894 .33137 L
.31016 .33099 L
.3113 .33036 L
.31255 .32937 L
.31387 .32801 L
.3166 .32427 L
.31916 .31979 L
.325 .30695 L
.34518 .25483 L
.35502 .23357 L
.36537 .21636 L
.37421 .20546 L
.38388 .19657 L
.39417 .18939 L
.40351 .184 L
.42446 .17336 L
.44528 .16392 L
.46447 .15681 L
.48316 .15166 L
.49259 .14967 L
.50295 .14786 L
.52241 .14527 L
.54331 .14326 L
.5645 .14178 L
.57424 .14125 L
.58461 .14078 L
.59503 .14039 L
.60447 .14011 L
.61395 .13988 L
.62287 .13972 L
.63267 .13959 L
.6376 .13954 L
.64301 .1395 L
.64763 .13947 L
.65022 .13946 L
Mistroke
.65258 .13945 L
.65477 .13944 L
.65593 .13944 L
.65716 .13944 L
.65823 .13944 L
.65941 .13944 L
.66049 .13943 L
.6615 .13943 L
.66274 .13943 L
.66344 .13943 L
.66407 .13943 L
.6653 .13943 L
.66645 .13944 L
.66781 .13944 L
.66906 .13944 L
.67187 .13945 L
.67416 .13945 L
.67667 .13946 L
.68173 .13948 L
.69131 .13954 L
.70026 .13961 L
.7206 .13983 L
.73915 .14007 L
.77898 .14069 L
.8173 .14134 L
.85807 .14202 L
.89733 .14264 L
.93506 .14319 L
.97525 .14373 L
.97619 .14374 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.02605 .04959 L
.02846 .0826 L
.03053 .10589 L
.03279 .12471 L
.03416 .13287 L
.03543 .13834 L
.03665 .14189 L
.03793 .14411 L
.03908 .14493 L
.04016 .14489 L
.04135 .14408 L
.04262 .1425 L
.04393 .14025 L
.04516 .13775 L
.04793 .13108 L
.05297 .1175 L
.06244 .09359 L
.06795 .0822 L
.07314 .07329 L
.08284 .06071 L
.08828 .05556 L
.09328 .05177 L
.09878 .04847 L
.10458 .04577 L
.10954 .04398 L
.11406 .04269 L
.11928 .04153 L
.12422 .04071 L
.12878 .04014 L
.133 .03977 L
.1352 .03963 L
.13763 .03952 L
.13885 .03947 L
.14017 .03944 L
.14141 .03942 L
.14255 .03941 L
.14383 .03941 L
.14503 .03942 L
.14612 .03944 L
.14729 .03948 L
.14857 .03952 L
.14993 .03959 L
.15235 .03976 L
.1546 .03997 L
.1567 .04023 L
.159 .04059 L
.16148 .04108 L
.16413 .04175 L
.16702 .04266 L
Mistroke
.17229 .04472 L
.17704 .04656 L
.17972 .04738 L
.18218 .04793 L
.18341 .04812 L
.18412 .04821 L
.18477 .04827 L
.18545 .04833 L
.18619 .04837 L
.18751 .0484 L
.18874 .04839 L
.18944 .04837 L
.19008 .04833 L
.19127 .04825 L
.19252 .04812 L
.19482 .04783 L
.19698 .04748 L
.20189 .04654 L
.21212 .04436 L
.22287 .04235 L
.23254 .041 L
.23801 .04043 L
.2431 .04001 L
.24779 .03971 L
.25205 .0395 L
.25697 .03933 L
.26161 .0392 L
.26626 .03911 L
.27136 .03902 L
.27633 .03895 L
.27907 .03892 L
.28167 .03889 L
.28406 .03887 L
.28532 .03886 L
.28666 .03885 L
.28778 .03885 L
.28902 .03885 L
.29015 .03884 L
.29121 .03884 L
.2923 .03884 L
.29345 .03885 L
.29443 .03885 L
.2955 .03885 L
.29666 .03886 L
.2979 .03887 L
.30013 .03889 L
.30545 .03895 L
.31036 .03903 L
.32145 .03924 L
.3416 .03966 L
Mistroke
.36193 .04014 L
.38097 .04077 L
.41882 .04245 L
.43737 .04318 L
.45761 .04379 L
.47876 .04426 L
.49886 .0446 L
.51855 .04484 L
.52955 .04494 L
.53952 .04501 L
.5444 .04504 L
.54956 .04506 L
.55401 .04508 L
.55879 .0451 L
.56392 .04511 L
.56872 .04512 L
.57164 .04512 L
.57308 .04512 L
.57442 .04513 L
.5756 .04513 L
.5769 .04513 L
.57822 .04513 L
.57894 .04513 L
.57961 .04513 L
.58079 .04513 L
.58205 .04513 L
.58323 .04513 L
.58431 .04513 L
.58558 .04513 L
.58696 .04513 L
.58945 .04513 L
.59207 .04512 L
.59484 .04512 L
.59981 .04511 L
.60862 .04509 L
.61832 .04507 L
.63778 .04499 L
.65868 .04489 L
.69997 .04465 L
.73975 .04437 L
.77802 .04409 L
.81874 .04379 L
.85794 .04351 L
.89959 .04322 L
.93973 .04295 L
.97619 .04273 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.02846 .08428 L
.03279 .13685 L
.03527 .16009 L
.03754 .17625 L
.03879 .1831 L
.04015 .18887 L
.04143 .19279 L
.04262 .19518 L
.04376 .19643 L
.04498 .19675 L
.04614 .19619 L
.0472 .19502 L
.04843 .19297 L
.04978 .19003 L
.05224 .18325 L
.06244 .14751 L
.07302 .11396 L
.07883 .0995 L
.08429 .08836 L
.08941 .07987 L
.09493 .07248 L
.09992 .06714 L
.10458 .06311 L
.10955 .05966 L
.11408 .05714 L
.11912 .05493 L
.12452 .05314 L
.1297 .05189 L
.13263 .05136 L
.13534 .05098 L
.1377 .05072 L
.13906 .05061 L
.1403 .05052 L
.14161 .05045 L
.1423 .05042 L
.14303 .0504 L
.14425 .05038 L
.14494 .05038 L
.14558 .05038 L
.14686 .0504 L
.1475 .05042 L
.14821 .05045 L
.14946 .05052 L
.15063 .05061 L
.15201 .05075 L
.15327 .0509 L
.15611 .05137 L
.15854 .05194 L
.1612 .05276 L
Mistroke
.16371 .05377 L
.16604 .05496 L
.17498 .06153 L
.17967 .06505 L
.18204 .06643 L
.18339 .06706 L
.18463 .06753 L
.18601 .06794 L
.18677 .06811 L
.18749 .06824 L
.18876 .0684 L
.18948 .06844 L
.19015 .06846 L
.19132 .06844 L
.19261 .06834 L
.19326 .06826 L
.19396 .06816 L
.19522 .06792 L
.19776 .0673 L
.20043 .06647 L
.20519 .06472 L
.22381 .0577 L
.22874 .05627 L
.23338 .05516 L
.23595 .05464 L
.23873 .05416 L
.24105 .05383 L
.24359 .05355 L
.24475 .05344 L
.246 .05335 L
.24717 .05328 L
.24824 .05323 L
.24945 .0532 L
.25077 .0532 L
.25201 .05322 L
.25316 .05327 L
.25421 .05333 L
.25519 .05341 L
.25627 .05352 L
.25743 .05367 L
.2598 .05409 L
.26197 .05462 L
.26445 .0554 L
.2667 .05629 L
.27176 .05895 L
.28087 .06546 L
.28597 .06923 L
.28866 .071 L
.29151 .0726 L
.294 .07375 L
Mistroke
.29532 .07425 L
.29674 .0747 L
.29804 .07504 L
.29923 .07529 L
.30043 .07548 L
.30156 .07561 L
.30281 .07569 L
.30351 .07571 L
.30416 .07571 L
.30534 .07568 L
.3066 .07559 L
.30772 .07548 L
.30877 .07533 L
.31116 .0749 L
.31374 .07429 L
.31609 .07363 L
.32138 .07188 L
.33978 .06508 L
.34904 .06212 L
.35888 .05957 L
.36966 .05746 L
.37964 .05603 L
.38902 .05503 L
.39913 .0542 L
.41741 .05309 L
.43747 .05214 L
.45857 .05136 L
.47833 .05082 L
.4967 .05046 L
.50723 .05031 L
.51717 .05019 L
.53576 .05002 L
.55579 .04988 L
.57425 .04979 L
.59303 .04972 L
.6037 .04969 L
.61367 .04967 L
.61866 .04967 L
.62409 .04966 L
.62888 .04965 L
.63398 .04965 L
.63903 .04964 L
.6436 .04964 L
.64581 .04964 L
.6482 .04964 L
.65046 .04964 L
.65252 .04964 L
.6549 .04964 L
.65622 .04964 L
.65746 .04964 L
Mistroke
.6586 .04964 L
.65966 .04964 L
.66082 .04964 L
.66206 .04964 L
.66329 .04964 L
.66399 .04964 L
.66463 .04964 L
.66703 .04964 L
.66837 .04964 L
.66984 .04964 L
.67251 .04964 L
.6778 .04964 L
.68344 .04964 L
.69359 .04965 L
.715 .04967 L
.73516 .04969 L
.7737 .04974 L
.81469 .0498 L
.85417 .04986 L
.89213 .04991 L
.93254 .04996 L
.97144 .05001 L
.97619 .05001 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.02846 .0835 L
.03068 .11052 L
.03279 .13165 L
.03398 .14163 L
.03527 .15085 L
.03754 .16307 L
.03882 .16795 L
.03952 .17005 L
.04018 .17168 L
.04134 .17378 L
.04262 .17508 L
.04384 .17545 L
.04453 .17532 L
.04517 .17501 L
.04635 .17399 L
.04761 .17237 L
.05 .16807 L
.05217 .16318 L
.06244 .13558 L
.07287 .11021 L
.07835 .09947 L
.08414 .09007 L
.08922 .08332 L
.09479 .0773 L
.10458 .06957 L
.10982 .06663 L
.11478 .06445 L
.11924 .06293 L
.12409 .06167 L
.12659 .06117 L
.12936 .06072 L
.13075 .06054 L
.13224 .06037 L
.13354 .06025 L
.13495 .06014 L
.13559 .06011 L
.13628 .06007 L
.13751 .06002 L
.13823 .06 L
.13892 .05999 L
.1402 .05999 L
.1414 .06001 L
.1425 .06005 L
.14372 .06011 L
.145 .0602 L
.14621 .06031 L
.14753 .06047 L
.14994 .06083 L
.15227 .06132 L
Mistroke
.15444 .0619 L
.15702 .0628 L
.15935 .06385 L
.16204 .06542 L
.16458 .06731 L
.17331 .07692 L
.17794 .08222 L
.18053 .08447 L
.18176 .0853 L
.18289 .08592 L
.18414 .08645 L
.1848 .08667 L
.18549 .08685 L
.18667 .08705 L
.18796 .08714 L
.18913 .08709 L
.1904 .08693 L
.19159 .08668 L
.19268 .08638 L
.19509 .0855 L
.19772 .08427 L
.20301 .08132 L
.22149 .07086 L
.2268 .06854 L
.2318 .0667 L
.23634 .06532 L
.24114 .06414 L
.24638 .06315 L
.25121 .06249 L
.25389 .06221 L
.2564 .062 L
.25915 .06183 L
.26056 .06176 L
.26211 .06169 L
.26334 .06165 L
.26466 .06161 L
.26539 .0616 L
.26606 .06159 L
.26738 .06157 L
.26852 .06157 L
.26976 .06157 L
.27106 .06158 L
.27226 .0616 L
.27295 .06162 L
.2737 .06164 L
.27506 .06169 L
.27761 .06182 L
.27905 .06192 L
.28058 .06204 L
.28332 .06231 L
Mistroke
.28827 .06295 L
.2929 .06372 L
.30344 .06595 L
.34223 .07381 L
.38347 .08375 L
.40408 .09081 L
.4232 .09664 L
.4417 .10068 L
.45204 .1023 L
.46141 .10346 L
.48068 .10521 L
.49152 .10591 L
.5015 .1064 L
.5062 .10659 L
.51125 .10675 L
.5156 .10687 L
.52034 .10696 L
.52323 .107 L
.52589 .10703 L
.52844 .10706 L
.52973 .10706 L
.53042 .10707 L
.53115 .10707 L
.53243 .10707 L
.5336 .10707 L
.53486 .10707 L
.53557 .10707 L
.53624 .10707 L
.53745 .10707 L
.53854 .10706 L
.53981 .10706 L
.54101 .10705 L
.5434 .10703 L
.54564 .107 L
.55074 .10693 L
.5557 .10683 L
.56104 .10671 L
.57949 .10615 L
.62079 .10446 L
.66057 .10257 L
.69884 .10067 L
.73955 .09866 L
.77876 .09679 L
.82041 .0949 L
.86055 .09317 L
.89917 .09161 L
.94025 .09006 L
.97619 .08881 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.02846 .08432 L
.03279 .13778 L
.03523 .16222 L
.03754 .18126 L
.0402 .19822 L
.04135 .20393 L
.04262 .20912 L
.04386 .2131 L
.04502 .21591 L
.04624 .21796 L
.04756 .2192 L
.04878 .21951 L
.04994 .21915 L
.05099 .21831 L
.05212 .21692 L
.05348 .21468 L
.05471 .21218 L
.05748 .20529 L
.06244 .19018 L
.07229 .15835 L
.08269 .13001 L
.08812 .11825 L
.09409 .10766 L
.09958 .09981 L
.10458 .09402 L
.10937 .08953 L
.11458 .08566 L
.12009 .08253 L
.12256 .0814 L
.1253 .08035 L
.13017 .07892 L
.13284 .07837 L
.13406 .07817 L
.13535 .078 L
.13646 .07788 L
.13768 .07778 L
.13879 .07771 L
.13982 .07768 L
.14105 .07767 L
.14216 .07769 L
.14344 .07775 L
.14465 .07785 L
.1458 .07798 L
.14704 .07816 L
.14928 .07861 L
.15064 .07897 L
.15194 .07937 L
.15437 .08033 L
.15692 .08168 L
Mistroke
.15929 .08332 L
.16189 .08566 L
.16466 .08894 L
.16965 .09733 L
.17434 .10757 L
.17888 .11724 L
.1811 .12108 L
.18311 .12386 L
.18419 .12505 L
.18537 .12611 L
.18661 .12696 L
.18778 .12753 L
.18907 .1279 L
.18973 .12799 L
.19044 .12802 L
.19171 .12791 L
.1929 .12762 L
.19417 .12714 L
.1955 .12647 L
.19788 .1249 L
.20323 .1202 L
.22172 .10177 L
.23129 .0947 L
.23664 .09185 L
.23917 .09078 L
.2415 .08998 L
.2437 .08937 L
.24483 .08913 L
.24604 .08891 L
.24725 .08875 L
.24838 .08866 L
.24907 .08862 L
.24973 .08861 L
.25096 .08865 L
.25203 .08874 L
.25317 .0889 L
.25415 .0891 L
.25523 .0894 L
.25638 .0898 L
.25762 .09034 L
.25988 .09167 L
.26227 .09361 L
.26482 .0964 L
.26724 .0998 L
.26943 .10359 L
.27481 .11575 L
.27989 .13037 L
.29013 .16204 L
.2953 .1752 L
.29827 .1812 L
Mistroke
.30098 .18558 L
.30353 .18873 L
.30596 .1909 L
.30729 .19176 L
.30852 .19236 L
.30922 .19263 L
.30987 .19282 L
.31061 .19298 L
.31131 .19308 L
.31248 .19314 L
.31373 .19306 L
.31479 .19288 L
.31595 .19257 L
.31721 .19213 L
.31855 .19153 L
.32097 .19018 L
.33062 .18255 L
.33942 .17466 L
.34868 .16732 L
.35376 .16408 L
.35852 .16159 L
.36365 .1595 L
.36931 .15782 L
.37411 .15681 L
.37928 .15604 L
.38879 .15504 L
.39895 .15392 L
.40478 .15305 L
.41008 .15205 L
.42044 .14956 L
.46009 .13749 L
.47929 .1328 L
.50009 .1291 L
.51998 .12651 L
.54103 .12439 L
.56084 .1228 L
.57893 .12166 L
.5984 .12073 L
.60924 .12033 L
.61929 .12003 L
.63833 .1196 L
.64838 .11943 L
.65908 .1193 L
.6694 .11921 L
.67521 .11917 L
.68054 .11915 L
.68523 .11913 L
.68789 .11912 L
.69037 .11912 L
.69172 .11912 L
Mistroke
.69299 .11912 L
.69413 .11911 L
.69537 .11911 L
.69602 .11911 L
.69673 .11911 L
.69746 .11911 L
.69816 .11911 L
.6994 .11911 L
.70009 .11911 L
.70073 .11911 L
.70202 .11911 L
.70323 .11912 L
.70549 .11912 L
.70793 .11912 L
.71057 .11913 L
.71533 .11914 L
.71971 .11916 L
.72978 .1192 L
.74043 .11927 L
.77839 .11959 L
.8188 .12001 L
.85769 .12043 L
.89904 .12087 L
.93888 .12126 L
.97619 .12159 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.02499 .03292 L
.02605 .04714 L
.02729 .05966 L
.02846 .06756 L
.02954 .07202 L
.03053 .0743 L
.03163 .07537 L
.03279 .07538 L
.03395 .07462 L
.0352 .07326 L
.03746 .06998 L
.04262 .0614 L
.0521 .04749 L
.05746 .04147 L
.06244 .03698 L
.0679 .03307 L
.07373 .02985 L
.07935 .02746 L
.08445 .02578 L
.08943 .02449 L
.09481 .0234 L
.0999 .0226 L
.10458 .02203 L
.10928 .02157 L
.11432 .02119 L
.11907 .0209 L
.1234 .0207 L
.12849 .02052 L
.13117 .02044 L
.13402 .02038 L
.1365 .02033 L
.13924 .02028 L
.14173 .02025 L
.14407 .02023 L
.14524 .02022 L
.1465 .02021 L
.14769 .02021 L
.14876 .0202 L
.15003 .0202 L
.15075 .0202 L
.1514 .0202 L
.15262 .0202 L
.1539 .02021 L
.15513 .02021 L
.15645 .02022 L
.15769 .02023 L
.15883 .02024 L
.16161 .02028 L
.16425 .02032 L
Mistroke
.17396 .02056 L
.17819 .02066 L
.17935 .02068 L
.18057 .0207 L
.18162 .02071 L
.18275 .02072 L
.18398 .02073 L
.18512 .02073 L
.18581 .02073 L
.18647 .02074 L
.18771 .02073 L
.18887 .02073 L
.18994 .02072 L
.19112 .02072 L
.19237 .0207 L
.19723 .02064 L
.2026 .02056 L
.221 .02026 L
.22593 .02019 L
.23112 .02014 L
.2356 .0201 L
.24039 .02006 L
.24556 .02003 L
.25036 .02001 L
.2533 .02 L
.25607 .01999 L
.26126 .01998 L
.27961 .01996 L
.29003 .01994 L
.29513 .01993 L
.29977 .01993 L
.30437 .01992 L
.30938 .01992 L
.31213 .01992 L
.31467 .01992 L
.3171 .01992 L
.31845 .01991 L
.31969 .01991 L
.3209 .01991 L
.32217 .01991 L
.32345 .01991 L
.32417 .01991 L
.32485 .01991 L
.32607 .01991 L
.32719 .01991 L
.32848 .01991 L
.32969 .01991 L
.33103 .01991 L
.33245 .01991 L
.33499 .01992 L
Mistroke
.33773 .01992 L
.34074 .01992 L
.34595 .01992 L
.35089 .01992 L
.36017 .01993 L
.37016 .01994 L
.38105 .01995 L
.42172 .02002 L
.44053 .02005 L
.46087 .02007 L
.48229 .02009 L
.50247 .0201 L
.52242 .02011 L
.53259 .02012 L
.54349 .02012 L
.55377 .02012 L
.56315 .02012 L
.56766 .02012 L
.57257 .02013 L
.57686 .02013 L
.58148 .02013 L
.58634 .02013 L
.59089 .02013 L
.59353 .02013 L
.59497 .02013 L
.59631 .02013 L
.59755 .02013 L
.59868 .02013 L
.59993 .02013 L
.60062 .02013 L
.60127 .02013 L
.60249 .02013 L
.60318 .02013 L
.60382 .02013 L
.60512 .02013 L
.60585 .02013 L
.60652 .02013 L
.60771 .02013 L
.609 .02013 L
.61136 .02013 L
.61411 .02013 L
.61703 .02013 L
.62229 .02013 L
.63261 .02013 L
.64375 .02012 L
.66394 .02012 L
.70502 .02011 L
.74458 .02011 L
.78262 .0201 L
.82312 .02008 L
Mistroke
.8621 .02007 L
.90353 .02006 L
.94345 .02005 L
.97619 .02004 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.02605 .04946 L
.02846 .08098 L
.02962 .09306 L
.03072 .10223 L
.03171 .1086 L
.03279 .11363 L
.03397 .11713 L
.03527 .11896 L
.03592 .11922 L
.03663 .11909 L
.0379 .11799 L
.03916 .11607 L
.04036 .1137 L
.04262 .10835 L
.05221 .0833 L
.06244 .06226 L
.06792 .05397 L
.07289 .04795 L
.08259 .03941 L
.08803 .03604 L
.09391 .03324 L
.09947 .03123 L
.10458 .0298 L
.10928 .02876 L
.11432 .02789 L
.11907 .02725 L
.1234 .02679 L
.12849 .02638 L
.13117 .02621 L
.13402 .02606 L
.1365 .02595 L
.13924 .02586 L
.14173 .02579 L
.14407 .02575 L
.14524 .02573 L
.1465 .02572 L
.14769 .02571 L
.14876 .02571 L
.15003 .02571 L
.15075 .02571 L
.1514 .02572 L
.15262 .02573 L
.1539 .02574 L
.15513 .02577 L
.15645 .0258 L
.15883 .02587 L
.16166 .02599 L
.16425 .02613 L
.17321 .02684 L
Mistroke
.17558 .02703 L
.17813 .02721 L
.1793 .02728 L
.18054 .02734 L
.18161 .02738 L
.18275 .02742 L
.18403 .02745 L
.18523 .02747 L
.18595 .02748 L
.18664 .02748 L
.18794 .02748 L
.1891 .02747 L
.19018 .02745 L
.19137 .02743 L
.19263 .0274 L
.19698 .02724 L
.20178 .02701 L
.2126 .02646 L
.22252 .02601 L
.23197 .02569 L
.23671 .02556 L
.2419 .02545 L
.24713 .02537 L
.25001 .02533 L
.25272 .0253 L
.25525 .02528 L
.25799 .02526 L
.26277 .02523 L
.28229 .02515 L
.30374 .02502 L
.31358 .02497 L
.319 .02495 L
.32414 .02493 L
.32891 .02492 L
.3341 .0249 L
.33883 .0249 L
.3432 .02489 L
.34561 .02489 L
.34782 .02489 L
.34898 .02489 L
.35025 .02489 L
.35089 .02489 L
.35157 .02489 L
.35281 .02489 L
.35397 .02489 L
.35524 .02489 L
.35643 .02489 L
.35754 .02489 L
.35853 .02489 L
.35963 .02489 L
Mistroke
.36184 .02489 L
.36452 .02489 L
.36696 .02489 L
.37247 .0249 L
.37758 .02491 L
.38243 .02492 L
.40225 .02496 L
.42064 .02502 L
.45979 .02512 L
.5014 .0252 L
.52228 .02523 L
.54148 .02525 L
.56024 .02527 L
.58005 .02528 L
.58954 .02529 L
.59971 .02529 L
.60923 .0253 L
.61804 .0253 L
.62823 .0253 L
.6336 .0253 L
.6393 .0253 L
.64424 .0253 L
.64887 .0253 L
.65152 .0253 L
.65395 .0253 L
.65522 .0253 L
.65662 .0253 L
.65732 .0253 L
.65807 .0253 L
.65878 .0253 L
.65943 .0253 L
.66062 .0253 L
.66174 .0253 L
.66296 .0253 L
.66428 .0253 L
.66566 .0253 L
.66697 .0253 L
.66942 .0253 L
.67382 .0253 L
.67863 .0253 L
.68386 .0253 L
.68942 .0253 L
.69943 .0253 L
.7209 .02529 L
.74108 .02529 L
.7797 .02527 L
.82078 .02525 L
.86034 .02523 L
.89838 .02521 L
.93888 .02519 L
Mistroke
.97619 .02518 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.02605 .04952 L
.02846 .08168 L
.02962 .09439 L
.03072 .10434 L
.03171 .11148 L
.03279 .11733 L
.03397 .12165 L
.03527 .12418 L
.03592 .1247 L
.03663 .12479 L
.0379 .12393 L
.03916 .12206 L
.04036 .11963 L
.04262 .11395 L
.05221 .08663 L
.06244 .0637 L
.06792 .05472 L
.07289 .04823 L
.07794 .04295 L
.08259 .03907 L
.08803 .03548 L
.09391 .03251 L
.0991 .0305 L
.10458 .02886 L
.10954 .02771 L
.11406 .02689 L
.11928 .02615 L
.12422 .02561 L
.12878 .02523 L
.133 .02496 L
.13763 .02474 L
.13997 .02465 L
.14255 .02458 L
.1449 .02453 L
.14623 .02451 L
.14747 .02449 L
.14878 .02448 L
.14997 .02447 L
.15063 .02447 L
.15135 .02447 L
.15264 .02447 L
.15376 .02447 L
.15498 .02449 L
.15626 .0245 L
.15746 .02452 L
.1596 .02457 L
.1619 .02464 L
.16457 .02475 L
.16749 .02489 L
Mistroke
.1728 .02521 L
.17758 .02547 L
.17889 .02552 L
.18028 .02557 L
.18146 .02561 L
.18275 .02563 L
.18345 .02565 L
.18409 .02565 L
.18482 .02566 L
.18551 .02566 L
.18675 .02566 L
.18744 .02566 L
.18808 .02566 L
.18924 .02564 L
.19052 .02562 L
.1931 .02556 L
.19793 .02541 L
.20247 .02524 L
.2127 .02482 L
.22345 .02446 L
.23312 .02421 L
.23859 .02411 L
.24367 .02404 L
.24837 .02399 L
.25263 .02396 L
.255 .02394 L
.25755 .02393 L
.26219 .02391 L
.30316 .02376 L
.313 .0237 L
.32356 .02365 L
.33352 .02362 L
.34262 .0236 L
.34746 .02359 L
.35194 .02358 L
.35686 .02358 L
.35938 .02358 L
.36209 .02357 L
.36445 .02357 L
.36662 .02357 L
.36882 .02357 L
.37087 .02357 L
.37312 .02357 L
.37431 .02357 L
.37559 .02357 L
.37623 .02357 L
.37692 .02357 L
.37819 .02357 L
.37942 .02357 L
.38056 .02357 L
Mistroke
.38181 .02357 L
.38299 .02357 L
.38406 .02357 L
.38522 .02357 L
.38782 .02357 L
.39024 .02357 L
.39462 .02357 L
.3993 .02357 L
.41993 .02359 L
.46153 .02362 L
.50162 .02364 L
.54019 .02366 L
.56014 .02367 L
.58121 .02368 L
.60086 .02368 L
.6192 .02368 L
.62966 .02368 L
.63957 .02369 L
.64846 .02369 L
.65345 .02369 L
.65813 .02369 L
.66266 .02369 L
.66754 .02369 L
.67018 .02369 L
.67162 .02369 L
.67296 .02369 L
.6742 .02369 L
.67533 .02369 L
.67658 .02369 L
.67727 .02369 L
.67792 .02369 L
.67913 .02369 L
.67982 .02369 L
.68047 .02369 L
.68177 .02369 L
.6825 .02369 L
.68317 .02369 L
.68436 .02369 L
.68565 .02369 L
.68801 .02369 L
.69075 .02369 L
.69368 .02369 L
.69893 .02369 L
.70431 .02369 L
.70926 .02369 L
.7204 .02369 L
.74059 .02368 L
.78015 .02368 L
.81819 .02367 L
.85869 .02367 L
Mistroke
.89767 .02366 L
.9391 .02365 L
.97619 .02365 L
Mfstroke
.601 0 1 r
.02381 .01472 m
.02605 .04937 L
.02729 .06622 L
.02846 .07978 L
.02954 .08986 L
.03072 .09781 L
.0318 .10243 L
.03279 .1048 L
.03396 .10574 L
.03506 .10524 L
.03626 .10362 L
.03756 .10107 L
.04262 .08795 L
.0521 .06463 L
.05746 .05453 L
.06244 .04704 L
.0679 .04057 L
.07373 .03528 L
.07935 .03139 L
.08445 .02868 L
.08943 .02661 L
.09481 .02488 L
.0999 .02361 L
.10458 .0227 L
.10928 .02198 L
.11432 .02138 L
.11907 .02094 L
.1234 .02062 L
.12849 .02033 L
.13402 .02009 L
.13924 .01993 L
.14176 .01987 L
.14407 .01983 L
.14628 .01979 L
.1487 .01976 L
.15113 .01974 L
.15246 .01973 L
.15369 .01972 L
.15487 .01972 L
.15598 .01972 L
.15698 .01972 L
.15806 .01972 L
.15924 .01972 L
.16049 .01972 L
.16156 .01973 L
.16273 .01974 L
.16541 .01976 L
.16786 .01979 L
.17338 .01987 L
.17582 .0199 L
Mistroke
.17711 .01991 L
.17848 .01993 L
.1798 .01994 L
.181 .01994 L
.1822 .01995 L
.18333 .01995 L
.1845 .01995 L
.18575 .01995 L
.18693 .01994 L
.188 .01994 L
.18926 .01993 L
.19063 .01992 L
.19312 .0199 L
.20345 .01977 L
.21299 .01965 L
.22194 .01955 L
.23136 .01947 L
.23636 .01944 L
.24175 .01942 L
.2471 .0194 L
.24979 .01939 L
.25272 .01939 L
.25524 .01938 L
.25793 .01938 L
.25924 .01938 L
.26047 .01938 L
.26277 .01938 L
.26393 .01938 L
.26517 .01938 L
.26742 .01938 L
.27252 .01938 L
.27384 .01937 L
.27528 .01937 L
.27791 .01937 L
.28046 .01937 L
.28282 .01937 L
.28708 .01937 L
.29177 .01936 L
.30129 .01935 L
.31149 .01933 L
.32224 .01931 L
.33219 .01929 L
.34146 .01928 L
.35038 .01928 L
.35537 .01927 L
.35991 .01927 L
.3649 .01927 L
.3703 .01927 L
.37537 .01927 L
.38012 .01926 L
Mistroke
.38467 .01926 L
.38956 .01926 L
.39235 .01926 L
.395 .01926 L
.39997 .01926 L
.40249 .01926 L
.40519 .01926 L
.40649 .01926 L
.40773 .01926 L
.40882 .01926 L
.41003 .01926 L
.41067 .01926 L
.41136 .01926 L
.41209 .01926 L
.41277 .01926 L
.4141 .01926 L
.4153 .01926 L
.41603 .01926 L
.4167 .01926 L
.41744 .01926 L
.41823 .01926 L
.41955 .01926 L
.421 .01926 L
.42335 .01926 L
.42592 .01926 L
.4311 .01926 L
.44036 .01926 L
.46122 .01926 L
.50181 .01927 L
.54087 .01927 L
.56223 .01927 L
.57203 .01927 L
.58239 .01927 L
.59193 .01927 L
.60242 .01927 L
.61196 .01927 L
.62087 .01927 L
.62586 .01927 L
.62849 .01927 L
.63129 .01927 L
.63399 .01927 L
.63642 .01927 L
.6376 .01927 L
.63887 .01927 L
.64007 .01927 L
.64118 .01927 L
.64225 .01927 L
.64341 .01927 L
.64449 .01927 L
.64548 .01927 L
Mistroke
.64665 .01927 L
.64791 .01927 L
.6502 .01927 L
.6526 .01927 L
.65515 .01927 L
.65972 .01927 L
.66463 .01927 L
.66912 .01927 L
.67924 .01927 L
.69754 .01927 L
.71652 .01927 L
.73724 .01927 L
.77787 .01927 L
.81699 .01927 L
.85856 .01927 L
.89861 .01926 L
.93715 .01926 L
.97619 .01926 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.02846 .08429 L
.03279 .13701 L
.03527 .16055 L
.03754 .17721 L
.03879 .18446 L
.04015 .19076 L
.04143 .19527 L
.04262 .19826 L
.04376 .20015 L
.04498 .2012 L
.04614 .20134 L
.0472 .20083 L
.04843 .19955 L
.04913 .19853 L
.04978 .19743 L
.05224 .19205 L
.05718 .17758 L
.06244 .16022 L
.07382 .1259 L
.07941 .11239 L
.08454 .102 L
.09417 .08716 L
.09923 .08138 L
.10458 .07649 L
.10945 .07295 L
.11406 .07028 L
.11937 .06789 L
.12422 .06626 L
.12643 .06567 L
.12878 .06515 L
.13081 .06477 L
.133 .06444 L
.13422 .06429 L
.13534 .06417 L
.13648 .06408 L
.13754 .064 L
.13871 .06395 L
.13998 .06391 L
.14122 .0639 L
.14192 .06391 L
.14255 .06392 L
.14374 .06396 L
.14486 .06403 L
.14608 .06413 L
.1474 .06427 L
.14878 .06446 L
.15008 .06468 L
.15253 .06521 L
.15482 .06588 L
Mistroke
.15694 .06667 L
.15926 .06778 L
.16174 .06928 L
.16444 .07139 L
.16736 .07429 L
.17265 .08094 L
.17512 .08421 L
.17777 .08738 L
.18005 .08964 L
.18126 .0906 L
.18253 .09144 L
.18387 .09212 L
.1851 .09257 L
.18625 .09284 L
.18752 .09299 L
.18865 .093 L
.18987 .09288 L
.19101 .09266 L
.19206 .09238 L
.1945 .09148 L
.19716 .09017 L
.20251 .08693 L
.21356 .07965 L
.22359 .07405 L
.22845 .07188 L
.2337 .06994 L
.23825 .0686 L
.24324 .06746 L
.24598 .06698 L
.24854 .06662 L
.25125 .06632 L
.25277 .0662 L
.25415 .06611 L
.25543 .06604 L
.25662 .066 L
.25793 .06598 L
.25858 .06598 L
.25931 .06598 L
.26052 .066 L
.26183 .06604 L
.26307 .06611 L
.2642 .06619 L
.26548 .0663 L
.26668 .06643 L
.26893 .06675 L
.27136 .0672 L
.27399 .06784 L
.27873 .06941 L
.2831 .07136 L
.29315 .07741 L
Mistroke
.30379 .08479 L
.31321 .09055 L
.32334 .09517 L
.33291 .09829 L
.34165 .10066 L
.36065 .10662 L
.3714 .11125 L
.38138 .11618 L
.40019 .12502 L
.40534 .12692 L
.41078 .12856 L
.41543 .12965 L
.42053 .13054 L
.42333 .13089 L
.42588 .13114 L
.42729 .13124 L
.42882 .13133 L
.43027 .1314 L
.43092 .13142 L
.43161 .13144 L
.43284 .13147 L
.434 .13148 L
.43467 .13148 L
.43537 .13148 L
.43663 .13147 L
.43795 .13144 L
.43917 .13141 L
.44052 .13136 L
.44195 .1313 L
.44739 .13096 L
.45253 .13053 L
.46213 .12955 L
.50062 .1252 L
.54155 .12078 L
.58098 .11687 L
.61888 .11387 L
.65924 .11145 L
.69809 .10965 L
.73938 .10816 L
.77917 .10699 L
.81743 .10603 L
.85815 .10512 L
.89735 .10432 L
.939 .10352 L
.97619 .10284 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.02499 .03209 L
.02605 .04243 L
.02729 .04753 L
.02846 .04865 L
.02954 .04833 L
.03053 .04752 L
.03279 .04501 L
.03746 .03944 L
.04262 .03416 L
.04725 .03032 L
.05224 .02704 L
.05751 .02433 L
.06244 .02237 L
.06784 .02072 L
.07373 .01936 L
.07929 .0184 L
.08445 .01773 L
.08956 .01721 L
.09419 .01685 L
.09954 .01653 L
.10458 .01629 L
.10923 .01612 L
.11434 .01598 L
.11968 .01587 L
.12466 .01578 L
.12932 .01573 L
.13357 .01568 L
.13848 .01565 L
.14313 .01562 L
.14772 .0156 L
.15278 .01558 L
.15533 .01557 L
.15807 .01557 L
.16045 .01556 L
.16304 .01556 L
.16546 .01556 L
.16772 .01556 L
.1701 .01555 L
.17265 .01555 L
.17693 .01555 L
.18146 .01555 L
.18679 .01555 L
.1917 .01554 L
.20281 .01553 L
.21252 .01552 L
.21788 .01552 L
.22296 .01552 L
.22785 .01551 L
.23319 .01551 L
Mistroke
.23804 .01551 L
.24253 .01551 L
.24493 .01551 L
.24719 .01551 L
.24924 .01551 L
.2514 .01551 L
.25253 .01551 L
.25377 .01551 L
.25489 .01551 L
.25594 .01551 L
.25718 .01551 L
.25831 .01551 L
.25961 .01551 L
.26085 .01551 L
.26199 .01551 L
.26322 .01551 L
.26545 .01551 L
.27052 .01551 L
.27553 .01551 L
.27826 .01551 L
.27959 .01551 L
.28079 .01551 L
.28194 .01551 L
.28302 .01551 L
.28416 .01551 L
.28539 .01551 L
.28666 .01551 L
.2873 .01551 L
.28801 .01551 L
.28925 .01551 L
.29042 .01551 L
.29264 .01551 L
.29467 .01551 L
.29923 .01551 L
.30402 .01551 L
.30912 .01551 L
.31829 .01551 L
.32827 .01551 L
.33904 .01551 L
.34918 .0155 L
.35849 .0155 L
.36738 .0155 L
.37676 .0155 L
.39648 .0155 L
.41483 .0155 L
.43527 .0155 L
.45385 .0155 L
.46381 .0155 L
.47301 .0155 L
.4938 .0155 L
Mistroke
.51254 .0155 L
.53317 .0155 L
.57348 .0155 L
.61227 .0155 L
.65351 .0155 L
.69324 .0155 L
.73145 .0155 L
.77212 .0155 L
.81127 .0155 L
.85287 .0155 L
.89296 .0155 L
.93153 .0155 L
.97255 .0155 L
.97619 .0155 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.02605 .04943 L
.02729 .06647 L
.02846 .08038 L
.02954 .09092 L
.03072 .09943 L
.0318 .10453 L
.03279 .10725 L
.03396 .10845 L
.03506 .10807 L
.03626 .10647 L
.03756 .10384 L
.04262 .09005 L
.0521 .06557 L
.05746 .05501 L
.06244 .04721 L
.0679 .04049 L
.07373 .035 L
.07935 .03098 L
.08445 .02818 L
.08943 .02604 L
.09481 .02426 L
.0999 .02296 L
.10458 .02202 L
.10928 .02128 L
.11432 .02066 L
.11907 .0202 L
.1234 .01988 L
.12849 .01958 L
.13402 .01933 L
.13924 .01916 L
.14407 .01905 L
.1487 .01897 L
.15131 .01894 L
.15369 .01892 L
.1558 .0189 L
.15699 .0189 L
.1581 .01889 L
.15927 .01889 L
.16034 .01889 L
.16157 .01889 L
.16273 .01889 L
.16392 .0189 L
.16523 .0189 L
.1666 .01891 L
.16788 .01892 L
.17262 .01895 L
.17527 .01897 L
.17778 .01899 L
.17917 .019 L
Mistroke
.1799 .019 L
.18068 .019 L
.18141 .019 L
.18206 .01901 L
.18333 .01901 L
.18454 .01901 L
.18567 .01901 L
.1869 .019 L
.18822 .019 L
.18961 .01899 L
.19092 .01898 L
.19338 .01897 L
.20262 .01888 L
.21273 .01877 L
.21826 .01872 L
.22345 .01868 L
.23294 .01863 L
.23798 .01861 L
.2434 .01859 L
.24809 .01858 L
.25045 .01858 L
.25302 .01857 L
.25523 .01857 L
.25759 .01857 L
.26183 .01857 L
.26443 .01856 L
.26718 .01856 L
.2721 .01856 L
.27484 .01856 L
.2774 .01856 L
.28322 .01856 L
.28561 .01856 L
.28821 .01856 L
.29295 .01856 L
.29578 .01856 L
.2984 .01855 L
.30338 .01855 L
.31299 .01854 L
.32203 .01854 L
.34262 .01852 L
.35243 .01851 L
.36278 .0185 L
.37161 .0185 L
.38127 .01849 L
.39153 .01849 L
.40086 .01849 L
.41175 .01849 L
.4218 .01848 L
.44096 .01848 L
.45106 .01848 L
Mistroke
.46175 .01848 L
.47117 .01848 L
.4813 .01848 L
.49086 .01848 L
.49961 .01848 L
.50946 .01848 L
.51861 .01848 L
.52864 .01848 L
.53425 .01848 L
.53934 .01848 L
.54422 .01848 L
.54937 .01848 L
.55377 .01848 L
.55627 .01848 L
.5586 .01848 L
.55989 .01848 L
.56057 .01848 L
.5613 .01848 L
.56193 .01848 L
.56263 .01848 L
.56386 .01848 L
.56505 .01848 L
.56633 .01848 L
.56754 .01848 L
.56865 .01848 L
.56995 .01848 L
.57116 .01848 L
.5739 .01848 L
.57657 .01848 L
.57942 .01848 L
.58967 .01848 L
.60078 .01848 L
.62094 .01848 L
.66188 .01848 L
.7013 .01848 L
.73921 .01848 L
.77957 .01848 L
.81841 .01848 L
.85971 .01848 L
.89949 .01848 L
.93775 .01848 L
.97619 .01848 L
Mfstroke
.696 0 1 r
.02381 .01472 m
.02846 .08431 L
.03279 .13744 L
.03523 .16124 L
.03754 .17918 L
.03881 .18712 L
.0402 .19414 L
.04146 .19912 L
.04262 .20255 L
.04376 .2049 L
.04498 .20636 L
.04614 .20681 L
.0472 .2065 L
.04843 .20536 L
.04913 .20438 L
.04978 .20327 L
.05224 .19768 L
.05718 .18198 L
.06244 .16275 L
.07382 .12454 L
.07941 .10957 L
.08454 .0981 L
.09417 .0818 L
.09923 .07547 L
.10458 .07012 L
.10945 .06625 L
.11406 .06332 L
.11937 .06067 L
.12422 .05884 L
.12878 .05753 L
.133 .05665 L
.1352 .0563 L
.13763 .056 L
.13885 .05588 L
.14017 .05578 L
.14141 .05571 L
.14255 .05567 L
.14383 .05564 L
.14503 .05564 L
.14612 .05566 L
.14729 .0557 L
.14857 .05578 L
.14922 .05583 L
.14993 .05589 L
.15119 .05603 L
.15235 .05619 L
.15463 .05659 L
.15707 .05718 L
.15933 .0579 L
.16148 .05877 L
Mistroke
.16396 .06005 L
.16661 .06179 L
.17138 .0659 L
.17701 .07151 L
.17947 .0737 L
.18218 .07565 L
.18343 .07635 L
.18477 .07696 L
.18604 .0774 L
.18719 .07769 L
.1885 .07789 L
.18923 .07794 L
.18991 .07796 L
.19116 .07792 L
.19179 .07786 L
.19249 .07777 L
.19319 .07765 L
.19393 .0775 L
.19526 .07716 L
.19824 .07615 L
.20363 .07372 L
.21339 .06869 L
.22381 .06391 L
.22915 .06195 L
.23418 .06044 L
.2387 .05936 L
.24103 .0589 L
.24359 .05847 L
.24583 .05817 L
.24824 .05791 L
.24957 .0578 L
.25078 .05772 L
.252 .05767 L
.25316 .05763 L
.25422 .05762 L
.25535 .05762 L
.25631 .05764 L
.25738 .05768 L
.25852 .05774 L
.25975 .05783 L
.26091 .05795 L
.26197 .05808 L
.26445 .05849 L
.2667 .059 L
.2693 .05975 L
.27176 .06064 L
.27613 .06267 L
.28087 .06542 L
.29072 .07183 L
.29594 .07476 L
Mistroke
.29883 .07604 L
.30156 .077 L
.30412 .07766 L
.30557 .07793 L
.30627 .07804 L
.30692 .07812 L
.30816 .07825 L
.30929 .07832 L
.3105 .07835 L
.31181 .07834 L
.31297 .07829 L
.31425 .07819 L
.31558 .07806 L
.31682 .07789 L
.32141 .07705 L
.32673 .07574 L
.33157 .07436 L
.34245 .07117 L
.35171 .06875 L
.36155 .06669 L
.36668 .06583 L
.37234 .06503 L
.38231 .06397 L
.39242 .06319 L
.40168 .06263 L
.42254 .06151 L
.44308 .06044 L
.46218 .05955 L
.48062 .05887 L
.50031 .05834 L
.51056 .05813 L
.52167 .05794 L
.54183 .05766 L
.56172 .05746 L
.58277 .05729 L
.59221 .05723 L
.60236 .05718 L
.61186 .05714 L
.62067 .05711 L
.63081 .05708 L
.63661 .05707 L
.64186 .05706 L
.6516 .05705 L
.65695 .05704 L
.65955 .05704 L
.66197 .05704 L
.66442 .05704 L
.66665 .05704 L
.66912 .05704 L
.6705 .05704 L
Mistroke
.67177 .05704 L
.67301 .05704 L
.67432 .05704 L
.67563 .05704 L
.67638 .05704 L
.67708 .05704 L
.67834 .05704 L
.6795 .05704 L
.68014 .05704 L
.68083 .05704 L
.6821 .05704 L
.68454 .05704 L
.68674 .05704 L
.69169 .05704 L
.69627 .05704 L
.70059 .05704 L
.71035 .05705 L
.72066 .05706 L
.73913 .05709 L
.77709 .05716 L
.8175 .05724 L
.8564 .05732 L
.89775 .05741 L
.93758 .05748 L
.9759 .05755 L
.97619 .05755 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.02846 .08429 L
.03279 .13705 L
.03527 .16069 L
.03754 .17753 L
.03879 .18491 L
.04015 .19138 L
.04143 .19608 L
.04262 .19926 L
.04376 .20134 L
.04498 .20259 L
.04614 .20291 L
.0472 .20256 L
.04843 .20146 L
.04913 .20054 L
.04978 .19951 L
.05224 .19438 L
.05718 .18016 L
.06244 .16275 L
.07382 .12783 L
.07941 .11397 L
.08454 .10327 L
.09417 .08793 L
.09923 .08193 L
.10458 .07685 L
.10945 .07317 L
.11406 .07038 L
.11937 .06788 L
.12422 .06617 L
.12643 .06555 L
.12878 .06499 L
.13081 .06458 L
.133 .06422 L
.13422 .06406 L
.13534 .06393 L
.13648 .06382 L
.13754 .06374 L
.13871 .06367 L
.13998 .06362 L
.14122 .0636 L
.14192 .06359 L
.14255 .0636 L
.14374 .06363 L
.14486 .06369 L
.14608 .06378 L
.1474 .0639 L
.14878 .06408 L
.15008 .06429 L
.15253 .0648 L
.15482 .06544 L
Mistroke
.15694 .06621 L
.15926 .06729 L
.16174 .06877 L
.16444 .07085 L
.16736 .07375 L
.17265 .08052 L
.17777 .08735 L
.18026 .09005 L
.18253 .09192 L
.18367 .09264 L
.1849 .09324 L
.18606 .09366 L
.18714 .09392 L
.18827 .09406 L
.18953 .09408 L
.19084 .09395 L
.19206 .09372 L
.19334 .09336 L
.19469 .09287 L
.19709 .09178 L
.20251 .0886 L
.21271 .08177 L
.22359 .07539 L
.22893 .07292 L
.23396 .07102 L
.23848 .06967 L
.24081 .0691 L
.24337 .06858 L
.24577 .06819 L
.24802 .06791 L
.24926 .0678 L
.25039 .06772 L
.2517 .06766 L
.25294 .06763 L
.254 .06763 L
.25513 .06767 L
.25609 .06771 L
.25716 .0678 L
.2583 .06792 L
.25952 .06808 L
.26175 .0685 L
.26414 .06914 L
.2667 .07007 L
.26911 .0712 L
.27131 .07247 L
.27668 .07659 L
.28177 .08179 L
.29201 .09464 L
.29761 .10164 L
.30286 .10734 L
Mistroke
.30783 .11167 L
.31237 .11464 L
.31496 .11594 L
.31742 .11694 L
.32001 .11776 L
.32285 .11843 L
.32528 .11884 L
.32748 .11911 L
.3287 .11923 L
.33002 .11933 L
.33116 .1194 L
.33241 .11947 L
.33466 .11956 L
.33704 .11963 L
.34129 .11975 L
.34381 .11985 L
.34654 .12 L
.34912 .1202 L
.35151 .12045 L
.35602 .12108 L
.36082 .12201 L
.37076 .12471 L
.38174 .12836 L
.39117 .13135 L
.39631 .13268 L
.4011 .13365 L
.40361 .13405 L
.4063 .13438 L
.40783 .13453 L
.40928 .13464 L
.41058 .13472 L
.4113 .13475 L
.41198 .13478 L
.41318 .13481 L
.41451 .13482 L
.41579 .13482 L
.41651 .1348 L
.41717 .13479 L
.41835 .13475 L
.41963 .13469 L
.42196 .13453 L
.42452 .1343 L
.4273 .13398 L
.43231 .13327 L
.44169 .13157 L
.46268 .12723 L
.48228 .12362 L
.50375 .12047 L
.54331 .11597 L
.56451 .11402 L
Mistroke
.58381 .11253 L
.62279 .11033 L
.64193 .10956 L
.66271 .1089 L
.68253 .1084 L
.70356 .108 L
.72309 .10772 L
.74138 .10752 L
.76162 .10734 L
.78014 .10723 L
.79912 .10713 L
.81984 .10705 L
.86047 .10694 L
.89959 .10685 L
.94116 .10676 L
.97619 .10667 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .0212 L
.03053 .02077 L
.03279 .02025 L
.04262 .01833 L
.04762 .01761 L
.05293 .01701 L
.05746 .01661 L
.06244 .01626 L
.06792 .01596 L
.07293 .01575 L
.07871 .01557 L
.0842 .01543 L
.08925 .01534 L
.09394 .01527 L
.09909 .01522 L
.10458 .01517 L
.10994 .01514 L
.11487 .01511 L
.12028 .01509 L
.12599 .01507 L
.13096 .01506 L
.13561 .01506 L
.1407 .01505 L
.14616 .01504 L
.14872 .01504 L
.15145 .01504 L
.15634 .01504 L
.15905 .01504 L
.1616 .01504 L
.16439 .01504 L
.16596 .01504 L
.1674 .01504 L
.17244 .01504 L
.17521 .01504 L
.17783 .01504 L
.18026 .01504 L
.18291 .01503 L
.18752 .01503 L
.20645 .01503 L
.21168 .01503 L
.21722 .01503 L
.22241 .01503 L
.22715 .01503 L
.23166 .01503 L
.23658 .01503 L
.23928 .01503 L
Mistroke
.24178 .01503 L
.24433 .01503 L
.24672 .01503 L
.24896 .01503 L
.25022 .01503 L
.25138 .01503 L
.25235 .01503 L
.25343 .01503 L
.25455 .01503 L
.25559 .01503 L
.25682 .01503 L
.25798 .01503 L
.25902 .01503 L
.26015 .01503 L
.26138 .01503 L
.26269 .01503 L
.26503 .01503 L
.27443 .01503 L
.27936 .01503 L
.28184 .01503 L
.28326 .01503 L
.28454 .01503 L
.28578 .01503 L
.28694 .01503 L
.28817 .01503 L
.28886 .01503 L
.28949 .01503 L
.29056 .01503 L
.29173 .01503 L
.29295 .01503 L
.29409 .01503 L
.2963 .01503 L
.29831 .01503 L
.30284 .01503 L
.30763 .01503 L
.31273 .01503 L
.3219 .01503 L
.33188 .01503 L
.34265 .01503 L
.35279 .01503 L
.3621 .01503 L
.37099 .01503 L
.38037 .01503 L
.40009 .01503 L
.41844 .01503 L
.43716 .01503 L
.45746 .01503 L
.47878 .01503 L
.49892 .01503 L
.51838 .01503 L
Mistroke
.53981 .01502 L
.57918 .01502 L
.61949 .01502 L
.65828 .01502 L
.69952 .01502 L
.73925 .01502 L
.77747 .01502 L
.81813 .01502 L
.85728 .01502 L
.89888 .01502 L
.93897 .01502 L
.97619 .01502 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.02846 .08375 L
.03068 .11051 L
.03279 .12993 L
.03398 .138 L
.03527 .14428 L
.03645 .14783 L
.03754 .14948 L
.03871 .14974 L
.04 .14852 L
.04065 .14743 L
.04135 .14597 L
.04262 .14271 L
.0521 .10965 L
.06244 .07853 L
.06829 .06559 L
.07373 .05617 L
.07892 .04907 L
.08445 .04315 L
.08988 .03865 L
.09501 .03536 L
.09996 .03286 L
.10458 .03101 L
.10923 .02952 L
.11434 .02824 L
.11932 .02728 L
.12466 .02649 L
.12962 .02593 L
.13432 .02553 L
.13854 .02527 L
.14313 .02505 L
.14546 .02498 L
.14669 .02494 L
.14798 .02491 L
.14911 .02489 L
.15035 .02487 L
.15148 .02486 L
.15253 .02485 L
.15318 .02485 L
.15388 .02484 L
.15516 .02485 L
.1564 .02485 L
.15755 .02486 L
.15879 .02488 L
.16015 .02491 L
.16157 .02494 L
.1629 .02498 L
.16562 .02508 L
.1682 .02521 L
.17303 .02549 L
Mistroke
.17597 .02566 L
.17874 .02579 L
.18123 .02589 L
.18263 .02593 L
.18391 .02595 L
.18507 .02597 L
.18614 .02598 L
.18733 .02598 L
.18859 .02597 L
.18923 .02597 L
.18992 .02596 L
.19117 .02594 L
.1924 .02591 L
.19352 .02589 L
.19849 .02572 L
.20376 .0255 L
.21336 .02508 L
.22216 .02475 L
.23155 .02448 L
.23648 .02438 L
.24167 .02429 L
.24386 .02426 L
.2462 .02424 L
.24822 .02422 L
.25041 .02421 L
.25175 .0242 L
.25299 .02419 L
.25417 .02419 L
.25542 .02419 L
.25654 .02418 L
.25758 .02418 L
.25873 .02418 L
.25996 .02418 L
.26118 .02419 L
.26187 .02419 L
.26252 .02419 L
.26393 .0242 L
.26523 .0242 L
.26758 .02422 L
.27012 .02424 L
.28118 .02437 L
.28621 .02443 L
.28898 .02446 L
.29159 .02449 L
.29403 .02451 L
.29531 .02451 L
.29667 .02452 L
.29781 .02453 L
.29907 .02453 L
.30022 .02454 L
Mistroke
.30129 .02454 L
.30246 .02454 L
.30373 .02454 L
.30493 .02454 L
.30605 .02454 L
.30715 .02454 L
.30815 .02453 L
.3104 .02452 L
.31282 .02451 L
.31544 .02449 L
.32019 .02446 L
.34088 .02425 L
.36083 .02409 L
.37088 .02403 L
.3819 .02398 L
.39212 .02394 L
.40143 .02392 L
.42235 .02387 L
.44145 .02385 L
.46221 .02382 L
.482 .0238 L
.49199 .0238 L
.50302 .02379 L
.52238 .02378 L
.53326 .02378 L
.54324 .02378 L
.56218 .02377 L
.57291 .02377 L
.58288 .02377 L
.59342 .02377 L
.60336 .02377 L
.61228 .02377 L
.61731 .02377 L
.62195 .02377 L
.62663 .02377 L
.62921 .02377 L
.63165 .02377 L
.63392 .02377 L
.63512 .02377 L
.63639 .02377 L
.63757 .02377 L
.63864 .02377 L
.63972 .02377 L
.64073 .02377 L
.64193 .02377 L
.64324 .02377 L
.64391 .02377 L
.64462 .02377 L
.6459 .02377 L
.64718 .02377 L
Mistroke
.64839 .02377 L
.65065 .02377 L
.65332 .02377 L
.65579 .02377 L
.66137 .02377 L
.67103 .02377 L
.68009 .02377 L
.70071 .02377 L
.73947 .02377 L
.78068 .02378 L
.82038 .02378 L
.85856 .02378 L
.89919 .02378 L
.93831 .02378 L
.97619 .02379 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.02846 .08345 L
.03068 .11026 L
.03279 .13088 L
.03398 .1404 L
.03527 .14894 L
.03635 .15465 L
.03754 .15956 L
.03882 .16334 L
.03952 .16479 L
.04018 .16578 L
.04135 .16675 L
.04262 .16676 L
.04393 .16582 L
.04516 .16422 L
.0465 .16182 L
.04793 .15867 L
.05297 .14474 L
.06244 .11658 L
.06791 .10242 L
.07382 .08953 L
.07904 .0802 L
.08454 .07217 L
.08952 .06631 L
.09498 .06114 L
.10458 .05458 L
.10982 .05205 L
.11478 .05018 L
.11924 .04887 L
.12409 .04777 L
.12936 .0469 L
.13202 .04658 L
.13495 .04631 L
.13745 .04615 L
.13885 .04608 L
.14014 .04604 L
.14127 .04602 L
.14251 .046 L
.1438 .04601 L
.145 .04603 L
.14628 .04606 L
.14692 .04609 L
.14763 .04612 L
.15005 .04628 L
.15142 .04641 L
.15288 .04657 L
.15553 .04696 L
.15819 .04749 L
.16072 .04815 L
.16546 .0499 L
Mistroke
.17049 .05252 L
.17522 .05527 L
.17728 .05635 L
.17946 .0573 L
.1806 .0577 L
.18185 .05807 L
.18299 .05834 L
.18405 .05853 L
.1853 .05868 L
.18648 .05876 L
.18754 .05877 L
.18869 .05874 L
.18994 .05865 L
.19058 .05858 L
.19127 .05849 L
.19366 .05809 L
.1962 .05752 L
.19894 .05679 L
.20389 .0553 L
.21343 .05236 L
.22229 .05002 L
.23189 .04811 L
.23696 .04736 L
.24237 .04674 L
.24511 .04649 L
.24807 .04626 L
.25068 .0461 L
.25344 .04597 L
.25593 .04587 L
.25867 .04579 L
.25987 .04576 L
.26116 .04574 L
.26236 .04572 L
.26349 .04571 L
.2647 .0457 L
.26535 .04569 L
.26604 .04569 L
.26673 .04569 L
.26746 .04569 L
.26876 .04569 L
.26997 .0457 L
.27109 .04572 L
.27232 .04574 L
.27364 .04576 L
.27662 .04585 L
.27944 .04596 L
.28196 .04609 L
.2847 .04627 L
.29516 .04723 L
.30482 .04835 L
Mistroke
.34419 .05203 L
.38204 .0556 L
.4031 .0581 L
.41308 .05909 L
.42235 .05981 L
.43186 .06035 L
.43689 .06056 L
.44224 .06073 L
.44469 .06079 L
.44735 .06084 L
.44969 .06088 L
.45216 .06092 L
.45439 .06095 L
.45684 .06097 L
.45906 .06099 L
.46114 .061 L
.4624 .061 L
.46374 .06101 L
.46489 .06101 L
.46615 .06101 L
.46686 .06101 L
.46751 .06101 L
.46822 .06101 L
.46896 .06101 L
.47022 .06101 L
.47094 .06101 L
.4716 .06101 L
.47289 .06101 L
.47411 .061 L
.47639 .061 L
.48151 .06097 L
.48614 .06094 L
.49042 .06091 L
.50007 .06082 L
.51885 .06058 L
.53949 .06023 L
.57985 .05944 L
.6187 .05869 L
.65999 .05799 L
.69977 .0574 L
.73804 .0569 L
.77876 .05642 L
.81796 .056 L
.85961 .05559 L
.89975 .05522 L
.93837 .05489 L
.97619 .05458 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02079 L
.03279 .02028 L
.04262 .01837 L
.04762 .01766 L
.05293 .01707 L
.0579 .01663 L
.06244 .01632 L
.06743 .01604 L
.0728 .01582 L
.07777 .01565 L
.0825 .01553 L
.08797 .01542 L
.09305 .01534 L
.09863 .01528 L
.10458 .01523 L
.10994 .01519 L
.11487 .01517 L
.12028 .01515 L
.12599 .01513 L
.13096 .01512 L
.13561 .01511 L
.1407 .01511 L
.14335 .0151 L
.14616 .0151 L
.14867 .0151 L
.15145 .0151 L
.154 .0151 L
.15634 .01509 L
.15908 .01509 L
.16052 .01509 L
.16204 .01509 L
.16337 .01509 L
.1646 .01509 L
.16531 .01509 L
.16596 .01509 L
.1667 .01509 L
.1674 .01509 L
.16856 .01509 L
.16984 .01509 L
.17049 .01509 L
.17118 .01509 L
.17243 .01509 L
.17464 .01509 L
.17589 .01509 L
.17706 .01509 L
Mistroke
.17777 .01509 L
.17842 .01509 L
.17916 .01509 L
.17986 .01509 L
.18114 .01509 L
.18186 .01509 L
.18253 .01509 L
.18496 .01509 L
.18618 .01509 L
.18752 .01509 L
.20871 .01509 L
.21874 .01508 L
.228 .01508 L
.23266 .01508 L
.2376 .01508 L
.24255 .01508 L
.24541 .01508 L
.24802 .01508 L
.25273 .01508 L
.2578 .01508 L
.26696 .01508 L
.28592 .01508 L
.29678 .01508 L
.30664 .01508 L
.31607 .01508 L
.32629 .01508 L
.3319 .01508 L
.33708 .01508 L
.34198 .01508 L
.34725 .01508 L
.35233 .01508 L
.35697 .01508 L
.36605 .01508 L
.37113 .01508 L
.37665 .01508 L
.38671 .01508 L
.40646 .01508 L
.41643 .01508 L
.4218 .01508 L
.42745 .01508 L
.43227 .01508 L
.43481 .01508 L
.43753 .01508 L
.44004 .01508 L
.44232 .01508 L
.44342 .01508 L
.44461 .01508 L
.44574 .01508 L
.44678 .01508 L
.44798 .01508 L
Mistroke
.44927 .01508 L
.45048 .01508 L
.4516 .01508 L
.4529 .01508 L
.45363 .01508 L
.45432 .01508 L
.4569 .01508 L
.45962 .01508 L
.46209 .01508 L
.46763 .01508 L
.48689 .01508 L
.50771 .01508 L
.54874 .01508 L
.58824 .01508 L
.62623 .01508 L
.66668 .01508 L
.70561 .01508 L
.74699 .01508 L
.78685 .01508 L
.8252 .01508 L
.86601 .01508 L
.90529 .01508 L
.94306 .01508 L
.97619 .01508 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.02499 .03249 L
.02605 .04454 L
.02729 .05224 L
.02846 .05502 L
.02954 .0555 L
.03053 .05503 L
.03163 .05399 L
.03279 .05258 L
.04262 .03965 L
.04716 .03495 L
.05205 .03086 L
.05742 .02734 L
.06244 .02479 L
.06784 .02267 L
.07373 .02093 L
.07929 .0197 L
.08445 .01882 L
.08956 .01816 L
.09419 .01769 L
.09954 .01727 L
.10458 .01696 L
.10923 .01674 L
.11434 .01656 L
.11968 .01641 L
.12466 .0163 L
.12932 .01623 L
.13357 .01617 L
.13848 .01612 L
.14313 .01609 L
.14772 .01606 L
.15278 .01604 L
.15533 .01603 L
.15807 .01603 L
.15934 .01602 L
.16066 .01602 L
.16191 .01602 L
.16304 .01602 L
.16417 .01602 L
.16524 .01602 L
.16637 .01602 L
.1676 .01602 L
.16867 .01602 L
.1698 .01602 L
.17077 .01602 L
.17184 .01602 L
.17423 .01602 L
.17492 .01602 L
.17558 .01602 L
.17681 .01602 L
Mistroke
.17796 .01602 L
.17903 .01602 L
.18021 .01602 L
.18146 .01602 L
.18271 .01602 L
.18408 .01602 L
.18683 .01601 L
.19177 .01601 L
.20291 .01599 L
.21348 .01597 L
.22309 .01596 L
.22791 .01596 L
.23314 .01595 L
.23808 .01595 L
.24264 .01595 L
.24747 .01595 L
.25022 .01595 L
.2528 .01595 L
.25412 .01594 L
.25551 .01594 L
.25669 .01594 L
.25799 .01594 L
.25872 .01594 L
.25939 .01594 L
.26016 .01594 L
.26088 .01594 L
.26217 .01594 L
.2629 .01594 L
.26357 .01594 L
.26483 .01594 L
.26602 .01594 L
.26826 .01594 L
.27087 .01594 L
.27329 .01594 L
.27438 .01594 L
.2754 .01594 L
.27646 .01594 L
.27764 .01594 L
.27883 .01594 L
.27992 .01594 L
.28111 .01594 L
.28237 .01594 L
.28366 .01594 L
.28484 .01594 L
.28748 .01594 L
.28992 .01594 L
.29223 .01594 L
.30303 .01594 L
.32132 .01594 L
.33172 .01594 L
Mistroke
.34146 .01593 L
.35103 .01593 L
.3564 .01593 L
.36131 .01593 L
.36647 .01593 L
.3721 .01593 L
.38235 .01593 L
.39267 .01593 L
.40203 .01593 L
.41284 .01593 L
.42301 .01593 L
.43279 .01593 L
.43771 .01593 L
.44311 .01593 L
.44772 .01593 L
.45266 .01593 L
.45699 .01593 L
.46158 .01593 L
.46687 .01593 L
.47177 .01593 L
.47703 .01593 L
.48284 .01593 L
.48784 .01593 L
.49322 .01593 L
.50296 .01593 L
.51336 .01593 L
.52302 .01593 L
.5331 .01593 L
.54412 .01593 L
.5646 .01593 L
.58319 .01593 L
.62319 .01593 L
.66168 .01593 L
.70262 .01593 L
.74204 .01593 L
.77995 .01593 L
.82031 .01593 L
.85915 .01593 L
.90045 .01593 L
.94023 .01593 L
.97619 .01593 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.02499 .03293 L
.02605 .04726 L
.02729 .06016 L
.02846 .0687 L
.02954 .07387 L
.03053 .07681 L
.03163 .07853 L
.03279 .07912 L
.03395 .07882 L
.0352 .07782 L
.03638 .07645 L
.03746 .07496 L
.04262 .06653 L
.0529 .05086 L
.06244 .04047 L
.06744 .03646 L
.07277 .03306 L
.07869 .03013 L
.08405 .02808 L
.08912 .02656 L
.09462 .02527 L
.09981 .02434 L
.10458 .02366 L
.10928 .02313 L
.11432 .02269 L
.11907 .02237 L
.1234 .02213 L
.12849 .02193 L
.13117 .02184 L
.13402 .02176 L
.1365 .02171 L
.13924 .02166 L
.14173 .02163 L
.14407 .02161 L
.14524 .0216 L
.1465 .02159 L
.14769 .02159 L
.14876 .02158 L
.15003 .02159 L
.15075 .02159 L
.1514 .02159 L
.15262 .02159 L
.1539 .0216 L
.15513 .02161 L
.15645 .02163 L
.15883 .02166 L
.16166 .02172 L
.16425 .02179 L
.17321 .02213 L
Mistroke
.17558 .02222 L
.17813 .0223 L
.1793 .02233 L
.18054 .02236 L
.18161 .02238 L
.18275 .0224 L
.18403 .02241 L
.18523 .02242 L
.18595 .02242 L
.18664 .02242 L
.18794 .02242 L
.1891 .02241 L
.19018 .0224 L
.19137 .02239 L
.19263 .02237 L
.19698 .02229 L
.20178 .02218 L
.2126 .02191 L
.22252 .02169 L
.23197 .02153 L
.23671 .02147 L
.2419 .02142 L
.24713 .02138 L
.25006 .02137 L
.25272 .02135 L
.2552 .02134 L
.25789 .02134 L
.26277 .02132 L
.26768 .02132 L
.27226 .02131 L
.27729 .0213 L
.28011 .0213 L
.28133 .0213 L
.28269 .0213 L
.28399 .0213 L
.2847 .0213 L
.28537 .0213 L
.28657 .0213 L
.28786 .0213 L
.28854 .0213 L
.28929 .0213 L
.29007 .0213 L
.2908 .0213 L
.2921 .0213 L
.29349 .0213 L
.29625 .0213 L
.29886 .02131 L
.30374 .02132 L
.34218 .02141 L
.38306 .02154 L
Mistroke
.40339 .02163 L
.42243 .02171 L
.43179 .02173 L
.44068 .02176 L
.45092 .02178 L
.46029 .02179 L
.46988 .0218 L
.48011 .02181 L
.48976 .02181 L
.4985 .02182 L
.50338 .02182 L
.50854 .02182 L
.51294 .02182 L
.51543 .02182 L
.51776 .02182 L
.51906 .02182 L
.52046 .02182 L
.52179 .02182 L
.52302 .02182 L
.52413 .02182 L
.52535 .02182 L
.52662 .02182 L
.52782 .02182 L
.52913 .02182 L
.5298 .02182 L
.53052 .02182 L
.533 .02182 L
.5344 .02182 L
.5359 .02182 L
.53859 .02182 L
.54392 .02182 L
.54884 .02182 L
.55995 .02182 L
.58011 .02181 L
.61953 .02179 L
.65744 .02177 L
.6978 .02174 L
.73664 .02172 L
.77794 .0217 L
.81772 .02168 L
.85598 .02165 L
.8967 .02163 L
.9359 .02162 L
.97619 .0216 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.02499 .03215 L
.02605 .04291 L
.02729 .04893 L
.02846 .05082 L
.02954 .051 L
.03053 .0505 L
.03163 .04957 L
.03279 .04835 L
.04262 .03728 L
.05205 .02963 L
.05742 .02653 L
.06244 .02428 L
.06788 .02238 L
.07305 .021 L
.07768 .02002 L
.08274 .01919 L
.08822 .01849 L
.09407 .01793 L
.09958 .01754 L
.10458 .01726 L
.10945 .01706 L
.1146 .01689 L
.119 .01677 L
.12383 .01668 L
.12902 .0166 L
.13459 .01653 L
.13985 .01649 L
.14465 .01646 L
.14693 .01645 L
.14945 .01644 L
.15209 .01643 L
.15329 .01643 L
.15456 .01643 L
.15566 .01642 L
.15686 .01642 L
.15796 .01642 L
.15897 .01642 L
.16018 .01642 L
.16127 .01642 L
.16254 .01642 L
.16373 .01642 L
.16493 .01643 L
.16625 .01643 L
.16891 .01643 L
.17369 .01644 L
.17638 .01645 L
.17786 .01645 L
.17927 .01645 L
.18058 .01645 L
Mistroke
.18131 .01645 L
.182 .01645 L
.18321 .01645 L
.18449 .01645 L
.18574 .01645 L
.18645 .01645 L
.18711 .01645 L
.18987 .01645 L
.19225 .01644 L
.1948 .01644 L
.20594 .01641 L
.21643 .01638 L
.22613 .01637 L
.23107 .01636 L
.23633 .01635 L
.2416 .01635 L
.24463 .01635 L
.24741 .01634 L
.2498 .01634 L
.25241 .01634 L
.25504 .01634 L
.2578 .01634 L
.26024 .01634 L
.26285 .01634 L
.26531 .01634 L
.26754 .01634 L
.2724 .01634 L
.27506 .01634 L
.27755 .01634 L
.28194 .01634 L
.28676 .01634 L
.2968 .01633 L
.30757 .01633 L
.31773 .01633 L
.32309 .01633 L
.32879 .01632 L
.33375 .01632 L
.33923 .01632 L
.34422 .01632 L
.3489 .01632 L
.35359 .01632 L
.35624 .01632 L
.35872 .01632 L
.36134 .01632 L
.36372 .01632 L
.36503 .01632 L
.36573 .01632 L
.36646 .01632 L
.36711 .01632 L
.36781 .01632 L
Mistroke
.36906 .01632 L
.37029 .01632 L
.37146 .01632 L
.37252 .01632 L
.37366 .01632 L
.37491 .01632 L
.37623 .01632 L
.37861 .01632 L
.38331 .01632 L
.38756 .01632 L
.39759 .01632 L
.40682 .01632 L
.42764 .01632 L
.44808 .01632 L
.46715 .01633 L
.48667 .01633 L
.50514 .01633 L
.52551 .01633 L
.54407 .01633 L
.55373 .01633 L
.564 .01633 L
.57276 .01633 L
.58242 .01633 L
.58734 .01633 L
.59003 .01633 L
.59252 .01633 L
.59695 .01633 L
.59929 .01633 L
.6005 .01633 L
.60178 .01633 L
.60245 .01633 L
.60319 .01633 L
.60448 .01633 L
.60521 .01633 L
.60599 .01633 L
.60673 .01633 L
.60741 .01633 L
.60871 .01633 L
.60945 .01633 L
.61013 .01633 L
.61138 .01633 L
.61272 .01633 L
.6154 .01633 L
.61793 .01633 L
.62264 .01633 L
.62732 .01633 L
.63244 .01633 L
.64278 .01633 L
.66127 .01633 L
.68083 .01633 L
Mistroke
.70176 .01633 L
.7432 .01633 L
.78311 .01633 L
.82152 .01633 L
.86237 .01633 L
.90171 .01632 L
.93953 .01632 L
.97619 .01632 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.02846 .08426 L
.03279 .13676 L
.03527 .16001 L
.03754 .17624 L
.03879 .18315 L
.04015 .18902 L
.04143 .19306 L
.04262 .19556 L
.04376 .19693 L
.04498 .19737 L
.04614 .19692 L
.0472 .19585 L
.04843 .19391 L
.04978 .19107 L
.05224 .18444 L
.06244 .14891 L
.07302 .11526 L
.07883 .10071 L
.08429 .0895 L
.08941 .08096 L
.09493 .07352 L
.09992 .06815 L
.10458 .0641 L
.10955 .06062 L
.11408 .05809 L
.11912 .05588 L
.12452 .05409 L
.1297 .05285 L
.13263 .05233 L
.13534 .05195 L
.1377 .0517 L
.13904 .05159 L
.1403 .05151 L
.14095 .05147 L
.14163 .05144 L
.14284 .0514 L
.14415 .05138 L
.14489 .05138 L
.14558 .05139 L
.14686 .05142 L
.1475 .05145 L
.14821 .05148 L
.14946 .05156 L
.15063 .05166 L
.15327 .05197 L
.15475 .0522 L
.15611 .05247 L
.15854 .05306 L
.1612 .05391 L
Mistroke
.16371 .05496 L
.16604 .05617 L
.17498 .06262 L
.17967 .06585 L
.18204 .06704 L
.18338 .06755 L
.18463 .06793 L
.18535 .06809 L
.18602 .06822 L
.18729 .06838 L
.18801 .06843 L
.18866 .06845 L
.18938 .06844 L
.19015 .06841 L
.1914 .06829 L
.19256 .06811 L
.19384 .06786 L
.19522 .06753 L
.20043 .06582 L
.20519 .0639 L
.2142 .06017 L
.22381 .05675 L
.22896 .05529 L
.23364 .05418 L
.23839 .05328 L
.24277 .05263 L
.24521 .05235 L
.24789 .05209 L
.25059 .05189 L
.25206 .05181 L
.25343 .05175 L
.25474 .05171 L
.25597 .05169 L
.25708 .05168 L
.25828 .05168 L
.25959 .0517 L
.26025 .05171 L
.26099 .05173 L
.26227 .05178 L
.26349 .05185 L
.26591 .05203 L
.26817 .05226 L
.27065 .05259 L
.2733 .05304 L
.27872 .05426 L
.28364 .05566 L
.29263 .0586 L
.30214 .06141 L
.30689 .06246 L
.3094 .0629 L
Mistroke
.31211 .06328 L
.31459 .06355 L
.31686 .06373 L
.31795 .06379 L
.31914 .06385 L
.32026 .06389 L
.3213 .06392 L
.32261 .06394 L
.32335 .06394 L
.32402 .06394 L
.32527 .06393 L
.32658 .06392 L
.32776 .06389 L
.32886 .06386 L
.33137 .06376 L
.33654 .0635 L
.34209 .06316 L
.35227 .06258 L
.35506 .06246 L
.35803 .06235 L
.36059 .06227 L
.36193 .06224 L
.36335 .06221 L
.36458 .06218 L
.36592 .06216 L
.36715 .06215 L
.36828 .06214 L
.36946 .06214 L
.37052 .06213 L
.37175 .06213 L
.37292 .06214 L
.3742 .06214 L
.37484 .06215 L
.37555 .06216 L
.37798 .06218 L
.38082 .06222 L
.38347 .06227 L
.38846 .06237 L
.39389 .06248 L
.39638 .06252 L
.39902 .06256 L
.40152 .06259 L
.40377 .06261 L
.40494 .06262 L
.40617 .06262 L
.40722 .06263 L
.40837 .06263 L
.40961 .06263 L
.41031 .06262 L
.41094 .06262 L
Mistroke
.41217 .06261 L
.41333 .0626 L
.41557 .06258 L
.41764 .06255 L
.42232 .06245 L
.42697 .06233 L
.43198 .06216 L
.44103 .06178 L
.46165 .06083 L
.48136 .06 L
.50287 .05929 L
.54256 .05838 L
.56223 .05803 L
.5832 .05773 L
.6046 .0575 L
.62477 .05733 L
.64483 .0572 L
.6633 .05712 L
.68212 .05706 L
.6928 .05703 L
.70278 .05701 L
.71322 .05699 L
.71837 .05699 L
.72312 .05698 L
.73201 .05698 L
.73669 .05697 L
.73912 .05697 L
.74168 .05697 L
.74401 .05697 L
.74656 .05697 L
.74768 .05697 L
.74888 .05697 L
.75 .05697 L
.75104 .05697 L
.75235 .05697 L
.75303 .05697 L
.75376 .05697 L
.75498 .05697 L
.75568 .05697 L
.75633 .05697 L
.75754 .05697 L
.75865 .05697 L
.75992 .05697 L
.76114 .05697 L
.76333 .05697 L
.76567 .05697 L
.76988 .05697 L
.77488 .05697 L
.77941 .05698 L
.79869 .05699 L
Mistroke
.81952 .057 L
.86056 .05704 L
.90009 .05708 L
.9381 .05712 L
.97619 .05715 L
Mfstroke
.933 0 1 r
.02381 .01472 m
.02499 .0325 L
.02605 .04466 L
.02729 .05265 L
.02846 .05575 L
.02954 .05645 L
.03053 .05613 L
.03163 .05519 L
.03279 .05384 L
.04262 .04081 L
.05205 .03171 L
.05742 .02805 L
.06244 .02538 L
.06788 .02315 L
.07305 .02151 L
.07768 .02037 L
.08274 .01938 L
.08822 .01857 L
.09407 .01791 L
.09958 .01745 L
.10458 .01713 L
.10945 .01689 L
.1146 .01669 L
.119 .01656 L
.12383 .01644 L
.12902 .01635 L
.13459 .01627 L
.13985 .01622 L
.14465 .01618 L
.14945 .01616 L
.15188 .01615 L
.15456 .01614 L
.15684 .01613 L
.15803 .01613 L
.15929 .01613 L
.1604 .01612 L
.16161 .01612 L
.16271 .01612 L
.16373 .01612 L
.16503 .01612 L
.16576 .01612 L
.16644 .01612 L
.16768 .01612 L
.16899 .01612 L
.17017 .01612 L
.17127 .01612 L
.17377 .01612 L
.17515 .01612 L
.17647 .01612 L
.17765 .01612 L
Mistroke
.17894 .01612 L
.17967 .01612 L
.18033 .01612 L
.1811 .01612 L
.18182 .01612 L
.1831 .01612 L
.18383 .01612 L
.18449 .01612 L
.18696 .01612 L
.18921 .01612 L
.19425 .01611 L
.20335 .01609 L
.2141 .01607 L
.21882 .01606 L
.22403 .01606 L
.23331 .01605 L
.23839 .01604 L
.24315 .01604 L
.2457 .01604 L
.24838 .01604 L
.25316 .01604 L
.25583 .01604 L
.25831 .01604 L
.26393 .01604 L
.30303 .01603 L
.32298 .01603 L
.33422 .01602 L
.34458 .01602 L
.35385 .01602 L
.36404 .01602 L
.37467 .01602 L
.38461 .01602 L
.39504 .01602 L
.40494 .01602 L
.42349 .01602 L
.43312 .01602 L
.43841 .01602 L
.44337 .01602 L
.44793 .01602 L
.45212 .01602 L
.45677 .01602 L
.45921 .01602 L
.46178 .01602 L
.46301 .01602 L
.46435 .01602 L
.46553 .01602 L
.46677 .01602 L
.4679 .01602 L
.46913 .01602 L
.47026 .01602 L
Mistroke
.47131 .01602 L
.47263 .01602 L
.47388 .01602 L
.475 .01602 L
.47622 .01602 L
.47755 .01602 L
.47896 .01602 L
.4815 .01602 L
.48646 .01602 L
.49113 .01602 L
.49986 .01602 L
.53843 .01602 L
.57945 .01602 L
.61896 .01602 L
.65695 .01602 L
.6974 .01602 L
.73633 .01602 L
.77771 .01602 L
.81757 .01602 L
.85592 .01602 L
.89672 .01602 L
.93601 .01602 L
.97378 .01602 L
.97619 .01602 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.02605 .04944 L
.02729 .06651 L
.02846 .08052 L
.02954 .09124 L
.03072 .10004 L
.0318 .10548 L
.03279 .10854 L
.03396 .11011 L
.03506 .11003 L
.03626 .10869 L
.03756 .10625 L
.0402 .09955 L
.04262 .09264 L
.04759 .07869 L
.0529 .06584 L
.06244 .04863 L
.06786 .04169 L
.07277 .03675 L
.07858 .03224 L
.08405 .02901 L
.08918 .02667 L
.09391 .02499 L
.0991 .02354 L
.10458 .02236 L
.10954 .02155 L
.11406 .02097 L
.11928 .02044 L
.12422 .02006 L
.12878 .01978 L
.133 .01958 L
.13763 .01941 L
.14255 .01928 L
.14493 .01923 L
.14744 .01918 L
.14961 .01915 L
.15192 .01912 L
.15323 .01911 L
.15442 .0191 L
.15563 .01909 L
.15675 .01909 L
.15805 .01908 L
.15873 .01908 L
.15946 .01908 L
.16068 .01908 L
.16137 .01908 L
.16202 .01908 L
.16315 .01908 L
.16438 .01909 L
.16555 .01909 L
Mistroke
.16663 .0191 L
.17083 .01913 L
.17324 .01915 L
.17577 .01917 L
.17811 .01919 L
.17926 .0192 L
.1803 .0192 L
.18148 .01921 L
.18273 .01921 L
.18339 .01921 L
.1841 .01921 L
.1854 .01921 L
.18606 .01921 L
.18678 .0192 L
.18825 .0192 L
.18962 .01919 L
.1909 .01918 L
.1957 .01914 L
.20086 .01909 L
.21052 .01898 L
.21948 .01889 L
.22908 .01882 L
.23415 .0188 L
.23956 .01877 L
.2423 .01876 L
.24526 .01876 L
.24787 .01875 L
.25063 .01874 L
.25312 .01874 L
.25586 .01874 L
.26068 .01873 L
.26318 .01873 L
.26591 .01873 L
.27086 .01873 L
.28016 .01872 L
.2901 .01872 L
.29575 .01872 L
.30107 .01872 L
.31057 .01871 L
.32082 .0187 L
.34182 .01868 L
.35218 .01867 L
.36183 .01867 L
.3719 .01866 L
.38293 .01866 L
.39343 .01865 L
.40336 .01865 L
.42194 .01865 L
.43164 .01865 L
.44193 .01865 L
Mistroke
.46037 .01865 L
.46979 .01864 L
.47992 .01864 L
.48948 .01864 L
.49823 .01864 L
.50808 .01864 L
.51723 .01864 L
.52726 .01864 L
.53287 .01864 L
.53796 .01864 L
.54284 .01864 L
.54799 .01864 L
.55239 .01864 L
.55489 .01864 L
.55722 .01864 L
.55851 .01864 L
.55992 .01864 L
.56116 .01864 L
.56248 .01864 L
.56366 .01864 L
.56497 .01864 L
.56616 .01864 L
.56727 .01864 L
.56859 .01864 L
.56925 .01864 L
.56998 .01864 L
.57126 .01864 L
.57246 .01864 L
.57516 .01864 L
.57804 .01864 L
.58338 .01864 L
.5883 .01864 L
.5994 .01864 L
.61956 .01864 L
.65898 .01864 L
.69689 .01864 L
.73725 .01864 L
.77609 .01864 L
.81739 .01864 L
.85717 .01865 L
.89544 .01865 L
.93615 .01865 L
.97536 .01865 L
.97619 .01865 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.02605 .04952 L
.02846 .08168 L
.02962 .09442 L
.03072 .10442 L
.0317 .11159 L
.03279 .11764 L
.03398 .12222 L
.03524 .12498 L
.03641 .12596 L
.0375 .12577 L
.03879 .1245 L
.03997 .12259 L
.04262 .11661 L
.0529 .08843 L
.06244 .06724 L
.06744 .05882 L
.07277 .05159 L
.07869 .04531 L
.08405 .04089 L
.08912 .0376 L
.09462 .03482 L
.09981 .03278 L
.10458 .03131 L
.10928 .03016 L
.11432 .02919 L
.11907 .02848 L
.1234 .02797 L
.12849 .02751 L
.13117 .02732 L
.13402 .02716 L
.1365 .02704 L
.13924 .02694 L
.14173 .02686 L
.14407 .02682 L
.14524 .0268 L
.1465 .02678 L
.14769 .02678 L
.14876 .02677 L
.15003 .02678 L
.15075 .02678 L
.1514 .02679 L
.15262 .0268 L
.1539 .02682 L
.15513 .02685 L
.15645 .02688 L
.15883 .02697 L
.16166 .0271 L
.16425 .02727 L
.17321 .02805 L
Mistroke
.17558 .02826 L
.17813 .02844 L
.1793 .02851 L
.18054 .02858 L
.18161 .02862 L
.18275 .02866 L
.18403 .02868 L
.18523 .0287 L
.18595 .0287 L
.18664 .0287 L
.18794 .02869 L
.1891 .02867 L
.19018 .02864 L
.19263 .02856 L
.19707 .02835 L
.20178 .02808 L
.21176 .02748 L
.22252 .02693 L
.22748 .02673 L
.2327 .02656 L
.23753 .02643 L
.24203 .02633 L
.24626 .02627 L
.25077 .02621 L
.25335 .02619 L
.25577 .02617 L
.26032 .02614 L
.26496 .02612 L
.27007 .0261 L
.27539 .02609 L
.27795 .02608 L
.27921 .02608 L
.28037 .02607 L
.28143 .02607 L
.2826 .02607 L
.28378 .02607 L
.28503 .02607 L
.28608 .02607 L
.28722 .02607 L
.28829 .02607 L
.28928 .02607 L
.29043 .02607 L
.2915 .02608 L
.29393 .02608 L
.2963 .02609 L
.29884 .0261 L
.30906 .02615 L
.32016 .02622 L
.3403 .02633 L
.38119 .02658 L
Mistroke
.40152 .02673 L
.41147 .02681 L
.42056 .02686 L
.42991 .0269 L
.4388 .02693 L
.44367 .02695 L
.44818 .02695 L
.45314 .02696 L
.4559 .02696 L
.45841 .02697 L
.46074 .02697 L
.4633 .02697 L
.46458 .02697 L
.46529 .02697 L
.46596 .02697 L
.46726 .02697 L
.46845 .02697 L
.46956 .02697 L
.47075 .02697 L
.47176 .02697 L
.47287 .02697 L
.47406 .02697 L
.47535 .02697 L
.47768 .02697 L
.48021 .02697 L
.48297 .02697 L
.48854 .02696 L
.4985 .02696 L
.51813 .02694 L
.53908 .02691 L
.5806 .02686 L
.6206 .0268 L
.65909 .02675 L
.70003 .02671 L
.73945 .02667 L
.77736 .02664 L
.81772 .02661 L
.85656 .02658 L
.89786 .02655 L
.93764 .02653 L
.9759 .0265 L
.97619 .0265 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02006 L
.0379 .01897 L
.04262 .01815 L
.04714 .01751 L
.05212 .01695 L
.05713 .01651 L
.06244 .01614 L
.06792 .01586 L
.07293 .01566 L
.07871 .01548 L
.0842 .01536 L
.08925 .01527 L
.09394 .0152 L
.09909 .01515 L
.10458 .01511 L
.10994 .01507 L
.11487 .01505 L
.12028 .01503 L
.12599 .01502 L
.13096 .01501 L
.13561 .015 L
.1407 .01499 L
.14616 .01499 L
.15145 .01498 L
.15634 .01498 L
.15889 .01498 L
.1617 .01498 L
.16464 .01498 L
.1674 .01498 L
.18752 .01498 L
.206 .01497 L
.21106 .01497 L
.21647 .01497 L
.22114 .01497 L
.22621 .01497 L
.23161 .01497 L
.23409 .01497 L
.23671 .01497 L
.23907 .01497 L
.24167 .01497 L
.24402 .01497 L
.24625 .01497 L
.24756 .01497 L
.249 .01497 L
.2503 .01497 L
Mistroke
.25151 .01497 L
.25225 .01497 L
.25294 .01497 L
.25424 .01497 L
.25497 .01497 L
.25564 .01497 L
.25638 .01497 L
.25715 .01497 L
.25837 .01497 L
.25967 .01497 L
.2609 .01497 L
.26202 .01497 L
.26735 .01497 L
.27663 .01497 L
.27888 .01497 L
.28131 .01497 L
.2827 .01497 L
.28398 .01497 L
.28519 .01497 L
.28647 .01497 L
.28777 .01497 L
.28849 .01497 L
.28915 .01497 L
.29043 .01497 L
.29163 .01497 L
.29304 .01497 L
.29434 .01497 L
.29727 .01497 L
.30212 .01497 L
.30725 .01497 L
.32709 .01497 L
.33575 .01497 L
.34519 .01497 L
.35519 .01497 L
.36467 .01497 L
.37553 .01497 L
.38558 .01497 L
.40581 .01497 L
.42481 .01497 L
.44296 .01497 L
.46253 .01497 L
.48255 .01497 L
.50364 .01497 L
.54172 .01497 L
.58224 .01497 L
.62126 .01497 L
.66272 .01497 L
.70267 .01497 L
.74111 .01497 L
.78199 .01497 L
Mistroke
.82136 .01497 L
.85922 .01497 L
.89953 .01497 L
.93832 .01497 L
.97619 .01497 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.02605 .04964 L
.02846 .08313 L
.03053 .10718 L
.03163 .11758 L
.03279 .12673 L
.03344 .13103 L
.03416 .13504 L
.03543 .14032 L
.03672 .14356 L
.03793 .1449 L
.03911 .14487 L
.04019 .14392 L
.04143 .14194 L
.04262 .13939 L
.05221 .10983 L
.06244 .08117 L
.06792 .06947 L
.07289 .06087 L
.08259 .04856 L
.08803 .04367 L
.09391 .03959 L
.09947 .03664 L
.10458 .03453 L
.10928 .03301 L
.11432 .03172 L
.11907 .03078 L
.1234 .0301 L
.12849 .02949 L
.13117 .02923 L
.13402 .02901 L
.1365 .02884 L
.13924 .0287 L
.14173 .0286 L
.14407 .02852 L
.14524 .0285 L
.1465 .02847 L
.14769 .02846 L
.14876 .02845 L
.15003 .02845 L
.15075 .02845 L
.1514 .02845 L
.15262 .02846 L
.1539 .02848 L
.15513 .02851 L
.15645 .02854 L
.15883 .02864 L
.16166 .02879 L
.16425 .02898 L
.17321 .02994 L
Mistroke
.17558 .03021 L
.17813 .03047 L
.18054 .03066 L
.18169 .03073 L
.18275 .03079 L
.18396 .03083 L
.18528 .03087 L
.18656 .03088 L
.18728 .03089 L
.18794 .03088 L
.18909 .03087 L
.19035 .03085 L
.19153 .03081 L
.19263 .03077 L
.19707 .03054 L
.20178 .03022 L
.21176 .02947 L
.22252 .02876 L
.22748 .0285 L
.2327 .02827 L
.23753 .02811 L
.24203 .02798 L
.24626 .02789 L
.24842 .02786 L
.25077 .02783 L
.25211 .02781 L
.25335 .0278 L
.2545 .02779 L
.25577 .02778 L
.25692 .02778 L
.25798 .02777 L
.25911 .02777 L
.26032 .02777 L
.26153 .02777 L
.26222 .02777 L
.26287 .02777 L
.26418 .02778 L
.26492 .02778 L
.26559 .02778 L
.26797 .0278 L
.26917 .02781 L
.27048 .02782 L
.27324 .02786 L
.2762 .02791 L
.28153 .02804 L
.30165 .02862 L
.30661 .02874 L
.31187 .02883 L
.31462 .02887 L
.31764 .0289 L
Mistroke
.32039 .02892 L
.32297 .02894 L
.32421 .02894 L
.32557 .02895 L
.32685 .02895 L
.32804 .02895 L
.32922 .02895 L
.33028 .02895 L
.33152 .02895 L
.33268 .02895 L
.33395 .02895 L
.33529 .02895 L
.33769 .02894 L
.34311 .02893 L
.34799 .02892 L
.35038 .02891 L
.3526 .02891 L
.35384 .02891 L
.35515 .02891 L
.35647 .02891 L
.35722 .02891 L
.35792 .02891 L
.35914 .02891 L
.36025 .02891 L
.36148 .02891 L
.36277 .02891 L
.36392 .02891 L
.36496 .02891 L
.36731 .02892 L
.37153 .02893 L
.37645 .02895 L
.3811 .02897 L
.38994 .02901 L
.39944 .02905 L
.40223 .02906 L
.40488 .02907 L
.40746 .02908 L
.40985 .02908 L
.41211 .02909 L
.41337 .02909 L
.41451 .02909 L
.41577 .02909 L
.41648 .02909 L
.41713 .02909 L
.41833 .02909 L
.41959 .02909 L
.42083 .02909 L
.42196 .02909 L
.42327 .02909 L
.4245 .02909 L
Mistroke
.42908 .02908 L
.43167 .02907 L
.43407 .02906 L
.43948 .02905 L
.46053 .02895 L
.49987 .02879 L
.53769 .02868 L
.55872 .02863 L
.57797 .02859 L
.61673 .02853 L
.6357 .0285 L
.65642 .02849 L
.67609 .02847 L
.69705 .02846 L
.71846 .02845 L
.73862 .02845 L
.75869 .02844 L
.77716 .02844 L
.79598 .02844 L
.80666 .02844 L
.81664 .02844 L
.82708 .02844 L
.83698 .02844 L
.85553 .02844 L
.86518 .02843 L
.87543 .02843 L
.89385 .02843 L
.93159 .02843 L
.97178 .02843 L
.97619 .02843 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.02846 .08402 L
.03068 .11183 L
.03279 .13356 L
.03398 .14363 L
.03527 .15259 L
.03645 .15895 L
.03754 .16337 L
.03871 .16664 L
.04 .16862 L
.04065 .16903 L
.04135 .16909 L
.04262 .16828 L
.04393 .16639 L
.04516 .16389 L
.04793 .15632 L
.05297 .13936 L
.06244 .10818 L
.06795 .09326 L
.07314 .08162 L
.08284 .06534 L
.08828 .05874 L
.09328 .05392 L
.09878 .04974 L
.10458 .04634 L
.10954 .04409 L
.11406 .04247 L
.11928 .04101 L
.12422 .03996 L
.12878 .03923 L
.133 .03873 L
.1352 .03853 L
.13763 .03835 L
.13885 .03828 L
.14017 .03822 L
.14139 .03817 L
.14255 .03813 L
.14381 .0381 L
.14495 .03809 L
.14618 .03808 L
.14687 .03809 L
.14751 .03809 L
.14858 .03811 L
.14975 .03814 L
.15098 .03819 L
.15212 .03824 L
.15348 .03832 L
.15476 .03842 L
.15717 .03865 L
.15976 .03898 L
Mistroke
.16259 .03947 L
.17366 .0425 L
.17621 .04323 L
.17889 .04387 L
.18118 .04428 L
.18248 .04444 L
.18369 .04455 L
.18493 .04462 L
.18605 .04466 L
.18735 .04466 L
.18857 .04462 L
.18989 .04455 L
.1911 .04446 L
.19385 .04416 L
.19848 .04348 L
.2034 .04261 L
.21351 .04081 L
.21881 .03997 L
.22439 .03922 L
.22926 .03867 L
.23457 .03817 L
.23946 .03782 L
.2439 .03756 L
.24849 .03737 L
.25084 .03729 L
.25338 .03722 L
.25574 .03716 L
.25792 .03712 L
.26011 .03709 L
.26219 .03707 L
.26337 .03706 L
.26464 .03705 L
.26581 .03704 L
.26688 .03704 L
.26804 .03704 L
.26932 .03703 L
.26996 .03703 L
.27066 .03703 L
.27191 .03704 L
.27301 .03704 L
.27422 .03705 L
.27548 .03706 L
.27665 .03707 L
.27875 .03709 L
.28099 .03713 L
.28366 .03718 L
.28656 .03725 L
.29181 .03742 L
.30165 .03781 L
.34253 .03915 L
Mistroke
.3819 .04023 L
.40168 .0409 L
.41033 .04114 L
.41976 .04135 L
.42493 .04144 L
.42972 .0415 L
.4343 .04154 L
.43686 .04156 L
.43918 .04157 L
.44049 .04158 L
.44188 .04158 L
.44307 .04159 L
.44435 .04159 L
.44507 .04159 L
.44573 .04159 L
.44702 .04159 L
.44774 .04159 L
.44852 .04159 L
.44926 .04159 L
.44994 .04159 L
.45114 .04159 L
.45227 .04159 L
.45351 .04159 L
.45485 .04159 L
.45757 .04158 L
.46007 .04157 L
.46988 .04153 L
.47901 .04147 L
.49971 .04134 L
.53878 .04105 L
.58029 .04074 L
.6203 .04048 L
.65878 .04028 L
.69972 .04011 L
.73914 .03998 L
.77705 .03987 L
.81741 .03977 L
.85625 .03968 L
.89755 .03959 L
.93733 .03951 L
.9756 .03944 L
.97619 .03944 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .0212 L
.03053 .02077 L
.03279 .02025 L
.04262 .01832 L
.04762 .01761 L
.05293 .01701 L
.05746 .01661 L
.06244 .01626 L
.06792 .01596 L
.07293 .01575 L
.07871 .01557 L
.0842 .01544 L
.08925 .01534 L
.09394 .01528 L
.09909 .01522 L
.10458 .01517 L
.10994 .01514 L
.11487 .01511 L
.12028 .01509 L
.12599 .01508 L
.13096 .01507 L
.13561 .01506 L
.1407 .01505 L
.14616 .01505 L
.14872 .01505 L
.15145 .01504 L
.15634 .01504 L
.15905 .01504 L
.1616 .01504 L
.16439 .01504 L
.16596 .01504 L
.1674 .01504 L
.17244 .01504 L
.17521 .01504 L
.17783 .01504 L
.18026 .01504 L
.18291 .01504 L
.18752 .01504 L
.20645 .01503 L
.21168 .01503 L
.21722 .01503 L
.22241 .01503 L
.22715 .01503 L
.23166 .01503 L
.23658 .01503 L
.23928 .01503 L
Mistroke
.24178 .01503 L
.24433 .01503 L
.24672 .01503 L
.24896 .01503 L
.25014 .01503 L
.25138 .01503 L
.25242 .01503 L
.25357 .01503 L
.25462 .01503 L
.25559 .01503 L
.25682 .01503 L
.25798 .01503 L
.25902 .01503 L
.26015 .01503 L
.26138 .01503 L
.26269 .01503 L
.26503 .01503 L
.26961 .01503 L
.27443 .01503 L
.27695 .01503 L
.27829 .01503 L
.27971 .01503 L
.28102 .01503 L
.28222 .01503 L
.28341 .01503 L
.28454 .01503 L
.2856 .01503 L
.28677 .01503 L
.28798 .01503 L
.28912 .01503 L
.29115 .01503 L
.29333 .01503 L
.2983 .01503 L
.30284 .01503 L
.32351 .01503 L
.3326 .01503 L
.34265 .01503 L
.35222 .01503 L
.36121 .01503 L
.37071 .01503 L
.38095 .01503 L
.40096 .01503 L
.42206 .01503 L
.43158 .01503 L
.44177 .01503 L
.46013 .01503 L
.47036 .01503 L
.48145 .01503 L
.5016 .01503 L
.54248 .01503 L
Mistroke
.58185 .01503 L
.61971 .01503 L
.66002 .01503 L
.69881 .01503 L
.74005 .01503 L
.77978 .01503 L
.81799 .01503 L
.85866 .01503 L
.89781 .01503 L
.93941 .01503 L
.97619 .01503 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.02605 .04953 L
.02846 .08204 L
.02962 .09526 L
.03072 .10596 L
.0317 .11397 L
.03279 .1211 L
.03398 .12699 L
.03524 .13114 L
.03641 .13331 L
.0375 .13409 L
.03879 .13373 L
.03997 .13244 L
.04062 .13141 L
.04132 .13008 L
.04262 .12721 L
.05302 .09707 L
.06244 .07342 L
.06789 .06296 L
.07302 .05502 L
.07889 .04785 L
.08429 .04271 L
.08894 .0392 L
.09404 .03613 L
.09916 .0337 L
.10458 .0317 L
.10982 .0302 L
.11478 .0291 L
.11924 .02833 L
.12409 .02766 L
.12936 .02712 L
.13224 .02688 L
.13495 .0267 L
.13973 .02645 L
.14227 .02636 L
.1437 .02631 L
.145 .02628 L
.14615 .02626 L
.1474 .02624 L
.14872 .02622 L
.14996 .02621 L
.15113 .02621 L
.15236 .02621 L
.15342 .02621 L
.15458 .02622 L
.15527 .02623 L
.15594 .02624 L
.15718 .02627 L
.15852 .0263 L
.15998 .02635 L
Mistroke
.16261 .02646 L
.16504 .02659 L
.17027 .02698 L
.17592 .02745 L
.17851 .02764 L
.17993 .02773 L
.18125 .02779 L
.18247 .02785 L
.18358 .02788 L
.18482 .02791 L
.1855 .02792 L
.18614 .02793 L
.18733 .02794 L
.18863 .02794 L
.18928 .02793 L
.18999 .02792 L
.19127 .0279 L
.19247 .02787 L
.19374 .02783 L
.196 .02774 L
.20671 .02718 L
.21647 .02664 L
.22533 .02624 L
.2349 .02592 L
.24015 .0258 L
.24256 .02575 L
.24511 .02571 L
.2473 .02568 L
.2497 .02566 L
.25189 .02564 L
.25287 .02563 L
.25393 .02563 L
.25517 .02562 L
.25634 .02562 L
.25748 .02562 L
.25854 .02562 L
.25968 .02562 L
.26094 .02562 L
.26225 .02563 L
.26349 .02563 L
.26591 .02565 L
.26817 .02567 L
.27065 .0257 L
.2733 .02574 L
.28364 .02596 L
.29326 .02618 L
.29749 .02626 L
.30214 .02633 L
.30471 .02636 L
.30711 .02638 L
Mistroke
.30841 .02639 L
.30964 .0264 L
.31107 .02641 L
.31237 .02641 L
.31307 .02641 L
.3137 .02641 L
.31443 .02641 L
.31512 .02641 L
.31635 .02641 L
.31704 .02641 L
.31767 .02641 L
.31837 .02641 L
.31902 .02641 L
.32049 .02641 L
.32346 .02639 L
.32855 .02636 L
.33319 .02632 L
.34361 .02623 L
.35287 .02616 L
.36271 .0261 L
.36784 .02607 L
.3735 .02605 L
.37864 .02604 L
.38347 .02603 L
.40196 .02601 L
.41244 .02599 L
.42218 .02598 L
.44224 .02592 L
.46334 .02586 L
.48209 .02581 L
.5024 .02577 L
.52377 .02574 L
.54392 .02571 L
.56342 .02569 L
.58486 .02568 L
.60523 .02567 L
.62428 .02566 L
.6347 .02565 L
.64459 .02565 L
.66313 .02565 L
.67275 .02565 L
.67803 .02565 L
.68299 .02564 L
.68763 .02564 L
.69265 .02564 L
.69721 .02564 L
.70139 .02564 L
.70382 .02564 L
.70611 .02564 L
.70738 .02564 L
Mistroke
.70876 .02564 L
.7099 .02564 L
.71116 .02564 L
.71235 .02564 L
.71346 .02564 L
.71464 .02564 L
.7159 .02564 L
.71707 .02564 L
.71818 .02564 L
.71918 .02564 L
.72027 .02564 L
.72167 .02564 L
.72299 .02564 L
.72546 .02564 L
.72812 .02564 L
.73099 .02564 L
.74095 .02564 L
.75045 .02564 L
.76088 .02565 L
.78194 .02565 L
.82236 .02565 L
.86125 .02566 L
.9026 .02566 L
.94243 .02566 L
.97619 .02567 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.02499 .02102 L
.02605 .02165 L
.02729 .02172 L
.02846 .0216 L
.02954 .02142 L
.03053 .02123 L
.03279 .02076 L
.03746 .01979 L
.04262 .01886 L
.05224 .01758 L
.05751 .01708 L
.06244 .01671 L
.06788 .01639 L
.07305 .01616 L
.07768 .01599 L
.08274 .01585 L
.08822 .01573 L
.09407 .01564 L
.09958 .01557 L
.10458 .01552 L
.10945 .01549 L
.1146 .01546 L
.119 .01544 L
.12383 .01542 L
.12902 .01541 L
.13459 .0154 L
.13729 .01539 L
.13985 .01539 L
.14232 .01539 L
.14465 .01538 L
.14704 .01538 L
.14923 .01538 L
.15167 .01538 L
.15295 .01538 L
.15366 .01538 L
.1543 .01538 L
.15553 .01538 L
.15684 .01538 L
.15805 .01538 L
.1592 .01538 L
.15985 .01538 L
.16054 .01538 L
.16177 .01538 L
.1631 .01538 L
.16456 .01538 L
.16908 .01538 L
.17401 .01539 L
.17626 .01539 L
.1775 .01539 L
Mistroke
.17866 .01539 L
.17975 .01539 L
.18092 .01539 L
.18199 .01539 L
.18298 .01539 L
.1842 .01539 L
.18533 .01539 L
.18658 .01539 L
.18728 .01539 L
.18792 .01539 L
.1906 .01539 L
.19314 .01539 L
.20242 .01538 L
.21256 .01538 L
.22332 .01537 L
.2328 .01537 L
.2382 .01537 L
.24326 .01536 L
.2479 .01536 L
.25214 .01536 L
.25437 .01536 L
.2568 .01536 L
.2617 .01536 L
.26696 .01536 L
.27266 .01536 L
.27804 .01536 L
.28299 .01536 L
.2922 .01536 L
.30231 .01536 L
.30705 .01536 L
.31214 .01536 L
.31693 .01536 L
.32131 .01536 L
.32625 .01536 L
.32904 .01536 L
.33038 .01536 L
.33163 .01536 L
.33388 .01536 L
.33508 .01536 L
.33637 .01536 L
.33765 .01536 L
.33829 .01536 L
.339 .01536 L
.34025 .01536 L
.34141 .01536 L
.34268 .01536 L
.34332 .01536 L
.34403 .01536 L
.34645 .01536 L
.34927 .01536 L
Mistroke
.35191 .01536 L
.3567 .01536 L
.36184 .01536 L
.37155 .01536 L
.38042 .01536 L
.40103 .01536 L
.42015 .01536 L
.43865 .01536 L
.44899 .01536 L
.45836 .01536 L
.4684 .01536 L
.47762 .01536 L
.48775 .01536 L
.49845 .01536 L
.50794 .01536 L
.51325 .01536 L
.5181 .01536 L
.52261 .01536 L
.52499 .01536 L
.52752 .01536 L
.52972 .01536 L
.53216 .01536 L
.53322 .01536 L
.53437 .01536 L
.53543 .01536 L
.53644 .01536 L
.5377 .01536 L
.53884 .01536 L
.54007 .01536 L
.54077 .01536 L
.5414 .01536 L
.54247 .01536 L
.54365 .01536 L
.54487 .01536 L
.54602 .01536 L
.54866 .01536 L
.55107 .01536 L
.5565 .01536 L
.56168 .01536 L
.56733 .01536 L
.5776 .01536 L
.61832 .01536 L
.65752 .01536 L
.69917 .01536 L
.73931 .01536 L
.77794 .01536 L
.81901 .01536 L
.85857 .01536 L
.89661 .01536 L
.93711 .01536 L
Mistroke
.97609 .01536 L
.97619 .01536 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .02121 L
.03053 .02077 L
.03279 .02026 L
.04262 .01834 L
.04762 .01763 L
.05293 .01704 L
.05746 .01664 L
.06244 .01629 L
.06792 .01599 L
.07293 .01579 L
.07871 .0156 L
.0842 .01547 L
.08925 .01538 L
.09394 .01531 L
.09909 .01526 L
.10458 .01521 L
.10994 .01518 L
.11487 .01515 L
.12028 .01513 L
.12599 .01512 L
.13096 .0151 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01509 L
.14867 .01508 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.16531 .01508 L
.16596 .01508 L
.1667 .01508 L
.1674 .01508 L
.16856 .01508 L
.16984 .01508 L
.17049 .01508 L
.17118 .01508 L
.17243 .01508 L
.17367 .01508 L
.17485 .01508 L
.1759 .01508 L
Mistroke
.17706 .01508 L
.17777 .01508 L
.17844 .01508 L
.17969 .01508 L
.18039 .01508 L
.18103 .01508 L
.18249 .01508 L
.18494 .01508 L
.18752 .01508 L
.20742 .01507 L
.21611 .01507 L
.22555 .01507 L
.23077 .01507 L
.23559 .01507 L
.2402 .01507 L
.2451 .01507 L
.24757 .01507 L
.25023 .01507 L
.25146 .01507 L
.25275 .01507 L
.25395 .01507 L
.25505 .01507 L
.25637 .01507 L
.25709 .01507 L
.25777 .01507 L
.25898 .01507 L
.26029 .01507 L
.26099 .01507 L
.26174 .01507 L
.26254 .01507 L
.26328 .01507 L
.2646 .01507 L
.26602 .01507 L
.27095 .01507 L
.27214 .01507 L
.27343 .01507 L
.27417 .01507 L
.27485 .01507 L
.2755 .01507 L
.27618 .01507 L
.27687 .01507 L
.2776 .01507 L
.27892 .01507 L
.27973 .01507 L
.28049 .01507 L
.28192 .01507 L
.28325 .01507 L
.28447 .01507 L
.28724 .01507 L
.29189 .01507 L
Mistroke
.297 .01507 L
.30735 .01507 L
.31815 .01507 L
.32841 .01507 L
.33761 .01507 L
.34288 .01507 L
.34766 .01507 L
.3574 .01507 L
.36275 .01507 L
.36778 .01507 L
.37675 .01507 L
.38181 .01507 L
.38645 .01507 L
.39116 .01507 L
.3962 .01507 L
.40529 .01507 L
.41085 .01507 L
.4161 .01507 L
.42083 .01507 L
.4233 .01507 L
.42596 .01507 L
.42849 .01507 L
.43081 .01507 L
.43317 .01507 L
.43537 .01507 L
.43778 .01507 L
.43906 .01507 L
.44043 .01507 L
.44111 .01507 L
.44186 .01507 L
.44257 .01507 L
.44322 .01507 L
.44445 .01507 L
.44575 .01507 L
.44705 .01507 L
.44824 .01507 L
.44962 .01507 L
.45092 .01507 L
.45576 .01507 L
.46102 .01507 L
.46676 .01507 L
.47693 .01507 L
.48649 .01507 L
.49179 .01507 L
.49457 .01507 L
.49751 .01507 L
.49999 .01507 L
.5013 .01507 L
.5027 .01507 L
.504 .01507 L
Mistroke
.50518 .01507 L
.50636 .01507 L
.50748 .01507 L
.50863 .01507 L
.50986 .01507 L
.51102 .01507 L
.51209 .01507 L
.51333 .01507 L
.51469 .01507 L
.51717 .01507 L
.51975 .01507 L
.5225 .01507 L
.52744 .01507 L
.53242 .01507 L
.53711 .01507 L
.54588 .01507 L
.56595 .01507 L
.58442 .01507 L
.62389 .01507 L
.66185 .01507 L
.70227 .01507 L
.74116 .01507 L
.78251 .01507 L
.82234 .01507 L
.86066 .01507 L
.90143 .01507 L
.94068 .01507 L
.97619 .01507 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.02846 .08408 L
.03068 .11208 L
.03279 .13411 L
.03398 .14436 L
.03527 .15348 L
.03645 .15991 L
.03754 .1643 L
.03871 .16745 L
.04 .16914 L
.04065 .16936 L
.04135 .16917 L
.04262 .16785 L
.04393 .16537 L
.04516 .16226 L
.04793 .15334 L
.05297 .13426 L
.06244 .10081 L
.06795 .08532 L
.07314 .07344 L
.08284 .05712 L
.08828 .0506 L
.09328 .04587 L
.09878 .04181 L
.10458 .03852 L
.10954 .03635 L
.11406 .03478 L
.11928 .03337 L
.12422 .03234 L
.12878 .0316 L
.133 .03108 L
.13763 .03065 L
.13997 .03049 L
.14255 .03034 L
.1449 .03024 L
.14623 .03019 L
.14747 .03016 L
.14878 .03014 L
.14997 .03012 L
.15063 .03012 L
.15135 .03011 L
.15264 .03012 L
.15376 .03013 L
.15498 .03015 L
.15626 .03018 L
.15746 .03022 L
.1596 .03031 L
.1619 .03045 L
.16457 .03067 L
.16749 .03097 L
Mistroke
.1728 .03166 L
.17758 .03228 L
.18028 .03257 L
.18156 .03267 L
.18275 .03275 L
.18399 .03282 L
.18465 .03285 L
.18535 .03287 L
.18608 .03289 L
.18678 .0329 L
.18808 .03291 L
.18933 .03289 L
.19049 .03287 L
.19176 .03283 L
.1931 .03277 L
.1954 .03264 L
.19755 .0325 L
.20247 .03209 L
.2127 .03117 L
.22345 .03033 L
.23312 .02979 L
.23859 .02957 L
.24121 .02948 L
.24367 .02941 L
.24593 .02936 L
.24837 .02931 L
.25059 .02928 L
.25263 .02926 L
.25378 .02925 L
.25485 .02924 L
.25602 .02923 L
.25728 .02923 L
.2586 .02923 L
.25985 .02923 L
.26097 .02923 L
.26219 .02924 L
.26341 .02924 L
.26452 .02925 L
.26703 .02928 L
.26924 .02932 L
.27158 .02937 L
.27652 .0295 L
.28194 .02967 L
.2876 .02986 L
.29294 .03002 L
.29774 .03013 L
.30044 .03017 L
.30165 .03019 L
.30294 .0302 L
.30416 .03021 L
Mistroke
.30528 .03022 L
.3064 .03023 L
.30747 .03023 L
.3087 .03023 L
.30985 .03023 L
.31111 .03022 L
.31181 .03022 L
.31245 .03022 L
.31495 .0302 L
.31764 .03017 L
.32253 .0301 L
.34347 .02968 L
.35379 .02949 L
.36342 .02935 L
.37347 .02923 L
.38449 .02914 L
.39496 .02908 L
.40486 .02903 L
.42342 .02896 L
.46177 .02882 L
.48156 .02877 L
.49168 .02875 L
.50257 .02873 L
.52206 .02871 L
.54034 .02869 L
.5604 .02867 L
.57061 .02867 L
.5815 .02866 L
.59186 .02866 L
.60126 .02865 L
.61019 .02865 L
.61963 .02865 L
.62962 .02865 L
.63883 .02865 L
.64395 .02865 L
.64874 .02865 L
.65399 .02865 L
.65694 .02865 L
.65963 .02865 L
.66215 .02864 L
.66333 .02864 L
.66442 .02864 L
.66568 .02864 L
.66635 .02864 L
.66705 .02864 L
.66822 .02864 L
.66952 .02864 L
.67071 .02864 L
.67181 .02864 L
.67306 .02864 L
Mistroke
.67426 .02864 L
.67637 .02864 L
.67867 .02865 L
.68116 .02865 L
.68391 .02865 L
.68946 .02865 L
.69942 .02865 L
.70954 .02865 L
.71882 .02865 L
.73969 .02865 L
.77939 .02866 L
.81757 .02866 L
.8582 .02867 L
.89732 .02867 L
.93889 .02868 L
.97619 .02869 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02079 L
.03279 .02028 L
.04262 .01837 L
.04762 .01766 L
.05293 .01706 L
.0579 .01662 L
.06244 .01631 L
.06743 .01603 L
.0728 .01581 L
.07777 .01564 L
.0825 .01552 L
.08797 .01541 L
.09305 .01533 L
.09863 .01527 L
.10458 .01522 L
.10994 .01518 L
.11487 .01516 L
.12028 .01513 L
.12599 .01512 L
.13096 .01511 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01509 L
.14867 .01509 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.1653 .01508 L
.16596 .01508 L
.16671 .01508 L
.1674 .01508 L
.16865 .01508 L
.16984 .01508 L
.17049 .01508 L
.1712 .01508 L
.17245 .01508 L
.17364 .01508 L
.1749 .01508 L
.1761 .01508 L
Mistroke
.17718 .01508 L
.1784 .01508 L
.17971 .01508 L
.18096 .01508 L
.1821 .01508 L
.18336 .01508 L
.18474 .01508 L
.18752 .01508 L
.19252 .01508 L
.19788 .01508 L
.20754 .01508 L
.21713 .01507 L
.22599 .01507 L
.23094 .01507 L
.23619 .01507 L
.24146 .01507 L
.24446 .01507 L
.24727 .01507 L
.24974 .01507 L
.25233 .01507 L
.25696 .01507 L
.2674 .01507 L
.27697 .01507 L
.28718 .01507 L
.30556 .01507 L
.31583 .01507 L
.32124 .01507 L
.32695 .01507 L
.33195 .01507 L
.33745 .01507 L
.34207 .01507 L
.34711 .01507 L
.35234 .01507 L
.3573 .01507 L
.36213 .01507 L
.3666 .01507 L
.37141 .01507 L
.37673 .01507 L
.38751 .01507 L
.40683 .01507 L
.41678 .01507 L
.42205 .01507 L
.42494 .01507 L
.42768 .01507 L
.43028 .01507 L
.4331 .01507 L
.43435 .01507 L
.43567 .01507 L
.43691 .01507 L
.43804 .01507 L
Mistroke
.43918 .01507 L
.44041 .01507 L
.44155 .01507 L
.44264 .01507 L
.44389 .01507 L
.44505 .01507 L
.44633 .01507 L
.44769 .01507 L
.45043 .01507 L
.45339 .01507 L
.45876 .01507 L
.46878 .01507 L
.50981 .01507 L
.54931 .01507 L
.58731 .01507 L
.62775 .01507 L
.66668 .01507 L
.70806 .01507 L
.74792 .01507 L
.78627 .01507 L
.82708 .01507 L
.86636 .01507 L
.90413 .01507 L
.94436 .01507 L
.97619 .01507 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.02846 .08384 L
.03068 .11084 L
.03279 .13066 L
.03398 .13899 L
.03527 .14553 L
.03645 .14927 L
.03754 .15102 L
.03871 .15131 L
.04 .15006 L
.04065 .14892 L
.04135 .14739 L
.04262 .14399 L
.0521 .10961 L
.06244 .07769 L
.06829 .06453 L
.07373 .05499 L
.07892 .04783 L
.08445 .04189 L
.08988 .03738 L
.09501 .03409 L
.09996 .03159 L
.10458 .02975 L
.10923 .02828 L
.11434 .02701 L
.11932 .02605 L
.12466 .02527 L
.12962 .02471 L
.13432 .02431 L
.13854 .02404 L
.14313 .02382 L
.14546 .02374 L
.14798 .02367 L
.14914 .02364 L
.15035 .02362 L
.15149 .0236 L
.15253 .02358 L
.15377 .02357 L
.15445 .02357 L
.1551 .02357 L
.15624 .02356 L
.15748 .02357 L
.15814 .02357 L
.15885 .02357 L
.1596 .02358 L
.1603 .02359 L
.16156 .02361 L
.1629 .02363 L
.1656 .0237 L
.16854 .02379 L
Mistroke
.17388 .024 L
.1764 .02409 L
.17909 .02417 L
.18039 .0242 L
.18162 .02423 L
.18272 .02424 L
.18391 .02425 L
.18516 .02426 L
.18629 .02426 L
.1876 .02425 L
.18884 .02424 L
.18999 .02423 L
.19105 .02421 L
.19344 .02416 L
.19851 .02402 L
.20389 .02383 L
.21404 .02348 L
.21937 .02333 L
.22497 .02318 L
.22984 .02308 L
.23515 .02299 L
.23999 .02293 L
.24448 .02289 L
.24912 .02285 L
.25333 .02283 L
.25566 .02282 L
.25819 .02281 L
.26057 .02281 L
.26277 .0228 L
.26403 .0228 L
.26522 .0228 L
.26629 .0228 L
.26746 .0228 L
.26873 .0228 L
.26937 .0228 L
.27007 .0228 L
.27132 .0228 L
.27249 .0228 L
.2736 .0228 L
.27477 .0228 L
.27686 .0228 L
.27911 .0228 L
.28157 .02281 L
.28674 .02281 L
.28958 .02282 L
.29227 .02282 L
.29348 .02282 L
.29477 .02282 L
.29544 .02282 L
.29618 .02282 L
Mistroke
.29748 .02282 L
.29866 .02282 L
.29993 .02282 L
.30113 .02282 L
.30223 .02282 L
.30352 .02282 L
.30473 .02282 L
.307 .02282 L
.30944 .02281 L
.31208 .02281 L
.32123 .02278 L
.34195 .02271 L
.36191 .02265 L
.37196 .02263 L
.38298 .02261 L
.39319 .0226 L
.4025 .02259 L
.42342 .02258 L
.44413 .02257 L
.46329 .02256 L
.48189 .02255 L
.49128 .02255 L
.50164 .02255 L
.521 .02255 L
.53188 .02255 L
.54186 .02254 L
.5608 .02254 L
.57153 .02254 L
.5815 .02254 L
.58656 .02254 L
.59204 .02254 L
.59687 .02254 L
.60198 .02254 L
.60659 .02254 L
.60903 .02254 L
.61165 .02254 L
.61406 .02254 L
.61626 .02254 L
.61847 .02254 L
.61956 .02254 L
.62057 .02254 L
.62182 .02254 L
.62248 .02254 L
.62317 .02254 L
.62434 .02254 L
.62562 .02254 L
.62676 .02254 L
.62799 .02254 L
.62914 .02254 L
.63019 .02254 L
Mistroke
.63271 .02254 L
.63545 .02254 L
.64043 .02254 L
.64507 .02254 L
.65 .02254 L
.65883 .02254 L
.67836 .02254 L
.69666 .02254 L
.73542 .02254 L
.77663 .02254 L
.81632 .02255 L
.85451 .02255 L
.89514 .02255 L
.93426 .02255 L
.97583 .02255 L
.97619 .02255 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02124 L
.02846 .02105 L
.03279 .02008 L
.0379 .01901 L
.04262 .0182 L
.04714 .01756 L
.05212 .01701 L
.05713 .01657 L
.06244 .01621 L
.06792 .01593 L
.07293 .01573 L
.07871 .01556 L
.0842 .01543 L
.08925 .01534 L
.09394 .01528 L
.09909 .01523 L
.10458 .01518 L
.10994 .01515 L
.11487 .01513 L
.12028 .01511 L
.12599 .01509 L
.13096 .01508 L
.13561 .01508 L
.1407 .01507 L
.14335 .01507 L
.14616 .01507 L
.14867 .01506 L
.15145 .01506 L
.154 .01506 L
.15634 .01506 L
.15908 .01506 L
.16052 .01506 L
.16204 .01506 L
.16268 .01506 L
.16337 .01506 L
.1646 .01506 L
.16536 .01506 L
.16607 .01506 L
.16671 .01506 L
.1674 .01506 L
.16865 .01506 L
.16982 .01506 L
.17111 .01506 L
.17249 .01506 L
.17393 .01506 L
.17464 .01506 L
.1753 .01506 L
Mistroke
.17653 .01506 L
.17718 .01506 L
.17787 .01506 L
.17913 .01506 L
.17983 .01506 L
.18048 .01506 L
.18168 .01506 L
.18294 .01506 L
.18512 .01506 L
.18752 .01506 L
.20871 .01505 L
.21874 .01505 L
.228 .01505 L
.23266 .01505 L
.2376 .01505 L
.24255 .01505 L
.24537 .01505 L
.24802 .01505 L
.25034 .01505 L
.25278 .01505 L
.25486 .01505 L
.25714 .01505 L
.25843 .01505 L
.2596 .01505 L
.26096 .01505 L
.26223 .01505 L
.26341 .01505 L
.2645 .01505 L
.26696 .01505 L
.26811 .01505 L
.26937 .01505 L
.27055 .01505 L
.27165 .01505 L
.27292 .01505 L
.27428 .01505 L
.27668 .01505 L
.2789 .01505 L
.28099 .01505 L
.28576 .01505 L
.29094 .01505 L
.2957 .01505 L
.30642 .01505 L
.31555 .01505 L
.32532 .01505 L
.33093 .01505 L
.33603 .01505 L
.34087 .01505 L
.34601 .01505 L
.35075 .01505 L
.35597 .01505 L
Mistroke
.36072 .01505 L
.36517 .01505 L
.36785 .01505 L
.3704 .01505 L
.37269 .01505 L
.37398 .01505 L
.37519 .01505 L
.37586 .01505 L
.3766 .01505 L
.37729 .01505 L
.37792 .01505 L
.37913 .01505 L
.3804 .01505 L
.38106 .01505 L
.38177 .01505 L
.38305 .01505 L
.38457 .01505 L
.38596 .01505 L
.38825 .01505 L
.39077 .01505 L
.39588 .01505 L
.40506 .01505 L
.42582 .01505 L
.44681 .01505 L
.456 .01505 L
.46605 .01505 L
.47517 .01505 L
.48491 .01505 L
.49519 .01505 L
.50475 .01505 L
.51501 .01505 L
.52079 .01505 L
.52354 .01505 L
.52611 .01505 L
.52855 .01505 L
.53078 .01505 L
.53325 .01505 L
.53461 .01505 L
.53591 .01505 L
.53715 .01505 L
.53785 .01505 L
.53848 .01505 L
.53971 .01505 L
.54087 .01505 L
.54153 .01505 L
.54222 .01505 L
.54347 .01505 L
.5448 .01505 L
.54627 .01505 L
.54879 .01505 L
Mistroke
.55153 .01505 L
.55651 .01505 L
.56136 .01505 L
.56583 .01505 L
.58677 .01505 L
.60548 .01505 L
.62611 .01505 L
.66638 .01505 L
.70514 .01505 L
.74635 .01505 L
.78605 .01505 L
.82423 .01505 L
.86486 .01505 L
.90398 .01505 L
.94555 .01505 L
.97619 .01505 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.02605 .04958 L
.02846 .0823 L
.02962 .0956 L
.03072 .10628 L
.0317 .11414 L
.03279 .12097 L
.03398 .12635 L
.03524 .12985 L
.03641 .13135 L
.0375 .13151 L
.03879 .13048 L
.03997 .12867 L
.04132 .12583 L
.04262 .12261 L
.05221 .09457 L
.06244 .06992 L
.06792 .06011 L
.07289 .05297 L
.08259 .04283 L
.08803 .03883 L
.09391 .0355 L
.09947 .03311 L
.10458 .03141 L
.10928 .03018 L
.11432 .02914 L
.11907 .02838 L
.1234 .02784 L
.12849 .02735 L
.13117 .02714 L
.13402 .02696 L
.1365 .02683 L
.13924 .02671 L
.14173 .02663 L
.14407 .02658 L
.14524 .02655 L
.1465 .02654 L
.14769 .02653 L
.14876 .02652 L
.15003 .02652 L
.15075 .02652 L
.1514 .02652 L
.15262 .02653 L
.1539 .02655 L
.15513 .02657 L
.15645 .0266 L
.15883 .02667 L
.16166 .0268 L
.16425 .02695 L
.17321 .0277 L
Mistroke
.17558 .0279 L
.17813 .02809 L
.1793 .02817 L
.18054 .02823 L
.18161 .02828 L
.18275 .02832 L
.18403 .02835 L
.18523 .02837 L
.18595 .02838 L
.18664 .02838 L
.18794 .02837 L
.1891 .02836 L
.19018 .02834 L
.19137 .02831 L
.19263 .02827 L
.19698 .02809 L
.20178 .02783 L
.2126 .0272 L
.22252 .02671 L
.23197 .02636 L
.23671 .02623 L
.2419 .02612 L
.24713 .02604 L
.25006 .026 L
.25272 .02598 L
.2552 .02597 L
.2566 .02596 L
.25789 .02595 L
.25902 .02595 L
.26026 .02595 L
.26156 .02595 L
.26277 .02595 L
.26403 .02595 L
.26466 .02595 L
.26536 .02595 L
.2666 .02596 L
.26777 .02596 L
.27038 .02598 L
.27321 .026 L
.27572 .02602 L
.27836 .02605 L
.2831 .02613 L
.30165 .0265 L
.31118 .02667 L
.31651 .02674 L
.32136 .02679 L
.32589 .02683 L
.3308 .02686 L
.33972 .0269 L
.38061 .02716 L
Mistroke
.39041 .02724 L
.40094 .02733 L
.40604 .02736 L
.41089 .02739 L
.41524 .02741 L
.41998 .02742 L
.42255 .02743 L
.42381 .02743 L
.42497 .02743 L
.426 .02743 L
.42714 .02743 L
.42828 .02743 L
.42949 .02744 L
.43017 .02744 L
.43081 .02744 L
.43202 .02744 L
.43331 .02744 L
.43405 .02743 L
.43473 .02743 L
.43585 .02743 L
.4371 .02743 L
.43962 .02743 L
.44414 .02742 L
.44902 .02741 L
.45784 .02739 L
.499 .02726 L
.53864 .02715 L
.57677 .02707 L
.61735 .02699 L
.65641 .02694 L
.69793 .0269 L
.73793 .02687 L
.77642 .02685 L
.81736 .02683 L
.85678 .02681 L
.89469 .0268 L
.93505 .02679 L
.97389 .02678 L
.97619 .02678 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.02605 .04918 L
.02729 .06534 L
.02846 .07755 L
.02954 .08576 L
.03072 .0913 L
.0318 .09377 L
.03279 .09443 L
.03396 .0938 L
.03506 .09229 L
.03626 .09 L
.03756 .08711 L
.04262 .07468 L
.0521 .05481 L
.05746 .0465 L
.06244 .04039 L
.0679 .03516 L
.07373 .03091 L
.07935 .0278 L
.08445 .02564 L
.08943 .02399 L
.09481 .02262 L
.0999 .02162 L
.10458 .0209 L
.10928 .02033 L
.11432 .01986 L
.11907 .01951 L
.1234 .01926 L
.12849 .01903 L
.13402 .01884 L
.13924 .01872 L
.14176 .01867 L
.14407 .01863 L
.14628 .0186 L
.1487 .01858 L
.15113 .01856 L
.15247 .01855 L
.15369 .01854 L
.15486 .01854 L
.15596 .01853 L
.15712 .01853 L
.15838 .01853 L
.15948 .01853 L
.16064 .01853 L
.16164 .01853 L
.16273 .01854 L
.16411 .01854 L
.16541 .01855 L
.16786 .01857 L
.17338 .01861 L
Mistroke
.17568 .01863 L
.17814 .01864 L
.17955 .01865 L
.18083 .01865 L
.18212 .01866 L
.18333 .01866 L
.1845 .01866 L
.18575 .01866 L
.18693 .01865 L
.188 .01865 L
.19063 .01864 L
.19312 .01862 L
.20345 .01854 L
.21224 .01846 L
.22194 .01839 L
.23162 .01833 L
.23692 .01831 L
.24189 .0183 L
.24652 .01829 L
.25076 .01828 L
.25299 .01828 L
.25542 .01828 L
.25796 .01828 L
.26032 .01827 L
.26296 .01827 L
.26538 .01827 L
.26805 .01827 L
.26939 .01827 L
.27015 .01827 L
.27087 .01827 L
.27217 .01827 L
.27335 .01827 L
.27462 .01827 L
.27534 .01827 L
.27601 .01827 L
.27712 .01827 L
.27834 .01827 L
.27962 .01827 L
.28082 .01827 L
.28309 .01827 L
.28548 .01827 L
.28976 .01827 L
.29942 .01828 L
.30894 .01829 L
.31428 .01829 L
.3168 .01829 L
.31913 .01829 L
.32129 .01829 L
.32366 .01829 L
.32605 .01829 L
Mistroke
.32735 .01829 L
.32857 .01829 L
.32972 .01829 L
.33082 .01829 L
.3318 .01829 L
.33287 .01829 L
.33403 .01829 L
.33527 .01829 L
.33643 .01829 L
.33749 .01829 L
.34237 .01829 L
.34504 .01829 L
.34634 .01829 L
.34753 .01829 L
.34862 .01829 L
.34965 .01829 L
.35074 .01829 L
.35193 .01829 L
.35314 .01829 L
.35443 .01829 L
.35554 .01829 L
.35675 .01829 L
.35807 .01829 L
.35945 .01829 L
.36192 .01829 L
.36459 .01829 L
.3675 .01829 L
.37272 .01829 L
.37758 .01829 L
.39633 .0183 L
.4062 .0183 L
.41117 .0183 L
.41664 .01831 L
.41941 .01831 L
.42094 .01831 L
.42239 .01831 L
.42373 .01831 L
.42444 .01831 L
.4252 .01831 L
.42589 .01831 L
.42653 .01831 L
.42776 .01831 L
.4284 .01831 L
.42908 .01831 L
.4303 .01831 L
.43161 .01831 L
.43235 .01831 L
.43304 .01831 L
.43544 .01831 L
.438 .01831 L
Mistroke
.44343 .01831 L
.44856 .0183 L
.45816 .0183 L
.49656 .0183 L
.53742 .01829 L
.57676 .01828 L
.61458 .01828 L
.63561 .01828 L
.65485 .01828 L
.69361 .01827 L
.71259 .01827 L
.73331 .01827 L
.77394 .01827 L
.81306 .01827 L
.85463 .01827 L
.89468 .01827 L
.93322 .01827 L
.97421 .01827 L
.97619 .01827 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.02605 .04945 L
.02729 .06657 L
.02846 .08074 L
.02954 .09176 L
.03072 .10111 L
.0318 .10724 L
.03279 .11105 L
.03396 .11358 L
.03506 .11436 L
.03626 .11388 L
.03756 .11222 L
.03821 .11107 L
.03891 .10963 L
.0402 .10665 L
.04262 .10031 L
.05302 .0733 L
.06244 .05536 L
.06789 .04781 L
.07302 .0422 L
.07844 .03755 L
.08429 .03369 L
.08943 .03109 L
.09486 .02895 L
.09949 .02753 L
.10458 .02629 L
.10982 .02531 L
.11478 .02459 L
.11924 .02409 L
.12409 .02366 L
.12936 .0233 L
.13224 .02315 L
.13495 .02303 L
.13973 .02287 L
.14227 .02281 L
.1437 .02278 L
.145 .02276 L
.14615 .02274 L
.1474 .02273 L
.14872 .02272 L
.14996 .02271 L
.15113 .0227 L
.15236 .0227 L
.15342 .0227 L
.15458 .02271 L
.15527 .02271 L
.15594 .02272 L
.15718 .02273 L
.15852 .02275 L
.15998 .02277 L
Mistroke
.16261 .02283 L
.16504 .02291 L
.17027 .0231 L
.17302 .02322 L
.17592 .02332 L
.17846 .0234 L
.1799 .02344 L
.18125 .02346 L
.18248 .02348 L
.18361 .02349 L
.18491 .02349 L
.18614 .02349 L
.18733 .02348 L
.18863 .02347 L
.18928 .02346 L
.18999 .02346 L
.19127 .02343 L
.196 .02333 L
.20671 .02302 L
.21636 .02274 L
.22533 .02254 L
.23492 .02238 L
.23999 .02233 L
.24541 .02228 L
.24814 .02226 L
.2511 .02225 L
.25371 .02223 L
.25647 .02222 L
.25897 .02222 L
.2617 .02221 L
.26652 .0222 L
.27175 .0222 L
.27432 .02219 L
.27671 .02219 L
.27886 .02219 L
.27995 .02219 L
.28116 .02219 L
.28236 .02219 L
.28366 .02219 L
.28488 .02219 L
.286 .02219 L
.28722 .02219 L
.28852 .02219 L
.28975 .02219 L
.29086 .02219 L
.2936 .02219 L
.29618 .0222 L
.30133 .02221 L
.30691 .02222 L
.3478 .0223 L
Mistroke
.38717 .02238 L
.40694 .02243 L
.41559 .02245 L
.42502 .02246 L
.43019 .02247 L
.43498 .02247 L
.43956 .02247 L
.44213 .02248 L
.44445 .02248 L
.44576 .02248 L
.44714 .02248 L
.44832 .02248 L
.44961 .02248 L
.45034 .02248 L
.45101 .02248 L
.45178 .02248 L
.4525 .02248 L
.4538 .02248 L
.45453 .02248 L
.4552 .02248 L
.45641 .02248 L
.45754 .02248 L
.46011 .02248 L
.46262 .02248 L
.46533 .02247 L
.47491 .02247 L
.48539 .02247 L
.50649 .02245 L
.54707 .02243 L
.58614 .0224 L
.62765 .02238 L
.66766 .02236 L
.70614 .02235 L
.74708 .02234 L
.7865 .02233 L
.82441 .02232 L
.86477 .02231 L
.90361 .02231 L
.94491 .0223 L
.97619 .02229 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.02499 .03252 L
.02605 .04484 L
.02729 .05333 L
.02846 .057 L
.02954 .05817 L
.03053 .05817 L
.03163 .05751 L
.03279 .05637 L
.04262 .04356 L
.05205 .03407 L
.05742 .03018 L
.06244 .02732 L
.06788 .02491 L
.07305 .02313 L
.07768 .02188 L
.08274 .0208 L
.08822 .0199 L
.09407 .01918 L
.09958 .01867 L
.10458 .01831 L
.10945 .01804 L
.1146 .01782 L
.119 .01767 L
.12383 .01754 L
.12902 .01744 L
.13459 .01735 L
.13729 .01732 L
.13985 .0173 L
.14232 .01728 L
.14465 .01726 L
.14704 .01725 L
.14923 .01724 L
.15167 .01723 L
.15295 .01723 L
.15366 .01723 L
.1543 .01723 L
.15553 .01723 L
.15684 .01723 L
.15805 .01723 L
.1592 .01723 L
.15985 .01723 L
.16054 .01723 L
.16177 .01723 L
.1631 .01724 L
.16456 .01724 L
.16908 .01726 L
.17401 .01729 L
.17626 .0173 L
.1775 .0173 L
Mistroke
.17866 .0173 L
.17975 .01731 L
.18092 .01731 L
.18199 .01731 L
.18298 .01731 L
.1842 .01731 L
.18533 .01731 L
.18658 .01731 L
.18728 .01731 L
.18792 .01731 L
.1906 .0173 L
.19314 .01729 L
.20242 .01725 L
.21256 .0172 L
.22332 .01716 L
.2328 .01713 L
.2382 .01712 L
.24326 .01711 L
.2479 .01711 L
.25214 .01711 L
.25437 .0171 L
.2568 .0171 L
.2617 .0171 L
.28299 .01709 L
.28788 .01709 L
.29305 .01709 L
.29746 .01709 L
.29997 .01709 L
.30231 .01709 L
.30356 .01709 L
.30475 .01709 L
.30581 .01709 L
.30697 .01709 L
.30823 .01709 L
.30887 .01709 L
.30957 .01709 L
.31081 .01709 L
.31197 .01709 L
.31325 .01709 L
.31389 .01709 L
.3146 .01709 L
.31701 .01709 L
.31982 .01709 L
.32243 .01709 L
.34141 .01709 L
.35191 .01709 L
.36184 .0171 L
.38042 .0171 L
.39872 .01711 L
.40912 .01711 L
Mistroke
.41885 .01711 L
.42922 .01712 L
.43871 .01712 L
.4439 .01712 L
.44884 .01712 L
.45406 .01712 L
.45679 .01712 L
.45974 .01712 L
.46251 .01712 L
.46506 .01712 L
.46745 .01712 L
.47007 .01712 L
.47242 .01712 L
.47462 .01712 L
.47584 .01712 L
.47694 .01712 L
.47822 .01712 L
.47943 .01712 L
.48063 .01712 L
.48132 .01712 L
.48196 .01712 L
.48326 .01712 L
.48398 .01712 L
.48465 .01712 L
.48577 .01712 L
.487 .01712 L
.48948 .01712 L
.49222 .01712 L
.49514 .01712 L
.50041 .01712 L
.51066 .01712 L
.52177 .01712 L
.54192 .01712 L
.58286 .01712 L
.62229 .01711 L
.66019 .01711 L
.70055 .01711 L
.7394 .01711 L
.78069 .01711 L
.82047 .0171 L
.85874 .0171 L
.89946 .0171 L
.93866 .0171 L
.97619 .0171 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05244 L
.02846 .05538 L
.02954 .05597 L
.03053 .05556 L
.03163 .05457 L
.03279 .05319 L
.04262 .0402 L
.05205 .03124 L
.05742 .02765 L
.06244 .02504 L
.06788 .02285 L
.07305 .02126 L
.07768 .02014 L
.08274 .01918 L
.08822 .01839 L
.09407 .01775 L
.09958 .0173 L
.10458 .01699 L
.10945 .01675 L
.1146 .01656 L
.119 .01643 L
.12383 .01632 L
.12902 .01623 L
.13459 .01615 L
.13985 .0161 L
.14465 .01607 L
.14945 .01604 L
.15188 .01603 L
.15456 .01602 L
.15684 .01602 L
.15929 .01601 L
.16042 .01601 L
.16161 .01601 L
.1627 .01601 L
.16373 .016 L
.16503 .016 L
.16621 .016 L
.16749 .016 L
.16821 .016 L
.16887 .016 L
.16997 .016 L
.17119 .016 L
.17246 .016 L
.17365 .016 L
.17505 .016 L
.17574 .016 L
.17638 .016 L
Mistroke
.17757 .016 L
.17887 .016 L
.17961 .016 L
.1803 .016 L
.1816 .016 L
.18232 .016 L
.18299 .016 L
.18449 .016 L
.18696 .016 L
.18921 .016 L
.19425 .01599 L
.20335 .01597 L
.2141 .01596 L
.21882 .01595 L
.22403 .01594 L
.2285 .01594 L
.23331 .01593 L
.23839 .01593 L
.24315 .01593 L
.24844 .01593 L
.2511 .01593 L
.254 .01593 L
.25915 .01593 L
.26393 .01593 L
.30303 .01592 L
.3133 .01592 L
.32441 .01592 L
.33491 .01591 L
.34458 .01591 L
.34927 .01591 L
.3543 .01591 L
.36338 .01591 L
.36892 .01591 L
.37418 .01591 L
.38403 .01591 L
.39367 .01591 L
.40392 .01591 L
.42233 .01591 L
.43168 .01591 L
.43695 .01591 L
.44178 .01591 L
.44602 .01591 L
.45067 .01591 L
.45302 .01591 L
.45553 .01591 L
.45674 .01591 L
.45789 .01591 L
.45902 .01591 L
.46005 .01591 L
.4612 .01591 L
Mistroke
.46243 .01591 L
.46358 .01591 L
.46467 .01591 L
.46593 .01591 L
.4671 .01591 L
.46838 .01591 L
.46975 .01591 L
.47253 .01591 L
.47515 .01591 L
.48004 .01591 L
.49848 .01591 L
.53705 .01591 L
.57807 .01591 L
.61758 .01591 L
.65557 .01591 L
.69602 .01591 L
.73495 .01591 L
.77633 .01591 L
.81619 .01591 L
.85454 .01591 L
.89534 .01591 L
.93463 .01591 L
.9724 .01591 L
.97619 .01591 L
Mfstroke
1 0 .617 r
.02381 .01472 m
.02605 .04937 L
.02729 .06618 L
.02846 .07964 L
.02954 .08954 L
.03072 .09718 L
.0318 .10146 L
.03279 .10348 L
.03396 .10403 L
.03506 .10321 L
.03626 .10131 L
.03756 .09852 L
.04262 .08497 L
.0521 .06182 L
.05746 .05195 L
.06244 .04467 L
.0679 .03841 L
.07373 .03332 L
.07935 .02959 L
.08445 .02699 L
.08943 .02501 L
.09481 .02336 L
.0999 .02216 L
.10458 .02129 L
.10928 .02061 L
.11432 .02003 L
.11907 .01961 L
.1234 .01931 L
.12849 .01903 L
.13402 .0188 L
.13924 .01864 L
.14407 .01854 L
.1487 .01846 L
.15131 .01843 L
.15369 .01841 L
.1558 .0184 L
.15699 .01839 L
.1581 .01839 L
.15927 .01838 L
.16034 .01838 L
.16157 .01838 L
.16273 .01838 L
.16392 .01838 L
.16523 .01838 L
.16589 .01839 L
.1666 .01839 L
.16788 .01839 L
.17262 .01842 L
.17549 .01843 L
.17691 .01844 L
Mistroke
.17822 .01844 L
.1794 .01845 L
.18067 .01845 L
.18139 .01845 L
.18207 .01845 L
.18333 .01845 L
.1845 .01845 L
.18575 .01845 L
.18693 .01845 L
.188 .01844 L
.19063 .01843 L
.19312 .01841 L
.20345 .01833 L
.21224 .01826 L
.22194 .01819 L
.23162 .01814 L
.23692 .01812 L
.24189 .01811 L
.24652 .0181 L
.25076 .0181 L
.25542 .01809 L
.26032 .01809 L
.29848 .01806 L
.31977 .01805 L
.33909 .01804 L
.34876 .01804 L
.35922 .01803 L
.36909 .01803 L
.37819 .01803 L
.38791 .01803 L
.39699 .01803 L
.41764 .01803 L
.42808 .01802 L
.43797 .01802 L
.44679 .01802 L
.45652 .01802 L
.46616 .01802 L
.47641 .01802 L
.4859 .01802 L
.49482 .01802 L
.4995 .01802 L
.50463 .01802 L
.50999 .01802 L
.51498 .01802 L
.51966 .01802 L
.52392 .01802 L
.52627 .01802 L
.52883 .01802 L
.53125 .01802 L
.53347 .01802 L
Mistroke
.53472 .01802 L
.53591 .01802 L
.53697 .01802 L
.53814 .01802 L
.5394 .01802 L
.5401 .01802 L
.54074 .01802 L
.54198 .01802 L
.54315 .01802 L
.54425 .01802 L
.54542 .01802 L
.54751 .01802 L
.54975 .01802 L
.55221 .01802 L
.55737 .01802 L
.56289 .01802 L
.57284 .01802 L
.5941 .01802 L
.61423 .01802 L
.65257 .01802 L
.69338 .01802 L
.73266 .01802 L
.77043 .01802 L
.81066 .01802 L
.84936 .01802 L
.89052 .01802 L
.93017 .01802 L
.9683 .01802 L
.97619 .01802 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.02846 .0838 L
.03068 .11071 L
.03279 .13046 L
.03398 .13878 L
.03527 .14537 L
.03645 .14922 L
.03754 .15111 L
.03871 .15159 L
.04 .15057 L
.04065 .14955 L
.04135 .14815 L
.04262 .14495 L
.0521 .11145 L
.06244 .07955 L
.06829 .06627 L
.07373 .0566 L
.07892 .04931 L
.08445 .04325 L
.08988 .03864 L
.09501 .03527 L
.09996 .03271 L
.10458 .03081 L
.10923 .0293 L
.11434 .02799 L
.11932 .02701 L
.12466 .0262 L
.12962 .02563 L
.13432 .02522 L
.13854 .02494 L
.14313 .02472 L
.14546 .02464 L
.14798 .02457 L
.14914 .02454 L
.15035 .02452 L
.15139 .02451 L
.15253 .02449 L
.15323 .02449 L
.15389 .02449 L
.15513 .02448 L
.15582 .02448 L
.15646 .02449 L
.15716 .02449 L
.1579 .0245 L
.15913 .02451 L
.16029 .02453 L
.16155 .02455 L
.1629 .02459 L
.1656 .02468 L
.16854 .0248 L
Mistroke
.17388 .02506 L
.1764 .02518 L
.17909 .02528 L
.18039 .02532 L
.18162 .02535 L
.18272 .02538 L
.18391 .02539 L
.18516 .0254 L
.18629 .0254 L
.1876 .0254 L
.18884 .02539 L
.18999 .02537 L
.19105 .02535 L
.19344 .02529 L
.19851 .02512 L
.20389 .0249 L
.21404 .02449 L
.21937 .0243 L
.22497 .02413 L
.22984 .02401 L
.23515 .0239 L
.23999 .02382 L
.24448 .02377 L
.24912 .02373 L
.25333 .0237 L
.25566 .02369 L
.25819 .02368 L
.26057 .02367 L
.26277 .02367 L
.26403 .02367 L
.26522 .02367 L
.26629 .02367 L
.26746 .02366 L
.26873 .02366 L
.26937 .02366 L
.27007 .02366 L
.27132 .02366 L
.27249 .02367 L
.2736 .02367 L
.27477 .02367 L
.27686 .02367 L
.28157 .02368 L
.29155 .0237 L
.29443 .02371 L
.29714 .02372 L
.29958 .02372 L
.30096 .02372 L
.30223 .02372 L
.30336 .02372 L
.30458 .02372 L
Mistroke
.30573 .02372 L
.30678 .02372 L
.30801 .02372 L
.30871 .02372 L
.30936 .02372 L
.31054 .02372 L
.3118 .02372 L
.31454 .02372 L
.31712 .02371 L
.32194 .0237 L
.3403 .02364 L
.34918 .02361 L
.35869 .02358 L
.36913 .02356 L
.37887 .02354 L
.38424 .02354 L
.38931 .02353 L
.39883 .02352 L
.4199 .02351 L
.45825 .02348 L
.47765 .02347 L
.49905 .02346 L
.51932 .02345 L
.53833 .02345 L
.55853 .02344 L
.57704 .02344 L
.59598 .02344 L
.60671 .02344 L
.61669 .02344 L
.62722 .02344 L
.63716 .02344 L
.64608 .02344 L
.65111 .02344 L
.65575 .02344 L
.66043 .02344 L
.66301 .02344 L
.66545 .02344 L
.66772 .02344 L
.6702 .02344 L
.67129 .02344 L
.67245 .02344 L
.67346 .02344 L
.67453 .02344 L
.6752 .02344 L
.67593 .02344 L
.67721 .02344 L
.67794 .02344 L
.67871 .02344 L
.67945 .02344 L
.68011 .02344 L
Mistroke
.68141 .02344 L
.68214 .02344 L
.68281 .02344 L
.68537 .02344 L
.68763 .02344 L
.69013 .02344 L
.69517 .02344 L
.70037 .02344 L
.7053 .02344 L
.71457 .02344 L
.73545 .02344 L
.77363 .02344 L
.81426 .02344 L
.85338 .02344 L
.89495 .02344 L
.935 .02344 L
.97354 .02345 L
.97619 .02345 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.02605 .04938 L
.02729 .06628 L
.02846 .07997 L
.02954 .09027 L
.03072 .09855 L
.0318 .10355 L
.03279 .10628 L
.03396 .10758 L
.03506 .10735 L
.03626 .10596 L
.03756 .10356 L
.04262 .09043 L
.0521 .06635 L
.05746 .05581 L
.06244 .04798 L
.0679 .0412 L
.07373 .03564 L
.07935 .03156 L
.08445 .02871 L
.08943 .02654 L
.09481 .02471 L
.0999 .02338 L
.10458 .02242 L
.10928 .02166 L
.11432 .02102 L
.11907 .02055 L
.1234 .02022 L
.12849 .01991 L
.13402 .01966 L
.13924 .01948 L
.14176 .01942 L
.14407 .01937 L
.1487 .01929 L
.15113 .01926 L
.15237 .01925 L
.15369 .01924 L
.15487 .01923 L
.15593 .01922 L
.157 .01922 L
.15801 .01922 L
.15919 .01921 L
.16028 .01921 L
.16147 .01922 L
.16273 .01922 L
.16401 .01922 L
.16518 .01923 L
.1678 .01925 L
.17254 .0193 L
.17524 .01932 L
Mistroke
.17777 .01934 L
.17917 .01935 L
.17991 .01936 L
.18069 .01936 L
.18135 .01937 L
.18207 .01937 L
.18333 .01937 L
.18462 .01937 L
.1858 .01937 L
.18645 .01937 L
.18716 .01937 L
.18844 .01936 L
.18964 .01935 L
.19092 .01935 L
.1932 .01933 L
.20236 .01923 L
.21234 .01911 L
.21758 .01906 L
.22309 .01901 L
.22796 .01897 L
.23328 .01894 L
.23811 .01891 L
.2426 .0189 L
.24724 .01888 L
.25145 .01888 L
.25379 .01887 L
.25632 .01887 L
.2609 .01886 L
.26326 .01886 L
.2658 .01886 L
.27039 .01886 L
.27319 .01886 L
.27584 .01886 L
.28081 .01886 L
.28607 .01886 L
.29102 .01885 L
.2935 .01885 L
.29617 .01885 L
.29914 .01885 L
.30187 .01885 L
.30649 .01885 L
.31155 .01885 L
.32175 .01884 L
.34017 .01882 L
.35024 .01881 L
.35975 .01881 L
.37072 .0188 L
.38069 .0188 L
.3904 .01879 L
.40068 .01879 L
Mistroke
.41913 .01879 L
.45698 .01878 L
.47641 .01878 L
.48732 .01878 L
.49729 .01878 L
.51629 .01878 L
.52704 .01878 L
.53702 .01878 L
.5476 .01878 L
.55756 .01878 L
.56643 .01878 L
.57617 .01878 L
.58594 .01878 L
.59092 .01878 L
.59626 .01878 L
.60126 .01878 L
.60582 .01878 L
.6104 .01878 L
.61474 .01878 L
.61711 .01878 L
.61933 .01878 L
.62061 .01878 L
.62177 .01878 L
.62306 .01878 L
.6237 .01878 L
.6244 .01878 L
.6251 .01878 L
.62575 .01878 L
.62697 .01878 L
.62829 .01878 L
.62904 .01878 L
.62972 .01878 L
.63086 .01878 L
.63212 .01878 L
.63466 .01878 L
.63706 .01878 L
.63926 .01878 L
.64419 .01878 L
.65309 .01878 L
.66297 .01878 L
.67213 .01878 L
.69287 .01878 L
.73207 .01878 L
.77373 .01878 L
.81386 .01878 L
.85249 .01878 L
.89356 .01878 L
.93312 .01878 L
.97117 .01878 L
.97619 .01878 L
Mistroke
Mfstroke
1 0 .545 r
.02381 .01472 m
.02499 .03293 L
.02605 .04725 L
.02729 .06006 L
.02846 .06839 L
.02954 .07325 L
.03053 .07583 L
.03163 .07711 L
.03279 .07723 L
.03395 .07648 L
.0352 .07505 L
.03746 .07153 L
.04262 .06222 L
.0521 .04722 L
.05746 .0408 L
.06244 .03605 L
.0679 .03193 L
.07373 .02856 L
.07935 .02607 L
.08445 .02434 L
.08943 .02301 L
.09481 .02189 L
.0999 .02108 L
.10458 .02049 L
.10928 .02003 L
.11432 .01964 L
.11907 .01935 L
.1234 .01914 L
.12849 .01895 L
.13402 .0188 L
.13924 .0187 L
.14176 .01866 L
.14407 .01863 L
.14628 .01861 L
.1487 .01859 L
.15113 .01857 L
.15246 .01857 L
.15369 .01856 L
.15487 .01856 L
.15598 .01856 L
.15698 .01856 L
.15806 .01856 L
.15924 .01856 L
.16049 .01857 L
.16156 .01857 L
.16273 .01857 L
.16541 .01859 L
.16786 .01861 L
.17338 .01867 L
.17582 .01869 L
Mistroke
.17711 .0187 L
.17848 .01871 L
.1798 .01872 L
.181 .01872 L
.1822 .01873 L
.18333 .01873 L
.1845 .01873 L
.18575 .01873 L
.18693 .01873 L
.188 .01872 L
.18926 .01872 L
.19063 .01871 L
.19312 .0187 L
.19849 .01866 L
.20345 .01861 L
.21235 .01853 L
.22194 .01845 L
.22698 .01842 L
.23159 .0184 L
.23628 .01838 L
.24064 .01836 L
.24544 .01835 L
.24798 .01834 L
.25069 .01834 L
.25354 .01834 L
.25623 .01833 L
.25864 .01833 L
.26126 .01833 L
.26362 .01833 L
.26495 .01833 L
.26616 .01833 L
.26729 .01833 L
.26851 .01833 L
.26967 .01833 L
.27074 .01833 L
.27198 .01833 L
.27315 .01833 L
.27442 .01833 L
.2758 .01833 L
.2786 .01833 L
.28117 .01833 L
.28606 .01833 L
.29142 .01834 L
.29698 .01834 L
.30223 .01834 L
.30715 .01835 L
.30849 .01835 L
.30992 .01835 L
.31116 .01835 L
.31248 .01835 L
Mistroke
.31368 .01835 L
.31478 .01835 L
.31588 .01835 L
.31692 .01835 L
.31814 .01835 L
.31926 .01835 L
.3205 .01835 L
.32181 .01835 L
.32323 .01835 L
.32453 .01835 L
.32747 .01835 L
.3328 .01835 L
.34275 .01834 L
.35185 .01834 L
.35685 .01834 L
.36159 .01833 L
.36427 .01833 L
.36719 .01833 L
.36847 .01833 L
.36984 .01833 L
.37102 .01833 L
.37229 .01833 L
.37356 .01833 L
.37473 .01833 L
.37585 .01833 L
.37703 .01833 L
.37832 .01833 L
.37953 .01833 L
.38085 .01833 L
.38159 .01833 L
.38226 .01833 L
.39238 .01833 L
.39791 .01833 L
.40061 .01833 L
.40308 .01833 L
.40519 .01833 L
.40749 .01834 L
.40875 .01834 L
.40991 .01834 L
.41103 .01834 L
.41222 .01834 L
.41352 .01834 L
.41426 .01834 L
.41494 .01834 L
.41618 .01834 L
.41749 .01834 L
.41867 .01834 L
.41977 .01834 L
.42226 .01833 L
.42466 .01833 L
Mistroke
.42727 .01833 L
.432 .01833 L
.44086 .01833 L
.46075 .01833 L
.48019 .01832 L
.5016 .01832 L
.54094 .01831 L
.56197 .01831 L
.58122 .01831 L
.60131 .01831 L
.61998 .01831 L
.63895 .01831 L
.65967 .01831 L
.68019 .01831 L
.69879 .01831 L
.71803 .01831 L
.72887 .01831 L
.73885 .01831 L
.74858 .01831 L
.75766 .01831 L
.76288 .01831 L
.76763 .01831 L
.77026 .01831 L
.77312 .01831 L
.77562 .01831 L
.77832 .01831 L
.77955 .01831 L
.78085 .01831 L
.78205 .01831 L
.78317 .01831 L
.78422 .01831 L
.78534 .01831 L
.78658 .01831 L
.78771 .01831 L
.78836 .01831 L
.78905 .01831 L
.79027 .01831 L
.79159 .01831 L
.79235 .01831 L
.79305 .01831 L
.79548 .01831 L
.79809 .01831 L
.80371 .01831 L
.80906 .01831 L
.81909 .01831 L
.83893 .01831 L
.85732 .01831 L
.89649 .01831 L
.93812 .01831 L
.97619 .01831 L
Mistroke
Mfstroke
1 0 .522 r
.02381 .01472 m
.02499 .03251 L
.02605 .04472 L
.02729 .05286 L
.02846 .05614 L
.02954 .05697 L
.03053 .05674 L
.03163 .05588 L
.03279 .05459 L
.04262 .04161 L
.05205 .03242 L
.05742 .0287 L
.06244 .02599 L
.06788 .02371 L
.07305 .02205 L
.07768 .02088 L
.08274 .01988 L
.08822 .01904 L
.09407 .01837 L
.09958 .0179 L
.10458 .01757 L
.10945 .01732 L
.1146 .01712 L
.119 .01699 L
.12383 .01687 L
.12902 .01677 L
.13459 .0167 L
.13985 .01664 L
.14465 .01661 L
.14693 .0166 L
.14945 .01658 L
.15209 .01658 L
.15329 .01657 L
.15456 .01657 L
.15566 .01657 L
.15686 .01656 L
.15796 .01656 L
.15897 .01656 L
.16018 .01656 L
.16127 .01656 L
.16254 .01656 L
.16373 .01656 L
.16493 .01656 L
.16625 .01657 L
.16891 .01657 L
.17369 .01658 L
.17638 .01659 L
.17789 .01659 L
.17861 .01659 L
.17927 .01659 L
Mistroke
.18055 .01659 L
.18123 .01659 L
.18195 .01659 L
.18264 .01659 L
.18328 .01659 L
.18449 .01659 L
.18566 .01659 L
.18691 .01659 L
.18916 .01658 L
.19184 .01658 L
.19428 .01657 L
.20461 .01654 L
.21358 .01652 L
.22309 .0165 L
.22782 .01649 L
.23303 .01648 L
.23777 .01647 L
.24222 .01647 L
.24476 .01647 L
.24744 .01647 L
.25222 .01646 L
.25489 .01646 L
.25737 .01646 L
.26299 .01646 L
.26806 .01646 L
.27354 .01646 L
.27838 .01646 L
.28349 .01646 L
.2881 .01646 L
.29072 .01646 L
.29198 .01646 L
.29317 .01646 L
.29425 .01646 L
.29542 .01646 L
.29649 .01646 L
.29747 .01646 L
.29854 .01646 L
.29971 .01646 L
.30094 .01646 L
.30209 .01646 L
.30326 .01646 L
.30452 .01646 L
.30678 .01646 L
.3119 .01646 L
.32225 .01646 L
.34074 .01646 L
.35097 .01646 L
.35674 .01646 L
.36207 .01646 L
.37185 .01646 L
Mistroke
.38221 .01646 L
.40198 .01647 L
.41063 .01647 L
.42007 .01647 L
.42523 .01647 L
.42775 .01647 L
.43003 .01647 L
.43223 .01647 L
.43461 .01647 L
.43712 .01647 L
.43949 .01647 L
.44079 .01647 L
.44201 .01647 L
.44271 .01647 L
.44335 .01647 L
.44408 .01647 L
.44478 .01647 L
.44546 .01647 L
.44617 .01647 L
.44746 .01647 L
.44817 .01647 L
.44884 .01647 L
.45037 .01647 L
.45288 .01647 L
.45518 .01647 L
.46037 .01647 L
.47019 .01647 L
.47931 .01647 L
.50002 .01647 L
.53908 .01647 L
.5806 .01646 L
.6206 .01646 L
.65909 .01646 L
.70003 .01646 L
.73945 .01646 L
.77736 .01646 L
.81772 .01646 L
.85656 .01646 L
.89786 .01646 L
.93764 .01646 L
.9759 .01646 L
.97619 .01646 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.02499 .03293 L
.02605 .0472 L
.02729 .05986 L
.02846 .06798 L
.02954 .07264 L
.03053 .07507 L
.03163 .07624 L
.03279 .0763 L
.03395 .07553 L
.0352 .07411 L
.03746 .07068 L
.04262 .06162 L
.0521 .04696 L
.05746 .04066 L
.06244 .03597 L
.0679 .0319 L
.07373 .02856 L
.07935 .0261 L
.08445 .02437 L
.08943 .02305 L
.09481 .02194 L
.0999 .02113 L
.10458 .02054 L
.10928 .02007 L
.11432 .01968 L
.11907 .0194 L
.1234 .01919 L
.12849 .019 L
.13402 .01885 L
.13924 .01874 L
.14176 .01871 L
.14407 .01868 L
.14628 .01865 L
.1487 .01863 L
.15113 .01862 L
.15246 .01861 L
.15369 .01861 L
.15487 .01861 L
.15598 .01861 L
.15698 .0186 L
.15806 .01861 L
.15924 .01861 L
.16049 .01861 L
.16156 .01862 L
.16273 .01862 L
.16541 .01864 L
.16786 .01866 L
.17338 .01871 L
.17582 .01874 L
Mistroke
.17711 .01875 L
.17848 .01876 L
.1798 .01877 L
.181 .01877 L
.1822 .01878 L
.18333 .01878 L
.1845 .01878 L
.18575 .01878 L
.18693 .01878 L
.188 .01877 L
.18926 .01877 L
.19063 .01876 L
.19312 .01875 L
.19849 .01871 L
.20345 .01866 L
.21235 .01857 L
.22194 .01849 L
.22698 .01846 L
.23159 .01844 L
.23628 .01842 L
.24064 .0184 L
.24544 .01839 L
.24819 .01838 L
.25069 .01838 L
.25314 .01837 L
.2558 .01837 L
.25861 .01837 L
.26126 .01837 L
.26362 .01837 L
.26616 .01837 L
.26856 .01836 L
.27074 .01836 L
.27208 .01836 L
.27331 .01836 L
.27395 .01836 L
.27466 .01836 L
.2754 .01836 L
.2761 .01836 L
.27737 .01836 L
.27854 .01836 L
.27982 .01836 L
.28117 .01836 L
.28369 .01836 L
.28637 .01837 L
.29122 .01837 L
.29694 .01837 L
.29946 .01837 L
.30079 .01837 L
.30223 .01837 L
.30291 .01837 L
Mistroke
.30357 .01837 L
.30479 .01837 L
.30594 .01837 L
.30719 .01837 L
.30851 .01837 L
.30925 .01837 L
.30992 .01837 L
.31122 .01837 L
.31245 .01837 L
.31523 .01837 L
.31778 .01837 L
.32355 .01837 L
.34369 .01836 L
.35279 .01835 L
.36253 .01835 L
.36812 .01835 L
.37322 .01834 L
.37835 .01834 L
.3832 .01834 L
.38779 .01834 L
.39286 .01834 L
.40312 .01834 L
.4121 .01834 L
.41661 .01834 L
.42155 .01834 L
.43165 .01834 L
.44091 .01834 L
.46177 .01833 L
.48304 .01833 L
.50235 .01833 L
.54142 .01832 L
.56062 .01832 L
.58142 .01832 L
.60131 .01832 L
.62236 .01832 L
.6318 .01832 L
.64195 .01832 L
.66027 .01832 L
.67041 .01832 L
.68146 .01832 L
.68651 .01832 L
.69189 .01832 L
.6966 .01832 L
.70156 .01832 L
.70413 .01832 L
.70694 .01832 L
.70953 .01832 L
.71188 .01832 L
.71467 .01832 L
.7162 .01832 L
Mistroke
.71691 .01832 L
.71765 .01832 L
.71829 .01832 L
.71899 .01832 L
.72023 .01832 L
.72093 .01832 L
.72168 .01832 L
.72238 .01832 L
.72303 .01832 L
.72427 .01832 L
.72496 .01832 L
.72559 .01832 L
.72798 .01832 L
.72931 .01832 L
.73076 .01832 L
.73338 .01832 L
.7385 .01832 L
.74322 .01832 L
.75295 .01832 L
.76203 .01832 L
.78269 .01832 L
.82159 .01832 L
.86294 .01832 L
.90277 .01832 L
.94109 .01832 L
.97619 .01832 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.02499 .03292 L
.02605 .04713 L
.02729 .05958 L
.02846 .06732 L
.02954 .07156 L
.03053 .0736 L
.03163 .07439 L
.03279 .07412 L
.03395 .07311 L
.0352 .07151 L
.03746 .06789 L
.04262 .05883 L
.0521 .04469 L
.05746 .0387 L
.06244 .03427 L
.0679 .03045 L
.07373 .02733 L
.07935 .02503 L
.08445 .02342 L
.08943 .02219 L
.09481 .02116 L
.0999 .02041 L
.10458 .01987 L
.10928 .01944 L
.11432 .01908 L
.11907 .01881 L
.1234 .01862 L
.12849 .01845 L
.13402 .01831 L
.13924 .01821 L
.14176 .01817 L
.14407 .01814 L
.14628 .01812 L
.1487 .0181 L
.15113 .01809 L
.15246 .01808 L
.15369 .01808 L
.15487 .01807 L
.15598 .01807 L
.15698 .01807 L
.15806 .01807 L
.15924 .01807 L
.16049 .01807 L
.16156 .01807 L
.16273 .01808 L
.16411 .01808 L
.16541 .01809 L
.16786 .0181 L
.17338 .01814 L
Mistroke
.17568 .01816 L
.17814 .01817 L
.17955 .01818 L
.18083 .01818 L
.18212 .01818 L
.18333 .01819 L
.1845 .01819 L
.18575 .01819 L
.18693 .01818 L
.188 .01818 L
.18926 .01818 L
.19063 .01817 L
.19312 .01816 L
.20345 .01809 L
.21299 .01801 L
.22194 .01796 L
.23136 .01791 L
.23636 .0179 L
.24175 .01788 L
.2471 .01787 L
.24979 .01787 L
.25272 .01787 L
.25524 .01786 L
.25793 .01786 L
.26024 .01786 L
.26277 .01786 L
.26537 .01786 L
.26812 .01786 L
.27066 .01786 L
.27304 .01786 L
.27448 .01786 L
.27584 .01786 L
.27708 .01786 L
.2784 .01786 L
.27908 .01786 L
.27983 .01786 L
.28052 .01786 L
.28116 .01786 L
.2819 .01786 L
.2827 .01786 L
.28341 .01786 L
.28416 .01786 L
.28542 .01786 L
.28657 .01786 L
.28789 .01786 L
.28914 .01786 L
.2914 .01786 L
.29263 .01786 L
.29378 .01786 L
.29503 .01786 L
Mistroke
.2957 .01786 L
.29641 .01786 L
.29768 .01786 L
.29884 .01786 L
.29953 .01786 L
.30018 .01786 L
.30165 .01786 L
.30294 .01786 L
.30432 .01786 L
.30693 .01786 L
.30968 .01785 L
.31462 .01785 L
.31992 .01785 L
.32575 .01785 L
.34592 .01784 L
.35595 .01784 L
.36545 .01783 L
.37069 .01783 L
.37639 .01783 L
.38157 .01783 L
.38637 .01783 L
.40664 .01783 L
.41656 .01783 L
.42565 .01783 L
.44383 .01783 L
.46342 .01783 L
.48397 .01782 L
.50307 .01782 L
.52151 .01782 L
.5412 .01782 L
.56112 .01782 L
.58271 .01782 L
.60353 .01782 L
.61345 .01782 L
.62272 .01782 L
.64149 .01782 L
.65145 .01782 L
.66214 .01782 L
.67228 .01782 L
.67801 .01782 L
.68333 .01782 L
.68596 .01782 L
.68844 .01782 L
.69069 .01782 L
.69307 .01782 L
.69431 .01782 L
.69567 .01782 L
.69692 .01782 L
.69805 .01782 L
.6994 .01782 L
Mistroke
.70014 .01782 L
.70084 .01782 L
.70208 .01782 L
.70279 .01782 L
.70344 .01782 L
.70468 .01782 L
.70587 .01782 L
.70693 .01782 L
.70809 .01782 L
.71069 .01782 L
.7131 .01782 L
.71748 .01782 L
.72215 .01782 L
.73297 .01782 L
.74277 .01782 L
.76201 .01782 L
.78283 .01782 L
.82382 .01782 L
.86329 .01782 L
.90125 .01782 L
.94167 .01782 L
.97619 .01782 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.02499 .02089 L
.02605 .02141 L
.02729 .0214 L
.02846 .02123 L
.03053 .02081 L
.03279 .0203 L
.04262 .01842 L
.04762 .01771 L
.05293 .01712 L
.0579 .01669 L
.06244 .01638 L
.06743 .01611 L
.0728 .01588 L
.07777 .01572 L
.0825 .0156 L
.08797 .01549 L
.09305 .01541 L
.09863 .01535 L
.10458 .0153 L
.10994 .01526 L
.11487 .01524 L
.12028 .01522 L
.12599 .0152 L
.13096 .01519 L
.13561 .01518 L
.1407 .01518 L
.14335 .01517 L
.14616 .01517 L
.14867 .01517 L
.15145 .01517 L
.15397 .01517 L
.15634 .01517 L
.15769 .01517 L
.15843 .01517 L
.15911 .01517 L
.16033 .01517 L
.16097 .01517 L
.16166 .01517 L
.1624 .01517 L
.16321 .01517 L
.16397 .01517 L
.16467 .01517 L
.166 .01517 L
.1674 .01517 L
.17202 .01517 L
.17457 .01517 L
.17582 .01517 L
.17698 .01517 L
.1777 .01517 L
Mistroke
.17834 .01517 L
.17906 .01517 L
.17983 .01517 L
.18047 .01517 L
.18117 .01517 L
.18243 .01517 L
.18372 .01517 L
.18437 .01517 L
.18508 .01517 L
.18752 .01517 L
.19004 .01517 L
.19278 .01517 L
.19775 .01517 L
.20707 .01516 L
.21703 .01516 L
.22231 .01516 L
.228 .01516 L
.23334 .01516 L
.23823 .01516 L
.2429 .01516 L
.24781 .01516 L
.25033 .01516 L
.25302 .01515 L
.25786 .01515 L
.26082 .01515 L
.26361 .01515 L
.26883 .01515 L
.27858 .01515 L
.28889 .01515 L
.29854 .01515 L
.30735 .01515 L
.31221 .01515 L
.31681 .01515 L
.32167 .01515 L
.32419 .01515 L
.32697 .01515 L
.32918 .01515 L
.33158 .01515 L
.33411 .01515 L
.33524 .01515 L
.33648 .01515 L
.33756 .01515 L
.33872 .01515 L
.33994 .01515 L
.34108 .01515 L
.34221 .01515 L
.34328 .01515 L
.34425 .01515 L
.34529 .01515 L
.34652 .01515 L
Mistroke
.34764 .01515 L
.34894 .01515 L
.35017 .01515 L
.35474 .01515 L
.35732 .01515 L
.35972 .01515 L
.36514 .01515 L
.37533 .01515 L
.38618 .01515 L
.40617 .01515 L
.41668 .01515 L
.42778 .01515 L
.43774 .01515 L
.44339 .01515 L
.44866 .01515 L
.45351 .01515 L
.45793 .01515 L
.46038 .01515 L
.46304 .01515 L
.46555 .01515 L
.46787 .01515 L
.46905 .01515 L
.47029 .01515 L
.47136 .01515 L
.47251 .01515 L
.47374 .01515 L
.47489 .01515 L
.4756 .01515 L
.47626 .01515 L
.4775 .01515 L
.4786 .01515 L
.47976 .01515 L
.48075 .01515 L
.48184 .01515 L
.48427 .01515 L
.48655 .01515 L
.49174 .01515 L
.49648 .01515 L
.50715 .01515 L
.52619 .01515 L
.54693 .01515 L
.58765 .01515 L
.62685 .01515 L
.66851 .01515 L
.70865 .01515 L
.74727 .01515 L
.78834 .01515 L
.8279 .01515 L
.86595 .01515 L
.90644 .01515 L
Mistroke
.94543 .01515 L
.97619 .01515 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.02605 .04945 L
.02729 .06658 L
.02846 .08073 L
.02954 .09173 L
.03072 .10101 L
.0318 .10702 L
.03279 .11067 L
.03396 .11295 L
.03506 .11347 L
.03626 .11269 L
.03756 .11072 L
.03891 .10783 L
.0402 .10459 L
.04262 .09785 L
.05221 .07197 L
.06244 .05215 L
.06792 .04464 L
.07289 .03929 L
.07794 .03499 L
.08259 .03185 L
.08803 .02897 L
.09391 .0266 L
.0991 .02502 L
.10458 .02373 L
.10954 .02283 L
.11406 .02218 L
.11928 .0216 L
.12422 .02118 L
.12878 .02088 L
.133 .02066 L
.13763 .02047 L
.14003 .02039 L
.14255 .02032 L
.14489 .02027 L
.14744 .02022 L
.14976 .02019 L
.15192 .02017 L
.15324 .02016 L
.15448 .02015 L
.1556 .02014 L
.15681 .02014 L
.15812 .02014 L
.15879 .02014 L
.15952 .02014 L
.16081 .02015 L
.16202 .02015 L
.16315 .02016 L
.16438 .02017 L
.16663 .02019 L
Mistroke
.17083 .02025 L
.17539 .02032 L
.17778 .02036 L
.17908 .02037 L
.1803 .02038 L
.18163 .02039 L
.18233 .02039 L
.18308 .02039 L
.18377 .0204 L
.18442 .0204 L
.18563 .0204 L
.18688 .02039 L
.18804 .02039 L
.1893 .02038 L
.19065 .02037 L
.1951 .02032 L
.20001 .02025 L
.21097 .02007 L
.221 .01993 L
.23045 .01984 L
.2352 .0198 L
.24039 .01977 L
.24562 .01975 L
.24855 .01974 L
.2512 .01973 L
.25369 .01973 L
.25638 .01972 L
.26126 .01972 L
.26362 .01972 L
.26616 .01971 L
.27074 .01971 L
.27354 .01971 L
.2762 .01971 L
.27858 .01971 L
.27991 .01971 L
.28117 .01971 L
.28369 .01971 L
.28503 .01971 L
.28647 .01971 L
.28921 .01971 L
.2921 .01971 L
.29462 .01971 L
.29605 .01971 L
.29738 .01971 L
.29972 .01971 L
.30223 .01971 L
.30481 .0197 L
.30754 .0197 L
.31245 .0197 L
.32355 .01969 L
Mistroke
.34369 .01967 L
.35311 .01967 L
.35831 .01966 L
.36324 .01966 L
.36781 .01966 L
.3728 .01966 L
.38155 .01965 L
.38687 .01965 L
.39187 .01965 L
.40123 .01965 L
.42221 .01965 L
.46078 .01964 L
.48034 .01964 L
.50181 .01963 L
.52224 .01963 L
.54131 .01963 L
.55996 .01963 L
.58024 .01963 L
.59129 .01963 L
.6015 .01963 L
.61188 .01963 L
.62162 .01963 L
.63137 .01963 L
.6403 .01963 L
.65022 .01963 L
.65543 .01963 L
.66091 .01963 L
.66592 .01963 L
.67046 .01963 L
.67298 .01963 L
.67571 .01963 L
.67696 .01963 L
.67829 .01963 L
.67953 .01963 L
.68067 .01963 L
.68178 .01963 L
.68285 .01963 L
.68397 .01963 L
.68519 .01963 L
.68625 .01963 L
.68738 .01963 L
.68845 .01963 L
.68942 .01963 L
.6918 .01963 L
.69437 .01963 L
.69904 .01963 L
.70398 .01963 L
.70858 .01963 L
.71903 .01963 L
.74011 .01963 L
Mistroke
.77909 .01963 L
.82053 .01963 L
.86044 .01963 L
.89885 .01963 L
.9397 .01963 L
.97619 .01963 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.02499 .03251 L
.02605 .04471 L
.02729 .05282 L
.02846 .05604 L
.02954 .05682 L
.03053 .05654 L
.03163 .05564 L
.03279 .05431 L
.04262 .0412 L
.05205 .03201 L
.05742 .0283 L
.06244 .0256 L
.06788 .02335 L
.07305 .0217 L
.07768 .02054 L
.08274 .01954 L
.08822 .01872 L
.09407 .01806 L
.09958 .0176 L
.10458 .01727 L
.10945 .01703 L
.1146 .01683 L
.119 .01669 L
.12383 .01658 L
.12902 .01648 L
.13459 .01641 L
.13985 .01636 L
.14465 .01632 L
.14945 .01629 L
.15188 .01628 L
.15456 .01628 L
.15684 .01627 L
.15803 .01627 L
.15929 .01627 L
.1604 .01626 L
.16161 .01626 L
.16271 .01626 L
.16373 .01626 L
.16503 .01626 L
.16576 .01626 L
.16644 .01626 L
.16768 .01626 L
.16899 .01626 L
.17377 .01627 L
.17504 .01627 L
.17641 .01627 L
.1777 .01627 L
.17887 .01627 L
.17959 .01627 L
Mistroke
.18025 .01627 L
.18098 .01627 L
.18176 .01627 L
.1825 .01627 L
.18319 .01627 L
.18449 .01627 L
.18566 .01627 L
.18691 .01627 L
.18916 .01626 L
.19428 .01625 L
.20461 .01623 L
.21422 .01621 L
.22309 .0162 L
.22804 .01619 L
.23329 .01619 L
.23856 .01618 L
.2416 .01618 L
.24437 .01618 L
.24938 .01618 L
.252 .01617 L
.25477 .01617 L
.25942 .01617 L
.26451 .01617 L
.2858 .01617 L
.29586 .01617 L
.30512 .01617 L
.31478 .01617 L
.32524 .01617 L
.33505 .01617 L
.34422 .01616 L
.34887 .01616 L
.35329 .01616 L
.35572 .01616 L
.35838 .01616 L
.36077 .01616 L
.36302 .01616 L
.36549 .01616 L
.3668 .01616 L
.36822 .01616 L
.36962 .01616 L
.37033 .01616 L
.3711 .01616 L
.37176 .01616 L
.37247 .01616 L
.37374 .01616 L
.37503 .01616 L
.37575 .01616 L
.37642 .01616 L
.37764 .01616 L
.37894 .01616 L
Mistroke
.3812 .01616 L
.38367 .01616 L
.39447 .01616 L
.40473 .01616 L
.40919 .01616 L
.41394 .01616 L
.41534 .01616 L
.41667 .01616 L
.41796 .01616 L
.41915 .01616 L
.42028 .01616 L
.42147 .01616 L
.42267 .01616 L
.42398 .01616 L
.42523 .01616 L
.42593 .01616 L
.42658 .01616 L
.42778 .01616 L
.42905 .01616 L
.43125 .01616 L
.43367 .01616 L
.43902 .01616 L
.44405 .01616 L
.46277 .01616 L
.50148 .01616 L
.54264 .01616 L
.58228 .01616 L
.62041 .01616 L
.64004 .01616 L
.66099 .01616 L
.68235 .01616 L
.70251 .01616 L
.72254 .01616 L
.741 .01616 L
.75978 .01616 L
.77057 .01616 L
.78042 .01616 L
.79988 .01616 L
.81061 .01616 L
.82078 .01616 L
.8304 .01616 L
.84064 .01616 L
.8503 .01616 L
.85905 .01616 L
.86394 .01616 L
.86911 .01616 L
.87834 .01616 L
.88349 .01616 L
.88829 .01616 L
.89104 .01616 L
Mistroke
.89355 .01616 L
.89645 .01616 L
.89777 .01616 L
.89918 .01616 L
.90043 .01616 L
.90156 .01616 L
.90271 .01616 L
.90379 .01616 L
.90505 .01616 L
.90622 .01616 L
.9075 .01616 L
.90822 .01616 L
.90887 .01616 L
.9102 .01616 L
.91141 .01616 L
.91416 .01616 L
.91659 .01616 L
.91915 .01616 L
.92794 .01616 L
.93759 .01616 L
.97619 .01616 L
Mfstroke
1 0 .379 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .0212 L
.03053 .02077 L
.03279 .02026 L
.04262 .01833 L
.04762 .01762 L
.05293 .01702 L
.05746 .01662 L
.06244 .01627 L
.06792 .01597 L
.07293 .01577 L
.07871 .01558 L
.0842 .01545 L
.08925 .01536 L
.09394 .01529 L
.09909 .01523 L
.10458 .01518 L
.10994 .01515 L
.11487 .01512 L
.12028 .0151 L
.12599 .01509 L
.13096 .01508 L
.13561 .01507 L
.1407 .01506 L
.14616 .01506 L
.14872 .01506 L
.15145 .01505 L
.15634 .01505 L
.15905 .01505 L
.1616 .01505 L
.16305 .01505 L
.16439 .01505 L
.16586 .01505 L
.1674 .01505 L
.16857 .01505 L
.1698 .01505 L
.17045 .01505 L
.17116 .01505 L
.17241 .01505 L
.17468 .01505 L
.17594 .01505 L
.17713 .01505 L
.1786 .01505 L
.17994 .01505 L
.1812 .01505 L
.18258 .01505 L
.18514 .01505 L
Mistroke
.18752 .01505 L
.19708 .01505 L
.20726 .01504 L
.21684 .01504 L
.22563 .01504 L
.23065 .01504 L
.23594 .01504 L
.24126 .01504 L
.24427 .01504 L
.24708 .01504 L
.24971 .01504 L
.25219 .01504 L
.25683 .01504 L
.26727 .01504 L
.27695 .01504 L
.28722 .01504 L
.30565 .01504 L
.31504 .01504 L
.31997 .01504 L
.32516 .01504 L
.32972 .01504 L
.33471 .01504 L
.33891 .01504 L
.34345 .01504 L
.34875 .01504 L
.35375 .01504 L
.35862 .01504 L
.3631 .01504 L
.36796 .01504 L
.37071 .01504 L
.37329 .01504 L
.37849 .01504 L
.38406 .01504 L
.40385 .01504 L
.41429 .01504 L
.42001 .01504 L
.42282 .01504 L
.42539 .01504 L
.42765 .01504 L
.43012 .01504 L
.43132 .01504 L
.4326 .01504 L
.43331 .01504 L
.43395 .01504 L
.43521 .01504 L
.43589 .01504 L
.43661 .01504 L
.43789 .01504 L
.4386 .01504 L
.43927 .01504 L
Mistroke
.44 .01504 L
.44079 .01504 L
.44221 .01504 L
.44355 .01504 L
.44606 .01504 L
.44836 .01504 L
.45081 .01504 L
.45522 .01504 L
.46521 .01504 L
.50681 .01504 L
.54689 .01504 L
.58546 .01504 L
.62649 .01504 L
.666 .01504 L
.70399 .01504 L
.74443 .01504 L
.78336 .01504 L
.82474 .01504 L
.86461 .01504 L
.90296 .01504 L
.94376 .01504 L
.97619 .01504 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.02499 .03209 L
.02605 .04244 L
.02729 .04757 L
.02846 .04871 L
.02954 .04841 L
.03053 .04762 L
.03279 .04513 L
.03746 .03959 L
.04262 .03432 L
.04725 .03048 L
.05224 .02719 L
.05751 .02448 L
.06244 .02252 L
.06784 .02086 L
.07373 .0195 L
.07929 .01854 L
.08445 .01786 L
.08956 .01734 L
.09419 .01698 L
.09954 .01665 L
.10458 .01642 L
.10923 .01625 L
.11434 .0161 L
.11968 .01599 L
.12466 .01591 L
.12932 .01585 L
.13357 .01581 L
.13848 .01577 L
.14313 .01574 L
.14772 .01572 L
.15278 .0157 L
.15533 .0157 L
.15807 .01569 L
.16066 .01569 L
.16181 .01569 L
.16304 .01569 L
.1642 .01568 L
.16526 .01568 L
.16633 .01568 L
.16733 .01568 L
.16848 .01568 L
.16974 .01568 L
.17084 .01568 L
.17201 .01568 L
.17418 .01568 L
.1754 .01568 L
.17651 .01568 L
.17782 .01568 L
.17907 .01568 L
Mistroke
.18021 .01568 L
.18146 .01568 L
.18402 .01568 L
.18679 .01568 L
.1918 .01567 L
.20117 .01566 L
.21118 .01565 L
.21648 .01565 L
.22216 .01564 L
.22757 .01564 L
.2325 .01564 L
.23745 .01563 L
.24214 .01563 L
.24468 .01563 L
.24739 .01563 L
.25224 .01563 L
.25493 .01563 L
.25746 .01563 L
.26321 .01563 L
.28173 .01563 L
.29221 .01563 L
.30195 .01563 L
.31167 .01563 L
.3171 .01563 L
.32203 .01563 L
.32725 .01563 L
.3329 .01563 L
.33823 .01563 L
.34314 .01563 L
.34783 .01563 L
.35046 .01563 L
.35286 .01562 L
.35395 .01562 L
.3551 .01562 L
.35636 .01562 L
.35753 .01562 L
.35861 .01562 L
.35963 .01562 L
.36074 .01562 L
.36195 .01562 L
.36324 .01562 L
.36445 .01562 L
.36577 .01562 L
.36719 .01562 L
.37008 .01563 L
.37272 .01563 L
.3826 .01563 L
.40338 .01563 L
.4125 .01563 L
.41769 .01563 L
Mistroke
.42255 .01563 L
.42496 .01563 L
.42725 .01563 L
.4293 .01563 L
.43154 .01563 L
.43282 .01563 L
.43397 .01563 L
.43461 .01563 L
.4353 .01563 L
.43656 .01563 L
.43774 .01563 L
.43898 .01563 L
.44004 .01563 L
.44121 .01563 L
.44254 .01563 L
.44379 .01563 L
.44615 .01563 L
.45144 .01563 L
.45601 .01563 L
.46098 .01563 L
.50179 .01563 L
.54107 .01562 L
.57884 .01562 L
.61907 .01562 L
.65777 .01562 L
.69893 .01562 L
.73858 .01562 L
.77671 .01562 L
.81729 .01562 L
.85635 .01562 L
.89787 .01562 L
.93787 .01562 L
.97619 .01562 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.02499 .03211 L
.02605 .04259 L
.02729 .04799 L
.02846 .04935 L
.02954 .04918 L
.03053 .04845 L
.03163 .04736 L
.03279 .04603 L
.03786 .03999 L
.04262 .03506 L
.05205 .02782 L
.05706 .02512 L
.06244 .02286 L
.06784 .02114 L
.07373 .01971 L
.07929 .01871 L
.08445 .018 L
.08956 .01746 L
.09419 .01707 L
.09954 .01673 L
.10458 .01648 L
.10923 .01631 L
.11434 .01615 L
.11968 .01603 L
.12466 .01594 L
.12932 .01588 L
.13357 .01584 L
.13848 .0158 L
.14313 .01577 L
.14772 .01574 L
.15278 .01573 L
.15533 .01572 L
.15807 .01571 L
.16066 .01571 L
.16304 .01571 L
.16411 .01571 L
.16526 .01571 L
.16625 .0157 L
.16733 .0157 L
.16859 .0157 L
.16978 .0157 L
.17094 .0157 L
.17201 .0157 L
.17455 .0157 L
.17579 .0157 L
.17695 .0157 L
.17799 .0157 L
.17911 .0157 L
.18034 .0157 L
Mistroke
.18146 .0157 L
.18387 .0157 L
.18613 .0157 L
.19115 .01569 L
.20022 .01568 L
.21027 .01567 L
.21575 .01567 L
.22086 .01566 L
.23046 .01566 L
.23554 .01565 L
.24098 .01565 L
.24595 .01565 L
.25066 .01565 L
.25488 .01565 L
.25947 .01565 L
.3003 .01564 L
.31007 .01564 L
.32059 .01564 L
.33052 .01564 L
.33962 .01564 L
.34843 .01564 L
.35341 .01564 L
.35805 .01564 L
.36742 .01564 L
.37266 .01564 L
.37742 .01564 L
.39664 .01564 L
.40748 .01564 L
.41746 .01564 L
.42653 .01564 L
.43626 .01564 L
.44184 .01564 L
.44693 .01564 L
.44939 .01564 L
.45206 .01564 L
.45439 .01564 L
.45691 .01564 L
.45943 .01564 L
.46054 .01564 L
.46175 .01564 L
.46282 .01564 L
.46396 .01564 L
.46517 .01564 L
.4663 .01564 L
.46699 .01564 L
.46763 .01564 L
.46834 .01564 L
.46909 .01564 L
.47034 .01564 L
.47106 .01564 L
Mistroke
.47172 .01564 L
.4741 .01564 L
.47666 .01564 L
.48229 .01564 L
.48763 .01564 L
.49766 .01564 L
.53587 .01564 L
.57654 .01564 L
.61569 .01564 L
.65729 .01564 L
.69738 .01564 L
.73595 .01564 L
.77697 .01564 L
.81648 .01564 L
.85447 .01564 L
.89491 .01564 L
.93384 .01564 L
.97522 .01564 L
.97619 .01564 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.02605 .04943 L
.02729 .06646 L
.02846 .08034 L
.02954 .09084 L
.03072 .09929 L
.0318 .10434 L
.03279 .10702 L
.03396 .10819 L
.03506 .10779 L
.03626 .10619 L
.03756 .10357 L
.04262 .08986 L
.0521 .06547 L
.05746 .05495 L
.06244 .04716 L
.0679 .04044 L
.07373 .03496 L
.07935 .03095 L
.08445 .02814 L
.08943 .02601 L
.09481 .02422 L
.0999 .02292 L
.10458 .02199 L
.10928 .02124 L
.11432 .02062 L
.11907 .02016 L
.1234 .01984 L
.12849 .01953 L
.13402 .01929 L
.13924 .01912 L
.14407 .019 L
.1487 .01893 L
.15131 .01889 L
.15369 .01887 L
.1558 .01886 L
.15699 .01885 L
.1581 .01885 L
.15927 .01885 L
.16034 .01884 L
.16157 .01884 L
.16273 .01885 L
.16392 .01885 L
.16523 .01885 L
.1666 .01886 L
.16788 .01887 L
.17262 .0189 L
.17527 .01892 L
.17778 .01894 L
.17917 .01894 L
Mistroke
.1799 .01895 L
.18068 .01895 L
.18141 .01895 L
.18206 .01895 L
.18333 .01895 L
.18454 .01895 L
.18567 .01895 L
.1869 .01894 L
.18822 .01894 L
.19092 .01892 L
.19338 .01891 L
.20262 .01882 L
.21345 .01871 L
.22345 .01863 L
.23273 .01857 L
.23741 .01855 L
.24258 .01854 L
.24774 .01853 L
.25064 .01852 L
.2533 .01852 L
.2582 .01851 L
.26335 .01851 L
.30151 .01848 L
.3228 .01847 L
.34212 .01846 L
.35179 .01845 L
.36225 .01845 L
.37213 .01845 L
.38122 .01845 L
.39094 .01845 L
.40002 .01845 L
.42068 .01844 L
.45955 .01844 L
.46971 .01844 L
.48077 .01844 L
.49032 .01844 L
.50088 .01844 L
.52063 .01844 L
.54163 .01844 L
.56095 .01844 L
.57183 .01844 L
.5818 .01844 L
.58653 .01844 L
.59159 .01844 L
.59596 .01844 L
.6007 .01844 L
.6036 .01844 L
.60627 .01844 L
.60878 .01844 L
.61154 .01844 L
Mistroke
.61401 .01844 L
.61632 .01844 L
.6176 .01844 L
.61877 .01844 L
.61941 .01844 L
.62011 .01844 L
.62139 .01844 L
.62204 .01844 L
.62273 .01844 L
.62395 .01844 L
.62527 .01844 L
.62602 .01844 L
.62671 .01844 L
.62798 .01844 L
.62913 .01844 L
.63172 .01844 L
.63403 .01844 L
.63653 .01844 L
.64108 .01844 L
.65198 .01844 L
.66206 .01844 L
.68074 .01844 L
.70135 .01844 L
.74157 .01844 L
.78028 .01844 L
.82144 .01844 L
.86108 .01844 L
.89921 .01844 L
.93979 .01844 L
.97619 .01844 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.02499 .03213 L
.02605 .04281 L
.02729 .04862 L
.02846 .05034 L
.02954 .0504 L
.03053 .04982 L
.03163 .04883 L
.03279 .04757 L
.04262 .0365 L
.05205 .02897 L
.05742 .02594 L
.06244 .02373 L
.06788 .02188 L
.07305 .02053 L
.07768 .01958 L
.08274 .01876 L
.08822 .01809 L
.09407 .01755 L
.09958 .01716 L
.10458 .01689 L
.10945 .01669 L
.1146 .01653 L
.119 .01642 L
.12383 .01632 L
.12902 .01624 L
.13459 .01618 L
.13985 .01614 L
.14465 .01611 L
.14945 .01608 L
.15188 .01608 L
.15456 .01607 L
.15684 .01606 L
.15803 .01606 L
.15929 .01606 L
.1604 .01606 L
.16161 .01606 L
.16271 .01606 L
.16373 .01606 L
.16503 .01606 L
.16576 .01606 L
.16644 .01606 L
.16768 .01606 L
.16899 .01606 L
.17127 .01606 L
.17377 .01606 L
.17644 .01606 L
.17721 .01606 L
.17794 .01606 L
.17859 .01606 L
Mistroke
.17931 .01606 L
.18061 .01606 L
.18134 .01606 L
.182 .01606 L
.18328 .01606 L
.18449 .01606 L
.18566 .01606 L
.18691 .01606 L
.18916 .01606 L
.19428 .01605 L
.20461 .01603 L
.21422 .01602 L
.22309 .016 L
.22804 .016 L
.23329 .01599 L
.23856 .01599 L
.2416 .01599 L
.24437 .01599 L
.24938 .01599 L
.252 .01598 L
.25477 .01598 L
.25942 .01598 L
.26451 .01598 L
.2858 .01598 L
.30512 .01598 L
.31478 .01598 L
.32524 .01597 L
.33505 .01597 L
.34422 .01597 L
.35371 .01597 L
.35874 .01597 L
.36413 .01597 L
.36978 .01597 L
.37514 .01597 L
.37992 .01597 L
.38519 .01597 L
.39483 .01597 L
.40507 .01597 L
.42349 .01597 L
.46366 .01597 L
.48211 .01597 L
.50231 .01597 L
.52233 .01597 L
.54342 .01597 L
.56301 .01597 L
.58395 .01597 L
.59418 .01597 L
.60527 .01597 L
.61575 .01597 L
.62541 .01597 L
Mistroke
.63008 .01597 L
.63509 .01597 L
.63983 .01597 L
.64192 .01597 L
.64415 .01597 L
.64553 .01597 L
.64678 .01597 L
.64805 .01597 L
.64921 .01597 L
.65058 .01597 L
.6513 .01597 L
.65206 .01597 L
.65333 .01597 L
.65406 .01597 L
.65473 .01597 L
.65604 .01597 L
.65727 .01597 L
.65838 .01597 L
.65959 .01597 L
.66229 .01597 L
.66479 .01597 L
.66942 .01597 L
.67442 .01597 L
.68346 .01597 L
.69422 .01597 L
.70407 .01597 L
.74372 .01597 L
.78184 .01597 L
.82242 .01597 L
.86149 .01597 L
.90301 .01597 L
.94301 .01597 L
.97619 .01597 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05244 L
.02846 .05537 L
.02954 .05595 L
.03053 .05554 L
.03163 .05455 L
.03279 .05316 L
.04262 .04017 L
.05205 .03123 L
.05742 .02764 L
.06244 .02503 L
.06788 .02285 L
.07305 .02125 L
.07768 .02014 L
.08274 .01918 L
.08822 .01839 L
.09407 .01775 L
.09958 .0173 L
.10458 .01699 L
.10945 .01676 L
.1146 .01656 L
.119 .01643 L
.12383 .01632 L
.12902 .01623 L
.13459 .01616 L
.13985 .01611 L
.14465 .01607 L
.14945 .01605 L
.15188 .01604 L
.15456 .01603 L
.15684 .01602 L
.15929 .01601 L
.16042 .01601 L
.16161 .01601 L
.1627 .01601 L
.16373 .01601 L
.16503 .01601 L
.16621 .01601 L
.16749 .01601 L
.16821 .01601 L
.16887 .01601 L
.16997 .01601 L
.17119 .01601 L
.17246 .01601 L
.17365 .01601 L
.17505 .01601 L
.17574 .01601 L
.17638 .01601 L
Mistroke
.17757 .01601 L
.17887 .01601 L
.17961 .01601 L
.1803 .01601 L
.1816 .01601 L
.18232 .01601 L
.18299 .01601 L
.18449 .01601 L
.18696 .016 L
.18921 .016 L
.19425 .01599 L
.20335 .01598 L
.2141 .01596 L
.21882 .01595 L
.22403 .01595 L
.2285 .01594 L
.23331 .01594 L
.23839 .01594 L
.24315 .01593 L
.24844 .01593 L
.2511 .01593 L
.254 .01593 L
.25915 .01593 L
.26393 .01593 L
.28443 .01593 L
.30303 .01592 L
.31237 .01592 L
.32225 .01592 L
.33308 .01592 L
.3383 .01592 L
.34306 .01592 L
.35252 .01592 L
.35773 .01592 L
.36267 .01592 L
.37145 .01592 L
.37641 .01592 L
.381 .01592 L
.39964 .01592 L
.42023 .01592 L
.42964 .01592 L
.43956 .01592 L
.44475 .01592 L
.45043 .01592 L
.45521 .01592 L
.4604 .01592 L
.46568 .01592 L
.4681 .01592 L
.47066 .01592 L
.47297 .01592 L
.47551 .01592 L
Mistroke
.47783 .01592 L
.47999 .01592 L
.48128 .01592 L
.48269 .01592 L
.48403 .01592 L
.48526 .01592 L
.48649 .01592 L
.4876 .01592 L
.48888 .01592 L
.49008 .01592 L
.4914 .01592 L
.49207 .01592 L
.4928 .01592 L
.4953 .01592 L
.49821 .01592 L
.50093 .01592 L
.5114 .01592 L
.5213 .01592 L
.53986 .01592 L
.57821 .01592 L
.61901 .01592 L
.6583 .01592 L
.69607 .01592 L
.73629 .01592 L
.775 .01592 L
.81616 .01592 L
.8558 .01592 L
.89393 .01592 L
.93451 .01592 L
.97358 .01592 L
.97619 .01592 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.02605 .04937 L
.02729 .06618 L
.02846 .07962 L
.02954 .0895 L
.03072 .09709 L
.0318 .10131 L
.03279 .10327 L
.03396 .10375 L
.03506 .10287 L
.03626 .10092 L
.03756 .09809 L
.04262 .08451 L
.0521 .06145 L
.05746 .05165 L
.06244 .04443 L
.0679 .03822 L
.07373 .03317 L
.07935 .02948 L
.08445 .02691 L
.08943 .02495 L
.09481 .02331 L
.0999 .02213 L
.10458 .02127 L
.10928 .02059 L
.11432 .02002 L
.11907 .01961 L
.1234 .01931 L
.12849 .01903 L
.13402 .01881 L
.13924 .01865 L
.14407 .01855 L
.1487 .01847 L
.15131 .01844 L
.15369 .01842 L
.1558 .01841 L
.15699 .0184 L
.1581 .0184 L
.15927 .01839 L
.16034 .01839 L
.16157 .01839 L
.16273 .01839 L
.16392 .01839 L
.16523 .0184 L
.16589 .0184 L
.1666 .0184 L
.16788 .01841 L
.17262 .01843 L
.17549 .01844 L
.17691 .01845 L
Mistroke
.17822 .01846 L
.1794 .01846 L
.18067 .01846 L
.18139 .01846 L
.18207 .01846 L
.18333 .01846 L
.1845 .01846 L
.18575 .01846 L
.18693 .01845 L
.188 .01845 L
.19063 .01844 L
.19312 .01842 L
.20345 .01834 L
.21224 .01826 L
.22194 .0182 L
.23162 .01815 L
.23692 .01813 L
.24189 .01812 L
.24652 .01811 L
.25076 .0181 L
.25542 .0181 L
.26032 .0181 L
.29848 .01807 L
.30944 .01806 L
.31977 .01806 L
.32983 .01805 L
.33909 .01805 L
.34822 .01805 L
.35787 .01804 L
.36287 .01804 L
.36755 .01804 L
.37264 .01804 L
.37819 .01804 L
.38862 .01804 L
.39852 .01804 L
.41707 .01804 L
.43643 .01804 L
.45782 .01804 L
.46755 .01804 L
.47804 .01804 L
.49705 .01804 L
.50661 .01804 L
.51707 .01804 L
.52811 .01804 L
.53816 .01804 L
.54755 .01804 L
.55774 .01804 L
.56851 .01804 L
.57377 .01804 L
.57869 .01804 L
Mistroke
.58362 .01804 L
.58814 .01804 L
.59315 .01804 L
.59591 .01804 L
.59854 .01804 L
.60106 .01804 L
.60248 .01804 L
.60376 .01804 L
.60495 .01804 L
.60625 .01804 L
.60747 .01804 L
.6086 .01804 L
.60991 .01804 L
.61114 .01804 L
.61185 .01804 L
.61249 .01804 L
.61394 .01804 L
.61683 .01804 L
.61957 .01804 L
.62417 .01804 L
.62924 .01804 L
.6395 .01804 L
.65792 .01804 L
.67728 .01804 L
.69815 .01804 L
.73931 .01804 L
.77895 .01804 L
.81708 .01804 L
.85766 .01804 L
.89672 .01804 L
.93824 .01804 L
.97619 .01804 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .02121 L
.03053 .02077 L
.03279 .02026 L
.04262 .01834 L
.04762 .01763 L
.05293 .01703 L
.05746 .01663 L
.06244 .01628 L
.06792 .01599 L
.07293 .01578 L
.07871 .0156 L
.0842 .01547 L
.08925 .01538 L
.09394 .01531 L
.09909 .01525 L
.10458 .01521 L
.10994 .01517 L
.11487 .01515 L
.12028 .01513 L
.12599 .01511 L
.13096 .0151 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01509 L
.14867 .01508 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.16531 .01508 L
.16596 .01508 L
.1667 .01508 L
.1674 .01508 L
.16856 .01508 L
.16984 .01508 L
.17049 .01508 L
.17118 .01508 L
.17243 .01508 L
.17367 .01508 L
.17485 .01508 L
.1759 .01508 L
Mistroke
.17706 .01508 L
.17777 .01508 L
.17844 .01508 L
.17969 .01508 L
.18039 .01508 L
.18103 .01508 L
.18249 .01508 L
.18494 .01508 L
.18752 .01508 L
.20742 .01507 L
.21611 .01507 L
.22555 .01507 L
.23077 .01507 L
.23559 .01507 L
.2402 .01507 L
.2451 .01507 L
.24757 .01507 L
.25023 .01507 L
.25254 .01507 L
.25505 .01507 L
.25784 .01507 L
.26078 .01507 L
.26602 .01507 L
.27133 .01507 L
.27632 .01507 L
.28567 .01507 L
.29586 .01507 L
.30664 .01507 L
.31619 .01507 L
.32162 .01507 L
.32669 .01507 L
.33135 .01507 L
.3356 .01507 L
.33795 .01507 L
.3405 .01507 L
.34293 .01507 L
.34516 .01507 L
.34748 .01507 L
.3487 .01507 L
.34999 .01507 L
.35112 .01507 L
.35216 .01507 L
.35331 .01507 L
.35454 .01507 L
.35524 .01507 L
.35588 .01507 L
.35658 .01507 L
.35733 .01507 L
.35859 .01507 L
.3593 .01507 L
Mistroke
.35997 .01507 L
.36235 .01507 L
.36491 .01507 L
.37053 .01507 L
.37587 .01507 L
.3859 .01507 L
.40595 .01507 L
.41468 .01507 L
.42412 .01507 L
.4294 .01507 L
.43426 .01507 L
.4389 .01507 L
.44124 .01507 L
.44381 .01507 L
.44521 .01507 L
.44655 .01507 L
.44774 .01507 L
.44904 .01507 L
.44972 .01507 L
.45046 .01507 L
.45123 .01507 L
.45196 .01507 L
.45326 .01507 L
.45399 .01507 L
.45466 .01507 L
.45588 .01507 L
.45701 .01507 L
.45959 .01507 L
.4621 .01507 L
.46478 .01507 L
.47504 .01507 L
.48614 .01507 L
.5063 .01507 L
.54724 .01507 L
.58666 .01507 L
.62457 .01507 L
.66493 .01507 L
.70377 .01507 L
.74507 .01507 L
.78485 .01507 L
.82312 .01507 L
.86383 .01507 L
.90304 .01507 L
.94469 .01507 L
.97619 .01507 L
Mfstroke
1 0 .19 r
.02381 .01472 m
.02499 .02109 L
.02605 .02178 L
.02729 .0219 L
.02846 .02181 L
.02954 .02165 L
.03053 .02148 L
.03279 .02102 L
.04262 .0191 L
.05224 .01776 L
.0571 .01727 L
.06244 .01683 L
.06792 .01649 L
.07293 .01625 L
.07871 .01603 L
.0842 .01587 L
.08925 .01576 L
.09394 .01567 L
.09909 .0156 L
.10458 .01554 L
.10994 .0155 L
.11487 .01547 L
.12028 .01544 L
.12599 .01542 L
.13096 .01541 L
.13561 .0154 L
.1407 .01539 L
.14356 .01539 L
.14616 .01539 L
.14864 .01539 L
.15097 .01538 L
.1534 .01538 L
.15469 .01538 L
.15541 .01538 L
.15608 .01538 L
.15719 .01538 L
.15841 .01538 L
.15959 .01538 L
.16086 .01538 L
.16204 .01538 L
.16316 .01538 L
.16525 .01538 L
.17046 .01539 L
.17533 .01539 L
.17778 .01539 L
.17916 .01539 L
.18041 .01539 L
.18113 .01539 L
.18179 .01539 L
.18251 .01539 L
Mistroke
.18328 .01539 L
.18402 .01539 L
.18471 .01539 L
.18601 .01539 L
.18717 .01539 L
.18845 .01539 L
.19102 .01539 L
.19563 .01539 L
.20602 .01538 L
.2155 .01537 L
.22447 .01537 L
.22938 .01537 L
.23471 .01537 L
.23955 .01537 L
.24402 .01536 L
.24885 .01536 L
.2516 .01536 L
.25418 .01536 L
.25936 .01536 L
.26495 .01536 L
.28464 .01536 L
.30614 .01536 L
.32694 .01536 L
.34582 .01536 L
.35067 .01536 L
.35593 .01536 L
.36048 .01536 L
.36547 .01536 L
.37077 .01536 L
.37348 .01536 L
.37638 .01536 L
.3791 .01536 L
.38158 .01536 L
.38388 .01536 L
.38643 .01536 L
.3889 .01536 L
.39123 .01536 L
.39368 .01536 L
.39633 .01536 L
.4007 .01536 L
.40549 .01536 L
.40822 .01536 L
.41076 .01536 L
.41367 .01536 L
.41631 .01536 L
.42111 .01536 L
.42624 .01536 L
.43621 .01536 L
.44541 .01536 L
.46619 .01536 L
Mistroke
.48653 .01536 L
.50557 .01536 L
.54342 .01536 L
.58221 .01536 L
.60336 .01536 L
.62346 .01536 L
.64328 .01536 L
.66167 .01536 L
.67225 .01536 L
.68221 .01536 L
.69115 .01536 L
.70082 .01536 L
.71033 .01536 L
.71573 .01536 L
.72077 .01536 L
.72351 .01536 L
.72609 .01536 L
.72842 .01536 L
.73094 .01536 L
.73225 .01536 L
.73369 .01536 L
.73441 .01536 L
.73519 .01536 L
.73593 .01536 L
.73661 .01536 L
.73782 .01536 L
.73852 .01536 L
.73916 .01536 L
.74046 .01536 L
.74118 .01536 L
.74184 .01536 L
.74415 .01536 L
.7467 .01536 L
.75183 .01536 L
.75659 .01536 L
.76104 .01536 L
.77107 .01536 L
.78184 .01536 L
.82314 .01536 L
.86292 .01536 L
.90119 .01536 L
.9419 .01536 L
.97619 .01536 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02006 L
.0379 .01898 L
.04262 .01816 L
.04714 .01752 L
.05212 .01696 L
.05713 .01652 L
.06244 .01616 L
.06792 .01587 L
.07293 .01568 L
.07871 .0155 L
.0842 .01538 L
.08925 .01529 L
.09394 .01522 L
.09909 .01517 L
.10458 .01513 L
.10994 .01509 L
.11487 .01507 L
.12028 .01505 L
.12599 .01504 L
.13096 .01503 L
.13561 .01502 L
.1407 .01501 L
.14616 .01501 L
.14872 .01501 L
.15145 .01501 L
.15634 .015 L
.15905 .015 L
.1616 .015 L
.16439 .015 L
.16596 .015 L
.1674 .015 L
.17244 .015 L
.17521 .015 L
.17783 .015 L
.18291 .015 L
.18752 .015 L
.20645 .015 L
.2165 .01499 L
.222 .01499 L
.22715 .01499 L
.23213 .01499 L
.23668 .01499 L
.24173 .01499 L
.24452 .01499 L
.24716 .01499 L
Mistroke
.24938 .01499 L
.25174 .01499 L
.25599 .01499 L
.25859 .01499 L
.26104 .01499 L
.26561 .01499 L
.27028 .01499 L
.2754 .01499 L
.28075 .01499 L
.28573 .01499 L
.30422 .01499 L
.30924 .01499 L
.3147 .01499 L
.31951 .01499 L
.32461 .01499 L
.3292 .01499 L
.33426 .01499 L
.33886 .01499 L
.34318 .01499 L
.34789 .01499 L
.35303 .01499 L
.35563 .01499 L
.35841 .01499 L
.36102 .01499 L
.3634 .01499 L
.36578 .01499 L
.36798 .01499 L
.36912 .01499 L
.37038 .01499 L
.3717 .01499 L
.37293 .01499 L
.37409 .01499 L
.3752 .01499 L
.37619 .01499 L
.37727 .01499 L
.37844 .01499 L
.37968 .01499 L
.38192 .01499 L
.38679 .01499 L
.39127 .01499 L
.40136 .01499 L
.41019 .01499 L
.41964 .01499 L
.42476 .01499 L
.42942 .01499 L
.43167 .01499 L
.43285 .01499 L
.43411 .01499 L
.4352 .01499 L
.43641 .01499 L
Mistroke
.43751 .01499 L
.43854 .01499 L
.43981 .01499 L
.44054 .01499 L
.44121 .01499 L
.44243 .01499 L
.44374 .01499 L
.44503 .01499 L
.44624 .01499 L
.44851 .01499 L
.45119 .01499 L
.45366 .01499 L
.45923 .01499 L
.46897 .01499 L
.47807 .01499 L
.49873 .01499 L
.53766 .01499 L
.57904 .01499 L
.61891 .01499 L
.65726 .01499 L
.69806 .01499 L
.73735 .01499 L
.77512 .01499 L
.81534 .01499 L
.85405 .01499 L
.89521 .01499 L
.93485 .01499 L
.97298 .01499 L
.97619 .01499 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.02499 .0325 L
.02605 .0446 L
.02729 .05246 L
.02846 .05542 L
.02954 .05603 L
.03053 .05564 L
.03163 .05466 L
.03279 .05329 L
.04262 .04032 L
.05205 .03136 L
.05742 .02776 L
.06244 .02514 L
.06788 .02295 L
.07305 .02135 L
.07768 .02022 L
.08274 .01926 L
.08822 .01846 L
.09407 .01782 L
.09958 .01737 L
.10458 .01706 L
.10945 .01682 L
.1146 .01663 L
.119 .0165 L
.12383 .01638 L
.12902 .01629 L
.13459 .01622 L
.13985 .01617 L
.14465 .01613 L
.14945 .0161 L
.15188 .01609 L
.15456 .01609 L
.15684 .01608 L
.15929 .01607 L
.16042 .01607 L
.16161 .01607 L
.1627 .01607 L
.16373 .01607 L
.16503 .01607 L
.16621 .01607 L
.16749 .01607 L
.16821 .01607 L
.16887 .01607 L
.16997 .01607 L
.17119 .01607 L
.17365 .01607 L
.17503 .01607 L
.17635 .01607 L
.17707 .01607 L
.17786 .01607 L
Mistroke
.17858 .01607 L
.17925 .01607 L
.17994 .01607 L
.18058 .01607 L
.18179 .01607 L
.18309 .01607 L
.18449 .01607 L
.18687 .01607 L
.18942 .01606 L
.19402 .01606 L
.20447 .01604 L
.21542 .01602 L
.22555 .016 L
.2305 .016 L
.23575 .01599 L
.24102 .01599 L
.24405 .01599 L
.24683 .01599 L
.25183 .01599 L
.25446 .01599 L
.25722 .01599 L
.26696 .01599 L
.28674 .01598 L
.30512 .01598 L
.31567 .01598 L
.32562 .01598 L
.33455 .01598 L
.33958 .01597 L
.34422 .01597 L
.34891 .01597 L
.35394 .01597 L
.35829 .01597 L
.36302 .01597 L
.36856 .01597 L
.37382 .01597 L
.38367 .01597 L
.39306 .01597 L
.40342 .01597 L
.42442 .01597 L
.43383 .01597 L
.44375 .01597 L
.44894 .01597 L
.45462 .01597 L
.46459 .01597 L
.46987 .01597 L
.47485 .01597 L
.47933 .01597 L
.48418 .01597 L
.4867 .01597 L
.48947 .01597 L
Mistroke
.49236 .01597 L
.49375 .01597 L
.49507 .01597 L
.49628 .01597 L
.4976 .01597 L
.4988 .01597 L
.49992 .01597 L
.50124 .01597 L
.50244 .01597 L
.5031 .01597 L
.50382 .01597 L
.50512 .01597 L
.50637 .01597 L
.5075 .01597 L
.51004 .01597 L
.5124 .01597 L
.51464 .01597 L
.51964 .01597 L
.52508 .01597 L
.53602 .01597 L
.54615 .01597 L
.56482 .01597 L
.58543 .01597 L
.62566 .01597 L
.66436 .01597 L
.70552 .01597 L
.74517 .01597 L
.7833 .01597 L
.82388 .01597 L
.86294 .01597 L
.90446 .01597 L
.94446 .01597 L
.97619 .01597 L
Mfstroke
1 0 .119 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02079 L
.03279 .02029 L
.04262 .01838 L
.04762 .01766 L
.05293 .01707 L
.05746 .01667 L
.06244 .01632 L
.06792 .01602 L
.07293 .01581 L
.07871 .01563 L
.0842 .01549 L
.08925 .0154 L
.09394 .01533 L
.09909 .01528 L
.10458 .01523 L
.10994 .01519 L
.11487 .01517 L
.12028 .01515 L
.12599 .01513 L
.13096 .01512 L
.13561 .01511 L
.1407 .01511 L
.14335 .01511 L
.14616 .0151 L
.14867 .0151 L
.15145 .0151 L
.154 .0151 L
.15634 .0151 L
.15908 .0151 L
.16052 .0151 L
.16204 .0151 L
.16268 .0151 L
.16337 .0151 L
.1646 .0151 L
.16536 .0151 L
.16607 .0151 L
.16671 .0151 L
.1674 .0151 L
.16865 .0151 L
.16982 .0151 L
.17111 .0151 L
.17249 .0151 L
.17393 .0151 L
.17464 .0151 L
.1753 .0151 L
Mistroke
.17653 .0151 L
.17718 .0151 L
.17787 .0151 L
.17913 .0151 L
.17983 .0151 L
.18048 .0151 L
.18168 .0151 L
.18294 .0151 L
.18512 .0151 L
.18752 .0151 L
.20871 .01509 L
.21874 .01509 L
.228 .01509 L
.23266 .01509 L
.2376 .01509 L
.24255 .01509 L
.24537 .01508 L
.24802 .01508 L
.25034 .01508 L
.25278 .01508 L
.25714 .01508 L
.26183 .01508 L
.26696 .01508 L
.27226 .01508 L
.27726 .01508 L
.28661 .01508 L
.2968 .01508 L
.30757 .01508 L
.31713 .01508 L
.32219 .01508 L
.32763 .01508 L
.33262 .01508 L
.33717 .01508 L
.34609 .01508 L
.35089 .01508 L
.35599 .01508 L
.36034 .01508 L
.36515 .01508 L
.36784 .01508 L
.3703 .01508 L
.373 .01508 L
.37438 .01508 L
.37585 .01508 L
.37715 .01508 L
.37834 .01508 L
.37953 .01508 L
.38065 .01508 L
.38196 .01508 L
.38317 .01508 L
.3838 .01508 L
Mistroke
.3845 .01508 L
.38522 .01508 L
.3859 .01508 L
.38715 .01508 L
.38848 .01508 L
.39087 .01508 L
.3963 .01508 L
.40617 .01508 L
.41117 .01508 L
.41363 .01508 L
.41589 .01508 L
.41795 .01508 L
.41898 .01508 L
.42012 .01508 L
.42126 .01508 L
.42249 .01508 L
.42364 .01508 L
.4247 .01508 L
.42588 .01508 L
.42699 .01508 L
.4282 .01508 L
.42951 .01508 L
.43218 .01508 L
.43462 .01508 L
.43909 .01508 L
.4438 .01508 L
.45372 .01508 L
.46456 .01508 L
.50514 .01508 L
.54421 .01508 L
.58573 .01508 L
.60654 .01508 L
.62573 .01508 L
.66421 .01508 L
.68299 .01508 L
.70364 .01508 L
.7231 .01508 L
.744 .01508 L
.75414 .01508 L
.76519 .01508 L
.77574 .01508 L
.78529 .01508 L
.79478 .01508 L
.80502 .01508 L
.81584 .01508 L
.8211 .01508 L
.82601 .01508 L
.83101 .01508 L
.83555 .01508 L
.8406 .01508 L
Mistroke
.84338 .01508 L
.846 .01508 L
.84855 .01508 L
.84984 .01508 L
.85126 .01508 L
.85246 .01508 L
.85376 .01508 L
.85499 .01508 L
.85611 .01508 L
.85679 .01508 L
.85751 .01508 L
.8588 .01508 L
.85959 .01508 L
.86034 .01508 L
.86174 .01508 L
.86431 .01508 L
.86709 .01508 L
.872 .01508 L
.87659 .01508 L
.88702 .01508 L
.89718 .01508 L
.90808 .01508 L
.94943 .01508 L
.97619 .01508 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.02499 .02082 L
.02605 .02128 L
.02729 .02123 L
.02846 .02103 L
.03279 .02006 L
.0379 .01898 L
.04262 .01816 L
.04714 .01752 L
.05212 .01696 L
.05713 .01652 L
.06244 .01615 L
.06792 .01587 L
.07293 .01567 L
.07871 .01549 L
.0842 .01537 L
.08925 .01528 L
.09394 .01522 L
.09909 .01516 L
.10458 .01512 L
.10994 .01508 L
.11487 .01506 L
.12028 .01504 L
.12599 .01503 L
.13096 .01502 L
.13561 .01501 L
.1407 .015 L
.14616 .015 L
.15145 .01499 L
.15634 .01499 L
.15889 .01499 L
.1617 .01499 L
.16464 .01499 L
.1674 .01499 L
.16986 .01499 L
.17245 .01499 L
.17708 .01499 L
.18207 .01499 L
.18489 .01499 L
.18752 .01499 L
.20626 .01498 L
.21612 .01498 L
.22657 .01498 L
.23186 .01498 L
.23767 .01498 L
.24022 .01498 L
.24296 .01498 L
.24791 .01498 L
.2505 .01498 L
.25332 .01498 L
Mistroke
.25844 .01498 L
.26807 .01498 L
.2734 .01498 L
.27841 .01498 L
.28778 .01498 L
.29799 .01498 L
.30876 .01498 L
.31836 .01498 L
.32381 .01498 L
.32888 .01498 L
.33347 .01498 L
.33781 .01498 L
.34281 .01498 L
.34737 .01498 L
.35197 .01498 L
.35459 .01498 L
.35705 .01498 L
.35946 .01498 L
.36199 .01498 L
.36477 .01498 L
.36732 .01498 L
.36952 .01498 L
.37188 .01498 L
.37411 .01498 L
.37612 .01498 L
.3785 .01498 L
.38108 .01498 L
.38575 .01498 L
.39033 .01498 L
.39524 .01498 L
.40063 .01498 L
.40566 .01498 L
.41096 .01498 L
.4166 .01498 L
.42141 .01498 L
.42415 .01498 L
.4254 .01498 L
.42672 .01498 L
.42794 .01498 L
.42858 .01498 L
.42927 .01498 L
.43048 .01498 L
.43161 .01498 L
.43229 .01498 L
.43302 .01498 L
.43372 .01498 L
.43437 .01498 L
.43558 .01498 L
.43688 .01498 L
.43819 .01498 L
Mistroke
.43959 .01498 L
.44214 .01498 L
.44517 .01498 L
.44793 .01498 L
.45825 .01498 L
.46805 .01498 L
.50626 .01498 L
.54693 .01498 L
.58608 .01498 L
.62768 .01498 L
.66776 .01498 L
.70634 .01498 L
.74736 .01498 L
.78687 .01498 L
.82486 .01498 L
.8653 .01498 L
.90423 .01498 L
.94561 .01498 L
.97619 .01498 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .0212 L
.03053 .02077 L
.03279 .02026 L
.04262 .01833 L
.04762 .01762 L
.05293 .01702 L
.05746 .01662 L
.06244 .01627 L
.06792 .01597 L
.07293 .01576 L
.07871 .01558 L
.0842 .01545 L
.08925 .01536 L
.09394 .01529 L
.09909 .01523 L
.10458 .01518 L
.10994 .01515 L
.11487 .01512 L
.12028 .0151 L
.12599 .01509 L
.13096 .01508 L
.13561 .01507 L
.1407 .01506 L
.14616 .01506 L
.14872 .01506 L
.15145 .01505 L
.15634 .01505 L
.15905 .01505 L
.1616 .01505 L
.16305 .01505 L
.16439 .01505 L
.16586 .01505 L
.1674 .01505 L
.16857 .01505 L
.1698 .01505 L
.17116 .01505 L
.17241 .01505 L
.17485 .01505 L
.17604 .01505 L
.17713 .01505 L
.17838 .01505 L
.17972 .01505 L
.18119 .01505 L
.18258 .01505 L
.18494 .01505 L
.18752 .01505 L
Mistroke
.19777 .01505 L
.20726 .01504 L
.21609 .01504 L
.22563 .01504 L
.23115 .01504 L
.23623 .01504 L
.24108 .01504 L
.24355 .01504 L
.24619 .01504 L
.2486 .01504 L
.25079 .01504 L
.25508 .01504 L
.26008 .01504 L
.26481 .01504 L
.27449 .01504 L
.27938 .01504 L
.28476 .01504 L
.3032 .01504 L
.31331 .01504 L
.32258 .01504 L
.32744 .01504 L
.33275 .01504 L
.3383 .01504 L
.34345 .01504 L
.34852 .01504 L
.35118 .01504 L
.354 .01504 L
.35647 .01504 L
.35918 .01504 L
.36167 .01504 L
.36395 .01504 L
.36859 .01504 L
.37114 .01504 L
.37356 .01504 L
.38255 .01504 L
.40074 .01504 L
.41111 .01504 L
.41619 .01504 L
.42085 .01504 L
.42538 .01504 L
.43035 .01504 L
.43293 .01504 L
.43417 .01504 L
.43534 .01504 L
.43598 .01504 L
.43667 .01504 L
.43788 .01504 L
.43856 .01504 L
.43929 .01504 L
.4406 .01504 L
Mistroke
.44189 .01504 L
.44308 .01504 L
.44374 .01504 L
.44445 .01504 L
.44576 .01504 L
.44826 .01504 L
.45059 .01504 L
.45592 .01504 L
.4616 .01504 L
.48302 .01504 L
.5032 .01504 L
.54177 .01504 L
.58279 .01504 L
.6223 .01504 L
.66029 .01504 L
.70073 .01504 L
.73966 .01504 L
.78104 .01504 L
.82091 .01504 L
.85926 .01504 L
.90006 .01504 L
.93935 .01504 L
.97619 .01504 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.02499 .02082 L
.02605 .02129 L
.02729 .02124 L
.02846 .02105 L
.03279 .02009 L
.0379 .01902 L
.04262 .0182 L
.04714 .01757 L
.05212 .01701 L
.05713 .01658 L
.06244 .01621 L
.06792 .01593 L
.07293 .01573 L
.07871 .01555 L
.0842 .01543 L
.08925 .01534 L
.09394 .01528 L
.09909 .01522 L
.10458 .01518 L
.10994 .01514 L
.11487 .01512 L
.12028 .0151 L
.12599 .01508 L
.13096 .01507 L
.13561 .01507 L
.1407 .01506 L
.14335 .01506 L
.14616 .01506 L
.14867 .01505 L
.15145 .01505 L
.154 .01505 L
.15634 .01505 L
.15908 .01505 L
.16052 .01505 L
.16204 .01505 L
.16337 .01505 L
.1646 .01505 L
.16596 .01505 L
.16671 .01505 L
.1674 .01505 L
.16867 .01505 L
.16938 .01505 L
.17003 .01505 L
.17129 .01505 L
.17249 .01505 L
.17382 .01505 L
.17505 .01505 L
.1757 .01505 L
.1764 .01505 L
Mistroke
.17717 .01505 L
.17787 .01505 L
.17912 .01505 L
.18026 .01505 L
.18152 .01505 L
.18284 .01505 L
.18508 .01505 L
.18752 .01505 L
.19232 .01505 L
.19745 .01505 L
.20671 .01504 L
.21752 .01504 L
.22751 .01504 L
.23245 .01504 L
.2377 .01504 L
.24298 .01504 L
.24597 .01504 L
.24879 .01504 L
.25125 .01504 L
.25385 .01504 L
.25848 .01504 L
.26892 .01504 L
.27849 .01504 L
.2887 .01504 L
.30708 .01504 L
.31735 .01504 L
.32275 .01504 L
.32847 .01504 L
.33347 .01504 L
.33896 .01504 L
.34359 .01504 L
.34863 .01504 L
.35386 .01504 L
.35882 .01504 L
.36364 .01504 L
.36811 .01504 L
.37293 .01504 L
.37825 .01504 L
.3838 .01504 L
.38902 .01504 L
.42768 .01504 L
.4473 .01504 L
.46878 .01504 L
.48929 .01504 L
.50838 .01504 L
.52709 .01504 L
.54739 .01504 L
.55848 .01504 L
.56871 .01504 L
.57849 .01504 L
Mistroke
.5839 .01504 L
.58885 .01504 L
.59336 .01504 L
.59827 .01504 L
.60097 .01504 L
.60347 .01504 L
.60601 .01504 L
.6084 .01504 L
.61064 .01504 L
.61181 .01504 L
.61305 .01504 L
.6141 .01504 L
.61525 .01504 L
.61629 .01504 L
.61727 .01504 L
.61849 .01504 L
.61965 .01504 L
.62069 .01504 L
.62182 .01504 L
.62306 .01504 L
.62436 .01504 L
.62671 .01504 L
.62909 .01504 L
.6316 .01504 L
.63609 .01504 L
.6462 .01504 L
.65493 .01504 L
.66448 .01504 L
.6841 .01504 L
.70506 .01504 L
.74658 .01504 L
.78658 .01504 L
.82507 .01504 L
.86601 .01504 L
.90543 .01504 L
.94334 .01504 L
.97619 .01504 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02139 L
.02846 .02122 L
.03053 .02078 L
.03279 .02028 L
.04262 .01836 L
.04762 .01765 L
.05293 .01705 L
.05746 .01665 L
.06244 .0163 L
.06792 .01601 L
.07293 .0158 L
.07871 .01561 L
.0842 .01548 L
.08925 .01538 L
.09394 .01532 L
.09909 .01526 L
.10458 .01521 L
.10994 .01518 L
.11487 .01515 L
.12028 .01513 L
.12599 .01511 L
.13096 .0151 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01508 L
.14867 .01508 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.16596 .01508 L
.16671 .01508 L
.1674 .01508 L
.16867 .01508 L
.16938 .01508 L
.17003 .01508 L
.17129 .01508 L
.17249 .01508 L
.17382 .01508 L
.17505 .01508 L
.1757 .01508 L
.1764 .01508 L
Mistroke
.17717 .01508 L
.17787 .01508 L
.17912 .01508 L
.18026 .01508 L
.18152 .01508 L
.18284 .01508 L
.18508 .01508 L
.18752 .01508 L
.19232 .01507 L
.19745 .01507 L
.20671 .01507 L
.21752 .01507 L
.22751 .01507 L
.23245 .01507 L
.2377 .01507 L
.24298 .01507 L
.24597 .01507 L
.24879 .01507 L
.25125 .01507 L
.25385 .01507 L
.25848 .01507 L
.26395 .01507 L
.26892 .01506 L
.27384 .01506 L
.27849 .01506 L
.2887 .01506 L
.30708 .01506 L
.31683 .01506 L
.32215 .01506 L
.32713 .01506 L
.33593 .01506 L
.34059 .01506 L
.3456 .01506 L
.35087 .01506 L
.35575 .01506 L
.36111 .01506 L
.36382 .01506 L
.36681 .01506 L
.3718 .01506 L
.37718 .01506 L
.38693 .01506 L
.40655 .01506 L
.41693 .01506 L
.42264 .01506 L
.42803 .01506 L
.43318 .01506 L
.43609 .01506 L
.43747 .01506 L
.43877 .01506 L
.43995 .01506 L
Mistroke
.44103 .01506 L
.44223 .01506 L
.44351 .01506 L
.44474 .01506 L
.44544 .01506 L
.44609 .01506 L
.44727 .01506 L
.44854 .01506 L
.44983 .01506 L
.45101 .01506 L
.45369 .01506 L
.45855 .01506 L
.46296 .01506 L
.46763 .01506 L
.50562 .01506 L
.54606 .01506 L
.58499 .01506 L
.62637 .01506 L
.66624 .01506 L
.70459 .01506 L
.74539 .01506 L
.78467 .01506 L
.82244 .01506 L
.86267 .01506 L
.90138 .01506 L
.94254 .01506 L
.97619 .01506 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .02088 L
.02605 .0214 L
.02729 .02138 L
.02846 .02121 L
.03053 .02077 L
.03279 .02026 L
.04262 .01835 L
.04762 .01763 L
.05293 .01704 L
.05746 .01664 L
.06244 .01629 L
.06792 .016 L
.07293 .01579 L
.07871 .01561 L
.0842 .01548 L
.08925 .01538 L
.09394 .01532 L
.09909 .01526 L
.10458 .01521 L
.10994 .01518 L
.11487 .01515 L
.12028 .01513 L
.12599 .01511 L
.13096 .0151 L
.13561 .0151 L
.1407 .01509 L
.14335 .01509 L
.14616 .01508 L
.14867 .01508 L
.15145 .01508 L
.154 .01508 L
.15634 .01508 L
.15908 .01508 L
.16052 .01508 L
.16204 .01508 L
.16337 .01508 L
.1646 .01508 L
.16531 .01508 L
.16596 .01508 L
.1667 .01508 L
.1674 .01508 L
.16865 .01508 L
.16984 .01508 L
.17049 .01508 L
.1712 .01508 L
.17245 .01508 L
.17363 .01508 L
.17474 .01508 L
.17602 .01508 L
Mistroke
.17718 .01508 L
.1784 .01508 L
.1791 .01508 L
.17973 .01508 L
.18089 .01508 L
.1821 .01508 L
.18344 .01508 L
.18469 .01508 L
.18752 .01508 L
.19258 .01508 L
.19719 .01507 L
.20754 .01507 L
.21649 .01507 L
.22599 .01507 L
.23072 .01507 L
.23593 .01507 L
.24067 .01507 L
.24511 .01507 L
.24766 .01507 L
.25033 .01507 L
.25512 .01507 L
.25778 .01507 L
.26026 .01507 L
.26589 .01507 L
.27095 .01507 L
.27644 .01507 L
.28638 .01507 L
.30498 .01507 L
.31447 .01507 L
.3249 .01506 L
.33015 .01506 L
.33578 .01506 L
.3411 .01506 L
.34596 .01506 L
.35075 .01506 L
.35585 .01506 L
.36021 .01506 L
.36502 .01506 L
.37016 .01506 L
.37572 .01506 L
.38577 .01506 L
.40578 .01506 L
.41598 .01506 L
.42688 .01506 L
.43219 .01506 L
.4372 .01506 L
.44209 .01506 L
.44659 .01506 L
.45087 .01506 L
.45302 .01506 L
Mistroke
.4554 .01506 L
.45778 .01506 L
.45911 .01506 L
.46033 .01506 L
.46147 .01506 L
.4627 .01506 L
.46387 .01506 L
.46495 .01506 L
.46624 .01506 L
.46689 .01506 L
.4676 .01506 L
.46886 .01506 L
.47003 .01506 L
.47269 .01506 L
.47553 .01506 L
.48549 .01506 L
.5041 .01506 L
.54548 .01506 L
.58535 .01506 L
.6237 .01506 L
.6645 .01506 L
.70379 .01506 L
.74156 .01506 L
.78178 .01506 L
.82049 .01506 L
.86165 .01506 L
.90129 .01506 L
.93942 .01506 L
.97619 .01506 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 370.812},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001LR000`400?l00000o`00003ooooooooo
oooooe[ooooo0021ooooo`?o00001?ooool2o`0000Cooooo0_l0001Pooooo`Go00000oooool2o`00
00Cooooo0_l0001Pooooo`?o00001?ooool2o`0000Cooooo0_l0001Rooooo`?o00000oooool2o`00
00Cooooo0_l0001Qooooo`?o00001?ooool2o`0000Cooooo0_l00009ooooo`00P_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000H?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000G_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0001Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool008;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00067ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
06;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo05gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000Hoooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool008;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0006;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0G_ooool2o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001Oooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0001Sooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`00P_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Gooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0001Rooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0001Oooooo`Co00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Sooooo0021ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0005oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000G_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Qooooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005oooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo000J
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0001Q
ooooo`?o00001?ooool2o`0000Cooooo0_l0001Pooooo`?o00001?ooool2o`0000Cooooo0_l0001S
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000H?ooool5o`0000?ooooo0_l00004
ooooo`;o00002Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03
o`000?oooooooooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo
?Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooo
oooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo?Oooool001[o
oooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooo
oooooolmooooo`003?ooool>o`000003ool00?l0003o000001So00000oooH@04ool06?ooo`00oooo
000?ool000ko00000Oooool001[ooooo00?oo`00ooooooooool03?ooool00ooo00coo`00ool0000@
ool000coo`0`oooo02Coool090?oo`0T3oooool001[ooooo00?oo`00ooooooooool01?ooool00ol0
LOooo`00ool00006ool000Goo`0`00?oooooo`000?ooool00oooool4o`30o`;oo`1D0ooo04P:ool0
90?oo`1W0ooo08D3ool0Z@Soo`1ioooo03caool0?0oooooo000Jooooo`05ool00?oooooooooooooo
oooo00`00ooo0002ool030Coo`0`2_ooool3o`30o`03ool0E?oo04Soo`1800Koo`0T0ooo08D4ool0
Z@Koo`1i3_oo03`9ool0C_ooo`1]j?oo06d?ooooo`006_ooool5ool000?oo`0`3Oooool3ojD0o`Co
o`180_oo02@3ool0Q@?oo`2Y00?o0?m6ool0NOoo07T01?oo07T6ool0?0?oo`1>2ooo06dNom`0o`Ko
Q`3o6_oL0?m>ool0/:;og03o`_oo0;0?ooooo`006_ooool00ooo02Coooooooooo`0?ooooo`;o0<3o
00CoY@3oool0B?oo04Soo`181?oo02@2ool0Z@?o0?ma00Co0?m6ool0NOoo07Woo`1i0ooo07l3ool0
?0?oo`1>1_oo06d3om`0o`;o04Ko?_oo0;3oool0UkWoo`2G3oooool001[ooooo00?oo`0Toooooooo
ool03?ooool3o`30o`;oo`1D00Goo`18ool09?oo02Coo`0Tool0Q@03ool0Z@;o0?ma00Co0:Ooool0
NOoo07Woo`1i0ooo07l3ool0?0?oo`1>0ooo06d3oonA00Soo`2`00Co0?nQool0b?oo0<Soo`38>_oo
09L8ol@0oaOoo`3V<_o40?m:ohd0ooooo`3V7_oo0>H?ooooo`006_ooool00ooo02Coooooooooo`0;
ooooo`04o`30oooo05_oo`1Kool0E0;oo`1800Coo`0Tool0QOoo08Goo`2Y0ol0og401?l0odKoo`1i
ool0NOoo07T3ool0O`?oo`0l0ooo04h3ool0K@?ooooo0ooo0;03o`3oX@?oo`381_oo09LIool0_0Co
o`3V2oo40?l3ohd0o`?oo`3Voooo0;c5ool0_0oooooo000Jooooo`03ool09?oooooooooo00[ooooo
00?o0<3oool0Fooo05@00_oo04P2ool09004ool0QOoolP3ooo80o`3oL@?o0?m600Coo`1iool0Oooo
07ooo`1o0_oo0;H01?oo03coo`1>ool0C_oo04h2ool0K@03o`P0oooo0;3oo`2`00Coo`2`0onC0?l3
ool0b0?oo`2G1Ooo0;`2ooX0o`;ook`05_oo0?PEool0_0KoooP0Gooo0?Soool0e63oo`3D3oooool0
01[ooooo00?oo`0Tooooooooool02Oooool01_l0`?ooo`1Kool0E?oo04SohP3oool090;oo`2Y00Go
oo80ooo>0?l0og7o0?m6o`2Wo`02ool0N@04ool0Oon70?ooQ`3oool0]P;oo`0l00Ooo`1>o`P0oooo
06go203ooonA0?ooooooo`2`00?o04Ko0onC0?l6ool0U`?ook`02Ooo0?P00olb0?ooo`3Dool0e00A
ool0e0;o<P3o6ooo0?P00olb0?ooo`3Dool0e01Lool0e?oo02;oH?l08_l?ooooo`006_ooool00ooo
02Coooooooooo`08ooooo`07o`30oonU0?ooo`1Dool0B?oF0?ooo`0Tool0Z@02ooob0003ooo>0?l0
og7o0?m600;oo`1i0_oo07l01?n70?ooo`2fool0]_oo03`2ool0CP;oo`1]00Goon00oonS0?oo0;3o
o`2`o`16o`03oi<0o`;oo`3800Coo`2Gool0_?oo0;coo`2l0oooool3ool0n0;o<P3o00?oooooool0
e?oo0=@01Ooo0=@Co`0Ro`Soo`3D1olb0?l2o`2do`goo`3D3_l08_lDooooo`?om?l04_o4o`3oo`2j
ohOo0;[o3oooool001[ooooo00?oo`0Tool0??ooool01oooool02Ol0`?ooY@3oool0E?oo04SoeP3o
ool09?oo06Oooo80ooo>0002o`3oL@04o`3oA_oo07Woo`1oool0O`;oQ`3o00Ooo`2fom`0oooo03co
o`1>o`P0oooo06goon0000?oo`2`00?ooooooi<0oonC0?l00ooo0<P2ool0U`04ool0_?oooooooooo
ooooo`?oo`3h0oooool3ool0e0Go02;o4oo4o`05ooooo`Co02;o00?oooooool0e?oo0=@01ooo0=@2
ooooo`_o02;o1Oooool00oo4o`3o0;[oo`2jo`0_o`2jo`03o`3og_l0od3o0?m0027o0?m0ool0g_mS
o`3No`oooooo000Jooooo`03ool09?oo03cooooo00Kooooo013o0<3ooooooooo05Coo`18omH0oooo
02Coo`1Wool0ZOoocP3o0?maooooool0odKoo`1iool0Oooo08_oQ`3o0_oo0;H00om40?ooo`0lool0
CP02ool0K@04oooP0?oo0;3o0?oZo`16o`;oT`3o00?oS@3oool0b?oo09L00_oo09L3ooooo`?oo`3h
0ol0]?l3ool0e0?o02;o0_o4o`03o`3NoaSo0;[o1?ooool<o`0Ro`Kooooo0_odo`02ol[o0003olCo
0?l0^_oo0;[o00Co0;[o00?o0?oNo`3Nool0g_l05Ol0g_l?o`3o@1WoTol01?lDo`0Ao`3Noooo5?l0
HolDo`0?ooooo`006_ooool00ooo02Coo`0looooo`04ooooo`;o0<3o01ooooooool0E?oo04Sooah0
ool09?oo06Ooo`2Yooo>0?l0og7oooooo`3oA_oo07Woo`1oool0RoooiP3oo`2fom`0oom40?ooo`0l
ool0C_oo06gooi40oooP0?oo0;3o0?oZo`16oonC0?ooS@3oooX0oooo0;coo`2G00;oo`3V00Cooooo
ool0n?oo0?Soo`3h0_odo`001?l0]?ooo`3Dool0e?oo0=@3olCo00?o0=ko1Ol0^_l7o`3o@0SoTol0
1Ol0od04o`3No`?o0;[o00?oa?l0ooooooooool02_ooool4olCo00Oo0;[o1ol0g_l3ojco00?oTol0
00?o5?l0ool0l_oo0?807ooo0?8:oaCo0?oo01KoQOl05_l?ooooo`006_ooool00ooo02Coo`0loooo
o`03ooooo`0Co`30ooooooooooooool0E?oo04SohP3oool09?oo06Ooo`2Yooo>0?oooooo0?mao`3o
A_oo07Woo`1oohL0ooooiP3oo`2fodCo0002ool0?009ool0C_oo06gooi40oooP0?oo0;3o0?oZohd0
oonC0?ooS@3o00;oo`2l00Goo`2Gool0i_ooooooooooool0n003ooCo00?oo`3D0on/o`03o`3No`?o
0;[o0_l0od0Eool0lPGoTol000Co[?l0o`3Nool0g_oo0=ko4Ol0^_l00ol0omko0=koo`3No`03o`3N
o`?oTol03?oo0?83oon;00Co01Ko6_m_0?lVool0lP03oon;0?oooooooooo09ooooooa_l0oa0?oooo
o`006_ooool00ooo07Woo`0Tooooo`02ooooo`0Qo`30ooooooooooooool0E?oo04SohP3oool09?oo
06Ooo`2Yooo>0?oooooo0?mao`3oA_ooK@3oo`1iohL0ooooiP3oo`2fodCo0?oo03coo`2Mool0C_oo
097oo`1]oooP0?oo0;3o04Koohd0oonC0?oo01coool0_?oo0<Soo`2G00;ooooo0_oo0?P01?odo`3o
a?l0olCo0?oo0=@2o`0Ro`04ojco0?l0g_oo0=koo`3No`?o0;[o1Ooo0?89ofl0o`;o01Ko2_m_0?l4
ool0lP05oaCo0?nCo`3oTol0oi?o0?n/o`004_l0g_l8ool0lP?o5?l04?m_0?lEooooo`oo0=ko2_oo
oolBofl0oaooo`3b??l0oa3oool0lPkoo`3b3oooool001[ooooo00?o0000ool09?ooool00_ooool0
8Ol0`?ooooooool0E?oo04SohP3ooolN0?oo02Coo`2Yooo>0?oooooo0?mao`3oA_ooK@3oo`1iool0
OoooiP3oooooool0]_oo03coo`2Mool0C_oo097oo`1]oooP0?oo0;3o04Koohd0oonC0?ooVOl0ool0
_?oo0<Soo`2Gooooo`02ool0n0;ob_l000Coa?l0ool0e?oo0=Co02;o0ol0g_l3o`2jo`?oo`3b0om_
0?l5o`0Foa;ooooo00Co01Koofl0oom_0?ooK`3o1?oo0?800olDo`3oTol0ojco0002ojco00Ko0?m0
0on/o`000onCo`3oo`3bool0lP02ool0lP;o5?l00oooR`06ofl0o`?o01Ko1ooooolAo`3o42?ooooo
3ol0oa0Iooooo`WoK`3o??oo0?;oooooo`;ooooo3?m_0?l?ooooo`006_ooool00ol0003oo`0To`30
o`02o`30o`0Toooooooo05Coo`18on80oooo7P3oo`0Tool0IooocP3oooooo`3oLOl0odKoooooool0
NOoo07ooonH0oooooooo0;Koo`0lool0WOoo04koo`2Ao`3o;_oo06goo`2`o`16oon=0?ooT`3ooiWo
0?oo0;coo`38ool0Uoooooooo`3hoc80ooo:o`3oa?l00_oo0=@2ooooo`04o`3NoonCo`3o0;[oo`2j
o`?oo`3b0_ooR`001?lDo`3o01Koo`0Fool05_l5oooooa;o0?l@1Oooool00om_0?oooh/0oon;0005
ool0lP?oTol01ooo0?83oaCo0003oon;0?ooooooK`3o00?oK`3o00?o01Koooooooooool00oooool:
o`3o417ooooo8ol0oa0iooooob?oK`3oQooooon;ofl0oa_ooooo000Jooooo`03o`000?oo02Coo`1K
00;ooooo00Ooo`1Dool0B?oR0?oooah0ool09?oo06Ooo`2Y00;ooooo01So0?maoooooooo07Woo`1o
oooV0?ooooooo`2fodCo0?oo03coo`1>ool0TOl80?ooo`1]ool0/?l0A_ooS@3ooi<0ool0oj7oo`2l
ool0b?oo09Ooooooool0n?lb0?l2olCo0003ool0e?l08_oooooo00;o0=ko00CoTol0ofl0oom_0?oo
o`3b0oooR`03o`0Fo`?ooooo1Ol0oa03ooooo`SobP3o1oooool5o`3o4004oooooom_0?ooK`3oo`0F
o`;ooh/00_lDo`03ool0lP?o5?l00oooR`03ooooo`?oK`3o1oooool3o`3o40_ooooo5oo:0?l[oooo
odgo0?l4Qom_0?nGo`3o10oooooo000Jooooo`0Yo`000?oo02Coo`18oooooooo05Coo`18on80oooo
ooooo`0Tool0Iooo0:Woolh0ooooool0og7o0?m6o`2Woooo07WoonH0oooooooo0;KoA?l0ool0??oo
04koo`2Ao`P0oooo06goo`2`o`3oj_n=0?ooT`3oo`3oXOoo0;coo`38ool0Uoooooooo`3hoc80ooo4
o`3o[?l0ool0e?l08_l00_l0g_l2oi?o0004ofl0oooo0?;oo`3boon;00?o01Ko0oooool2o`3o40Wo
bP3o2?ooool6olX0o`Kooooo0_l0oa000oooooooK`3oofl0o`02ofl0o`03o`0FooooR`3ooh/000;o
oh/000?oooooo`0Foom_0?l01Om_0?l4ooooo`Ko0?l@2?ooool6olX0oaOooooo2_o:0?l4oooooe7o
0P3o3?ooooooo`3oGbco0?mO3oooool001[ooooo02Co0000ool09?oo04Soo`1Dool0B?oR0?oooooo
omH0oooo02Coo`2Yooo>0?oooooo0?mao`3oA_l0Yoooo`1iool0Oooooooog03oool0]_oo03coo`2M
ool0C_l80?ooo`1]oooooooo0;3o04Kooi<0ool0oj7oo`2loc;o0?oo09Oob_l0ool0n?lb0?l2ojco
0003ool0e?l0g_oo0=ko00;oTol00_m_0?l01?oo0?;ooh/0oaCo0?l05_l3ooooo`?o0?l@0_o:0?lG
ooooo`?obP3o1Oooool00ol0oa3oooooooooo`02ooooo`OoK`3o1_ooool4o`3o40Wooooo1Oo:0?l<
ooooo`_o0?l44?l20?l8olX0oc?ooooo6_l0oemMo`80o`03oooooome0?ooM@3o04CoM@3oR?ooool;
o`80o`oooooo000Jooooo`03o`000?oo03coo`0T00;oo`1802CoooooomH0oooo02Coo`2Yooo>0?oo
oooo0?mao`3oA_ooooooo`1iool0OoooiP3og03oool0]_m40?ooo`0lool0C_oo097oo`1]oooooooo
0;3o04Koohd0oonC0?ooo`2loc;o0?oo0<Soo`2Goooooooo0?So<P3ooooooooo0=Co0=koooo80?nC
o`02ofl0o`;oo`3b00?ooh/0o`0Fool05_l00oooool01?l0oa3obP3oolX0ooo:0?l6ooooo`;o0P3o
1ome0?l2onP0o`OoM@3o1?ooool3olX0o`?ooooo0_l0oa0<ooooo`?o0?l@2?ooool5olX0o`Oooooo
1Ol0o`@@o`80oaSooooo2oo:0?lGoooooa7o0?mO6_oooomNogD0odKo0P3oTome0?l?ooooo`006_oo
ool00ol0003oo`0lool09002ooooo`04omH0oooo02Coo`2Yooob00;ooooo01So0?mao`3oA_l0Yooo
o`1iool0Roooooooo`2fodCo0?oo03coo`1>ool0TOoo06goooooool0/?l0on[o04Kooi<0oooo0;co
<_l0ool0b?oo09Ooooooool0n?lb0?l2ooooo`04ool0e?oob03oK`3oofl0o`;oo`3b0_ooR`001?l0
5_ooooooooooooooool3olX0o`Kooooo0ol20?l9onP0o`03oooooooX0?ooj03o00Ooj03o0_me0?l4
ooooo`03olX0oooooooooooo00;ooooo3?l0oa07ooooo`CobP3o2?ooool3o`3o10;o0P3o5_oX0?l8
oooooaWoJOl03?o:0?l6ofWo00Go0?mO5?mYo`0GogD0oaCoJOl0oooooolcooooo`006_ooool01?l0
003oo`0lool09?ooool2ool0900Lool0ZOoolP3oooooooooool0og7o0?m6o`2Woooo07Woo`1ooooV
0?oL0?ooo`2fod@0oooo03coo`1>oo@0oooo06goo`2`o`3oj_l0A_ooT`3oo`0Loooo0;co2?l0ool0
Uoooooooo`3hoc80o`;ooooo00Goo`3Do`3Noom_0?oo0;[oool0lP02oon;00;o01Ko00CoooooolX0
ooo:0?oobP3o1_ooool3o`80o`?oj03o3_ln0?l5ooooo`;oj03o00?oM@3oooooooooool00_ooool0
0oo:0?ooooooooooo`0Aooooo`?obP3o2Oooool2o`3o1003o`80oooX0?ooj03o00?oj03o3_me0?l0
0omYo`3o?P3ooch0o`05och0o`?oj03o:_ln0?l;olX0o`coMOl02?me0?l[oooooh_oJOl0S?ooool<
olX0o`oooooo000Jooooo`03o`000?oo03coo`0T00;oo`0T01coo`2Yooob0?ooooooooooo`3oLOoo
oooo0?m6o`2Woooo07WoonH0om`0oooo0;KoA03oool0??oo04kom03oool0KOoo0;3o0?oZooooool0
A_ooT`3oool0_?l8o`3oo`38ool0Uooo0?So<P3o0_ooool03?oo0=Co0=koofl0ool0^_ooo`3bo`3o
@?oooooo01KooaCo0?oooooobP3oo`3o40Gooooo0ol20?l3onP0o`;o?P3o00?oJOl0ogGo0?meo`00
0_meo`0;ok80o`?o?P3o0oooool3onP0o`03o`80oooooooooooo00?obP3o3Oooool3olX0o`Wooooo
00?o0?l4o`80ool20?l00ooX0?l00ome0?oo0?mOo`3oG`03ooooo`CoJOl02Oln0?l3ogD0o`Sooooo
0_oX0?lMooooo`co0?ol2_ln0?l<olX0omGo0?olMOo:0?l<o`3oo0oooooo000Jooooo`03o`000?oo
03coo`1i00;oo`1W02Kooo80ooooooooooooooooo`3oLOl0odKo0:Ooool0NOoo07ooooooom`0oooo
0;Koo`0lool0WOoo04kom03oool0KOoo0;3oooooo`16oonC0?oonP3oool0_?l8o`3oo`2Gool0n?o4
o`3o<P3ooooooooo0=Co0=koofl0ool0^_ooo`3bo`3o@?oooooo01KooaCo00;obP3o00Co0?l@oooo
oooooooooooo0ol20?l3onP0o`;o?P3o00?oooooogGo0?meo`001Onb0?l;ooooo`Co/P3o00?o?P3o
ogGo0?ooool00_ooool00ooX0?ooM@3oooooo`03ooooo`;obP3o1_ooool5olX0o`Wooooo00?o0?l4
o`80ool20?l00ooX0?l2o`3oG`04oooooomYo`3oJOl0ofWo00Co?P3o3?nb0?l2o`3oG`03oooooome
0?oooooo00Sooooo0ooX0?l<ooooo`ko0?ol00?oooooo`3oGol0oel03Ol0Mol6ogD0o`_o07Oo00?o
?P3oolX0ooo:0?l01oo:0?l2och0ocKo07Oo7?nb0?oionP0o`oooooo000Jooooo`03o`000?oo09Oo
o`0l00;ooo800oooool06?l0og7o0?m6oom]0?oo07Woo`1ooooV0?oL0?ooo`2fod@0oooo03coo`1>
oo@0oooo06goo`2`o`3oj_l0A_ooT`3oooX0ool0oj7oo`2lool0b?oo09Ooa?l0oc80o`;ooooo00Wo
o`3Dofl0ooooooooo`3bo`3o@?oooooo01KooaCo0?o:0?l00_l0oa03ooooo`04o`80oome0?ooM@3o
onP0o`?ooooo0omeo`02ok80oaCooooo0_nb0?l2och0o`;ooooo00?oj03oogD0ooooool01?ooool6
olX0o`_ooooo0ol20?l3onP0o`?ooooo0_mYo`04och0o`Co/P3o3?ooool4ok80o`;oM@3o2_l0oo`4
onP0o`Oo0?ol4_l0Mol9ooooo`CoM@3o6?ooool3okko00_obP3o0oln0?l;okko01Oo/P3o9?oX0?l4
ooooobkobP3oe_ooool001[ooooo00?o0000ool0Uooo03`01Oooool05ol0og7o0?m6o`2Woooo07Wo
o`2;om`0ooooooooo`2fool0??oo09goo`1>oo@0oooo06goo`2`oooooon=0?ooT`3oooX0oooo0;co
o`38ool0Uoo4o`3o<P3o00;ooooo00[oo`3Dofl0oooooooo0;[oool0l_oooooo01Koooooooo:0?oo
0?l@0oooool2o`80o`03ogD0oooX0?ooj03o00?ooooo00GoMOl0ok80oonb0?oo/P3oooooo`0Aog/0
o`Kooooo00?o/P3oofWo0?ln0?l00_ooool00ooX0?ooM@3oo`3o100Aooooo`?o0P3o0ooX0?l3oooo
o`;oJOl00oln0?l01?meo`3o/P3ook80oonb0?l8ooooo`So0?ol1?mk0?l3ok80o`03ogGo0?oooooo
oooo00Gooooo1Ol0Mol5onP0o`;o07Oo2_ooool3o`3oG`_ooooo0ome0?l4oooooacoB_l02_nb0?l=
olX0oaSoj03o:?o:0?ooooooo`Gooooo000Jooooo`03o`000?oo09Ooo`0l00Cooooo01So0?mao`3o
A_l0Yoooo`1iool0OoooiP3og03oool0]_m40?ooo`0lool0C_od0?ooo`1]ool0/?l0on[oS@3ooi<0
oooj0?oo0?nQool0_?oo09Ooo`3hojco0?lb0?l2ooooo`09ool0e?m_0?oo0;[oool0l_l0od3o01Ko
ooooooo:0?oo0?l@00?ooooo00Co0P3ooch0oome0?ooj03o0oooool3ok80o`CoN`3o00Gooooookko
0?nno`3o__l0ooooo`0<o`3oo0?oN`3o1?ooool2ok80o`03och0oooooooooooo00;oj03o00?o0?l4
ooooooooool02oooool3o`80o`?oj03o00?o0?mOooooooooool00_mYo`03och0o`04oooooonb0?oo
/P3ook80o`Gooooo0_l0oo`<og/0o`Go07Oo0_mk0?l00onb0?ooN`3oog/0o`06og/0o`Wooooo1?oX
0?l00oooooooB_l0od[o0002od[o00?o0?mO1om:o`11onP0o`03o`3of?ln0?oo?P3o013o?P3oool0
omPSo`3of0oooooo000Jooooo`03o`000?oo09Ooo`0l00?ooooo01So0?maooooool0odKoo`1iool0
Oooo08_og03ooooooooo0;Koo`0lool0WOoo04kom03oool0KOoo0;3ooooooi<0oooj0?oo0?nQool0
_?oo0<Soo`2GolCo0?lb0?l2ooooo`0>ool0e?m_0?ooooooool0l_l0od3o01Koooooooo:0?oooooo
o`3o4?ooooooJOl0o`80ooln0?l2onP0o`04oooooomeo`3oMOl0ok80o`?oN`3o0oooool2okko0003
oooooonh0?oo^03o00go^03o00?oooooo`3oo?l0oo`00_mk0?l4ooooo`03ok80ooln0?oooooo00;o
oooo00?oj03oo`80ool20?l02Oooool2o`80o`04o`3o1?oX0?ooj03oo`3oG`?ooooo0_mYo`02och0
o`04oooooonb0?oo/P3ook80o`Gooooo0_l0oo`3og/0o`03okko0?l0Mooo07Oo00Go07Oo1?ooool6
okko00;ooooo00?o/P3oo`3oGoooool00omeo`02ooooo`GoN`3o2?m:o`0?onP0o`04o`3of?me0?oo
M@3oogD0o`?o0?oH2oooool:ok80ocSooooo7Oln0?o;oooooc[o?P3o3oooool001[ooooo00?o0000
ool0Uooo03`00oooool09Ol0og7o0?m6o`2Woooo07Woo`1oom`0ooooooooo`2fodCo0?oo03coo`1>
oo@0oooo06goo`2`o`3oj_n=0?ooT`3oooX0oooo0;coo`3Vool0Uooo0?So[?l0oc80ooooooooo`3D
ofl0oooob03oo`3bo`3o@?oooooo01KoolX0oooooooo0?l@oooooomYo`000_ln0?l01?oX0?oooooo
oooooomeo`02ok80o`04og/0ooooooooooooooooo`?o__l00onh0?l00onO0?oo07Ooo`1go`0;oooo
o`07oil0oonh0?oo^03ookP0oooooooo0?olog/0o`04ooooo`03ok80ooln0?oooooo00;ooooo00?o
j03oogD0ool20?l00_l20?l2ooooo`Co0P3o0ooX0?l3ooooo`;oJOl00oln0?l00ooooooo/P3ook80
o`05ooooo`GoN`3o00Goooooo`1gool0Mooo07Ooooooo`0<oil0o`Cooooo00?o__l0od[o0?m:o`00
0_nb0?l00ol0oeooB_l0od[o0004od[o00?oMOl01Omk0?l5o`3of0Wooooo0onno`02ogD0o`03okko
0?oooooooooo00Sooooo1_nb0?mOooooob?o?P3oH_oooom6och0odWooooo000Jooooo`03o`000?oo
0<Soo`0l00?o0?ma01Oo0?m6oooooooo07Woo`1ooooV0?oL0?ooooooool0]_m40?ooo`0lool0C_od
0?ooo`1]ool0/?ooooooT`3oooX0oooo0;coo`3Vool0b?oo09Ooo`3hoc80o`02ooooo`09ool0e?nC
o`3oooooool0l_oooooo01Koooooooo:0?oo0?l@00;oJOl000?o?P3ooooooooX0?l00_ooool00ome
o`3o/P3oooooo`02ooooo`?o__l00onh0?l2o`1go`ooB_l01?ooool2okP0o`03o`1goomk0?oooooo
00?ooooo00?o/P3ooch0ooooool00_ooool:onP0o`03ogD0oooooooooooo00?oJOl00_ln0?l2oooo
o`;o/P3o1Oooool00ol0oocoN`3ookko0002ooooo`?o07Oo0_nO0?l:okP0o`;ooooo0_m:o`06oil0
o`?o0?oH0_nb0?l9o`3of004ooooool0oeoo0?mOo`3oG`GoN`3o0_ooool7okko00?oM@3o2_ooool3
ok80ohSoooooH_ln0?n0okSo00oooooo000Jooooo`0;o`000?ooooooo`0lo`3oA_l0og7oooooo`3o
A_oo07WoQ`3oool0OooL0?l00_ooool07ooo0;Koo`0lool0C_od0?ooo`1]ool0/?l0on[oS@3ooi<0
oooo0;co<_l0ool0i_oo09Ooo`3hojco0?lb0?ooooooool0e?m_0?ooooooool0l_l0od3o01Kooooo
ooo:0?oo0?l@ofWo0?oooooo?P3ooooooooX0?l00_ooool00omk0?oo/P3oooooo`02ooooo`04okko
0?oooooooooookP0o`;o07Oo0om:o`000oooooooj?l0onSo0005onSo00Co0?oH0_oXo`001?oooooo
B_l0od[o0?m:o`03ooooo`04okP0ool0MoooN`3ookko00?ooooo00?o/P3oogGo0?ooool00oooool3
o`3oG`03ogD0ool0oeoo0?mO00?ooooo0_mYo`000omeo`3o?P3ooch0o`02ooooo`;o/P3o1?ooool2
okko00;oN`3o00Coooooo`1goonO0?ooW`3o1Onh0?l3ooooo`;oB_l01Ol0omP4okP0o`03o`3of?oo
oooooooo00?ooooo0onO0?l01OooooooM@3ook80oonb0?oo__l000Oo0?mO1_ooool2okko00CoN`3o
0_ooool3ogD0o`Sooooo1Onb0?mQoooooego^?l0__ooool001[ooooo00Co0000oooooooo03coo`1i
0_l0odH01?oo07WoQ`3oool0OooL0?l2ooooo`0@ool0]_m40?ooo`0lool0C_od0?ooo`1]ool0/?oo
ooooT`3oooX0oooo0;coo`3Vool0b?oo09Ooo`3hoc80o`;ooooo00goo`3Doi?o0?ooooooo`3boooo
ool05_oobP3oooooool0oa3ooooooch0ooooooooj03o00;ooooo00CoN`3ooooooonb0?oooooo0_nn
o`001?oooooo^03ookP0ool0Mol2od[o00Coj?l000?oooooo`3of?l0omP01?l0omP4okSo00Go0?oH
00?ooooood[o0?m:o`000_ooool01?nh0?oo07Ooog/0oonno`03ooooo`03ok80oomYo`3ooooo00Wo
oooo0_mYo`000omeo`3o?P3ooch0o`02ooooo`;o/P3o1?ooool01Onno`3oN`3oog/0oomk0?oooooo
00;o07Oo00?oW`3ookP0oonh0?l01_ooool2od[o00;o0?oH2OoXo`02okP0o`Ooj?l00_nO0?l01?oX
o`3oM@3ook80oonb0?l<okko00Gooooo00?oM@3oog/0oomk0?l00_mk0?l5ooooo`Co/P3o=oooool_
okSo0?oooooo7?ooool001[ooooo00Co0000oooooooo03coo`1i0_l0Yol01?oo07Woo`1ooooV0?oL
0?l2ooooo`0Nool0]_m40?ooo`0lool0C_oo06goo`2`o`3oj_n=0?ooT`3oool0_?oo0>Ko2?l0ool0
Uooo0?Soa?l0oc80ooooooooo`3Doi?o0?ooooooo`3bo`3o@?l05_oobP3oooooool0oa3oJOl0och0
ooooooooj03o0_ooool01Omk0?oooooook80oooooooo__l000?o^03o0_l0Mol00om:o`3oj?l0onSo
0002okSo00?o0?oH3?ooool3okSo00?o0?oH00OoB_l0oooooooooooo^03oo`1goomk0?oo__l000?o
oooo00?o/P3ooch0ooln0?l01Oooool3ofWo00?o?P3o0_ooool2ok80o`Cooooo00Go__l0og/0oomk
0?oo0?olooooo`02o`1go`?o^03o1?ooool00ooXo`3o0?oHo`3of003o`3of0;ooooo1Onho`06oooo
o`;o^03o1oooool01_nO0?oooooooooooome0?oo/P3oooooo`goj?l00_me0?l5ooooo`;oN`3o0onb
0?lmoe3o0?oooooo5OoooolUonko00oooooo000Jooooo`04o`000?ooooooo`0lool0R`;oo`1i00?o
o`1ooooooooL0?l00_ooool04?oo0;KoA03oool0??oo04kom03oool0KOoo0;3ooooooi<0ool07?oo
o`2lool0i_oo0<Soo`2Gool0n?lb0?l2ooooo`0Dool0e?oob03oo`3bo`2joooooooo01KoolX0ool0
oa3oJOl0och0oooooooo0?mOonP0ooooooooN`3oogGo0?nb0?oooooookko0?nh0?l2od[o0004o`1g
oooXo`3oj?l0onSo00;o^?l00_l0omPBooooo`;o^?l000?oj?l0o`3of?l0omP00_ooool00onh0?oo
07Ooog/0o`04ooooo`04ok80oooooooo?P3ooch0o`?oJOl000?oMOl0och0ooln0?l00oooool2ok80
o`Cooooo00?o__l0og/0oomk0?l00_l0oo`01?l0MoooW`3ooil0oonh0?l4ooooo`05onSo0?m:o`3o
B_l0o`3of?ooool01_nho`04ooooo`Wo^?l000?o^03oooooooooool01Oooool01?nO0?oooooooooo
oome0?l2ok80o`Kooooo00?oD?l0ogD0oome0?l00ome0?l6oe3o00?o/P3o0_m@o`000oooooooN`3o
og/0o`02og/0o`Gooooo3?nho`04ooooob;oj?l00_oooom5oe3o00?ooooolOoXo`0?ooooo`006_oo
ool2o`000003ool0??ooooooo`1o00;oo`1o02gog03oooooooooooooooooool0]_m40?ooo`0lool0
C_oo06goo`2`o`3oj_n=0?ooT`3oooX0oooo0;co2?l0ool0Uooo0?Sooooooc80ooooooooo`3Doi?o
0?ooooooo`3bo`3o@?l05_oobP3oooooool0oa3ooooooch0ool0oeooj03ooooooomk0?ooMOl0ok80
oooooooo__l0okP0oom:o`3o0?olo`1goooXo`000_ooool00onho`3o0?oHo`3of007ooooo`Sok_l0
1oooool02Onho`3oj?l0ooooool0omSooooookP0ool0Mooo0?olog/0o`04ooooo`?o/P3o1?ln0?l2
ooooo`?o/P3o1Oooool01Onno`3oN`3oo`3oo?l0oocooooo00;oW`3o0_nh0?l2ooooo`;oj?l00_m:
o`02o`3of0;o^?l04oooool00onho`3o^03ookSo0006ooooo`03oil0oooooooooooo00;oD?l000?o
/P3oogD0oome0?l01?me0?l8ooooo`?o/P3o2_ooool5og/0oc;oooooAooXo`0`oe3o0=?ooooo000J
ooooo`04o`000?ooooooo`0looooo`;oo`2;01Cog03oooooooooooooooooool0]_ooooooA03oool0
??oo04koo`1]ool0/?ooooooS@3ooi<0oooo0;coo`3Vool0b?oo09Ooa?l0oc80o`;ooooo01Koo`3D
ooo80?oo0?;o0;[oooooooo:0?ooooooo`3o4?oooooo?P3oo`3oGooX0?ooooooog/0oomeo`3o/P3o
oooooonno`3o^03ood[o0?l0ooco07Oo0_ooool2okSo0003o`3of?oooooooooo00;ooooo00Cok_l0
oe3o0?m@o`3oD?l02on10?l2onko00Cooooo00Wo^?l0onSo0?l0omSoB_l0oooooonh0?oo07Ooog/0
oonno`001_ooool6ok80o`Kooooo00Ko__l0og/0oomk0?oo0?oloooooonO0?l3okP0o`?ooooo00?o
j?l0od[o0?l0omP00_l0omP00onho`3oooooooooo`04oooooa;ok_l000?o^03ooe3o0?m@o`001Om@
o`02oil0o`?ooooo3_nb0?l5ooooo`So^?l01Oooool5og/0odko0?lFool0ok@Ko`3o]0oooooo000J
ooooo`03o`000?ooooooo`0l00;ooooo0_oL0?l3ooooo`0Wool0]_m40?ooo`0lool0C_od0?ooo`1]
ool0/?n=0?ooT`3oooX0oooo0;coo`3Vool0Uooo0?Sooooooc80ooooooooo`3Doi?o0?ooooooo`3b
o`2jooo:0?oo5?l0ooooool0oa3o?P3oo`3oGome0?ooj03oog/0oomeo`3o/P3ooooooonno`3o^03o
od[o0?l0ooco07Oo00;ooooo00?o^?l0o`3of?l0omP00oooool2oe3o00CoP@3o2ol0Sol4oh40o`?o
oooo00?o^?l0ooooool0omP00_ooool01?nh0?oo07Ooog/0oonno`0?ooooo`03okko0?mk0?ooN`3o
00;o0?ol00?oW`3ookP0oonh0?l01?ooool01OoXo`3oB_l0od[o0?l0omSo^?l000Cooooo1Oo^o`0=
ooooo`KoD?l000?o^03oonko0?o^o`001Onho`000oooooooW`3ooil0o`0=ooooo`Ko^?l01On7o`0<
o`3o5P;oQol01Omk0?l<ohOo02Ko6_l05ol0ok@>oa[o08goooooAOm@o`19ooooo`006_ooool00ol0
003oooooool0?006ooooo`0@ool0]_ooooooA03oool0??oo04koo`1]ool0/?l0on[oS@3ooi<0oooo
0;coo`3Vo`So0?oo09Oooooooc80o`;ooooo01Koo`3Dooo80?oo0?;o0;[oo`3o@?o:0?ooooooo`3o
4?ln0?ooooooo`3oGooX0?ooN`3ooooooonb0?oooooookko0?nh0?ooB_l0ooooool0Mooooooo0_nh
o`001?l0omSoooooooooooooool2oe3o00;oP@3o0_l0Sol>ooooo`?o08oo00OoP@3ooooooooooooo
oooookSo0?l0omSoB_l000;ooooo00?o^03oo`1goomk0?l00_nno`0;ooooo`06okko0?mk0?ooN`3o
ooooool0oocoW`3o0_nh0?l4ooooo`03onSo0?m:o`3oB_l000;o0?oH0oooool3onko00Sooooo2_m@
o`07ooooo`04okP0ooooooooooooooooo`?ok_l00onho`000onO0?oo^?l0okSo0002okSo00OoQol0
3?l0oaHCoa[o00GoN`3o1olJo`0Gooooo`oo0?nd9On7o`0Boa[o0?3o08oo2_lJo`0?ooooo`006_oo
ool01?l0003oooooool0??oo0;H5ooooo`0[ool0]_m40?oo;03oool0??oo04koo`1]ool0/?n=0?oo
T`3oooX0oooo0;coo`3Vool0b?oo09Oo<P3oooo/0?ooooooK`3oool0e?ooooooo`3bo`2jooo:0?oo
5?l0ofWo0?l0oa3o?P3oo`3oGome0?ooj03ooooooomeo`3o/P3ookko0?nO0?oo^03oooooool0Mooo
oooookSo0?oooooo0?oHooooo`03oe3o00;oP@3o00?o08ooooooooooool00oooool:o`3o]0Gooooo
00?o08oooh40ooo^o`000_ooool01onho`3o0?oHod[o0?oooooo^03oooooool0Mol00_mk0?l00onn
o`3oooooooooo`07ooooo`03okko0?mk0?oooooo00;o0?ol00?oW`3ookP0ool0Mol00oooool01OoX
o`3oB_l0od[o0?nho`3o0?oH00?ooooo0_o^o`08ooooo`?oD?l04Oooool00onh0?ooooooooooo`05
ooooo`?oQol00_nO0?l2ohOo0003ooooool0oaKo0?lF00Co0?lF1Oooool6oa[o01Wooooo0omk0?lB
ooooo`Wo0?nd:ooooolKo`2?oaooQol0dOooool:o`2?o`oooooo000Jooooo`04o`000?ooooooo`0l
ool0]PGooooo00ooo`2fod@0oooo03coo`1>oo@0oooo06goo`2`ohd0oonC0?oonP3oool0_?oo0>Ko
o`2Goooooolb0?l00_ooool06?oo0=CoolP0ool0l_l0^_oo0?m0olX0oomYo`3o0?l@och0ool0oeoo
M@3oonP0oomk0?ooMOl0ok80oonno`3oW`3ookP0oooooooo07Oooooooonho`3oooooo`3of0;oD?l0
00?oooooo`2?oon10?l01?ooool4o`3o]0SoQol00_ooool3o`3o]0?ooooo00?o08oooh40ooo^o`00
0_ooool02Onho`3o0?oHod[o0?oooooo^03oooooool0Mooo0?olog/0o`02okko00Cooooo00Co__l0
og/0oomk0?ooN`3o0_l0oo`00onO0?oo^03ookP0o`03ooooo`;oj?l000CoB_l0ooooool0omSo0?oH
0_ooool2onko00Oooooo0om@o`0Dooooo`03ohOo0?nh0?ooQol000GoQol01Ol0oaH2oil0o`03o`3o
5_lJo`3o6_l000Wo6_l08_ooool3og/0o`[ooooo1Ol0ok@Soooooa7o08oo>_oooom6ohOo0:Cooooo
000Jooooo`04o`000?ooooooo`1]ool0?0Cooooo02Woo`2foooooom40?ooo`0lool0C_oo06goo`2`
ohd0oonC0?oo01coool0_?oo0>Ko2?l0ool0Uolb0?ooon`0oooooom_0?ooo`3Doooooooo0?;o0;[o
olX0oolDo`3oJOl0och0ool20?oo0?mOonP0oomk0?ooMOl0ok80ooooooooW`3ookP0oooooooo07Oo
oooooonho`3oooooo`3of002onko0003oooooon10?ooP@3o00?ooooo0_l0ok@2ohOo00[ooooo1?n7
o`000ooooooo0?ndo`3o]002ooooo`07o`2?oon10?oooooooooooonho`3oj?l0o`3of002ooooo`04
okP0ool0Moooooooo`3oo0OoN`3o00?oooooo`3oo?l0oo`00_nO0?l00onh0?oo07Ooooooo`02oooo
o`05onSo0?ooooooB_l0okSo0?l0omP00oooool00oo^o`3oooooooooo`04ooooo`?oD?l04?ooool7
ohOo00;o0?lF00?o^03oo`3o5_l0oaH00ol0oaH00ooooooo6_l0oa[o0004oa[o00;oW`3o;oooool2
og/0o`;ooooo1_l0ok@Mooooo`_o08ooTOooool^ohOo07Kooooo000Jooooo`04o`000?ooooooo`2G
ool0?0Cooooo02;oo`2fod@0oooo03coV@3oool0C_oo06goo`2`ohd0oonC0?oonP3oool0_?oo0>Ko
o`38ool0Uolb0?ooooooofl0oooo0=CoolP0ool0l_l0^_oo0?m0olX0oomYo`3o0?l@och0ool0oeoo
M@3oonP0oomeo`3ooooook80oonno`3o^03o0_ooool01Ol0Mooo^?l0oe3o0?l0omSok_l000;ooooo
00CoP@3ooooooooooooooooo0_l0ok@7ooooo`[o0?lF00WoooooohOo0?ooooooooooo`3o]?oooooo
D?l0oh40ooo^o`000_ooool00onho`3o0?oHod[o0002ooooo`04okP0ool0Moooooooooooo`;o0?ol
0oooool2o`3oo005oooooonO0?oo^03ookP0ool0Mol00oooool01OoXo`3ooooood[o0?nho`3o0?oH
00?ooooo00?ok_l0ooooooooool00oooool2oe3o00Gooooo1On10?l00oooooooQol0ohOo0002ohOo
00_o0?lF0oooool00onh0?oo6_l0oa[o0003oa[o00Sooooo00?oW`3oooooooooool0;?ooool2o`3o
]0;oN`3o7_ooool5o`2?ol[ooooo;_n7o`0^ooooo`_oN`3o3oooool001[ooooo00Go0000oooooooo
09Ooo`0lool0]P02ooooo`0Zool0]_ooooooA03oool0??oo04kom03oool0KOl0on[oS@3ooi<0oooo
0;cob_l0ool0i_oo09Oooooooc80ooooooooK`3oool0e?ooooooo`3bo`2jooo:0?oo5?l0ooooooln
0?oo0P3oo`3oGooX0?ooooooogGo0?nb0?oo__l0oil0oonh0?ooooooo`1goonho`3oD?l0ooooool0
omSooooo0_n10?l01?ooooooQol0ohOo0?l0ok@5ooooo`Co0?lF2OlJo`002_oooooo0?lFo`3o5_l0
oaKoQol0ooooool0okCooooooe3o0?n10?l3ooooo`03okSo0?l0omSoB_l000;ooooo0_nh0?l3oooo
o`?o0?ol0_ooool00onO0?oo^03oo`1go`04ooooo`05onSo0?ooooooB_l0okSo0?l0omP00_ooool2
onko00Gooooo00?oD?l0ooooooooool00_ooool3oh40o`?ooooo0_n7o`03oh40o`;o0?lF2Oooool5
oa[o0003okP0oooooooooooo00cooooo0_nO0?lYooooo`?o0?nd1?ooool3og/0oaGooooo1_l0Soom
oooooaOoQol05omk0?l;ohOo00oooooo000Jooooo`07o`000?ooooooo`38ool0??oo0;Koooooool0
]P02ooooo`0Xod@0oooo03coo`1>ool0KOoo0;3oS@3ooi<0oooj0?ooo`2lool0i_l8o`3oo`2Goc80
ooook03oK`3oool0e?oob03oooooool0l_l0od3obP3oofWo0?l0oa3o?P3oo`3oGome0?ooj03oogGo
0?oooooo/P3ooil0oonh0?ooooooo`1gooooooooD?l0ooooool0omSooooooh40o`?oQol00_l0ok@4
ooooo`;o0?lF0olJo`0:ooooo`?o6_l000Soooooo`3o5_n7o`3oooooo`3o]?ooooooP@3oo`2?o`;o
oooo00?o^?l0o`3of?m:o`001?ooool00onh0?oo07Ooooooo`03ooooo`;oW`3o00?o^03oo`1goooo
ool00_ooool2onSo0004oooooom:o`3oooooo`3of0;ooooo00?ok_l0ooooooooool00oooool2oe3o
0003oooooon10?ooP@3o00;oP@3o0oooool3ohOo00;ooooo0ol0oaH00on10?ooooooooooo`02oooo
o`Ko6_l01_ooool00onh0?ooooooooooo`0=ooooo`;oW`3o9?ooool3o`3o]0[ooooo0omk0?l<oooo
o`Ko08ooooooool4oooooaOoN`3o<Oooool001[ooooo02So0000oooooooX0?ooo`0lool0]_oooooo
o`2foooooom40?ooo`0lool0C_od0?ooo`1]ool0/?n=0?ooT`3oooX0oooo0;coo`3Vool0b?oo09Oo
<P3oofl0ool0g_ooo`3Doooooooo0?;o0;[oolX0oolDo`3ooooooch0ool20?oo0?mOonP0oomeo`3o
oooook80oonno`3o^03o0_ooool01ol0MoooD?l0ooooool0omSooooooh40oon7o`000_ooool00ol0
okCoooooooooo`03ooooo`03o`3o5_lJo`3o803o00go803o0oooool02OlJo`3oooooo`3o5_n7o`3o
ooooo`3o]?ooooooP@3oonko0002ooooo`03okSo0?l0omSoB_l000?ooooo0onh0?l2oil0o`?o^03o
1?ooool01ooXo`3ooooood[o0?m:o`3oooooo`3of?ooool00_o^o`05ooooo`04oe3o0?oooooooooo
oh40o`Cooooo0on7o`02ooooo`?o0?lF00Gooooooa[o0?lJo`3o6_l0oh40o`03oa[o00gooooo00?o
^03oooooooooool03_ooool2oil0ob3ooooo0_l0ok@@ooooo`CoN`3o0_ooool6o`2?oo7ooooo6?mk
0?m8ooooo`006_ooool0<?l0003ooooooooooooo04koo`0lool0]_ooooooA03oob`0oooo03coo`1>
oo@0oooo06go0?oZohd0oonC0?ooo`2loooooooo0>Koo`2Goooooolb0?ooK`3ooi?o0?oo0=Cooooo
ool0l_l0^_oobP3oofWo0?ln0?oo0P3oo`3oGome0?ooj03oogGo0?nb0?oo__l0oil0oonh0?oooooo
o`1goom@o`3oooooonko0?l0omSooooooh40o`;ooooo00?o0?ndooooooooool00_ooool01?l0oaKo
803oob00oolP0?l>ooooo`;o803o0_ooool02?lJo`3oooooo`3o5_n7o`3o0?ndoooooom@o`3oP@3o
0_ooool00onho`3o0?oHod[o0006ooooo`;o^03o1Oooool2onSo00;oB_l000Go^?l0ooooool0omSo
ooooonko0005ooooo`;oD?l000?ooooooh40oon10?l00_ooool3ohOo00?ooooo0_l0oaH01?oooooo
6_l0oa[o0?lJo`04ooooo`03oh40oooooooooooo00kooooo00?o^03oooooooooool03oooool3oil0
oacooooo00?o0?ndooooooooool04_ooool2o`2?o`CoN`3ogOoooolHog/0of3ooooo000Jooooo`0W
o`000?ooooooooooool0KOoo03cooooood@0ool/0?ooPOl0ool0??oo04koo`1]ool0/?n=0?ooT`3o
ooX0oooo0;coo`3Vo`So0?oo09Oo<P3oofl0ool0g_ooo`3Doooooooo0?;o0;[oolX0ool05_oooooo
och0ool20?oo0?mOonP0oomeo`3ooooook80oonO0?oo^03o00;ooooo00Ko07Oooooooooooooo0?oH
oooooon10?l2ooooo`03o`3o]?oooooooooo00;ooooo0_lP0?lCooooo`;o803o00Wooooooa[o0?oo
oooo0?lFohOo0?l0okCoooooo`2?oon10?l00_ooool00onho`3o0?oHod[o000;ooooo`09onSo0?m:
o`3oB_l0oooooonho`3oooooo`3of?ooooook_l000Gooooo00GoD?l0ooooooooooooP@3oooooo`03
ohOo00?ooooo0ol0oaH00ooooooo6_l0oa[o0008ooooo`03oh40oooooooooooo00gooooo00?o^03o
ooooooooool04_ooool3oil0o`Wooooo8_l0UOl3o`2?o`03o`2Eoooooooooooo00?ooooo1Omk0?o1
oooooaOoN`3oN?ooool001[ooooo00Go0000ooooooooooooo`2Gool0?002od@0o`0Oob`0oooo03co
o`1>oo@0oooo06goo`2`ohd0oonC0?oonP3oool0_?oo0>Koo`38ool0Uolb0?ooK`3oo`3Noooo0=Co
ooooool0l_l0^_oobP3oofWo0?ln0?oo0P3oo`3oGoooooooj03oogGo0?nb0?oo__l0okP0o`02oooo
o`06o`1goom@o`3oooooo`3of?ooooooP@3o0_ooool01?l0okCoooooooooooooool2ob00oaOooooo
00Wo803ooooooolJo`3oooooo`3o5_l0okCoooooo`2?oon10?l00oooool00onho`3o0?oHod[o0009
ooooo`03onSo0?m:o`3ooooo00;o^?l00_l0omP00oooooook_l0ooooo`03ooooo`;oD?l00_ooool0
0on10?ooooooohOo0005ooooo`05o`3o5_oooooooooooooooolJo`002_ooool00on10?oo803oob00
o`0:ob00o`Cooooo00?o^03oooooooooool04Oooool3o`2Eo`CoW`3o1Ol0UOl<ooooo`;o0?nd4Ooo
ool3o`2?o`Cooooo2_l0UOl5og/0oaSo09GoS?oooolHog/0ohoooooo000Jooooo`05o`000?oooooo
ooooool0Uooo03`00_l/0?l09_n1o`3oo`0lool0C_l80?ooo`1]o`3oj_n=0?ooT`3oool0_?oo0>Ko
2?l0ool0Uooooooo<P3oofl0oooo0=Coooooool0l_l0^_oo0?m0olX0ooln0?ooooooo`80ool0oeoo
j03oogGo0?oooooo/P3ooil0oonh0?ooooooo`1goom@o`3oooooonko0?l0omSoP@3o0_ooool01Ol0
okCooooooooooooooooo803o01[ooooo00Wo803ooooooolJo`3o0?lFohOo0?l0okCoooooo`2?oon1
0?l00oooool01?nho`3o0?oHod[o0?m:o`05ooooo`;oj?l000GoB_l0oooooonho`3oooooo`3of002
ooooo`03onko0?oooooooooo00;ooooo00OoD?l0oooooooooooooooooh40ooooooooQol000Gooooo
00?o0?lFooooooooool01_l0ok@00ooooooo803oob00o`05ob00o`03oh40oooooooooooo00Wooooo
1OlP0?l00onh0?ooooooooooo`0:ooooo`Ko09Go1oooool3oil0o`cooooo0_l0ok@@ooooo`?o08oo
5_ooool6og/0oa;ooooo5ol0UOmNoooooaOoN`3oYoooool001[ooooo02Go0000ooooooooooooo`2G
ool0??ooooooPOl0ool0??nI0?ooo`1>ool0KOoo0;3oS@3ooi<0oooj0?ooo`2lool0i_l8o`3oo`2G
oc80oom_0?oo0=koool0e?ooooooo`3bo`2jooo:0?oo01Kooch0ool0oa3o0P3oo`3oGooX0?ooMOl0
ok80oonO0?oo^03o00;ooooo00So07Oooooooooooooo0?oHo`2?oon10?ooooooo`3o]0;ooooo0_lP
0?lKooooo`0:ob00oooooooo6_l0ooooool0oaKo0?ndooooool0SoooP@3oonko00?ooooo00Go0?oH
onSo0?oXo`3oB_l0ooooo`03onSo0006oooooom:o`3o^?l0okSo0?oooooo0?oH0_ooool00oo^o`3o
ooooooooo`02ooooo`07oe3o0?oooooooooooooooon10?ooooooohOo0004ooooo`So08oo1?lP0?l0
0ol0okCoooooooooo`05ooooo`03oh40oooooooooooo00gooooo00Co803ookP0oolP0?oo803o0ooo
ool6o`2Eoa3ooooo0onO0?l7ooooo`;o0?nd3oooool3o`2?oaoooooo1_mk0?lSoooooaSo09Go=Ooo
oolAog/0okkooooo000Jooooo`05o`000?ooooooooooool0Uooo04h00_oo03`07OnI0?ooo`1>oo@0
oooo06go0?oZohd0oonC0?oonP3oool0_?oo0>Koo`38ool0Uolb0?ooK`3oo`3Noooo0=Coooooool0
l_l0^_oobP3ooch0oooooooo0P3oo`3oGooX0?ooMOl0oooooonb0?oo^03o00;ooooo00So07OookSo
0?oooooo0?oHo`2?oon10?ooooooo`3o]0;ooooo00?o803ooa[o0?l0oaH07?ooool02OlP0?oooooo
oa[o0?l0oaKoQol0o`3o]?oooooo08oooh40o`04ooooo`03o`3of?oooooooooo00GoB_l000Co^?l0
oooooooooooo0?oH0_ooool00oo^o`3oooooooooo`02ooooo`07oe3o0?oooooooooooooooon10?oo
ooooohOo0003ooooo`;o08oo0_l0ok@2oa[o00?ooooo00Co803ooooooooooooo08oo0_ooool00ol0
okCoooooooooo`05ooooo`03oh40oooooooooooo00kooooo00?o^03oo`2EoolP0?l01?lP0?lGoooo
o`?oW`3o0oooool00ol0okCoooooooooo`0=ooooo`;o08oo:?ooool8og/0oc?ooooo:Ol0UOl<og/0
oigooooo8onO0?l?ooooo`006_ooool01Ol0003ooooooooooooo0=Coo`1>00;oV@3o023oo`2Aool0
C_oo06goo`2`oonS0?n=0?ooT`3oool0_?oo0>Ko2?l0ool0Uooooooo<P3oofl0oooo0=Coooooool0
l_l0^_oobP3oo`0Fooln0?oo0?l@o`80oomk0?ooj03oogGo0?nb0?ooW`3ookP0oooooooo07OookSo
00;ooooo00Co08oooh40oooooooo0?nd0_ooool00olP0?oo6_l0o`3o5P0=ooooo`?o09Go1?mY0?l0
0ol0UOooooooooooo`06ooooo`0:ob00oooooooooooooa[o0?l0oaKo0?ndooooool0SoooP@3oonko
00Cooooo0_l0omP2ooooo`?o^?l00ol0omP2ooooo`03onko0?oooooooooo00;ooooo00OoD?l0oooo
oooooooooooooh40ooooooooQol000?ooooo00Go08ooooooool0okCooooooa[o0003ooooo`;o803o
0oooool01Ol0Sooooooooooooooooooo0?nd00Kooooo00?oP@3oooooooooool02_ooool4o`2Eo`03
oooooonh0?oooooo00Cooooo0olP0?lGooooo`?oW`3o3_ooool2o`2?oc;ooooo3omk0?lkoooooa;o
N`3o1_oooomdo`2EobooW`3o<_ooool001[ooooo0ol000008?oX0?ooo`1]ool0C_oo097oo`1>oo@0
oooo06go0?oZohd0oonC0?oonP3oool0_?oo0>Ko2?l0ool0UoooooooK`3oo`3Noooo0=Coooooool0
l_l0^_oobP3ooch0oooooooo0P3oo`3oGomk0?ooj03oogGo0?nb0?oo^03o0_ooool01Ol0Mooooooo
ooooool0SoooP@3o00;ooooo00Go0?ndoooooooooooo803oo`3o5P0;ooooo`03o`2EoomY0?ooJ@3o
00?oJ@3o0oooool5ofT0o`Kooooo00[o803ooooooooooooo0?lFohOo0?l0okCoooooo`2?oon10?oo
k_l01Oooool5o`3of0Cooooo00?ok_l0ooooooooool00_ooool01om@o`3oooooooooooooooooP@3o
oooooon7o`000_ooool2o`2?o`;o0?nd00?ooooooa[o0?ooool00olP0?l6ooooo`05o`2?oooooooo
ooooooooool0ok@01_ooool00on10?ooooooooooo`05ooooo`Co09Go1_ooool00onh0?oooooooooo
o`05ooooo`?o803o3?ooool9o`;o0004o`3o]?l2o`3oW`3ooil0o`[o0_l00_l0Sol@o`;o03?ooooo
>omk0?m>oooooi3o^03o3oooool001[ooooo02co0000ooooooooooooj03oool0KOod0?ooo`1>oo@0
ool80?ooo`1]oonS0?n=0?ooT`3oooX0oooo0;coo`3Vool0b?oo09Oo<P3oofl0ool0g_ooo`3Dool0
l_l0^_oobP3oo`0Fooln0?ooooooo`80oomk0?ooj03oogGo0?oooooo/P3ookP0oooooooo07OookSo
0?ooooook_l0o`2?oon10?ooooooo`3o]0;ooooo00?o803oo`3o5_ooool02Oooool3ofT0o`gooooo
00?oJ@3oooooooooool01?ooool02_lP0?oooooooa[o0?l0oaKo0?ndooooool0SoooP@3oooooooo^
o`0<ooooo`03onko0?oooooooooo00;ooooo00OoD?l0oooooooooooooooooh40ooooooooQol000;o
oooo00So08ooooooool0okCo0?lFoooooolJo`3oooooob00o`[ooooo00Go08oooooooooooooooooo
o`3o]005ooooo`03oh40oooooooooooo00Go09Go2oooool00onh0?ooooooooooo`07ooooo`?o803o
2Ol2o`001?oooooo00Coo`04ool01?l4ooooo`03o`3o]?oooooooooo00;ooooo0_nO0?l7o`3oY`03
o`2?ool0ojOo0?nW03Wo0?nWI?ooool_okP0oa3oW`3oSoooool001[ooooo02_o0000oooooooooooo
j03oool0Uooo06gom03oo`P0oooo06goo`2`oooooon=0?ooT`3oool0_?oo0>Ko2?l0ool0Uooooooo
<P3oofl0ool08_ooo`3Dool0l_l0^_oobP3oo`0Fooln0?oo0?l@og/0ooooooooj03oogGo0?nb0?oo
^03ooooooom@o`3o07Ooooooooo^o`3o08oooh40oooooooo0?nd00;ooooo00?o803ooa[o0?l0oaH0
2?ooool01?l0UOooJ@3oooooooooool3ofoo00GoG@3o00?oKol0ooooooooool01?ooool2ofT0o`Go
oooo00[o803oooooool0oaKoQol0o`3o]?oooooo08oooh40ooooooook_l02Oooool2onko00Cooooo
00OoD?l0oooooooooooooooooh40ooooooooQol000;ooooo00Ko08ooooooool0okCo0?lFoooooolJ
o`02ob00o`_ooooo00Go08ooooooooooooooooooo`3o]003ooooo`?o09Go00?oP@3oo`2Eooooool0
4?ooool01?nh0?ooooooooooooooool8o`04o`?o803o1ol01?l2ooooo`03o`3oYol01?oo00Co00Wo
00Co0_nO0?l6o`04obCooooo5ol2o`16o`3oY`;ooooo7?nh0?l@oooooaOoW`3oYoooool001[ooooo
02oo0000ooooooooooooJ@3oool0Uooo06go203oool0KOoo0;3o0?oZohd0oonC0?oonP3oool0_?oo
0>Ko2?l0ool0UoooooooK`3oo`3Noooo0=Coooooool0l_l0^_oobP3ooch0oooooooo0P3oog/0oooo
ooooj03ooooooonb0?oo^03oooooool0Mooo0?olonko0?n7o`3o08oooh40oooooooo0?ndoooooolP
0?oo6_l0o`3o5P08ooooo`;oJ@3o0om_o`04oed0o`Co00Co1OmM0?l4ooooo`03ofT0oooooooooooo
00;ooooo00So803ooooooolJo`3o0?lFo`3o]?oooooo08oooh40o`;ooooo00?ok_l0ooooooooool0
1Oooool00oo^o`3oooooooooo`03ooooo`07oe3o0?oooooooooooooooon10?ooooooohOo0003oooo
o`06o`2?ool0okCoooooo`3o5_lJo`3o803o3_ooool00ol0Soooooooooooo`04o`2Eo`?ooooo00?o
P@3oooooooooool03?ooool5o`04o`;o^03o00?o00Coo`;o0?l2o`001oooool2o`3oY`Co803o1Ol0
ojL4ooooo`03o`3o]?oooooooooo00Oooooo0onO0?l00ol0Soooooooooooo`09o`04oc?ooooo4Ol2
o`0Toooooa;o^03o5?l0ojLHoil0oego0?nWHOooool001[ooooo02ko0000ooooooooooooooooool0
Uon=0?ooo`1]ool0/?l0on[oS@3ooooooonC0?oonP3oool0_?oo0>Koa?l0ool0Uolb0?ooK`3oo`3N
oooo0=Coo`3bo`2jooo:0?oo01Kooch0ooooooooN`3ooooooooX0?ooMOl0ok80oonh0?oooooooe3o
0?l0Moooooooonko0?l0SoooP@3oooooool0okCoooooob00oolJo`3o0?lF2?ooool01?mY0?ooKol0
ofoo0?ooool2oed0o`04o`04ool2o`3o0_l0o`;o00;ooooo1?l2o`03o`04o`03oed0oooooooooooo
00;ooooo00?oJ@3oooooooooool00_ooool02OlP0?oo6_l0o`3o5_oooooo0?ndooooool0SoooP@3o
ooooo`02onko00Cooooo0_o^o`05ooooo`07oe3o0?oooooooooooooooon10?ooooooohOo0003oooo
o`06o`2?ool0okCoooooo`3o5_lJo`3o803o3oooool01Ol0Sooo09Goo`2Eoooooooo0?nd00Gooooo
00?oP@3oooooooooool01oooool5o`04o`Co0_l00oooool00onh0?ooooooooooo`03ooooo`Co0?nW
1_ooool4ob00o`Cooooo00?o0?ndooooooooool02_ooool01?l0SoooW`3ooil0oonO0?l9ooooo`So
00Co??ooool;o`;o00gooooo3?nh0?lEoooooa7oW`3oMOoooomBo`3oY`oooooo000Jooooo`06o`00
0?oooooooooooooooooo09OonP3o0_l0onX07oooX`3oS@3ooooooonC0?ooo`2lool0i_l8o`3oo`38
ool0Uolb0?ooK`3ooi?o0?oo0=Coo`3bo`2jooo:0?oo?P3oooooool20?ooN`3ooooooooX0?oooooo
ok80oonh0?oooooooe3o0?l0Moook_l0ohOo0?n10?l00_ooool01?l0okCo803oooooool0oaH7oooo
o`03o`2EoomY0?ooKol000?oG@3o3Oooool2o`;o0003o`04oomM0?ooG@3o00;ooooo00?o09GoofT0
ooooool00oooool01olP0?oo6_l0o`3o5_l0okCoooooo`2?oon10?l00oooool4onko00Kooooo00Oo
D?l0oooooooooooooooooh40ooooooooQol000?ooooo00Ko08ooo`3o]?oooooo0?lFoa[o0?lP0?l?
ooooo`03o`2Eoooooooo08oo00?ooooo00?o0?ndooooooooool00oooool01?n10?oooooooooooooo
ool5o`04o`Co0_l02Oooool3okP0o`;o0?nW3_ooool3ob00o`03o`3o]?oooooooooo00[ooooo00?o
08ooooooooooool00_ooool2oil0o`oooooo1Ol01?m2ooooo`?o0_l02_nh0?l5o`;o017ooooo2onO
0?oWooooo`006_ooool0;Ol0003oooooooooooooooooo`2GooX0oon=0?oooj<0oooooon=0?ooT`3o
ooX0oooo0;coo`3Vo`So0?oo09Ooooooofl0ool0g_oo02;oool0e?oo0?;obP3oo`0Fooln0?oooooo
o`80oomk0?ooM@3oonP0oooooooo^03ooooooom@o`3o07Ooo`3oo?n7o`3o08oooh40oooooooo0?nd
ob00oooooooo6_l0o`3o5P06ooooo`04o`2EoomY0?ooG@3ooed0o`;o00Co4Oooool00ol2o`3o00Co
oed0o`02ooooo`03o`2EoomY0?oooooo00;ooooo00So803ooa[o0?l0oaKoooooo`3o]?oooooo08oo
oh40o`_ooooo00OoD?l0oooooooooooooooooh40ooooooooQol000?ooooo00Ko08ooo`3o]?oooooo
0?lFoa[o0?lP0?l>ooooo`;o09Go0_ooool01Ol0Sooooooooooooooooooo0?nd00Gooooo00CoP@3o
o`04ool01?oo00Co1?l2o`0;ooooo`Go0?nW00CooooookP0oonh0?oo^03o3oooool01?l0okCo803o
ob00oolP0?l9ooooo`03o`2?oooooooooooo00Gooooo0_nO0?lBooooo`Oo00Co=_ooool8okP0o`oo
oooo1Ol2o`0<oil0o`Ko0_l0k?ooool001[ooooo00Ko0000ooooooooooooooooool0Uooo0;`3ohd0
o`0Soi<0ool07?oonP3oool0_?oo0>Koa?l0ool0UoooooooK`3oo`3Noooo0=Coo`3bo`2jooo:0?oo
?P3ooaCo0?l0oa3oN`3ooooooooX0?ooMOl0ok80oonh0?oooooooe3o0?l0Moook_l0o`2?oon10?oo
ooooo`3o]?lP0?oooooooa[o0?l0oaH01Oooool01?m_o`3o09GoofT0oomM0?l2o`04oaCooooo00?o
0_l0o`04oomM0?l00_ooool03?mY0?oooooooooooooooooo803ooa[o0?oooooo0?lFo`3o]?oooooo
08oooh40o`[ooooo00OoD?l0oooooooooooooooooh40ooooooooQol000?ooooo00Ko08ooo`3o]?oo
oooo0?lFoooooolP0?l=ooooo`;o09Go1Oooool01Ol0Sooooooook;o0?nbo`3o0?nd00Co00Co00Co
Kol0oh40ool2o`3o0_l02_m_o`05o`3oY`WoKol02onh0?l3ooooo`03o`3o]?oooooooooo00;ooooo
0_lP0?l6ooooo`03o`2?oooooooooooo00Sooooo0_nO0?lGooooo`So00Co9oooool7okP0oa7ooooo
2onO0?lBoooooa7o0_l0I?n10?mgooooo`006_ooool01ol0003oooooooooooooooooo`2Gool0_?oj
0?l00_ooool08_nC0?oonP3oool0_?oo0>Ko2?l0ool0n?oo09OoK`3oo`3NoonCo`3oo`3Dool0l_l0
^_oobP3ooch0oooooooo0P3oog/0ooooooooj03ooooooonb0?oo^03ooe3o0?l0Mooo0?olohOo0?l0
SoooP@3oooooool0okCo803ooa[o0?l0oaH5ooooo`04ofoo0?l0UOooJ@3ooed0oaSooooo00?o0_l0
oed0ooooool00_ooool03?mY0?oooooooooooooooooo803ooa[o0?l0oaKoooooo`3o]?l0SoooD?l0
oh40o`Sooooo00OoD?l0oooooooooooooooooh40ooooooooQol000;ooooo0_l0Sol01_l0okCooooo
o`3o5_oooooo6_l0ob00o`_ooooo0_l0UOl4ooooo`?o/_l000?o08ooofoo0?l01?l00_l01?l2ofoo
00?o0_l000CoP@3ooooooooooooooooo1Onbo`04o`3oY`oooooo2_m_o`0;okP0o`;o803o0_ooool0
0ol0Soooooooooooo`0;ooooo`03oil0oooooooooooo01cooooo1ol01?lIooooo`Oo^03o3_ooool:
oil0oaKooooo6?n10?l6oooooaSo0_l0A_oooomMoh40oa[ooooo000Jooooo`0Zo`000?oooooooooo
oooooooo0=Coo`2GooX0ooooooooooP0ooX0oonUo`3oo`2lool0i_l8o`3oo`38ool0Uom_0?oo0=ko
oooooooo0=Coo`3bolX0ool05_oo?P3ooooooomk0?oo0?mOogD0oooX0?oooooookP0ooooooooD?l0
o`1goooooooo08oooh40oooooooo0?ndob00oooooooo0?lF1?ooool2ofoo0003o`2EoomY0?ooG@3o
00_ooooo2_l0ojL5ooooo`05o`;o0?mM0?oooooooooooomY0?l00oooool02OlP0?oo6_l0o`3o5_n7
o`3o0?ndooooool0SoooP@3ooe3o0005ooooo`;oD?l00oooool00on10?ooooooohOo0002ooooo`08
o`2?oooooooo0?ndooooool0oaKooooooa[o0?lP0?l;ooooo`03o`2Eoooooooooooo00;o/_l01?m_
o`03o`04o`;ooooo00?o0?ndo`;o0?l2o`000oooool00on10?ooooooooooo`03ooooo`?o0?nW0ooo
ool3ok;o01Wooooo00?o0?ndooooooooool01_ooool4okP0o`KoKol02Oooool2oil0ob?ooooo2?l0
1?l:ooooo`Oo^03o3Oooool8oil0o`[ooooo5_n10?lfoooooaOo0_l0S?ooool;oh40o`oooooo000J
ooooo`0Zo`000?oooooooooooooooooX0?ooo`2Gool0_?nC0?oonP3oojGo0?ooooooo`2lool0i_l8
o`3oo`2Goooooom_0?oo0=koo`0Roooo0=Coo`3bolX0ooln0?oo5?l0o`3o4?mk0?ooooooonP0oome
o`3o/P3ookP0oom@o`3o^?l0o`1goon7o`3o08oooh40ool0okCo803ooooooolJo`3o0?lF0oooool0
1Om_o`3o/_l0o`2EoomY0?oo00Co00[ooooo0_l0ojL:ooooo`?o0?nW0oooool01OmM0?oo00Cooooo
oomY0?oo09Go00;ooooo00Wo803ooa[o0?oooooo0?lFooooool0okCo08oooooooon10?l01Om@o`04
ooooo`03oh40ooooooooQol000;ooooo00So08oooooooooooooo0?ndooooool0oaKo6_l0ob00o`_o
oooo00Co09Gooooooonbo`3o/_l00_m_o`03ooooo`04o`04ooooooooooooo`2?o`;o0_l000?ooooo
o`3o]?ooool01?ooool00on10?oo0?nWo`3oY`02o`3oY`Wooooo1?nbo`0Dooooo`03o`3o]?oooooo
oooo00Wooooo00?o08oooooooonh0?l00onh0?l2ooooo`WoKol00_ooool2oil0obWooooo1?l01?l6
okP0o`cooooo2?nO0?l9ooooo`WoP@3oHooooolGo`;o08oooooo000Jooooo`07o`000?oooooooooo
oooooooX0?ooo`2Gool0_002ooX0o`0Poooooooo0;coo`3Vo`So0?oo0?Soo`2Gofl0ool0g_ooTol0
ool0e?oo0?;o0;[oolX0ooln0?ooooooo`80oomk0?ooooooonP0oooooooo/P3ookP0oooooooo07Oo
o`3oo?l0SoooP@3oooooool0okCo803oooooool0oaH3ooooo`05ofoo0?nbo`3oooooofT0ool01?l0
2Oooool2o`3oY`oooooo00Go0?nWoooooooooooo0_l0oed0o`02ooooo`0=ofT0oooooooooooooooo
oolP0?oo6_l0o`3o5_n7o`3o0?ndooooool0Sooooooooh40o`05ooooo`?oP@3o00GoooooohOo0?oo
ooooooooo`2?o`02ooooo`05o`3o]?oooooo0?lFoooooolP0?l03?ooool01?l0UOoo/_l0oooooom_
o`03ooooo`03o`04oomM0?ooG@3o00;oG@3o00Ko08ooooooooooooooooooo`3o]?ooool4o`3oY`03
oh40oooooooooooo00oooooo2Onbo`0:ooooo`03o`3o]?oooooooooo00Wooooo00?o08oooooooooo
ool00_ooool2ob00o`;o^03o2Oooool4ofoo00?oW`3o00?oKol0ooooooooool08_ooool5okP0o`Co
oooo1Ol01?l9oil0o`[ooooo1on10?n3oooooaSo0_l000?ooooooeOo0?mGo`00IOmGo`0?ooooo`00
6_ooool01ol0003oooooooooooooooooj03oool0Uooo0;`00_l0A_l08?ooooooo`2lool0i_l8o`3o
o`3hool0Uom_0?oo0=kooooooooo0=Coo`3bolX0ool05_oo?P3ooooooomk0?oo0?mOogD0oooX0?oo
oooookP0oom@o`3oooooo`1goon7o`3o08oooh40ool0okCo803ooooooolJo`3o0?lF0oooool01?m_
o`3oooooo`2EoomY0?l9ooooo`03o`3oYooooooooooo00oooooo00Wo0?nWooooooooooooooooo`;o
0?mM0?ooooooo`2EoomY0?l00_ooool01olP0?oo6_l0ooooool0oaKo0?ndooooool0Sol00_ooool6
oh40o`;ooooo00CoQol0oooooooooooo08oo0_ooool01_l0okCoooooo`3o5_oooooo6_l0ob00o`_o
oooo00Go09Gooooooom_o`3oKol0ooooo`04oed0o`;o0_l00_ooool3oed0o`;o0?nW00?o0?ndoooo
ooooool00_ooool00on10?ooooooooooo`0Hooooo`Wo/_l000?o0?ndok;o0?nbo`001onbo`03oooo
o`03o`2?oooooooooooo00Cooooo0_lP0?l2okP0o`kooooo0onO0?l4ofoo01Sooooo1_nh0?l3oooo
o`_oW`3o0_ooool8o`04o`03oooooon10?ooP@3o00KoP@3oGOoooom5oeOo01Ko0_l0HOooool001[o
oooo00Oo0000ooooooooooooooooonP0oooo09Ooo`2l00;ooooo01ooo`2lojco0?oo0>Ko2?l0ool0
UoooooooK`3oo`3Nool08_ooo`3Dool0l_o:0?oo?P3ooaCo0?l20?ooN`3ooooooooX0?ooMOl0ok80
oonh0?oooooookSo0?l0Mooo08ooo`3of?n10?oo0?ndob00oooooooo0?lF00?ooooo00GoKol0ok;o
0?l0UOooJ@3oo`04o`07ooooo`;o0?nW1oooool5o`0do`Oooooo0_l0ojL01_oooooo0_l0oed0oonb
o`3oooooofT0o`;ooooo00Oo803ooa[o0?oooooo0?lFohOo0?l0okCo08oo00Wooooo00CoQol0oooo
oooooooo08oo0_ooool01_l0okCoooooo`3o5_oooooo6_l0ob00o`_ooooo00Co09Goofoo0?m_o`3o
oooo0_mM0?l00ooooooo0_l0o`;o0005ooooo`03o`2?ool0ojOo0?nW00;oG@3o00?o0?ndoooooooo
ool00oooool00on10?ooooooooooo`0Oooooo`03o`3o]?oooooooooo00Sooooo0_nbo`000ol0Sooo
/_l0ok;o0008ok;o0003ob00oonh0?oo^03o00;o^03o3Oooool6oil0o`CoKol03?ooool6okP0o`Wo
W`3o3Oooool9oh40o`Oo00CoA_oooolHoeOo05_ooooo5ol2o`1:ooooo`006_ooool01ol0003ooooo
ooooooooooooJ@3oool0Uooo0>H00_oo0;`07oooooooo`3Vo`So0?lbo`3oo`2Gofl0oolb0?ooTol0
o`0Roooo0=Coo`3bolX0ooln0?oo5?l0og/0ool0oeooooooonP0oooooooo^03ooe3o0?oooooo07Oo
o`3oo?l0SoooP@3oo`3o]?lP0?oooooooa[o0?l0oaH00_ooool01Om_o`3o/_l0o`2EoomY0?oo00Co
00Oooooo00?o0?nWooooooooool00oooool4o`0do`Cooooo1?l0=?l6ooooo`06o`3oYooooooo0_l0
oed0ooooooooJ@3o0oooool01olP0?oo6_l0o`3o5_n7o`3o0?ndooooool0Sol01oooool01?n7o`3o
ooooooooool0Sol2ooooo`06o`3o]?oooooo0?lFoooooolJo`3o803o2oooool02?l0UOooKol0oooo
ooooooooG@3oo`04oooooooo0_l01?ooool3o`3oY`03ooooool0Sooooooo00;ooooo00?oG@3oo`3o
]?ooool00oooool00on10?ooooooooooo`0Oooooo`03o`3o]?oooooooooo00Wooooo00?o08oooooo
ooooool02_ooool01?nbo`3o803oob00oonbo`05okP0o`kooooo2_nO0?l6okP0o`KoW`3o4?ooool6
oh40oa3ooooo1ol01?lXoooooaOoEol0R_oooolGo`;o03?ooooo0002ooooo`;o00001?ooool01?l0
003oooooooooooooool5o`0000Wooooo00?o0000ooooooooool00_ooool07ooo09OoK`3oool0i_nI
o`3oo`3Vo`3oXOl8o`3oo`3hool0Uom_0?oo0=kooooooooo0=Coo`3bolX0ool05_oo?P3ooooooomk
0?oo0?mOogD0oooX0?oooooookP0oooooooo^?l0o`1goon7o`3o08oooh40oolP0?l00_ooool02?lJ
o`3o0?lFoooooom_o`3o/_l0oooooomM0?ooJ@3o1oooool01?l0ojOoooooooooooooool3o`0do`?o
oooo1_l0od`3ooooo`;o03Co1?ooool01ol0ojOoooooooooool01?ooG@3ooooooomY0?l00_ooool0
2?lP0?oo6_l0ooooool0oaKoQol0o`3o]?oooooo08oo1_ooool00on7o`3oooooo`2?o`02ooooo`06
o`3o]?ooooooooooo`3o5_oooooo803o2oooool00ol0UOooKol0ooooo`02oed0o`03o`04ool2o`3o
J@3o00?oJ@3o00?oooooo`3oYoooool00oooool00ol0Soooooooooooo`02ooooo`03oed0oooooooo
oooo00;ooooo00?oP@3oooooooooool07_ooool00ol0okCoooooooooo`09ooooo`03o`2?oooooooo
oooo00kooooo0_lP0?l01?oooooo/_l0ok;o0?nbo`03okP0oa7ooooo1?nh0?l7ofoo013ooooo1On1
0?lMooooo`[o00Co1_oooolHoeOo05coooooP?l0od`?ooooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool08_oo09Ooo`3h
oooooooo0>Ko0?nQolCo0?l8o`3oo`3hool0Uolb0?oo0=kooooooooo0=Coo`3bolX0ooln0?oo5?l0
o`80oomk0?ooooooonP0oomeo`3o/P3ookP0oooooooo^?l0o`1gool0SoooP@3ooooooolP0?oooooo
oa[o0?l0oaH2ooooo`04ofoo0?oooooo09GoofT0o`Oooooo00Go0?nWooooooooooooooooo`0do`02
ooooo`Co0?m<1_ooool3o`3oC0;ooooo00?o03Coooooooooool00_ooool01_l0ojOoooooo`04oomM
0?ooooooofT0o`;ooooo00Ko803ooa[o0?oooooo0?lFooooool0ok@2ooooo`03o`2?oooooooooooo
00;ooooo00?oQol0o`2?ool0Sol00_ooool01ol0okCoooooooooool0oaKooooooa[o0?lP0?l02_oo
ool01_l0UOooKol0oooooomM0?ooooooo`04o`;oJ@3o0oooool00ol0ojOoJ@3oofT0o`04ooooo`03
o`2?oooooooooooo00;ooooo00?o0?ndoed0ooooool00oooool00on10?ooooooooooo`0Looooo`03
o`3o]?oooooooooo00[ooooo00?o08ooooooooooool01Oooool;o`3oV`03ob00ool0oi_o0?nK00Co
0?nK4Onh0?lGo`3oV`CoP@3o1?l0oi/Goooooa7oEol02ol01?lYooooodKo0?m<M?ooool<o`;o00oo
oooo00001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`0Gool0e?oo09Oo0?nQo`3oXOo4o`3o2?l0oc;o0?oo09OoK`3ooc80oonCo`3o
02;oool0e?oo0?;obP3ooch0oolDo`3oN`3oo`3oGoooooooj03ooooooonh0?l00_ooool01Ol0Mooo
0?olo`2?oon10?oo803o00;ooooo00So6_l0o`3o5_ooooooKol0ok;o0?l2o`3oG@3oofT0o`Kooooo
00Ko0?nWooooooooooooooooo`0dooooool2o`3oC0gooooo0_l0od`00ooooooo03Coooooo`02oooo
o`06o`3oYooooooo0_l0oed0ooooooooJ@3o0oooool00olP0?oo6_l0o`3o5P02ooooo`03o`3o]?n7
o`3ooooo00Go08oo0oooool01ol0okCoooooooooool0oaKooooooa[o0?lP0?l02_ooool01Om_o`3o
09GooooooomM0?oooooo00;oJ@3o1?ooool01Ol0ojOoooooooooooooooooJ@3o00Cooooo00?o08oo
ooooooooool00_ooool00omM0?ooooooooooo`02ooooo`03oh40oooooooooooo01_ooooo00?o0?nd
ooooooooool01_ooool01Ol0of_o0?nKo`3oVol0oi_o08oo00So0?nK0_l0of/:ooooo`;o803o1_oo
oolFo`3oJ`[ooooo0_m_o`04oh40o`?oKol01Oooool]o`3oV`Kooooo3?l01?l6oooooaOo0?m<eOoo
ool00005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`08ooooo`Co000000Co
ooooool0e?oo09Oooooo0_o4o`008_l8o`3oo`3hool0Uolb0?oo0=koooooool08_ooo`3DolX0ool0
5_oo?P3ooaCo0?mk0?oo0?mOogD0oooX0?ooB_l0okP0oooooooo^?l0o`1gooo^o`3o08oooh40oolP
0?oooooooa[o0?l0oaKoooooofoo0?nbo`3o0_l0oed0oomY0?l6ooooo`05o`3oYooooooooooooooo
ool0=?l00_l0od`=ob3o00Cooooo00?o0?m<ooooool0=?l00oooool01_l0ojOoooooo`04oomM0?oo
J@3oo`2Eo`;ooooo00Co803ooa[o0?oooooo0?lF0_ooool01?l0okCoQol0ohOo0?n7o`05ooooo`04
o`3o]?ooooooooooo`3o5P;ooooo00?o803oooooooooool02?ooool01om_o`3o09GooooooomM0?oo
ooooofT0ool2o`001?ooool00ol0ojOoooooooooo`02ooooo`03ofT0oooooooooooo00;ooooo00?o
08ooooooooooool00_ooool00ol0okCoG@3oooooo`02ooooo`03oh40oooooooooooo01_ooooo00Co
0?ndo`3oJol0of_o0?m[1_l0oi/2ooooo`03o`2?oooooooooooo01Gooooo00?o803oooooooooool0
3?ooool6ok;o00Oooooo2?l0of/4oh40o`co0?m[1_mGo`0Qooooo`Ko0?m<4_l0oi/<o`04oa7o0?nK
X_oooolTo`04o`oooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00;ooooo01goo`3Dool0Uoooooooooooo`So0?lbo`3o
o`3hool0Uolb0?oo0=kooooooooo0=Coo`3bolX0ooln0?oo5?l0og/0ool0oeooooooonP0oomeo`3o
/P3ookP0ooooooooQol0o`1gool0SoooP@3oob00o`02ooooo`07oa[o0?l0oaKoKol0ok;o0?oooooo
G@3oofT0o`07ooooo`05o`3oYoooooooEol0o`0dool0od`00_lPo`08ooooo`;o0?o`0oooool00olP
o`3oooooooooo`02ooooo`03o`3oC?oooooo03Co00;ooooo00Ko0?nWooooool2o`3oG@3ooooooomY
0?l2ooooo`04ob00oolJo`3oooooo`3o5P;ooooo00?o0?ndooooooooool01Oooool01ol0okCooooo
oooooooooooo0?lFoooooolP0?l02_ooool01onbo`3o09GooooooomM0?ooooooofT0ool2o`001?oo
ool00ol0ojOoooooooooo`04ooooo`05ofT0ooooooooooooooooool0Sol01?ooool00ol0okCooooo
oed0o`03ooooo`03oh40oooooooooooo01Kooooo0_l0of/00ol0oi_o0?ndo`3oV`03o`3oV`Oooooo
00?o08ooooooooooool05oooool00olP0?ooooooooooo`0Aooooo`Ko/_l01_ooool3oh40o`Oooooo
1OmGo`04oooooaOo0?m[1?ooool<o`3oC1goooooGomY0?l/oooooboo00Co<oooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool00_ooool09_oX0?ooo`2Gofl0ool8o`3o<_l0oonM0?oo0?Soo`2Goc80oonCo`3o02;oool0e?oo
0?;obP3ooch0oolDo`3oN`3oo`3oGoooooooj03ood[o0?nh0?oooooookSo0?l0Mooo0?olo`2?oon1
0?oo803ooooooolJo`3o0?lFoooooom_o`3oooooo`;o0?mM0?ooJ@3o1_ooool01Ol0ojOooooooeOo
0?l0=?oo0?m<00Kooooo1Ol0oo000ooooooo0?o`o`3ol003o`3ol0;o8?l00oooool02_l0odcoEol0
o`0doooooooo0?nWooooool2o`3oG@3ooooooomY0?l3ooooo`04ob00oolJo`3oooooo`3o5P;ooooo
0_l0ok@3ooooo`;o0?nd0oooool01?l0oaKooooooa[o0?lP0?l9ooooo`07ok;o0?l0UOoooooooed0
ooooooooJ@3oo`04o`04ooooo`03o`3oYooooooooooo00Gooooo00GoJ@3oooooooooooooooooo`2?
o`05ooooo`03o`3o]?ooooooG@3o00;ooooo00?oP@3oooooooooool04Oooool4o`3oJ`?o0?nK00?o
ooooo`3o]?ooool02_lPo`000ol0Sooo8?l0ob3o0005ob3o01?ooooo0_lP0?lGooooo`?o/_l00on1
0?l00onbo`3oEol0oeOo0007oeOo01Sooooo2?l0od`Bo`3oJa_oJ@3o0_l0of/Nooooocoo00Co;_mY
0?m5o`3oVa_ooooo0002ooooo`;o00002Oooool3o`0000[ooooo00?o0000ooooooooool00_ooool0
9OoX0?ooo`2Gofl0ooooU`3o<_l0ool0n?oo09Oo<P3oo`3Noooooooo02;oool0e?oo0?;o01Kooch0
oolDo`3oN`3oo`3oGome0?ooj03ood[o0?nh0?ooooooohOo0?l0Moook_l0o`2?oon10?oo803ooooo
oolJo`3o0?lFofoo0?nbo`3o0_l0oed0oomY0?l01_ooool01Ol0ojOooooooeOo0?l0=?oo0?m<00Co
oooo0ol0oo0;ooooo`03o`3ol?oooooo8?l000?ooooo00[o0?m<o`0dooooooooooooo`3oYooooooo
G@3oo`04oomY0?oo09Go0_ooool01?lP0?oooooooa[o0?l0oaH3ooooo`Co0?nd1?ooool01?l0oaKo
oooooooooolP0?l9ooooo`08ok;o0?m_o`3o09Gooed0ooooooooJ@3oo`04ool2o`03ooooo`03o`3o
Yooooooooooo00Oooooo00CoJ@3ooooooooooooo08oo1Oooool00ol0okCooooooed0o`02ooooo`03
oh40oooooooooooo00cooooo0_lPo`03o`3oJ`04ob3o0?l0oi_o0?nKo`3oV`?o8?l000?o0?ndob3o
0?lPo`002Oooool5o`1mo`Cooooo3OlPo`08ooooo`03ob00oooooooooooo01;ooooo00?oEol0oh40
oon10?l00_n10?l4oeOo00;ooooo4onbo`0<o`3oC0kooooo0om_o`09ofT0oagooooo5_l0of]eoooo
odGoJ@3o3?l0oi/?ooooo`006_ooool00ol0003oooooooooo`02ooooo`03onP0oooo09Ooo`3h00;o
o`3h023oK`3oool0Uolb0?oo0=kooooooooo0=Coo`3bolX0ooln0?ooooooog/0ool0oa3o0?mOonP0
oomeo`3o/P3ookP0ooooooooQol0o`1gool0SoooP@3oob00oooooooo6_l0ooooool0oaKo/_l0oooo
oomM0?ooJ@3oo`04o`Gooooo00Go0?nWoooooooooooo03Coo`3oC004ooooo`03o`3ol?oooooooooo
00;ooooo1omG0?l4ooooo`;o0?o`00Ko8?l0oooooooooooo0?m<oeOo0?l0=?l2ooooo`05o`3oYol2
o`3oG@3oofT0ool0UOl00oooool01?lP0?oo6_l0ooooool0oaH9ooooo`04o`3o5_ooooooooooob00
o`Wooooo00So/_l0ofoo0?l0UOooG@3ooooooomY0?oo00Coo`;o00Cooooo00?o0?nWooooooooool0
2?ooool01?mY0?ooooooooooool0Sol4ooooo`04o`3o]?oooooooooooed0o`;ooooo00?oP@3ooooo
ooooool00oooool7ob3o00?o0?m[00Coooooo`3oVol0oi_o0?nK0oooool?o`1mo`04o`2?oooooooo
ooooooooo`ko07go1?ooool5ob3o00Cooooo0_lP0?l>ooooo`;oEol00on10?lDooooo`Wo0?m<1?oo
ool<ok;o00Oooooo1_mY0?l9ooooo`coKol09ooooolGo`3oJakoooooQOl0oo0<ofT0o`oooooo000J
ooooo`03o`000?oooooooooo00;ooooo00?oj03oool0Uoooool00_ooool07oo40?ooo`2Goc80oooo
ooooolP0ool0e?oo0?;obP3ooch0oolDo`3oN`3oo`3oGoooooooj03ood[o0?nh0?ooooooohOo0?l0
Mooo0?olo`2?oon10?oo803ooooooolJo`3o0?lFofoo0?oooooo0_l0oed0oomY0?l01_ooool01?l0
ojOoooooo`0dool0od`3ooooo`;o0?o`00?ooooooeL0oomG0?l00_mG0?l7o`1mo`?oE`3o0oooool0
1_l0oo3o8?l0oooooooooooo0?m<o`0do`;ooooo00Go0?nWoooooomM0?ooooooofT0o`03ooooo`03
ob00oooooooo6_l000;o0?lF2?ooool00ol0oaKoooooob00o`0:ooooo`07ok;o0?l0UOooG@3ooooo
oomY0?oo00Coo`;o0004ooooo`03o`3oYooooooooooo00Wooooo00CoJ@3ooooooooooooo08oo1Ooo
ool01_l0okCooooooooooomM0?oooooooh40o`Go8?l01?ooool3o`3oJ`04ooooool0oi_o0?nKo`3o
V`;ooooo1?l0OOl2ooooo`03o`3o]?oooooooooo00Wooooo00?o08ooooooooooool04?ooool<o`1m
o`?o8?l000?o803oooooooooool02?ooool2oeOo00?oP@3o4_ooool5o`3oC1Oooooo2OmY0?lKok;o
00SoKol0E?l0oo2Pooooo`006_ooool00ol0003oooooooooo`02ooooo`0SonP0oooo09Ooa03ooooo
ooo40?ooo`2Goc80oonCo`3oooooo`0Roooo0=Coo`3bo`2jooln0?oo5?l0og/0ool0oeooM@3oonP0
oom:o`3o^03ooooooon7o`3o07Ooonko0?n10?oo803oo`3o]?oooooo6_l0o`3o5_oooooo0_l0oed0
oomY0?l01_ooool01?l0ojOoooooo`0dool0od`3ooooo`04o`3ol?oooooooooooeL0o`?o07go1?l0
of/3ooooo`?o0?m[00?o07gooeL0ooooool00_ooool03?l0oo3oooooooooool0odco03CooeOo0?oo
oooo0?nWoooooomM0?oo00CoofT0o`?ooooo00Go803ooooooolJo`3oooooo`3o5P06ooooo`;o0?lF
00?ooooooa[o0?lP0?l02Oooool01onbo`3o09GooooooomM0?ooooooofT0ool01?l01?ooool00ol0
ojOoooooooooo`0;ooooo`03ofT0oooooooo08oo00Gooooo00Ko0?ndoooooolPo`3oG@3oob3o0?n1
0?l7ooooo`;o0?m[00Coooooo`3oVol0oi_o0?nK1Ol0OOl6ooooo`03o`3o]?oooooooooo00Sooooo
00?o08ooooooooooool07Oooool4o`1mo`03ob00oolPo`3o8?l000;o8?l000CooooooeOo0?mGo`3o
Eol00on10?l?ooooo`Ko0?m<4oooool9ofT0oaGooooo5ol0oo04ooooo`_oKol0?_nbo`0_o`3oJgSo
oooo000Jooooo`03o`000?oooooooooo00;ooooo00Oo^03oool0e?oo09Ooa03oool0b?oo09Oo<P3o
00;ooooo01[o02;oool0e?o:0?oo?P3ooooooomk0?oo0?l@o`3oGooX0?ooB_l0oil0oonh0?oooooo
ohOo0?l0Mooo08oooh40oolP0?oooooooa[o0?l0oaKo/_l0ooooool2o`3oG@3oofT0o`Gooooo00Co
0?nWooooool0=?oo0?m<0oooool01Ol0oo3ooooooooooomG0?oo07go00?o0?m[0_ooool8o`3oV`;o
0?m[0_mG0?l2ooooo`05o`3ol?ooooooooooo`3oC?l0=?l00_ooool01Ol0ojOo0_l0oed0oomY0?oo
09Go00?ooooo00Co803ooooooolJo`3ooooo0_l0oaH2ooooo`;o0?lF0_ooool00olJo`3o803ooooo
o`08ooooo`08ok;o0?m_o`3o09Gooed0ooooooooJ@3oo`04ool2o`03ooooo`03o`3oYooooooooooo
00cooooo00?oJ@3oooooool0Sol01?ooool00olPo`3o0?ndob3o0002ooooo`03oed0ooooooooP@3o
00Cooooo0_l0of/00ooooooo0?nKo`1mo`03o`1mo`_ooooo00?o0?ndooooooooool02?ooool00ol0
Soooooooooooo`0Qooooo`04o`1moolP0?oo803oo`1mo`GoP@3o0_lPo`0;ooooo`Go0?m<5?ooool5
ofT0o`oooooo3ol0oo0Voooooa7oKol0AooooolEok;o02ko0?m[B_ooool001[ooooo00?o0000oooo
ooooool00_ooool00ol0Moooo`3Doc80o`02ool0U`0Moooooolb0?ooooooooo80?oo0=Coo`3bolX0
ooln0?oo5?l0og/0ool0oeooooooonP0oom:o`3o^03ooooooon7o`3o07Ooo`3oo?l0SoooP@3oob00
oooooooo6_l0o`3o5_oooooo0_l0oed0oomY0?l01_ooool00ol0ojOo8?l0o`0do`03ooooo`04o`3o
l?oooooooooooeL0o`;o0?m[0oooool2o`3oV`Oooooo0ol0oi/00ol0of_o07gooeL0o`02ooooo`0;
o`3ol?ooooooooooo`3oC?l0=?ooooooo`3oYol2o`3oG@3ooooooomY0?l00oooool01?lP0?oooooo
oooooolJo`02ooooo`?o0?lF0_ooool00olJo`3o803oooooo`09ooooo`07ok;o0?l0UOooG@3ooooo
oomY0?oo00Coo`;o0004ooooo`03o`3oYooooooooooo00cooooo00CoJ@3oooooool0Sooooooo0olP
o`02ooooo`07o`3o]?oooooooooooed0ooooooooP@3oooooo`03o`3oJ`04o`3oVol0OOoo07goo`1m
o`kooooo00?o0?ndooooooooool02?ooool00ol0Soooooooooooo`0Pooooo`;oEol01?n10?l4o`1m
o`?ooooo1_lPo`000ooooooo0?m<o`3oC002o`3oC1Cooooo1OmY0?l;ooooo`Wo0?o`A_oooolAofoo
06Cooooo5Onbo`0_o`3oJa_ooooo000Jooooo`03o`000?oooooooooo00?ooooo027oo`3DolX0ool0
g_oo0=kooc80ooook03oooooo`0Roooo0=Coo`3bo`2jooln0?ooN`3oo`80ool0oeooM@3oonP0oom:
o`3o^03ooooooon7o`3o07Ooonko0?n10?oo803ooooooolJo`3oKol0o`3o5_l2o`3ooooooed0oomY
0?l01Oooool01?l0ojOo8?l0o`0dool0od`2ooooo`05o`3ol?ooooooE`3ooeL0ool0of/00oooool0
0ol0oi_o6P3ooaX0o`09oaX0o`;ooooo0_l0oi/01?l0of_oE`3oooooool0oo02ooooo`08o`3oC?l0
=?ooooooo`3oYoooooooG@3ooooooomY0?l4ooooo`03ob00oooooooo6_l000Gooooo0_lJo`000olP
0?ooooooooooo`08ooooo`07ok;o0?m_o`3oG@3ooooooomY0?oo00Coo`;o0004ooooo`03o`3oYooo
oooooooo00kooooo00?oJ@3oob3o0?l0Sol01Oooool02?l0okCoooooooooooooooooG@3ooh40ool0
of_o0?nK0ol0OOlAooooo`03o`3o]?oooooooooo00Sooooo00?o08ooooooooooool07Oooool00omG
o`3oP@3ooh40o`02oh40o`Cooooo0_lP0?l2ooooo`Go07go0_ooool3o`3oC0Co8?l04?ooool4ofT0
o`Oooooo2Ol0oo1Pooooo`coKol0Q_oooolFok;o00co0?m[3oooool001[ooooo00?o0000oooooooo
ool00oooool00ooo0=CobP3ooc80o`02oc80o`0Loooooooob03o02;oool0e?o:0?oo?P3ooooooomk
0?oo0?l@o`3oGooX0?ooB_l0oil0oonh0?ooooooohOo0?l0Mooo08oooh40oolP0?oooooooa[o0?l0
oaKoooooo`;o0?mM0?oo00CoofT0o`Gooooo00?o0?nWo`0dool0od`00_ooool01Ol0oo3ooooooeL0
ool0OOoo0?m[00;ooooo00Co0?nKoaX0oolJ0?oo?_l02?ooool2ocko000<oaX0oolno`3ooooooooo
ool0oi_o07gooeL0oooooooo0?o`ooooool0odco03Co0_ooool01?l0ojOo0_l0oed0oomY0?l5oooo
o`04ob00oooooooo6_l0oa[o00;ooooo00?o6_l0oooooolP0?l02_ooool01onbo`3oKol0o`2EoomM
0?ooooooofT0ool01?l01?ooool00ol0ojOoooooooooo`0:ooooo`Go8?l000?oJ@3oooooool0Sol0
1Oooool02?l0okCoooooooooool0of_oG@3oo`1moon10?oo07go4oooool00ol0okCoooooooooo`08
ooooo`03o`2?oooooooooooo01Gooooo2_n10?l:ooooo`03ob00oooooooooooo00?ooooo00?o0?m<
o`1mool0OOl01?l0OOl3ooooo`Ko8?l01oooool3ofT0o`Gooooo1_l0oo1eooooo`coKol0TOooool;
ok;o00oooooo000Jooooo`03o`000?oooooooooo00?ooooo00Coo`3DolX0oomYo`3oon`00_ooool0
6_oob03oo`3Dool0l_o:0?oo?P3ooooooomk0?oo0?mOoooooooX0?ooB_l0okP0ooooooooQol0o`1g
ool0ooco08oooh40oolP0?oo6_l0ofoo0?l0oaKo0_l0oooooomM0?ooJ@3o1Oooool00ol0ojOoEol0
o`0do`02ooooo`06o`3ol?ooooooE`3oo`1mool0of_ooooo0olJ0?l>ooooo`0BoaX0oolno`3ooooo
ooooool0oi_o07gooeL0ool0oo3o8?l0ooooool0odco03Coooooool0ojOo0_l0oed0oomY0?oo09Go
1Oooool00olP0?oooooooa[o0003oa[o0003ob00oooooooooooo00Wooooo00Oo/_l0o`2EoomM0?oo
ooooofT0ool01?oo0_l000Cooooo00?o0?nWooooooooool02Oooool00olPo`3oooooooooo`04oooo
o`03ofT0ool0Sooooooo00Gooooo00Ko0?ndo`3oVol0OOooG@3ooooooon10?lDooooo`03o`3o]?oo
oooooooo00Sooooo00?o08ooooooooooool03_ooool7oh40o`?ooooo0omGo`0?ooooo`03ob00oooo
oooo0?m<00;o0?m<1oooool6o`1mo`?ooooo1?lPo`03ofT0o`;ooooo1_l0oo27ooooo`_oKol0X?oo
ool001[ooooo00?o0000ooooooooool00oooool00ooX0?ooo`3DolX0o`02ooooo`0Kooo80?l08_oo
o`3Dool0l_ln0?oo01Koog/0ool20?oo0?mOogD0oooX0?ooMOl0okP0ooooooooQol0o`1gool0ooco
P@3oob00oooooooo6_l0ofoo0?l0oaKo0_l0oed0ool01?ooJ@3o00Cooooo00ko8?l0o`3oYol0=?oo
0?m<ooooool0oo3ooooooeL0ool0OOoo0?m[oooooolJ0?oo0?nKocko00?ooooo2Ol02_l4ooooo`;o
6P3o00ooooooo`3oVol0of_oE`3oo`3ol?lPo`3oooooo`3oC?l0=?ooooooo`3oYol2o`3oG@3ooooo
oomY0?l01Oooool2ob00o`;ooooo0_lP0?l;ooooo`07ok;o0?m_o`3oG@3ooooooomY0?oo00Coo`;o
0004ooooo`03o`3oYooooooooooo00Sooooo0_lPo`07ooooo`03ofT0ool0Sooooooo00;ooooo00?o
0?m[o`3oVol0OOl00_l0OOl2ooooo`03oed0oon10?oooooo01;ooooo00?o0?ndooooooooool02?oo
ool00ol0Soooooooooooo`0<ooooo`?oP@3o2?ooool2oeOo017ooooo0_l0od`2ob00o`oooooo1?l0
OOl3ofT0o`03ooooool0oo3o0?o`00;o0?o`1_lPo`2Boooooa;oKol0S_ooool001[ooooo00?o0000
ooooooooool00oooool00ooX0?ooo`3DolX0o`02ooooo`0Jooo80?l08_ooo`3DolX0ooln0?oo01Ko
og/0ool0oa3o0?mOonP0oom:o`3oW`3ookP0oon7o`3o^?l0o`1gool0SoooP@3oob00oooooooo6_l0
o`3o5_l2o`3ooooooed0oomY0?l4ooooo`04ob3o0?l0ojOoEol0o`0do`;ooooo00Oo0?o`oeL0ool0
OOoo0?m[oooooolJ0?oo0?nK00?ooooo0ol02_l8o`10o`?o00[o0_ooool02_lno`3o6P3oooooool0
oi_o0?m[oeL0ool0oo3o8?l0o`3oC?l0=?l2ooooo`04o`3oYomM0?ooooooofT0o`Oooooo0_lP0?l<
ooooo`07ok;o0?m_o`3o09Gooed0ooooooooJ@3oo`04o`05ooooo`03o`3oYooooooooooo00Oooooo
00?o8?l0ooooooooool01oooool00omY0?oo08ooo`3oJ`02o`3oV`;o07go00?oooooo`3o]?ooool0
0_ooool00omM0?oooooooh40o`0Aooooo`03o`3o]?oooooooooo00Wooooo00?o08ooooooooooool0
2Oooool3oh40o`Wooooo0_mGo`0Aooooo`;o0?m<1?ooool00olP0?ooooooooooo`0=ooooo`?oJ@3o
00?oooooo`3ol?l0OOl01Ol0OOl6ooooo`Oo8?l0WOoooolBofoo07cooooo000Jooooo`03o`000?oo
oooooooo00?ooooo00?oj03oool0e?o:0?l00_mYo`006_l08_ooo`3Dool0l_ooR`3o?P3ooooooomk
0?oo0?l@o`3oGooX0?ooB_l0okP0ooooooooQol0ooooool0Mooo08oooh40ool0okCo6_l0ofoo0?l0
oaKo0_l0oed0ool01?ooJ@3o0oooool03_lPo`3o0?nWoeOo0?l0=?oo0?m<ooooool0oo3oE`3oo`1m
ool0of_ooooooaX0ool0oi_ooooo0ol02_l3o`10o`Sooooo0ol0@?l04ol02_oooooooooooolJ0?oo
?_l0o`3oVoooooooE`3oooooool0oo3oooooo`3oC?l0=?ooooooo`3oYol2o`3oG@3oofT0ool0UOl0
5?ooool01_nbo`3oKol0oed0ooooooooJ@3oo`04o`Gooooo00?o0?nWooooooooool01Oooool01?mG
o`3o8?l0ob3o0?mGo`08ooooo`04o`3oJol0oi_oJ@3oo`3oV`;o07go1?ooool01_l0okCooooooooo
oomM0?oooooooh40oa7ooooo00?o0?ndooooooooool02?ooool00ol0Soooooooooooo`07ooooo`?o
P@3o2_ooool2oeOo017ooooo0_l0od`7ooooo`;o803o2_ooool3ofT0o`Co0?o`1oooool5o`1mo`So
oooo1olPo`2Xooooo`_oKol0E_ooool<ocko00oooooo000Jooooo`03o`000?oooooooooo00?ooooo
00?oj03oofT0oooo0=@00_oob0006Ol08_ooo`3DolX0ooln0?oo01Koog/0ool20?oo0?mOoooooooX
0?ooD?l0okP0ooooooooQol0o`1gool0SoooP@3oob00oooooooo6_l0ofoo0?l0oaKo0_l0oed0oomY
0?l01?ooool02OlPo`3o0?nWo`0dool0odcoooooo`3ol?ooooooE`3oo`3oJ`02oaX0o`04o`3oVooo
oooo00[oooooo`;o043o1?ooool8obH0o`;ooooo01?o043oo`0:ool02_oooooooaX0oolno`3o0?nK
oeL0ool0OOoo0?o`ooooool0odco03Coooooool0ojOo0_l0oed0oomY0?oo09Go01?ooooo00Oo/_l0
ofoo0?mM0?ooooooofT0ool01?oo0_l000Gooooo00?o0?nWooooooooool00oooool2oeOo0004ob3o
0?ooooooooooooooo`;oEol00oooool3o`3oJ`04o`3oVol0OOooJ@3oo`1mo`Kooooo00Ko0?ndoooo
oooooooooooooed0oon10?l@ooooo`03o`3o]?oooooooooo00Wooooo00?o08ooooooooooool01_oo
ool00on10?ooooooooooo`0:ooooo`03oeOo0?oooooooooo00oooooo0_l0od`;ooooo`;o803o1_oo
ool2ofT0o`?o0?o`4?ooool6o`1mo`Wooooo1_lPo`2]oooooa;oKol06?ooool/ocko01_ooooo000J
ooooo`03o`000?oooooooooo00?ooooo01ko^03oonP0oooo0=CobP3oo`0Roooo0=Coo`3boch0ool0
^_oo01Koog/0ool0oa3o0?mOonP0oom:o`3oW`3ookP0oon7o`3o^?l0o`1gool0SoooP@3oob00oolJ
o`3oKol0o`3o5_l2o`3oG@3oo`04oomY0?l3ooooo`04ob3o0?l0ojOoEol0o`0do`;ooooo00[o0?o`
oeL0ool0OOoo6P3oooooool0oi_oooooo`0:oooooooo043o0oooool3obH0o`Sooooo0_lV0?l04ooo
oooo043oo`10ool02_oooooooaX0ool0oi_ooooooeL0ool0oo3o8?l0o`3oC?l0=?ooooooo`3oYol2
o`3oG@3ooooooomY0?l04oooool01_nbo`3oKol0oed0ooooooooJ@3oo`04o`Gooooo00?o0?nWoooo
ooooool00oooool2oeOo0003ob3o0?oooooooooo00Cooooo00GoEol0ooooool0of_oooooo`3oV`02
o`1mo`03oooooomY0?oo08oo00Kooooo00Oo0?ndoooooooooooooooooed0ooooooooP@3o00oooooo
00?o0?ndooooooooool02Oooool00ol0Soooooooooooo`04ooooo`;oP@3o2oooool2oeOo013ooooo
0_l0od`?ooooo`;o803o0_ooool2ofT0o`03o`3ol?oooooooooo01Sooooo1Ol0OOl:ooooo`Oo8?l0
XOooool_ocko04Oooooo000Jooooo`03o`000?oooooooooo00?ooooo00?oP@3oonP0oooo0=@00_o:
0?l06Ooo0=Co?P3ooch0ool0^_ooN`3oo`80ool0oa3o0?mOonP0oom:o`3oW`3ookP0oon7o`3ooooo
o`1gool0SoooP@3ooooooolJo`3oKol0o`3o5_l2o`3oG@3oo`04oomY0?l00_ooool03_lPo`3ooooo
o`3oYol0=?oo0?m<ooooool0oo3oE`3oo`1moolJ0?ooooooocko0?l0oi_o00[o0_l0@?l01?oooooo
9P3oobH0oolV0?l=ooooo`04obH0ooooooooooooo`0:o`;ooooo00ko6P3oo`3oVol0OOooE`3oo`3o
l?oooooo0?m<o`0doooooooo0?nWoed0ooooooooJ@3oo`2Eoa7ooooo00Oo/_l0ofoo0?mM0?oooooo
ofT0ool01?oo0_l000Cooooo00?o0?nWooooooooool00oooool00omGo`3oooooob3o0008ooooo`04
o`3oJol0OOoo07goo`1mo`?ooooo00?oJ@3oo`2?ooooool01_ooool01_l0okCooooooooooooooooo
G@3ooh40o`kooooo00?o0?ndooooooooool02Oooool00ol0Soooooooooooo`03ooooo`;oP@3o3?oo
ool00omGo`3oooooooooo`0>ooooo`;o0?m<4_ooool00ol0oo3oJ@3oofT0o`0Rooooo`Ko07go2ooo
ool6ob3o08Cooooo5olno`0Xooooo`coKol0;?ooool7ob00o`oooooo000Jooooo`?o00000oooool0
7Ol0Moooj03oool0e?oo0=Coo`3bool0e?ooR`3oooooo`0Foomk0?oo0P3oo`3oGoooooooj03ooe3o
0?nh0?ooooooohOo0?l0Mooo08oooh40oolP0?oooooooa[o0?nbo`3o0?lFoooooomM0?ooJ@3o00?o
oooo00Co8?l0o`3oYomGo`3o03Co0_ooool01OmG0?oo07goo`3oJolJ0?oo?_l000;o00[o00Co043o
oooooooooooo9P3o4Oooool2obH0o`0Ao`10ool02_oooooooaX0oooooooo0?nKoeL0ool0oo3ooooo
o`3oC?l0=?ooooooo`3oYonbo`3oG@3oofT0ool0UOl04Oooool01_nbo`3o09Gooed0oomY0?oo00Co
o`;o00Gooooo00?o0?nWooooooooool00_ooool00omGo`3oooooob3o0009ooooo`03o`1moomGo`3o
oooo00Cooooo00?oJ@3oo`2?ooooool01_ooool01_l0okCoooooooooooooooooG@3ooh40o`gooooo
00?o0?ndooooooooool02_ooool00ol0Soooooooooooo`02ooooo`03oh40oooooooooooo00[ooooo
0_mGo`0?ooooo`;o0?m<4_ooool3ofT0o`;ooooo0_lP0?lVooooo`Ko07go2oooool7ob3o06Gooooo
6?lno`1;ooooo`coKol05Oooool;ob00oaKooooo000Jooooo`03o`000?oooooooooo00Cooooo01co
j03oo`80oomk0?ooo`3Doon;0?oooooo0;[oo`0Foomk0?oo0P3oo`3oGome0?ooj03ooil0oonh0?oo
Qol0okSo0?l0Mooo08oooh40ool0okCo6_l0ofoo0?l0oaKo0_l0oed0ool01?ooJ@3o0_ooool03_lP
o`3oooooo`3oYol0=?oo0?m<ooooool0oo3oE`3oo`1moolJ0?oo?_l0o`0:oooooooo043o0_ooool0
0olV0?ooooooooooo`04ooooo`So>?l01_ooool04OlV0?oo00[ooooooolno`3o6P3oo`3oVomG0?oo
0?o`ob3o0?l0odco03Coooooool0ojOo0_l0oed0ooooooooJ@3o013ooooo00Oo/_l0ofoo0?mM0?oo
ooooofT0ool01?oo0_l000Cooooo00?o0?nWooooooooool00_ooool00omGo`3oooooob3o0009oooo
o`03o`1mooooooooEol000Kooooo00?oJ@3oooooooooool01Oooool01ol0okCooooooooooooooooo
G@3ooooooon10?l03?ooool00ol0okCoooooooooo`09ooooo`03o`2?oooooooooooo00;ooooo00?o
P@3oooooooooool02_ooool00omGo`3oooooooooo`0=ooooo`;o0?m<4_ooool2ofT0o`Oooooo0_lP
0?lZooooo`Ko07go3?ooool8ob3o04_ooooo4_lno`1_ooooo`_oKol02_lP0?lQooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03onP0ool20?ooN`3o00;ooh/001Koooooo`2joomk0?oo0P3oo`3o
4?l0oeooj03ooe3o0?nO0?oo^03oohOo0?oooooo07Ooo`2?oon10?oooooooa[o0?nbo`3o0?lFoooo
oomM0?ooJ@3o0oooool03OlPo`3oooooo`3oYol0=?ooooooo`3ol?mG0?oo07gooaX0oooooooo00[o
ooooool0@?l00_ooool00olV0?ooooooooooo`02ooooo`?o>?l02?ooool00olho`3oooooooooo`03
ooooo`0AobH0ool0@?oo00[ooooooolJ0?ooooooo`1moomG0?oo0?o`o`3oC?l0=?ooooooo`3oYol2
o`3oG@3ooooooomY0?l03oooool01onbo`3oKol0oed0ooooooooJ@3oo`04ool2o`001Oooool01Ol0
ojOoooooooooooooooooEol000;ooooo00?o8?l0ooooooooool01Oooool00ol0of_o07goooooo`02
ooooo`03oeOo0?oooooooooo00?ooooo00?oJ@3oo`2?ooooool01Oooool00ol0okCoooooooooo`02
ooooo`03oed0oon10?oooooo00[ooooo00?o0?ndooooooooool02_ooool01Ol0Sooooooooooooooo
ooooP@3o00cooooo00?oEol0ooooooooool03Oooool00ol0odcoooooooooo`0@ooooo`;oJ@3o2ooo
ool2ob00obkooooo1_l0OOl>ooooo`Oo8?l0>Oooool;ocko08Cooooo2?lP0?lAofoo01[ooooo000J
ooooo`03o`000?oooooooooo00Cooooo01_o^03oonP0ooooooooN`3oooooool0^_ooN`3oooooool2
0?oo0?mOoooooooX0?ooD?l0okP0oon7o`3o^?l0ooooool0MoooP@3oo`3of?oooooo6_l0ok;o0?l0
oaKoG@3oo`04oomY0?l00_ooool03OlPo`3oooooo`3oYol0=?oo0?m<oooooomG0?oooooooaX0oooo
oooo?_l0o`0:ool0@?l00_ooool01?lV0?ooooooooooooooool2ocSo00cooooo0olho`03ooooo`0A
obH0ool0@?oo00[ooaX0oolno`3o0?nKoeL0ool0oo3oooooo`3oC?l0=?ooooooo`3oYomM0?oooooo
ofT0ool0UOl03_ooool01_nbo`3oKol0oed0ooooooooJ@3oo`04o`Gooooo00Go0?nWoooooooooooo
oooooeOo0002ooooo`03ob3o0?oooooooooo00Gooooo00?o0?m[o`1mooooool00oooool00omGo`3o
ooooooooo`03ooooo`03ofT0ool0Sooooooo00Kooooo00Ko0?ndoooooooooooooooooed0oon10?l;
ooooo`03o`3o]?oooooooooo00Wooooo00Go08oooooooooooooooooooh40o`03oooooaoo0?3o3?oo
ool2ofT0o`oooooo0_lP0?lbooooo`Ko07go3oooool8ob3o00kooooo<Ol0=?miooooo`So803o6Ooo
ool;ofoo00oooooo000Jooooo`03o`000?oooooooooo00Cooooo00CoP@3oonP0ool0^_oooooo0_mk
0?l05ol0od3oooooo`80ool0oeooooooonP0oonO0?oo^03oohOo0?nho`3o07Ooo`2?oon10?oo0?oH
oa[o0?nbo`3o0?lFo`;o0?mM0?oo00CoofT0oooooooo8?l000;ooooo00[o0?nWo`0doooooooo0?o`
oeL0ool0OOoo6P3oocko0?l02_oo043o0_ooool01OlV0?oooooooooooooooooo>?l0013ooooo01Go
>?l0ooooooooooooooooobH0oooooooo00[ooooooolJ0?oo0?nKoeL0ool0oo3o8?l0o`3oC?l0=?oo
ooooo`3oYomM0?ooKol0oooooomY0?l03Oooool01onbo`3oKol0oed0ooooooooJ@3oo`04ool2o`00
1Oooool01?l0ojOooooooooooomGo`02ooooo`03ob3o0?oooooooooo00Gooooo00?o0?m[o`1moooo
ool01Oooool00omGo`3oooooooooo`02ooooo`03ofT0ool0Sooooooo00Kooooo00Oo0?ndoooooooo
oooooooooed0ooooooooP@3o00Wooooo00?o0?ndooooooooool02_ooool01?l0Sooo0?3ooh40oon1
0?l4o`3`o`Sooooo00?oEol0ooooooooool03?ooool00ol0odcoooooooooo`05ooooo`Wo0?3o00?o
ooooofT0oomY0?l04oooool2ob00ocKooooo1Ol0OOl7oooooaWo03Co4Olno`0Poooood3o03Co<Ooo
ool8ob00oc_ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oP@3oonP0ool05_l00_l0^_l0
5Ol05_ooooooo`80oolDo`3o0?mOonP0oom@o`3oW`3ookP0oon7o`3oooooo`1gool0oocoP@3ooooo
oolJo`3o/_l0o`3o5_mM0?oo00CoofT0o`02ooooo`0?ob3o0?oooooo0?nWo`0dool0odcooooooeL0
ool0OOoo6P3oocko0?l02_ooooooo`10oooooooo9P3o00;ooooo0_lho`0Booooo`;o>?l00_ooool0
4?lV0?oo043oo`0:oolJ0?oooooooeL0oooooooo0?o`o`3oC?l0=?ooooooo`3oYol2o`3oG@3ooooo
oomY0?l=ooooo`06ok;o0?m_o`3oG@3ooooooomY0?oo0_l01Oooool01Ol0ojOooooooooooooooooo
Eol000;ooooo00?o8?l0ooooooooool01?ooool00ol0of_o07goooooo`06ooooo`03oeOo0?oooooo
oooo00;ooooo00?oJ@3oo`2?ooooool01_ooool00ol0okCoooooo`10o`02o`10o`03oed0oon10?oo
043o00oo043o0oooool3o`3`o`03o`2?oon10?oooooo00cooooo00?oEol0ooooooooool03?ooool0
0ol0odcoooooooooo`0>ooooo`;oJ@3o2?l0l?l?ooooo`03ob00oooooooooooo03Oooooo2?l0=?l>
ooooo`Co?_l01olPo`1aoooooaOo03Co4_ooool8ob00od?ooooo000Jooooo`03o`000?oooooooooo
00Cooooo00?oE`3oonP0ool20?l00_l05_l2ooooo`0Eo`80ool0oa3o0?mOonP0oom@o`3o^03ook80
oonho`3oooooo`1goon10?oo0?oHofoo0?lJo`3oooooo`3o5_mM0?oo00CoofT0oooooooo8?l000;o
oooo00co0?nWo`0doooooooo0?o`oeL0oolJ0?ooooooo`0:ool0oi_o043ooooooolV0?l2ooooo`03
ocSo0?oooooooooo00Wooooo0ol0;_l8ooooo`0BocSo0?oooooo9P3oooooool02_oooooooaX0oomG
0?oo07goo`3ol?l0odco03Coooooool0ojOo0_l0oed0ooooooooJ@3o3?ooool01onbo`3oKol0oed0
ooooooooJ@3oo`04ool2o`001Oooool01?l0ojOooooooooooomGo`02ooooo`03ob3o0?oooooooooo
00Cooooo00?o0?m[o`1mool0oi/01oooool00omGo`3oooooooooo`03ooooo`03ofT0oooooooooooo
00;ooooo1Ol0@?l3ooooo`03oed0oon10?oooooo00Oooooo00?o0?ndooooooooool01?ooool00ol0
l?oo043oo`10o`03o`10o`;oP@3o3_ooool00omGo`3oooooooooo`0;ooooo`03o`3oC?oooooooooo
00gooooo0_mY0?l00ol0oo3oooooooooo`07ooooo`So0?3o2?ooool2ob00ob_ooooo3?l0=?l7oooo
o`Go07go2_lno`0;ooooo`Oo8?l0POooool;o`0do`Oo803o<_l0=?lIooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`0@oooX0?oo0P3o00;o0?m00_ooool05Ol20?oo0?mOoooooooX0?ooW`3o
okP0oon7o`3o^?l0o`1gool0SoooP@3oo`3of?lJo`3o/_l0o`3o5_ooooooG@3oo`04oomY0?oooooo
ob3o0002ooooo`0;o`3oYol0=?oooooooeL0ool0of_o6P3oocko0?l02_oo043ooooooolV0?l00_oo
ool00olho`3oooooooooo`06ooooo`Co02ko0oooool3o`0^o`Gooooo00co>?l0oooooooooooo9P3o
o`0:oooooooo6P3oo`3oVomG0?oo0?o`o`3oC?l0=?l2ooooo`05o`3oYomM0?ooooooofT0ool0UOl0
2oooool01_nbo`3o09Gooed0ooooooooJ@3oo`;o00Gooooo00Co0?nWooooooooooooEol00_ooool0
0olPo`3oooooooooo`04ooooo`03o`3oJol0OOoo0?nK00Wooooo00?oEol0ooooooooool00_ooool0
0omY0?ooooooo`10o`02o`10o`Cooooo00?o0?ndooooooooool00_ooool00omM0?ooP@3oooooo`05
ooooo`03o`3o]?oooooooooo00;ooooo0ol0l?l5ooooo`03oh40ool0Sooooooo00Ko043o1oooool0
0omGo`3oooooooooo`0;ooooo`03o`3oC?oooooooooo00cooooo0_mY0?l2o`3ol1;ooooo2?l0l?l2
ooooo`;o803o8?ooool9o`0doa3ooooo2?lno`09o`1moa?ooooo1_lPo`1nooooo`So803o>Oooool:
o`0do`oooooo000Jooooo`03o`000?oooooooooo00Cooooo00Go013oonP0ool0oeoo0P3oooooo`02
o`80o`0DoaCo0?l0oeooj03ooe3o0?nO0?oo^03oohOo0?oooooo07Ooob00oon10?ooKol0oa[o0?oo
oooo0?lFoed0ool01?ooJ@3ooooooolPo`02ooooo`09o`3oYol0=?ooooooo`3ol?mG0?oo6P3oocko
0?l02_oo043o00;ooooo00?o9P3ooooooolho`001oooool2o`0^o`;ooooo1ol0l?l01?oooooo02ko
o`0^ool0;_l3ooooo`0BocSo0?oooooo9P3oo`10ool02_oo6P3ooooooomG0?oo0?o`o`3oC?mGo`3o
03Coooooool0ojOo00Cooed0ooooooooJ@3o2_ooool01onbo`3oKol0oed0ooooooooJ@3oo`04ool2
o`001Oooool01_l0ojOooooooooooomGo`3oooooob3o00Oooooo00?o0?m[o`1mooooool01Oooool5
oaX0o`?ooooo00?o043oofT0ool0@?l02?ooool01_l0okCoooooooooooooooooG@3ooh40o`Kooooo
00?o0?ndooooool0l?l00_l0l?l7ooooo`03oh40ool0Sooooooo00Oooooo1_l0@?l00omGo`3ooooo
ooooo`0;ooooo`03o`3oC?oooooooooo00_ooooo0_mY0?l00ooooooo0?o`ooooo`0Kooooo`Co0?3o
0_lP0?l4o`3`oaCooooo1_l0=?lBooooo`Oo?_l04Oooool=o`1mo`cooooo1_lPo`1`ooooo`So803o
F_ooool001[ooooo00?o0000ooooooooool01?ooool01Ol04?ooj03oo`3oGooooooo0P3o00;ooooo
01Co0?mOo`3o4?oX0?ooD?l0okP0oonb0?oo^?l0ooooool0MoooP@3oo`3of?m_o`3o6_l0o`;o0?l0
oaKoG@3oo`04oomY0?ooooooob3o00;ooooo00go0?nWo`0dooooooooE`3oo`3oJolJ0?oo00[oo`3o
Vol0@?ooooooobH0oooooooo>?l000Kooooo0_l0;_l01?oooooo0?3oo`3`ool0l?l7ooooo`?o0?3o
00Go02koooooooooooooooooocSo0002ooooo`0@obH0ool0@?oo00[ooaX0oomG0?oo07goob3o0?l0
odco03Coooooool0ojOo0_l0oed0ooooooooJ@3oo`2Eo`Sooooo00Oo/_l0ofoo0?l0UOooG@3ooooo
oomY0?oo0_l000Gooooo00Ko0?nWooooooooooooEol0oooooolPo`06ooooo`03o`3oC?l0of_o07go
00OoE`3o1?ooool01omGo`3o6P3ooaX0oolJ0?ooooooofT0ool0Sol02Oooool01_l0okCooooooooo
oomM0?oooooooh40o`Cooooo00?o0?ndo`3`ool0l?l02Oooool00on10?ooooooo`2?o`0=ooooo`03
oeOo0?l0@?oo043o00?o043o2?ooool00ol0odcoooooooooo`0:ooooo`;oJ@3o00?oooooo`3ol?l0
oo008oooool3ob00o`03ooooool0l?oo0?3o00Wo0?3o1?ooool5o`0doa3ooooo2?lno`0Uooooo`Wo
07go2Oooool6ob3o06?ooooo1olP0?mRooooo`006_ooool00ol0003oooooooooo`05ooooo`03onP0
ool0oeoooooo00;ooooo01Co5?l0o`3oGom:o`3oj03ooil0oonh0?ooQol0okSo0?oooooo07Oooh40
ool0omSo6_l0ooooool0oaKoG@3oooooool01?ooJ@3oob3o00;ooooo00go0?nWo`0doooooooo0?o`
oeL0oolJ0?oo00[oooooool0@?ooooooobH0oooooooo>?l000Kooooo00Co02kooooooooooooo0?3o
3Oooool00ol0l?oo02koo`0^o`02ooooo`0BocSo0?ooooooooooobH0ool02_oo6P3ooeL0ool0OOoo
0?o`o`3oC?l0=?ooooooo`3oYol2o`3oG@3oofoo0?mY0?oo09Go1oooool02?nbo`3oooooofoo0?mM
0?ooooooofT0oooooooo0_l01Oooool01_l0ojOooooooooooomGo`3oooooob3o00Cooooo0_l0od`0
1ooooooo03CooeL0oomG0?oo03Coo`3oC?lJ0?l00oooool2oeL0o`;ooooo1?l02_l00olJ0?ooJ@3o
o`0:o`06o`0:o`?ooooo00Oo0?ndoooooooooooooooooed0ooooooooP@3o00;ooooo0_l0l?l:oooo
o`04oh40ooooooooooooo`2?o`cooooo00?oEol0ooooooooool01?ooool3o`10o`Gooooo00?o0?m<
ooooooooool02?ooool2ofT0o`;ooooo00?o0?o`ooooooooool09_ooool3ob00o`Wooooo1?l0=?l5
o`3`o`Sooooo2?lno`0fooooo`Ko07go2Oooool7ob3o05Cooooo2?lP0?mYooooo`006_ooool00ol0
003oooooooooo`05ooooo`0IokP0oooX0?oo0?mOoooooolDo`3oooooo`3oGom:o`3oj03ooil0oonh
0?ooQol0ooooool0Mooo803ooh40ool0omSo6_l0o`;o0?l0oaKoG@3oo`04oomY0?ooooooob3o0002
ooooo`08o`3oYol0=?oo0?o`oeL0oolJ0?oo00[oocko0?l0@?l2ooooo`03obH0oooooooo>?l000Go
oooo00Co02koooooool0l?oo0?3o3oooool00ol0l?ooooooo`0^o`02ooooo`0:ocSo0?oooooo9P3o
o`0:oolJ0?oo0?nKoeL0ool0oo3o0?m<o`0do`;ooooo00Ko0?nWo`04oomM0?oo/_l0ofT0ool0UOl6
ooooo`07ok;o0?m_o`3o09Gooed0ooooooooJ@3oo`;o0006ooooo`05o`3oYoooooooEol0oooooolP
o`001?ooool01ol0odcoooooooooool0=?ooE`3oo`3oVoooool00_lJ0?l2o`3oC0?ooooo00GoE`3o
o`0:ool02_oooooooeOo0003ooooo`03oaX0oomY0?oooooo00Gooooo00Go00[ooooooooooooooooo
o`3o]002ooooo`05oed0oooooooooooooh40ool0l?l02oooool01?n10?ooooooooooool0Sol<oooo
o`03oeOo0?oooooooooo00Sooooo0ol0@?l00ooooooo0?m<ooooo`09ooooo`05ofT0oooooooooooo
ooooool0oo00;?ooool3ob00o`?ooooo0ol0=?l9ooooo`So0?3oA?oooolDo`1mo`Co8?l0A?ooool8
ob00og7ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o^03oonP0ool0oa000ol0oel04_oo
ooooj03oogGo0?nh0?oo/P3ookSo0?oooooo07Oooh40ool0omSoKol0oa[o0?l2o`3oG@3oooooool0
1?ooJ@3oob3o00?ooooo00co03CooooooomG0?oo07gooaX0ool02_ooooooo`10oooooooo9P3ooooo
oolho`05ooooo`03o`0^oooooooo0?3o00Gooooo1OmSo`08ooooo`0>o`3`ool0;_oooooooooooolh
o`3oooooobH0ool0@?oo6P3oocko0?mG0?oo07goo`3oC?l0=?l2ooooo`06o`3oYol2o`3oG@3oofoo
0?mY0?oo09Go1Oooool01onbo`3oKol0o`2EoomM0?ooooooofT0ool2o`001_ooool01Ol0ojOooooo
oooooomGo`3o8?l000Cooooo00So0?m<oooooooooooo03CooeL0ool0oi_ooooooaX0o`;ooooo00?o
03Coo`3oC?l02_l00_l02_l01Ol0@?ooE`3oooooooooooooEol000Cooooo00?oJ@3ooaX0ooooool0
1Oooool2o`0:o`05ooooool0okCo0?ndoooooomM0?l00_l0l?l00ol0okCoP@3oooooo`09ooooo`05
oh40ooooooooooooooooool0Sol02oooool00omGo`3oooooooooo`0<ooooo`?o043o1oooool2ofT0
o`?ooooo00?o0?o`ooooooooool0;_ooool3ob00o`Kooooo1_lno`08ooooo`So0?3oD?ooool;o`1m
ocGooooo2?lP0?miooooo`006_ooool00ol0003oooooooooo`05ooooo`03ok80oooX0?ooD?l000;o
0?l@0_m:o`004OoX0?ooW`3ookP0oon7o`3o^?l0ooooool0MoooP@3oo`3of?lJo`3o0_l0o`3o5_mM
0?oo00Coo`2EoomY0?oo8?l000;ooooo00So0?nWo`0dool0oo3oE`3ooaX0ool02_oo?_l0o`10o`;o
oooo00?o9P3oocSo0?ooool01?ooool00ol0;_ooooooo`3`o`03ooooo`03of?o0?mMo`3oGOl000Oo
GOl000?oHol0ooooooooool01?ooool05_l0l?oo02kooooooooooooo>?l0oooooolV0?oo00[ooaX0
oomG0?oo07goob3o0?l0odco03Coooooool0ojOo0_l0o`04oomM0?ooJ@3oooooool0UOl3ooooo`08
ok;o0?l0UOoo09GooooooomM0?ooJ@3oo`04ool2o`06ooooo`05o`3oYoooooooEol0oooooolPo`00
1?ooool01ol0odcoooooo`0doomG0?oo0?nKoooooolJ0?l01?ooool01_l02_ooooooo`10ool0@?oo
oooooeL0o`?ooooo00OoEol0ooooooooooooooooofT0ool0Sooo6P3o00Oooooo0_l02_l01Ooooooo
0?3oo`3`oomM0?oo0?nd00;ooooo00?oP@3oooooooooool01Oooool2oh40o`?ooooo00?o08oooooo
ooooool02_ooool00omGo`3oooooooooo`0;ooooo`04o`3oC?ooooooooooooooo`;o043o1?ooool0
0omY0?ooooooooooo`02ooooo`03o`3ol?oooooooooo02cooooo0ol0=?l3ooooo`Co803o0_lno`0F
ooooo`[o0?3oDOoooolFo`1moaOooooo2?lP0?n1ooooo`006_ooool00ol0003oooooooooo`05oooo
o`03ofT0oonh0?ooj03o00?oB_l0017oM@3oonP0oonO0?oo^03oohOo0?nho`3oooooob00oon10?oo
0?oHoa[o0?l2o`3o0?lFoed0ool01?ooJ@3oob3o0003ooooo`0;o`0dooooooooE`3oo`1moolJ0?oo
00[oooooool0@?ooooooobH0oolho`001Oooool01Ol0;_ooooooo`3`ooooooooHol000?oGOl02Ooo
ool00omMo`3oHol0of?o0004ooooo`0Fo`3`ool0;_oooooooooooolho`3oooooobH0ool02_oo6P3o
oeL0ool0OOoo8?l0o`3oC?l0=?ooooooo`3oYol2o`3o00Cooed0oonbo`3oJ@3oooooo`Go09Go00Go
oooooed0oomY0?oo00Coo`;o0006ooooo`05o`3oYooooooooooooeOo0?lPo`001?ooool01ol0odco
ooooo`0doomG0?oo0?m[o`3oVolJ0?l01?ooool00ol02_oo03Coo`10o`04ooooo`04oeL0oooooooo
oooooeOo00?ooooo00?oJ@3oo`2?oolJ0?l02?ooool01Ol0l?oo00[oooooooooooooG@3o00Cooooo
0on10?l01?ooooooP@3ooh40oon10?l5ooooo`03o`2?oooooooooooo00Wooooo4_l0f?l3ooooo`;o
043o00?oooooofT0ooooool01?ooool00ol0oo3oooooooooo`0Yooooo`?o03Co0_ooool5ocko00?o
oooo0olP0?lOooooo`_o0?3oC_ooool7ob3o00Oooooo3ol0OOl8ob00og[o07go3oooool001[ooooo
00?o0000ooooooooool01Oooool01?mY0?oo^03oonP0ooooool2oe3o000AonP0oooooooo^03ook80
oonho`3oooooo`2?oon10?oo0?ndo`3of?lJo`3o0_l0oed0oooooooo00CoofT0oolPo`000_ooool0
3?l0ojOo03Coo`3ol?mG0?oo6P3oo`0:oolno`3o043ooooooolV0?ooooooocSo00Cooooo00?o02ko
ooooool0l?l00omMo`0=ooooo`;oGOl000?oHol0ooooooooool00_ooool04_l0l?oo02kooooooolh
o`3oooooobH0ool02_oo6P3oo`3oVomG0?oo0?o`o`3oC?l0=?ooooooo`3oYooooooo0_l0oed0o`;o
Kol000_oJ@3ook;o0?nbo`3oooooofoo0?ooooooG@3ooooooomY0?ooooooo`;o0006ooooo`05o`3o
YoooooooEol0oooooolPo`000oooool01ol0odcooooooooooomG0?oo0?m[o`3oVolJ0?l01?ooool0
1?lno`3o00[oo`10ool0=?l4ooooo`04oeL0oooooooooooooeOo00?ooooo00CoJ@3oo`2?oooooooo
6P3o1Oooool2o`3`o`;ooooo00?o00[ooooooomM0?l01_ooool3oh40o`Kooooo00?o08oooooooooo
ool01Oooool5o`3Ho`gooooo00?o0?m<ooooooooool00_ooool5o`3Ho`03ofT0ool0f?oo0=So00?o
0=So00?o0?o`ooooooooool0:?ooool2o`0do`03oooooolno`3o?_l000;o?_l02oooool4ob00obKo
oooo3?l0l?m9ooooo`Oo8?l02?ooool7ob00oi7ooooo000Jooooo`03o`000?oooooooooo00Gooooo
01KoJ@3ook80oonh0?ooj03ooooooooX0?oooooooil0oonh0?ooQol0okSo0?oooooo07Oooh40ool0
omSo6_l0o`;o0?l0oaKoG@3oo`04ool0UOooJ@3o0oooool02ol0ojOo03CooeL0oolJ0?oo0?m[o`0:
ool0@?oo0?nKoooooolV0?oo>?l000Cooooo00Co02koooooool0l?ooGOl04_ooool00omMo`3oHol0
ooooo`02ooooo`0=o`3`ool0;_oooooooooooolho`3o9P3oo`0:oolJ0?oo0?nKoeL0ool0OOoo0?m<
o`0do`02ooooo`06o`3oYol2o`3o00Cooed0oom_o`3oJ@3o0om_o`001_ooooooG@3oofT0oomY0?oo
00Coo`;o00Kooooo00Go0?nWooooooooooooEol0ob3o0003ooooo`09o`3oC?ooooooooooo`0doomG
0?oo0?m[o`3oVolJ0?oooooo00?o?_l000Go00[oo`10oolno`3o03Coo`3oC004ooooo`04oeL0oooo
oooooooooeOo00;ooooo00CoJ@3oo`2?oooooooo6P3o0oooool2o`3`o`Gooooo00?o00[ooooooomM
0?l03_ooool00ol0Sooo0=Soo`3Ho`05o`3Ho`?ooooo00?oEol0ooooooooool02oooool00ol0odco
ooooooooo`07ooooo`04ofT0oooooooo043oo`10o`;ooooo00?o0?o`o`3Hool0f?l01?l0f?lSoooo
o`;o03Co0olno`0Cooooo`Co803o;_ooool;o`3`od?ooooo2_lP0?nHooooo`006_ooool00ol0003o
ooooooooo`05ooooo`03oeL0oon10?oo^03o00?oj03o013ooooookP0oonb0?oooooookSo0?oooooo
803ooh40ool0omSo6_l0o`;o0?l0oaKoG@3oo`04oomY0?oo8?l00oooool02_l0=?oo0?o`oeL0oolJ
0?oo00[oocko0?l0@?ooooooobH0oolho`04ooooo`04o`0^oooooooo0?3ooego00Sooooo00?o0=So
o`1<ool0C?l01_l0C?l3ooooo`03oego0?mSo`3ooooo00;ooooo00co0?3oo`0^oooooooo>?l0oooo
oolV0?oo6P3oocko0?mG0?oo07goo`3oC?l0=?l2ooooo`04o`3oYooooooo0_l0o`04o`;oG@3o0_mY
0?l01oooooooG@3oofT0oooooooo00Coooooool2o`001_ooool01Ol0ojOooooooeOo0?oooooo8?l0
00?ooooo00Oo0?m<ooooool0=?ooE`3oo`3oJol0oi_o6P3o00;o?_l00_ooool01_l02_oo043ooooo
oooooooo?_l0o`0do`Cooooo00CoE`3oooooooooooooEol00oooool01?mY0?oooooooooooolJ0?l2
o`3`o`Sooooo00?o00[ooed0ooooool02_ooool3o`3Ho`03o`2?oooooooooooo00Sooooo00?oEol0
ooooooooool02oooool00ol0odcoooooooooo`05ooooo`;oJ@3o1?ooool2o`10o`Oooooo1_l0f?lI
ooooo`;o?_l00_l0=?lLooooo`Co803o=Oooool;o`3`obcooooo3?lP0?l:ooooo`So8?l0T?ooool0
01[ooooo0ol00005ooooo`04o`0@oon10?oo/P3ookP0o`;ooooo00ooW`3ookP0oonb0?oo^?l0oooo
ool0SoooP@3oo`3o]?l0omSo0_l0oooooomM0?oo00CooooooomY0?l00oooool02ol0ojOo03CooeL0
oolJ0?oo00[oocko0?l0@?oo0?nKoooooolV0?oo>?l000Cooooo00?o02koo`3`oomMo`001oooool3
o`1<o`Oo0:ko00Ooooooo`1<ool0f?oo0=SooooooomMo`3oHol000;ooooo01?o0?3oo`0^oooooooo
>?l0oooooolV0?oo00[ooaX0oomG0?oo07goob3o0?l0odco03Coooooool0ojOoooooo`;o0?oooooo
00Co00;oG@3o1?mY0?l00ooooooo00Coo`;o0006ooooo`05o`3oYooooooooooooeOo0?lPo`000ooo
ool02?l0odcoooooo`0doomG0?ooooooo`3oVolJ0?oo?_l00oooool00ol02_oo043oooooo`03oooo
o`03o`0doooooooooooo00?ooooo00?oE`3ooooooomGo`000oooool01?mY0?ooooooo`3`oolJ0?l;
ooooo`03oed0ool02_oooooo00Oooooo0_l0f?l2ooooo`03o`2?oooooooooooo00Sooooo00?oEol0
ooooooooool02oooool00ol0odcoooooooooo`05ooooo`03ofT0oooooooooooo00Cooooo00?o0?o`
ooooool0@?l03?ooool5o`3Hoa3ooooo0olno`03o`0dob;ooooo1OlP0?lkooooo`co0?3o5Oooool;
ob00oakooooo2?lPo`28ooooo`006_ooool00ol0003oooooooooo`06ooooo`03oh40oonb0?oo^03o
00;oW`3o0_nh0?l03Ooooooo^?l0ooooool0SoooP@3oo`3o]?l0omSo0_l0oooooomM0?oo00Coo`2E
oomY0?l00oooool02_l0=?oo0?o`oeL0oolJ0?oo00[oocko0?l0@?ooooooobH0oolho`04ooooo`03
o`0^ool0l?ooGOl000Kooooo0_l0C?l00ol0f?oo0:koo`2^o`06ooooo`?o0:ko0_l0C?l01?l0f?oo
oooooego0?mSo`02ooooo`0>o`3`ool0;_ooooooocSo0?lV0?oo00[ooaX0ool0oi_oE`3oob3o0?l0
odco03Coooooool0ojL2ooooo`03o`;o0?l01?oooooo00Gooooo00?o00Coo`;o0?ooool01_ooool0
1Ol0ojOooooooeOo0?oooooo8?l000;ooooo00Wo0?m<ooooooooooooE`3oo`1mool0of_o6P3ooooo
oolno`000_ooool00ol02_ooooooo`10o`04ooooo`03o`0dool0odcooooo00?ooooo00CoE`3ooooo
ooooooooEol00_ooool01OmY0?oo08oooooooooooooo6P3o00_ooooo00?oG@3oo`0:ooooool01?oo
ool2o`3Ho`Cooooo00?o08ooooooooooool01oooool01?mGo`3ooooooooooooooolBo`3oU@03ofT0
oooooooooooo00Cooooo00Co0?o`oooooooooooooooo0_l0@?l?ooooo`Go0=So1oooool4ocko0003
ooooool0=?oo03Co02[ooooo1OlP0?m2ooooo`[o0?3o2olP0?laooooo`So8?l0P?ooool001[ooooo
00?o0000ooooooooool01_ooool00omY0?ooP@3ook80o`02okP0o`0?ohOo0?nb0?oooooookSo0?l0
Sooo803ooh40ool0omSo0_l0oooooomM0?ooooooo`04oomY0?oo8?l000?ooooo00[o03CooeL0oolJ
0?oo00[oocko0?l0@?oo0?nKoooooolV0?oo>?l00oooool00ol0;_ooooooo`3`o`06ooooo`04o`1<
ool0[_oo0:koo`2^o`Cooooo0_l0oiD5ooooo`;o0:ko00Co04coooooooooooooGOl00_ooool03_l0
l?oo02kooooooolho`3o9P3oo`10oolJ0?oo0?nKoeL0ool0oo3o0?m<o`0doooooooo0?nW0_ooool0
0ol2o`3oooooo`04o`03ooooo`;o00Co00?o0_l0ooooooooool01Oooool01_l0ojOooooooooooomG
o`3oooooob3o00;ooooo00So0?m<ooooool0=?ooE`3oooooool0oi_o6P3oocko00;ooooo00?o00[o
ooooool0@?l01Oooool00ol0=?oo0?m<ocko0003ooooo`04oeL0oooooooooooooeOo00;o0?3o00Go
J@3oo`2?oooooooooooooaX0o`0;ooooo`03oed0oooooooo00[o00;ooooo0_l0f?l5ooooo`03o`2?
oooooooooooo00Cooooo2?l0oiD:ooooo`03o`3oC?oooooooooo00Cooooo00?oJ@3oooooool0oiD0
1?l0oiD00ol0oo3o0?nEooooo`04ooooo`;o043o4_ooool5o`3Ho`;o?_l00oooool2o`0doc7ooooo
1_lP0?lkooooo`_o803o0_ooool;o`3`ocOooooo2?lPo`1hooooo`006_ooool00ol0003ooooooooo
o`06ooooo`03ofT0oon10?oo/P3o00?ooooo00go/P3ookSo0?oooooo803ooh40ool0okCo0?oHo`;o
0?ooooooG@3oo`04ool0UOooJ@3o00?ooooo00[o0?nWo`0doomG0?oo6P3oo`0:ool0@?ooooooo`3o
VolV0?oo>?l01?ooool00ol0;_oo0?3oof?o0005ooooo`03o`1<ool0[_oooooo00;ooooo1?l0oiD2
ooooo`Co0?nE0oooool01Ol0[_oo04coo`1<ooooooooGOl000;ooooo00_o0?3oo`0^oooooooo>?l0
obH0oolJ0?oo0?nKoeL0ool0OOoo0?m<o`0do`02ooooo`03o`3oYooooooo0_l000;ooooo0ol01?l2
ooooo`03o`;o0?oooooooooo00Gooooo00Go0?nWoooooomGo`3oooooob3o0002ooooo`08o`3oC?oo
oooo03CooeL0ool0OOoo0?m[oaX0oolno`02ooooo`03o`0:oooooooo043o00Oooooo00?o03Coocko
0?ooool00oooool00omG0?oo0?3oo`3`o`02ooooo`03ofT0ool0Sooooooo00;ooooo00?o6P3ooooo
ooooool02?ooool01OmM0?ooooooo`3Hool02_oo0=So00Oooooo00Co08oooooooooooooooooo0ol0
oiD3ooooo`03oeOo0?oooooooooo00_ooooo00?o0?m<ooooooooool01?ooool00omY0?oooooooooo
o`05ooooo`03o`3ol?oooooo0?nE00Co0?nE0_ooool00ol0@?ooooooooooo`0>ooooo`Co?_l00_oo
ool3o`3Ho`;o03Co>Oooool@ob00oacooooo3olP0?lHoooooa7o0?3o;_ooool7ob3o077ooooo000J
ooooo`03o`000?oooooooooo00Kooooo00?oJ@3ooh40oolP0?l00onb0?l01onho`3oooooo`2?oolP
0?ooP@3oo`3o]?l0omP00_ooool01?mM0?oo00Coo`2EoomY0?l3ooooo`0:o`0dool0oo3oE`3oo`0:
oolno`3o043oo`3oVooooooo9P3oocSo00?ooooo00?o02koo`3`oomSo`001Oooool00ol0C?oo0:ko
ooooo`03o`3oU@[ooooo0_l0oiD2ooooo`04o`2^oooooooo04cooego00;ooooo00_o0?3oo`0^oooo
oooo>?l0obH0oolJ0?oo?_l0oeL0ool0OOooooooo`0do`02ooooo`04o`3oYoooooooooooo`;o00Go
oooo00?o0_l0ooooooooool01_ooool01Ol0ojOooooooeOo0?oooooo8?l000;ooooo00Oo0?m<oooo
oomG0?oo07gooooooolJ0?oo?_l000?ooooo00?o00[oo`10ooooool01oooool00ol0=?ooooooocko
0002ooooo`08o`3`oomG0?oooooooooooomGo`3oooooofT0ool0Sol3ooooo`03oaX0oooooooooooo
00Oooooo0_l0f?l01?mM0?ooooooooooool02_l7ooooo`04o`2?ool0oiGo0?nEo`3oU@Gooooo00?o
Eol0ooooooooool03?ooool00ol0odcoooooooooo`03ooooo`03ofT0oooooooooooo00Gooooo00?o
0?o`ooooooooool01Oooool3o`3oU@03o`10ool0oiGo0?nE00Wooooo1?lno`07ooooo`;o03Co00?o
ooooo`3Hool0f?l00ol0f?m5oooooaco803o>?oooolHo`3`oagooooo2?lPo`1Yooooo`006_ooool0
0ol0003oooooooooo`06ooooo`06ofT0oomM0?ooP@3ookSo0?nb0?oo^?l00_ooool02_lP0?oo07Oo
oh40ool0omSo0_l0oooooomM0?ooooooo`04oomY0?l3ooooo`0:oeOo0?l0=?ooE`3ooaX0ool02_oo
043oooooool0oi_o9P3oocSo00?ooooo00?o02kooego0?l0l?l01Oooool01?l0C?oo0:koo`3oUOl0
oiD?ooooo`;o0?nE00Goooooo`2^ool0C?oooooooego0002ooooo`0=o`3`ool0;_oo>?l0obH0ool0
2_oo6P3ooeL0ool0OOoo8?l0o`3oC?l0=?ooooooo`3oY`03ooooo`;o0_l000?oooooo`;o0?l2o`00
2?ooool01Ol0ojOooooooeOo0?oooooo8?l000;ooooo00So0?m<ooooool0=?ooE`3oo`1mool0of_o
6P3oocko00;ooooo00?o00[oooooool0@?l02?ooool01ol0=?oo0?m<ocko0?oooooo0?3ooooooomG
0?l00_ooool01?mGo`3oooooofT0ool0Sol4ooooo`03oaX0oooooooooooo00Cooooo0_l0f?l2oooo
o`04oed0ooooooooooooooooo`;o00[o0oooool00ol0oiGo08ooo`3oU@08ooooo`03oeOo0?oooooo
oooo00_ooooo00?o0?m<ooooooooool01?ooool00omY0?ooooooooooo`04ooooo`03o`3ol?oooooo
oooo00[ooooo0_l0@?l6o`3oU@?o?_l02Oooool2o`0do`Sooooo1Ol0f?n/oooooaOo0?3o3_ooool8
ob3o04Gooooo3Olho`0?ooooo`006_ooool00ol0003oooooooooo`06ooooo`03ofT0oomM0?ooP@3o
00;o803o0_ooool02olP0?ook_l0o`1goon10?oo0?oHoa[o0?ooooooG@3oo`04ool0UOooJ@3o00?o
oooo00[o03Coo`3ol?mG0?oo00[oocko0?l0@?oo0?nKobH0oooooooo>?l00oooool00ol0;_oo0?3o
ooooo`04ooooo`03o`1<ool0[_oo0?nE01?ooooo00Go0?nEooooool0[_oo04cooego0002ooooo`0=
o`3`ool0;_ooooooobH0ool0@?oo6P3oo`3oVomG0?oo8?l0o`3oC?l0=?ooooooo`3oY`05ooooo`03
o`;o0?oooooooooo00Sooooo00Go0?nWoooooomGo`3oooooob3o0002ooooo`07o`3oC?ooooooE`3o
o`1mool0of_o6P3oocko0002ooooo`03o`0:oooooooo043o00?ooooo1_lho`001?oooooo03Cooooo
ool0l?l2ooooo`04oeL0oooooooooooooeOo00;ooooo00?oJ@3oo`2?ooooool00_ooool00olJ0?oo
ooooooooo`03ooooo`03o`3Hoooooooooooo00?ooooo00?oG@3oooooooooool00_ooool01Ol02_oo
0?nEo`3oUOoooooo08oo00Sooooo00?oEol0ooooooooool02oooool00ol0odcoooooooooo`04oooo
o`03ofT0oooooooooooo00Cooooo00?o0?o`ooooooooool03Oooool00ol0@?ooooooooooo`03ocko
00Ko0?nE1Oooool00ol0=?ooooooooooo`0=ooooo`Go0=So__ooool_o`3`oaGooooo5olho`0Loooo
o`006_ooool00ol0003oooooooooo`06ooooo`04oeL0oomY0?ooP@3oooooo`Co803o00CoKol0oh40
ool0okCo0?oH0_ooool01?mM0?oo00Coo`2EoomY0?l3ooooo`09o`0doomG0?oo6P3oo`0:ool0@?oo
ooooo`3oVolV0?oo>?l000?ooooo00?o02koo`3`oomSo`001?ooool01?l0C?oo0:koooooool0oiDC
ooooo`06o`3oUOooooooooooo`1<oomMo`3oHol00_ooool03?l0;_ooooooocSo0?lV0?oo6P3oo`3o
VomG0?oo0?o`o`3oC?l0=?ooooooo`3oY`oooooo00Go0?nWoooooomGo`3oooooob3o0002ooooo`07
o`3oC?oooooo03CooeL0ool0OOoo0?m[oaX0o`03ooooo`04o`0:ool0@?ooooooooooo`?o>?l01?oo
ool2ocSo0003o`0dool0l?oo?_l000?ooooo00?oE`3ooooooomGo`000_ooool00omY0?oo08oooooo
o`03ooooo`03oaX0oooooooooooo00;o0=So1_ooool00omM0?ooooooo`3oU@02o`3oU@04ooooool0
2_ooooooo`2?o`Wooooo00?oEol0ooooooooool02oooool00ol0odcoooooooooo`03ooooo`03ofT0
oooooooooooo00Gooooo00?o0?o`ooooooooool03Oooool00olno`3o043oo`10o`09ooooo`Co0?nE
00?o03Coo`3oUOooool04oooool6o`3HomKooooo1olPo`09ooooo`03ocSo0?l0l?oo0?3o01Go0?3o
<Oooool001[ooooo00?o0000ooooooooool01oooool00omY0?ooP@3ook;o0004ofoo0009o`1goon1
0?oo0?oHoa[o0?ooooooG@3oo`04ooooooooJ@3o00?ooooo00WoEol0o`0doomG0?oo07goo`0:ool0
@?oo0?nKobH0oolho`000oooool00ol0;_ooGOl0o`3`o`04ooooo`04o`1<ool0[_ooooooo`3oU@?o
oooo3?l0o`X6ooooo`05o`3oUOoooooo04cooooooomMo`000_ooool02_l0l?oo02koocSo0?lV0?oo
6P3oo`3oVomG0?oo07goo`3oC?l0=?l2ooooo`03o`3oYooooooooooo00cooooo00Go0?nWoooooomG
o`3oooooob3o0002ooooo`07o`3oC?ooooooE`3oo`1mool0of_o6P3oo`3oV`02ooooo`05o`0:ool0
@?oooooooooooolho`002Oooool00ol0=?oo0?m<ocko0003ooooo`07oeL0oooooooooooooeOo0?oo
ooooJ@3oo`2?o`04ooooo`03oaX0ool0f?oo0=So00Oooooo00?o0?nEoed0ool0oiD01Oooool00ol0
2_oo08ooooooo`07ooooo`03oeOo0?oooooooooo00_ooooo00?o0?m<ooooooooool00oooool00omY
0?ooooooooooo`05ooooo`03o`3ol?oooooooooo00_ooooo0olno`03ooooo`03o`10oooooooooooo
00Sooooo0_l0=?l2ooooo`Ko0?nE5?ooool5o`3HolWooooo3olho`06ob3o00?o>?l06?oooolRo`3`
o`oooooo000Jooooo`03o`000?oooooooooo00Oooooo013oJ@3ooh40ool2o`3o/_l0ooooooo^o`3o
oooooh40ool0ooco0?oHoa[o0?ooooooG@3oo`04ool0UOooJ@3o0oooool02Ol0=?ooE`3ooaX0ool0
2_oo043oooooool0oi_o9P3oocSo0003ooooo`03o`0^ool0l?oooooo00?ooooo00Co04coo`2^ool0
oiGo0?nE0oooool00ol0o`[oooooooooo`0:ooooo`03o`3o2_oooooooooo00Cooooo013o0?nEoooo
ool0C?oooooooego0?oooooo0?3oo`0^oolho`3o9P3oo`0:oolJ0?ooE`3oo`1moooooooo03Co0_oo
ool00ol0ojOoooooooooo`0;ooooo`03o`3oYoooooooEol000;ooooo00Wo8?l0ooooool0odcooooo
o`0doomG0?oo07goo`3oJolJ0?l00oooool00ol02_oo0?o`o`3ol003o`3ol0Oooooo00Co0?3oo`0d
ool0odco?_l00oooool01omG0?oooooooooooomGo`3oooooofT0ool0Sol01?ooool00ol0f?oo6P3o
ooooo`05ooooo`;o0?nE0_ooool00omM0?ooooooooooo`04ooooo`;o00[o1oooool00omGo`3ooooo
ooooo`0;ooooo`03o`3oC?oooooooooo00;ooooo00?oJ@3oooooooooool01Oooool00ol0oo3ooooo
ooooo`09ooooo`?o?_l01oooool00ol0@?ooooooooooo`06ooooo`03o`0doooooooooooo00Sooooo
1_l0oiDCooooo`Ko0=SoZooooolHocSo01Gooooo1OlPo`17ooooo`006_ooool00ol0003ooooooooo
o`07ooooo`04ofT0oomM0?ooP@3oo`;o00;o/_l000[oP@3oooooool0ooco0?oHoooooomM0?oo0?lF
o`04ool0UOooJ@3o0_ooool02OmGo`3o03CooeL0ool0OOoo00[oo`10ool0oi_o9P3oocSo0003oooo
o`03o`0^ool0l?oooooo00Cooooo00Co04coo`3oUOoooooooooo0ol0o`X>ooooo`03o`3o2_oooooo
oooo00Cooooo00Co0?nEo`1<ool0f?ooGOl00_ooool03?l0;_ooooooobH0ool02_oo6P3ooeL0ool0
OOoo8?l0o`3oC?l0=?ooooooo`3oY`gooooo00Go0?nWoooooomGo`3oooooob3o0002ooooo`07o`3o
C?ooooooE`3oo`1mool0of_o6P3oo`3oV`02ooooo`04o`0:ool0@?oo0?o`ocSo00;ooooo0_l0oo05
ooooo`06o`3`ooooooooooooo`0doolho`3o?_l00oooool01_mG0?oooooooeOo0?ooooooJ@3oo`2?
o`;ooooo0_l0f?l00ooooooo6P3oooooo`03ooooo`;o0?nE1?ooool00omM0?ooooooooooo`03oooo
o`04o`2?ooooooooooooo`0:o`Kooooo00?oEol0ooooooooool02_ooool00ol0odcoooooooooo`02
ooooo`03ofT0oooooooooooo00Gooooo00?o0?o`ooooooooool01oooool3ocko00_ooooo0_l0@?l4
ooooo`;o03Co4Oooool5o`3oUACooooo1_l0f?nCoooooa;o>?l0<_ooool6ob3o047ooooo000Joooo
o`03o`000?oooooooooo00Oooooo00ooJ@3ooed0ool0MoooP@3oo`;o0?l0MoooP@3oo`3oo?oooooo
0?oHoooooomM0?oo00Coo`2EoomY0?l00oooool02Ol0=?oo0?o`oeL0ool02_oo043oooooool0oi_o
9P3oocSo0003ooooo`03o`0^ool0l?oooooo00?ooooo00Go04coo`2^ooooooooooooo`3o2P08oooo
o`Go0?mU1Oooool00ol0o`[oooooooooo`03ooooo`04o`3oUOl0[_oo04cooego00;ooooo00co0?3o
o`0^oolho`3o9P3ooaX0ool0oi_oE`3oob3o0?l0odco03Coooooool0ojL<ooooo`0>o`3oYooooooo
oooooeOo0?oooooo8?l0ooooool0odcoooooo`0doomG0?oo07goo`3oJolJ0?l2ooooo`04o`0:ool0
@?ooooooocSo00Cooooo00?o0?o`ooooooooool00_ooool01ol0l?oooooooooooooooooo03Coo`3o
C?lno`000oooool02?mG0?oooooooooooomGo`3oJ@3oooooool0Sooo0=So1?ooool01?lJ0?oooooo
o`3oUOl0oiD6ooooo`03oed0oooooooooooo00?ooooo00Go08ooooooooooooooooooo`0:o`04oooo
o`03oeOo0?oooooooooo00_ooooo00?o0?m<ooooooooool00_ooool00omY0?ooooooooooo`05oooo
o`03o`3ol?oooooooooo00Cooooo0olno`0@ooooo`04o`10ooooooooooooo`0doaSooooo1Ol0oiDE
ooooo`Ko0=SoP_ooool;ocSo04[ooooo1olPo`0jooooo`006_ooool00ol0003oooooooooo`07oooo
o`04oeL0oomY0?ooooooo`1go`;oP@3o00Wo0?ndo`3oo?l0omSooooooed0ool0oaKo00Coo`2EoomY
0?l00oooool02?l0=?ooE`3oooooool02_oo043ooooooolV0?oo>?l00oooool00ol0;_oo0?3ooooo
o`03ooooo`05o`1<ool0[_oo0?nEooooool0o`X01Oooool5o`3oI@Cooooo1?l0ofD2ooooo`03o`3o
2_oooooooooo00?ooooo00oo0?nEo`1<ooooooooGOl0ooooool0l?oo02koocSo0?lV0?oo6P3oo`3o
VomG0?oo8?l0o`3oC?l0=?l00_ooool00ol0ojOoooooooooo`09ooooo`05o`3oYoooooooEol0oooo
oolPo`000_ooool01ol0odcoooooo`0doomG0?oo0?m[oaX0ool0oi/00_ooool01?l02_oo043ooooo
oolho`05ooooo`05o`3ol?ooooooooooooooool0l?l00oooool00ol0=?oo0?m<ocSo0003ooooo`07
oeL0oooooooooooooeOo0?l0f?ooJ@3oo`2?o`05ooooo`03oaX0ool0oiGooooo00Sooooo00?oG@3o
ooooooooool00_ooool00ol0Soooooooooooo`02ooooo`05o`0:oooooooooooooooooomGo`003?oo
ool00ol0odcoooooooooo`02ooooo`03ofT0oooooooooooo00Gooooo00?o0?o`ooooooooool00_oo
ool3ocko01Cooooo00?o043oo`0dooooool07Oooool4o`3oUAOooooo1_l0f?m`ooooo`co>?l0G?oo
ool7ob3o03?ooooo000Jooooo`03o`000?oooooooooo00Oooooo00Co013oofT0oomM0?oooooo0_l0
ok@02Ol0oocoooooo`3of?ooooooG@3oo`04oolPo`3o09GoofT0o`02ooooo`09o`3oC?l0=?ooE`3o
o`0:ool0@?ooooooo`3oVolV0?oo>?l000?ooooo00?o02koo`3`ooooool00_ooool01Ol0C?oo0:ko
o`3oUOoooooo0?l:00Gooooo00?o0?mUooooooooool01?ooool3o`0Xo`Cooooo00Co0?mUoooooooo
oooo0?l:1?ooool01?l0oiGo0:koo`1<oomMo`02ooooo`0<o`0^oolho`3o9P3ooaX0ool0oi_oE`3o
o`3ol?l0odco03CooeOo0?oooooo0?nW2_ooool03_l0ojOooooooooooomGo`3oooooob3o0?oooooo
0?m<ooooool0=?ooE`3oo`1mool0of_o6P3o0_ooool01?l02_oo043ooooooolho`07ooooo`03o`3o
l?oooooo0?3o00Cooooo00Co03Coo`3oC?oooooo>?l00_ooool01omG0?ooooooo`3Hool0f?oooooo
ofT0ool0Sol01?ooool2o`3oU@03oaX0oooooooooooo00Oooooo00GoG@3oooooooooooooooooo`2?
o`06ooooo`03o`0:ooooooooEol000cooooo00?o0?m<ooooooooool00_ooool00omY0?oooooooooo
o`06ooooo`03o`3ol?oooooooooo00;o?_l05_ooool2o`0do`03ooooool0@?oooooo023ooooo1?l0
oiDIooooo`Ko0=SoGoooool;ocSo06oooooo1olPo`0/ooooo`006_ooool00ol0003oooooooooo`07
ooooo`0>o`0@oomY0?ooG@3oo`3oo?l0okCoooooo`3oo?l0omSooooooed0ool0oaKo00Coo`2EoomY
0?l3ooooo`08o`0doomG0?ooooooo`0:ool0@?ooooooobH0oolho`03ooooo`03o`0^ool0l?oooooo
00?ooooo00Co04coo`2^ool0o`[o0?l:1?ooool2o`3oI@?ooooo1?l0:?l2ooooo`Co02So0_ooool2
o`3oI@03ooooool0o`[ooooo00;ooooo00Co0?nEooooool0C?ooGOl00_ooool02_l0;_oo>?l0obH0
ool02_oo6P3ooeL0ool0OOoo8?l0o`0doomGo`02ooooo`03o`3oYooooooooooo00Oooooo00Oo0?nW
oooooomGo`3oooooob3o0?oooooo0?m<00;ooooo00_o03CooeL0ool0OOoo6P3oo`3oVooooooo0?o`
o`0:ool0@?ooooooocSo0007ooooo`03o`3ol?l0l?oooooo00Cooooo00Co03Coo`3oC?oooooo>?l0
0oooool01_mG0?oooooooeOo0?ooooooJ@3oo`2?o`?ooooo00Co0?nEoooooooooooo6P3o2Oooool0
1OmM0?oooooooooooooooooo08oo00Oooooo0_l02_l<ooooo`03o`3oC?oooooooooo00;ooooo00?o
J@3oooooooooool01Oooool01?l0oo3oooooocko0?lno`0Gooooo`03o`0doooooooooooo00;ooooo
0_l0@?lSooooo`Go0?nE6_ooool6o`3Hodoooooo2_lho`21ooooo`So8?l09?ooool001[ooooo00?o
0000ooooooooool01oooool01?l0VoooJ@3oo`04oomM0?l2o`3oo008ooooool0omSooooooed0ool0
1?oo8?l0o`2EoomY0?l3ooooo`08o`0doomG0?ooooooo`0:oooooooo0?nKobH0oolho`02ooooo`03
oego0?l0;_oo0?3o00?ooooo00?o04coo`2^ool0o`X01Oooool00ol0ofGoooooooooo`03o`0Xo`Co
oooo0_l0i?l4ooooo`;o02So0_ooool00ol0ofGoooooo`3o2P03ooooo`0?o`3oUOl0C?ooGOl0of?o
0?oooooo02kooooooolV0?oo00[ooaX0oomG0?oo07goob3o0?l0=?ooEol000;ooooo00?o0?nWoooo
ooooool01_ooool05?l0ojOooooooooooomGo`3oooooob3o0?oooooo0?m<ooooool0=?ooE`3oo`1m
ool0of_o6P3oo`3oVooooooo00[oo`10oooooooo>?l02?ooool00ol0l?ooooooooooo`04of?o0008
o`0dool0odcoooooocko0?lho`3oooooo`3HoomG0?l2ooooo`04oeOo0?mY0?oo08ooooooo`;o0?nE
0oooool00olJ0?ooooooooooo`08ooooo`03oed0oooooooo08oo00Sooooo00?oEol0ooooool02_l0
2_ooool00ol0odcoooooooooo`02ooooo`03ofT0oooooooooooo00Gooooo00?o0?o`oooooolno`00
6?ooool00ol0=?ooooooooooo`05ooooo`03o`10oooooooooooo02Gooooo1Ol0oiDKooooo`Go0=So
@_ooool8ocSo09?ooooo2?lPo`0Looooo`006_ooool00ol0003oooooooooo`08ooooo`03ofT0oolJ
0?ooG@3o00?o6_l000Oo0?oHoed0oooooooo00Coob3o0?l0UOooJ@3o00;ooooo00So0?m<oeL0oooo
oooo00[oo`10oooooooo9P3oocSo00?ooooo00?o02koo`3`ooooool00_ooool00ol0C?oo0:koo`3o
U@04ooooo`;o0?mU00?oooooo`0Xool0:?l00oooool4o`3To`;ooooo1Ol0i?l01?oooooo02Soo`0X
ool0ofD2ooooo`0Co`3o2_ooooooooooo`3oUOl0[_oo04cooego0?oooooo02kooooooolho`3o9P3o
oaX0ool0oi_oE`3oooooool0odco03CooeOo0002ooooo`03o`3oYooooooooooo00Gooooo00?o0?nW
oooooomGo`000_ooool03_lPo`3o0?m<oooooooooooo03CooeL0ool0OOoo6P3oo`3oVooooooo0?o`
o`0:ool0@?oo>?l02Oooool00ol0l?ooHol0of?o0004ooooo`08of?o0?l0=?oo0?m<of?o0?lno`3o
0=SooooooomG0?l2ooooo`04oeOo0?mY0?oo08ooo`3oU@Kooooo00?o6P3oooooooooool01oooool0
0omM0?ooooooo`2?o`08ooooo`04oeOo0?ooooooooooo`0:o`Wooooo00?o0?m<ooooooooool00_oo
ool00omY0?ooooooooooo`05ooooo`03o`3ol?lno`3ooooo01Oooooo00?o03Coooooooooool01ooo
ool2o`10ob[ooooo1_l0oiDJooooo`Ko0=So=Oooool7ocSo0:?ooooo2?lPo`0Dooooo`006_ooool0
0ol0003oooooooooo`08ooooo`04ofT0oolJ0?oo00Cooed0o`;o0?oH00KoG@3oooooool01?oooooo
o`2EoomY0?l3ooooo`08o`0doomG0?ooooooo`0:oolno`3o0?nKobH0oolho`02ooooo`03oego0?l0
;_oo0?3o00?ooooo00?o04coo`2^ool0o`X00oooool01?l0ofGoooooooooool0:?l3ooooo`;o0>Co
00?o0?lXo`3o=?l0oc@01ol0oc@02?oooooo0>Cooooooooooooo02Soo`3oIOoooooo0?l:0oooool0
3ol0oiGo04cooego0?mSo`3o0?3oo`0^oolho`3o9P3ooaX0ool0oi_oE`3oooooool0odco03CooeOo
0002ooooo`03o`3oYooooooooooo00Cooooo01Co0?nWooooooooooooEol0oooooolPo`3oooooo`3o
C?oooooo03CooeL0ool0OOoo0?m[oaX0ool0oi_o0?o`o`0:ool0@?ooooooocSo00Sooooo00Co0?3o
of?o0?l0oo3ooooo1OmMo`001ol0=?oo0?m<ooooool0f?oo>?l0oooooomG0?l00_ooool01?mGo`3o
J@3oooooool0Sol6ooooo`03oaX0oooooooooooo00Oooooo00?oG@3oooooool0Sol01oooool00omG
o`3oooooooooo`02ooooo`03o`0:oooooooooooo00Gooooo00?o0?m<ooooooooool00_ooool00omY
0?ooooooooooo`05ooooo`03o`3ol?oooooooooo01Oooooo00?o03Coooooooooool02_ooool2o`10
obkooooo1ol0oiDIooooo`Oo0=So9_ooool8ocSo0;;ooooo1OlPo`0?ooooo`006_ooool3o`0000So
oooo00?oJ@3ooeL0ooooool01?mM0?l01Ooooooo00Coob3o0?l0UOooJ@3o00;ooooo00So0?m<oaX0
oomG0?oo00[oo`10oooooooo9P3oocSo00;ooooo00CoGOl0o`0^oooooooo0?3o0_ooool00ol0C?oo
0:koo`3o2P03ooooo`06o`3oIOooooooooooo`0Xoooooooo0?lX0_l0i?l3o`3o=0Sooooo00?o0?lX
o`3o=?l0oc@00_l0i?l01Ol0:?oo0?mUoooooooooooo0?l:00;ooooo00oo0?nEo`2^ool0C?ooHol0
o`3`ool0;_oo>?l0obH0oolJ0?oo0?nKoeL0ool0oo3o0?m<o`0doomGo`000oooool01?l0ojOooooo
ooooooooool2o`3oY`;ooooo00GoEol0oooooooooooo8?l0o`3oC002ooooo`0:o`0doomG0?oo07go
o`3oJolJ0?ooooooo`3ol?l02_oo043oocSo00Kooooo1OlV0?l00ol0oo3oGOl0oego0003ooooo`09
oego0?l0=?oo0?m<o`3Hoolno`3oHol0ocSo0?mG0?oooooo00;o0?nE00?oJ@3oooooool0Sol01_oo
ool00olJ0?ooooooooooo`08ooooo`03oed0oooooooooooo00Kooooo00?oEol0ooooooooool00ooo
ool00ol02_ooooooooooo`04ooooo`05o`3oC?oooooooooooooooomY0?l01_ooool2ocko0003o`3o
l?oooooooooo01Kooooo00?o03Coooooooooool03Oooool00ol0@?ooooooooooo`0booooo`Ko0?nE
6_ooool8o`3HoaKooooo2?lho`3>ooooo`006_ooool00ol0003oooooooooo`08ooooo`06obH0oomY
0?oo0?lFo`04oolPo`3ooooo0_l01?l01?l0oaKoooooo`2EoomY0?l2ooooo`08o`0doomG0?oo00[o
o`10oolno`3oooooobH0oolho`02ooooo`03oego0?l0;_oo0?3o00?ooooo00?o04coo`3oUOooool0
0oooool02?l0ofGoooooo`0Xoooooooo0?lXo`3Toooooooo0?ld3Oooool02?l0obSoooooo`3o=?l0
i?oo02Soo`3oIOoooooo0?l:0_ooool04?l0oiGo0:koo`1<oomMo`3oooooo`0^oolho`3o9P3oo`0:
oolJ0?ooE`3oo`1moolPo`3o03CooooooomGo`03ooooo`Co0?nW0_ooool04_mGo`3ooooooooooolP
o`3oooooo`3oC?oooooo03CooooooomG0?oo07gooaX0ool0oi_o0?o`o`0:ool0@?ooooooocSo00Go
oooo00Go9P3ooooooomSo`3o0?3ooego0002obH0o`03o`3ol?oooooooooo00?ooooo00So03Coo`3H
oooooooo?_l0oego0?lho`3o0?nEoeL0o`;ooooo00?oEol0ofT0ool0Sol01oooool00olJ0?oooooo
ooooo`07ooooo`03oed0oooooooooooo00Gooooo00?oEol0ooooooooool01Oooool2o`0:o`?ooooo
00?o0?m<ooooooooool00_ooool00omY0?ooooooooooo`03ooooo`03ocko0?oooooo0?o`01Sooooo
00?o03Coooooooooool03oooool2o`10ocSooooo1Ol0oiDMooooo`So0=So1_ooool8ocSo0=Kooooo
000Jooooo`03o`000?oooooooooo00Sooooo00Co013oofT0ool0UOoooooo0ol01?l01?l0oaKooooo
o`2EoomY0?l3ooooo`07oaX0oomG0?oo00[oo`10oooooooo0?nKobH0o`02ooooo`04oego0?l0;_oo
ooooo`3`o`;ooooo00?o04coo`2^ooooool00oooool00ol0ofGoooooo`0Xo`02o`3o:003o`3Tool0
ocCo0?ld00oooooo00Oo0?lXo`3o=?l0i?oo02Soooooool0ofGo0?l:00?ooooo00oo0:koo`1<oomM
o`3oooooo`0^oooooooo9P3oo`0:oolJ0?ooE`3oo`1moolPo`3o03CooooooomGo`002Oooool01OmG
o`3ooooooooooolPo`3o0?m<00;ooooo00[o03CooeL0ool0OOoo0?m[oaX0ool0oi_o0?o`o`0:ool0
@?oo>?l01Oooool01OlV0?ooooooof?o0?l0l?ooGOl000;ooooo00?o9P3oo`3ol?ooool01?ooool0
2?l0=?oo0?m<oooooooooooo?_l0o`3oUOlho`3oE`3o0_ooool00omGo`3oJ@3oo`2?o`07ooooo`03
oaX0oooooooooooo00Oooooo00?oG@3oooooooooool01?ooool00omGo`3oooooooooo`08ooooo`04
o`0:ooooooooooooo`3oC0?ooooo00?oJ@3oooooooooool00oooool01?lno`3oooooooooool0oo0G
ooooo`03o`0doooooooooooo01;ooooo00?o043oooooooooool0>_ooool5o`3oUAkooooo0_lho`08
o`3Homcooooo000Jooooo`03o`000?oooooooooo00Sooooo00Co013oofT0oolJ0?oo09Go0_ooool0
1Ol0oaKoooooooooool0UOooJ@3o00;ooooo00go0?m<oeL0ool02_oo043oocko0?oooooo9P3oocSo
0?ooooooGOl0of?o0?l0;_oo0?3o00?ooooo00?o04coo`3oUOooool00_ooool01ol0ofGoooooo`0X
ool0obSoooooo`3Tool0oc@01_ooool9o`3oM`?ooooo00Oo0?lXo`3o=?l0i?oo02Soooooool0ofGo
0?l:00;ooooo013o0?nEo`2^ool0C?ooHol0o`0^oooooooo>?l0obH0oolJ0?oo0?nKoeL0oooooooo
0?m<o`0dooooooooEol01oooool04OmGo`3ooooooooooolPo`3oooooo`3oC?oooooo03CooooooomG
0?oo07gooaX0ool0oi_o0?o`o`0:oooooooo043o00Gooooo00Go9P3ooooooomSo`3o0?3ooego0004
ooooo`03obH0oooooooooooo00;ooooo00Co0=Soooooool0=?oooooo0_l0oiD00omMo`3o>?l0oeL0
o`03ooooo`03ofT0ool0Sooooooo00Kooooo00?o6P3oooooooooool01_ooool00ol0Sooooooooed0
o`05ooooo`04oeOo0?ooooooooooooooo`So0?mU00?o00[oo`3oIOl0ofD00ol0ofD01_mY0?oo0?mU
o`3oIOl0ofGoooooocko00;ooooo00?o0?o`ooooooooool05Oooool00ol0=?ooooooooooo`0Doooo
o`;o043o?oooool5o`3oUA;ooooo1olho`0:ooooo`So0=Soe?ooool001[ooooo00?o0000oooooooo
ool02?ooool01?l04?ooE`3oofT0ool0UOl3o`3o5P04ooooool0UOooooooofT0o`;ooooo00Oo6P3o
oeL0ool0OOoo043oocko0?l0oi_o9P3o00;ooooo00CoGOl0o`0^oooooooo0?3o0_ooool00ol0C?oo
0:koooooo`02ooooo`07o`3oIOooooooooooo`0Xoooooooo0>Coo`3o=004ooooo`?o0?mg2Oooool2
o`3oM`;ooooo00Ko0?ldooooool0i?oo02Soo`3oIOl0o`X2ooooo`0@o`3oUOl0[_oo04coof?o0?l0
;_ooooooocSo0?lV0?oo6P3oo`3oVomG0?ooooooob3o0?l0=?oooooooeOo00Oooooo00GoEol0oooo
oolPo`3oooooo`3oC002ooooo`0:o`0doomG0?oo07goo`3oJolJ0?oo0?nKo`3ol?l02_oo043oocSo
00Cooooo00Ko9P3ooooooomSo`3oooooo`3`oomMo`04ooooo`05obH0ool0oo3oooooooooool0f?l0
0_ooool02?l0=?oo0?nEoooooolno`3oooooocSo0?mG0?ooHol00_ooool00omY0?oo08ooooooo`07
ooooo`03oaX0oooooooooooo00Gooooo00Co08oooooooomM0?oooooo2?l0ofD9ooooo`05o`0:oooo
oooooooooooooomY0?l01?ooool4o`3oI@03o`3ol?l0ofGooooo01Cooooo00?o03Coooooooooool0
5oooool00ol0@?ooooooooooo`11ooooo`Co0?nE1oooool7ocSo01Wooooo1ol0f?o=ooooo`006_oo
ool00ol0003oooooooooo`09ooooo`03obH0oomY0?oo6P3o00?ooooo00?o09GooooooomY0?l00_oo
ool03Ol0odcoE`3oo`0:ool0of_o043ooooooolV0?oo>?l0oooooomMo`3oHol0o`0^ool0l?l00_oo
ool00ol0C?oo0:koooooo`02ooooo`07o`3oIOooooooooooo`0Xoooooooo0>Coo`3o=004ooooo`03
o`3oMooooooooooo00?ooooo1?l0Pol5ooooo`0Jo`3oMoooooooooooo`3o=?oooooo0>Coo`0Xool0
ofGo0?l:ooooool0oiGo0:koo`1<oomMo`3o0?3oo`0^oolho`3o9P3ooaX0ool0oi_oE`3ooooooolP
o`3o03CooooooomGo`06ooooo`0AoeOo0?ooooooooooob3o0?oooooo0?m<ooooool0=?oooooooeL0
ool0OOoo6P3oooooool0oo3o00[oooooool0@?l01?ooool01_lV0?oooooooooooomSo`3o0?3ooego
00Kooooo00?o9P3oooooool0f?l00_ooool00ol0oiGo03Coo`3oC002ooooo`09ocko0?ooooooE`3o
oooooomSo`3oooooofT0oooooooo08oo00Oooooo00?o6P3oooooooooool00oooool2o`3oI@04o`2?
ool0ofGo0?mUoed0o`?ooooo00?oEol0ooooooooool02oooool01Ol0odco00[oooooooooooooJ@3o
00Cooooo00Ko?_l0ooooooooooooooooo`3ol?ooool6o`3oI@kooooo00?o03Coooooooooool06Ooo
ool2o`10odGooooo1Ol0oiD2ocSo02Oooooo2_l0f?o3ooooo`006_ooool00ol0003oooooooooo`09
ooooo`03obH0oomG0?ooJ@3o00?o09Go0_ooool04?mY0?oooooooooooolJ0?ooE`3oo`1mool0@?oo
?_l0oooooolV0?oooooooego0?mSo`3o02koooooool0l?l2ooooo`05o`1<ool0oiGoooooooooool0
ofD00_ooool01?l0:?ooooooo`3Tool0oc@3ooooo`;o0?mg00?oooooo`23ool0Pol00ol0Pol3oooo
o`Co08?o0oooool06_l0ogOoooooo`3o:?l0ocCo0>Coo`0Xool0ofGo0?l:ooooool0oiGoooooo`1<
oomMo`3o0?3oo`0^oolho`3o9P3ooooooolJ0?ooE`3oo`1moolPo`3o0?m<o`0dooooooooEol01?oo
ool04_mGo`3ooooooooooolPo`3oooooo`3oC?oooooo03CooooooomG0?ooooooo`1moolJ0?oo0?nK
o`3ol?l02_oo043oocSo00Cooooo00Go9P3ooooooomSo`3oooooo`3`o`07ooooo`08o`3ol?lV0?oo
ooooooooool0oiGoooooo`0dool0od`2ooooo`09ocko0?oooooo>?l0oeL0oomSo`3oooooofT0oomG
o`3o08oo00Oooooo00?o6P3oooooooooool00ol0ofD00ooooooo08ooooooo`02ooooo`04oed0oooo
oooooooooeOo00kooooo00Co0?m<ooooool02_ooJ@3o1?ooool01Olno`3ooooooooooooooooo0?o`
00Sooooo0ol0ofD:ooooo`03o`0doooooooooooo01cooooo00?o043oooooooooool0??ooool6ocSo
00Gooooo1_l0oiD]ooooo`_o0=So^?ooool001[ooooo00?o0000ooooooooool02Oooool00olV0?oo
E`3oofT0o`04ooooo`0@ofT0oooooooooooooooooolJ0?ooE`3oo`3oJol0@?oo?_l0obH0oolho`3o
oooooego0?mSo`3o02koo`3`o`;ooooo00Go04coo`2^ooooooooooooo`3oI@02ooooo`04o`0Xoooo
oooo0>Coo`3o=0?ooooo00Co0?mgoooooooooooo08?o0oooool8o`0@o`03ooooool0Pooooooo00;o
oooo01Oo0?mgooooool0obSo0?ldo`3Tool0:?ooooooo`3o2_oooooo0?nEo`2^ool0C?ooooooo`0^
oooooooo9P3oo`0:oolJ0?ooE`3oo`1moooooooo8?l0o`0do`02ooooo`CoEol00_ooool03olPo`3o
ooooooooool0odcoooooo`0dooooooooE`3oo`1mool0of_o6P3oo`3ol?l02_ooooooo`10o`04oooo
o`06obH0ooooooooHol0ooooool0l?ooGOl01oooool01?l0f?oo9P3oooooool0oiD2ooooo`0=o`0d
ool0odcooooooooooolno`3oooooocSo0?mG0?ooGOl0of?o0?mY0?ooEol0o`2?o`07ooooo`03o`3o
IOlJ0?oo0?mU00Cooooo00?o08ooooooooooool00_ooool00omM0?oooooooeOo000=ooooo`05o`3o
C?oooooooooooooooomY0?l00oooool00olno`3oooooooooo`02ooooo`03o`3ol?oooooooooo00Wo
oooo0ol0ofD7ooooo`03o`0doooooooooooo01gooooo0_l0@?lfooooo`Ko>?l04Oooool7o`3oUC7o
oooo4_l0f?nVooooo`006_ooool00ol0003oooooooooo`09ooooo`04o`0@oolV0?ooE`3oofT0o`;o
oooo017oJ@3ooooooooooooooooooaX0oomG0?oo07goooooool0@?ooooooobH0ooooooooGOl0of?o
0?l0;_ooooooo`3`o`02ooooo`04o`1<ooooooooooooo`3oI@;ooooo00Go02Soooooool0i?oooooo
o`3o=002ooooo`04o`3oMooooooo08?oo`23o`Co013o2?l0D_l3o`0@o`0Io`23ooooooooooooo`3o
Mooooooo0?lXo`3Tool0:?oo0?mUo`3o2_oooooo0?nEo`2^ool0C?ooHol0o`0^oooooooo9P3oo`0:
oolJ0?oo0?nKoeL0oooooooo8?l0o`0do`08ooooo`05ob3o0?oooooo0?m<ooooool0=?l00_ooool0
2?mG0?oo07gooaX0oooooooo0?o`o`0:ool0@?oo>?l00oooool00olV0?ooooooof?o0002ooooo`03
o`3`oooooooooooo00Gooooo00Co0=Soo`3ol?lV0?oo0?nE0oooool00ol0=?oo0?m<ooooo`02oooo
o`08ocko0?ooooooE`3ooego0?mSo`3oooooofT0ool0Sol4ooooo`?o0?mU00?ooooooaX0ooooool0
1?ooool00ol0Soooooooooooo`02ooooo`03oed0oomGo`3ooooo00gooooo00So0?m<oooooooooooo
J@3oooooool02_ooooooocko00Cooooo00?o0?o`ooooooooool03Oooool3o`3oI@?ooooo00?o03Co
ooooooooool08?ooool2o`10obkooooo1_lho`0Nooooo`Oo0?nE??oooolBo`3HoiCooooo000Joooo
o`03o`000?oooooooooo00Wooooo00?o013oobH0oomG0?l00omY0?l3ooooo`0=oaX0ool02_ooE`3o
ooooool0@?oo?_l0obH0ool0oi_ooooooego0?mSo`3o02koo`3`o`02ooooo`0;o`1<ool0[_oooooo
ooooool0ofGoooooo`0Xoooooooo0>Coooooool0oc@00_ooool01Ol0ogOoooooo`23oooooooo013o
00;o05;o2_ooool2o`1Bo`03o`3fool04?oo08?o00;ooooo01Ko0?mgo`3o:?oooooo02Soooooool0
ofGo0?l:o`3oUOl0[_oo04coof?o0?l0;_ooooooocSo0?lV0?oo6P3oo`3oVomG0?ooooooob3o0?oo
oooo03Co1_ooool03olPo`3oooooooooool0odcoooooo`0dooooooooE`3oo`1mool0of_o6P3oo`3o
l?l02_ooooooo`10o`04ooooo`05obH0ooooooooHol0ooooool0l?l01oooool01Ol0f?oooooooooo
ool0oo3o9P3o00?ooooo00?o03Coo`3oC?ooool00_ooool02Olno`3ooooooeL0ooooooooGOl0oooo
oomY0?ooEol0o`2?o`03o`3oI@Cooooo00?o6P3oooooooooool00_ooool00ol0Soooooooooooo`04
ooooo`03oed0oooooooooooo00_ooooo00Go0?m<ooooooooooooooooofT0o`02ooooo`03o`0:oooo
oooooooo00?ooooo00?o0?o`ooooooooool04?ooool2o`3oI@03o`0doooooooooooo02?ooooo00?o
043oooooooooool09_ooool5ocSo02_ooooo1ol0oiE7ooooo`_o0=SoROooool001[ooooo00?o0000
ooooooooool02Oooool01Ol04?oo9P3oo`0doomG0?oo6P3o00?ooooo017o6P3oo`0:oomG0?oo07go
o`10oooooooo?_l0obH0ooooooooGOl0of?o0?l0;_ooooooo`3`oooooooo04coo`2^o`02ooooo`03
o`3oIOoooooo02So00;ooooo00Go0>Coo`3o=?ooooooooooo`3oM`02o`23o`;o013o00?o05;ooooo
ooooool03?ooool2o`1Bo`0Eo`0@ool0Poooooooo`3oMooooooo0?lXo`3Tool0:?oo0?mUo`3o2_oo
oooo0?nEo`1<oomSo`3o02kooooooolho`3o9P3ooaX0ool0oi_oE`3o00;ooooo00?o8?l0o`0doooo
ool01Oooool01OlPo`3oooooo`3oC?oooooo03Co00;ooooo00SoE`3oo`1moolJ0?ooooooo`3ol?l0
2_ooooooo`10o`?ooooo00Ko9P3ooooooomSo`3ooooooego0?l0l?l6ooooo`06o`3Hoooooooooooo
ooooool0oo3o9P3o1?ooool03_l0=?oooooooooooooooooo?_l0oooooomG0?oo>?l0oego0?mSo`3o
J@3ooeOo0?l0ofGo08oo1oooool01OlJ0?oooooooooooooooooo08oo00Gooooo00?oEol0oed0oooo
ool03?ooool02Ol0odcoooooooooooooooooJ@3ooooooolno`3oooooo`0:o`04ooooo`03o`3ol?oo
oooooooo017ooooo00Co03Coo`3oIOl0ofGo0?mU9?ooool2o`10ob7ooooo1Olho`0gooooo`Ko0?nE
C?oooolAo`3HogSooooo000Jooooo`03o`000?oooooooooo00Wooooo00Go0?Koo`0@oolV0?ooE`3o
ooooo`04oaX0o`0<o`0doomG0?oo043ooooooolno`3oooooobH0oomMo`3oHol0ooooool0;_oo0?3o
0_ooool01_l0C?oo0?nEooooool0ofGoooooo`0Xo`;ooooo00So0>Coo`3o=?ooooooooooo`3oMol0
Poooooooo`0@o`;o05;o4Oooool05_l04?oo08?ooooooooooooo0?mgo`3o:?l0ocCo0>Coo`0Xool0
o`[oooooo`3oUOl0C?oo0=Soo`3`ool0;_oo>?l0obH0oooooooo6P3ooeL0ool0oo02ooooo`03o`0d
oooooooooooo00Cooooo00oo8?l0ooooool0odcoooooo`0dooooooooE`3oooooool0OOoo6P3oo`3o
l?l0oi_o00[oo`10oolho`000oooool01_lV0?ooooooof?o0?ooooooGOl0o`3`o`Gooooo00Oo0=So
ooooooooooooooooo`3oUOl0oo3o9P3o00Cooooo00ko03Coooooooooooooooooocko0?ooooooE`3o
ocSo0?ooooooGOl0ofT0ool0ofGoEol0o`2?o`Oooooo00Go6P3oooooooooooooooooo`2?o`05oooo
o`03oeOo0?ooooooG@3o00cooooo00Co0?m<ooooooooooooJ@3o0_ooool01?lno`3oooooooooool0
2_l2ooooo`03o`3ol?oooooooooo017ooooo00?o03Coooooooooool00_ooool3o`3oIB?ooooo0_l0
@?lJooooo`Go>?l0=ooooomno`2^oaSo0=SoB_ooool001[ooooo00?o0000ooooooooool02_ooool0
1?l04?oo9P3ooeL0oomG0?l4o`0:o`0?oeL0ool0@?ooooooocko0?oooooo9P3oo`3oVomMo`3oHol0
ooooool0;_oo0?3oooooool0C?oo0:ko00;ooooo00Ko0?mUooooool0:?ooooooo`3Tool0oc@3oooo
o`05o`23oooooooo013oo`1Bool0m_l04_ooool05_l0D_oo013oo`23oooooooo0?mgooooool0obSo
0>Coo`0Xool0ofGo0?l:o`3oUOl0C?oo0=Soo`3`ool0;_oo>?l0obH0ool02_oo6P3oo`3oJomG0?l2
ooooo`03o`3oC?l0=?oooooo00?ooooo00Go8?l0ooooool0odcoooooo`0do`02ooooo`08oeL0ool0
OOoo6P3oooooool0oo3o00[oooooool0@?l3ooooo`06obH0ooooooooooooof?o0?mMo`3o0?3o1_oo
ool01ol0f?ooooooooooool0oiGoooooo`3ol?lV0?l01?ooool00ol0=?oo0?m<ooooo`02ooooo`09
ocko0?ooooooE`3oooooool0ofGoJ@3ooooooomGo`3o08oo00Oooooo00Co6P3ooooooooooooo08oo
1Oooool01?mGo`3ooooooooooomM0?l;ooooo`07o`3oC?oooooooooooooooomY0?ooooooocko0004
ooooo`03o`0:oooooooo0?o`01;ooooo00?o03Coooooooooool01_ooool3o`3oIB;ooooo0_l0@?lC
ooooo`Go>?l09_oooolFo`2^oa7ooooo1_l0oiEWoooooe?o0:ko3oooool001[ooooo00?o0000oooo
ooooool02_ooool02Ol04?oo9P3oo`3oYomG0?oo043oo`3oC?l0oo3oE`3oo`10o`02ooooo`0;ocko
0?oooooo9P3ooego0?mSo`3oooooo`0^ool0l?ooooooo`3o2_l0C?l00_ooool01_l0ofGoooooo`0X
oooooooo0>Coo`3o=0?ooooo00?o08?oooooool04?l00_l0m_l6ooooo`Ko0?mI2?ooool05Ol0D_oo
013oo`23oooooooo0?mgo`3o:?l0i?oo02Soo`3oIOl0o`[oooooo`2^ool0C?ooooooo`0^oooooooo
9P3oo`0:oolJ0?oo0?nKoeL0o`03ooooo`03o`0doolPo`3o8?l000;o8?l00_ooool03Ol0odcooooo
o`0dooooooooE`3oooooool0OOoo6P3oo`3ol?l0oi_o00[oo`10oolho`000oooool01_lV0?oooooo
of?o0?mMo`3oooooo`3`o`Gooooo00Co0=Sooooooooooooo0?nE0_ooool00ol0oo3o9P3oooooo`03
ooooo`03o`0dool0odcooooo00;ooooo00[o?_l0oooooomG0?oo0?mUoooooomY0?oooooooeOo0?oo
oooo08oo1oooool00olJ0?oo08ooooooo`05ooooo`05oeOo0?oooooooooooooooomM0?l02_ooool0
1_l0odcooooooooooomY0?ooooooocko00Kooooo00?o00[oo`3ol?ooool04?ooool00ol0=?oooooo
ooooo`0:ooooo`;o0?mU8_ooool2o`10o`cooooo1Olho`0Rooooo`Wo0:ko;Oooool7o`3oUJOooooo
3?l0f?l?ooooo`006_ooool00ol0003oooooooooo`0:ooooo`04o`0@ool0:?oo9P3oo`0do`?oE`3o
00Co043oo`3oYooooooo?_l00_ooool03OlV0?ooGOl0of?o0?oooooo02koo`3`oooooooo04coo`2^
oooooooo0?mUooooool0:?l00_ooool02?l0i?oooooooooooooooooo08?oooooool04?oo0?Ko1Ooo
ool3o`3oF@Kooooo0ol0oeT6ooooo`0Eo`1Bool04?ooooooo`3oMooooooo0?ldo`3Tool0:?oo0?l:
ooooool0oiGo04coof?o0?l0;_ooooooobH0ool02_oo6P3oo`3oVomG0?oo0?o`00?ooooo00Co03Co
o`3oC?oooooooooo0_l0od`03?oooooo03CoooooooooooooE`3oo`1mool0of_o6P3oo`3ol?l02_oo
ooooo`10o`?ooooo00Ko9P3oooooooooooooHol0oego0?l0l?l6ooooo`04o`3Hooooooooooooo`3o
U@;ooooo00?o0?o`oooooolV0?l00oooool00ol0=?oo0?m<ooooo`02ooooo`;o0?mU00SoE`3oocSo
0?ooooooooooofT0ooooooooEol0o`2?o`Oooooo00?o6P3oo`2?ooooool01?ooool00omGo`3ooooo
ooooo`02ooooo`03oed0oooooooooooo00Sooooo00Go0?m<ooooooooooooJ@3oocko0007ooooo`03
o`3ol?l02_oooooo00oooooo00?o03Coooooooooool03Oooool2o`3oIB;ooooo00?o043ooooooooo
ool01Oooool4ocSo01kooooo2Ol0[_lmooooo`So0?nE^_ooool000;ooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0ol00009ooooo`03o`000?oooooooooo00[ooooo00Co05Woo`0@oolV0?oo
oooo0ol0OOl00ol0ojOoooooocko0002ooooo`09obH0ool0oi_oGOl0ooooool0;_oo0?3oooooool0
o`[o04co00;ooooo00Ko0?mUo`3o:?l0:?ooooooo`3Tool0oc@2ooooo`04o`23ooooooooooooo`0@
o`?ooooo0ol0oeT<ooooo`;o0?mI1Oooool05?l04?oo08?oooooool0ogOo0?lXo`3Tool0:?oo0?l:
ooooool0oiGo04coof?o0?l0;_ooooooocSo0?lV0?oo6P3oo`3oVol0OOooE`3o1?ooool00ol0=?oo
0?m<o`3oC002ooooo`0<o`0doooooooooooooooooomG0?oo07gooaX0ool0oo3o0?nKo`0:oooooooo
043o0oooool01_lV0?ooooooof?o0?mMo`3oooooo`3`o`Gooooo00Co0=Sooooooooooooo0?nE1?oo
ool00ol0oo3o9P3oo`3o2P02o`3o2P03o`0dool0odcooooo00;o0?mU00Coooooocko0?mG0?oo>?l0
0_ooool01?mY0?oooooooeOo0?l0Sol7ooooo`03o`2?oolJ0?oooooo00Cooooo00?oEol0oooooooo
ool00oooool00omM0?ooooooooooo`06ooooo`06o`3oC?ooooooooooofT0oooooooo?_l01oooool0
0ol0oo3oooooo`0:o`0>ooooo`03o`0doooooooooooo013ooooo0ol0ofDPooooo`;o043o1Olho`0K
ooooo`Oo0:koC_ooool7o`3oUK?ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`04o`2Kool04?oo9P3oo`3oY`;ooooo0_l0
ojL05?lno`3ooooooooooolV0?oo0?nKoego0?mSo`3oooooo`0^ool0l?oo0?l:o`1<ool0f?oooooo
o`3oIOl0obSo02Soooooool0i?oo0?ld0oooool01Ol0Poooooooo`0@ool0m_oooooo00;o0?mI4Ooo
ool00ol0oeWoooooooooo`02ooooo`0Do`1Bool04?oo08?oo`3oMol0obSo0>Coo`0Xool0ofGo0?l:
ooooool0C?oo0=Soo`0^oooooooo>?l0obH0oooooooo6P3oo`1moomG0?l4ooooo`Go03Co0oooool0
2?mG0?ooooooo`1moolJ0?oo0?o`o`3oVol02_oo043o0oooool01olV0?oooooooooooomSo`3oGOl0
ooooool0l?l01Oooool00ol0f?ooooooo`3oU@03ooooo`;o0?l:00?o0?o`obH0ooooool00_ooool0
1?l0=?oo0?mUo`3oIOl0o`X2ooooo`0:ocko0?mG0?ooooooocSo0?ooooooJ@3ooego0?ooooooEol0
o`2?o`Gooooo00?o08ooo`3ToolJ0?l02ol0i?l00omM0?oo0>Coo`3To`03o`3To`?ooooo00Go0?m<
ooooooooooooJ@3oocko0007ooooo`05o`3ol?ooooooooooooooool02_l03?ooool00ol0=?oooooo
ooooo`0Dooooo`;o0?mU6oooool5ocSo00;o043o6Oooool5o`2^oecooooo2?l0oiF[ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`Go00002Oooool00ol0003oooooooooo`0;ooooo`03o`0@
oolV0?ooGOl000;o0?nW0_lno`02ooooo`0>obH0ool0oi_oGOl0oooooomSo`3o02koo`3`oooooooo
0?l:o`1<oooooooo0?mUo`3o:?l0:?l2ooooo`0:o`3Tooooooooooooooooool0Poooooooo`0@ool0
m_ooooooo`3oF@Sooooo1_l0ocX6ooooo`03o`3oFOoooooooooo00;ooooo01Co013oo`23oooooooo
0?mgo`3o=?l0:?oo0?mUo`3o2_oooooo04coo`3Hool0l?oo02koocSo0?lV0?oo00[ooaX0ool0oi_o
E`3oo`3ol0_ooooo00SoE`3oo`1moolJ0?oo0?o`o`3oVol02_ooooooo`10o`?ooooo00Ko9P3ooooo
oomSo`3oGOl0ooooool0l?l5ooooo`05o`3Hooooooooooooo`3oUOooool00_l0o`X2ooooo`03o`3o
l?lV0?oooooo00;ooooo00Co03Coo`3oC?oooooooooo0_l0o`X02?lno`3oE`3ooooooolho`3ooooo
ofT0oomMo`3oHol00_l0i?l01?l0Sooo0>Coo`3Tool0i?l2o`2?o`;ooooo00Go6P3ooooooooooooo
oooooeOo0007ooooo`03oed0oooooooooooo00;ooooo1Ol0i?l00omY0?oo0>Coo`3To`03o`3To`Co
oooo00?o0?o`ooooooooool00_ooool00ol02_ooooooooooo`08ooooo`03o`0doooooooooooo01Oo
oooo0_l0ofDEooooo`Co>?l01oooool2o`10oa;ooooo1Ol0[_mYooooo`Oo0?nEY?ooool00005oooo
ool0003oooooooooool000001oooool01?l0003oooooooooool0000:ooooo`Co00002_ooool01_l0
4?oo02SoobH0oomMo`3oooooocko00;ooooo01;o9P3oocSo0?l0oi_oooooof?o0?oooooo02koo`3`
ool0o`[o04coo`3Hoooooooo0?mUooooool0:?ooooooo`3Tool0oc@2ooooo`06o`23ool0D_oo013o
o`3foooooooo0?mI1Oooool5o`3o>PGooooo0ol0ocX4ooooo`0Ho`3oFOooooooooooooooool0D_oo
013oo`23ool0ogOo0?lXo`3Tool0:?oo0?l:ooooool0C?oo0=Soooooool0;_oo>?l0obH0ool02_oo
6P3oo`3oVol0OOooE`3o2_ooool02OmG0?ooooooo`1moolJ0?ooooooo`3oVol02_oo043oocSo0002
ooooo`07obH0ooooooooHol0oooooomMo`3oooooo`3`o`05ooooo`05o`3Hoooooooo0?nEooooool0
o`X01?ooool02?l0oo3o9P3ooooooooooooo0?mUo`0doooooooo0?m<0oooool01_l0o`[oE`3ooooo
oooooooo>?l0ofT0o`;o0>Co00?oEol0ooooooooool00ol0Sol4ooooo`04oaX0oooooooooooooeOo
00Sooooo00?oG@3oooooooooool01?ooool01?l0odcooooooooooomY0?l5ooooo`Go0>Co1Oooool0
0ol02_ooooooooooo`06ooooo`03o`0doooooooooooo01[ooooo0_l0ofD>ooooo`Go>?l03Oooool0
0ol0@?ooooooooooo`09ooooo`Ko0:koMOooool7o`3oUIgooooo00001Ooooooo0000oooooooooooo
000000Sooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0;ooooo`05o`0@ool0:?oo
0?nKobH0oomMo`000oooool04OlV0?oo0?nKoooooomSo`3oooooo`0^ool0l?oo0?l:ooooool0C?oo
ooooo`3oIOl0obSo02Soooooool0i?oo0?ld00;ooooo00Ko08?oo`1Bool04?oo0?Koooooool0oeT5
ooooo`03o`3o>_oooooooooo00?ooooo1_l0ob82ooooo`;o0?lj0oooool05ol0oeWoooooooooool0
D_oo0?Koo`0@ool0ogOoooooo`3Tool0:?oo0?mUooooool0oiGo04coof?o0?l0;_oo>?l0obH0ool0
2_oo6P3oo`3oVol0OOooE`3o00Wooooo00WoE`3oooooool0OOoo6P3oo`3ol?oooooo0?nKo`0:ool0
@?l00oooool01_lV0?ooooooof?o0?mMo`3oooooo`3`o`Gooooo00Go0=Soooooool0oiGoooooo`3o
2P05ooooo`04o`3ol?oooooo9P3oo`3oI@;ooooo00?o03Coo`3oC?ooool00oooool01Ol0o`[oE`3o
o`3Tool0i?ooJ@3o00;ooooo00?oGOl0oeOo0?ooool02?ooool00olJ0?ooEol0ooooo`09ooooo`03
oed0oooooooooooo00?ooooo00Co0?m<ooooooooooooJ@3o2?ooool00ol0oo3oooooo`3To`02o`3T
o`;ooooo00?o00[oooooooooool01Oooool00ol0=?ooooooooooo`0Mooooo`;o0?mU1oooool5ocSo
01?ooooo0_l0@?l5ooooo`Co0:koP_ooool8o`3oUIGooooo00001Ooooooo0000oooooooooooo0000
00Wooooo0_l0000:ooooo`03o`000?oooooooooo00_ooooo00Co05Woo`0@ool0oi_o0?l:1?lV0?l0
0ol0oi_oHol0of?o0002ooooo`0;o`0^ool0l?ooooooo`1<ool0f?oo0?mUo`3o:?l0:?ooooooo`3T
ool0oc@00oooool01Ol0D_oo013oo`3foooooooo0?mI00Gooooo00?o0?ljooooooooool01?l0ob86
ooooo`?o0?lR00Goooooo`3o>_ooooooooooo`3oF@03ooooo`0Do`1Bool04?ooooooo`3oMol0ocCo
02Soo`3oIOoooooo0?nEo`1<oomSo`3o02kooooooolV0?oo00[ooooooolJ0?oo07gooeL0ool0oo08
ooooo`09oeL0oooooooo07gooaX0oooooooo0?nKo`0:oooooooo043o00;ooooo00Oo9P3ooooooomS
o`3ooooooego0?oooooo0?3o00Gooooo00Co0=Soooooool0oiGo0?l:1oooool00ol0oo3o9P3ooooo
o`02ooooo`04o`0dool0odcoooooooooo`?o0>Co00SoE`3ooooooolho`3oooooofT0ooooooooGOl0
oeOo00Wooooo00?o6P3oooooooooool02_ooool00omM0?ooooooooooo`02ooooo`03o`3oC?oooooo
J@3o00Wooooo00?o0?o`ooooooooool00_ooool3o`3To`03o`0:oooooooooooo00Cooooo00?o03Co
ooooooooool07oooool3o`3oI@Co>?l06_ooool2o`10o`?o0:koS_ooool8o`3oUE[ooooo9?mSo`0?
ooooo`000_ooool2o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`1Iool04?oo02ko00;o0?nK0_ooool2o`3oV`Cooooo00_o02koooooool0[_oo04coo`3Hool0
obSoooooo`0Xoooooooo0>Coo`3o=002ooooo`05o`1Bool04?oo0?Koooooool0oeT01?ooool2o`3o
>P03ooooool0ob;o0?lR00Gooooo1Ol0j_l3ooooo`03o`3o8_oooooo0?lj00;ooooo00[o0?mIoooo
oooooooo05;oo`0@ool0Pooo0?mgo`3o:?l0i?oo02So0_ooool02ol0C?ooGOl0o`0^oooooooo>?l0
obH0oooooooo6P3oo`3oJol0OOooE`3o00Oooooo00WoE`3ooooooooooooo07gooaX0oooooooo0?nK
o`0:ool0@?l00oooool01?lV0?ooooooof?o0?mMo`02ooooo`03o`3`oooooooooooo00?ooooo00?o
0=Soo`3oUOl0o`X02?ooool00ol0oo3o9P3oooooo`02ooooo`04o`0dool0odcoooooo`3To`;ooooo
00Ko?_l0oeL0ooooooooooooocSo0?mY0?l2ooooo`03oego0?mGo`3oEol000Kooooo00?oEol0oooo
oolJ0?l02oooool01OmM0?oooooooooooooooooo0?m<00;ooooo00?oJ@3oooooooooool01oooool0
0ol0oo3oooooooooo`05ooooo`03o`3Tool02_oooooo00?ooooo00?o03Coooooooooool06oooool6
ocSo00;ooooo0_l0ofDKooooo`?o0:ko0_l0@?nGooooo`So0?nE>_oooolHof?o03?ooooo000Joooo
o`03o`000?oooooooooo00_ooooo00Co09_oo`0@ool0;_oooooo0ol0oi/2of?o00?ooooo00_o02ko
o`3`oooooooo04coo`3Hool0ofGoooooo`0Xoooooooo0>Coo`3o=002ooooo`05o`23ool04?oo0?Ko
ooooool0oeT00oooool2o`3o>P;ooooo00?o0?lRooooooooool00_ooool:o`1[o`05o`3Zoooooooo
0?lRo`3o8_l0ocX00_ooool05_l0oeWoooooooooool0D_oo013oo`3oMooooooo0>Coo`0Xool0o`[o
ooooo`1<ool0f?oo02kooooooolho`3o9P3oo`0:oolJ0?oo0?nKo`1moomG0?l7ooooo`04oeL0oooo
oooo07gooaX0o`;ooooo00?o00[oooooool0@?l00oooool01_lV0?ooHol0oooooomMo`3oooooo`3`
o`Gooooo00Co0=Soooooool0oiGo0?l:1oooool00ol0ofGo0?o`obH0o`03ooooo`03o`0dool0i?oo
0>Co00Cooooo00GoE`3oo`3o2_oooooo>?l0ofT0o`02ooooo`03oego0?ooooooEol000Gooooo00Co
Eol0oooooooooooo6P3o3?ooool01_mM0?ooooooooooool0odcoooooofT0o`Wooooo00?o0?o`oooo
ooooool02?ooool01Ol02_oo0>Cooooooooooooo03Co01Oooooo1_lho`0:ooooo`;o0?mU5_ooool3
o`2^o`Gooooo0_l0@?nMooooo`[o0?nE6OoooolGof?o04_ooooo000Jooooo`03o`000?oooooooooo
00cooooo00Go013oo`0Xool0;_ooooooo`3o2P05ooooo`0;o`0^oooooooo0?3oo`2^ool0C?oo0=So
ooooool0:?ooooooo`3Tool0oc@00_ooool01Ol0Pooo05;oo`0@ool0m_oo0?mI00?ooooo00?o0?lj
ooooooooool00_l0ob82ooooo`?o06_o2_ooool01Ol0Jooo08Wooooooooooooo0?lj00?ooooo01Go
0?mIooooool0D_oo013oooooool0ogOo0>Coo`0Xool0o`[oooooo`1<ool0f?oo0?3oo`0^oolho`3o
9P3oo`0:oooooooo6P3oo`3oJomG0?l01_ooool02_mG0?ooooooo`1moooooooo6P3oooooool0oi_o
00[oooooool0@?l2ooooo`04obH0ooooooooHol0oego00;ooooo00?o0?3oooooooooool00oooool0
0ol0f?oo0?nEo`3o2P07ooooo`05o`3oIOoooooo0?o`oooooolV0?l00_l0i?l00ol0=?oo0?m<oooo
o`04ooooo`05oeL0oooooooo0?l:ocSo0?mY0?l00oooool00omMo`3ooooooeOo0004oeOo00Cooooo
00?o6P3oooooooooool02Oooool01_mM0?ooooooooooool0odco?_l0ofT0o`Wooooo00?o0?o`oooo
ooooool02?ooool01?l02_ooooooo`3Tool0=?l?ooooo`Wo>?l04_ooool2o`3oIA7ooooo0ol0[_l:
ooooo`;o043oYOooool;o`3oU@koHol0H_ooool001[ooooo00?o0000ooooooooool03?ooool01?l0
4?oo02Soo`2^ool0;_l5o`3o2P08o`0^oooooooo0?3oooooool0C?oo0=Soooooool0:?l2ooooo`08
o`3Tool0ocCoooooo`23ool0D_oo013oo`3fool0oeT3ooooo`04o`3o>_ooooooooooo`3o8P;ooooo
0_l0Jol00ol0ROooooooooooo`0;ooooo`;o06_o00?o0>[oo`3o8_l0ocX00_ooool05_l0oeWooooo
ooooool04?oo08?oo`3oMol0ocCo02Soo`3oIOoooooo04coo`2^oooooooo02koocSo0?lV0?oo00[o
oooooolJ0?oo0?m[o`1moomG0?l3ooooo`;oE`3o00Woooooo`1moooooooo6P3oo`3oJooooooo0?nK
o`0:ool0@?l00oooool01_lV0?ooooooof?o0?mMo`3oooooo`3`o`Gooooo00?o0=Soooooool0oiD0
1oooool01_l0ofGoooooooooool0oo3oooooobH0o`;ooooo00?o03Coo`3oC?ooool01?ooool01OmG
0?ooooooooooool0o`[oJ@3o00Cooooo00?oGOl0ooooooooool01oooool00olJ0?ooooooooooo`0:
ooooo`05oed0ool0odcoooooocko0?mY0?l02Oooool00ol0oo3oooooooooo`09ooooo`03o`0:oolh
o`3o03Co00;o0>Co3Olho`0Mooooo`?o0?mU2oooool3o`2^o`oooooo0_l0@?nDoooooa7oHol02Ooo
ool<o`3oUFCooooo000Jooooo`03o`000?oooooooooo00cooooo00?o05Woo`0@ool0C?l00_l0;_l2
ooooo`;o02ko0_ooool02Ol0l?oo04coo`3oIOl0f?ooooooo`0Xoooooooo0>Coo`3o=002ooooo`04
o`1Bool04?oo0?Koo`3oF@?ooooo00Co0?ljoooooooooooo0?lR0_ooool00ol0Jooo08Woo`29o`0@
ooooo`04o`1[ool0j_oo0?lRo`3o>P;ooooo01Go0?mIooooool0D_oo013oo`3oMol0obSo02Soo`3o
IOoooooo0?nEo`1<oomSo`3o02koocSo0?lV0?oo043oo`0:oolJ0?ooooooo`1mool0oo001?mG0?l2
ooooo`08o`1mool0oo3o6P3oooooool0oi_o00[oooooool0@?l2ooooo`04obH0ooooooooHol0oego
00;ooooo00?o0?3oooooooooool00oooool00ol0f?oo0?nEooooo`06ooooo`07o`3oIOoooooooooo
ooooool0oo3o0>CoobH0o`02ooooo`03o`0dool0obSo0?m<00Co0?lX00GoE`3oocko0?oooooooooo
ofT0o`04ooooo`03oego0?oooooooooo00Sooooo00?o6P3oooooooooool02Oooool01?mM0?oo0?m<
ocko0?mY0?l9ooooo`03o`3ol?oooooooooo00Gooooo1Olho`000ooooooo00[oooooo`02ooooo`03
o`3Toooooooooooo02[ooooo0_l0ofD7ooooo`;o0:ko5?ooool2o`10ohOooooo2omSo`0Vooooo`co
0?nEF?ooool001[ooooo00?o0000ooooooooool03?ooool01?l0FOoo013oo`0Xool0C?l4o`0^o`;o
oooo00Wo0?3oo`1<ool0ofGo0=Soooooool0:?ooooooo`3Tool0oc@00_ooool01?l0Pooo013ooooo
ool0m_l3ooooo`04o`3o>_ooooooooooo`3o8P;ooooo00?o06_oo`29ooooool04_ooool01_l0Jooo
ooooo`3o8_l0oc[oooooo`3oF@;ooooo01?o013oooooool0ogOo0>Coo`0Xoooooooo0?nEo`1<oomM
o`3o02koocSo0?oooooo9P3oo`0:oolno`3o6P3oo`3oJol0OOoo0?o`00Cooooo00Wo07goo`3ol?lJ
0?oo0?m[ooooool0oi_o00[oo`10oolho`000_ooool01?lV0?ooooooof?o0?mMo`02ooooo`03o`3`
oooooooooooo00?ooooo00?o0=Soo`3oUOooool01Oooool00ol0ofGoooooooooo`02ooooo`03o`3T
ool0obSo9P3o00;o0?lX00?o03Coooooool0od`01?ooool01_l0obSoE`3oo`3o:?l0obSo>?l0ofT0
o`Cooooo00?oGOl0ooooooooool01oooool00olJ0?ooooooooooo`0:ooooo`03oed0oolno`3oJ@3o
00Wooooo00?o0?o`ooooooooool00_ooool3ocSo00Gooooo00?o03Coooooool02_l00oooool2o`3T
obcooooo0ol0ofD01?oooooo0:koo`2^ool0[_lHooooo`;o043oNoooool:of?o03gooooo3?l0oiE<
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`05o`1Iool04?oo02Soo`1<ool0[_l00oooool2
o`3`o`0>o`1<ool0ofGo0=Soooooool0:?ooooooo`3Toooooooo0?ldooooool0Pooo05;oo`0@ool0
m_l3ooooo`04o`3o>_ooooooooooo`3o8P;ooooo00?o06_oooooooooool01?ooool9o`3oDPOooooo
00Go06_oooooool0oc[oooooo`3oF@02ooooo`0Do`0@ool0Pooo0?mgo`3Tool0:?ooooooo`3oUOl0
C?ooGOl0o`0^oooooooo>?l0obH0ool02_oooooooaX0oooooooo0?m[o`1mool0oo02ooooo`;o07go
00Oo0?o`oaX0oooooooo0?nKo`0:oooooooo043o00;ooooo00Co9P3oooooooooooooGOl00_ooool0
0ol0l?ooooooooooo`03ooooo`03o`3Hool0oiGooooo00Gooooo00?o0?mUooooooooool00_ooool0
1?l0i?oo0?lXo`3ol?lV0?l2ooooo`03o`0doooooooo0?m<00Gooooo00KoE`3ooooooooooooo0?lX
ofT0ool0obP3ooooo`03oego0?mSo`3ooooo00Sooooo00?o6P3oooooooooool02?ooool00ol0odco
?_l0ofT0o`0:ooooo`03o`3ol?oooooooooo00;o>?l02?ooool00ol0=?ooooooo`0:o`05ooooo`03
o`3Toooooooooooo02[ooooo0ol0[_l00ol0ofGoooooooooo`0Jooooo`;o043oLOooool8of?o05?o
oooo2ol0oiE1ooooo`006_ooool00ol0003oooooooooo`0<ooooo`04o`1Iool04?oo05;oo`0Xo`;o
04co0_l0l?l2o`1<o`04o`3oIOoooooo0=Soo`0Xo`;ooooo00Oo0>Coo`3o=?oooooo08?oo`1Bool0
4?oo0?Ko00?ooooo00Co0?ljoooooooooooo0?lR0_ooool01?l0Joooooooooooooooool4o`3oDP03
ooooool0om;o0?oB00Ko0?oB00?o0?mBooooooooool01?ooool06Ol0Joooooooo`3o8_l0oc[ooooo
o`3oFOoooooo05;oo`0@ool0ogOo0>Coo`0Xool0o`[oooooo`1<ool0f?oo02kooooooolho`3o9P3o
o`0:oooooooo6P3oo`3oVol0of/01?l0OOl2o`3ol007oaX0oolno`3oooooo`3oVol02_ooooooo`10
o`02ooooo`04obH0ooooooooHol0oego00;ooooo00?o0?3oooooooooool00oooool00ol0f?oo0?nE
ooooo`02o`0^o`;ooooo00?o0?mUooooooooool00_ooool01Ol0i?oo0?lXooooool0oo3o9P3o00?o
oooo00?o03Coo`3oC?ooool01?ooool01_mG0?oo?_l0ooooooooooooJ@3oo`3o2P;o0?lX0_ooool0
0omMo`3oooooooooo`07ooooo`03oaX0oooooooooooo00Sooooo00?o0?m<oooooomY0?l02Oooool0
1?l0oo3ooooooooooolho`09ooooo`05o`0dooooooooooooooooool02_l01Oooool2o`3TobWooooo
00?o0:koooooooooool00_ooool3o`3oIA_ooooo0_l0@?mWooooo`SoHol0I_ooool<o`3oUCGooooo
000Jooooo`03o`000?oooooooooo00cooooo00Ko09_oo`1Iool04?ooooooo`0Xooooool3o`1<o`0>
o`3oIOoooooo0=Soooooool0:?ooooooo`3Toooooooo0?ldo`23ool0D_oo013oo`3oFOl0m_l2oooo
o`04o`3o>_ooooooooooo`3o8P;ooooo00?o06_oo`29ooooool00_l0oe800ooooooo0?oBo`3odP02
o`3odPSooooo0_l0om82o`3oDPCooooo00?o06_oooooool0ocX00_ooool04ol0oeWoooooo`0@oooo
oooo0?mgo`0Xool0o`[oooooo`1<ool0f?oo0?3oo`0^oolho`3o9P3oo`10ool02_oooooooaX0ool0
of/01_ooool01olJ0?ooooooooooool0oi_o00[oo`10oolho`000_ooool00olV0?oooooooego0002
ooooo`03o`3`oooooooooooo00Cooooo00?o0=Soo`0^ool0;_l00_ooool00ol0;_oo0?mUooooo`02
ooooo`;o0?lX00Ko0>Cooooooooooooo0?o`oooooolV0?l2ooooo`03o`0dool0odcooooo00Cooooo
00WoE`3oocko0?ooooooooooofT0oooooooo0?l:ooooool0obP00_ooool00omMo`3oooooooooo`07
ooooo`03oaX0oooooooooooo00Oooooo00Co0?m<oooooomY0?ooG@3o2?ooool00ol0oo3o>?l0ocSo
000:ooooo`03o`0doooooooooooo00;ooooo00?o00[oooooooooool01?ooool00ol0i?oooooooooo
o`0Tooooo`;o0:ko2?ooool2o`3oIA_ooooo0_l0@?mMooooo`SoHol0N_ooool;o`3oUA_o0?ld3ooo
ool001[ooooo00?o0000ooooooooool03Oooool01?l0FOoo013oo`1Bool0:?l4ooooo`;o0=So0_l0
:?l02Ooooooo0>Coooooool0ocCo08?oo`1Bool04?oo0?mIo`3fo`02ooooo`04o`3o>_oooooooooo
o`3o8P;ooooo00Co06_oo`29oooooooo0?mB0_ooool01?l0om;oooooooooooooool:o`3<o`03oooo
ool0om;o0?oB00Gooooo01So06_oo`3o8_l0oc[oooooo`3oFOoooooo013oo`23ool0ogOo02Soo`3o
2_oooooo04coo`3HoomSo`3o02kooooooolho`3o9P3oo`0:oooooooo6P3oocko0?l0of/4ooooo`07
oaX0ooooooooooooo`3oVol02_ooooooo`10o`02ooooo`04obH0ooooooooHol0oego00;ooooo00?o
0?3oooooooooool00oooool00ol0f?oo02koooooo`03ooooo`07o`3oIOl0;_oo02koooooool0obSo
ooooo`3To`03ooooo`03o`3ol?oooooo9P3o00;ooooo00?o03Coo`3oC?ooool01?ooool03OmG0?oo
?_l0ooooooooooooJ@3oocSo0?oooooo0?l:ooooool0obSooooooego0?mSo`002?ooool00olJ0?oo
ooooooooo`06ooooo`03o`3oC?ooooooJ@3o00;ooooo00?oG@3oooooooooool01Oooool00ol0oo3o
ooooooooo`09ooooo`03o`0doooooooooooo00?ooooo00?o00[oooooooooool01Oooool2o`3Tob?o
oooo00?o0:koooooooooool02_ooool3o`3oIA[ooooo0_l0@?mCooooo`SoHol0KooooolGo`3o=0Oo
oooo2ol0oiDOooooo`006_ooool00ol0003oooooooooo`0=ooooo`04o`1Iool04?oo05;oo`3To`;o
02So0_l0f?l03?oooooo02Sooooooooooooo0>Coooooool0ocCo08?oo`1Boooooooo013oo`3fo`;o
oooo00Co0?ljoooooooooooo0?lR0_ooool01Ol0Jooo08Woo`3oD_l0oe;ooooo00;o0?oB00Cooooo
o`3<ool0c?oo0<co0_l0oh<4ooooo`?o0?n30_l0c?l2ooooo`03o`3od_oooooooooo00;ooooo00?o
06_oo`3Zool0ocX00_ooool03ol0oeWo05;oo`0@ool0ogOo02Soo`3oIOoooooo04coo`2^oomMo`3o
02kooooooolho`3o9P3oo`0:o`02ooooo`03oaX0oooooooo0?m[00;o0?m[00So6P3ooooooooooooo
ooooo`3oVol02_oo043oocSo00;ooooo00Co9P3ooooooomSo`3oGOl00_ooool00ol0l?oooooooooo
o`03ooooo`03o`0^oooooooooooo00?ooooo00Ko0?mUooooool0;_oo0?lXooooool0i?l4ooooo`03
o`3ol?oooooo9P3o00;ooooo00?o03Coo`3oC?ooool01?ooool00omG0?oo?_l0ooooo`02ooooo`09
ofT0ooooooooooooo`3o2_oooooo0?lXoooooomMo`3oHol000Sooooo00?o6P3oooooooooool01Ooo
ool00ol0odcoooooofT0o`02ooooo`03oed0oooooooooooo00?ooooo00?o>?l0o`3ol?ooool02ooo
ool00ol0=?ooooooooooo`04ooooo`03o`0:oooooooooooo00Kooooo0_l0i?lOooooo`;o0:ko4?oo
ool2o`3oIA[ooooo0_l0@?m9ooooo`SoHol0H?oooolGo`3o=2Wooooo2ol0oiDDooooo`006_ooool0
0ol0003oooooooooo`0=ooooo`04o`1Iool0Jooo013oo`1Bo`;ooooo0ol0:?l3ooooo`0:o`3Toooo
oooo08?oo`1Boooooooo013oooooool0m_ooooooo`3o>P;ooooo00Ko0?lRoooooooooooo06_oo`29
ool0oe82ooooo`04o`3od_ooooooooooo`3<o`gooooo00Go0?n3o`3<ool0c?ooooooo`3odP04oooo
o`0Co`1[ool0ob;o0?ljooooool0oeWo05;oo`0@ool0ogOo02Soo`3oIOoooooo0?nEo`1<oomMo`3o
02kooooooolho`3o9P3oo`0:o`02ooooo`05o`3oVolJ0?oo?_l0oooooolJ0?l00oooool01ol0oi_o
ooooo`0:ool0@?oo>?l0oooooolV0?l00_ooool01?mMo`3oooooooooool0l?l5ooooo`03o`0^ool0
oiGooooo00?ooooo00Ko0?mUoooooooooooo02koooooool0i?l5ooooo`03o`3ol?oooooo9P3o00;o
oooo00?o03Coooooool0od`01?ooool00omG0?ooooooocko0002ooooo`04ofT0ooooooooooooo`3o
2P;ooooo0_l0obP00omSo`3oooooooooo`06ooooo`03oaX0oooooooooooo00Cooooo00?o?_l0o`3o
C?mY0?l01?ooool01omM0?oooooooooooooooooo>?l0ooooool0oo002oooool00ol0=?oooooooooo
o`05ooooo`03o`0:oooooooooooo00Sooooo00?o0>Coooooooooool06oooool00ol0[_oooooooooo
o`0Booooo`?o0?mU6Oooool2o`10ocoooooo2?mSo`1Foooooa;o0?ldBoooool5o`3oU@oooooo000J
ooooo`03o`000?oooooooooo00gooooo00Go09_oo`1Iool0m_oo013oo`3To`06ooooo`0:o`3Tool0
ocCo08?oo`1Bool0ogOo013oooooool0m_ooooooo`3o>P;ooooo00Co0?lRoooooooooooo06_o0_l0
oe801?oooooo0?oBo`3od_ooool2o`3<o`oooooo0_l0oh<00ol0c?ooooooo`3odP03ooooo`0Co`1[
ool0j_oo0?lRo`3o>_l0oeWoooooo`0@oooooooo0>Coo`0Xool0o`[o0?nEo`1<oomMo`3o02kooooo
oolho`3o9P3oo`0:o`02ooooo`04o`3oVolJ0?oo6P3ooaX0o`?ooooo00Go0?nKooooool02_oooooo
o`10o`02ooooo`04obH0ooooooooHol0oego00;ooooo00?o0?3oooooooooool00_ooool00ol0o`[o
02koo`3oU@03ooooo`07o`3oIOooooooooooooooool0;_ooooooo`3To`05ooooo`03o`3ol?oooooo
9P3o00;ooooo00?o03Coooooool0od`01Oooool01_mG0?oo?_l0ooooooooooooJ@3oocSo00;ooooo
00Co0?l:oooooooooooooooo0_l0obP8ooooo`03oaX0oooooooooooo00?ooooo00?o0?m<oooooomY
0?l01Oooool00omM0?oo>?l0ocSo0002ooooo`03o`3ol?oooooooooo00Wooooo00?o03Cooooooooo
ool01_ooool00ol02_ooooooooooo`08ooooo`;o0>Co6_ooool00ol0[_ooooooooooo`0Fooooo`;o
0?mU6Oooool3o`10ocGooooo1omSo`1Cooooo`_o0?ldLOooool001[ooooo00?o0000ooooooooool0
3Oooool01Ol0Vooo05Woo`1[ool04?oo05;o00;o0>Co0_ooool2o`3To`09o`3o=?l0Pooo05;oo`3o
Mol04?ooooooo`3foooooooo0?lj00;ooooo00Go0?lRoooooooooooo06_oo`3oDP02ooooo`04o`3o
d_l0c?oo0<coo`3<o`Cooooo0ol0ol`6o`3omP?o0?o<0oooool01?l0oh?o0<coo`3od_l0oe83oooo
o`0Co`1[ool0ob;o0?ljooooool0oeWo013oo`23ool0ogOo02Soo`3o2_oooooo04coo`3Hool0;_oo
ooooocSo0?lV0?oo043oo`0:o`02ooooo`03o`3oVooooooooooo00?ooooo00Oo0?nKo`0:oooooooo
043oocSo0?oooooo9P3o00;ooooo00GoHol0oego0?ooooooooooo`3`o`04ooooo`03o`0^ool0f?oo
oooo00?ooooo00Ko0?mUoooooooooooo0?lXooooool0;_l6ooooo`03o`3ol?oooooo9P3o00;ooooo
00?o03Coooooool0od`01Oooool01_mG0?oo?_l0ooooooooooooJ@3oocSo00?ooooo00Go0?l:oooo
oooooooooooooego0002o`3o:0Kooooo00?o6P3oooooooooool00_ooool01?lno`3o0?m<oooooomY
0?l5ooooo`03oed0oooooooooooo00;ooooo00?o0?o`ooooooooool02?ooool00ol0=?oooooooooo
o`08ooooo`03o`0:oooooooooooo00Wooooo00?o0>Coooooooooool05_ooool00ol0[_oooooooooo
o`0Iooooo`?o0?mU6Oooool2o`10obcooooo1omSo`1>ooooo`co0?ldO?ooool001[ooooo00?o0000
ooooooooool03_ooool01Ol0FOoo06_oo`0@oooooooo05;o00?o0>Co00[oooooo`3o=?oooooo05;o
o`3oMol04?ooooooo`3foooooooo0?lj0_ooool01Ol0ob;oooooooooool0Jooo0?mB00;ooooo00?o
0?oBo`3<ooooool01?ooool00ol0olco0?ofo`3omP02o`3omPKooooo1?l0ooH3ooooo`04o`3oPol0
c?oo0?oBo`3oDP?ooooo01;o06_oo`3o>_oooooo0?mIo`1Bool04?oo0?mgo`0Xool0o`[oooooo`1<
ool0f?oo0?3oo`0^oooooooo>?l0obH0ool02_l3ooooo`06o`3oVoooooooooooooooool0oi_o00[o
0_ooool01?l0@?oo>?l0oooooolV0?l2ooooo`04oego0?ooooooooooo`3`o`Cooooo00?o0?l:o`0^
ool0oiD00oooool02?l0ofGoooooooooool0obSoooooo`3Toooooooo02ko1Oooool00ol0oo3ooooo
obH0o`02ooooo`03o`0doooooooo0?m<00Gooooo00?oE`3ooooooolno`000_ooool00omY0?oo>?l0
ooooo`02ooooo`06o`3o2_oooooooooooego0?ooooooHol00_l0obP5ooooo`07oaX0oooooooooooo
ocko0?oooooo0?m<ofT0o`04ooooo`;o>?l000Gooooooed0ooooooooooooo`3ol00;ooooo`03o`0d
oooooooooooo00Sooooo00?o00[oooooooooool02_ooool2o`3ToaCooooo0_l0[_lOooooo`;o0?mU
6Oooool3o`10ob;ooooo1omSo`19ooooo`co0?ldR?ooool001[ooooo0ol0000>ooooo`05o`2Kool0
FOoo0?Koo`0@ooooool00_l0D_l2o`23o`;o05;o00Ko0?mgo`0@oooooooo0?Koooooool0ocX2oooo
o`05o`3o8_ooooooooooo`1[ool0ROl00_ooool00ol0om;o0<coooooo`03ooooo`;o0?o<00?o0?of
ooooooooool03?ooool02?l0ooKo0?o<oooooooooooo0<coooooool0om;o0?mB0_ooool04ol0Jooo
0?lRo`3o>_l0oeWo05;oo`0@ool0ogOo02Soo`3oIOoooooo04coo`3HoomMo`3o02kooooooolho`3o
9P3oo`10ool02_l00oooool3o`3oV`05ooooool02_ooooooooooool0@?l00_ooool01?lV0?oooooo
of?o0?mMo`02ooooo`07o`3`ooooooooooooooooool0o`[o02koo`3Ho`04ooooo`08o`3oIOoooooo
ooooo`3o:?oooooo0>Coooooool0;_l6ooooo`05o`3ol?lV0?ooooooooooool0=?l01Ol0Pol2oooo
o`03oeL0oooooooo?_l000;ooooo00?oJ@3oocSo0?ooool00_ooool01_l0o`[ooooooooooooooooo
GOl0of?o00;ooooo0_l0obP3ooooo`07oaX0ooooooooooooocko0?oooooo0?m<ofT0o`03ooooo`05
ocSo0?oooooooooooooooomM0?l00_ooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooooooo
00[ooooo00?o00[oooooooooool02oooool00ol0i?ooooooooooo`0@ooooo`03o`2^oooooooooooo
027ooooo0ol0ofDIooooo`?o043o6Oooool6of?o03WoooooW?l0m_l?ooooo`006_ooool00ol0003o
ooooooooo`0>ooooo`06o`2Kool0FOoo06_oo`3fool04?oo0?mg0ol0D_l2o`3oM`05o`0@oooooooo
0?Koooooool0ocX00_ooool01Ol0ob;oooooooooool0Jooo08Wo00;ooooo00?o0?oBo`3<ooooool0
0_ooool2o`3oc0;o0?of0oooool:o`1Io`?ooooo0_l0ooH2ooooo`03o`3<ool0om;o0?mB00;ooooo
01?o06_oo`3o8_l0oc[oooooo`1Bool04?oo0?mgo`0Xool0ofGoooooo`1<ool0f?ooGOl0o`0^oooo
oooo>?l0obH0ool0@?oo00[o00Kooooo00Oo00[ooooooooooooo043oocSo0?oooooo9P3o00;ooooo
00GoGOl0ooooooooooooooooo`3`o`03ooooo`03o`0^ool0f?oo0?nE00?ooooo00Ko0?mUoooooooo
oooo0?lXooooool0i?l2ooooo`03o`0^oooooooooooo00Cooooo00?o0?o`oooooolV0?l00_l0Pol0
0ol0=?oo0?m<ooooo`02ooooo`;o08?o00?oE`3ooooooolno`000_ooool00omY0?ooooooocSo0003
ooooo`06o`3o2_oooooooooooego0?ooooooHol00oooool2o`3o:007oooooolJ0?ooooooocko0?oo
oooo0?m<ofT0o`03ooooo`03ocSo0?oooooooooo00?ooooo00?oG@3oooooool0oo002_ooool00ol0
=?ooooooooooo`0;ooooo`03o`0:oooooooooooo00_ooooo0_l0i?l?ooooo`03o`2^oooooooooooo
02Gooooo0ol0ofDIooooo`;o043o4Oooool6of?o00kooooo<Ol0m_l00ooooooo0?ldo`3o=009o`3o
=3goooooA_l0ogLLooooo`006_ooool00ol0003oooooooooo`0?ooooo`04o`1Iool0Joooooooo`3f
o`;o013o0_l0ogL2o`0@o`04ooooool0m_ooooooo`3o>P?ooooo00Go0?lRooooool0Jooo08Wooooo
o`02o`3odP04o`3<ooooooooooooooooo`?o0?of0_ooool3o`1Io`;o0?nj2?ooool3o`1Io`03oooo
ool0olco0?of00;ooooo00?o0<coo`3od_l0oe800_ooool04ol0Jooo0?ljooooool0oeWo013oo`3o
:?l0:?oo0?mUooooool0[_oo04cooego0?l0;_ooooooocSo0?lV0?oo043oooooool02_l01Oooool0
1?l02_ooooooo`10oolho`02ooooo`04obH0ooooooooHol0oego00;ooooo00?o0?3oooooooooool0
0_ooool00ol0;_oo0=Soooooo`03ooooo`03o`3oIOoooooo0?lX00;ooooo00Co0>Cooooooooooooo
02ko1_ooool2o`23o`06obH0ooooooooooooo`0doooooooo0?m<1?ooool02?mG0?oo08?oo`23ooln
o`3oooooofT0oooooooo>?l01?ooool01Ol0o`[ooooooooooomMo`3ooooo00;oHol00oooool2o`3o
:005oaX0oolno`3oooooo`3oC?mY0?l00_ooool00olho`3oooooooooo`05ooooo`03oed0oooooooo
oooo00Sooooo00?o03Coooooooooool03?ooool00ol02_ooooooooooo`0=ooooo`03o`3Toooooooo
oooo00_ooooo00?o0:koooooooooool0:Oooool2o`3oIAWooooo0ol0@?l8ooooo`KoHol02?ooool<
o`3fobKooooo3?l0oc@Jooooobko0?mgH_ooool001[ooooo00?o0000ooooooooool03oooool01Ol0
Vooo05Woo`3oD_oooooo0?Ko00?o013o0_ooool00ol0m_ooooooo`3o>P03ooooo`06o`3o8_oooooo
06_oo`29oooooooo0?oB0_l0c?l3ooooo`04o`3om_ooooooooooooooo`;o05Wo00?o0?njoooooooo
ool03Oooool00ol0FOooooooo`3omP02ooooo`03o`3oPol0c?oo0?mB00;ooooo00go06_oo`3o>_oo
oooo0?mIo`1Bool04?oo0?mgo`0Xool0o`[o0:koo`1<oomMo`3o02ko00;ooooo00Go9P3oooooool0
@?ooooooo`0:o`02ooooo`;o00[o00Koooooo`10oooooooo>?l0oooooolV0?l2ooooo`05of?o0?mM
o`3oooooooooool0l?l00oooool00ol0;_ooooooo`3Ho`04ooooo`05o`3oIOl0obSoooooooooool0
i?l01?ooool01?l0;_ooooooooooooooool2o`23o`03o`3ol?oooooo9P3o00;ooooo00?o03Cooooo
ool0od`01?ooool01?mG0?ooooooooooool0Pol2ooooo`03ofT0oooooooo>?l000Cooooo00Co0?l:
ooooooooooooGOl00_ooool00omSo`3oooooooooo`02ooooo`07oaX0ool0obSoooooo`3oC?mY0?oo
ooooocSo0008ooooo`03oed0ooooooooHol000SoHol000Co03Coof?o0?mSo`3oHol03?ooool00ol0
2_ooooooooooo`0=ooooo`;o0>Co2Oooool2o`2^obkooooo0ol0ofDIooooo`;o043o1_mSo`02oooo
o`co0?Ko9_ooool<o`3o=0oooooo5ol0ogN@ooooo`006_ooool00ol0003oooooooooo`0?ooooo`04
o`2Kool0FOoo06_oo`3oDPKo0?Ko0_l0ocX3ooooo`04o`3o8_oooooo06_oo`29o`;o0?oB00Ko0<co
ooooooooooooooooo`3oc?l0ooH3ooooo`03o`1Iool0ok[o0?nj017ooooo00?o05Woooooool0ooH0
0_ooool04Ol0c?oo0?oBoooooooooooo06_oo`3o>_oooooo0?mIo`1Bool04?oo0?mgo`0Xool0o`[o
0?nEo`1<ool0f?oo02ko00;ooooo00Go>?l0obH0oooooooo043oooooo`02o`0:o`?ooooo00Go043o
ocSo0?ooooooooooobH0o`02ooooo`05oego0?ooooooooooooooool0l?l00oooool00ol0;_oo0=So
o`3oU@03ooooo`03o`3oIOoooooo0?lX00;ooooo00?o0>Coooooool0:?l00ol0:?l00ooooooo08?o
o`23o`02ooooo`03o`3ol?oooooo9P3o00;ooooo00?o03Coooooool0od`00oooool2o`3oF@03oeL0
ool0oeWo0?mI00;o08?o00?oJ@3oo`3oFOl0oeT01ol0oeT01?ooooooGOl0ooooooooool3of?o0007
ocko0?oooooo6P3oo`3oC?mY0?ooooooocSo0007ooooo`;oHol000?o0?o`oed0ooooool01oooool0
0ol0=?ooooooooooo`02ooooo`GoHol01oooool00ol02_ooooooooooo`0?ooooo`03o`3Toooooooo
oooo00Gooooo00?o0:koooooooooool0<Oooool2o`3oIA?ooooo0_mSo`04o`3fo`?o043o1Ol0m_lY
ooooo`Wo0?ld0ooooolHo`3oMjOooooo000Jooooo`03o`000?oooooooooo00oooooo00Ko09_oo`1I
ool0ROoo06_oo`3oD_ooool3o`3o>PCooooo0_l0ob801_l0oe;o06_oo`29ool0om;oooooo`3<o`?o
oooo00Co0?o<o`3om_oooooooooo0_l0FOl00ol0ok[oooooooooo`07ooooo`;o0?mm2Oooool06Ol0
FOooooooo`3om_oooooo0?n3o`3<ool0om;oooooo`1[ool0ob;o0?ljo`3oFOl0D_oo013oo`3oMol0
:?oo0?mUooooool0C?oo0=Sooego0?l0;_ooooooocSo0?lV0?l00_ooool01?l0@?oooooooooooooo
ool2o`10o`04oooooolho`3oooooobH0o`;ooooo00GoHol0oego0?ooooooooooo`3`o`03ooooo`03
o`0^ool0o`[o0=So00Cooooo00Go0?mUo`3o:?ooooooooooo`3To`02o`0Xo`?ooooo00?o02koo`0X
ool0:?l00oooool00ol0oo3oooooobH0o`02ooooo`04o`0doooooooo0?m<ooooo`;o0?mI0_ooool0
1_mG0?oooooooooooolno`3oooooofT0o`?ooooo00Ko>?l0ooooooooooooooooo`3o2_ooool4o`3o
F@?ooooo00Go?_l0of?o0?lJ0?oo0?m<ofT0o`02o`3o:0OoHol000Coooooo`3ol?ooooooG@3o2?oo
ool00ol0=?ooooooooooo`07ooooo`?oHol01Oooool00ol02_ooooooooooo`0?ooooo`;o0>Co1?oo
ool00ol0[_ooooooooooo`0dooooo`?o0?mU2Oooool9o`3fo`Oooooo0ol0@?lUooooo`03o`3o=?l0
ogOo0?mg00oo0?mg_oooool001[ooooo00?o0000ooooooooool04?ooool01Ol0Vooo05Woo`29ool0
Jooo0?lR00Gooooo0_l0ob801ooooooo0?mBo`1[ool0ROoo0?oBooooool0c?l00_ooool2o`3oc004
o`3om_ooooooooooo`1Io`;o0?nj1_ooool4o`3oO@;ooooo1?l0ogd6ooooo`0Eo`1Ioooooooo0?of
o`3oPol0c?oo0?oBo`3oD_oooooo06_oo`3o>_oooooo0?mIo`0@ool0ogOo02Soo`3oIOoooooo04co
o`3HoomMo`3o02ko00;ooooo00Co>?l0obH0oooooooo043o0oooool00ol0@?ooooooocSo0002oooo
o`04obH0oooooooooooooego00?ooooo00Oo0?3oooooooooooooooooo`0^ool0f?oo0?nE00?ooooo
00?o0?mUo`3o:?ooool00_ooool00ol0:?ooooooooooo`03ooooo`03o`0^ool0Pooo02So00?ooooo
00?o0?o`oooooolV0?l00_ooool01?l0=?oo0?mIo`3oFOl0oeT4ooooo`04oeL0ooooooooooooocko
00;ooooo00CoJ@3ooooooooooooo>?l01?ooool01Ol0o`[oooooooooooooooooGOl000Co0?mI0_oo
ool01?mY0?oo>?l0ooooooooool2o`3o:0Kooooo00Co0?o`ooooooooooooG@3o1_ooool00ol0=?oo
ooooooooo`0;ooooo`?oHol00oooool00ol02_ooooooooooo`0@ooooo`04o`3Tooooooooooooo`2^
oc[ooooo0_l0ofD2ooooo`Go0?Ko00?oHol0ooooooooool04?ooool4o`10oaOooooo2ol0ogO@oooo
o`006_ooool00ol0003oooooooooo`0@ooooo`04o`2Kool0FOoo0<coo`1[o`;o0?mB1?l0ob82oooo
o`07o`3oD_l0Jooo08Woo`3od_oooooo0<coooooo`02o`3oc0;o0?of00Coooooo`1Iool0FOoo0?nj
1_ooool2o`3oO@03ooooool0XOoo0:7o00Oo0:7o0ol0ogd3ooooo`0Eo`3o^_l0FOoo0?ofooooool0
oh?o0<coo`3od_oooooo06_oo`3o>_oooooo0?mIo`0@ool0ogOo02Soo`3oIOoooooo04coo`3HoomM
o`3o02ko00?ooooo00?o9P3oooooooooool00ol0@?l2ooooo`04ocSo0?ooooooooooobH0o`;ooooo
00GoGOl0ooooooooooooooooo`3`o`02ooooo`03o`0^ool0o`[o0=So00Cooooo00Go0?mUo`3o:?oo
ooooooooo`0Xo`06ooooo`04o`23ool0;_ooooooo`0Xo`;ooooo00?o0?o`oooooolV0?l00_l0oeT0
0ol0=?ooooooo`3oC005ooooo`08oeL0oooooooooooooooooolno`3oooooofT0ool0Pol2ooooo`;o
>?l00oooool2o`3o2P;ooooo00CoGOl0ocko0?mMo`3ooooo0_l0oeT00omY0?oo0?mIo`3oF@05o`3o
F@Cooooo00Go0?o`oooooooooooooooooed0o`05ooooo`03o`0doooooooooooo00kooooo0omSo`00
0ol02_ooooooooooo`0Aooooo`03o`3Tool0[_oooooo03Oooooo00?oHol0o`3fool0m_l01?l0m_l0
0ol0ofGoooooooooo`0Iooooo`?o043o2?ooool<o`3oM`Co0?ldeoooool001[ooooo00?o0000oooo
ooooool04?ooool01_l0Vooo0:7oo`1Iool0ROoo06_oooooo`Ko0?mB00Oo06_oo`29oooooooo0?oB
o`3<oooooooo0?o<00;o0?of0_ooool00ol0FOoo0?njo`3o^P04ooooo`?o0?mm0ol0XOl9ooooo`?o
0:7o01So0?mmooooooooooooooooo`1Ioooooooo0?ofooooool0c?oo0?mBo`3od_l0Jooo0?ljoooo
ool0oeWo05;oo`0@ool0ogOo02Soooooool0[_oo04cooego0?l0;_l3ooooo`03obH0oooooooooooo
00Cooooo00Co>?l0oooooooooooo9P3o0_ooool01OmSo`3oGOl0oooooooooooo0?3o00?ooooo00?o
02koo`3o2_l0f?l01?ooool01?l0ofGoooooooooool0:?l6ooooo`05o`23oooooooo02koooooool0
:?l00_ooool00ol0oo3o0?mIobH0o`02ooooo`03o`0doooooooo0?m<00Gooooo00WoE`3ooooooooo
ooooooooocko0?ooooooJ@3oooooool0Pol00oooool00olho`3oooooooooo`02ooooo`05o`3o2_oo
ooooooooocko0?ooool00_lho`000ol0odcoJ@3ooaX0o`06ooooo`Co0?mI00Go0?o`o`3oFOoooooo
oooooed0o`04ooooo`03o`0doooooooooooo01;ooooo00CoHol0o`0:oomSo`3oHol04?ooool00ol0
[_ooooooo`3To`0_ooooo`CoHol01Ol0m_l7ooooo`;o0?mU6oooool00ol0ogOo043oo`10o`02o`10
o`Co0?mg1?ooool6o`3o==gooooo000Jooooo`03o`000?oooooooooo017ooooo00Co09_oo`1Iool0
c?oo08Wo1ol0Jol01?l0ROoo0?oBo`3<ool0c?l2o`3oc003o`3om_oooooooooo00;o05Wo00Co0?nj
oooooooooooooooo0ol0ogd3o`2Qo`oooooo00?o0:7oo`3oOOooool00_ooool04ol0FOoo0?ofoooo
ool0oh?o0<coo`3od_oooooo06_oo`3o>_l0oeWo05;oo`0@ool0ogOo02Soo`3o2_l0[_oo04cooego
0?l0;_l00oooool00olV0?ooooooooooo`03ooooo`04ocSo0?ooooooooooobH0o`?ooooo00GoGOl0
ooooooooooooooooo`3`o`02ooooo`04o`0^ool0o`[o0=Soo`3oU@?ooooo00Go0?mUo`3o:?oooooo
ooooo`0Xo`05ooooo`04o`23ooooooooooooo`0^o`;ooooo00So02Soo`3oFOoooooo0?o`oooooolV
0?ooooooo`0do`;ooooo00?o0?m<ooooooooool00_ooool00omG0?ooooooooooo`02ooooo`05ocko
0?mY0?ooooooooooool0Pol00oooool2ocSo00?ooooo00Co0?l:ocko0?lho`3o>?l00_ooool00omY
0?oooooooaX0o`09ooooo`03o`3ol?l0obSo0?lX00?o0?mI00GoG@3oooooooooooooooooo`0do`0F
ooooo`03o`0:ooooooooHol000?oHol02oooool01?l0[_ooooooooooooooool2o`3TobKooooo1_mS
o`05o`3fo`kooooo0ol0ofDBooooo`Ko0?mg1Oooool4o`10o`Co0?ldhoooool001[ooooo00?o0000
ooooooooool04Oooool00ol0Vooo0:7oo`1Io`02o`3<o`;o08Wo00So06_oo`29ool0ROoo0?oBoooo
ool0c?ooooooo`3oc0;o0?of0_ooool00ol0FOoo0?njo`3o^P03ooooo`04o`3oOOooooooooooo`2Q
o`?ooooo2ol0olH4ooooo`03o`2Qoooooooo0?mm00?ooooo01;o05Woo`3om_oooooo0?n3o`3<oooo
oooo06_oo`3o>_l0oeWo05;oo`0@ool0ogOo02Soo`3oIOl0[_oo04coo`3Hool0;_l4ooooo`05obH0
oolho`3ooooooooooolho`000_ooool01_lV0?ooooooooooooooooooHol0oego00;ooooo00Oo0?3o
ooooooooooooooooo`0^ool0o`[o0=So00Cooooo00Co0?mUoooooooooooo02So1_ooool01Ol0Pooo
oooooooooooooooo02ko00;o0?mI00Go02Soooooool0oo3oooooobH0o`02ooooo`03o`0doooooooo
0?m<00Cooooo00?oE`3oooooooooool00oooool01OmY0?oooooooooooooooooo08?o00Cooooo1?lh
o`001_l0o`[ooooooooooooooooo0?m<ofT0o`;oGOl000?o6P3oooooooooool01_ooool00ol0oo3o
ooooooooo`02ooooo`03o`3o:?mM0?oo0?mI00;o0?mI00?o03Coooooooooool05?ooool00ol02_oo
ooooooooo`03ooooo`?oHol01oooool00ol0[_ooooooooooo`04ooooo`;o0>Co6_ooool:of?o00;o
oooo1?l0m_lFooooo`?o0?mU2Oooool6o`3oM`Sooooo1Ol0oc@2ooooo`?o043ocoooool6o`10o`oo
oooo000Jooooo`03o`000?oooooooooo01;ooooo00Ko09_oo`1Iool0ooKo0?ofo`3<ooooool2o`3o
dP03ooooool0c?oo0<co00;o0?o<00?o0?ofooooooooool00_l0FOl01?l0ok[oooooooooooooool2
o`3oO@04ooooool0XOoo0:7oooooo`?o0?o60_ooool8o`3oS`03ooooool0olKo0?o600?ooooo0_l0
XOl05_l0oggoooooooooool0ok[o05Woo`3oc?l0oh?o0<coo`3od_l0Jooo0?ljo`3oFOoooooo013o
o`3oMol0:?oo0?mUo`3oUOl0C?oo0=Sooego0?l0;_l4ooooo`03obH0oolho`3o>?l000;ooooo00?o
9P3oooooooooool00_ooool01OmSo`3oGOl0oooooooooooo0?3o00;ooooo00Co02koooooool0f?oo
0?nE1?ooool01?l0ofGoooooooooool0:?l5ooooo`03o`23oooooooooooo00;ooooo00So02koo`1B
ool0D_oo02Soooooool0oo3oooooobH0o`;ooooo00?o03Coooooool0od`01Oooool00omG0?oooooo
ooooo`02ooooo`03ocko0?mY0?oooooo00;ooooo00?o08?oooooooooool00oooool01?lno`3ooooo
ooooool0o`X2ooooo`05ofT0oooooooooooooooooolJ0?l01omMo`000ooooooo0?o`ooooo`05oooo
o`03oed0ool0obSo03Co00?o0?mI5Oooool00ol02_ooooooooooo`05ooooo`CoHol00_ooool00ol0
[_ooooooooooo`07ooooo`03o`3Toooooooooooo00oooooo2?mSo`08ooooo`Co0?Ko7Oooool2o`3o
I@03ooooool0ogOo0?mg00Co0?mg2?ooool6o`3o=0[ooooo1?l0@?o0ooooo`_o043o5Oooool001[o
oooo00?o0000ooooooooool04_ooool01Ol0Vooo0:7oo`1Ioooooooo0?of00Go0<co00?o0?o<o`3o
m_l0ooH00_ooool00ol0FOoo0?njo`3o^P03ooooo`04o`3oOOooooooooooo`2Qo`?o0?o60_ooool3
o`3oS`Sooooo0ol0ohl00ol0olKoooooooooo`02ooooo`0Fo`2Qool0oggoooooooooool0FOoo0?of
o`3oPol0c?oo0?oBooooool0Jooo0?lRo`3oFOl04?oo0?mgo`0Xool0ofGoooooo`1<ool0f?ooGOl0
o`0^o`Cooooo0_lV0?l2ooooo`;o9P3o1?ooool01OmMo`3ooooooooooooooooo0?3o00;ooooo00Co
02koo`3o2_l0f?oo0?nE0oooool01?l0ofGoooooooooool0:?l5ooooo`04o`23oooooooooooooooo
o`;o05;o00So02kooooooooooooo05;oo`0Xool0D_ooooooobH0o`;ooooo00?o03Coooooool0od`0
1Oooool00omG0?ooooooooooo`03ooooo`03ofT0oooooooooooo00;ooooo0_l0Pol2ooooo`03ocko
0?oooooooooo00;ooooo0_l0o`X00omY0?ooooooooooo`02ooooo`03oaX0oooooooooooo00Cooooo
00?o0?o`oego0?mMo`001OmMo`000omM0?ooooooo`0do`02o`3o:004ooooool0oeWo0?mIo`3oFA;o
oooo00?o00[oooooooooool02Oooool00omSo`3o0:koof?o000:of?o00;o0>Co3omSo`0=ooooo`?o
0?Ko7oooool5o`3oM`;o0?mU1oooool5o`3o=1Cooooo1?l0@?nbooooo`[o043o8?ooool001[ooooo
00?o0000ooooooooool04oooool01?l0Vooo0?njo`1Iooooool6o`3omP?ooooo00?o05Woo`3o^_oo
ool00oooool01Ol0oggoooooo`2Qool0XOoo0?o600?ooooo0_l0ohl4ooooo`Ko0?o01?ooool00ol0
ohoo0?o6o`3oaP03ooooo`0Eo`2Qooooooooooooo`3o^_l0FOooooooo`3oPol0c?ooooooo`1[ool0
oc[o0?mIo`1Bool04?oo0>Coo`0Xoooooooo04coo`3HoomMo`3o02ko00Kooooo0olV0?l4ooooo`05
of?o0?mMo`3oooooooooool0l?l00_ooool01?l0;_ooooooo`3o2_l0f?l4ooooo`04o`3oIOoooooo
ooooo`0Xo`Cooooo00So08?oooooooooooooooooo`1Boooooooo0?mIo`0^o`?ooooo00Co02Soo`1B
ool0D_oo9P3o0_ooool00ol0=?ooooooo`3oC005ooooo`03oeL0oooooooooooo00?ooooo00?oJ@3o
ocko0?ooool01?ooool00ol0Pooo?_l0ooooo`05ooooo`03o`3oC?mY0?oooooo00?ooooo00?o6P3o
ooooooooool01?ooool00ol0oo3oooooooooo`05ooooo`03oego0?mM0?oo03Co00;ooooo0_l0obP2
ooooo`;o0?mI4Oooool00ol02_ooooooooooo`08ooooo`03o`2^oooooooooooo00cooooo00?o0>Co
ooooooooool05_ooool3o`3foacooooo1_l0ogL7ooooo`;o0?mU1Ol0oc@Mooooo`Co043oXoooool;
o`10ob[ooooo000Jooooo`03o`000?oooooooooo01?ooooo00Co09_oo`3oa_l0ok[o05Wo2?ooool0
0ol0FOoo0?njooooo`03ooooo`03o`3oOOoooooo0:7o00;o0?o600Coooooo`3oSol0ohoo0?n?0_oo
ool3o`3o`0So09_o0_l0ol02ooooo`;o0?n?01So0?o6ooooooooooooooooo`2Qoooooooo0?njo`1I
ool0ooKo0?n3o`3<oooooooo06_oo`3o>_l0oeWo05;oo`0@ool0ogOo02Soo`3o2_l0[_oo04cooego
0?l0;_l=ooooo`05oego0?ooooooooooooooool0l?l00_ooool01?l0;_oo0?l:o`3Hool0oiD3oooo
o`04o`3oIOl0obSoooooo`0Xo`Gooooo00So08?ooooooooooooo05;oooooool0oeWoooooo`0^o`?o
oooo00Co02Soo`3ol?oooooo9P3o0_ooool00ol0=?ooooooo`3oC005ooooo`03oeL0oooooooooooo
00?ooooo00CoJ@3ooooooolno`3o?_l00_ooool2ocko0003o`23oooooooooooo00Cooooo00?oJ@3o
ooooool0o`X00_l0o`X2ooooo`03oaX0oooooooooooo00?ooooo00?o0?o`ooooooooool01_ooool0
1?l0=?ooG@3ooego0?mMo`02ooooo`;o0?lX0_ooool2o`3oFA3ooooo00?o00[oooooooooool01_oo
ool00ol0[_ooooooooooo`0>ooooo`;o0>Co4oooool3o`3foaWooooo1_l0ogL:ooooo`Go0?ld0ol0
ofDSooooo`Go043oT_ooool<o`10ocGooooo000Jooooo`03o`000?oooooooooo01?ooooo00Co09_o
o`2Qool0olKo0?nj2?l0FOl00ol0ok[oooooooooo`02ooooo`05o`3oOOl0XOoo0:7oo`3oa_ooool0
0_l0ohl3ooooo`;o0?o000?oooooo`2Kool0Vol01oooool4o`2Ko`05o`3o`?ooooooooooo`3oSol0
olH00_ooool05Ol0XOooooooooooool0ok[o05Woo`3oPol0c?ooooooo`1[ool0oc[o0?mIooooool0
4?oo0?mgo`0Xool0o`[o0:koo`1<ool0f?ooHol0o`0^o`0<ooooo`05oego0?ooooooooooooooool0
l?l00_ooool01?l0;_oo0?l:o`3Hool0oiD3ooooo`04o`3oIOooooooooooo`0Xo`Cooooo00Ko08?o
oooooooooooo05;oooooool0oeT2ooooo`03o`0^oooooooooooo00;ooooo00So02SooooooolV0?oo
05;oooooool0=?ooooooo`3oC0Gooooo00?oE`3oooooooooool01?ooool00omY0?ooooooocko0002
ocko00?ooooo00?o08?oooooooooool00oooool00omY0?ooooooooooo`02ooooo`;o0?l:00?o6P3o
ooooooooool00_ooool00ol0oo3oooooooooo`07ooooo`04o`0doomM0?ooooooooooo`?oGOl000?o
ooooo`3o:?l0obP00_ooool2o`3oF@kooooo00?o00[oooooooooool01_ooool00ol0[_oooooooooo
o`0@ooooo`03o`3Toooooooooooo00gooooo0ol0m_lGooooo`Go0?mg2oooool5o`3o=0Sooooo0_l0
ofDVooooo`Ko043oP?ooool<o`10od7ooooo000Jooooo`03o`000?oooooooooo01Cooooo00?o09_o
o`2Qool0ogd00_l0okX3ooooo`?o0?nj0oooool00ol0oggo0:7oo`2Qo`02o`3oaP;o0?n?0_ooool3
o`3o`0?o09_o3Oooool2o`2Ko`;ooooo00Go0?n?o`3oa_ooooooooooo`2Qo`02ooooo`0Ao`1Ioooo
oooo0<coo`3od_oooooo06_oo`3oFOoooooo013oo`3oMol0:?oo0?mUo`2^ool0C?oo0=Soof?o0?l0
;_l02oooool01OmSo`3oGOl0oooooooooooo0?3o00;ooooo00Co02koooooool0o`[o0=So0oooool0
1?l0ofGo0?lXooooool0:?l5ooooo`05o`23oooooooo05;oooooool0oeT01?ooool02_l0;_oooooo
oooooooooooo02SooooooolV0?ooooooo`1Bool0=?l2ooooo`03o`3oC?oooooooooo00;ooooo00?o
E`3oooooooooool01?ooool00omY0?ooooooooooo`06ooooo`03o`23oooooooooooo00;ooooo00?o
J@3oooooooooool01?ooool00ol0o`[o6P3oooooo`02ooooo`03o`3ol?oooooooooo00Oooooo00?o
03CooooooomM0?l01?ooool3oego00;o0?lX0_ooool2o`3oF@gooooo00?o00[oooooooooool01?oo
ool00ol0[_ooooooooooo`0Booooo`;o0>Co2oooool2o`3foaGooooo1Ol0ogL;ooooo`Go0?ld3ooo
ool3o`3oIBWooooo1_l0@?mXoooooa;o043oCOooool001[ooooo00?o0000ooooooooool05Oooool0
1?l0Vooo0:7oo`3oOOooool3o`3o^P?ooooo0ol0ogd00ol0XOoo0?o6o`3oaP02o`3oS`;ooooo0_l0
ol03o`2Koa;ooooo01[o09_ooooooooooooo0?n?o`3oa_oooooo0:7oo`3oOOoooooo05Woo`3om_l0
c?oo0?oBooooool0Jooo0?mIooooool04?oo0?mgo`0Xool0ofGo0?nEo`1<ool0f?ooGOl0o`0^o`_o
oooo00GoGOl0ooooooooooooooooo`3`o`02ooooo`04o`0^ool0o`[o0=Soo`3oU@?ooooo00Co0?mU
oooooooooooo02So1?ooool01Ol0Poooooooo`1Boooooooo0?mI00Gooooo00[o02kooooooooooooo
ooooo`0Xoooooooo9P3oooooool0D_oo03Co0_ooool00ol0odcoooooooooo`02ooooo`03oeL0oooo
oooooooo00Gooooo00?oJ@3oooooooooool01_ooool2o`23o`03oooooomY0?oooooo00Oooooo00Go
6P3oo`3o2_l0o`[oooooo`3ol008ooooo`04o`0doooooooooooooed0o`Oooooo0_mMo`02o`3o:0;o
oooo00?o0?mIooooooooool02_ooool00ol02_ooooooooooo`03ooooo`03o`2^oooooooooooo01Go
oooo00?o0>Coooooooooool01_ooool2o`3foaCooooo0ol0ogL<ooooo`Co0?ld5oooool2o`3oIBgo
oooo3?l0@?m:oooooa;o043oGoooool001[ooooo0ol0000Eooooo`04o`2Koooooooo0:7oo`3oaPKo
0?mm00?oooooo`2Qool0XOl00_ooool00ol0ohooooooooooo`02o`3o`0;o09_o5Oooool02?l0Vooo
0?o0oooooooooooo0?o6ooooool0XOoo0?mm0_ooool04Ol0FOoo0?n3o`3<oooooooo06_oo`3o>_l0
oeWo013oo`3oMol0i?oo02Soooooool0C?oo0=Sooego0?oooooo02ko00Wooooo00?oHol0oego0?oo
ool00_ooool01ol0l?ooooooo`0^oooooooo0?l:o`3Hool0oiD00oooool00ol0ofGoooooo`0Xo`05
ooooo`04o`23ool0D_ooooooo`3oF@Kooooo00?o02koooooooooool00_ooool01Ol0:?ooooooobH0
oooooooo03Co00;ooooo00?o0?m<ooooooooool00oooool00omG0?ooooooooooo`04ooooo`03ofT0
oooooooooooo00Sooooo00?oJ@3oo`3oC?ooool02?ooool01OlJ0?ooooooo`3o2_l0oo3o0?l:00Oo
oooo00Go03Cooooooooooooooooooed0o`08ooooo`03oego0?oooooo0?lX00;ooooo0_l0oeT;oooo
o`03o`0:oooooooooooo00;ooooo00?o0:koooooooooool05_ooool2o`3To`Gooooo00?o0?Kooooo
ooooool04Oooool3o`3oM`cooooo0ol0oc@Mooooo`?o0?mU=_ooool<o`10oc;ooooo3?l0@?maoooo
o`006_ooool00ol0003oooooooooo`0Fooooo`03o`2Kool0ol3o0:7o00;o0:7o0_l0olH3o`2Qo`Co
0?n?00?oooooo`3o`?l0ol000_l0VolHooooo`0Jo`2Kool0ol3oooooo`3oSol0olKoooooo`2Qool0
oggoooooo`1Ioooooooo0<coo`3oD_l0Jooo0?ljo`3oFOl0D_oo013oo`3Tool0:?oo0?l:o`1<ool0
f?ooGOl0of?o0?l0;_l9ooooo`05of?o0?mMo`3oooooooooool0l?l00_ooool01?l0;_oo0?l:oooo
ool0f?l3ooooo`04o`3oIOooooooooooo`0Xo`Cooooo00Go08?oooooool0D_ooooooo`3oF@06oooo
o`03o`0^oooooooooooo00;ooooo00So02SooooooolV0?ooooooo`1Bool0=?ooooooo`3oC0Gooooo
00?oE`3oooooooooool01?ooool00omY0?ooooooooooo`07ooooo`03ofT0oooooooo08?o00Wooooo
00?o6P3oooooool0oo000_ooool3o`3o2PCooooo00Go03Cooooooooooooooooooed0o`09ooooo`;o
GOl000Go0?lXooooooooooooooooo`3oF@0;ooooo`04o`0:ooooooooooooo`2^oa_ooooo00?o0>Co
ooooooooool00_l0m_lAooooo`?o0?mg3?ooool3o`3o=2?ooooo0ol0ofDooooooc;o043oOOooool0
01[ooooo00?o0000ooooooooool05oooool01?l0Vooo0?o0o`3oSol0ohl3o`2Qo`;o0?n?0oooool0
1?l0ol3o09_oo`2Kool0VolKooooo`;o09_o01Ooooooo`3oa_ooooooooooo`2Qoooooooo05Woo`3o
m_l0c?oo0?oBo`1[ool0oc[o0?mIooooool04?oo0?ldo`0Xool0o`[o0:koo`1<ool0f?ooHol0o`0^
o`08ooooo`03of?o0?mMo`3ooooo00;ooooo00Oo0?3oooooool0;_ooooooo`3o2_l0f?oo0?nE00?o
oooo00Co0?mUooooool0:?oo0>Co0oooool01Ol0Poooooooo`1Boooooooo0?mI00Oooooo00?o02ko
ooooooooool00_ooool00ol0:?ooooooobH0o`02ooooo`03o`0doooooooo0?m<00Gooooo00?oE`3o
ooooooooool01Oooool00omY0?ooooooooooo`06ooooo`04ofT0ool0odcoooooo`23o`Wooooo00?o
6P3oo`3ol?ooool01?ooool3o`3o2P03o`0doooooooooooo00?ooooo00?oG@3oooooooooool02?oo
ool00omMo`3o0?lXooooo`02ooooo`03o`3oFOoooooooooo00Sooooo00?o00[oooooool0[_l07Ooo
ool2o`3Toa3ooooo0ol0ogL<ooooo`?o0?ld:Oooool2o`3oI@Kooooo@ol0C?nSooooo`006_ooool0
0ol0003oooooooooo`0Hooooo`03o`2Kool0ol3o0?o000Gooooo0_l0ol02o`2Kob3ooooo01Oo09_o
o`3oSol0olKoooooo`2Qool0oggoooooo`1Iool0c?oo0?oBooooool0Jooo0?mIooooool04?oo0?mg
o`0Xool0ofGo0:koo`1<ool0f?ooGOl0o`0^o`08ooooo`03of?o0?mMo`3ooooo00;ooooo00Oo0?3o
ooooool0;_ooooooo`3o2_l0f?oo0?nE00;ooooo00Co0?mUo`3o:?oooooo02So1?ooool01?l0Pooo
05;oooooool0oeT8ooooo`03o`0^oooooooooooo00;ooooo00?o0?o`o`0XoolV0?l00_ooool01?l0
=?ooooooooooool0od`4ooooo`03oeL0oooooooooooo00Kooooo00?oJ@3oooooooooool01?ooool0
0omY0?ooooooo`3oC002ooooo`03o`23oooooooooooo00Kooooo00?o6P3oo`3ol?ooool01oooool0
0ol0=?oo0?l:o`3o2P03ooooo`03oed0oooooooooooo00[ooooo00Co0?lXoooooooooooooooo0_l0
oeT9ooooo`03o`0:ool0[_oooooo01_ooooo00?o0?Koooooooooool00_l0i?l;ooooo`?o0?mg3?oo
ool3o`3o=2;ooooo4_l0C?m3oooooaOo04coS?ooool001[ooooo00?o0000ooooooooool06Oooool3
o`2Ko`?o0?o00ol0VolRooooo`0Ho`2Kool0ol3o0?n?o`3oa_oooooo0:7oooooool0FOoo0?ofo`3<
oooooooo06_oo`3oFOoooooo013oo`3oMol0:?oo0?mUo`2^ool0C?oo0=Sooego0?mSo`3o02ko1ooo
ool02omMo`3ooooooooooooooooo0?3oooooool0;_ooooooo`3o2_oooooo0=So00?ooooo00Co0?mU
ooooool0:?oo0>Co0oooool01?l0Pooo05;oooooool0oeT9ooooo`03o`0^oooooooooooo00;ooooo
00?o0?o`o`0XoolV0?l00_ooool01?l0=?oo05;oooooool0od`4ooooo`03oeL0oooooooooooo00Oo
oooo00?oJ@3oooooooooool00_ooool2ofT0o`03ooooool0odcooooo00;ooooo0_l0Pol7ooooo`03
oaX0oooooooooooo00Kooooo00?o03Coooooooooool00_l0o`X2ooooo`03oed0oooooooooooo00[o
oooo0_l0obP3ooooo`03o`3oFOoooooooooo00Kooooo00?o0:koo`0:ooooool06Oooool2o`3fo`Go
oooo00?o0>Coooooooooool01_ooool2o`3oM`cooooo0ol0oc@Oooooo`Ko04co3oooool2o`3oIE_o
oooo6?l0C?mdooooo`006_ooool00ol0003oooooooooo`0Kooooo`Go09_o9Oooool05ol0Vooooooo
o`3oa_oooooo0:7oo`3oOOl0FOoo0?ofo`3<ool0oe;o06_oo`3o>_l0oeWo013oo`3oMol0i?oo02So
ooooool0C?oo0=SooooooomMo`3o02ko00Kooooo00?oHol0oego0?ooool00_ooool01ol0l?oooooo
o`0^oooooooo0?l:o`3Hool0oiD00_ooool01?l0ofGo0?lXooooool0:?l3ooooo`Co04co00?o0?mI
ooooooooool01oooool00ol0;_ooooooooooo`02ooooo`03o`3ol?l0:?oo9P3o00;ooooo00Co03Co
o`1Boooooooo0?m<1?ooool00omG0?ooooooooooo`07ooooo`GoJ@3o0_ooool00ol0odcooooooooo
o`04ooooo`03o`23oooooooooooo00?ooooo00?o0?o`oaX0ooooool01_ooool00ol0=?oooooooooo
o`03ooooo`;o0?l:00?oG@3oooooooooool03?ooool01?l0obSoooooooooooooool2o`3oF@Gooooo
00?o0:koooooool02_l06?ooool2o`3fo`Sooooo0_l0i?l4ooooo`;o0?mg2oooool3o`3o=1cooooo
1_l0C?lGooooo`?o0?mUL?ooool]o`1<odOooooo000Jooooo`03o`000?oooooooooo04Gooooo01Co
09_oo`3o`?l0ohoo0?o6ooooool0XOoo05Woo`3om_l0c?oo0?mBo`1[ool0oc[o0?mIo`0@ool0Pooo
0>Coo`0Xool0o`[o04coo`3Ho`;ooooo00?o02koooooooooool01?ooool00omSo`3oGOl0ooooo`02
ooooo`06o`3`ool0;_ooooooo`3o2_oooooo0=So0oooool01?l0ofGoooooo`0Xool0i?l2ooooo`06
o`1<ool0Pooo05;oooooool0oeWo04co2_ooool01ol0;_oooooooooooooooooo0?o`o`0XoolV0?l0
0_ooool01?l0=?ooooooo`1Bool0od`5ooooo`03oeL0oooooooooooo00Sooooo0_mY0?l3ooooo`03
o`3oC?oooooooooo00Gooooo00?o08?oooooooooool00_ooool00ol0oo3ooooooaX0o`06ooooo`03
o`0doooooooooooo00Gooooo00?o0?l:oed0ooooool03Oooool00ol0obSoGOl0ooooo`02ooooo`05
o`3oFOooooooooooooooool0[_l00oooool00ol02_ooooooooooo`0Dooooo`03o`3foooooooooooo
00[ooooo0_l0i?l2o`3oM`[ooooo0ol0oc@Iooooo`Ko04co8?ooool2o`3oII_ooooo6?l0C?l_oooo
o`006_ooool00ol0003oooooooooo`16ooooo`0Co`2Koooooooo0?o6ooooool0XOooooooo`1Iool0
c?oo0?oBo`1[ool0oc[o0?mIo`1Bool04?oo0?ldo`0Xool0o`[o04coo`3Ho`02ooooo`03o`0^oomS
o`3ooooo00?ooooo00?oHol0oego0?ooool00_ooool01ol0l?ooooooo`0^oooooooo0?l:ooooool0
f?l00oooool00ol0ofGoooooo`0Xo`02ooooo`05o`1<oooooooo08?oo`1Bool0oeT00_ooool00ol0
C?ooooooooooo`07ooooo`07o`0^ooooooooooooooooool0oo3oooooobH0o`02ooooo`04o`0doooo
oooo05;oo`3oC0Gooooo00?oE`3oooooooooool03Oooool00ol0odcoooooooooo`06ooooo`07o`23
ooooooooooooooooool0oo3ooooooaX0o`05ooooo`03o`0doooooooooooo00Oooooo00?oG@3oo`3o
2_l0o`X03Oooool00ol0obSoGOl0ooooo`02ooooo`04o`3oFOooooooooooo`2^o`?ooooo00?o00[o
ooooooooool04oooool00ol0m_ooooooooooo`0:ooooo`;o0?mg00?oooooo`3Tooooool01oooool3
o`3o=1Oooooo1Ol0C?lXooooo`?o0?mU/?oooolPo`1<o`oooooo000Jooooo`03o`000?oooooooooo
04Oooooo01So09_oo`3oSol0olKo0:7oo`3oOOl0FOoo0?ofo`3<oooooooo06_oo`3oFOl0D_oo013o
o`3o=?l0:?oo0?l:o`2^ool0C?oo0=SooooooomMo`3o02koof?o0?ooool2of?o0003oego0?oooooo
oooo00;ooooo00Oo0?3oo`0^oooooooo0?l:ooooool0f?oo0?nE00;ooooo00Co0?mUo`3o:?l0:?oo
0>Co0_ooool01Ol0C?oo08?oooooool0D_oo0?mI00;ooooo00?o04coooooooooool01oooool00ol0
;_ooooooooooo`02ooooo`03o`3ol?l0:?oo9P3o00;o0?oB00?o03Coo`3od_l0D_l01Ol0om800omG
0?oo0?oBo`3odP03o`3odP[ooooo00?o0?m<ooooooooool01oooool01?l0Poooooooooooool0oo02
ooooo`03oaX0oooooooooooo00;ooooo00?o03Coooooooooool02?ooool00omM0?ooooooo`3o2P0=
ooooo`03o`3o:?mMo`3oGOl000;ooooo00?o0?mIo`2^ooooool01?ooool00ol02_ooooooooooo`0A
ooooo`03o`3foooooooooooo00Wooooo0_l0ogL4ooooo`;o0>Co1?ooool2o`3o=1Kooooo1?l0C?l`
ooooo`?o0?mUg?ooool001[ooooo00?o0000ooooooooool0Aoooool04ol0Voooooooo`3oa_oooooo
0:7oo`1Iool0ooKo0<coo`3oD_l0Jooo0?mIooooool04?oo0?mgo`0Xool0ofGo0:koo`1<ool0f?l0
0_ooool01Ol0;_ooHol0of?o0?mSo`3oGOl000Cooooo00Oo0?3oooooool0;_ooooooo`3o2_oooooo
0=So00?ooooo00?o0?mUooooool0:?l00_ooool01_l0C?ooooooo`23ool0D_oo0?mIooooo`?o0?ld
00?o04coo`3o>_l0ocX00ol0ocX3ooooo`03o`0^oooooooooooo00;ooooo00?o0?o`o`0XoolV0?l0
0_ooool01?l0=?ooooooo`1Bool0od`4ooooo`03oeL0oooooooooooo00?ooooo0ol0om86ooooo`03
o`3oC?oooooooooo00Wooooo0_l0Pol01?l0oo3ooooooooooolJ0?l4ooooo`03o`0doooooooooooo
00Sooooo00?oG@3oooooooooool00_l0o`X<ooooo`;o0?lX00GoGOl0ooooool0[_ooooooo`3oF@05
ooooo`03o`0:oooooooooooo00kooooo0_l0m_l;ooooo`03o`3oMooooooooooo00Kooooo0_l0i?l2
o`3o=1Cooooo1?l0C?lgooooo`?o0?mUOOoooom=oego00oooooo000Jooooo`03o`000?oooooooooo
04Sooooo01;o09_oo`3oa_oooooo0:7oooooool0FOoo0<coo`3oD_l0Jooo0?ljo`3oFOl04?oo0?mg
o`0Xool0ofGoooooo`1<ool0f?l2ooooo`04o`0^oomMo`3oGOl0oego00Gooooo00Oo0?3oo`0^oooo
ooooooooo`3o2_l0f?oo0?nE00;ooooo00Ko0?mUo`3o:?l0:?oo0>Coooooool0C?l2ooooo`04o`23
ool0D_oo0?mIo`3o=0;ooooo00?o0?ljo`1<ooooool00oooool2o`3o>P;ooooo00So02kooooooooo
ooooooooo`3od_l0oo3o02SoobH0o`;ooooo00Co03Coooooool0D_oo0?m<1?ooool00omG0?oooooo
ooooo`06ooooo`?o0?oB0oooool00ol0odcoooooooooo`0:ooooo`03o`3ol?l0Pooooooo00;ooooo
00Co6P3ooooooooooooo03Co3?ooool01OmM0?oooooooooooooooooo0?l:00gooooo00?o0?lXoego
0?l0[_l00_ooool2o`3oF@?ooooo00?o00[oooooooooool03Oooool00ol0m_ooooooooooo`09oooo
o`;o0?mg2?ooool3o`3o=003o`3Toooooooooooo013ooooo0ol0C?lnooooo`?o0?mUEooooolSoego
05cooooo000Jooooo`03o`000?oooooooooo04Sooooo01;o09_oo`3oSol0olKo0:7oooooool0FOoo
0<coo`3oD_l0Jooo0?ljo`3oFOl04?oo0?mgo`3Tool0:?oo0?l:o`1<ool0f?l3ooooo`03o`0^oooo
oooooooo00Cooooo00So0?3oooooool0;_ooooooo`3o2_oooooo0=Soo`3oU@;ooooo00Go0?mUoooo
ool0:?oo0>Coo`1<o`02ooooo`03o`23ool0[_oo05;o00?o0:ko0_l0ocX00ooooooo04coooooo`04
ooooo`03o`3o>_oooooo02ko00;ooooo00Go0?oBooooool0oo3o02SoobH0o`02ooooo`04o`0doooo
ooooooooo`1Bo`Cooooo00?oE`3oooooooooool02Oooool3o`3odP03o`3oC?oooooooooo00[ooooo
00?o0?o`ooooool0Pol00oooool00olJ0?ooooooo`0do`0<ooooo`03oed0oooooooooooo00;ooooo
00?o0?l:ooooooooool02oooool00ol0[_oooooooego0002oego0003ooooool0oeWooooo00;ooooo
00?o00[oooooooooool02oooool00ol0m_ooooooooooo`08ooooo`;o0?mg2?ooool2o`3o=0Cooooo
0_l0i?l=ooooo`?o04coA?ooool3o`3oID?ooooo4OmMo`1Zooooo`KoG@3o3oooool001[ooooo00?o
0000ooooooooool0BOooool04Ol0Vooo0?o6ooooool0XOoo05Woo`3<ool0om;o06_oo`3o>_l0oeWo
05;oo`0@ool0i?oo02Soo`3o2_l0[_oo04co00Cooooo00Co02kooooooooooooooooo0_l0l?l01ooo
oooo02kooooooooooooo0?l:ooooool0f?l00_ooool01_l0ofGo0?lXo`0Xool0i?ooooooo`1<o`;o
oooo00?o08?oo`1Bool0oeT00_ooool2o`2^o`;ooooo00?o04coo`3o=?ooool00oooool00ol0oc[o
ooooo`0^o`02o`3odP;ooooo00?o0?o`oooooolV0?l00_ooool01?l0=?ooooooooooool0D_l4oooo
o`03oeL0oooooooooooo00_ooooo00?o0?m<o`3od_l0om800_l0om89ooooo`04o`3ol?oooooooooo
o`23o`;ooooo00?o6P3oooooool0=?l03Oooool00omM0?ooooooooooo`02ooooo`;o0?l:2_ooool0
0ol0[_ooooooo`3o:003ooooo`;oGOl000Go0?mIooooooooooooooooo`0:o`0;ooooo`03o`3foooo
oooooooo00Sooooo00?o0?mgooooooooool01_ooool2o`3o=0Sooooo0_l0i?l8ooooo`?o04coB_oo
ool3o`3oIBWooooo5omMo`1`ooooo`_oG@3o5Oooool001[ooooo00?o0000ooooooooool0BOooool0
4Ol0Vooo0?n?o`3oa_l0XOoo05Woo`3om_l0c?oo06_oo`3Zool0oeWo05;oo`0@ool0ocCo02Soo`3o
2_l0[_oo04co00Cooooo00?o02koo`3`ool0l?l00_l0l?l02?oooooo02kooooooooooooo0?l:oooo
ool0f?oo0?nE0_ooool01Ol0ofGo0?lXo`0Xool0i?oo04co00;ooooo00?o08?oo`1Bool0oeT00_oo
ool01?l0oc[oooooooooool0[_l2ooooo`03o`1<oooooooooooo00?ooooo00?o0?ljo`0^ooooool0
0oooool00ol0oo3oooooobH0o`02ooooo`05o`0dooooooooooooo`1Bool0od`01?ooool00omG0?oo
ooooooooo`0:ooooo`03o`3oC?oooooooooo00;ooooo0ol0om86ooooo`05o`3ol?oooooooooooooo
ool0Pol00_ooool00olJ0?ooooooooooo`0<ooooo`03oed0oooooooooooo00Cooooo00?o0?l:oooo
ooooool01oooool01?l0[_ooooooooooool0obP4ooooo`03oego0?l0oeWo0?mI00;ooooo00?o00[o
ooooooooool01_ooool2o`3fo`Wooooo0_l0ogL7ooooo`;o0?ld3?ooool00ol0i?ooooooooooo`02
ooooo`?o04coD?ooool3o`3oIACooooo4_mMo`1nooooo`WoG@3o8?ooool001[ooooo00?o0000oooo
ooooool0BOooool04Ol0Vooo0?o0o`3oa_l0XOooooooo`1Iool0c?oo0?mBo`1[ool0oeWo05;oo`0@
ool0ocCo02Soooooool0oiGo04co00Gooooo0_l0;_l00ooooooo02koo`0^o`03ooooo`04o`3o2_oo
oooo0=Soo`3oU@;ooooo00Co0?mUo`0Xoooooooo04co0_ooool01?l0[_oo08?oo`1Bool0oeT2oooo
o`03o`3o>_oooooooooo00;o013o00?oooooo`1<ooooool00oooool2o`3odP03o`3o>_l0;_oooooo
00;ooooo00?o0?o`oooooolV0?l00_ooool01Ol0=?oooooooooooooooooo05;o00Cooooo00?oE`3o
ooooooooool02_ooool00ol0odcoooooooooo`05ooooo`?o0?oB0_ooool00ol0oo3oooooooooo`03
ooooo`03o`23oooooooo6P3o00oooooo00?oG@3oooooooooool01?ooool00ol0o`[oooooooooo`05
ooooo`03o`2^oooooooooooo00;ooooo0_l0obP4ooooo`05oego0?l0oeWoooooooooool02_l01_oo
ool00ol0m_ooooooooooo`07ooooo`;o0?mg1oooool2o`3o=0oooooo00Co0>Coo`1<ool0C?oo04co
E_ooool3o`3oI@Gooooo3?mMo`2:ooooo`KoG@3o:Oooool001[ooooo00?o0000ooooooooool0B_oo
ool04Ol0Vooo0?o6o`2Qool0oggo05Woo`3<ool0oe;o06_oo`3oFOoooooo013oo`3oMol0:?oo0?mU
o`3o2_l0[_oo04co00Gooooo0_l0;_l5ooooo`03o`3o2_l0f?oo0?nE00;ooooo00[o0?mUo`3o:?l0
:?oo0>Coo`1<oooooooo0:koooooool0D_oo0?mI0_ooool01_l0oc[oooooo`0@ool04?oo0:kooooo
o`;o013o00Co0?ldoooooooooooo0?oB0_ooool00ol0oc[o02koooooo`02ooooo`03o`3ol?oooooo
9P3o00;ooooo00Go03Coooooooooooooooooo`1Bo`04ooooo`03oeL0oooooooooooo00Wooooo00?o
0?m<ooooooooool02Oooool2o`3odP03o`3ol?oooooooooo00?ooooo00Co08?oooooool0=?oo6P3o
3_ooool00omM0?ooooooooooo`05ooooo`03o`3o2_oooooooooo00Cooooo00?o0:koooooooooool0
1?ooool00ol0obSoooooooooo`03ooooo`;o0?mI00?oooooo`0:ooooool00oooool00ol0m_oooooo
ooooo`07ooooo`03o`3oMooooooooooo00Gooooo0_l0oc@?ooooo`?o04co00?oooooo`3Tool0i?l0
D_ooool7oego00?o0?mU0_mMo`2@ooooo`KoG@3o;oooool001[ooooo00?o0000ooooooooool0B_oo
ool04Ol0Vooo0?n?o`2Qool0oggo05Woo`3<ool0oe;o06_oo`3o>_l0oeWo013oo`3oMol0:?oo0?mU
o`3o2_l0[_oo04co00_ooooo00Co0?l:ooooool0f?oo0?nE0_ooool03_l0ofGo02Soooooool0C?oo
ooooo`2^oooooooo05;oo`3o=?l0oeWoooooo`3o>_oooooo013o0oooool01_l0[_ooooooo`1<ool0
4?ooooooo`3odPCooooo00So02koooooooooooooooooo`3ol?oooooo02SoobH0o`;ooooo00Go03Co
oooooooooooo0?m<o`1Bo`03ooooo`03oeL0oooooooooooo00Wooooo00?o0?m<ooooooooool02ooo
ool00ol0oo3o0?oBo`3odP02o`3odP;ooooo00?o03CooooooolJ0?l03oooool00omM0?oooooooooo
o`05ooooo`;o0?l:0oooool00ol0[_ooooooooooo`06ooooo`03o`3o:?oooooooooo00Cooooo00Ko
0?mIoego0?l02_ooGOl0ooooool0m_l9ooooo`03o`3oMooooooooooo00Cooooo0_l0oc@?ooooo`;o
04co1_ooool2o`3TodGooooo2omMo`0:ooooo`?o0?mUROooool6oed0ocGooooo000Jooooo`03o`00
0?oooooooooo04[ooooo017o09_oo`3o`?l0olKo0:7oo`1Iool0c?oo0?oBo`1[ool0oc[o0?mIo`0@
ool0Pooo0>Coo`0Xool0o`[o0:koo`1<o`0;ooooo`0Co`3o2_l0f?ooooooo`3oUOoooooo0?mUo`3o
:?l0:?ooooooo`1<oooooooo0:koooooool0D_oo0?ldo`3oFOl0oc[oooooo`0@o`04ooooo`06o`2^
ooooooooooooo`0@ool0ocCo0?oB1?ooool00ol0;_ooooooooooo`02ooooo`03o`3ol?oooooo9P3o
00;ooooo00Go03Coooooooooooooooooo`1Bo`03ooooo`03oeL0oooooooooooo00Wooooo00?o0?m<
ooooooooool02oooool00ol0oo3oooooooooo`02ooooo`;o0?oB00Co03Coo`23oooooooo6P3o3_oo
ool00omM0?ooooooooooo`07ooooo`03o`3o2_oooooo0:ko00[ooooo00?o0?lXooooooooool01?oo
ool01?l0oeWo00[oooooool0m_l3oego00Gooooo0_l0ogL5ooooo`;o0?ld3oooool2o`1<o`[ooooo
0_l0i?lgooooo`coGOl06?ooool4o`3oIGkooooo1omM0?lkooooo`006_ooool3o`0004_ooooo013o
09_oo`3oa_l0XOoo05Woo`3om_l0c?oo06_oo`3Zool0oeWo05;oo`0@ool0i?oo02Soooooool0[_oo
04co2_ooool01?l0o`[oooooo`3Hool0oiD2ooooo`0>o`3oIOl0obSo02Soo`1<oooooooo0:kooooo
ool0D_oo08?oo`3oFOoooooo0?ljooooool04?l5ooooo`05o`2^oooooooo04coo`0@ooooool01?l0
oh<00ol0;_oo0?ljooooo`02ooooo`03o`3ol?oooooo9P3o00;ooooo00Go03Cooooooooooooooooo
o`1Bo`03ooooo`03oeL0oooooooooooo00Sooooo00?o0?m<ooooooooool02oooool00ol0oo3ooooo
ooooo`05ooooo`04o`0dool0om;o08?ooaX0o`oooooo00?oG@3oooooooooool01oooool00ol0o`[o
0:koooooo`0:ooooo`03o`3o:?oooooooooo00Gooooo00?o00[oooooooooool00_ooool4oego0003
o`3oMomMo`3oGOl000Cooooo00?o0?ldooooooooool03?ooool3o`1<o`kooooo0_l0i?lYooooo`co
GOl0:?ooool3o`3oIG?ooooo2?mM0?m2ooooo`006_ooool00ol0003oooooooooo`1;ooooo`0Ao`2K
ool0ol3o0:7oo`3oOOl0FOoo0<coo`3oD_l0Jooo0?mIo`1Bool04?oo0>Coo`0Xoooooooo0?l:o`1<
ool0f?l02Oooool02ol0o`[oooooo`3Hool0oiGoooooo`3oIOl0obSo02Soo`1<ool0i?oo0:ko00;o
oooo00Ko05;oo`3o=?l0oeWo0?ljooooool04?l6ooooo`07o`2^oooooooo04coo`3oPol04?oo0?n3
ooooo`02o`3<o`03o`0^ool0c?oo0<co00Co0<co00Co9P3ooooooooooooo03Co0oooool01Ol0odco
05;oooooooooooooE`3o00[ooooo00?o0?m<ooooooooool02oooool00ol0oo3oooooooooo`04oooo
o`06o`0dooooooooooooooooool0Pooo6P3o0_l0om8<ooooo`03oed0oooooooooooo00Oooooo00?o
0:koo`3o2_ooool02oooool2o`3o:0Cooooo00Co0?Koooooool02_oo0?mI1Oooool01?l0ogOooooo
ooooooooool2oego00;o0?ld00?oGOl0ooooooooool02_ooool2o`1<oa?ooooo0ol0i?lJooooo`co
GOl0=oooool3o`3oIFWooooo1omM0?m:ooooo`006_ooool00ol0003oooooooooo`1;ooooo`0Ao`2K
ool0ol3o0:7oo`3oOOl0FOoo0<coo`3oD_l0Jooo0?mIo`1Bool04?oo0?mgo`0Xoooooooo0?l:o`2^
ool0C?l02Oooool02ol0o`[o0=Soooooool0oiGoooooo`3oIOl0obSo02Soo`1<ool0i?oo0:ko00;o
oooo00Go05;oo`3oFOoooooo0?ljo`0@o`07ooooo`05o`3oD_l0[_oo04coo`3oPol04?l00_l0c?l2
ooooo`03o`0^ool0oc[ooooo00;o0?n300?o0?o`oooooolV0?l00_ooool01_l0=?oooooooooooooo
oooo0?m<o`1Bo`?ooooo00?oE`3oooooooooool01oooool00ol0odcoooooooooo`0;ooooo`03o`3o
l?oooooooooo00Cooooo00?o03Coooooooooool00_ooool00ol0Pooo6P3oooooo`02o`3odP_ooooo
00?oG@3oooooooooool01_ooool00ol0[_ooooooo`3o2P0=ooooo`04o`3o:?ooooooooooo`3fo`?o
oooo00Co00[oo`3oFOoooooooooo0_l0ogL5ooooo`04o`3o=?ooooooooooooooo`_oGOl000?o04co
ooooooooool05_ooool2o`3To`Wooooo3omMo`16ooooo`?o0?mUG_ooool8oed0oe7ooooo000Joooo
o`03o`000?oooooooooo04cooooo017o09_oo`3oa_l0XOoo05Woo`3<ool0oe;o06_oo`3oFOoooooo
013oo`3oMol0:?oo0?mUo`3o2_l0[_oo04coo`3Ho`07ooooo`04o`3o2_oooooo0=Soo`3oU@;ooooo
00Go0?mUo`0Xool0C?oo0>Coo`2^o`02ooooo`05o`1Bool0ocCo0?mIooooool04?l01oooool02Ol0
oe;oooooo`2^ool0C?ooooooo`3<ool04?ooooooo`3oDP02ooooo`0:o`0^ool0oc[oooooooooool0
oo3oooooobH0ool0c?ooooooo`0do`Cooooo00Go05;ooooooooooooooooooeL0o`08ooooo`03o`3o
C?oooooooooo00cooooo00?o0?o`ooooooooool01?ooool00ol0=?ooooooooooo`03ooooo`04oaX0
ooooooooooooooooo`;o0?oB2Oooool00omM0?ooooooooooo`05ooooo`04o`2^oooooooooooooooo
o`;o0?l:3?ooool00ol0obSo0?Koooooo`04ooooo`03o`0:ool0oeWo0?mg00Gooooo0_l0oc@>oooo
o`03o`1<ooooooooGOl001WoGOl00_l0i?l7oego05Sooooo1?l0ofEBooooo`SoG@3oFOooool001[o
oooo00?o0000ooooooooool0C?ooool04Ol0Vooo0?o6o`2Qool0FOoo0<coo`3od_l0Jooo0?ljo`3o
FOl04?oo0?mgo`0Xool0ofGoooooo`2^ool0C?oo0=So00Oooooo00[o0?l:o`3Hoooooooo0?nEoooo
ool0ofGo0?lXo`0Xool0C?oo0:ko0oooool01Ol0D_oo0?mIooooool0oc[o013o00Kooooo00Wo0?mB
o`3oPol0om;o0:koooooool0C?oo0?ldo`0@ooooool00ol0ol`02_l0;_oo0?o<o`3oc?l0olco0?o`
oooooolV0?ooooooo`3<ool0=?l4ooooo`05o`3oC?l0D_oooooooooooomG0?l02?ooool00ol0odco
ooooooooo`0;ooooo`03o`3ol?oooooooooo00Cooooo00?o03Coooooooooool01Oooool00olJ0?oo
ooooooooo`02ooooo`;o0?oB2?ooool00omM0?ooooooooooo`03ooooo`03o`2^oooooooooooo00Co
oooo00?o0?l:ooooooooool02Oooool00ol0m_ooooooo`3o:005ooooo`04o`0:oooooooo0?mIo`3o
F@;ooooo00?o0?ldooooooooool03?ooool2o`1<oakooooo0_l0i?mQooooo`Co0?mUA_ooool8oed0
of7ooooo000Jooooo`03o`000?oooooooooo04cooooo01;o09_oo`3oa_l0XOoo05Woo`3om_l0c?oo
06_oo`3o>_l0oeWo013oo`3oMol0:?oo0?mUooooool0o`[o04coooooool0f?l5ooooo`04o`3o2_oo
oooo0=Soo`3oU@;ooooo00Go0?mUo`0Xool0C?oo0>Coo`2^o`02ooooo`05o`1Boooooooo0?mIoooo
ool04?l01Oooool2o`3oDP08o`3oPol0om;oooooo`2^ool0c?oo04coooooool04?l2o`3oc004o`3o
D_oooooo02koo`3o>P;ooooo00Ko0?o`o`3oc?lV0?oo02Soooooool0=?l5ooooo`04o`1Boooooooo
oooooeL0o`Sooooo00?o0?m<ooooooooool02oooool00ol0oo3oooooooooo`04ooooo`03o`0doooo
oooooooo00Gooooo00?o6P3oo`23ooooool01?ooool2o`3odPKooooo00?oG@3oooooooooool00ooo
ool00ol0[_ooooooooooo`05ooooo`03o`3o2_oooooooooo00Oooooo00Co0?Kooooooooooooooooo
0_l0obP01Ooooooo0?mgo`3oMooooooo00[o00;ooooo00?o0?mIo`3o=?ooool03Oooool00ol0C?oo
ooooooooo`0Pooooo`;o0>CoHoooool4o`3oIC_ooooo1omM0?mYooooo`006_ooool00ol0003ooooo
ooooo`1=ooooo`0Ao`2Kool0olKo0:7oo`1Iool0c?oo08Woo`1[ool0oeWo05;oo`0@ool0i?oo02So
ooooool0o`[o04coooooool0f?l01Oooool02_l0o`[o0=Soooooool0oiGoooooo`3oIOl0obSo02So
ooooool0[_l3ooooo`04o`1Bool0oeWoooooo`0@o`Gooooo00co0?mBoooooooooooo0?n3o`3od_oo
oooo0:koooooool0C?oo0?o<o`3o=?l04?l2ooooo`09o`3oD_l0;_ooooooo`3o>_oooooo0?o`oooo
ool0olco9P3o00;ooooo00?o03Coooooooooool00_ooool01?l0D_oooooooooooomG0?l7ooooo`03
o`3oC?oooooooooo00cooooo00?o0?o`ooooooooool01?ooool00ol0=?ooooooooooo`06ooooo`03
oaX0ool0Pooooooo00Gooooo00?o0?oBooooooooool01?ooool01OmM0?oooooooooooooooooo0:ko
00Wooooo0_l0o`X6ooooo`03o`3foooooooooooo00Cooooo00Go0?mgooooooooooooooooo`0:o`02
o`3o=003ooooool0oeWo0?mI00_ooooo0_l0C?lUooooo`;o0>CoIOooool3o`3oIC?ooooo1OmM0?m`
ooooo`006_ooool00ol0003oooooooooo`1=ooooo`0Bo`2Kool0olKo0:7oo`1Iool0c?oo0?mBo`1[
ool0oeWo05;oo`0@ool0i?oo02Soo`3oIOoooooo0:koo`1<oooooooo0=So0oooool2o`3Ho`09oooo
ool0oiGoooooooooool0ofGoooooo`0Xool0[_oo0>Co00;ooooo00Go08?oo`1Bool0oeWoooooo`0@
o`05ooooo`04o`3oD_oooooo0?n3o`3odP;ooooo00Ko0:koooooool0olco04coo`3o=?l04?l3oooo
o`03o`0^oooooooo0?lj00;ooooo00Oo0?o`oooooolV0?oo0?o<ooooool0=?oo0<co00?ooooo00Co
0?m<o`1BooooooooE`3o1oooool00ol0odcoooooooooo`0<ooooo`03o`3ol?oooooooooo00?ooooo
00?o03Coooooooooool01oooool00olJ0?ooooooo`23o`06ooooo`;o0?oB1?ooool01OmM0?oooooo
oooooooooooo0:ko00_ooooo00?o0?l:ooooooooool00oooool00ol0m_ooooooooooo`03ooooo`07
o`3oMooooooo0?lXo`3o:?oooooo0?ldo`0:o`04ooooo`03o`3oFOoooooooooo00Oooooo00?o04co
ooooooooool09oooool2o`3TofKooooo1?l0ofDYooooo`KoG@3oMOooool001[ooooo00?o0000oooo
ooooool0COooool04_l0Vooo0?o6o`2Qool0FOoo0<coo`3oD_l0Jooo0?mIo`1Bool04?oo0?mgo`0X
ool0ofGoooooo`2^ool0C?oo0?nEooooo`Co0=So00?oooooo`3oUOooool00_ooool01?l0ofGo02So
ooooool0[_l3ooooo`04o`1Boooooooo0?mIo`0@o`Gooooo00go0?mBoooooooooooo0?n3o`3od_oo
oooo0<coo`3oc?l0[_ooooooo`1<ool0ocCo013o00?ooooo00co02kooooooooooooo0?ljooooool0
oo3oooooobH0oooooooo0?o<o`0dool0c?l4ooooo`04o`1BoooooooooooooeL0o`Gooooo00?o0?m<
ooooooooool03Oooool00ol0oo3oooooooooo`03ooooo`03o`0doooooooooooo00Sooooo00?o6P3o
ooooool0Pol01oooool00ol0om;oooooooooo`02ooooo`03oed0oooooooo0:ko00gooooo00Go0?l:
ooooooooooooooooo`3fo`05ooooo`04o`3oMoooooooooooooooo`;o0?ld0_ooool00ol02_oooooo
ooooo`02ooooo`;o0?mI1_ooool00ol0C?ooooooooooo`0Zooooo`;o0>CoJ?ooool4o`3oIB3ooooo
1OmM0?mkooooo`006_ooool00ol0003oooooooooo`1=ooooo`0=o`2Kool0olKo0:7oo`1Iool0c?oo
0?oBo`1[ool0oeWo05;oo`0@ool0ogOo02Soo`3oI@02ooooo`05o`1<ool0oiGoooooooooool0o`X0
0oooool02?l0oiGoooooooooool0ofGoooooo`0Xool0[_oo0>Co0_ooool01Ol0ocCo05;oo`3oFOoo
oooo013o00Gooooo00ko0?mBooooool0oh?o0?oBooooool0c?oo0?o<ooooool0[_ooooooo`1<ool0
ocCoooooo`0@o`;ooooo00go02koo`3oD_oooooo0?ljooooool0oo3oooooobH0ool0oh?o0?o<o`0d
oooooooo0<co00?ooooo00Co05;oooooooooooooE`3o1Oooool00ol0odcoooooooooo`0<ooooo`03
o`3ol?oooooooooo00Cooooo00?o03Coooooooooool02Oooool00olJ0?ooooooo`23o`07ooooo`;o
0?oB0_ooool00omM0?ooooooo`2^o`0>ooooo`;o0?l:00?o0?Koooooooooool00oooool01Ol0ogOo
oooooooooooooooo0?ld00;ooooo0_l0obP00ooooooo00[oooooo`04ooooo`04o`3oFOoooooooooo
ooooo`;o04co;oooool3o`3TofWooooo1?l0ofDEooooo`OoG@3oP?ooool001[ooooo00?o0000oooo
ooooool0C_ooool04Ol0Vooo0?mmo`2Qool0FOoo0<coo`1[ool0oeWoooooo`0@ool0ogOo0>Coo`0X
ool0ofGoooooo`2^ool0C?oo0?nE00;o0?l:00?oooooo`3oUOl0oiD00oooool01Ol0ofGo02Soo`2^
oooooooo0>Co00;ooooo00Go08?oo`1Bool0oeWo013oo`3o>P04ooooo`07o`3oD_ooooooooooo`3o
d_oooooo0<coo`3oc002ooooo`06o`2^oooooooo04coo`3o=?oooooo013o0oooool02_l0;_oooooo
o`3o>_oooooo0?o`oooooolV0?oo0?n3ooooool0=?l2ooooo`07o`3<ooooooooooooooooool0D_oo
oooooeL0o`04ooooo`03o`3oC?oooooooooo00gooooo00?o0?o`ooooooooool00oooool00ol0=?oo
ooooooooo`0:ooooo`04oaX0ooooooooooooo`23o`Sooooo00Co0?oBooooooooooooG@3o4Oooool0
0ol0m_ooooooooooo`02ooooo`03o`3oMooooooooooo00;o0?ld1Oooool00ol0obSoooooo`0:o`05
ooooo`;o0?mI00?o04coooooooooool0<_ooool2o`3Tof_ooooo1?l0ofD9ooooo`SoG@3oQoooool0
01[ooooo00?o0000ooooooooool0C_ooool03Ol0Vooo0?o6o`2Qool0FOoo0<coo`1[ool0oc[o0?mI
o`0@ool0ogOo0?ldo`0Xool0ofD00_ooool00ol0[_oo04coo`3oU@02o`3oU@Gooooo00Co04coo`0X
ool0[_oo0>Co0_ooool01Ol0ocCo05;oo`3oFOoooooo013o00Cooooo00So0?mBoooooooooooo0?n3
o`3od_l0ob;o0<coo`3oc0;ooooo00Ko0:koooooool0C?ooooooo`3o=?l04?l3ooooo`0=o`0^ool0
oe;oooooo`3o>_l0oo3oooooobH0ool0:?oo0?n3o`0dool0olcoooooo`3<o`03ooooo`03o`1Boooo
ooooE`3o00?ooooo00?o0?m<ooooooooool03_ooool00ol0oo3oooooooooo`03ooooo`03o`0doooo
oooooooo00_ooooo00Co6P3ooooooooooooo08?o2?ooool00ol0om;o0:kooed0o`0@ooooo`03o`3f
oooooooo0?l:00;ooooo00Co0?mgoooooooooooo0?ld2?ooool2o`3o:003o`0:oooooooooooo00?o
oooo00?o04coo`3oFOooool0=Oooool2o`3Tofgooooo0_l0ofD7oed0ohoooooo000Jooooo`03o`00
0?oooooooooo04kooooo00go09_oo`3oa_l0XOoo05Woo`3<ool0oe;o06_oo`3oFOl04?oo08?oo`3o
Mol0:?oo0?mU00;ooooo00?o0:koo`1<ooooool01_ooool01Ol0C?ooooooo`0Xoooooooo0>Co00;o
oooo00Go08?oo`1Bool0oeWo013oo`3o>P04ooooo`08o`3oD_oooooo0?n3o`3od_l0ob;o0<coo`3o
c?ooool2o`3o8P06o`2^oooooooo04coooooool0ocCo013o0oooool03_l0;_oo0?mBooooool0oc[o
0?o`oooooolV0?oo02Soo`3oPol0=?ooooooo`3oc?oooooo0<co0_ooool00ol0D_oo0?m<oeL0o`02
ooooo`;o0?m<4?ooool00ol0oo3oooooooooo`03ooooo`03o`0doooooooooooo00_ooooo00Go6P3o
ooooooooooooooooo`23o`08ooooo`03o`2^ooooooooG@3o00kooooo00Oo0?Kooooooooooooooooo
o`3o2_l0ogOooooo00;o0?ld2oooool00ol02_ooooooooooo`02ooooo`03o`1<oooooooooooo00;o
0?mI=_ooool3o`3TofGooooo1omM0?l2ooooo`?o0?mUTOooool001[ooooo00?o0000ooooooooool0
C_ooool03_l0Vooo0?o6o`2Qool0FOoo0<coo`3oD_l0Jooo0?mIo`1Bool04?oo0?mgo`3Tool0:?oo
0?mU0_ooool00ol0[_oo04coooooo`04ooooo`0<o`1<ool0ofGo02Soo`2^oooooooo0>Coooooool0
ocCo05;oo`3oFOoooooo013o1?ooool01ol0oe;oooooo`3oPol0ob;o0?oBo`3<ool0ol`00oooool0
2?l0ob;oooooo`2^ool0C?ooooooo`3o=?oooooo013o0_ooool03?l0;_ooooooo`3oD_l0oc[o0?o`
oooooolV0?oo02Soooooool0oh?o03Coo`3oc0;ooooo00Go0<coooooool0D_oooooooeL0o`02o`3o
C17ooooo00?o0?o`ooooooooool01?ooool00ol0=?ooooooooooo`0<ooooo`05oaX0oooooooooooo
ooooool0Pol01_ooool01Ol0[_ooooooo`3od_ooooooG@3o00cooooo00?o0?Koooooooooool00_oo
ool01?l0ogOoooooo`3o=?l0o`X=ooooo`04o`0:ool0obSo04coo`1<o`Gooooo0_l0oeTgooooo`;o
0>CoGOooool6oed0o`cooooo1?l0ofF=ooooo`006_ooool00ol0003oooooooooo`1?ooooo`0=o`2K
ool0XOoo05Woo`3<ool0om;o06_oo`3oFOl0D_oo013oo`3oMol0i?oo02Soo`3oI@02ooooo`03o`2^
oooooooo04co00;ooooo0_l0C?l01Ol0ofGo0:koo`0Xoooooooo0>Co00;ooooo00Go08?oo`1Bool0
oeWo013oo`3o>P04ooooo`06o`3oD_l0ogOo0?n3o`3od_l0c?oo0?o<1Oooool01ol0ob;o0:kooooo
ool0C?oo0?ldooooool04?l00_ooool01Ol0;_ooooooo`3oD_oooooo0?o`00;ooooo00So9P3ooooo
ool0oh?o03Coooooool0olcoooooo`3<o`;ooooo00?o05;ooooooomG0?l04_ooool00ol0oo3ooooo
ooooo`03ooooo`03o`0doooooooooooo00gooooo00?o6P3oooooooooool00_ooool00ol0Pooooooo
ooooo`03ooooo`05o`2^ooooooooooooo`3od_mM0?l03?ooool01Ol0m_oooooooooooooooooo0?mg
00;o0?ld0_ooool00ol0o`[oooooooooo`0;ooooo`03o`0:ool0obSooooo00Oooooo00?o0?mIoooo
ooooool0=_ooool2o`3ToeGooooo1_mM0?lFooooo`Co0?mULoooool7o`3o8Poooooo0002ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool00ol0003oooooooooo`1?ooooo`0=
o`2Kool0oggo0:7oo`1Iool0c?oo06_oo`3oFOoooooo013oo`3oMol0i?oo02Soo`3oI@03ooooo`03
o`2^oooooooo04co00;o04co00?oooooo`2^ool0:?l00_ooool01ol0i?ooooooo`3o=?l0Pooo05;o
o`3oFOl04?l01?ooool02?l0oe;o0?mgo`3oPol0om;oooooo`3<ool0olco0?mg1?ooool01ol0ob;o
0:koooooool0C?oo0?ldooooool04?l00_ooool02?l0;_ooooooo`3oD_oooooo0?ljo`3ol?oooooo
9P3o0_ooool02_l0=?ooooooooooool0olcoooooo`3<oooooooo05;ooooooomG0?lBooooo`03o`3o
l?oooooooooo00?ooooo00?o03Coooooooooool03_ooool00olJ0?ooooooooooo`02ooooo`05o`23
ooooooooooooooooool0[_l01?ooool00ol0om;oG@3oooooo`09ooooo`06o`3foooooooooooooooo
ool0ogOo0?ld1Oooool2o`3o2P[ooooo00?o04coooooool02_l00_l0obP7ooooo`;o0?mI>?ooool3
o`3Todcooooo1_mM0?lPooooo`Co0?mUHoooool<o`3o8QKooooo00001Ooooooo0000oooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo04oooooo00ko
09_oo`3oa_l0XOoo05Woo`3<ool0Jooo0?ljo`3oFOl04?oo08?oo`3o=?l0i?oo02Soo`3oI@?ooooo
0_l0[_l2ooooo`03o`2^oooooooo02So00;ooooo00Oo0>Coo`3o=?l0Pooo05;oo`3oFOoooooo013o
00?ooooo00Wo0?mBo`3oMooooooo0?n3o`3od_l0c?oo0?o<ooooool0ogL00oooool2o`3omP06o`2^
oooooooo04coooooool0ocCo013o0_ooool02?l0;_ooooooooooool0oe;o0?ljo`3ol?oooooo9P3o
0_ooool01?l0=?ooooooooooool0ol`2ooooo`04o`3<ool0D_oooooooeL0oa;ooooo00?o0?o`oooo
ooooool00oooool00ol0=?ooooooooooo`0>ooooo`03oaX0oooooooooooo00?ooooo00Co08?ooooo
oooooooo0:ko1Oooool00omM0?oo0?oBooooo`07ooooo`03o`3foooooooooooo00;ooooo00?o0?mg
ooooooooool01_ooool2o`3o2POooooo00Oo04coooooooooooooooooo`0:oooooooo0?lX00Sooooo
0_l0oeTiooooo`;o0>CoA?ooool6oed0ob[ooooo1?l0ofE>oooooa7o0?lR8_ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooooooo
ool0Coooool03ol0Vooo0?o6o`2Qool0FOoo0<coo`29ool0Jooo0?mIo`0@ool0Pooo0?mgo`3Tool0
:?ooooooo`3oI@03ooooo`?o0:ko00_o0?mUo`0Xooooooooooooo`3Toooooooo0?ldo`23ool0D_oo
0?mIo`0@o`04ooooo`06o`3oMooooooo0?n3o`3od_oooooo0<co0oooool02ol0ogOo0?ofo`3om_l0
ooKoooooo`2^ool0ooKo04coooooool0ocCo013o00;ooooo00co02kooooooooooooo0?mBo`3o>_l0
oo3oooooobH0ool0:?ooooooo`0dool0oh<2ooooo`06o`3oc?oooooo0<coooooool0D_ooE`3o4Ooo
ool00ol0oo3oooooooooo`03ooooo`03o`0doooooooooooo013ooooo00?o6P3oooooooooool00ooo
ool00ol0Pooo0:koooooo`06ooooo`03oed0ool0om;ooooo00Kooooo00Go0?Kooooooooooooooooo
o`3oM`0;ooooo`03o`3o2_oooooooooo00?ooooo00?o04coooooooooool00oooool01?l02_oooooo
o`3o:?l0obP8ooooo`;o0?mI>Oooool2o`3Toccooooo1_mM0?ldooooo`Co0?mU>_ooool@o`3o8S?o
oooo00001Ooooooo0000oooooooooooo000000Oooooo1?l0000:ooooo`Co0000C_ooool03ol0Vooo
0?o6o`2Qool0FOoo0<coo`3oD_l0Jooo0?mIo`0@ool0Pooo0?mgo`3Tool0:?ooooooo`3oI@04oooo
o`;o0?mU00_oooooo`0Xooooooooooooo`3Tool0ocCoooooo`1Bool0oeWoooooo`0@o`03ooooo`07
o`3oD_l0ogOoooooo`3oPol0om;o0<coo`3oc003ooooo`;o0?of0oooool01_l0ob;o0:koo`1<ool0
ooKo0?ldo`0@o`?ooooo00_o02kooooooooooooo0?mBo`3ol?oooooo9P3oo`0Xoooooooo03Coo`3o
P`03ooooo`05o`3oc?oooooo0<coo`1BoomG0?l04Oooool00ol0oo3oooooooooo`03ooooo`03o`0d
oooooooooooo017ooooo00?o6P3oooooooooool00oooool00ol0Poooooooooooo`05ooooo`03oed0
oooooooo0?oB00Gooooo00Go0?Kooooooooooooo0?ldo`3oM`0=ooooo`;o0?l:0_ooool00ol0C?oo
ooooooooo`05ooooo`;o00[o00?oooooo`3o:?l0obP02?ooool2o`3oFCWooooo0ol0i?ldooooo`Go
G@3o?_ooool4o`3oIBkooooo2?l0ob93ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool03_l0Vooo0:7oo`1Iool0c?oo0?oB
o`1[ool0oc[o013oo`1Bool0ogOo0>Coooooool0:?oooooo1?l0ofD00ooooooo0?lXo`0Xo`02oooo
o`08o`3Toooooooo0?ldo`23ool0D_oo0?mIo`0@ool0ocX3ooooo`06o`3oMooooooo0?n3o`3od_oo
oooo0<co0oooool00ol0ooKoooooo`3oM`04ooooo`06o`2^ool0C?ooooooo`3om_oooooo013o0_oo
ool03?l0;_ooooooooooool0oe;o0?o`oooooolV0?oo02Soooooool0=?ooooooo`3oP`;ooooo00Go
0?o<ooooool0c?oo05;ooeL0o`0Aooooo`03o`3ol?oooooooooo00?ooooo00?o03Coooooooooool0
4Oooool00olJ0?ooooooooooo`03ooooo`03o`2^ool0Pooooooo00Kooooo00?oG@3oooooool0om80
0oooool01Ol0m_ooooooooooool0ocCo0?mg013ooooo0_l0o`X00ol0C?ooooooooooo`07ooooo`03
o`0:oooooooooooo00;o0?lX2?ooool00ol0oeWoooooooooo`0iooooo`?o0>Co:oooool6oed0odOo
oooo1?l0ofDSooooo`Oo0?lRBoooool00005ooooool0003oooooooooool000002?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00ko09_oo`2Qool0ok[o05Woo`3<ool0Jooo
0?ljo`3oFOl04?oo0?mgooooool0i?oo0?lXo`0Xo`Cooooo00co0?lXooooool0:?ooooooo`3Toooo
oooo0?ldooooool0Pooo05;oooooool04?l3ooooo`07o`3oMooooooo0?n3ooooool0om;o0<coo`3o
c002ooooo`04o`3om_ooooooooooo`3oM`Cooooo00Ko0:koo`1<oooooooo0?ldo`3om_l04?l2oooo
o`0<o`0^ooooooooooooo`3oD_l0oo3oooooobH0ool0:?ooooooo`0doooooooo0?n30oooool01Ol0
olcoooooo`1BooooooooE`3o013ooooo00?o0?o`ooooooooool00oooool00ol0=?ooooooooooo`0B
ooooo`05oaX0ooooooooooooooooool0[_l00_ooool00ol0Poooooooooooo`05ooooo`05oed0oooo
oooo0?oBooooool0m_l00_ooool00ol0ocCo0?mgooooo`0Aooooo`04o`1<ool0o`[o0?l:o`3o2PSo
oooo00Co00[ooooooooooooooooo0ol0obP6ooooo`;o0?mI??ooool3o`3Tob?ooooo1OmM0?mAoooo
o`Co0?mU5_ooool9o`3o8U;ooooo0002ooooo`;o00002_ooool2o`0000[ooooo00?o0000oooooooo
ool0D?ooool03_l0Vooo0?o6o`2Qool0FOoo0<coo`1[ool0oc[o0?mIo`0@ool0Poooooooo`3Toooo
oooo02So0oooool00ol0obSo02Soo`0Xo`02ooooo`08o`3Toooooooo0?ldo`23ool0D_oo0?mIo`0@
ool0ocX2ooooo`07o`3oMol0oe;o0?lRo`3oPooooooo0?oBo`3<o`03ooooo`05o`3om_oooooooooo
ooooool0ogL00oooool01_l0[_oo04cooooooooooooo0?ofo`0@o`;ooooo00So02kooooooooooooo
ooooo`3ol?l0oc[o9P3oo`0Xo`;ooooo00?o03Coooooool0oh<00oooool01?l0olco0<coo`1BoomG
0?l?ooooo`03o`3ol?oooooooooo00?ooooo00?o03Coooooooooool04oooool01OlJ0?oooooooooo
oooooooo0:ko00;ooooo00?o08?oooooooooool01Oooool02OmM0?ooooooooooool0om;o0?Kooooo
ool0ocCoooooo`3oM`0Aooooo`03o`1<oooooooooooo00;ooooo0_l0o`X7ooooo`03o`0:oooooooo
oooo00?ooooo0_l0obP6ooooo`;o0?mI?Oooool3o`3Toa_ooooo1OmM0?mJooooo`Co0?mU1oooool;
o`3o8U_ooooo000Jooooo`03o`000?oooooooooo053ooooo00ko09_oo`3oa_l0XOoo05Woo`3<ool0
ROoo06_oo`3oFOl04?oo05;oo`3oMol0ocCo0>Coooooo`Co02So0oooool02?l0i?ooooooo`3o=?oo
oooo08?oo`1Bool0oeWo013o0oooool01ol0ogOo0?mBo`3oPooooooo0?oBo`3<ool0ol`00_ooool0
0ol0ooKoooooooooo`02ooooo`06o`3oMoooooooooooooooool0[_oo04co0_ooool01Ol0ooKo013o
oooooooooooo02ko00?ooooo00Co0?o`o`3o>_lV0?oo02So0_ooool00ol0=?ooooooo`3oP`03oooo
o`04o`3oc?oooooo05;ooeL0o`oooooo00?o0?o`ooooooooool00oooool00ol0=?ooooooooooo`0D
ooooo`03oaX0oooooooo0:ko00Cooooo00?o08?oooooooooool01Oooool00omM0?ooooooo`3fo`02
o`3odP03ooooool0ogOooooo013ooooo00?o04coooooooooool01Oooool2o`3o2PKooooo00?o00[o
ooooooooool01?ooool2o`3o:0Kooooo0_l0oeTnooooo`?o0>Co4oooool5oed0of3ooooo0ol0ob84
o`3oI@?o0?lRI_ooool001[ooooo00?o0000ooooooooool0D?ooool03_l0Vooo0?o6o`2Qool0FOoo
0<coo`3oD_l0Jooo0?ljo`3fool04?oo0?mgooooool0ocCo0>Co1oooool02?l0i?ooooooo`3o=?oo
oooo08?oo`1Bool04?oo0?lj0_ooool01ol0ogOo0?mBo`3o8_l0oh?oooooo`3od_l0c?l00_ooool0
0ol0ooKoooooooooo`03ooooo`0:o`3oMoooooooooooooooool0[_oo0?lRo`1<oooooooo0?ldo`0@
o`;ooooo00_o02koooooooooooooooooo`3oD_l0oo3oooooobH0ool0:?ooooooo`0do`02ooooo`07
o`3oPoooooooooooooooool0olco05;ooeL0o`0?ooooo`03o`3ol?oooooooooo00?ooooo00?o03Co
ooooooooool05?ooool00olJ0?ooooooo`2^o`05ooooo`03o`23oooooooooooo00Gooooo00GoG@3o
o`3o=?l0ocCoooooo`3odP0Aooooo`03o`1<oooooooooooo00Sooooo0ol0o`X4ooooo`;o00[o1_oo
ool2o`3o:0Kooooo00?o0?mIooooooooool0?_ooool3o`3To`cooooo1?mM0?mMooooo`So0?lR1ooo
ool4o`3oIFGooooo000Jooooo`03o`000?oooooooooo057ooooo00go09_oo`2Qool0FOoo0<coo`3o
d_l0Jooo0?ljo`3oFOl04?oo0?mgooooool0ocCo0>Co00Kooooo00So0>Coooooool0ocCoooooo`23
ool0D_oo0?mIo`0@o`;ooooo00[o0?mgooooool0oe;o0?n3ooooool0om;oooooo`3<oooooooo0?of
1oooool02Ol0ogOooooooooooooooooo0:koo`1<oooooooo0?ldo`0@o`02ooooo`03o`0^oooooooo
oooo00;ooooo00Ko0?o`oooooolV0?oo02Soooooool0=?l2ooooo`03o`3oPooooooooooo00;ooooo
00?o0?o<oeL0ooooool03_ooool00ol0oo3oooooooooo`02ooooo`03o`0doooooooooooo01Kooooo
00?o6P3oooooooooool01?ooool00ol0Poooooooooooo`05ooooo`06oed0ooooooooooooo`3oMooo
oooo0?oB3oooool00ol0C?ooooooooooo`0<ooooo`?o0?l:0oooool00ol02_ooooooooooo`05oooo
o`;o0?lX1Oooool2o`3oFD7ooooo0ol0i?l4ooooo`GoG@3oF_ooool7o`3o8Q?ooooo0ol0ofERoooo
o`006_ooool00ol0003oooooooooo`1Aooooo`0:o`2Kool0XOoo0?njo`1Iool0c?oo06_oo`3o>_l0
oeWo013oo`1Bo`;ooooo00?o0?ldo`3Tooooool00oooool00ol0i?ooooooo`3o=002ooooo`04o`23
ool0D_oo013oo`3o>P;ooooo00Oo0?mgo`3oD_l0ob;o0?n3ooooool0om;o0<co00;ooooo00?o0?of
ooooooooool01Oooool03?l0ogOooooooooooooooooo0:koo`1<oooooooo0?ldooooool04?oooooo
o`0^o`Cooooo00Ko0?o`o`3o>_lV0?oo02Soooooool0=?l3ooooo`07o`3oPoooooooooooooooool0
olcoE`3oo`3<o`0>ooooo`03o`3ol?oooooooooo00;ooooo00?o03Coooooooooool05_ooool00olJ
0?ooooooooooo`05ooooo`03o`23oooooooooooo00?ooooo00Co0?KooooooomM0?oo0?mg0oooool0
0ol0om;oooooooooo`0;ooooo`03o`1<oooooooooooo013ooooo0ol0o`X00ooooooo00[oooooo`07
ooooo`?o0?lX1?ooool2o`3oFD;ooooo1?mM0?mGooooo`So0?lR7Oooool4o`3oIEkooooo000Joooo
o`03o`000?oooooooooo057ooooo00go09_oo`2Qool0ok[o05Woo`3<ool0Jooo0?lRo`3o>_l0m_oo
013oo`3oMooooooo0?ld00Go0>Co00?oooooo`3o=?ooool00_ooool00ol0D_oo0?mIo`0@o`02oooo
o`0:o`3oMooooooo0?mBo`3oPooooooo0?oBooooool0c?ooooooo`3omPSooooo00go0?mgoooooooo
ooooooooo`2^ool0C?ooooooo`3o=?oooooo013oo`3om_oooooo02ko00?ooooo00Ko0?o`o`3o>_lV
0?oo02Soooooool0=?l3ooooo`03o`3oPooooooooooo00;ooooo00?o05;ooeL0ooooool03?ooool0
0ol0oo3oooooooooo`03ooooo`03o`0doooooooooooo01Kooooo00?o0:kooaX0ooooool01_ooool0
1_l0Pooooooooooooooooooo0?ldo`3fo`;ooooo00?oG@3oooooooooool00_ooool00ol0om;ooooo
ooooo`09ooooo`03o`1<oooooooooooo01Cooooo0_l0o`X00ol02_oo0?l:ooooo`08ooooo`;o0?lX
1?ooool2o`3oFC_ooooo1OmM0?l3ooooo`?o0>CoCOooool8o`3o8RWooooo1?l0ofEJooooo`006_oo
ool00ol0003oooooooooo`1Aooooo`0;o`2Kool0olKo0:7oo`1Iool0c?oo06_oo`3o8_l0oc[o0?Ko
o`0@ool0ogL00_ooool00ol0ocCoooooooooo`03ooooo`07o`3o=?ooooooooooo`23ool0D_oooooo
o`0@o`02ooooo`07o`3oMol0oe;o0?lRo`3oPooooooo0?oBo`3<o`02ooooo`03o`3om_oooooooooo
00Oooooo00co0?mgoooooooooooo0:koo`1<ool0ob;oooooo`3o=?l04?oo0?ofooooool0;_l3oooo
o`06o`3ol?l0oc[o9P3oo`0Xoooooooo03Co0oooool00ol0oh?oooooooooo`03ooooo`03oeL0ool0
c?oooooo00_ooooo00?o0?o`ooooooooool00oooool00ol0=?ooooooooooo`0Eooooo`04o`2^oooo
oooooooooaX0o`Kooooo00Go08?oooooool0ocCo0?ldo`3fo`02ooooo`03o`3oMoooooooG@3o00Co
oooo00?o0?oBooooooooool01oooool00ol0C?ooooooooooo`0Hooooo`04o`0:ool0o`[o0?l:o`3o
2PSooooo0_l0obP4ooooo`;o0?mI=?ooool5oed0o`_ooooo1?l0i?m1ooooo`So0?lR=Oooool4o`3o
IEKooooo000Jooooo`03o`000?oooooooooo05;ooooo00[o09_oo`2Qool0FOoo0<coo`29ool0Jooo
0?ljo`3fool04?oo08?o0_ooool2o`3o=0;ooooo0_l0oc@3ooooo`03o`1Bool0oeWo013o00;ooooo
00Co0?mgooooool0oe;o0?n30_ooool01?l0om;o0<coooooool0ooH:ooooo`0<o`3oMooooooooooo
o`2^ool0C?oo0?lRooooool0ocCo013oo`3om_oooooo02ko0oooool01?l0oo3o0?mBobH0ool0:?l2
ooooo`05o`0dooooooooooooooooool0oh<01?ooool00omG0?oo0<coooooo`0;ooooo`03o`3ol?oo
oooooooo00;ooooo00?o03Coooooooooool05_ooool01?l0[_oooooooooooolJ0?l7ooooo`03o`23
oooooooo0?Ko00;ooooo00Go0?mgoooooooooooooooooed0o`04ooooo`03o`3od_oooooooooo00Go
oooo00?o04coooooooooool06_ooool00ol02_ooooooooooo`03o`3o2POooooo0_l0obP4ooooo`03
o`3oFOoooooooooo02cooooo1OmM0?lDooooo`?o0>Co>?ooool6o`3o8T7ooooo1Ol0ofEAooooo`00
6_ooool00ol0003oooooooooo`1Booooo`0;o`2Kool0XOoo05Woo`3<ool0om;o06_oo`3o>_l0oeWo
0?Koo`0@ool0Pol00oooool3o`3o=0?ooooo00Ko08?oo`1Bool0oeWo013oooooool0ogL2ooooo`05
o`3oD_l0oh?oooooo`3od_l0c?l00_ooool00ol0ooKoooooooooo`08ooooo`0<o`3oMooooooooooo
o`2^ool0C?oo0?lRooooool0ocCo013oooooool0ooKo02ko0oooool01ol0oo3o0?mBobH0oooooooo
02Soooooool0=?l00oooool00ol0oh?oooooooooo`02ooooo`03oeL0ool0olco0<co00_ooooo00?o
0?o`ooooooooool00_ooool00ol0=?ooooooooooo`0Eooooo`03o`2^oooooooooooo00;ooooo00?o
6P3oooooooooool00oooool01_l0ocCoooooo`23ool0m_ooooooo`3oM`Gooooo00?oG@3ooooooooo
ool00_ooool2o`3odPCooooo00?o04coooooooooool07?ooool2o`0:o`?ooooo1?l0o`X5ooooo`;o
0?lX0oooool2o`3oFBOooooo1OmM0?lLooooo`?o0>Co<?ooool5o`3o8Tcooooo1Ol0ofE<ooooo`00
6_ooool00ol0003oooooooooo`1Booooo`0;o`2Kool0XOoo0?njo`1Iool0c?oo06_oo`3o8_l0oc[o
0?Koo`0@ool0Pol02?ooool04?l0Pooo05;oo`3oFOl04?oo0?ljooooool0ogOoooooo`3oD_oooooo
0?n3ooooool0om;o0<coooooool0ooH3o`3fo`Sooooo00co0?mgooooooooooooooooo`2^ool0C?oo
ooooo`3o=?l04?ooooooo`3om_l0;_l4ooooo`06o`3ol?l0oc[o9P3oo`0Xoooooooo03Co1?ooool0
2?l0oh?oooooooooooooooooE`3oo`1Bool0olco0<co2Oooool00ol0oo3oooooooooo`03ooooo`03
o`0doooooooooooo01Gooooo00?o0:koooooooooool00_ooool00olJ0?ooooooooooo`02ooooo`06
o`3o=?ooooooooooo`23oooooooo0?mg1oooool00omM0?ooooooooooo`03ooooo`04o`3od_oooooo
ooooo`1<ob7ooooo00?o00[oooooooooool01?ooool3o`3o2PCooooo0ol0obP2ooooo`;o0?mI8?oo
ool5oed0obCooooo1?l0i?lWooooo`Go0?lRE_ooool4o`3oIDSooooo000Jooooo`03o`000?oooooo
oooo05;ooooo00co09_oo`2Qool0ok[o05Woo`3<ool0Jooo0?lRo`3o>_l0m_oo013oo`3oMol0Pol7
ooooo`06o`23ool0D_oo0?mIo`0@oooooooo0?mg0_ooool01_l0oe;o0?n3ooooool0om;o0?o<o`3<
o`?o0?Ko00Coooooo`3fool0m_oo0?Ko1oooool02ol0ogOoooooooooool0[_oo04coo`3o8_l0ocCo
ooooo`0@ool0ooKo02ko00Cooooo00Ko0?o`o`3oD_lV0?oo02Soooooool0=?l4ooooo`09o`3oPooo
oooooooooooooomG0?oo05;oooooool0olco0<co00Sooooo00?o0?o`ooooooooool00oooool00ol0
=?ooooooooooo`0Dooooo`03o`2^oooooooooooo00Cooooo00Co6P3ooooooooooooo0?ld0oooool0
0ol0m_oo08?oo`3oM`08ooooo`03oed0oooooooooooo00?ooooo00?o0?oBo`1<ooooool08_ooool0
0ol02_ooooooooooo`06ooooo`Go0?l:0_ooool2o`3o:0;ooooo0_l0oeTIooooo`GoG@3o;Oooool3
o`3Tob3ooooo1?l0ob9Oooooo`Go0?mU@oooool001[ooooo00?o0000ooooooooool0D_ooool03?l0
Vooo0:7oo`3o^_l0FOoo0<coo`1[ool0ob;o0?ljo`3fool04?oo05;oo`23o`Kooooo00Ko08?oo`1B
ool0oeWo013oo`3o>_l0ogL2ooooo`06o`3oD_oooooo0?n3ooooool0om;o0<co0_l0m_l6ooooo`03
o`3foooooooooooo00Cooooo00_o0?mgoooooooooooo0:koo`1<ool0ob;oooooo`3o=?l04?oooooo
o`0^o`04ooooo`06o`3ol?l0oe;o9P3oo`0Xoooooooo03Co1Oooool01Ol0oh?ooooooooooooooooo
E`3o00;ooooo00?o0<coooooooooool01_ooool00ol0oo3oooooooooo`02ooooo`03o`0doooooooo
oooo01Gooooo00?o0:koooooooooool01?ooool00olJ0?ooooooo`3o=003ooooo`03o`3foooooooo
08?o00[ooooo0_mM0?l4ooooo`03o`1<oooooooooooo02;ooooo0_l02_l;ooooo`Co0?l:0_l0obP2
ooooo`;o0?mI4_ooool5oed0ocGooooo1?l0i?lGooooo`Go0?lRJ?ooool4o`3oICoooooo000Joooo
o`03o`000?oooooooooo05?ooooo00co09_oo`2Qool0FOoo0<coo`1[ool0ob;o0?ljo`3oFOl0m_oo
013oo`1Bool0Pol3ooooo`;o08?o00Go05;oo`3oFOl04?oo0?ljo`3oM`03ooooo`07o`3oD_l0oh?o
ooooo`3od_l0olco0<coo`3omP04ooooo`Co06_o1_ooool02ol0ogOoooooooooool0[_oo04coo`3o
8_oooooo0?ldo`0@oooooooo02ko00Cooooo00Co0?o`o`3oD_lV0?oo02So0_ooool00ol0=?oooooo
ooooo`02ooooo`06o`3oPooooooooooooooooomG0?oo05;o0_ooool00ol0c?ooooooooooo`05oooo
o`03o`3ol?oooooooooo00;ooooo00?o03Coooooooooool05Oooool00ol0[_ooooooooooo`05oooo
o`03oaX0ool0ocCooooo00;ooooo00Co0?Koo`3oMooooooo08?o2oooool01_mM0?ooooooooooool0
C?ooooooo`3odRGooooo00?o00[oooooooooool03_ooool2o`3o:0;o0?l:0_l0oeT<ooooo`CoG@3o
?_ooool5o`3To`kooooo1?l0ob9aooooo`Go0?mU>_ooool001[ooooo00?o0000ooooooooool0Dooo
ool03?l0Vooo0:7oo`1Iool0olco06_oooooool0ob;o0?ljo`3fool04?oo05;oooooo`Co08?o00Go
05;oooooool0oeWo013oo`3oM`03ooooo`08o`3o8_l0oe;o0?n3ooooool0om;o0<coooooool0ooH2
ooooo`;o06_o1?ooool2o`1[o`Cooooo00co0?mgoooooooooooo0:koo`1<ool0ob;oooooo`3o=?l0
4?ooooooo`3om_l0;_l3ooooo`04o`3ol?l0oe;o9P3oo`0Xo`;ooooo00?o03Coooooooooool00ooo
ool01Ol0oh?ooooooooooomG0?oo05;o00?ooooo00?o0<coooooooooool00oooool00ol0oo3ooooo
ooooo`03ooooo`03o`0doooooooooooo01Cooooo00?o0:koooooooooool01_ooool01_lJ0?oooooo
oooooooooooo0?Koo`3oM`?ooooo00?o08?oooooooooool02Oooool00omM0?oo04coooooo`02oooo
o`;o0?oB9?ooool2o`0:oa3ooooo0_l0obP2ooooo`;o0?mI0ol0o`X2ooooo`GoG@3oAoooool5o`3T
o`Cooooo1Ol0ob9jooooo`Go0?mU=Oooool001[ooooo00?o0000ooooooooool0Doooool02ol0Vooo
0:7oo`3o^_l0FOoo0<coo`1[ool0ob;o0?ljo`3foooooooo013o00;o05;o00Coooooo`1Bool0D_oo
oooo0_l04?l00ol0ogOoooooooooo`02ooooo`07o`3oD_l0oh?oooooo`3od_l0m_oo0<coo`3omP02
ooooo`03o`1[oooooooooooo00Cooooo00?o0?Koo`1[ooooool00oooool03?l0ogOoooooooooool0
[_oo04coooooool0ob;o0?ldo`0@oooooooo0?ofo`0^o`Cooooo00Ko0?o`obH0oooooooo02Sooooo
ool0=?l5ooooo`06o`3oPooooooooooooeL0oooooooo05;o0oooool00ol0c?ooooooooooo`02oooo
o`03o`3ol?oooooooooo00;ooooo00?o03Coooooooooool05Oooool00ol0[_ooooooooooo`05oooo
o`07o`3o=?oooooo6P3oooooool0m_ooooooo`3oM`03ooooo`03o`23oooooooooooo00Wooooo00?o
04cooed0ooooool01?ooool00ol0om;oooooooooo`0Sooooo`03o`0:oooooooooooo00oooooo0ol0
obP00oooooooG@3ooed0o`03oed0o`Go0?l:Boooool00ol0ob;o0>Coo`3To`02o`3TohCooooo1?l0
ofDaooooo`006_ooool3o`0005?ooooo00_o09_oo`2Qool0ok[o05Woo`3<ool0Jooo0?lRo`3o>_oo
oooo0?Koooooo`02o`0@o`;o05;o00Goooooo`0@ool0oeWo0?mgo`3o>P03ooooo`0:o`3o8_l0oe;o
0?n3ooooool0m_oo0<coooooool0ooKoooooo`1[o`Kooooo0ol0FOl01Ol0Jooooooooooooooooooo
0?mg00?ooooo00Go04coooooool0ob;o0?ldo`0@o`02ooooo`03o`0^oooooooooooo00;ooooo00Ko
0?o`obH0ool0oc[o02Soooooool0=?l6ooooo`05o`3oPoooooooE`3oooooool0D_l00oooool00ol0
c?oo0?o<ooooo`02ooooo`03o`3ol?oooooooooo00;ooooo00?o03Coooooooooool05?ooool00ol0
[_ooooooooooo`05ooooo`07o`3o=?oooooooooooooooolJ0?oo0?Koo`3oM`05ooooo`03o`23oooo
oooooooo00Oooooo00?o04coooooooooool00omM0?l3ooooo`03o`3od_oooooooooo02?ooooo00?o
00[oooooooooool03Oooool5oed0o`03o`3o:?l0oeWo0?mI00Oooooo2?l0o`Xoooooo`Co0?lR1Ooo
ool5o`3Toh?ooooo1Ol0ofD/ooooo`006_ooool00ol0003oooooooooo`1Cooooo`0:o`2Kool0XOoo
0?njo`1Iool0c?oo06_oo`3o8_oooooo0?ljo`3fo`;ooooo1Ol04?l2o`3oM`Cooooo00Wo0?mBoooo
ool0oh?o0?Koo`3oc?l0c?oo0?ofooooool0Jol01Oooool3o`1Io`04ooooool0FOoo05Woo`1Io`?o
oooo00_o0?mgoooooooooooo0:koo`1<ool0ob;o0?ldooooool04?ooooooo`0^o`04ooooo`06o`3o
l?l0oe;o9P3oo`0Xoooooooo03Co1_ooool01Ol0oh?ooooooeL0oooooooo05;o00Cooooo00Go0<co
o`3oc?ooooooooooo`3ol004ooooo`03o`0doooooooooooo01Cooooo00?o0:koooooooooool01?oo
ool00ol0ocCoooooooooo`02ooooo`03oaX0ool0ogOooooo00Kooooo00?o08?oooooooooool01Ooo
ool00ol0C?ooooooooooo`04ooooo`?oG@3o00?oooooo`3od_ooool09?ooool2o`0:o`Oooooo1_mM
0?l6ooooo`;o0?lX0_l0oeT=ooooo`Oo0?l:<oooool5o`3o8Pkooooo1_l0i?n2ooooo`Go0?mU9ooo
ool001[ooooo00?o0000ooooooooool0Doooool03?l0ol3o09_oo`3oa_l0FOoo0?o<o`1[oooooooo
0?lRo`3o>_oooooo0?Koo`3oF@;ooooo0_l0ogL00ooooooo0?ljooooo`03ooooo`09o`3o8_l0oe;o
0?n3ooooool0m_oo0<coooooool0ooKo06_o00Gooooo0_l0FOl4ooooo`03o`3fool0FOoooooo00;o
oooo00_o0?mgoooooooooooo0:koo`1<ool0ob;oooooo`3o=?l04?ooooooo`0^o`04ooooo`06o`3o
l?l0oe;o9P3oo`0Xoooooooo03Co1oooool01Ol0oh?ooooooeL0oooooooo05;o00Cooooo00?o0<co
o`3oc?l0oo001Oooool00ol0=?ooooooooooo`0Cooooo`03o`2^oooooooooooo00Cooooo00?o0?ld
ooooooooool00oooool00ol0m_oo6P3oooooo`06ooooo`03o`23oooooooooooo00Cooooo00?o04co
ooooooooool02?ooool2oed0o`03o`3od_oooooooooo02Cooooo0_l02_l5oed0o`kooooo0_l0obP2
o`3oFA;ooooo2?l0o`XWooooo`Co0?lR6Oooool8o`3Togoooooo1_l0ofD=ooooo`Go00[o3oooool0
01[ooooo00?o0000ooooooooool0E?ooool02_l0Vooo0:7oo`1Iool0olco08Woo`1[ool0ob;ooooo
o`3o>_l0m_l5o`3oF@03ooooool0oc[ooooo00?ooooo00Wo0?mBooooool0oh?o0?Koo`3<ool0olco
0?ofooooool0Jol01?ooool00ol0FOooooooooooo`04ooooo`03o`3fool0Jooo05Wo00;ooooo00co
0?mgoooooooooooo0:koo`1<ool0ob;oooooo`3o=?l04?ooooooo`0^ool0ooH3ooooo`04o`3ol?oo
oooo9P3oo`0Xo`;ooooo00?o03Coooooooooool01?ooool01Ol0oh?ooooooeL0oooooooo05;o00Go
oooo00?o0<coo`3ol?ooool00oooool00ol0=?ooooooooooo`0Dooooo`03o`2^oooooooooooo00?o
oooo00?o0?ldooooooooool00oooool00ol0m_oooooooaX0o`08ooooo`03o`23oooooooooooo00?o
oooo00?o04coooooooooool02_ooool4oed0oa[ooooo2omM0?l2o`0:oaCooooo00?o0?lXo`3oFOl0
oeT06?ooool7o`3o2P?ooooo?_l0;_l4ooooo`Oo0>CoO_ooool5o`3oI@So00[o5?ooool001[ooooo
00?o0000ooooooooool0E?ooool02_l0Vooo0:7oo`1Iool0ooKo0<coo`1[oooooooo0?lRooooool0
m_l5ooooo`03o`3o>_oooooooooo00;ooooo00Wo0?lRo`3oD_l0oh?o0?Koo`3od_l0c?ooooooo`3o
m_l0Jol01?ooool00ol0FOooooooooooo`06ooooo`05o`1[oooooooo05Woooooool0ogL00_ooool0
2Ol0[_oo04coooooool0ob;o0?ldo`0@oooooooo02koo`3omP03ooooo`07o`3ol?oooooo9P3oo`3o
>_l0:?ooooooo`0do`06ooooo`05o`3oPoooooooE`3oooooool0D_l01_ooool00ol0c?oo0?o<oooo
o`02ooooo`03o`0doooooooooooo01Cooooo00?o0:koooooooooool00_ooool00ol0ocCooooooooo
o`04ooooo`04o`3foooooooooooooaX0o`Sooooo00Go08?oooooooooooooooooo`1<o`0@ooooo`03
o`3od_mM0?ooG@3o01SoG@3o3Oooool00ol02_ooooooooooo`0Dooooo`;o0?mI00?o0?lXoooooooo
ool04Oooool<o`0^o`Co0?l:3oooool5o`3o8RKooooo7Ol0;_mZooooo`Oo00[o1_l0ofDFooooo`00
6_ooool00ol0003oooooooooo`1Dooooo`0;o`2Kool0XOoo0?njo`1Iool0c?oo06_oooooool0ob;o
ooooo`3o>_l0m_l00_ooool2o`3o>PGooooo00Wo0?lRo`3oD_l0m_oo0?oBo`3<ool0olco0?ofoooo
ool0Jol00oooool00ol0FOooooooooooo`04ooooo`;o0?o600Koooooo`3fool0Joooooooo`1Iool0
ogL2ooooo`09o`2^ool0C?ooooooo`3o8_l0ocCo013oooooool0;_oo0?of00Cooooo00Ko0?o`obH0
ool0oc[o02Soooooool0=?l7ooooo`05o`3oPomG0?ooooooooooool0D_l01?ooool01?l0oo3ooooo
o`3<ool0ol`2ooooo`03o`0doooooooooooo01?ooooo00?o0:koooooooooool00_ooool00ol0ocCo
ooooooooo`04ooooo`05o`3foooooooooooooooooolJ0?l02Oooool00ol0Poooooooo`1<o`0Boooo
o`03o`3od_oooooooooo02Gooooo0_l02_lFooooo`;o0?mI0_l0obP:ooooo`Ko02ko4?ooool:o`3o
2PGo0?lR?_ooool8o`3To`;ooooo5ol0;_m<ooooo`Oo00[o3Oooool5o`3oIA7ooooo000Jooooo`03
o`000?oooooooooo05Cooooo00Wo09_oo`2Qool0oggo05Woo`3oc?l0ROoo06_oooooool0ob800_oo
ool00ol0m_oo0?ljo`3o>P05ooooo`09o`3o8_l0oe;o0?Koooooool0om;o0<coooooool0ooKo06_o
00?ooooo00?o05Woooooooooool00_ooool3o`3oaP;o0?n?00Oo0?o6o`3fool0Joooooooo`1Ioooo
oooo0?mg00;ooooo00So04coooooool0ob;o0?ldo`0@oooooooo02koo`3omPCooooo00Ko0?o`obH0
ool0oe;o02Soooooool0=?l7ooooo`05o`3oPomG0?ooooooooooool0D_l01?ooool00ol0oo3ooooo
ooooo`02o`3<o`03o`0doooooooooooo01Cooooo00Go0:koooooooooooooooooo`3o=006ooooo`03
o`3foooooooooooo00?ooooo00?o6P3oooooooooool01_ooool00ol0Pooo04coooooo`0Cooooo`03
o`3od_oooooooooo02Kooooo0_l02_lFooooo`;o0?mI0ol0obP7o`0^oa_ooooo1Ol0ob8=o`3o2Sko
oooo1ol0i?lBoooooaSo02ko;_ooool6o`0:o`oooooo3?l0ogd?ooooo`006_ooool00ol0003ooooo
ooooo`1Dooooo`09o`3o`?l0Vooo0?o6o`1Iool0ooKo0<coo`1[oooooooo0?lR00;ooooo00?o0?Ko
ooooooooool01Oooool2o`3fo`06o`3oPol0om;o0<coo`3oc?l0ooKo06_o0oooool00ol0FOoooooo
ooooo`02ooooo`04o`3oa_l0ohoo0?n?o`3oS`;ooooo00Oo0?n?o`3fool0olKo06_oo`1Ioooooooo
0?mg00;ooooo00Wo04coooooool0ob;oooooo`3o=?l04?ooooooo`0^ool0ooH00oooool01_l0oo3o
9P3oo`3oD_l0:?ooooooo`0do`Sooooo00GoE`3oooooooooooooooooo`1Bo`03ooooo`03o`3ol?oo
oooooooo00;ooooo00?o03Coo`3oc?l0ol`04oooool01Ol0[_oooooooooooooooooo0?ld00Kooooo
00?o0?mgo`3fooooool01?ooool00olJ0?ooooooooooo`06ooooo`03o`1<ool0Pooooooo01Cooooo
00?o0?oBooooooooool09oooool2o`0:oa?ooooo1_l0;_l3o`3o:1[ooooo1Ol0ob8Boooooa;o0?l:
<oooool8o`3Tob;ooooo5_l0;_lBooooo`Ko00[o0ooooolBo`3oOA_ooooo000Jooooo`03o`000?oo
oooooooo05Cooooo00Wo0?o0o`2Kool0XOoo05Woo`3om_l0c?oo06_oooooool0ob800oooool00ol0
m_ooooooooooo`02ooooo`;o0?Ko00Oo0?mBooooool0oh?o0?oBo`3<oooooooo06_o00Cooooo00?o
05Woooooooooool00_ooool00ol0olKoooooooooo`04ooooo`06o`3fool0ohoo06_oooooool0FOoo
0?mg0_ooool02Ol0[_oo04coo`3o8_oooooo0?ldo`0@oooooooo02koo`3omP03ooooo`04o`3ol?oo
oooo9P3oo`0Xo`;ooooo00?o03Coooooooooool01Oooool01Ol0oh?oE`3ooooooooooooo05;o00?o
oooo00?o0?o`ooooooooool00_ooool01?l0=?oo0<coooooool0ol`Booooo`04o`2^oooooooooooo
o`3o=0Kooooo00?o0?mgo`3fooooool01_ooool00olJ0?ooooooooooo`04ooooo`04o`1<oooooooo
ooooo`23oaGooooo0_l0om8Yooooo`;o00[o3?ooool5o`0^o`Kooooo0_l0oeT01?oooooo0?lXo`3o
:?l0obPDooooo`?o0?lR:OoooolAo`3o2R[ooooo2?l0i?l`ooooo`co02ko1_l02_l5o`0^o`Co0?mm
;Oooool001[ooooo00?o0000ooooooooool0EOooool02Ol0Vooo0:7oo`1Iool0ooKo0<coo`29ool0
Joooooooo`3o8P03ooooo`Go0?Ko00So0?mBooooool0oh?oooooo`3<ool0olco0?ofo`1[o`?ooooo
00Co05Wooooooooooooooooo0_l0ROl00ol0ohooooooooooo`05ooooo`05o`3fool0Joooooooo`1I
ool0ogL00_ooool02Ol0[_oo04coooooool0ob;o0?ldo`0@oooooooo02koo`3omP03ooooo`07o`3o
l?oooooo9P3oo`3oD_l0:?ooooooo`0do`08ooooo`07oeL0ooooooooooooooooool0D_ooooooo`3o
l004ooooo`05o`0dooooooooooooo`3<ooooool00_l0ol`@ooooo`04o`2^ooooooooooooo`3o=0Ko
oooo00?o0?mgo`3fooooool01_ooool00olJ0?ooooooooooo`03ooooo`03o`1<oooooooooooo00;o
oooo00?o08?oooooooooool05?ooool00ol0om;oooooooooo`0Xooooo`;o00[o1Oooool5o`0^o`go
oooo0_l0oeT2ooooo`?o0?lX3_ooool3o`3o8Sgooooo2ol0o`XWooooo`Oo0>Co;?ooool3o`3oO@Ko
00[o0ol0ogd8oooooaOo02ko6_ooool001[ooooo00?o0000ooooooooool0EOooool01ol0Vooo0:7o
o`3oOOl0FOoo0<coo`3od_l0Jol00_ooool00ol0ob;oooooooooo`03ooooo`09o`3o8_oooooo0?mB
ooooool0oh?o0?oBo`3<oooooooo06_o00Cooooo00Co05Woooooool0ROoo08Wo0_l0j_l3o`29o`Go
oooo00Go0?Koo`1[ool0olKo05Woo`3oM`02ooooo`0:o`2^ool0C?ooooooo`3o8_l0ocCo013ooooo
ool0;_ooooooo`3omP?ooooo00Ko0?o`obH0ool0oe;o02Soooooool0=?l8ooooo`07oeL0oooooooo
ooooooooool0D_ooooooo`3ol004ooooo`04o`0dooooooooooooooooo`;o0<co00?oooooo`3oc?l0
ol`03Oooool01?l0[_ooooooooooool0oc@6ooooo`03o`3oMol0m_oooooo00Sooooo00?o6P3ooooo
ooooool00_ooool00ol0C?ooooooooooo`03ooooo`03o`23oooooooooooo01Cooooo00?o0?oBoooo
ooooool0:Oooool2o`0:o`?o02ko5?ooool2o`3oF@?ooooo0ol0obP7ooooo`Co0?lR5_oooomSo`3Z
o`[o0>Co8?l0j_l5o`0:obSo0>[o2ol0;_l?ooooo`006_ooool00ol0003oooooooooo`1Eooooo`07
o`2Kool0XOoo0?mmo`1Iool0ooKo0<coo`1[o`02ooooo`?o0?lR00_oooooo`3o8_l0ob;oooooo`3o
D_oooooo0?n3ooooool0om;o0<coo`1[o`04ooooo`06o`1Iool0ROoo08Woo`3Zool0olKo0?n?0_oo
ool00ol0j_oo08Woooooo`04ooooo`0Ao`3foooooooo06_oooooool0FOoo0?mgooooool0[_oo04co
ooooool0ob;o0?ldo`0@oooooooo02koooooool0ooH00oooool01?l0oo3o9P3oo`3oD_l0:?l2oooo
o`03o`0doooooooooooo00Gooooo00?oE`3oo`3oPoooool00_ooool00ol0D_oo0?o`ooooo`03oooo
o`03o`0doooooooooooo00?ooooo00Co0<cooooooooooooo0?o<3?ooool00ol0[_ooooooo`3o=007
ooooo`03o`3oMol0m_oooooo00Wooooo00Co6P3ooooooooooooo04co1_ooool00ol0Pooooooooooo
o`0Eooooo`03o`3od_oooooooooo02Gooooo1?l0;_l00ooooooo00[oo`0:o`0Gooooo`;o0?mI1?oo
ool3o`3o:004ooooool0ob;o0?lRo`3o8PGooooo5Ol0j_m0ooooo`co0?l:8Oooool=o`3To`[o0?mm
0oooool6o`0:odOooooo000Jooooo`03o`000?oooooooooo05Gooooo00So09_oo`2Qool0oggo05Wo
o`3om_l0c?oo08Woo`1[o`?ooooo0_l0ob82ooooo`08o`3oD_ooooooooooo`3oPol0om;o0<coo`1[
ool0ooH3ooooo`06o`1Iool0ROoo0>[oooooool0olKo0?n?1?ooool00ol0j_oo08Woooooo`04oooo
o`0@o`3fool0Jooo0?o6o`1Iool0ogOoooooo`2^ool0C?ooooooo`3o8_l0ocCo013oooooool0;_oo
ooooo`3omP?ooooo00Co0?o`obH0oooooooo02So0_ooool00ol0=?ooooooooooo`05ooooo`03oeL0
oooooooo0?n300;ooooo00?o05;oo`3ol?ooool00_ooool00ol0=?ooooooooooo`05ooooo`03o`3<
oooooooooooo00;o0?o<2_ooool00ol0[_ooooooo`3o=006ooooo`03o`3oMol0m_oooooo00[ooooo
00?o6P3oooooool0C?l02?ooool00ol0Poooooooooooo`0Eooooo`03o`3od_oooooooooo023ooooo
1?l0;_l7ooooo`;o00[o5oooool2o`3oF@?ooooo2ol0j_mQooooo`co0?l:5Oooool;o`3oO@;ooooo
2?l0i?l5o`0:o`Go0>CoB?ooool001[ooooo00?o0000ooooooooool0EOooool02Ol0Vooo0?o0o`2Q
ool0oggo05Woo`3<ool0om;o08Woo`1[o`05ooooo`08o`3oD_ooooooooooo`3oPol0om;oooooo`1[
ool0ooH4ooooo`05o`1Iool0j_ooooooooooool0olH01_ooool00ol0ROooooooooooo`03ooooo`05
o`3fool0Jooo0?n?o`3oa_l0FOl00_ooool01ol0C?ooooooooooool0ob;o0?ldo`0@ool0;_l00_oo
ool01ol0ooKooooooooooooooooo0?o`obH0ool0:?l00_ooool00ol0=?ooooooooooo`06ooooo`05
oeL0ool0oh?oooooooooool0D_l01?ooool00ol0=?ooooooooooo`06ooooo`05o`3<oooooooooooo
ooooool0ol`02?ooool00ol0[_ooooooo`3o=007ooooo`03o`3oMol0m_oooooo00_ooooo00?o6P3o
ooooooooool02?ooool00ol0Poooooooooooo`0Eooooo`;o0?oB7Oooool3o`0^o`gooooo0ol02_lA
ooooo`So0>[o1Oooool4o`3o:6oooooo2Ol0o`X<o`3oO@kooooo1ol02_l:oooooaOo0>Co<Oooool0
01[ooooo00?o0000ooooooooool0E_ooool02?l0Vooo0:7oo`3oOOl0FOoo0?ofo`3<ool0ROoo06_o
1?ooool02?l0oe;oooooooooool0oh?oooooo`3od_l0c?oo06_o1?ooool01ol0FOoo0>[ooooooooo
oooo0?o6o`3oSoooool01Ol0ogd00ol0j_oo08Woooooo`03ooooo`05o`3fool0Joooooooo`3oa_l0
FOl00_ooool01ol0C?ooooooooooool0ob;o0?ldo`0@ool0;_l00_ooool02?l0ooKooooooooooooo
oooo0?o`obH0ool0oe;o02So0_ooool00ol0=?ooooooooooo`05ooooo`06oeL0oooooooo0?n3oooo
ool0oo3o05;o0oooool00ol0=?ooooooooooo`07ooooo`;o0<co0_ooool2o`3oc0Kooooo00?o0:ko
ooooool0oc@01_ooool00ol0ogOoooooo`3fo`0;ooooo`03o`1<oolJ0?oooooo00[ooooo00?o08?o
ooooooooool05_ooool00ol0om;oooooooooo`0Gooooo`?o02ko4oooool3o`0:o`Sooooo1_l0j_l0
0ooooooo0?lRo`3o8P02o`3o8P;ooooo0ol0oeT7ooooo`?o0?lXJ_ooool;o`3oO@;ooooo4?l0o`X8
o`0:obSooooo5ol0i?lJooooo`006_ooool00ol0003oooooooooo`1Fooooo`08o`2Kool0XOoo0?mm
o`1Iool0ooKo0<coo`3oPol0Jol4o`3oDP?ooooo00Go0?n3o`3od_l0c?oo06_oo`3omP03ooooo`08
o`29ool0FOooooooooooool0olKo0?n?ooooool0ogd6ooooo`03o`29ool0oggooooo00;ooooo00Go
0?Koo`1[oooooooo0?o6o`1Io`02ooooo`0:o`2^ool0C?ooooooo`3o8_l0ocCo013oooooool0;_oo
ooooo`3omP?ooooo00Co0?o`obH0oooooooo02So0_ooool00ol0=?ooooooooooo`05ooooo`06oeL0
oooooooo0?n3ooooool0oo3o05;o0_ooool00ol0=?ooooooooooo`0:ooooo`05o`3<oooooooooooo
ooooool0ol`01Oooool00ol0[_oo0?ldooooo`05ooooo`03o`3oMooooooo0?Ko00_ooooo00Co04co
oooooooooooo6P3o2_ooool00ol0Poooooooooooo`0Gooooo`;o0?oB5?ooool3o`0^oaWooooo0ol0
2_l5o`3Zo`Cooooo0ol0ob89ooooo`;o0?mI2?ooool3o`3o:5gooooo2_l0ogdFooooo`Oo00[o0_oo
oolAo`3o2SCooooo2ol0i?l?ooooo`006_ooool00ol0003oooooooooo`1Fooooo`09o`2Kool0XOoo
0?mmo`1Iool0ooKo0?o<o`3<ool0ROoo06_o00Cooooo0_l0oh<01?l0om;o06_oo`1[ool0ooH2oooo
o`;o08Wo00Go05Wooooooooooooo0?o6o`3oS`02ooooo`03o`3oOOoooooooooo00Cooooo00?o0>[o
o`29ooooool00oooool04?l0m_oo06_oooooool0olKo05Woooooool0[_oo04coooooool0ob;o0?ld
o`0@oooooooo02koooooool0ooH3ooooo`04o`3ol?lV0?ooooooo`0Xo`;ooooo00?o03Cooooooooo
ool01_ooool00omG0?ooooooo`3ol002ooooo`03o`1Boooooooo03Co00gooooo00Co0<cooooooooo
oooooooo0_l0ol`2ooooo`03o`2^ool0ocCooooo00Kooooo00?o0?mgooooool0m_l02_ooool01Ol0
C?oooooooooooooooooo6P3o00_ooooo00?o08?oooooooooool06?ooool2o`3odPoooooo0ol0;_lI
ooooo`Go0>[o00Coooooo`0:ool02_oo00[o0oooool3o`3o8Pkooooo0ol0oeT8ooooo`?o0?lXD_oo
ool8o`3oOAWooooo1ol02_lJooooo`_o0?l:@oooool001[ooooo00?o0000ooooooooool0E_ooool0
2_l0Vooo0:7oooooool0oggo05Woo`3om_oooooo0<coo`29ool0Jol2ooooo`09o`3oPooooooo0?oB
o`1[ool0c?oo0?o<o`3om_oooooo08Wo00;ooooo00Go05Wooooooooooooo0?o6ooooo`02o`3oO@So
oooo00?o08Woo`3oOOooool00_ooool03_l0m_oo06_oooooool0olKo05Woooooool0[_oo04cooooo
ool0ob;o0?ldo`0@oooooooo02ko0_ooool02?l0ooKooooooooooooooooo9P3oooooool0:?oo0?mB
0_ooool00ol0=?ooooooooooo`05ooooo`08oeL0oooooooo0?o`o`3oPooooooo05;oooooool0=?l>
ooooo`03o`3<oooooooooooo00;ooooo00Co0?o<ooooool0[_oo0?ld1_ooool00ol0ogOoooooo`3f
o`0;ooooo`03o`1<oooooooooooo00;ooooo00?o6P3oooooooooool02Oooool00ol0Pooooooooooo
o`0Iooooo`03o`3od_oooooooooo00Wooooo0ol0;_lGooooo`Go0>[o2?ooool01?l0ob;o00[oo`0:
ool02_lDooooo`;o0?mI2Oooool4o`3o:4Oooooo1ol0ogdKooooo`Ko00[o;?ooool<o`3o2SOooooo
000Jooooo`?o0000Eoooool02Ol0Vooo0:7oo`3oOOl0FOoo0?ofooooool0c?oo08Woo`3odP06o`1[
o`04o`3oc?l0ooKoooooo`29o`;ooooo00Ko05Wooooooooooooo0?o6o`3oSol0ogd3ooooo`Co0?nj
0oooool00ol0j_oo08Woo`3oO@02ooooo`08o`3fool0Joooooooo`3oa_l0FOooooooo`2^ool0C?l2
ooooo`04o`3o8_l0ocCo013oo`0^o`;ooooo00So0?ofooooooooooooooooo`3ol?lV0?oo02Soo`3o
DP;ooooo00?o03Coooooooooool01Oooool01?mG0?ooooooo`3ol?l0oh<2ooooo`03o`0doooooooo
oooo00kooooo0_l0c?l3ooooo`03o`3oc?l0[_oooooo00Kooooo00?o0?mgooooool0m_l02_ooool0
0ol0C?ooooooooooo`04ooooo`03oaX0oooooooooooo00Wooooo0_l0PolJooooo`;o0?oB1_ooool3
o`0^oaKooooo1?l0j_l:ooooo`?o0?lR1?ooool4o`0:oa;ooooo0_l0oeT;ooooo`Co0?lX??ooool7
o`3oOAcooooo1_l02_lnooooo`_o0?l:;?ooool001[ooooo00?o0000ooooooooool0Eoooool02Ol0
Vooo0:7oo`3oOOl0FOooooooo`3om_oooooo0<coo`29o`02o`3odP;ooooo00So0<coo`3oc?l0ooKo
ooooo`3Zool0ROooooooo`1Io`;ooooo00?o0?o6o`3oSol0ogd00_ooool2o`3o^P?ooooo0_l0ol00
3?l0ok[oooooo`3Zool0ROooooooo`3oOOoooooo0?Koo`1[oooooooo0?o6o`1Io`;ooooo00Oo04co
oooooooooooo0?lRo`3o=?l04?oo02ko00;ooooo00So0?ofooooooooooooooooo`3ol?lV0?oooooo
o`0Xo`;ooooo00?o03Coooooooooool01_ooool01_mG0?ooooooooooool0oh?oooooo`0doa;ooooo
00Ko0<cooooooooooooo0:koooooool0ol`5ooooo`03o`3oMooooooo0?Ko00[ooooo00?o04cooooo
ooooool01_ooool00olJ0?ooooooooooo`0:ooooo`03o`23oooooooooooo01Wooooo00?o0?oBoooo
ooooool00ol0;_lFooooo`?o0>[o2oooool3o`3o8P_ooooo1?l02_l@ooooo`?o0?mI3?ooool4o`3o
:3;ooooo1_l0ogdMooooo`Ko00[oCoooool<o`3o2R3ooooo000Jooooo`03o`000?oooooooooo05Oo
oooo00Oo09_oo`2Qool0oggo05Woooooool0ooKo0?o<00;o0<co00_o08Woooooool0c?oo0<cooooo
ool0olco0?ofo`3Zool0ROooooooo`1Io`03ooooo`05o`3oa_oooooo0?mmooooool0okX00oooool3
o`3o`00@ooooool0ol3o0?o0ooooool0ROooooooo`3oOOoooooo0?Koooooool0Joooooooo`3oa_l0
FOooooooo`1<o`;ooooo00Co0?lRo`3o=?l04?oo02ko0oooool02_l0ooKoooooooooool0oo3o9P3o
ooooool0:?oo0?mBooooool0=?l8ooooo`07oeL0ooooooooooooooooool0=?ooooooo`1Bo`0Boooo
o`03o`3<oooooooo0:ko00;ooooo0_l0ol`3ooooo`03o`3oMooooooo0?Ko00Wooooo00?o04cooooo
ooooool02?ooool00olJ0?ooooooooooo`0:ooooo`03o`23oooooooooooo01Wooooo0_l0;_lEoooo
o`Co0>[o2oooool3o`3o8Q;ooooo1Ol02_l>ooooo`;o0?mI3_ooool3o`3o:2Wooooo1_l0ogdJoooo
o`Wo00[oHOooool;o`3o2QGooooo000Jooooo`03o`000?oooooooooo05Sooooo00Oo09_oo`2Qool0
oggo05Woooooool0ooKo0?o<00;ooooo0_l0ROl2o`3Zo`?o08Wo0_ooool01_l0FOooooooooooool0
olKo0?n?o`3oO@;o0?nj0oooool00ol0ol3oooooooooo`03ooooo`05o`3o^_l0ol3o0>[oo`29ool0
ogd00_ooool01ol0m_oo06_oooooool0olKo05Woooooool0C?l00_ooool01?l0ob;o0?ldo`0@ool0
;_l3ooooo`08o`3om_ooooooooooo`3ol?lV0?ooooooo`0Xool0oe82ooooo`03o`0doooooooooooo
00Gooooo00OoE`3oooooooooooooooooo`0dool0oh?o05;o01?ooooo00?o0<coo`2^ooooool00ooo
ool00ol0olcoooooo`3oM`02ooooo`03o`3foooooooooooo00Kooooo00?o04coooooooooool02_oo
ool00olJ0?ooooooooooo`0:ooooo`03o`23oooooooooooo01Kooooo0_l0;_l2ooooo`;o0?oB3ooo
ool4o`3Zo`_ooooo1?l0ob8Jooooo`Ko00[o2_ooool3o`3oF@kooooo1?l0obPOooooo`Ko0?mm5Ooo
ool;o`0:ogGooooo1_l0o`X?ooooo`006_ooool00ol0003oooooooooo`1Hooooo`07o`2Kool0XOoo
0?mmo`3o^_l0FOoo0?ofooooo`04o`3oc0;o08Wo1?ooool01ol0FOoooooooooooooooooo0?o6o`3o
OOl0okX00oooool2o`3o`0Oooooo00ko0?njo`3o`?l0ROooooooo`3oOOoooooo0?Koo`1[oooooooo
0?o6o`1Ioooooooo0:koo`1<o`;ooooo00Co0?ldo`0@oooooooo02ko0_ooool02?l0ooKooooooooo
oooooooo9P3oooooool0:?oo0?mB0_ooool00ol0=?ooooooooooo`04ooooo`05o`3ol?ooooooE`3o
ooooool0=?l00_ooool00ol0oh?o05;oooooo`0@ooooo`04o`3o=?l0[_oo0<coo`3<o`Cooooo0_l0
ol`00ooooooo0?Koooooo`07ooooo`03o`1<oooooooooooo00cooooo00?o6P3oooooooooool02_oo
ool00ol0Poooooooooooo`0Cooooo`;o02ko1_ooool00ol0om;oooooooooo`08ooooo`Co0>[o3?oo
ool3o`3o8RCooooo1_l02_l7ooooo`;o0?mI4?ooool4o`3o:1Cooooo1ol0ogd@ooooo`_o00[oUOoo
ool001[ooooo00?o0000ooooooooool0F?ooool01_l0Vooo0:7oo`3oOOl0ok[o05Woooooo`Ko0?of
1?ooool01ol0FOoooooooooooooooooo0?o6o`3oSol0okX00oooool00ol0ol3oooooooooo`07oooo
o`0>o`3o^_oooooo0>[oo`29ool0oggoooooo`3fool0Joooooooo`3oa_l0FOooooooo`2^ool0C?l2
ooooo`04o`3o8_l04?ooooooo`0^o`;ooooo00Wo0?ofooooooooooooooooo`3ol?lV0?oo02Soo`3o
>_l0oe800_ooool00ol0=?ooooooooooo`03ooooo`04o`3ol?ooooooE`3oo`0do`Cooooo00?o0?n3
o`1Booooool03oooool01Ol0ocCo0:kooooooooooooo0<co00?ooooo00Co0?mgooooool0olco0?Ko
1oooool00ol0C?ooooooooooo`0=ooooo`03oaX0oooooooooooo00_ooooo00?o08?oooooooooool0
4Oooool00ol0;_ooooooooooo`07ooooo`;o0?oB1Oooool3o`3Zo`gooooo0ol0ob8]ooooo`co00[o
4Oooool4o`3o:0Wooooo1ol0ogd9ooooo`ko00[oX?ooool001[ooooo00?o0000ooooooooool0FOoo
ool01Ol0Vooo0:7oo`3o^_oooooo05Wo00?ooooo00?o0?ofooooooooool00oooool01ol0FOoooooo
oooooooooooo0?o6o`3oSol0okX01?ooool00ol0ol3oooooooooo`08ooooo`07o`3o^_l0ol3o08Wo
o`3oOOoooooo0?Koo`1[o`02ooooo`04o`3oa_l0FOoo0:koo`1<o`;ooooo00Co0?lRo`3o=?l04?oo
02ko0oooool02?l0ooKoooooooooool0oo3o9P3oooooool0:?oo0?mB0oooool00ol0=?oooooooooo
o`02ooooo`03o`3ol?ooooooE`3o00Kooooo00?o05;oooooooooool03Oooool00ol0ocCo0:kooooo
o`03ooooo`03o`3<oooooooo0?mg00;ooooo00?o0?Koo`3oc?l0ol`01_ooool00ol0C?oooooooooo
o`0>ooooo`03oaX0oooooooooooo00_ooooo00?o08?oooooooooool03_ooool2o`0^o`cooooo00?o
0?oBooooool0j_l00_l0j_l<ooooo`Co0?lR??ooool^o`0:ogcooooo8ol0okX?ooooo`006_ooool0
0ol0003oooooooooo`1Iooooo`05o`2Kool0XOoo0?mmo`3o^_l0FOl02?ooool00ol0FOoooooooooo
o`02ooooo`03o`3oa_l0ok[ooooo00?ooooo00?o0?o0ooooooooool02Oooool03Ol0ok[oooooo`29
oooooooo0?mmo`3foooooooo06_oooooool0olKo05Woooooool0C?l00_ooool01?l0ob;o0?ldo`0@
ool0;_l3ooooo`08o`3om_oooooooooooooooolV0?ooooooo`0Xool0oe84ooooo`04o`0doooooooo
ooooo`3ol0;ooooo00?o03CooeL0ooooool01Oooool00ol0D_oo0?n3ooooo`0<ooooo`03o`3o=?l0
[_oooooo00Cooooo0_l0c?l2ooooo`04o`3fooooooooooooo`3oc0Cooooo00?o04coooooooooool0
4?ooool00olJ0?ooooooooooo`0;ooooo`03o`23oooooooooooo00_ooooo0_l0;_l>ooooo`;o0>[o
00?o0?oBooooooooool02Oooool3o`3o8T;ooooo0ol0oeT<ooooo`Ko0?mm0oooool5o`3o:7Cooooo
5ol0okXbooooo`006_ooool00ol0003oooooooooo`1Iooooo`06o`2Kool0XOoo0?mmo`3o^_oooooo
05Wo1_ooool00ol0FOooooooooooo`02ooooo`03o`3oa_l0ok[ooooo00?ooooo00?o0?o0oooooooo
ool02?l0Vol3ooooo`0<o`3o^_l0j_oo08Woo`3oOOl0m_ooooooo`1[oooooooo0?o6o`1Ioooooooo
04co0_ooool01?l0ob;o0?ldo`0@ool0;_l3ooooo`09o`3om_oooooooooooooooolV0?ooooooo`0X
ool0oc[o0?mB00?ooooo0_l0=?l01_l0oo3oooooo`0dool0=?oooooooeL0o`Kooooo00?o05;ooooo
ool0oh<02oooool00ol0ocCoooooo`2^o`05ooooo`04o`3oMooooooo0<coo`3fo`Cooooo0_l0ol`0
0ooooooo04coooooo`0Cooooo`03oaX0oooooooooooo00_ooooo00?o08?oooooooooool02?ooool2
o`0^o`kooooo0_l0j_l3ooooo`;o0?oB1_ooool3o`3o8TSooooo0ol0oeT4ooooo`Go0?mm3_ooool4
o`3o:5Wooooo5ol0okY9ooooo`006_ooool00ol0003oooooooooo`1Iooooo`06o`2Kool0ol3o0:7o
o`3oOOl0ok[ooooo0_l0FOl2ooooo`;o05Wo1?ooool00ol0olKo0?njooooo`03ooooo`04o`3o`?oo
ooooooooo`2Ko`Sooooo00[o09_ooooooooooooo0?njo`3o`?l0ROooooooo`3foooooooo06_o0_oo
ool00ol0FOooooooo`1<o`03ooooo`03o`3o8_l04?oo02ko00Cooooo00So0?ofoooooooooooo9P3o
o`3ol?l0:?oo0?ljo`3oDPCooooo1?l0=?l2ooooo`03oeL0oooooooooooo00Gooooo00?o05;ooooo
ool0oh<02Oooool00ol0ocCoooooo`2^o`06ooooo`04o`3oMoooooooooooo`3<o`Kooooo00?o0?o<
o`1<ooooool05?ooool00olJ0?ooooooooooo`0;ooooo`03o`23oooooooooooo00Kooooo00?o02ko
ooooooooool02oooool3o`3Zo`Oooooo00?o0?oBooooooooool00ol0ob9=ooooo`Go0?mm5oooool5
o`3o:4;ooooo4_l0okYPooooo`006_ooool00ol0003oooooooooo`1Jooooo`06o`2Kool0XOoo0?mm
ooooool0ok[ooooo1?l0FOl5ooooo`03o`3oa_oooooooooo00;ooooo00Co0?o0oooooooooooo09_o
2_ooool02Ol0Voooooooooooool0ok[o08Woooooool0oggo0?Koo`1[o`02ooooo`04o`3oa_l0FOoo
0:koo`1<o`;ooooo00Co0?lRo`0@oooooooo02ko0oooool02Ol0ooKooooooooooooooooo9P3oo`0X
oooooooo0?ljo`3oDP03ooooo`03o`3ol?oooooooooo00Cooooo00?oE`3oooooooooool01?ooool0
1?l0D_ooooooooooool0oh<8ooooo`03o`3o=?oooooo0:ko00Gooooo00Ko0?mgoooooooooooooooo
o`3fool0c?l5ooooo`03o`1<ool0olco0?o<01Gooooo00?o6P3oooooooooool02oooool00ol0Pooo
ooooooooo`03ooooo`;o02ko3?ooool2o`3Zo`[ooooo00?o0?lRo`3od_l0om80Boooool5o`3oO@?o
oooo0ol0oeTKooooo`Co0?lX<_ooool<o`3o^Uoooooo1?lJ0?l?ooooo`006_ooool00ol0003ooooo
ooooo`1Jooooo`06o`2Kool0XOoo0?o6o`3oOOoooooo0?nj1oooool00ol0ok[o0?o6ooooo`03oooo
o`04o`3o`?ooooooooooo`2Ko`?ooooo0_l0XOl6ooooo`0?o`2Kooooooooooooo`3o^_l0ROoo0?o0
o`3oOOl0m_ooooooo`1[oooooooo0?o6o`1Iool0[_oo04co00;ooooo00Co0?lRo`0@oooooooo02ko
0oooool02Ol0ooKooooooooooooooooo9P3oooooool0:?oo0?ljo`3oDP02ooooo`03o`3ol?oooooo
oooo00Gooooo00?oE`3oooooooooool01Oooool00ol0D_ooooooooooo`02o`3oP`Gooooo00Co0?ld
oooooooooooo0:ko1Oooool01?l0ogOoooooooooool0m_l2ooooo`;o0<co0_ooool01Ol0C?oooooo
oooooooooooo0?o<01Cooooo00?o6P3oooooooooool03?ooool01Ol0Pooooooooooooooooooo02ko
00cooooo0_l0j_l9ooooo`?o0?lR0oooool2o`3odTCooooo1Ol0ogd;ooooo`;o0?mI7Oooool5o`3o
:1cooooo4Ol0okYTooooo`Oo6P3o4oooool001[ooooo00?o0000ooooooooool0F_ooool01ol0Vooo
0?o0o`2Qoooooooo0?mmooooool0okX01Oooool2o`3oaPCooooo00Co0?o0oooooooooooo09_o1?l0
XOl01?oooooo0:7oo`2Qool0XOl5ooooo`0>o`2Koooooooo0?njo`3Zool0ROooooooo`3foooooooo
06_oooooool0olKo05Woo`2^ool0C?l2ooooo`04o`3o8_l0ocCo013oo`0^o`?ooooo00_o0?ofoooo
ooooooooooooobH0oooooooo02Soo`3ol?oooooo0?mBo`3ol008ooooo`03oeL0oooooooooooo00Ko
oooo00Co05;ooooooooooooooooo0_l0oh<3ooooo`03o`3o=?oooooo0:ko00Gooooo00Go0?mgoooo
ooooooooooooo`3fo`04ooooo`03o`3<oooooooo04co00Cooooo00?o0?o<ooooooooool04_ooool0
0olJ0?ooooooooooo`0<ooooo`03o`23ool0;_oo02ko00_ooooo0_l0j_l9ooooo`;o0?lR2?ooool2
o`3odSkooooo1?l0ogdBooooo`?o0?mI7oooool5o`3o:0Gooooo4_l0okY^ooooo`Oo6P3o2ol0ocX?
ooooo`006_ooool00ol0003oooooooooo`1Kooooo`05o`2Koooooooo0:7oooooool0ogd01Ol0okX0
0ol0olKo0?n?ooooo`03ooooo`05o`3o`?ooooooooooo`2Kool0XOl02?ooool00ol0XOoooooooooo
o`03ooooo`0=o`2Koooooooo0?njo`29ool0ol3o0?Koooooool0Joooooooo`3oMol0FOooooooo`1<
o`03ooooo`03o`3o=?l04?oo02ko00Cooooo00Oo0?ofoooooooooooo9P3oooooool0:?oooooo00;o
0?o`2_ooool00omG0?ooooooooooo`06ooooo`03o`1Boooooooooooo00;ooooo0_l0oh<01?l0ocCo
ooooooooool0[_l5ooooo`04o`3oMoooooooooooo`3fo`Kooooo00?o04coooooooooool01?ooool0
0ol0olcoooooooooo`0Booooo`03oaX0oooooooooooo00_ooooo00?o02koo`23ooooool02Oooool2
o`3Zo`Sooooo0ol0ob8<ooooo`03o`3od_oooooooooo03Oooooo1?l0ogdIooooo`?o0?mI6oooool;
o`3o^Vkooooo2_l0ocX8oaX0o`Go0?lj7?ooool001[ooooo00?o0000ooooooooool0Foooool00ol0
Vooo0?o0o`2Qo`02o`3oaP06o`3oOOooooooooooooooool0olKo0?n?1?ooool01Ol0ol3ooooooooo
ool0Vooo0:7o00[ooooo00?o0:7oooooooooool00_ooool02?l0Voooooooo`3o^_l0ROoo0?o0o`3f
oooooooo06_o0_ooool00ol0FOooooooo`1<o`03ooooo`03o`3o8_l04?oo02ko00Cooooo00Wo0?of
oooooooooooo9P3oooooool0:?ooooooo`3o>_l0oe802_ooool00omG0?ooooooooooo`07ooooo`03
o`1Boooooooooooo00?ooooo0_l0oh<00ooooooo0:koooooo`03ooooo`05o`3oMooooooooooooooo
ool0m_l01Oooool00ol0C?ooooooo`3<o`06ooooo`03o`3oc?oooooooooo01;ooooo00?o6P3ooooo
ooooool02Oooool01?l0;_ooooooooooool0Pol7ooooo`;o0>[o1oooool3o`3o8Q3ooooo0_l0om8c
ooooo`Co0?mm8?ooool3o`3oF@cooooo3?l0okX:ooooo`Go0?lXFOoooolAo`3o>P;ooooo2?lJ0?lY
ooooo`006_ooool00ol0003oooooooooo`1Looooo`03o`2Koooooooo0:7o00Go0?o600?o0?n?oooo
ooooool00_ooool01Ol0ol3oooooooooool0Vooo0:7o00cooooo00?o0:7oooooooooool00_ooool0
1ol0Vooo0?njo`29ool0ol3o0?mmo`3fool0Jol00_ooool01?l0olKo05Woo`2^ool0C?l2ooooo`03
o`3o8_l04?oo02ko00Cooooo00[o0?ofooooooooooooooooobH0ool0:?ooooooo`3o>_oooooo0?mB
2_ooool00omG0?ooooooooooo`07ooooo`05o`1Booooooooooooooooool0oc@00_ooool00ol0[_oo
ooooooooo`03ooooo`04o`3oMoooooooooooo`3fo`Kooooo00Co04cooooooooooooo0<co1_ooool0
0ol0olcoooooooooo`0Booooo`03oaX0oooooooooooo00Kooooo0_l0;_l4ooooo`03o`23oooooooo
oooo00;ooooo0_l0j_l7ooooo`;o0?lR5Oooool2o`3odRgooooo1?l0ogdWooooo`03o`3oFOl0ok[o
0?nj00Wo0?nj6oooool5o`3o:4Wooooo2ol0ocX;ooooo`So6P3o<Oooool001[ooooo00?o0000oooo
ooooool0G?ooool00ol0Vooo0?o0o`2Qo`05o`3oS`Cooooo00Co0?o0ooooool0XOoo09_o3oooool0
4Ol0XOoooooooooooooooooo09_oooooool0ROooooooo`3o`?l0m_ooooooo`1[oooooooo0?o6o`1I
ool0[_oo04co00;ooooo00?o0?lRo`0@ool0;_l01Oooool02Ol0ooKooooooooooolV0?ooooooo`0X
oooooooo0?ljo`3oDP0:ooooo`03oeL0oooooooooooo00Sooooo00?o05;oooooool0oc@00oooool0
0ol0[_oo0?n3o`3oP`02ooooo`05o`3oMoooooooooooooooool0m_l01Oooool01Ol0C?oooooooooo
oooooooo0<co00Oooooo0_l0ol`Cooooo`;o6P3o1Oooool00ol0;_ooooooooooo`05ooooo`04o`23
oooooooo0>[oo`3Zo`Kooooo0ol0ob8Iooooo`;o0?oB9oooool4o`3oOB;ooooo2_l0okX2ooooo`Co
0?mI9Oooool6o`3o:3Oooooo3?l0ocX>ooooo`So6P3o>Oooool001[ooooo00?o0000ooooooooool0
GOooool00ol0Vooo0?o0o`2Qo`07ooooo`04o`3o`?l0XOoo0:7oo`2Koa3ooooo017o0:7ooooooooo
ooooooooo`2Koooooooo0>[oo`29ool0ol3o0?Koooooool0Joooooooo`3oMol0FOoo0:koo`1<o`02
ooooo`04o`3o8_l04?ooooooo`0^o`Cooooo00[o0?ofoooooooooooo9P3oooooool0:?ooooooo`3o
>_oooooo0?mB2_ooool00omG0?ooooooooooo`08ooooo`03o`1Bool0ocCooooo00;ooooo00Ko0:ko
oooooooooooo0?n3ooooool0ogL2ooooo`03o`3foooooooooooo00?ooooo00?o04coooooooooool0
0oooool00ol0c?ooooooooooo`06ooooo`03o`3oc?oooooooooo01;ooooo00?o6P3oooooooooool0
0_l0;_l9ooooo`03o`23oooooooooooo00Cooooo0_l0ob8Nooooo`;o0?oB8Oooool4o`3oOAkooooo
2?l0okX@ooooo`?o0?mI:?ooool6o`3o:2Gooooo3?l0ocXCooooo`Oo6P3o@Oooool001[ooooo0ol0
001Mooooo`03o`2Koooooooo0?o000;o0:7o1?ooool01?l0ol3o0:7oooooool0VolBooooo`0@o`2Q
ooooooooooooooooool0Vooo0?njo`29ool0ol3o0?Koooooool0Joooooooo`3oMol0FOoo0:koo`1<
o`?ooooo00?o0?lRo`0@ool0;_l01?ooool01_l0ooKooooooooooolV0?ooooooo`0Xo`;ooooo00?o
0?ljo`3oD_ooool02Oooool00omG0?ooooooooooo`08ooooo`05o`3o=?l0D_ooooooooooool0[_l0
1?ooool2o`3oP`;ooooo00?o0?Koooooooooool00oooool00ol0C?ooooooooooo`04ooooo`03o`3<
oooooooooooo00Kooooo00?o0?o<ooooooooool04_ooool2oaX0o`Wooooo0_l0j_l01?oooooo08?o
ooooooooool3o`3o8R;ooooo0_l0om8Kooooo`Co0?mm6oooool7o`3o^Q_ooooo0ol0oeT[ooooo`Ko
0?lX4oooool<o`3o>QSooooo1olJ0?m8ooooo`006_ooool00ol0003oooooooooo`1Nooooo`04o`2K
ool0ol3o0?o0ooooo`Go0:7o0_l0VolCooooo`0;o`2Qooooooooooooooooool0Vooo0?njo`29oooo
oooo0?Koooooool0Jol00_ooool00ol0FOoo0?n?o`1<o`03ooooo`03o`3o8_l04?oo02ko00Gooooo
00Go0?ofoooooolV0?ooooooo`0Xo`02ooooo`03o`3o>_oooooo0?mB00[ooooo00?oE`3ooooooooo
ool01oooool01Ol0ocCoooooo`1Boooooooo0:ko00Cooooo00Go0?mgooooool0oh?oooooo`3fo`04
ooooo`03o`1<oooooooooooo00Kooooo00?o0<coooooooooool01_ooool00ol0olcoooooooooo`0A
ooooo`03o`0^oooooooo6P3o00Oooooo00?o0>[oooooooooool00_ooool00ol0Pooo0?lRooooo`0V
ooooo`03o`3od_oooooooooo01Cooooo1?l0ogdGooooo`So0?nj9Oooool3o`3oFBkooooo1Ol0obP3
ooooo`_o0?lj7?ooool8oaX0odoooooo000Jooooo`03o`000?oooooooooo05oooooo00?o09_ooooo
ool0ol000_l0ol02ooooo`03o`2Koooooooooooo01?ooooo017o0:7oooooooooooooooooo`2Koooo
oooo08Woooooool0ol3o0?Koooooool0Joooooooo`3oa_l0FOoo0:koo`1<o`02ooooo`03o`3o8_l0
4?oo02ko00Gooooo00Go0?ofoooooooooooo9P3oo`0Xo`02ooooo`03o`3o>_oooooo0?mB00[ooooo
00?oE`3oooooooooool01_ooool01_l0ocCooooooooooooooooo05;oo`2^o`Cooooo00Go0?mgoooo
oooooooo0?Koo`3oP`03ooooo`03o`1<oooooooooooo00Sooooo00?o0<coooooooooool01_ooool0
0ol0olcoooooooooo`0>ooooo`;o02ko0oooool2oaX0o`Cooooo00?o0>[oooooooooool00ol0ob80
0ooooooo08?oooooo`0Wooooo`;o0?oB4?ooool4o`3oOA?ooooo2?l0okX`ooooo`Co0?mI9_ooool<
o`3o>P;o0?lX7Oooool8oaX0oeOooooo000Jooooo`03o`000?oooooooooo063ooooo1_l0VolGoooo
o`0@o`2Qooooooooooooooooool0Vooo08Woooooool0ol3o0?Koooooool0Joooooooo`3oMol0FOoo
0:koo`1<o`;ooooo00?o0?lRo`0@ool0;_l01Oooool01_l0ooKooooooooooolV0?ooooooo`0Xo`;o
oooo00?o0?ljo`3oD_ooool02_ooool00omG0?ooooooooooo`05ooooo`06o`3o=?oooooooooooooo
ool0[_oo05;o0oooool01ol0ogOooooooooooooooooo0?Koooooool0oh<00_ooool00ol0C?oooooo
ooooo`09ooooo`03o`3<oooooooooooo00Kooooo00?o0?o<ooooooooool03?ooool00ol0;_oooooo
ooooo`05ooooo`;o6P3o0_l0j_l00ooooooo0?lRo`3o8P05ooooo`03o`23oooooooooooo02Oooooo
0_l0om8;ooooo`?o0?mm3oooool8o`3o^Scooooo0ol0oeTHooooo`_o0?lj3_ooool5o`3o:13ooooo
2?lJ0?mOooooo`006_ooool00ol0003oooooooooo`1mooooo`0@o`2Qooooooooooooooooool0Vooo
0>[oo`29ool0ol3o0?Koooooool0Joooooooo`3oMol0FOoo0:koo`1<o`?ooooo00?o013oo`3o=?l0
;_l01?ooool01_l0ooKooooooooooolV0?ooooooo`0Xo`;ooooo00?o0?ljooooool0oe802_ooool0
0omG0?ooooooooooo`04ooooo`03o`3o=?oooooooooo00;ooooo00?o0:koooooool0D_l00_ooool0
1?l0ogOoooooooooool0m_l3ooooo`03o`3oPol0C?oooooo00cooooo00?o0<coooooooooool01_oo
ool00ol0olcoooooooooo`09ooooo`;o02ko2Oooool01?l0j_oo6P3ooaX0ool0ob88ooooo`;o08?o
:Oooool2o`3odPGooooo1?l0ogd<ooooo`Ko0?njAoooool4o`3oF@[ooooo2_l0ocXNooooo`Go0?lX
1?ooool7oaX0ofOooooo000Jooooo`03o`000?oooooooooo07gooooo013o0:7ooooooooooooooooo
o`2Kool0ok[o08Woooooool0m_ooooooo`1[oooooooo0?mgo`1Iool0[_oo04co0oooool00ol0ob;o
013oo`0^o`05ooooo`05o`3om_oooooo9P3oooooool0:?l00oooool00ol0oc[o0?mBooooo`0:oooo
o`03oeL0oooooooooooo00?ooooo00Go0?ldooooooooooooooooo`2^o`03ooooo`03o`1Bool0ogOo
oooo00;ooooo00Oo0?Koooooooooooooooooo`1<oooooooo0?n300gooooo00?o0<coooooooooool0
1_ooool2o`3oc0Sooooo00?o02koooooooooool01oooool2o`3Zo`03o`3o8_oooooooooo00;o6P3o
2Oooool00ol0Poooooooooooo`0Xooooo`;o0?oB0ol0ogd;ooooo`Go0?njDOooool3o`3oF@Oo0?lj
:oooool6oaX0o`03o`3o:?oooooooooo06_ooooo000Jooooo`03o`000?oooooooooo07gooooo00?o
0:7oooooooooool00_ooool01_l0Vooo08Woooooool0m_oo0?mmo`1[o`;ooooo00?o05Woo`2^ool0
C?l00oooool00ol0ob;o013oo`0^o`05ooooo`05o`3om_ooooooooooobH0ool0:?l01?ooool00ol0
oc[o0?mBooooo`0:ooooo`05oeL0ooooooooooooooooool0oc@01?ooool01_l0[_oooooooooooooo
oooo05;oo`3oM`;ooooo00Go0?Koooooooooooooooooo`1<o`03ooooo`;o0?n33?ooool00ol0c?oo
ooooooooo`07ooooo`03o`3oc?oooooooooo00Cooooo00?o02koooooooooool01_ooool00ol0ob;o
0>[oooooo`06ooooo`;o6P3o2?ooool2o`23obGooooo1?l0ogd00ooooooo0?oBo`3odP08ooooo`Co
0?njCoooool8o`3o>P;ooooo0ol0oeTYooooo`Ko6P3o1oooool6o`3o:6Oooooo000Jooooo`03o`00
0?oooooooooo07kooooo013o0:7oooooooooooooooooo`2Kool0ROooooooo`3o`?l0m_ooooooo`1[
oooooooo0?mgo`1Iool0[_oo04co0oooool00ol04?oo02koooooo`04ooooo`06o`3om_oooooooooo
obH0oooooooo02So1?ooool00ol0oe;oooooooooo`0:ooooo`03oeL0oooooooo0?ld00Gooooo00Ko
0:koooooooooooooooooo`3oMol0D_l2ooooo`05o`3fooooooooooooooooool0C?l01Oooool00ol0
oh?oooooooooo`0:ooooo`03o`3<oooooooooooo00Oooooo00Co0?o<oooooooooooooooo0_l0;_l6
ooooo`;o0?lR0_l0j_l:ooooo`;o6P3o2?ooool00ol0Poooooooooooo`0Oooooo`?o0?mm1oooool3
o`3odP03ooooool0ok[o0?nj00;o0?njC?ooool7o`3o>Pgooooo1?l0oeTOooooo`Ko6P3o4oooool7
o`3o:63ooooo000Jooooo`03o`000?oooooooooo07kooooo013o0:7oooooooooooooooooo`2Kool0
j_oo08Woo`3o`?l0m_ooooooo`1[oooooooo0?mgo`1Iool0[_oo04co0oooool00ol04?oo0?ldo`0^
o`05ooooo`05o`3om_oooooo9P3oooooool0:?l01?ooool00ol0oe;o0?ljooooo`0;ooooo`03oeL0
ool0ocCooooo00?ooooo00?o0:koooooooooool00_ooool01Ol0ogOoooooo`1Boooooooo0?Ko00;o
oooo00?o04coooooooooool01Oooool2o`3oP`_ooooo00?o0<coooooooooool01oooool00ol0olco
02koo`0^o`06ooooo`;o0?lR00?oooooo`3Zooooool03Oooool3oaX0o`Kooooo0_l0PolKooooo`Co
0?mm2Oooool4o`3o^P;o0?oBBOooool6o`3o>QSooooo0ol0oeTDooooo`So6P3o8?ooool7o`3o:5Wo
oooo000Jooooo`03o`000?oooooooooo07kooooo00?o0:7oooooooooool00_ooool02ol0Vooo08Wo
ooooool0m_ooooooo`1[oooooooo0?mgo`1Iool0[_oo04co00?ooooo00?o013oo`3o=?l0;_l01Ooo
ool01Ol0ooKoooooobH0oooooooo02So00Gooooo00?o0?mBo`3o>_ooool02_ooool00ol0ocCoE`3o
ooooo`03ooooo`05o`2^ooooooooooooooooool0ogL00oooool01?l0D_ooooooooooool0C?l:oooo
o`03o`3oPooooooooooo00Wooooo00?o0<coooooooooool01Oooool2o`0^o`03o`3oc?oooooooooo
00;ooooo0ol0ob800ooooooo0>[oo`3Zo`0Booooo`?o6P3o1Oooool00ol0Poooooooooooo`0Eoooo
o`?o0?mm2Oooool4o`3o^PKooooo0_l0om92ooooo`Go0?lj8Oooool4o`3oF@Gooooo2olJ0?l_oooo
o`Oo0?lXD_ooool001[ooooo00?o0000ooooooooool0Ooooool03ol0XOoooooooooooooooooo09_o
o`29oooooooo0?Koo`3oOOl0Joooooooo`3oMol0FOoo0:koo`1<o`03ooooo`03o`3o8_l04?oo02ko
00Gooooo00?o0?ofoooooolV0?l00_ooool00ol0:?ooooooooooo`02ooooo`03o`3oD_l0oc[ooooo
00[ooooo00?o0?ldoooooomG0?l00_ooool00ol0[_ooooooooooo`02ooooo`08o`3oMooooooooooo
ooooool0m_oo05;oooooool0C?l;ooooo`;o0?n32_ooool00ol0c?ooooooooooo`02ooooo`;o02ko
0oooool01?l0olcoooooo`3o8_l0ob83ooooo`03o`3Zoooooooooooo01Gooooo0olJ0?l3ooooo`;o
08?o4_ooool3o`3oO@Oooooo1Ol0okX<ooooo`;o0?oB>_ooool6o`3o>RGooooo2_lJ0?m1ooooo`Ko
0?lXC?ooool001[ooooo00?o0000ooooooooool0Ooooool02_l0XOoooooooooooooooooo09_oo`29
oooooooo0?o0o`3fool0Jol2ooooo`03o`3oMol0FOoo04co00Cooooo00?o013oo`0^ooooool01Ooo
ool01Ol0ooKoooooobH0oooooooo02So00Gooooo00?o0?mBo`3o>_l0ocX02?ooool01ol0ocCooooo
ooooooooooooE`3oooooool0[_l00oooool01Ol0ogOooooooooooooooooo0?Ko00;ooooo00?o04co
ooooooooool03?ooool00ol0oh?oooooooooo`08ooooo`04o`3<oooooooo02koo`0^o`Cooooo0_l0
ob82o`3oc0?ooooo00?o0>[oooooooooool06Oooool3oaX0o`;ooooo00?o08?oooooooooool02ooo
ool4o`3oO@Gooooo1Ol0okXCooooo`;o0?oB<Oooool7o`3o>R?ooooo2?lJ0?l9ooooo`Co0?mIA?oo
ool6o`3o:4Kooooo000Jooooo`03o`000?oooooooooo07oooooo013o0:7oooooooooooooooooo`2K
ool0ROooooooo`3o`?l0m_ooooooo`1[oooooooo0?mgo`1Iool0[_oo04co0oooool00ol04?oo02ko
ooooo`05ooooo`05o`3om_oooooo9P3oooooool0:?l01_ooool00ol0oe;oooooo`3o>P07ooooo`03
o`3o=?oooooooooo00;ooooo00?oE`3oo`2^ooooool00_ooool02Ol0ogOooooooooooooooooo0?Ko
ooooool0C?ooooooo`1Bo`0>ooooo`;o0?n32?ooool2o`0^o`?ooooo0ol0ob84ooooo`03o`3oc?l0
j_oo0>[o01oooooo1?lJ0?l00ol0Poooooooooooo`06ooooo`?o0?mm1?ooool5o`3o^Q[ooooo0ol0
om8Vooooo`So0?lj8_ooool8oaX0oaGooooo0ol0oeU7ooooo`Ko0?lX@?ooool001[ooooo00?o0000
ooooooooool0P?ooool03ol0XOoooooooooooooooooo09_oo`29oooooooo0?Koooooool0Jooooooo
o`3oMol0FOoo0:koo`1<o`03ooooo`03o`0@ool0ocCo02ko00Gooooo00Go0?ofoooooolV0?oooooo
o`0Xo`07ooooo`;o0?mB00?o0?ljooooooooool00oooool00ol0ocCoooooooooo`03ooooo`03o`2^
oomG0?oooooo00;ooooo00Co0?mgoooooooooooo0?Ko0_ooool01?l0C?ooooooooooool0D_l?oooo
o`03o`3oPooooooooooo00?ooooo0_l0;_l2ooooo`03o`3<ool0ob;o0?lR00Oooooo00?o0>[ooooo
ool0ol`08oooool5oaX0o`04ooooool0oggo0?mmo`3oO@;ooooo1Ol0okXRooooo`;o0?oB7?ooool8
o`3o>R3ooooo2_lJ0?lPooooo`Co0?mIBOooool7o`3o:3Wooooo000Jooooo`03o`000?oooooooooo
083ooooo00oo0:7oooooooooooooooooo`2Kool0ROooooooo`3fool0oggo06_oooooool0ogOo05Wo
o`2^ool0C?l00oooool00ol04?oo0?ldo`0^o`06ooooo`05o`3om_lV0?ooooooooooool0:?l02?oo
ool01_l0oe;o0?ljo`3o>_l0oc[oooooo`3o=0Kooooo00Go0:kooooooomG0?ooooooo`3oM`03oooo
o`03o`3foooooooo04co00?ooooo00?o05;oooooooooool03_ooool00ol0oh?oooooo`0^o`02o`0^
o`06ooooool0ob;o0?lRo`3o8_oooooo0<co1_ooool2o`3Zo`?ooooo0_l0ol`Sooooo`;o08?o00Co
0?mmoaX0oolJ0?oo6P3o0ol0okXYooooo`;o0?oB4oooool7o`3o>Qcooooo3?lJ0?l^ooooo`Co0?mI
C?ooool8o`3o:37ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002_oo
ool00ol0003oooooooooo`20ooooo`0?o`2Qooooooooooooooooool0Vooo08Woooooool0m_oo0?mm
o`1[oooooooo0?mgo`1Iool0[_oo04co00Cooooo00?o013oo`0^ooooool01Oooool01Ol0ooKooooo
obH0oooooooo02So00Wooooo00?o0?mBooooooooool00ol0ocX4ooooo`06o`2^oooooooooooooooo
oomG0?oo0?mg0oooool00ol0m_oo04coooooo`04ooooo`03o`1Boooooooooooo00cooooo0ol0;_l4
o`3o8PGooooo00?o0<coooooooooool00_ooool00ol0j_ooooooooooo`05ooooo`;o0?o<8?ooool2
o`3oO@03ooooool0Pooo0?nj00;o0?nj1?lJ0?lZooooo`?o0?oB2oooool5o`3o>QOooooo3?lJ0?ln
ooooo`Co0?mID?ooool7o`3o:2[ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo083ooooo013o0:7ooooooooooooooooo
o`2Kool0ROooooooo`3o`?l0m_ooooooo`1[oooooooo0?mgo`1Iool0C?oo0?n?0oooool00ol04?oo
0?ldo`0^o`05ooooo`05o`3om_oooooo9P3oooooool0:?l02_ooool2o`3oDP03o`3o=?oooooooooo
00Co0?lj00Ko0:koo`3o>_l0oc[o0?ljo`3oMomG0?l2o`3o>P04o`3fool0oc[o04coo`3o>PGooooo
00?o05;oooooooooool02?ooool3o`0^o`?o0?lR00?o0?n3ooooooooool01oooool01?l0c?oooooo
ooooool0j_l:ooooo`03o`3oc?oooooooooo01[ooooo0ol0ogd01?oooooo0?njo`3o^_l0okX2o`23
o`Gooooo2_lJ0?lSooooo`?o0?oB0_ooool6o`3o>Q3ooooo3?lJ0?m>ooooo`Go0?mID_ooool8o`3o
:2;ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000009
ooooo`03o`000?oooooooooo087ooooo00Go0:7oooooooooooooooooo`29o`02ooooo`08o`3foooo
oooo06_oooooool0ogOo05Woo`2^ool0C?l3ooooo`03o`0@ool0ocCo02ko00Kooooo00Go0?ofoooo
oolV0?ooooooo`0Xo`0;ooooo`03o`3oD_oooooooooo00Cooooo00[o0:koooooooooooooooooo`3o
MoooooooE`3oooooool0m_oo04co0_ooool6o`3o>P03o`1Boooooooooooo00Cooooo00?o0?lRo`0^
ool0;_l00_l0ob85ooooo`;o0?n32?ooool00ol0c?oo0>[oooooo`0;ooooo`;o0?o<6?ooool2o`3o
O@;ooooo0_l0okX5ooooo`03o`23oooooooooooo00cooooo3OlJ0?lFooooo`?o0?lj0ol0om800ooo
oooo6P3ooaX0o`0BoaX0oeoooooo1Ol0oeUEooooo`Oo0?lX6oooool00005ooooool0003ooooooooo
ool000002?ooool3o`0000[ooooo1?l00020ooooo`0?o`2Qooooooooooooooooool0Vooo08Wooooo
ool0m_oo0?mmo`1[oooooooo0?mgo`1Iool0[_oo04co00?ooooo00?o013oo`3o=?l0;_l01_ooool0
1Ol0ooKoooooobH0oooooooo02So00[ooooo00?o0?ldooooool0oe800_l0oe82ooooo`05o`2^oooo
ooooooooooooool0ogL00oooool00omG0?oo04coooooo`08ooooo`03o`3o>_l0D_oo0?lj00;o0?lR
0ol0;_l;ooooo`03o`3oPooooooooooo00Cooooo00?o0>[oooooool0c?l03_ooool2o`3oc1Cooooo
0_l0ogd01?oooooo0?njo`3o^_l0okX8ooooo`;o08?o6OoooolMoaX0o`;o0?oBM_ooool4o`3oFESo
oooo1ol0obPDooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`21ooooo`0?o`2Qooooooooooooooooool0Vooo08Wooooo
ool0m_oo0?mmo`1[oooooooo0?mgo`1Iool0[_oo04co00?ooooo00Co013oo`3o8_l0ocCo02ko1Ooo
ool01Ol0ooKoooooobH0oooooooo02So00Wooooo00?o0?ldooooooooool00oooool2o`3oDP05o`2^
ooooooooooooooooool0ogL00oooool00ol0m_ooE`3oooooo`08ooooo`;o0?lR0ol0;_l00ol0oc[o
ooooooooo`0<ooooo`03o`3oPooooooooooo00;ooooo00Go0>[oooooooooooooooooo`3<o`0?oooo
o`;o0?o<3oooool3o`3oO@?o0?nj3Oooool00ol0Poooooooooooo`0Mooooo`So0?lj4?ooool3o`3o
dWOooooo1Ol0oeUJooooo`Go0?lX3oooool00005ooooool0003oooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0P_ooool03ol0XOooooooooooool0
Vooo08Woooooool0m_oo0?mmo`1[oooooooo0?mgooooool0FOoo04coo`3oS`03ooooo`03o`0@ool0
ocCo02ko00Kooooo00Go0?ofoooooolV0?ooooooo`0Xo`08ooooo`03o`3o=?oooooooooo00Cooooo
00Go0:koo`3oD_ooooooooooo`3oM`03ooooo`04o`3fool0C?oooooooeL0o`Kooooo0_l0ob82o`0^
o`04ooooool0D_ooooooooooo`?o0?lj3?ooool01?l0oh?oooooo`3Zool0j_l5ooooo`;o0<co3ooo
ool2o`3oc0_ooooo0_l0ogd00ooooooo0?njo`3o^P0Aooooo`;o08?o5_ooool7o`3o>Q_ooooo0ol0
om9iooooo`Co0?mID?ooool;oeL0o`oooooo0002ooooo`;o00002Oooool3o`0000[ooooo00?o0000
ooooooooool0P_ooool01Ol0XOoooooooooooooooooo08Wo00;ooooo00So0?Koo`3oOOl0Jooooooo
o`3oMol0FOoo04coo`3oS`?ooooo00?o013oo`3o8_l0;_l01_ooool01Ol0ooKoooooobH0oooooooo
02So00Oooooo00?o0?ldooooooooool01Oooool01Ol0[_ooooooo`3oD_l0oe;o0?mg00?ooooo00Go
04cooooooooooooooooooeL0o`03ooooo`;o0?lR0_l0;_l4ooooo`03o`1Boooooooooooo00;ooooo
0ol0ocX:ooooo`03o`3Zoooooooooooo00Oooooo00?o0<coooooooooool03_ooool2o`3oc0Kooooo
0ol0ogd3o`3o^QGooooo0ol0Pol;ooooo`So0?lj9Oooool3o`3odW[ooooo1Ol0oeTLooooobooE`3o
6_ooool001[ooooo00?o0000ooooooooool0P_ooool01Ol0XOoooooooooooooooooo08Wo00;ooooo
00So0?Koo`3oOOl0Joooooooo`3oMol0FOoo0:koo`1<o`?ooooo00Co013oooooool0ocCo02ko1_oo
ool01?l0ooKoooooobH0ool0:?l7ooooo`03o`3o=?oooooooooo00Gooooo00Go0:kooooooooooooo
0?mgooooo`03o`3oDP03o`1<oooooooooooo00;ooooo00?oE`3oo`3o8_l0ob800_l0;_l7ooooo`03
o`1Boooooooooooo00Cooooo0ol0ocX6ooooo`04o`3Zoooooooo0?n3o`3oP`Sooooo0_l0c?l@oooo
o`;o0?o<0_ooool2o`3oO@?o0?nj6oooool2o`23o`03ooooool0oc[o0?lj00Ko0?lj<?ooool3o`3o
dVWooooo;omG0?m9ooooo`006_ooool00ol0003oooooooooo`22ooooo`0@o`2Qoooooooooooooooo
ool0Vooo08Woooooool0m_oo0?mmo`1[oooooooo0?mgo`1Iool0[_oo04coo`3oS`;ooooo00Co013o
ooooool0ocCo02ko1_ooool01Ol0ooKoooooobH0oooooooo02So00Gooooo00?o0?ldooooooooool0
1Oooool01Ol0[_oooooooooooooooooo0?mg00?ooooo00?o04coo`3oD_l0oe800_ooool2o`3o8P03
oeL0ool0;_oooooo00Sooooo00?o05;oooooooooool01oooool3o`3o>P03ooooool0j_oo0>[o00Co
oooo0_l0oh<8ooooo`03o`3<oooooooooooo00oooooo0_l0ol`2o`3o^QWooooo1ol0ocX2o`23oc[o
oooo0ol0om9?oooooaOoE`3o6?ooool4o`3oFEcooooo000Jooooo`03o`000?oooooooooo08?ooooo
00oo0:7ooooooooooooo09_oo`29oooooooo0?Koooooool0Joooooooo`3oMooooooo05Woo`1<ool0
ohl00_ooool01?l04?ooooooooooool0;_l6ooooo`05o`3om_ooooooooooobH0ool0:?l01?ooool0
0ol0ocCoooooooooo`06ooooo`04o`2^ooooooooooooo`3oM`?ooooo00Co04coo`3foooooooooooo
0_l0oe82o`0^o`03oooooomG0?oooooo00Wooooo00?o05;oooooooooool02Oooool00ol0j_oo0?lj
o`3o>P06ooooo`;o0?n31oooool2o`3<o`cooooo0ol0ogd2o`3o^P;o0?o<3oooool:o`3o>PWooooo
0ol0Poljooooo`Co0?oB=?oooolGoeL0oc?ooooo1Ol0oeUGooooo`006_ooool00ol0003ooooooooo
o`23ooooo`05o`2Qooooooooooooooooool0ROl00_ooool02?l0m_oo06_ooooooooooooo0?mgo`1I
ool0C?oo0?n?0oooool01?l04?ooooooo`0^ool0oc@6ooooo`05o`3om_oooooo9P3oooooool0:?l0
0oooool00ol0ocCoooooooooo`05ooooo`04o`2^ooooooooooooo`3oM`Cooooo00Co04cooooooooo
oooo0?lR0_l0;_l2o`3oDP;ooooo00?oE`3oooooooooool02?ooool00ol0D_ooooooooooo`07oooo
o`04o`3Zooooooooooooooooo`Co0?lj1?ooool2o`3oP`Oooooo00?o0<coooooooooool01oooool2
o`3oO@?o0?nj1?ooool3o`3oc003ooooool0oc[o0?lj00Wo0?lj5_ooool2o`23occooooo0ol0om8I
oooooaSoE`3oCoooool5o`3oFCOooooo3?l0ohl?ooooo`006_ooool00ol0003oooooooooo`23oooo
o`05o`2Qooooooooooooooooool0ROl00_ooool02Ol0m_oo0?mmo`1[oooooooo0?mgo`1Iool0[_oo
04coo`3oS`02ooooo`05o`0@oooooooo0?lRo`0^ool0oc@01Oooool01Ol0ooKoooooobH0oooooooo
02So00;ooooo00?o0?ldooooooooool01_ooool01?l0[_ooooooooooool0ogL3ooooo`05o`1<ool0
m_ooooooo`3o8_l0;_l01?ooool3o`3oDP03oeL0oooooooooooo00Sooooo00?o05;oooooooooool0
1?ooool2o`3Zo`Sooooo1_l0ocX2o`3oP`Kooooo0_l0c?l5ooooo`;o0?mm0_l0okX2ooooo`So0?lj
0_l0ol`Rooooo`?o08?o??ooool4o`3odPCooooo4OmG0?m/ooooo`Ko0?mI8?oooolAo`3oSa_ooooo
000Jooooo`03o`000?oooooooooo08?ooooo013o0:7oooooooooooooooooo`2Kool0ROooooooo`3f
ool0oggo06_oooooool0ogOo05Woo`2^ool0C?oo0?n?0_ooool01Ol04?ooooooooooool0;_oo0?ld
00Kooooo00Ko0?ofoooooolV0?ooooooo`0Xool0oc@9ooooo`03o`2^oooooooo0?mg00Cooooo00Co
04coo`3o8_l0ob;o02ko2?ooool00ol0oe;oE`3ooeL0o`09ooooo`03o`1Boooooooooooo00;ooooo
00?o0>[oooooooooool03_ooool2o`3o>P03o`3oPol0oc[o0?lj00Go0?lj00?o0<coo`3o>_l0ogd0
0_l0ogd2o`3o^PCo0?lj2_ooool2o`3oc2?ooooo0_l0Polgooooo`_oE`3oF_lV0?lYooooo`Go0?mI
3oooool<o`3oSbcooooo000Jooooo`03o`000?oooooooooo08Cooooo00Go0:7ooooooooooooo09_o
o`29o`02ooooo`08o`3fool0Joooooooo`3oMol0FOoo0:koo`1<ool0ohl2ooooo`06o`0@oooooooo
ooooo`0^oooooooo0?ld1_ooool01?l0ooKo9P3oo`3o=?l0:?l9ooooo`04o`2^ooooooooooooo`3o
M`?ooooo00Co04coo`3foooooooo02ko2oooool00ol0oe;oE`3oooooo`08ooooo`04o`1Boooooooo
ooooo`3ZoaCooooo0_l0oh<5ooooo`03o`3oOOl0c?oo0<co00;o0?nj4_ooool3o`3oc2;ooooo0_l0
PolYooooo`;o9P3o2_mG0?l9obH0o`;ooooo0ol0om9GooooodGo9P3o<?ooool001[ooooo00?o0000
ooooooooool0Q?ooool01Ol0XOoooooooooooooooooo08Wo00;ooooo00So0?Koo`1[oooooooooooo
o`3oMol0FOoo04coo`3oS`?ooooo00Go013ooooooooooooo02koooooo`02o`3o=0Cooooo00Co0?of
o`3o=?lV0?oo02So2Oooool00ol0[_ooooooo`3oM`03ooooo`04o`1<ool0m_ooooooo`0^o`kooooo
00?oE`3oo`3oD_ooool01oooool00ol0D_oo0>[oooooo`0Fooooo`;o0?n300?oooooo`3oOOl0ogd0
0_l0okX00ooooooo0<coo`3<o`0Eooooo`;o0?o<8_ooool3o`23oa[ooooo1_lV0?l8oeL0oaSooooo
1?l0om9^oooooa7o0?n?2?ooool6o`3oF@_ooooo8OlV0?l?ooooo`006_ooool00ol0003ooooooooo
o`24ooooo`05o`2Qooooooooooooooooool0ROl00_ooool02Ol0m_oo06_ooooooooooooo0?mgo`1I
ool0[_oo04coo`3oS`02ooooo`06o`0@ooooooooooooo`3o8_l0;_oooooo1_l0oc@01?l0ooKooooo
obH0ool0:?l7ooooo`04o`2^ooooooooooooo`3oM`;ooooo00Co0?lRo`1<ool0;_oo02ko4?ooool0
0omG0?oo0?mBo`3oDP05ooooo`04o`3Zoooooooo05;oo`1BoaKooooo0_l0ogd00ol0oh?o0?njo`3o
^P05ooooo`;o0<co5Oooool3o`3oc2;ooooo0ol0Pol;ooooo`[o9P3o2?mG0?lTooooo`Go0?oBG_oo
ool;o`3oSaoooooo1_l0oeTeooooo`006_ooool00ol0003oooooooooo`25ooooo`0?o`2Qoooooooo
ooooo`2Kool0ROooooooo`3fool0Jooo0?mmooooool0ogOo05Woo`2^ool0C?oo0?n?00;ooooo00Go
013ooooooooooooo0?lRo`0^o`07ooooo`04o`3om_ooooooooooobH0o`Oooooo00Co0:koooooool0
ogOooooo0_l0ob800ol0C?oo02koooooo`0Booooo`03oeL0oooooooo0?mB00;o0?mB00?oooooo`3Z
ooooool00oooool00ol0D_ooooooooooo`0Aooooo`;o0?mm0ol0okX2ooooo`;o0?n31Oooool2o`3<
oaKooooo0_l0ol`Sooooo`_o9P3o00?ooooooeL0oomG0?l01omG0?laooooo`Go0?oBCoooool:o`3o
Sc3ooooo1ol0oeT^ooooo`006_ooool00ol0003oooooooooo`25ooooo`05o`2Qooooooooooooo`2K
ool0ROl00_ooool02?l0m_oo06_oooooool0ogOo05Woo`2^ool0C?oo0?n?0oooool01Ol04?oooooo
ooooool0ob;o02ko00Oooooo00Co0?ofoooooooooooo9P3o1_ooool01?l0[_ooooooo`3oMol0ob82
ooooo`03o`0^oooooooooooo01?ooooo0_mG0?l01?oooooo0>[oo`3Zool0oe85ooooo`03o`1Boooo
oooooooo00kooooo0_l0ogd2o`3o^POooooo0_l0oh<5ooooo`;o0<co5_ooool2o`3oc1Oooooo2_lV
0?l00oooooooE`3ooeL0o`09oeL0ocoooooo1Ol0om92ooooo`So0?n?@Oooool6o`3oF@gooooo3?l0
ol0?ooooo`006_ooool00ol0003oooooooooo`25ooooo`05o`2Qooooooooooooooooool0ROl00_oo
ool02Ol0m_oo06_ooooooooooooo0?mgo`1Iool0[_oo04coo`3oS`02ooooo`06o`0@oooooooooooo
ooooool0;_oo0?lR1oooool01?l0ooKooooooooooolV0?l4ooooo`04o`2^oooooooo0?mgo`3o8P;o
oooo00?o02koo`3fooooool05_ooool01?mG0?ooooooooooooooool2o`3oDPCooooo00?o05;ooooo
ooooool02_ooool3o`3oO@;o0?nj2oooool3o`3oP`Cooooo0_l0c?lFooooo`?o0?o<3?ooool8obH0
o`03oooooomG0?ooE`3o00SoE`3o1Oooool3o`23o`ooooooB_l0ROlXooooo`So0?n?AOoooolGo`3o
`1_ooooo000Jooooo`03o`000?oooooooooo08Gooooo00Go0:7oooooooooooooooooo`29o`02oooo
o`09o`3fool0Jooo0?mmooooool0ogOo05Woo`2^ool0C?oo0?n?00;ooooo00Oo013ooooooooooooo
ooooo`0^oooooooo0?lR00Oooooo00?o0?ofooooool0:?l00_lV0?l2ooooo`03o`2^ool0ogOooooo
00;ooooo00?o02koo`3fooooool05_ooool01?l0j_oooooooeL0oomG0?l3ooooo`;o0?mB0oooool0
0ol0D_ooooooooooo`06ooooo`?o0?mm0ol0okX@ooooo`Co0?n30_ooool2o`3<oaOooooo0ol0ol`2
ooooo`Oo9P3o00?ooooooeL0oomG0?l01_mG0?lBooooo`Go08?o2_l0ROlmooooo`Go0?oB2?ooool_
o`29ocGooooo4Ol0ol0Aooooo`Oo0?mI6_ooool001[ooooo0ol00026ooooo`0?o`2Qoooooooooooo
o`2Kool0ROooooooo`3fool0Jooo0?mmooooool0ogOo05Woo`2^ool0C?oo0?n?00?ooooo00Ko013o
ooooooooooooooooo`0^ool0ob88ooooo`08o`3om_oooooo02SooooooolV0?oo0:koo`3o8_l0ogL2
ooooo`03o`0^ool0C?oo0?Ko01Gooooo0_l0j_l4ooooo`03oeL0oooooooooooo00;ooooo0_l0oe82
ooooo`;o05;o0oooool3o`3oO@?o0?nj5oooool4o`3oP`?o0<co4oooool6obH0o`03o`3oc?mG0?oo
E`3o00GoE`3o3oooool<o`29o`Cooooo1Ol0Pom7ooooo`Go0?oB5oooool;o`3oSa3ooooo5ol0ROlC
ooooo`_o0?o0:Oooool7o`3oFA?ooooo000Jooooo`03o`000?oooooooooo08Kooooo00Go0:7ooooo
ooooooooooooo`29o`02ooooo`09o`3fool0Joooooooooooool0ogOo05Woo`2^ool0C?oo0?n?00;o
oooo00?o013oooooooooool00_ooool00ol0;_oo0?lRo`3o8P07ooooo`04o`3om_l0:?oooooooooo
o`;o9P3o0_ooool00ol0;_oo04coo`3fo`0Eooooo`03o`3Zoooooooooooo00Gooooo0_mG0?l4oooo
o`;o0?mB0_ooool01?l0D_oo0?mmo`3oOOooool2o`3o^Qkooooo0ol0oh<3o`3<o`_ooooo1OlV0?l7
oeL0o`03ooooool0olco0?o<00;o0?o<1_ooool;o`29oaGooooo1_l0Pom6ooooo`Ko0?oB1oooool:
o`3oSc;oooooAOl0ROl9ooooo`Co0?mI3oooool001[ooooo00?o0000ooooooooool0Q_ooool01Ol0
XOoooooooooooooooooo08Wo00;ooooo00Wo0?Koo`1[ool0oggoooooo`3oMol0FOoo0:koo`1<ool0
ohl00_ooool00ol04?ooooooooooo`03ooooo`03o`0^oooooooo0?lR00Oooooo00Go0?ofo`0Xool0
[_ooooooo`3oM`04obH0o`03o`3foooooooooooo01;ooooo00?o0>[oooooooooool02?ooool2oeL0
o`?ooooo0ol0ogd01?l0oe;o05;oo`3o^_l0okXTooooo`;o0?n30_l0c?l4ooooo`Co9P3o1_mG0?l9
ooooo`Wo08Wo9_ooool6o`23odGooooo00?o0?n?o`3od_l0om800ol0om82o`3oSb_ooooo4_l0ol14
ooooo`go08Wo3oooool001[ooooo00?o0000ooooooooool0Q_ooool02_l0XOoooooooooooooooooo
08Woo`3o^_oooooo0?Koo`1[ool0ogd2ooooo`05o`1Iool0[_oo04coooooool0ohl00_ooool00ol0
4?ooooooooooo`03ooooo`03o`0^oooooooo0?lR00Ko0?lR0_ooool01ol0:?oo0?mgo`0^ool0;_oo
ooooo`1<ool0m_l01?lV0?l@ooooo`03o`3Zoooooooooooo00_ooooo00CoE`3oo`3oOOl0oggooooo
0ol0okX00ol0oe;o05;oo`3oDP0Wooooo`?o9P3o1_mG0?l:ooooo`Go08Wo1oooool4o`3oc2[ooooo
1_l0Polgooooo`So0?n?1_ooool6o`3odQcooooo2ol0ol1booooo`006_ooool00ol0003ooooooooo
o`27ooooo`0@o`2Qooooooooooooo`29ool0Voooooooo`3fool0ol3o06_oo`3oOOoooooo05Wooooo
ool0[_oo04coo`3oS`;ooooo00?o013oooooooooool00oooool00ol0;_ooooooooooo`07ooooo`08
o`2^ool0:?oo02koo`3om_oooooo04coooooool0m_l4ooooo`Go9P3o2Oooool2o`3Zo`_ooooo0ol0
ogd01?ooooooE`3ooeL0oomG0?l5ooooo`04o`1Bool0oe;o0?mBo`3oDQoooooo0_lV0?l6oeL0o`03
ooooool0c?oo0<co00Co0?n31?ooool5o`29oa3ooooo1?l0ol`/ooooo`Go08?o:oooool7o`3oSaCo
oooo1_l0om85oooooa7o0?o0OOooool001[ooooo00?o0000ooooooooool0Qoooool02_l0XOoooooo
oooooooooooo08Woooooool0m_ooooooo`1[ool0ogd2ooooo`04o`1Iool0[_oo04coo`3oS`;ooooo
00?o013oooooooooool01?ooool3o`0^o`Gooooo0_l0;_l01_l0ogOo02Soooooool0C?ooooooo`3f
o`[ooooo2?lV0?l00ol0j_ooooooooooo`08ooooo`?o0?mm0_ooool3o`3o^P;ooooo0omG0?l3oooo
o`;o05;o00Coooooo`3oD_l0oe;o0?mB6?ooool6oeL0o`Wooooo0ol0c?l00ooooooo08Woo`29o`02
o`29o`;o0?n35oooool4o`3oc2gooooo2Ol0PolLooooo`Ko0?n?5?ooool=o`3o`0Oo0?oBIOoooolH
o`23o`oooooo000Jooooo`03o`000?oooooooooo08Oooooo00[o0:7oooooooooooooooooo`29ool0
ok[oooooo`3fool0Jooo0?mm0_ooool01Ol0FOooooooo`2^ool0C?oo0?n?00;ooooo00?o013ooooo
ooooool01_ooool5o`0^o`08o`2^ool0ogOoooooooooool0:?ooooooo`3om_l0m_lAooooo`04o`3Z
oolV0?oo9P3oobH0o`Gooooo0ol0ogd2ooooo`?o0?nj2?ooool2oeL0o`?ooooo00Co05;ooooooooo
oooooooo1?l0oe8=ooooo`OoE`3o3oooool4o`29o`;o0<co1?ooool6o`3oPaGooooo1Ol0ol`aoooo
o`_o08?o2oooool6o`3oS`kooooo3?l0ol0Dooooo`Ko0?oBDoooool<o`23obOooooo000Jooooo`03
o`000?oooooooooo08Sooooo013o0:7ooooooooooooo08Woo`2Koooooooo0?Koo`3o`?l0Jooo0?mm
ooooool0FOooooooo`2^ool0C?oo0?n?0_ooool00ol04?ooooooooooo`0:ooooo`0:o`2^ool0ogOo
ooooooooool0C?ooooooo`0Xool0m_ooooooo`3omPkooooo0_l0j_l4ooooo`?o9P3o0_l0ogd3oooo
o`;o0?nj3Oooool5oeL0o`03o`1Boooooooooooo00?ooooo1?l0oe89oeL0o`?o9P3o3oooool4o`29
o`Kooooo0ol0c?l7ooooo`Ko0?n35?ooool4o`3oc3Sooooo2?l0Pol3o`3oS`Sooooo3?l0ol0Voooo
o`Oo0?oB>_oooolBo`23oc?ooooo000Jooooo`03o`000?oooooooooo08Sooooo00[o0:7ooooooooo
oooo08Woo`2Koooooooo0?Koooooool0Jooo0?mm0_ooool01ol0FOoo0:koo`1<oooooooo0?n?oooo
ool04?l02oooool01Ol0[_ooooooo`3oMooooooo04co00;ooooo00Co0?Koo`0Xoooooooooooo0ol0
ooH:ooooo`03o`3Zoooooooooooo00Cooooo0ol0ogd3obH0o`;o0?nj4oooool;oeL0o`04ooooool0
oe;o0?mBo`3oDPCo9P3o3oooool4o`29o`gooooo0ol0c?l:ooooo`Go0?n34oooool4o`3oc3;ooooo
1ol0ohl3oooooaSo08?o;?ooool8o`3odPWooooo:Ol0Pom5ooooo`006_ooool00ol0003ooooooooo
o`28ooooo`0Ao`2Qooooooooooooooooool0ROoo0?njooooool0m_oo06_oooooool0oggoooooo`1I
ool0ogOo0:koo`1<ool0ohl00_ooool00ol04?ooooooooooo`07ooooo`05o`2^oooooooo0?mgoooo
ool0C?l00oooool01?l0m_ooooooo`0Xool0:?l3ooooo`?o0?of1_ooool00ol0j_ooooooooooo`02
ooooo`?o0?mm0oooool3o`3o^P?o9P3o5Oooool2o`1Bo`Kooooo1?lV0?l2ooooo`co0?mB00?ooooo
o`29ool0ROl00_l0ROlDooooo`Co0<co2oooool6o`3oPa7ooooo1Ol0ol`Uooooo`So0?n?2_l0ol0H
ooooocgo08?oGol0oe8?ooooo`006_ooool00ol0003oooooooooo`28ooooo`0Do`2Qoooooooooooo
ooooool0ROoo09_oooooool0m_oo0?o0o`1[ool0oggoooooo`1Iool0ogOoooooo`2^ool0C?oo0?n?
ooooool04?l8ooooo`05o`2^oooooooo0?mgooooool0C?l00oooool00ol0m_ooooooooooo`02oooo
o`03o`0Xoooooooooooo00?ooooo0_l0ooH3ooooo`04o`3Zooooooooooooooooo`;o0?mm1?ooool2
o`3o^PKooooo0olV0?lDooooo`;o05;o1?lV0?l?ooooo`Co08Wo1ol0oe8Eooooo`Co0<co3Oooool9
o`3oP`gooooo1Ol0ol`Iooooo`Oo0?n?2?l0ol0Xo`3oDSGooooo2?l0om9Xooooo`006_ooool00ol0
003oooooooooo`29ooooo`05o`2Qooooooooooooo`29ool0Vol00_ooool02_l0m_oo06_oooooool0
oggoooooo`1Iool0ogOo0?o6o`2^ool0C?l2ooooo`03o`0@oooooooooooo00Cooooo00Go0:kooooo
ool0ogOoooooo`1<o`04ooooo`03o`3foooooooooooo00?ooooo0_l0:?l5ooooo`04o`3om_l0j_oo
0>[oooooo`?o0?mm1?ooool2o`3o^P_ooooo2?lV0?l4ooooo`[o9P3o0_l0D_l>ooooo`?o08Wo2ooo
oolIo`3oDP?o0<co1?l0oe8?ooooo`_o0?n31ol0oe86o`3oc0_o0?mB1ol0ohl8o`3o`003o`3oD_oo
oooooooo06[ooooo1ol0om9Qooooo`006_ooool00ol0003oooooooooo`29ooooo`0Do`2Qoooooooo
ooooooooool0ROoo0?njooooool0m_oo0?o0o`1[ool0oggoooooo`1Ioooooooo0?mgo`3oa_l0[_oo
04coooooool04?l4ooooo`;o0:ko00Coooooo`3oMol0C?oo04co1?ooool00ol0m_ooooooooooo`06
ooooo`03o`0Xoooooooooooo00;ooooo00?o0>[oooooool0ogd00_l0ooH4ooooo`;o0?nj5Oooool4
obH0o`cooooo0ol0D_l8ooooo`?o08Wo:_ooool4o`3<oaCo0?mB1_ooool<o`3oP`03ooooool0olco
0?o<00Co0?o<0ol0ohl9o`3o`7cooooo1ol0om9Jooooo`006_ooool00ol0003oooooooooo`29oooo
o`06o`2Qooooooooooooooooool0ROoo09_o0_ooool01Ol0m_oo06_oo`3oOOoooooo05Wo00;ooooo
00Ko0?o6ooooool0[_oo04coooooool04?l2ooooo`05o`2^ooooooooooooo`3oMol0C?l01_ooool0
0ol0m_ooooooooooo`07ooooo`;o02So00Coooooo`3Zool0oggo0?mm0oooool2o`3omP;o0?nj:_oo
ool3o`1Bo`;ooooo0ol0ROlaooooo`Co0<co7oooool2o`3oS`So0?o01_l0olb9ooooo`[o0?oBD?oo
ool001[ooooo00?o0000ooooooooool0R_ooool01Ol0XOooooooooooool0ROoo09_o00;ooooo00Ko
0?Koo`1[oooooooo0?mmooooool0FOl2ooooo`07o`3oa_oooooo0?n?o`1<ool04?oo04coo`2^o`02
ooooo`;o04co1_ooool00ol0m_ooooooooooo`09ooooo`03o`3Zool0:?oo02So00Cooooo0ol0okX3
o`3omR_ooooo00Co08Woo`1Bool0D_oo05;o=oooool4o`3<oa?ooooo2_l0ol0=ooooo`03o`3oPol0
olco0?o<00Go0?o<1?l0oh>8ooooo`co0?oBA?ooool001[ooooo00?o0000ooooooooool0R_ooool0
1_l0XOoooooooooooooooooo08Woo`3o^P;ooooo00Go0?Koo`1[ool0oggoooooo`1Io`03ooooo`05
o`3oa_l0ogOo0?n?ooooool04?l00ol0C?l7ooooo`03o`3foooooooooooo00Sooooo00?o0?mmo`3Z
ooooool00_ooool01?l0:?ooooooo`3o^_l0okX6ooooo`;o0?of9_ooool3o`29o`Cooooo0ol0D_lh
ooooo`Co0<co1oooool8o`3o`1oooooo2?l0ol`7o`3oPhWooooo3?l0om8hooooo`006_ooool00ol0
003oooooooooo`2:ooooo`06o`2Qooooooooooooooooool0ROoo09_o0oooool01Ol0Joooooooo`3o
OOoooooo05Wo00;ooooo00Go0?o6ooooool0ogOo0?n?o`0@o`09ooooo`03o`3foooooooooooo00So
oooo00?o0?mmo`3Zooooool00oooool00ol0ok[o02Soo`0Xo`09ooooo`;o0?of8Oooool3o`29o`[o
oooo0ol0D_liooooo`?o0<co1?l0ol0_ooooo`Oo0?o<4Ol0oh>4ooooo`_o0?oB;Oooool001[ooooo
00?o0000ooooooooool0Roooool01Ol0XOoooooooooooooooooo08Wo00?ooooo00Go0?Koo`1[ool0
oggoooooo`1Io`03ooooo`05o`3oa_ooooooooooo`3oSol04?l02?ooool00ol0m_ooooooooooo`06
ooooo`;o0?mm00Co0>[ooooooooooooooooo0_l0okX3ooooo`;o02So2Oooool2o`3omQ_ooooo1?l0
ROl@ooooo`?o05;o;_ooool8o`3o`0?ooooo1Ol0c?leooooo`[o0?o<1ooooolGo`3oPgSooooo4_l0
om8Kooooo`006_ooool3o`0008_ooooo00Ko0:7oooooooooooooooooo`29ool0Vol3ooooo`05o`1[
ool0ol3o0?mmo`3oOOl0FOl00oooool01Ol0olKoooooooooool0ohoo013o00Kooooo00?o0?Kooooo
ooooool01Oooool2o`3oO@;o0>[o0_ooool2o`3o^POooooo00?o02Soooooooooool02?ooool3o`3o
mQ?ooooo1Ol0ROlGooooo`Co05;o8_ooool8o`3o`13ooooo1_l0c?liooooo`_o0?o<4ooooolGo`3o
Pg?ooooo3?l0om8?ooooo`006_ooool00ol0003oooooooooo`2;ooooo`03o`2Qoooooooooooo00;o
oooo00Ko08Woo`3o^_ooooooooooo`3fool0Jol2ooooo`03o`1Ioooooooooooo00;ooooo00Go0?o6
oooooooooooo0?n?o`0@o`03ooooo`;o0?Ko1oooool00ol0oggoooooo`3Zo`02ooooo`;o0?nj2_oo
ool2o`0Xo`_ooooo0_l0ooH=ooooo`Co08Wo8?ooool6o`1BoaCooooo2?l0ol0Nooooo`Wo0<co>ooo
ool<o`3oc1kooooo5ol0oh=gooooo`006_ooool00ol0003oooooooooo`2<ooooo`06o`2Qoooooooo
ooooooooool0ROoo09_o0oooool01_l0Jooo0?Kooooooooooooo05Woo`3oO@;ooooo00So0?o6oooo
ooooooooooooo`0@ool0ohooooooo`3fo`Oooooo0_l0ogd01Ooooooo0>[ooooooooooooo0?nj00ko
oooo0_l0:?l;ooooo`;o0?of1oooool4o`29ob[ooooo1_l0D_l4ooooo`[o0?o000?o0?n?oooooooo
ool0;?ooool00ol0c?oo0:7oo`2Qo`3Qo`2Qo`oooooo000Jooooo`03o`000?oooooooooo08cooooo
00?o0:7oooooooooool00_ooool00ol0ROoo0?njooooo`02ooooo`06o`1[ool0m_ooooooo`1Ioooo
oooo0?mm0_ooool2o`3oaP;ooooo00Co013oo`3fool0ohoo0?n?1?ooool2o`3oO@;ooooo00Co0>[o
ooooool0ok[o0?nj4Oooool2o`0Xo`_ooooo00?o0?ofo`29ool0ROl01?l0ROl]ooooo`Oo0?o01_l0
D_l00ol0ohooooooooooo`0PoooooaGo0:7o2oooool<o`3<oc[ooooo3?l0ola=oooooaOo0?n3<Ooo
ool001[ooooo00?o0000ooooooooool0SOooool00ol0XOooooooooooo`02ooooo`0:o`29ool0ok[o
ooooooooool0Joooooooo`3foooooooo05Woooooo`;o0?mm0_ooool00ol0olKo0?Koo`0@o`03oooo
o`04o`3oSol0oggo0?mmo`3oO@?ooooo00?o0>[oo`3o^_l0okX05Oooool2o`0Xo`Cooooo1_l0ROl2
ooooo`?o0?of9?ooool:o`3o`0Ko0?n?1oooool5o`1Bo`Kooooo6?l0XOl/ooooo`_o0<co>oooool;
o`3oc5Wooooo8_l0oh<?ooooo`006_ooool00ol0003oooooooooo`2>ooooo`07o`2Qoooooooooooo
ooooool0Vooo08Woo`3o^P02ooooo`07o`1[oooooooo0?Koo`3fool0FOooooooo`3oO@03o`3fo`;o
0?o600Co013oo`3oOOl0oggo0?mm1?l0ohl2o`3Zo`03o`3o^_oooooooooo00Cooooo3ol0ohl2oooo
o`;o08Wo0_l0:?l2o`29o`_ooooo0ol0ooHIooooo`So0?o02?l0ohl>ooooo`Ko0:7o2Ol0D_m<oooo
o`co0<co>_oooolBo`3oc7Sooooo000Jooooo`03o`000?oooooooooo08kooooo00?o0:7ooooooooo
ool00_ooool00ol0ROooooooo`3o^P02ooooo`06o`1[ool0ol3oooooooooool0FOoo0?Ko1Oooool0
0ol0olKo013oooooo`03ooooo`;o0>[o00?o0?njooooooooool01_l0ohl8ooooo`Wo08Wo1?l0ohl2
o`0Xo`;o0?n?3?ooool3o`3omPoooooo1ol0ol06o`3oS`gooooo2ol0XOl?ooooo`_o05;oCOooool<
o`3<od3ooooo6?l0ol`^ooooob?o05;o3oooool001[ooooo00?o0000ooooooooool0Soooool02?l0
XOoooooooooooooooooo09_oo`29ool0j_oo0?nj0_ooool01?l0Jooo0?o0ooooool0FOl7ooooo`03
o`3oa_l04?oo0?o600;o0>[o00?o0?njooooooooool02_ooool6o`29o`oooooo0_l0:?l?o`3oS`Co
0?of1?l0ohl7o`3o`0Co0?n?3Oooool9o`2QobGooooo3?l0D_m=oooooa;o0<coA_oooolGo`3oc1Oo
05;o6?l0olHJooooo`006_ooool00ol0003oooooooooo`2?ooooo`03o`2Qoooooooooooo00;ooooo
0_l0ROl01Ol0j_oo0?njo`3o^_oooooo06_o00;o0?o000?o05Woooooooooool01Oooool00ol0j_oo
013oo`0@o`02o`3oaPWooooo0ol0ROl7ooooo`oo0?o000Coooooo`0Xool0:?oo02So2?ooool8o`3o
`0Go0?of4Oooool6o`2Qoc[ooooo5_l0D_m9oooooaSo0<co5oooool^o`1BoaOo0?o<<_ooool001[o
oooo00?o0000ooooooooool0T?ooool02ol0XOoooooooooooooooooo09_oooooool0ROoo0>[ooooo
ool0ok[ooooo00;o06_o00?o0?o0o`1Iooooool01?ooool01_l0j_oo0?njoooooooooooo013ooooo
o`Ko0?o60ol0ROl00ooooooo0?o0o`3o`007o`3o`0oooooo1?l0ol03o`0Xo`Go0?o03Oooool;o`3o
mPKo0:7oE_oooomho`1Bob_o0<co?Ol0:?l?ooooo`006_ooool00ol0003oooooooooo`2Aooooo`07
o`2Qooooooooooooooooool0Vooo08Woooooo`02o`3Zo`?o0?nj00Go06_oo`3o^_l0FOoo05Woo`3o
`002o`3Zo`Gooooo0_l04?l00ooooooo0?o0o`29o`02o`29o`co0?o65oooool7o`0Xoa3ooooo1_l0
XOl00ooooooo0?ofo`3omP07o`3omXGooooo6?l0olHYoooooboo02So0oooooljo`3<o`oooooo000J
ooooo`03o`000?oooooooooo09;ooooo00Go0:7oooooooooooooooooo`2Ko`02o`29o`03ooooool0
j_oo0>[o00;o0>[o00Co06_oo`3Zool0j_oo05Wo2Ol0ol02o`0@o`oooooo1_l0olHHooooo`;o02So
2?ooool6o`2Qoa3ooooo6?l0ooIFoooooaCo0?o6A?l0:?mkooooo`006_ooool00ol0003ooooooooo
o`2Cooooo`03o`2Qoooooooooooo00;ooooo00?o09_oo`29ool0ROl01?ooool2o`1[o`03ooooool0
FOoo05Wo00Cooooo0ol0ROl2ooooo`03o`0@oooooooooooo01;ooooo1_l0olHBooooo`;o0:7o3?l0
:?lZooooo`_o0?of5oooool2o`1[odKo02So/?l0Jol?ooooo`006_ooool00ol0003oooooooooo`2D
ooooo`;o0:7o0_ooool00ol0Voooooooooooo`04o`29o`;ooooo0ol0Jol01?l0FOoo08Woo`29ool0
ROl6ooooo`?o013o0_oooolWo`2Qo`koooooC_l0:?lJo`3om^_ooooo000Jooooo`03o`000?oooooo
oooo09Kooooo00?o0:7oooooooooool00_l0Vol3ooooo`Co08Wo0_ooool01Ol0Jooo05Woo`1Iool0
FOoo06_o00Gooooo0ol0XOl4o`0@oaWooooo2ol0olHQooooo`_o0?o62ol0JolCo`3oaRgooooog?l0
ooH?ooooo`006_ooool00ol0003oooooooooo`2Gooooo`;o0:7o0_ooool3o`2Ko`[ooooo0ol0FOl:
o`1[o`Co013o2Ol0JolGoooooaGo0?o65ol0JoooooooocOooooo000Jooooo`03o`000?oooooooooo
09Wooooo00?o0:7oooooooooool00_ooool00ol0Voooooooooooo`04ooooo`Co0:7o0_ooool3o`1I
o`_ooooo0ol04?l6ooooo`So06_o6oooool9o`1[oooooooo1?oooolko`2Ko`oooooo000Jooooo`03
o`000?oooooooooo09[ooooo1Ol0XOl4o`2Ko`;o0:7o2Oooool7o`1Io`Oooooo1?l04?l:oooooa_o
06_oZ_oooonMo`0@o`oooooo000Jooooo`?o0000X_oooolCo`2Ko`So05Wo0oooool6o`0@oe[ooooo
Kol04?l6o`2KojKooooo000Jooooo`03o`000?oooooooooo0;cooooo00?o09_oo`1Iool0FOl00ol0
FOl4o`2Ko`Ko013o:_oooolZo`0@oaOo09_oooooool5ooooo`006_ooool00ol0003oooooooooo`32
ooooo`Ko05Wo1?l0VolZo`0@o`ko09_oIoooooo1o`1Io`oooooo000Jooooo`03o`000?oooooooooo
0<Sooooo2ol0FOl2ooooo`go09_o3?oooommo`1Iom3ooooo000Jooooo`03o`000?oooooooooo0=?o
oooo6ol0FOooooooodkooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_oo
ool00ol0003oooooooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0oooooooo
ooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_ooool00ol0003o
ooooooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo
000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3o
oooooooooooo?Oooool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {369.812, 0}} -> {-23.4649, -0.0454358, \
0.896058, 0.00278266}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 600 370.82 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.0147149 0.0917192 [
[.21429 .00221 -9 -9 ]
[.21429 .00221 9 0 ]
[.40476 .00221 -9 -9 ]
[.40476 .00221 9 0 ]
[.59524 .00221 -9 -9 ]
[.59524 .00221 9 0 ]
[.78571 .00221 -9 -9 ]
[.78571 .00221 9 0 ]
[.97619 .00221 -9 -9 ]
[.97619 .00221 9 0 ]
[.01131 .10643 -6 -4.5 ]
[.01131 .10643 0 4.5 ]
[.01131 .19815 -6 -4.5 ]
[.01131 .19815 0 4.5 ]
[.01131 .28987 -6 -4.5 ]
[.01131 .28987 0 4.5 ]
[.01131 .38159 -6 -4.5 ]
[.01131 .38159 0 4.5 ]
[.01131 .47331 -6 -4.5 ]
[.01131 .47331 0 4.5 ]
[.01131 .56503 -6 -4.5 ]
[.01131 .56503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01471 m
.21429 .02096 L
s
[(100)] .21429 .00221 0 1 Mshowa
.40476 .01471 m
.40476 .02096 L
s
[(200)] .40476 .00221 0 1 Mshowa
.59524 .01471 m
.59524 .02096 L
s
[(300)] .59524 .00221 0 1 Mshowa
.78571 .01471 m
.78571 .02096 L
s
[(400)] .78571 .00221 0 1 Mshowa
.97619 .01471 m
.97619 .02096 L
s
[(500)] .97619 .00221 0 1 Mshowa
.125 Mabswid
.0619 .01471 m
.0619 .01846 L
s
.1 .01471 m
.1 .01846 L
s
.1381 .01471 m
.1381 .01846 L
s
.17619 .01471 m
.17619 .01846 L
s
.25238 .01471 m
.25238 .01846 L
s
.29048 .01471 m
.29048 .01846 L
s
.32857 .01471 m
.32857 .01846 L
s
.36667 .01471 m
.36667 .01846 L
s
.44286 .01471 m
.44286 .01846 L
s
.48095 .01471 m
.48095 .01846 L
s
.51905 .01471 m
.51905 .01846 L
s
.55714 .01471 m
.55714 .01846 L
s
.63333 .01471 m
.63333 .01846 L
s
.67143 .01471 m
.67143 .01846 L
s
.70952 .01471 m
.70952 .01846 L
s
.74762 .01471 m
.74762 .01846 L
s
.82381 .01471 m
.82381 .01846 L
s
.8619 .01471 m
.8619 .01846 L
s
.9 .01471 m
.9 .01846 L
s
.9381 .01471 m
.9381 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .10643 m
.03006 .10643 L
s
[(1)] .01131 .10643 1 0 Mshowa
.02381 .19815 m
.03006 .19815 L
s
[(2)] .01131 .19815 1 0 Mshowa
.02381 .28987 m
.03006 .28987 L
s
[(3)] .01131 .28987 1 0 Mshowa
.02381 .38159 m
.03006 .38159 L
s
[(4)] .01131 .38159 1 0 Mshowa
.02381 .47331 m
.03006 .47331 L
s
[(5)] .01131 .47331 1 0 Mshowa
.02381 .56503 m
.03006 .56503 L
s
[(6)] .01131 .56503 1 0 Mshowa
.125 Mabswid
.02381 .03306 m
.02756 .03306 L
s
.02381 .0514 m
.02756 .0514 L
s
.02381 .06975 m
.02756 .06975 L
s
.02381 .08809 m
.02756 .08809 L
s
.02381 .12478 m
.02756 .12478 L
s
.02381 .14312 m
.02756 .14312 L
s
.02381 .16147 m
.02756 .16147 L
s
.02381 .17981 m
.02756 .17981 L
s
.02381 .2165 m
.02756 .2165 L
s
.02381 .23484 m
.02756 .23484 L
s
.02381 .25318 m
.02756 .25318 L
s
.02381 .27153 m
.02756 .27153 L
s
.02381 .30822 m
.02756 .30822 L
s
.02381 .32656 m
.02756 .32656 L
s
.02381 .3449 m
.02756 .3449 L
s
.02381 .36325 m
.02756 .36325 L
s
.02381 .39994 m
.02756 .39994 L
s
.02381 .41828 m
.02756 .41828 L
s
.02381 .43662 m
.02756 .43662 L
s
.02381 .45497 m
.02756 .45497 L
s
.02381 .49165 m
.02756 .49165 L
s
.02381 .51 m
.02756 .51 L
s
.02381 .52834 m
.02756 .52834 L
s
.02381 .54669 m
.02756 .54669 L
s
.02381 .58337 m
.02756 .58337 L
s
.02381 .60172 m
.02756 .60172 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04016 L
.03652 .04108 L
.0379 .04192 L
.04033 .04308 L
.04262 .0439 L
.04761 .04515 L
.05217 .04599 L
.06244 .04754 L
.08259 .05087 L
.09399 .05331 L
.10458 .05614 L
.11466 .05957 L
.1238 .06362 L
.12887 .06642 L
.13435 .07005 L
.13949 .07423 L
.14429 .07901 L
.15379 .09194 L
.15925 .10165 L
.16423 .11082 L
.16673 .11466 L
.16814 .11633 L
.16945 .11745 L
.17059 .11804 L
.17185 .11825 L
.17316 .11796 L
.17439 .11722 L
.17503 .11666 L
.17573 .11594 L
.17713 .11412 L
.17964 .10994 L
.18529 .09836 L
.19013 .0886 L
.19538 .0797 L
.20033 .07321 L
.2049 .06875 L
.21023 .06508 L
.21292 .06374 L
.21588 .06259 L
.21836 .06185 L
.22103 .06125 L
.22232 .06103 L
.22355 .06085 L
Mistroke
.22475 .06071 L
.22585 .0606 L
.2271 .06051 L
.22776 .06048 L
.22845 .06044 L
.22962 .06041 L
.2309 .06039 L
.23204 .0604 L
.23326 .06042 L
.23441 .06046 L
.23546 .0605 L
.23798 .06066 L
.24072 .06089 L
.2457 .0614 L
.25034 .0619 L
.25288 .06214 L
.25412 .06223 L
.25526 .0623 L
.25625 .06235 L
.25729 .06238 L
.25833 .0624 L
.25946 .0624 L
.26063 .06237 L
.26187 .06231 L
.26304 .06222 L
.2641 .06213 L
.26642 .06185 L
.26896 .06145 L
.27411 .06044 L
.28332 .05847 L
.28851 .05751 L
.29408 .05665 L
.29895 .05606 L
.30413 .05556 L
.30941 .05518 L
.31429 .05492 L
.31954 .05472 L
.32254 .05463 L
.32535 .05457 L
.3278 .05452 L
.33039 .05449 L
.3326 .05446 L
.33502 .05444 L
.33639 .05443 L
.33763 .05443 L
.33832 .05443 L
.33907 .05442 L
.33972 .05442 L
.34043 .05442 L
.3417 .05442 L
Mistroke
.34239 .05442 L
.34305 .05442 L
.34421 .05442 L
.34546 .05442 L
.35501 .05445 L
.36025 .05446 L
.36282 .05447 L
.36519 .05448 L
.36653 .05448 L
.368 .05448 L
.36948 .05448 L
.37029 .05449 L
.37104 .05449 L
.37173 .05449 L
.37238 .05449 L
.3736 .05449 L
.37492 .05449 L
.37566 .05449 L
.37635 .05449 L
.37758 .05448 L
.37874 .05448 L
.38137 .05448 L
.38394 .05447 L
.38671 .05446 L
.40568 .05437 L
.41644 .05432 L
.42168 .0543 L
.42643 .05429 L
.43142 .05428 L
.43613 .05427 L
.43872 .05426 L
.4411 .05426 L
.44372 .05426 L
.44504 .05426 L
.44649 .05426 L
.4479 .05426 L
.44859 .05426 L
.44924 .05426 L
.45044 .05426 L
.45175 .05426 L
.45249 .05426 L
.45318 .05426 L
.45448 .05426 L
.45521 .05426 L
.45588 .05426 L
.4574 .05426 L
.45976 .05426 L
.46236 .05426 L
.46759 .05426 L
.47241 .05426 L
Mistroke
.47765 .05426 L
.48005 .05427 L
.48259 .05427 L
.48476 .05427 L
.48599 .05427 L
.48716 .05427 L
.48784 .05427 L
.48858 .05427 L
.48988 .05427 L
.49062 .05427 L
.4914 .05427 L
.49214 .05427 L
.49281 .05427 L
.49412 .05427 L
.49486 .05427 L
.49554 .05427 L
.49679 .05427 L
.49812 .05427 L
.50057 .05427 L
.50287 .05427 L
.50809 .05426 L
.51853 .05426 L
.52843 .05425 L
.54699 .05424 L
.5853 .05423 L
.62607 .05421 L
.66533 .05419 L
.70307 .05417 L
.74326 .05415 L
.78193 .05413 L
.82306 .05411 L
.86267 .05409 L
.90077 .05407 L
.94132 .05405 L
.97619 .05403 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04396 L
.04761 .04524 L
.05217 .04608 L
.06244 .04765 L
.08259 .05104 L
.09399 .05351 L
.10458 .05638 L
.11466 .05988 L
.1238 .06402 L
.12887 .06688 L
.13435 .07063 L
.13949 .07495 L
.14429 .07992 L
.15379 .09353 L
.15925 .10394 L
.16423 .11393 L
.16673 .11817 L
.16814 .12004 L
.16945 .1213 L
.17059 .122 L
.17185 .12229 L
.17316 .12203 L
.17439 .12128 L
.17503 .12071 L
.17573 .11996 L
.17713 .11806 L
.17964 .11366 L
.18529 .10146 L
.19013 .09117 L
.19538 .08178 L
.20033 .07492 L
.2049 .07019 L
.21023 .06628 L
.21292 .06484 L
.21588 .0636 L
.21836 .0628 L
.22103 .06215 L
.22232 .0619 L
.22355 .0617 L
Mistroke
.22585 .06142 L
.2271 .06131 L
.22776 .06127 L
.22845 .06123 L
.22973 .06118 L
.2309 .06115 L
.23202 .06115 L
.23308 .06116 L
.23423 .06119 L
.23546 .06124 L
.23678 .0613 L
.23822 .0614 L
.24082 .06161 L
.2457 .06212 L
.25034 .06264 L
.25288 .06289 L
.25412 .06299 L
.25526 .06306 L
.25625 .06312 L
.25729 .06316 L
.25833 .06318 L
.25946 .06318 L
.26063 .06316 L
.26187 .0631 L
.26304 .06303 L
.2641 .06293 L
.26642 .06266 L
.26896 .06227 L
.27411 .06127 L
.28332 .05927 L
.28851 .05827 L
.29408 .05738 L
.29895 .05675 L
.30413 .05623 L
.30941 .05582 L
.31429 .05554 L
.31954 .05532 L
.32254 .05522 L
.32535 .05515 L
.3278 .0551 L
.33039 .05506 L
.3326 .05503 L
.33502 .055 L
.33763 .05498 L
.3391 .05497 L
.34043 .05497 L
.34167 .05496 L
.34232 .05496 L
.34302 .05496 L
.34429 .05496 L
Mistroke
.34546 .05496 L
.34667 .05495 L
.34798 .05495 L
.34923 .05496 L
.35038 .05496 L
.35152 .05496 L
.35256 .05496 L
.35488 .05496 L
.35975 .05497 L
.36108 .05497 L
.36249 .05497 L
.36369 .05497 L
.36501 .05497 L
.36624 .05497 L
.36736 .05497 L
.36866 .05497 L
.36989 .05497 L
.37102 .05497 L
.37207 .05497 L
.37444 .05497 L
.37649 .05496 L
.37874 .05496 L
.38332 .05494 L
.39342 .05489 L
.40268 .05484 L
.41349 .05478 L
.42354 .05474 L
.4327 .05471 L
.43782 .0547 L
.44248 .05469 L
.44759 .05468 L
.45047 .05468 L
.45313 .05468 L
.45801 .05468 L
.46048 .05468 L
.46318 .05468 L
.47317 .05467 L
.48265 .05467 L
.48787 .05467 L
.49357 .05466 L
.50354 .05466 L
.54426 .05462 L
.58346 .05458 L
.62512 .05455 L
.66526 .05452 L
.70388 .05449 L
.74495 .05446 L
.78451 .05444 L
.82256 .05442 L
.86305 .05439 L
Mistroke
.90203 .05437 L
.94347 .05435 L
.97619 .05434 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03777 L
.03527 .0402 L
.03652 .04112 L
.0379 .04197 L
.04033 .04315 L
.04262 .04397 L
.04761 .04525 L
.05217 .04609 L
.06244 .04766 L
.08259 .05104 L
.09399 .0535 L
.10458 .05637 L
.11466 .05985 L
.1238 .06397 L
.12887 .06681 L
.13435 .07053 L
.13949 .0748 L
.14429 .07971 L
.15379 .09309 L
.15925 .10328 L
.16423 .1131 L
.16673 .11733 L
.16814 .11922 L
.16945 .12055 L
.17059 .12131 L
.17185 .12169 L
.17316 .12154 L
.17439 .12091 L
.17503 .1204 L
.17573 .11971 L
.17713 .11793 L
.17964 .1137 L
.18529 .10162 L
.19013 .09122 L
.19538 .08166 L
.20033 .07466 L
.2049 .06984 L
.21023 .06587 L
.21292 .06442 L
.21588 .06318 L
.21836 .06238 L
.22103 .06173 L
.22232 .06149 L
.22355 .06129 L
Mistroke
.22475 .06113 L
.22585 .06102 L
.2271 .06091 L
.22775 .06087 L
.22845 .06083 L
.22964 .06078 L
.2309 .06076 L
.23204 .06076 L
.23326 .06077 L
.23441 .06081 L
.23546 .06085 L
.23677 .06092 L
.23798 .061 L
.24072 .06122 L
.2457 .06172 L
.25031 .06221 L
.25256 .06241 L
.25463 .06255 L
.25568 .06261 L
.2568 .06264 L
.25791 .06266 L
.25913 .06265 L
.26038 .06262 L
.26107 .06258 L
.26171 .06255 L
.26294 .06245 L
.2641 .06233 L
.2665 .06202 L
.26874 .06165 L
.27385 .06062 L
.28415 .05843 L
.29306 .05694 L
.29806 .05632 L
.30262 .05587 L
.30741 .0555 L
.31251 .0552 L
.31687 .055 L
.32168 .05484 L
.32436 .05477 L
.32682 .05471 L
.32953 .05467 L
.33238 .05463 L
.33486 .05461 L
.33718 .0546 L
.33851 .05459 L
.33971 .05459 L
.34038 .05458 L
.34111 .05458 L
.34243 .05458 L
.34366 .05458 L
Mistroke
.34478 .05458 L
.34608 .05458 L
.34731 .05458 L
.34844 .05458 L
.34949 .05459 L
.35188 .05459 L
.35734 .05461 L
.36228 .05463 L
.3648 .05464 L
.36753 .05464 L
.36878 .05464 L
.3701 .05465 L
.37123 .05465 L
.37246 .05465 L
.37319 .05465 L
.37388 .05465 L
.37517 .05465 L
.3759 .05465 L
.37657 .05465 L
.3773 .05465 L
.37808 .05465 L
.37936 .05465 L
.38057 .05465 L
.38332 .05464 L
.38575 .05463 L
.38802 .05463 L
.39316 .05461 L
.40351 .05456 L
.4124 .05452 L
.42202 .05449 L
.4275 .05447 L
.42991 .05447 L
.43256 .05446 L
.43489 .05446 L
.43739 .05446 L
.43877 .05446 L
.44003 .05446 L
.44129 .05446 L
.4425 .05446 L
.44367 .05446 L
.44473 .05446 L
.44596 .05446 L
.44711 .05446 L
.44819 .05446 L
.44917 .05446 L
.45025 .05446 L
.45139 .05446 L
.45379 .05446 L
.45602 .05446 L
.46109 .05446 L
Mistroke
.47978 .05448 L
.4849 .05448 L
.49033 .05449 L
.49496 .05449 L
.4976 .05449 L
.50007 .05449 L
.50138 .05449 L
.50281 .05449 L
.50408 .05449 L
.50542 .05449 L
.50676 .05449 L
.50797 .05449 L
.50918 .05449 L
.51033 .05449 L
.51097 .05449 L
.51167 .05449 L
.5124 .05449 L
.51309 .05449 L
.51431 .05449 L
.51563 .05449 L
.51717 .05449 L
.51863 .05449 L
.52136 .05449 L
.53101 .05449 L
.5415 .05449 L
.5517 .05449 L
.56127 .05449 L
.57125 .05448 L
.58227 .05448 L
.5921 .05448 L
.60244 .05448 L
.61128 .05448 L
.62095 .05448 L
.6615 .05447 L
.70053 .05445 L
.74201 .05444 L
.78198 .05442 L
.82044 .0544 L
.86134 .05438 L
.90073 .05436 L
.93861 .05434 L
.97619 .05433 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04114 L
.0379 .04199 L
.04033 .04317 L
.04262 .04401 L
.04761 .0453 L
.05217 .04616 L
.06244 .04776 L
.08259 .05119 L
.09399 .0537 L
.10458 .05662 L
.11466 .06019 L
.1238 .06443 L
.12887 .06738 L
.13435 .07125 L
.13949 .07575 L
.14429 .08097 L
.15379 .0955 L
.15925 .10687 L
.16423 .11805 L
.16673 .1229 L
.16814 .12507 L
.16945 .12658 L
.17059 .12744 L
.17185 .12786 L
.17316 .12767 L
.17439 .12694 L
.17503 .12636 L
.17573 .12558 L
.17713 .12359 L
.17964 .11891 L
.18529 .10586 L
.19013 .09482 L
.19538 .08473 L
.20033 .07733 L
.2049 .07221 L
.21023 .06795 L
.21292 .06637 L
.21588 .065 L
.21836 .06411 L
.22103 .06337 L
.22355 .06286 L
.22585 .06252 L
Mistroke
.22715 .06239 L
.22836 .06229 L
.22945 .06223 L
.23063 .06218 L
.23192 .06215 L
.23257 .06215 L
.23329 .06215 L
.23455 .06218 L
.23572 .06221 L
.23691 .06227 L
.23804 .06234 L
.24014 .0625 L
.24488 .06296 L
.2497 .06351 L
.25234 .06379 L
.25482 .064 L
.2561 .06408 L
.25682 .06412 L
.25749 .06414 L
.25817 .06416 L
.25892 .06417 L
.2597 .06417 L
.26043 .06416 L
.26174 .06411 L
.26294 .06404 L
.2636 .06399 L
.26431 .06392 L
.26561 .06378 L
.26798 .06345 L
.27052 .06299 L
.2751 .06201 L
.28553 .0596 L
.29118 .0585 L
.29654 .05765 L
.30135 .05705 L
.30658 .05656 L
.31142 .05622 L
.31597 .05598 L
.32095 .05579 L
.32376 .05572 L
.32633 .05566 L
.32869 .05562 L
.33122 .05558 L
.33398 .05555 L
.33656 .05553 L
.33795 .05553 L
.33946 .05552 L
.34089 .05552 L
.3422 .05551 L
.34339 .05551 L
Mistroke
.34469 .05551 L
.34535 .05551 L
.34606 .05551 L
.34733 .05551 L
.34802 .05551 L
.34867 .05551 L
.34987 .05551 L
.35258 .05551 L
.35745 .05552 L
.36003 .05552 L
.36133 .05553 L
.36275 .05553 L
.3635 .05553 L
.3643 .05553 L
.36505 .05553 L
.36574 .05553 L
.36641 .05553 L
.36715 .05553 L
.36784 .05553 L
.36848 .05553 L
.36963 .05553 L
.37087 .05552 L
.37312 .05552 L
.37579 .05551 L
.37823 .05551 L
.38327 .05549 L
.38858 .05547 L
.40856 .05536 L
.41727 .05532 L
.42671 .05529 L
.43196 .05528 L
.4368 .05527 L
.44143 .05526 L
.44633 .05526 L
.45149 .05525 L
.45631 .05525 L
.46729 .05525 L
.47771 .05524 L
.48759 .05523 L
.49646 .05523 L
.50613 .05522 L
.54685 .05517 L
.58605 .05514 L
.62771 .0551 L
.66784 .05507 L
.70647 .05504 L
.74754 .05502 L
.7871 .055 L
.82515 .05499 L
.86564 .05498 L
Mistroke
.90462 .05497 L
.94606 .05496 L
.97619 .05496 L
Mfstroke
1 .119 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04127 L
.0379 .04213 L
.04033 .04333 L
.04262 .04418 L
.04761 .04549 L
.05217 .04636 L
.06244 .04799 L
.08259 .05147 L
.09399 .05401 L
.10458 .05699 L
.11466 .06062 L
.1238 .06494 L
.12887 .06796 L
.13435 .07192 L
.13949 .07653 L
.14429 .08189 L
.15379 .09691 L
.15883 .1078 L
.16423 .12067 L
.16694 .12632 L
.16847 .12882 L
.1692 .12978 L
.16989 .13051 L
.17112 .13142 L
.17178 .13167 L
.17248 .13176 L
.17319 .13166 L
.17392 .13135 L
.17525 .1303 L
.17645 .12885 L
.17773 .12684 L
.18004 .12228 L
.18529 .1097 L
.19027 .09781 L
.19553 .08712 L
.20131 .07817 L
.20388 .07507 L
.20664 .07228 L
.20923 .0701 L
.2116 .06845 L
.21623 .066 L
.21882 .06501 L
Mistroke
.22165 .0642 L
.22294 .06391 L
.22432 .06365 L
.22679 .06329 L
.22804 .06317 L
.2294 .06307 L
.23009 .06303 L
.23083 .06299 L
.23153 .06297 L
.23216 .06296 L
.23338 .06295 L
.2347 .06297 L
.23595 .06301 L
.2371 .06306 L
.23843 .06314 L
.23967 .06323 L
.24251 .06348 L
.24824 .06412 L
.25298 .06463 L
.25413 .06473 L
.25536 .06482 L
.25607 .06486 L
.25671 .06489 L
.25796 .06493 L
.25866 .06495 L
.25931 .06495 L
.26002 .06494 L
.26077 .06493 L
.26203 .06487 L
.26275 .06483 L
.26342 .06478 L
.26584 .06454 L
.26842 .06417 L
.28821 .06027 L
.29363 .05941 L
.2994 .05866 L
.30438 .05815 L
.30975 .0577 L
.31484 .05737 L
.31951 .05713 L
.32397 .05695 L
.32867 .0568 L
.33383 .05667 L
.33864 .05659 L
.34141 .05656 L
.34392 .05653 L
.34661 .05651 L
.34957 .05649 L
.3544 .05647 L
.35953 .05645 L
Mistroke
.36873 .05642 L
.37946 .05638 L
.38952 .05633 L
.40807 .05622 L
.41787 .05617 L
.42831 .05613 L
.43928 .05609 L
.44946 .05607 L
.46955 .05603 L
.51115 .05597 L
.55124 .05589 L
.58981 .05582 L
.63083 .05576 L
.67034 .0557 L
.70833 .05565 L
.74878 .05561 L
.78771 .05557 L
.82909 .05554 L
.86895 .05551 L
.9073 .05549 L
.9481 .05547 L
.97619 .05546 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03488 L
.03279 .03779 L
.03527 .04023 L
.03652 .04116 L
.0379 .04202 L
.04033 .0432 L
.04262 .04403 L
.04761 .04532 L
.05217 .04617 L
.06244 .04775 L
.08259 .05114 L
.09399 .05363 L
.10458 .05651 L
.11466 .06002 L
.1238 .06417 L
.12887 .06704 L
.13435 .07079 L
.13949 .0751 L
.14429 .08007 L
.15379 .09364 L
.15925 .10405 L
.16423 .11424 L
.16673 .11872 L
.16805 .12066 L
.16877 .12155 L
.16945 .12227 L
.17067 .12322 L
.17132 .12354 L
.17202 .12373 L
.17326 .12367 L
.17439 .12317 L
.17571 .12209 L
.17693 .12064 L
.1797 .11604 L
.18529 .10377 L
.19034 .09247 L
.19581 .08211 L
.20098 .07464 L
.20575 .06961 L
.21005 .06634 L
.21249 .06492 L
.21478 .06385 L
.21714 .06296 L
.21939 .06229 L
.22197 .0617 L
Mistroke
.22434 .06132 L
.22559 .06117 L
.22694 .06105 L
.22821 .06096 L
.22938 .06091 L
.23044 .06088 L
.2316 .06086 L
.23282 .06087 L
.23395 .06089 L
.23459 .06091 L
.23528 .06093 L
.23654 .061 L
.23889 .06115 L
.24418 .06163 L
.24882 .06211 L
.25136 .06234 L
.25261 .06244 L
.25375 .06251 L
.25473 .06257 L
.25577 .06261 L
.25681 .06263 L
.25795 .06263 L
.25911 .06261 L
.26035 .06256 L
.26152 .06248 L
.26258 .06239 L
.2649 .06211 L
.26745 .06171 L
.27259 .06066 L
.28181 .05862 L
.287 .05762 L
.29256 .05675 L
.29782 .05611 L
.30262 .05565 L
.30741 .05529 L
.31251 .055 L
.31687 .05481 L
.32168 .05465 L
.32436 .05458 L
.32682 .05453 L
.32953 .05449 L
.33238 .05446 L
.33358 .05445 L
.33486 .05444 L
.33597 .05443 L
.33718 .05443 L
.33791 .05442 L
.33859 .05442 L
.33923 .05442 L
.33993 .05442 L
Mistroke
.34114 .05442 L
.34243 .05442 L
.34372 .05442 L
.34492 .05442 L
.34623 .05442 L
.34763 .05442 L
.35023 .05443 L
.35258 .05444 L
.36185 .05448 L
.36702 .0545 L
.36993 .05451 L
.37132 .05451 L
.37261 .05452 L
.37384 .05452 L
.37496 .05452 L
.3762 .05452 L
.37689 .05452 L
.37754 .05452 L
.37883 .05452 L
.38003 .05452 L
.38134 .05452 L
.382 .05452 L
.38274 .05452 L
.38509 .05451 L
.38766 .05451 L
.39284 .05449 L
.4021 .05446 L
.41303 .05442 L
.4182 .0544 L
.42296 .05439 L
.42531 .05439 L
.42781 .05439 L
.43031 .05438 L
.43173 .05438 L
.43236 .05438 L
.43306 .05438 L
.43429 .05438 L
.43546 .05438 L
.4366 .05438 L
.43765 .05438 L
.43891 .05438 L
.44004 .05438 L
.44135 .05438 L
.44259 .05438 L
.44514 .05439 L
.44784 .05439 L
.45266 .0544 L
.46354 .05442 L
.48346 .05445 L
.49215 .05447 L
Mistroke
.50158 .05448 L
.51164 .05449 L
.52115 .0545 L
.54208 .05451 L
.58294 .05454 L
.60324 .05455 L
.61318 .05455 L
.62227 .05456 L
.64049 .05456 L
.65054 .05456 L
.6601 .05456 L
.66503 .05456 L
.66968 .05456 L
.67503 .05456 L
.6774 .05456 L
.67989 .05456 L
.68208 .05457 L
.68449 .05457 L
.68555 .05457 L
.68668 .05457 L
.68775 .05457 L
.68872 .05457 L
.68994 .05457 L
.69107 .05457 L
.69231 .05457 L
.69363 .05457 L
.69477 .05457 L
.69584 .05457 L
.69701 .05457 L
.69828 .05457 L
.70067 .05457 L
.70323 .05456 L
.70784 .05456 L
.71333 .05456 L
.71831 .05456 L
.72916 .05456 L
.7394 .05456 L
.75941 .05456 L
.77786 .05455 L
.81725 .05454 L
.85512 .05453 L
.89545 .05452 L
.93426 .05451 L
.97553 .05449 L
.97619 .05449 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04552 L
.05217 .04639 L
.06244 .04801 L
.08259 .05147 L
.09399 .05401 L
.10458 .05697 L
.11466 .06059 L
.1238 .06488 L
.12887 .06787 L
.13435 .07178 L
.13949 .07632 L
.14429 .08159 L
.15379 .09623 L
.15883 .10678 L
.16423 .1193 L
.16694 .12491 L
.16837 .12731 L
.16915 .1284 L
.16989 .12926 L
.17058 .12991 L
.17121 .13036 L
.17191 .13069 L
.17267 .13084 L
.17392 .13063 L
.17525 .12979 L
.17645 .12852 L
.17773 .12668 L
.18004 .12235 L
.18529 .1099 L
.19553 .08673 L
.20131 .07749 L
.20406 .0741 L
.20664 .07145 L
.2113 .06776 L
.21377 .0663 L
.21643 .06505 L
.2192 .06404 L
.22184 .06332 L
Mistroke
.22421 .06286 L
.22555 .06265 L
.22679 .0625 L
.22808 .06238 L
.22879 .06233 L
.22944 .06229 L
.23061 .06224 L
.23188 .06221 L
.2326 .0622 L
.23327 .0622 L
.23454 .06222 L
.23525 .06224 L
.2359 .06227 L
.23738 .06234 L
.23968 .0625 L
.24222 .06272 L
.24735 .06326 L
.25198 .06373 L
.25325 .06384 L
.25458 .06393 L
.25572 .06399 L
.25696 .06403 L
.25815 .06404 L
.25922 .06403 L
.26046 .06399 L
.26163 .06393 L
.26272 .06385 L
.26372 .06376 L
.26597 .06348 L
.27581 .06166 L
.28637 .05963 L
.29633 .05818 L
.30543 .05725 L
.31475 .05656 L
.32002 .05628 L
.3249 .05608 L
.32915 .05594 L
.33385 .05582 L
.33621 .05577 L
.33876 .05573 L
.34337 .05568 L
.34576 .05566 L
.34831 .05564 L
.35073 .05563 L
.35292 .05562 L
.3555 .05561 L
.3583 .0556 L
.36338 .05559 L
.36871 .05559 L
.37435 .05557 L
Mistroke
.37917 .05556 L
.38447 .05554 L
.40553 .05542 L
.41551 .05536 L
.42478 .05533 L
.42939 .05531 L
.43429 .0553 L
.4371 .05529 L
.43974 .05529 L
.44214 .05529 L
.44467 .05528 L
.44693 .05528 L
.44812 .05528 L
.4494 .05528 L
.45058 .05528 L
.45165 .05528 L
.45273 .05528 L
.45375 .05528 L
.45494 .05528 L
.4562 .05528 L
.45727 .05528 L
.45846 .05528 L
.45973 .05528 L
.4611 .05528 L
.46357 .05528 L
.47308 .05528 L
.47831 .05528 L
.48324 .05529 L
.48604 .05529 L
.48751 .05529 L
.48907 .05529 L
.49039 .05529 L
.49108 .05529 L
.49183 .05529 L
.49315 .05529 L
.49437 .05529 L
.49506 .05529 L
.4957 .05529 L
.49641 .05529 L
.49715 .05529 L
.49787 .05529 L
.49854 .05529 L
.49979 .05529 L
.50217 .05529 L
.50473 .05529 L
.50953 .05529 L
.51479 .05528 L
.5254 .05528 L
.54438 .05527 L
.58487 .05526 L
Mistroke
.62385 .05524 L
.66529 .05522 L
.7052 .0552 L
.74361 .05518 L
.78446 .05515 L
.8238 .05513 L
.86162 .05511 L
.9019 .05509 L
.94066 .05507 L
.97619 .05505 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03492 L
.03279 .03786 L
.03527 .04032 L
.03652 .04126 L
.0379 .04213 L
.04033 .04333 L
.04262 .04418 L
.04761 .04549 L
.05217 .04636 L
.06244 .04799 L
.08259 .05146 L
.09399 .05401 L
.10458 .05698 L
.11466 .06061 L
.1238 .06493 L
.12887 .06794 L
.13435 .0719 L
.14429 .08187 L
.15372 .09679 L
.15901 .10837 L
.16384 .12024 L
.16656 .12644 L
.168 .12919 L
.16879 .13047 L
.16953 .13151 L
.17023 .13232 L
.17087 .13291 L
.17157 .13339 L
.17234 .1337 L
.1736 .13371 L
.17424 .13349 L
.17493 .13307 L
.17563 .13247 L
.17629 .13176 L
.17753 .13006 L
.1803 .12487 L
.18529 .11289 L
.1945 .09147 L
.19914 .08317 L
.20424 .07619 L
.2069 .07335 L
.20976 .07084 L
.21241 .06894 L
.21493 .06748 L
.21739 .06632 L
Mistroke
.22007 .06534 L
.22252 .06465 L
.22478 .06418 L
.22607 .06397 L
.22743 .06379 L
.2286 .06367 L
.22987 .06357 L
.23059 .06353 L
.23125 .0635 L
.232 .06347 L
.23272 .06346 L
.23399 .06345 L
.23471 .06346 L
.23537 .06348 L
.23656 .06352 L
.23767 .06357 L
.24021 .06375 L
.24268 .06398 L
.24534 .06428 L
.25008 .06485 L
.25266 .06515 L
.25506 .06537 L
.25612 .06545 L
.25712 .06551 L
.25827 .06556 L
.25931 .06558 L
.26048 .06559 L
.26155 .06558 L
.26272 .06554 L
.26396 .06548 L
.26518 .06539 L
.2665 .06528 L
.26891 .06502 L
.27342 .06439 L
.28357 .06279 L
.3019 .0603 L
.31128 .0593 L
.32165 .05844 L
.32686 .05812 L
.33248 .05783 L
.33778 .05762 L
.34265 .05748 L
.34738 .05737 L
.35244 .05728 L
.35721 .05722 L
.36155 .05717 L
.38224 .057 L
.40302 .05684 L
.42219 .0567 L
.44085 .05659 L
Mistroke
.45026 .05655 L
.46063 .05652 L
.50093 .05641 L
.53973 .05631 L
.58097 .05621 L
.6207 .05613 L
.65891 .05605 L
.69958 .05598 L
.73873 .05592 L
.78033 .05587 L
.82041 .05582 L
.85899 .05578 L
.90001 .05575 L
.93952 .05572 L
.97619 .05569 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04035 L
.03652 .0413 L
.0379 .04217 L
.04033 .04338 L
.04262 .04424 L
.04761 .04557 L
.05217 .04646 L
.06244 .04811 L
.08259 .05165 L
.09399 .05425 L
.10458 .05728 L
.11466 .061 L
.1238 .06545 L
.12887 .06857 L
.13435 .07269 L
.14429 .08319 L
.15372 .09925 L
.15901 .11198 L
.16384 .12515 L
.16656 .13202 L
.168 .13504 L
.16879 .13642 L
.16953 .13753 L
.17023 .13838 L
.17087 .13899 L
.17157 .13947 L
.17234 .13974 L
.1736 .13964 L
.17424 .13933 L
.17493 .1388 L
.17563 .13808 L
.17629 .13724 L
.17753 .13529 L
.1803 .12947 L
.18529 .11647 L
.1945 .09385 L
.19914 .08519 L
.20424 .07792 L
.2069 .07496 L
.20976 .07233 L
.21241 .07034 L
.21493 .06879 L
.21739 .06757 L
Mistroke
.22007 .06652 L
.22252 .06578 L
.22478 .06526 L
.22607 .06503 L
.22743 .06483 L
.22861 .06469 L
.22987 .06457 L
.23058 .06452 L
.23123 .06448 L
.2325 .06443 L
.23321 .06442 L
.23398 .06441 L
.2347 .06441 L
.23537 .06442 L
.23656 .06445 L
.23767 .06449 L
.2389 .06456 L
.24021 .06465 L
.24534 .06514 L
.25008 .06569 L
.25266 .06597 L
.25392 .06608 L
.25506 .06617 L
.25605 .06624 L
.25712 .06629 L
.25825 .06633 L
.25931 .06634 L
.26049 .06633 L
.26173 .06629 L
.2628 .06623 L
.26396 .06614 L
.26526 .06601 L
.26647 .06586 L
.26919 .06543 L
.27415 .06445 L
.28345 .06239 L
.29358 .06054 L
.2987 .05984 L
.30435 .05923 L
.30926 .05882 L
.31443 .05848 L
.31884 .05826 L
.32368 .05806 L
.32889 .0579 L
.33447 .05777 L
.33974 .05769 L
.34452 .05763 L
.34683 .05761 L
.34936 .05759 L
.35449 .05756 L
Mistroke
.35924 .05755 L
.36369 .05753 L
.38447 .05747 L
.40303 .0574 L
.42327 .05734 L
.43424 .05731 L
.44442 .05729 L
.46451 .05726 L
.50366 .0572 L
.54526 .05711 L
.58535 .05703 L
.62392 .05696 L
.66494 .05689 L
.70445 .05684 L
.74244 .0568 L
.7636 .05678 L
.78289 .05677 L
.82181 .05675 L
.84091 .05674 L
.86168 .05673 L
.88147 .05673 L
.89146 .05673 L
.90248 .05672 L
.91258 .05672 L
.92184 .05672 L
.93201 .05672 L
.93712 .05672 L
.9427 .05672 L
.9448 .05672 L
.94707 .05672 L
.94907 .05672 L
.95119 .05672 L
.9531 .05672 L
.95419 .05672 L
.9552 .05672 L
.95613 .05672 L
.95698 .05672 L
.95797 .05672 L
.9589 .05672 L
.95999 .05672 L
.96098 .05672 L
.96212 .05672 L
.96319 .05672 L
.96511 .05672 L
.96717 .05672 L
.97187 .05672 L
.97619 .05672 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03488 L
.03279 .0378 L
.03527 .04025 L
.03652 .04119 L
.0379 .04205 L
.04033 .04325 L
.04262 .0441 L
.04761 .04543 L
.05217 .04631 L
.06244 .04795 L
.08259 .05147 L
.09399 .05404 L
.10458 .05706 L
.11466 .06075 L
.1238 .06517 L
.12887 .06828 L
.13435 .07238 L
.14429 .08287 L
.14913 .09016 L
.15372 .09899 L
.15901 .11187 L
.16384 .12528 L
.16641 .13196 L
.16782 .13506 L
.16915 .13742 L
.1699 .13848 L
.17058 .13925 L
.17134 .13987 L
.17215 .14027 L
.1728 .14038 L
.17351 .14028 L
.17425 .13996 L
.17493 .13945 L
.17558 .13881 L
.17628 .13794 L
.17756 .13594 L
.17994 .13105 L
.18529 .11731 L
.19527 .09319 L
.2003 .08423 L
.20584 .07693 L
.21055 .07247 L
.2132 .07055 L
.21562 .06912 L
.21787 .06802 L
Mistroke
.22032 .06705 L
.22264 .06633 L
.22478 .06581 L
.22734 .06536 L
.22869 .06518 L
.23011 .06504 L
.23135 .06495 L
.2325 .06489 L
.23377 .06485 L
.23448 .06485 L
.23512 .06484 L
.23632 .06486 L
.23743 .06489 L
.23865 .06494 L
.23994 .06502 L
.2421 .06519 L
.24449 .06542 L
.24971 .06601 L
.25244 .06631 L
.25394 .06646 L
.25532 .06658 L
.25655 .06666 L
.25786 .06673 L
.2586 .06675 L
.25931 .06677 L
.26062 .06677 L
.26184 .06674 L
.26295 .06669 L
.26418 .0666 L
.26548 .06647 L
.26802 .06613 L
.27042 .06571 L
.27494 .06473 L
.28509 .06223 L
.2938 .06041 L
.29876 .05961 L
.30342 .05902 L
.30805 .05856 L
.31305 .05819 L
.3184 .0579 L
.3233 .05771 L
.32758 .05759 L
.33227 .0575 L
.33463 .05746 L
.33716 .05743 L
.33933 .05741 L
.34171 .0574 L
.3443 .05738 L
.34703 .05737 L
.34957 .05736 L
Mistroke
.35194 .05736 L
.35337 .05736 L
.35473 .05736 L
.35729 .05735 L
.36004 .05735 L
.36303 .05735 L
.36809 .05735 L
.37092 .05734 L
.37348 .05734 L
.38318 .05732 L
.39334 .0573 L
.40406 .05728 L
.41322 .05727 L
.41842 .05726 L
.42327 .05726 L
.42566 .05725 L
.42827 .05725 L
.42946 .05725 L
.43073 .05725 L
.43183 .05725 L
.43301 .05725 L
.43414 .05725 L
.43519 .05725 L
.43618 .05725 L
.43723 .05725 L
.43838 .05725 L
.43945 .05725 L
.44063 .05725 L
.44189 .05725 L
.44447 .05725 L
.44726 .05725 L
.45234 .05726 L
.46184 .05726 L
.46679 .05726 L
.47211 .05726 L
.47469 .05726 L
.47714 .05726 L
.47936 .05726 L
.48173 .05726 L
.48303 .05727 L
.48422 .05727 L
.48541 .05727 L
.48652 .05727 L
.48783 .05727 L
.48904 .05727 L
.49036 .05727 L
.49102 .05727 L
.49175 .05727 L
.4932 .05727 L
.49451 .05726 L
Mistroke
.49746 .05726 L
.50019 .05726 L
.50277 .05726 L
.51246 .05726 L
.52274 .05726 L
.54118 .05725 L
.579 .05723 L
.60003 .05722 L
.61927 .05721 L
.62877 .05721 L
.63914 .0572 L
.64894 .0572 L
.65367 .0572 L
.65803 .0572 L
.66311 .0572 L
.66577 .0572 L
.66714 .0572 L
.66859 .0572 L
.66988 .0572 L
.67105 .0572 L
.67222 .0572 L
.67334 .0572 L
.67463 .0572 L
.67583 .0572 L
.67715 .0572 L
.67781 .0572 L
.67855 .0572 L
.67972 .0572 L
.68095 .0572 L
.68316 .0572 L
.68554 .0572 L
.68814 .0572 L
.69281 .0572 L
.69715 .0572 L
.70767 .0572 L
.7176 .05721 L
.73618 .05721 L
.75619 .05722 L
.77464 .05723 L
.81403 .05726 L
.8519 .05729 L
.89223 .05734 L
.93104 .05738 L
.97231 .05743 L
.97619 .05743 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .0379 L
.03527 .04038 L
.03652 .04134 L
.0379 .04222 L
.04033 .04344 L
.04262 .0443 L
.04761 .04565 L
.05217 .04654 L
.06244 .04819 L
.08259 .05172 L
.09399 .05431 L
.10458 .05733 L
.11466 .06104 L
.1238 .06546 L
.12887 .06854 L
.13435 .07261 L
.14429 .08289 L
.15372 .0984 L
.15901 .1106 L
.16384 .12333 L
.16656 .13018 L
.168 .13329 L
.16953 .13601 L
.17018 .13693 L
.17087 .13775 L
.17163 .13844 L
.17234 .13888 L
.173 .1391 L
.17369 .13913 L
.17493 .1387 L
.17617 .13765 L
.17686 .13682 L
.1775 .13592 L
.17988 .13145 L
.18529 .11758 L
.19504 .0925 L
.20054 .08207 L
.2056 .07507 L
.21004 .07069 L
.21256 .0688 L
.21492 .06735 L
.21736 .06615 L
.21967 .06524 L
.22234 .06444 L
Mistroke
.22478 .06391 L
.22603 .0637 L
.22738 .06351 L
.22865 .06338 L
.22982 .06329 L
.23088 .06323 L
.23205 .06318 L
.23326 .06316 L
.23439 .06316 L
.23503 .06317 L
.23572 .06319 L
.23698 .06324 L
.2382 .0633 L
.23933 .06337 L
.24462 .06384 L
.24923 .06434 L
.25149 .06456 L
.25355 .06472 L
.25461 .06479 L
.25572 .06484 L
.25684 .06488 L
.25806 .06489 L
.2593 .06487 L
.26 .06485 L
.26063 .06482 L
.26186 .06475 L
.26302 .06465 L
.26543 .06438 L
.26767 .06405 L
.27277 .06313 L
.28308 .06118 L
.29192 .0598 L
.30154 .05863 L
.31198 .05765 L
.31677 .05729 L
.32187 .05697 L
.32645 .05673 L
.3315 .05652 L
.3361 .05638 L
.34042 .05627 L
.3451 .05619 L
.35023 .05612 L
.35282 .05609 L
.35559 .05607 L
.36058 .05604 L
.37907 .05593 L
.39896 .0558 L
.40944 .05573 L
.41517 .05569 L
.42054 .05566 L
Mistroke
.42571 .05564 L
.43043 .05563 L
.43568 .05561 L
.43857 .05561 L
.44132 .0556 L
.44362 .0556 L
.44607 .0556 L
.44727 .0556 L
.44839 .05559 L
.44939 .05559 L
.45049 .05559 L
.4517 .05559 L
.45299 .05559 L
.45418 .05559 L
.45529 .05559 L
.45661 .05559 L
.4578 .05559 L
.45846 .05559 L
.45918 .05559 L
.46049 .05559 L
.46283 .05559 L
.46534 .05559 L
.4699 .0556 L
.48028 .0556 L
.48562 .0556 L
.48853 .05561 L
.49124 .05561 L
.49376 .05561 L
.49604 .05561 L
.49858 .05561 L
.49998 .05561 L
.50129 .05561 L
.50245 .05561 L
.50369 .05561 L
.50486 .05561 L
.50593 .05561 L
.50718 .05561 L
.50789 .05561 L
.50854 .05561 L
.50974 .05561 L
.51102 .05561 L
.51381 .05561 L
.51643 .05561 L
.52132 .05561 L
.53978 .0556 L
.54958 .0556 L
.55991 .0556 L
.56873 .0556 L
.5784 .0556 L
.58846 .0556 L
Mistroke
.59796 .0556 L
.60892 .0556 L
.6189 .05559 L
.63886 .05559 L
.6573 .05558 L
.69664 .05557 L
.73446 .05555 L
.77474 .05553 L
.81349 .05551 L
.85471 .05549 L
.8944 .05547 L
.93258 .05545 L
.97322 .05544 L
.97619 .05543 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04015 L
.03652 .04107 L
.0379 .04191 L
.04033 .04306 L
.04262 .04387 L
.04517 .04457 L
.04761 .0451 L
.05217 .04592 L
.06244 .04743 L
.07302 .04903 L
.08429 .05102 L
.09474 .05325 L
.10458 .05583 L
.1142 .05899 L
.12461 .06346 L
.13407 .06898 L
.14277 .07604 L
.15263 .08757 L
.15805 .09583 L
.16319 .10412 L
.16551 .10745 L
.16678 .10899 L
.16797 .1102 L
.16925 .11118 L
.16994 .11155 L
.17067 .11182 L
.17197 .11196 L
.17317 .1117 L
.17426 .11113 L
.17528 .11033 L
.1764 .10917 L
.1776 .10765 L
.18226 .09978 L
.18717 .09032 L
.19249 .08099 L
.19719 .07434 L
.20215 .06897 L
.20663 .06545 L
.20918 .06392 L
.21156 .06274 L
.21574 .0612 L
.21809 .06058 L
.22023 .06014 L
Mistroke
.22152 .05993 L
.22274 .05976 L
.22385 .05964 L
.22501 .05953 L
.22629 .05945 L
.22746 .05939 L
.22872 .05935 L
.22944 .05934 L
.2301 .05933 L
.23129 .05934 L
.23242 .05936 L
.23343 .05939 L
.23452 .05944 L
.23698 .05958 L
.23926 .05975 L
.24441 .06023 L
.24711 .0605 L
.24996 .06077 L
.25246 .06097 L
.25388 .06106 L
.2552 .06111 L
.25641 .06114 L
.25752 .06115 L
.25879 .06113 L
.25999 .06108 L
.26108 .06102 L
.26227 .06092 L
.26467 .06064 L
.26689 .06029 L
.26897 .0599 L
.27869 .05775 L
.28376 .05668 L
.28928 .05569 L
.29449 .05497 L
.29931 .05445 L
.30399 .05407 L
.30916 .05376 L
.31176 .05365 L
.31456 .05354 L
.31699 .05347 L
.31964 .05341 L
.32208 .05337 L
.32435 .05334 L
.32675 .05331 L
.32809 .0533 L
.32931 .0533 L
.33045 .05329 L
.3315 .05329 L
.33265 .05329 L
.33388 .05329 L
Mistroke
.33494 .05329 L
.33593 .05329 L
.33702 .0533 L
.33819 .0533 L
.34073 .05332 L
.34343 .05334 L
.3483 .05338 L
.35934 .05349 L
.36477 .05354 L
.36988 .05357 L
.37447 .0536 L
.37705 .05361 L
.37943 .05362 L
.3807 .05362 L
.38189 .05362 L
.38298 .05362 L
.38414 .05363 L
.38539 .05363 L
.38655 .05363 L
.3878 .05363 L
.38851 .05363 L
.38918 .05363 L
.39029 .05363 L
.39146 .05363 L
.39246 .05363 L
.39355 .05363 L
.396 .05362 L
.39827 .05362 L
.40891 .0536 L
.41413 .05359 L
.41642 .05359 L
.41763 .05359 L
.41894 .05358 L
.42023 .05358 L
.42141 .05358 L
.42259 .05358 L
.42371 .05358 L
.42497 .05358 L
.42613 .05358 L
.42741 .05358 L
.42812 .05358 L
.42877 .05358 L
.43014 .05358 L
.4314 .05358 L
.43425 .05359 L
.43676 .05359 L
.43941 .0536 L
.44828 .05362 L
.458 .05364 L
.47921 .05371 L
Mistroke
.4985 .05377 L
.51854 .0538 L
.53748 .05383 L
.57588 .05388 L
.59532 .05391 L
.61674 .05393 L
.65608 .05396 L
.67548 .05397 L
.69635 .05398 L
.70645 .05398 L
.71748 .05398 L
.72801 .05399 L
.73756 .05399 L
.74769 .05399 L
.75723 .05399 L
.76247 .05399 L
.7673 .05399 L
.76982 .05399 L
.7726 .05399 L
.77399 .05399 L
.77549 .05399 L
.77678 .05399 L
.7782 .05399 L
.77952 .05399 L
.78076 .05399 L
.78207 .05399 L
.7828 .05399 L
.78348 .05399 L
.78461 .05399 L
.78586 .05399 L
.78716 .05399 L
.78836 .05399 L
.79117 .05399 L
.79371 .05399 L
.79943 .05399 L
.80439 .05399 L
.80977 .05399 L
.81955 .05399 L
.83941 .05399 L
.86045 .05398 L
.89833 .05398 L
.93865 .05397 L
.97619 .05396 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04225 L
.04033 .04347 L
.04262 .04434 L
.04761 .0457 L
.05217 .0466 L
.06244 .04827 L
.08259 .05184 L
.09399 .05446 L
.10458 .05753 L
.11466 .06129 L
.1238 .0658 L
.12887 .06896 L
.13435 .07314 L
.14429 .0838 L
.16384 .1276 L
.16659 .13547 L
.16919 .14163 L
.17063 .14411 L
.17144 .14516 L
.17219 .14587 L
.17283 .14628 L
.17352 .14652 L
.17425 .14654 L
.17493 .14633 L
.1762 .14543 L
.17684 .14473 L
.17753 .14378 L
.17992 .13936 L
.18529 .12524 L
.19518 .09837 L
.20072 .08701 L
.20575 .07936 L
.21044 .07418 L
.21309 .07196 L
.21554 .0703 L
.22003 .06802 L
.22229 .0672 L
.22478 .06651 L
.22727 .06602 L
.22868 .06581 L
.22999 .06567 L
Mistroke
.23125 .06556 L
.23239 .0655 L
.2337 .06546 L
.23494 .06545 L
.23607 .06546 L
.23727 .0655 L
.23829 .06555 L
.2394 .06562 L
.2419 .06583 L
.24423 .06608 L
.24937 .06675 L
.25208 .06711 L
.25496 .06745 L
.25617 .06756 L
.25747 .06767 L
.25822 .06772 L
.2589 .06775 L
.2596 .06779 L
.26024 .06781 L
.26138 .06784 L
.26262 .06785 L
.26383 .06784 L
.26512 .06781 L
.26579 .06778 L
.26649 .06776 L
.26776 .06769 L
.27062 .06751 L
.27581 .06709 L
.28551 .06609 L
.30408 .06347 L
.31426 .06195 L
.32392 .06074 L
.33258 .05991 L
.34202 .05926 L
.34692 .05902 L
.35214 .05882 L
.36151 .05855 L
.37144 .05834 L
.38241 .05817 L
.40336 .05788 L
.42258 .05766 L
.4414 .0575 L
.45087 .05744 L
.46124 .05739 L
.50177 .05723 L
.54078 .0571 L
.58224 .05699 L
.62219 .05689 L
.66063 .05681 L
.70151 .05673 L
Mistroke
.74089 .05666 L
.77874 .05661 L
.81905 .05655 L
.85784 .05651 L
.89908 .05647 L
.93881 .05643 L
.97619 .0564 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04347 L
.04262 .04434 L
.04761 .0457 L
.05217 .0466 L
.06244 .04829 L
.08259 .05188 L
.09399 .05452 L
.10458 .05762 L
.11466 .06142 L
.1238 .066 L
.12887 .06922 L
.13435 .07349 L
.14429 .08449 L
.16384 .13111 L
.16659 .13958 L
.16919 .14612 L
.17063 .14869 L
.17144 .14974 L
.17219 .15044 L
.17283 .15081 L
.17352 .151 L
.17425 .15094 L
.17493 .15066 L
.1762 .14959 L
.17684 .1488 L
.17753 .14776 L
.17992 .14302 L
.18529 .12846 L
.19518 .10143 L
.20072 .08995 L
.20575 .0821 L
.21044 .07669 L
.21292 .07448 L
.21554 .07254 L
.21783 .07116 L
.22035 .06992 L
.22265 .06902 L
.22478 .06837 L
.22727 .06779 L
.22859 .06756 L
Mistroke
.22999 .06736 L
.23133 .06722 L
.23259 .06713 L
.23372 .06707 L
.23494 .06704 L
.23606 .06704 L
.2373 .06706 L
.23858 .0671 L
.23978 .06717 L
.24193 .06734 L
.24423 .06758 L
.2495 .06826 L
.25238 .06864 L
.25509 .06895 L
.25621 .06906 L
.25738 .06915 L
.25868 .06923 L
.25986 .06928 L
.26116 .06931 L
.26237 .06931 L
.26307 .0693 L
.2637 .06929 L
.26443 .06927 L
.26512 .06924 L
.26636 .06918 L
.26767 .06909 L
.27002 .0689 L
.27532 .06837 L
.2864 .06718 L
.30653 .06493 L
.31672 .06379 L
.32637 .06286 L
.33504 .06221 L
.34447 .0617 L
.34938 .06151 L
.35459 .06135 L
.35904 .06125 L
.36396 .06116 L
.36914 .06109 L
.37474 .06103 L
.38002 .06099 L
.38486 .06096 L
.42446 .06073 L
.46253 .06045 L
.50306 .06019 L
.54207 .05996 L
.58354 .05971 L
.62349 .05949 L
.66192 .05931 L
.70281 .05915 L
Mistroke
.74218 .05903 L
.78003 .05893 L
.82034 .05885 L
.85913 .05879 L
.90038 .05874 L
.94011 .0587 L
.97619 .05867 L
Mfstroke
1 .356 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03488 L
.03279 .0378 L
.03527 .04024 L
.03652 .04118 L
.0379 .04204 L
.04033 .04324 L
.04262 .04409 L
.04761 .04541 L
.05217 .04629 L
.06244 .04793 L
.08259 .05144 L
.09399 .05401 L
.10458 .05701 L
.11466 .06069 L
.1238 .0651 L
.12887 .06819 L
.13435 .07228 L
.14429 .08274 L
.16384 .12632 L
.16659 .13429 L
.16919 .1406 L
.17063 .14318 L
.17144 .1443 L
.17219 .14508 L
.17283 .14555 L
.17352 .14586 L
.17425 .14596 L
.17493 .14585 L
.1762 .14514 L
.17684 .14454 L
.17753 .14373 L
.17992 .13981 L
.1827 .13364 L
.18529 .12706 L
.19511 .10237 L
.19994 .09265 L
.20438 .08547 L
.20951 .07912 L
.21216 .07655 L
.21507 .0742 L
.21979 .07133 L
.22237 .07017 L
.22478 .06931 L
.22736 .0686 L
.22976 .06812 L
Mistroke
.23114 .06791 L
.23239 .06776 L
.23308 .0677 L
.23383 .06764 L
.23453 .06759 L
.23519 .06756 L
.23638 .06752 L
.23769 .06751 L
.23897 .06753 L
.23968 .06755 L
.24034 .06758 L
.2415 .06765 L
.24277 .06774 L
.24507 .06797 L
.24974 .06863 L
.2547 .06951 L
.25904 .07033 L
.2636 .07111 L
.26595 .07143 L
.26719 .07157 L
.26851 .07169 L
.26973 .07178 L
.27084 .07184 L
.27195 .07188 L
.273 .0719 L
.27423 .07189 L
.27553 .07186 L
.27664 .0718 L
.27786 .07172 L
.27917 .0716 L
.28057 .07144 L
.28311 .07107 L
.28802 .0701 L
.29268 .06896 L
.30141 .06659 L
.31104 .06414 L
.31633 .06301 L
.32129 .06211 L
.33004 .0609 L
.33469 .06043 L
.3397 .06002 L
.34465 .05971 L
.34926 .05948 L
.35972 .05911 L
.36991 .05886 L
.38081 .05861 L
.4007 .05815 L
.42228 .05768 L
.43236 .0575 L
.44305 .05734 L
Mistroke
.46223 .05714 L
.47165 .05706 L
.48178 .05699 L
.50008 .05688 L
.51981 .05678 L
.54133 .0567 L
.56193 .05663 L
.58105 .05659 L
.60159 .05656 L
.6202 .05653 L
.63947 .05651 L
.65031 .05651 L
.66029 .0565 L
.66499 .0565 L
.67004 .0565 L
.67439 .0565 L
.67913 .0565 L
.68202 .0565 L
.68468 .0565 L
.68718 .0565 L
.68851 .0565 L
.68994 .0565 L
.69123 .0565 L
.69241 .0565 L
.69354 .0565 L
.69472 .0565 L
.69598 .0565 L
.69715 .0565 L
.69843 .0565 L
.69915 .0565 L
.6998 .0565 L
.70099 .0565 L
.70211 .0565 L
.70334 .0565 L
.70465 .0565 L
.70734 .0565 L
.70979 .0565 L
.71451 .0565 L
.719 .0565 L
.72895 .0565 L
.7398 .0565 L
.75953 .05651 L
.78052 .05652 L
.82217 .05655 L
.86231 .05657 L
.90093 .0566 L
.94201 .05664 L
.97619 .05667 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03483 L
.03279 .03771 L
.03397 .03896 L
.03527 .04009 L
.03653 .041 L
.0379 .04181 L
.04033 .04294 L
.04262 .04372 L
.04516 .04439 L
.04793 .04497 L
.05297 .0458 L
.06244 .04713 L
.08284 .05032 L
.09424 .05262 L
.10458 .0552 L
.11463 .05835 L
.12551 .06282 L
.13578 .0686 L
.14523 .07603 L
.15496 .08663 L
.15963 .09254 L
.16405 .09775 L
.16526 .09892 L
.16655 .09998 L
.16722 .10043 L
.16796 .10085 L
.16927 .10136 L
.17045 .10153 L
.17172 .10139 L
.17292 .10095 L
.17402 .10028 L
.17531 .09921 L
.17651 .09795 L
.17923 .09438 L
.18471 .0857 L
.18976 .07797 L
.19524 .0711 L
.2004 .06625 L
.20517 .06303 L
.20947 .06097 L
.21191 .06009 L
.2142 .05943 L
.21661 .05889 L
.21881 .05851 L
.22002 .05835 L
Mistroke
.22135 .0582 L
.22252 .0581 L
.22376 .05801 L
.22439 .05797 L
.22509 .05794 L
.22632 .0579 L
.22701 .05789 L
.22775 .05788 L
.22845 .05788 L
.22909 .05788 L
.23032 .0579 L
.23102 .05792 L
.23166 .05794 L
.2341 .05806 L
.23626 .05819 L
.23865 .05838 L
.24347 .05884 L
.24869 .05936 L
.25142 .0596 L
.25291 .0597 L
.25364 .05975 L
.2543 .05978 L
.25553 .05983 L
.25683 .05986 L
.25752 .05986 L
.25826 .05985 L
.25896 .05984 L
.2596 .05982 L
.26073 .05976 L
.26196 .05967 L
.26325 .05955 L
.26446 .05941 L
.28307 .0556 L
.28817 .05466 L
.29359 .05387 L
.29822 .05336 L
.30333 .05295 L
.30608 .05278 L
.30859 .05266 L
.31136 .05255 L
.31427 .05247 L
.31681 .05241 L
.31918 .05237 L
.32054 .05236 L
.32177 .05235 L
.32246 .05234 L
.3232 .05234 L
.3239 .05234 L
.32455 .05234 L
.3257 .05233 L
Mistroke
.32695 .05233 L
.32812 .05234 L
.3292 .05234 L
.33045 .05235 L
.33182 .05235 L
.33431 .05237 L
.33968 .05243 L
.34466 .0525 L
.35381 .05264 L
.36347 .05277 L
.36852 .05283 L
.37407 .05287 L
.3765 .05289 L
.37911 .05291 L
.38155 .05292 L
.38381 .05293 L
.38657 .05294 L
.388 .05294 L
.38957 .05294 L
.39084 .05295 L
.39221 .05295 L
.39297 .05295 L
.39366 .05295 L
.39432 .05295 L
.39502 .05295 L
.39625 .05295 L
.3974 .05295 L
.3981 .05295 L
.39876 .05295 L
.4 .05295 L
.40131 .05295 L
.40251 .05295 L
.40524 .05295 L
.40768 .05295 L
.4103 .05295 L
.41157 .05295 L
.41278 .05295 L
.41386 .05295 L
.41504 .05295 L
.41628 .05295 L
.4176 .05295 L
.41885 .05295 L
.41998 .05295 L
.42068 .05295 L
.42133 .05295 L
.42278 .05295 L
.42406 .05295 L
.42541 .05295 L
.42797 .05295 L
.43039 .05296 L
Mistroke
.43493 .05296 L
.43981 .05298 L
.4451 .05299 L
.46346 .05306 L
.48289 .05314 L
.50431 .0532 L
.52462 .05324 L
.54365 .05328 L
.58241 .05334 L
.60211 .05337 L
.62362 .05339 L
.66332 .05343 L
.68298 .05344 L
.70395 .05345 L
.72535 .05346 L
.73516 .05346 L
.74552 .05347 L
.75509 .05347 L
.76559 .05347 L
.77507 .05347 L
.78406 .05347 L
.78894 .05347 L
.79426 .05347 L
.79868 .05348 L
.80356 .05348 L
.80882 .05348 L
.81171 .05348 L
.81442 .05348 L
.81694 .05348 L
.81926 .05348 L
.82047 .05348 L
.82116 .05348 L
.8218 .05348 L
.82247 .05348 L
.82318 .05348 L
.82447 .05348 L
.82566 .05348 L
.82678 .05348 L
.828 .05348 L
.82932 .05348 L
.83069 .05348 L
.832 .05348 L
.83445 .05348 L
.83885 .05348 L
.84365 .05348 L
.85443 .05347 L
.86444 .05347 L
.88499 .05347 L
.90361 .05347 L
.94372 .05347 L
Mistroke
.97619 .05346 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04668 L
.06244 .04839 L
.08259 .05203 L
.09399 .05471 L
.10458 .05785 L
.11466 .06172 L
.1238 .06639 L
.12887 .06969 L
.13435 .0741 L
.13953 .07936 L
.14429 .08554 L
.14935 .09413 L
.15414 .10495 L
.15967 .12164 L
.16471 .14026 L
.16701 .14871 L
.16945 .15642 L
.17046 .15896 L
.17154 .16118 L
.17273 .16293 L
.17384 .16388 L
.17505 .16415 L
.17637 .16358 L
.17703 .16297 L
.17774 .1621 L
.17902 .16002 L
.18151 .15442 L
.18378 .14813 L
.19315 .11923 L
.19808 .10605 L
.20331 .09484 L
.20788 .0873 L
.2129 .08115 L
.21511 .07906 L
.21747 .07717 L
.22175 .07458 L
.22429 .07346 L
Mistroke
.22569 .07297 L
.227 .07258 L
.22823 .07227 L
.22956 .072 L
.23076 .0718 L
.23188 .07166 L
.23258 .07159 L
.23321 .07154 L
.23392 .07149 L
.23468 .07146 L
.23541 .07145 L
.2362 .07144 L
.23694 .07146 L
.23763 .07148 L
.23885 .07155 L
.23955 .0716 L
.2402 .07166 L
.24292 .07201 L
.24539 .07244 L
.24798 .073 L
.2526 .07419 L
.26302 .07709 L
.27259 .07974 L
.27535 .08042 L
.27795 .08097 L
.28028 .08137 L
.28159 .08154 L
.28281 .08167 L
.28387 .08175 L
.28501 .08181 L
.28608 .08184 L
.28706 .08184 L
.28821 .08181 L
.28946 .08175 L
.29064 .08165 L
.29174 .08153 L
.29391 .08123 L
.29632 .08078 L
.30118 .07961 L
.32213 .07326 L
.33131 .07098 L
.33616 .07001 L
.34136 .06913 L
.34646 .06843 L
.3511 .06791 L
.36018 .06715 L
.36507 .06684 L
.37038 .06658 L
.38001 .06622 L
.4209 .06512 L
Mistroke
.46027 .06416 L
.49812 .0635 L
.53843 .06294 L
.57722 .06246 L
.61847 .06202 L
.6582 .06165 L
.69641 .06136 L
.73707 .0611 L
.77622 .0609 L
.81783 .06072 L
.85791 .06058 L
.89648 .06046 L
.93751 .06036 L
.97619 .06027 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .0379 L
.03527 .04038 L
.03652 .04133 L
.0379 .04221 L
.04033 .04344 L
.04262 .0443 L
.04761 .04566 L
.05217 .04656 L
.06244 .04824 L
.08259 .05184 L
.09399 .05448 L
.10458 .05757 L
.11466 .06137 L
.1238 .06594 L
.12887 .06916 L
.13435 .07344 L
.14429 .08445 L
.14913 .0922 L
.15372 .10169 L
.15901 .11573 L
.16384 .13067 L
.16641 .13826 L
.16782 .14184 L
.16915 .14462 L
.1699 .14588 L
.17058 .14682 L
.17134 .14762 L
.17215 .14817 L
.1728 .14837 L
.17351 .14836 L
.17425 .1481 L
.17493 .14763 L
.17558 .14699 L
.17628 .14611 L
.17756 .14405 L
.17994 .13889 L
.18529 .12409 L
.19527 .09774 L
.2003 .08788 L
.20584 .0798 L
.21055 .07485 L
.2132 .07272 L
.21562 .07112 L
.21787 .06989 L
Mistroke
.22032 .06881 L
.22264 .06799 L
.22478 .0674 L
.22734 .06688 L
.22869 .06667 L
.23011 .0665 L
.23135 .06639 L
.2325 .06631 L
.23377 .06626 L
.23448 .06624 L
.23512 .06623 L
.23632 .06624 L
.23743 .06626 L
.23865 .06631 L
.23994 .06638 L
.2421 .06654 L
.24449 .06676 L
.24971 .06736 L
.25244 .06767 L
.25394 .06782 L
.25532 .06793 L
.25655 .06801 L
.25786 .06807 L
.2586 .06809 L
.25931 .0681 L
.26062 .06809 L
.26184 .06805 L
.26295 .06798 L
.26418 .06788 L
.26548 .06774 L
.26802 .06738 L
.27042 .06695 L
.27494 .06597 L
.28509 .06364 L
.29386 .06204 L
.29882 .06138 L
.30342 .0609 L
.30804 .06051 L
.31303 .06019 L
.31774 .05996 L
.32206 .05979 L
.32684 .05964 L
.33208 .05952 L
.33473 .05947 L
.33756 .05942 L
.34265 .05936 L
.34523 .05934 L
.34797 .05932 L
.3503 .05931 L
.35288 .0593 L
Mistroke
.35432 .0593 L
.35564 .05929 L
.35716 .05929 L
.35786 .05929 L
.35861 .05929 L
.3593 .05929 L
.35994 .05929 L
.36117 .05929 L
.36186 .05929 L
.36261 .05929 L
.36332 .05929 L
.36397 .05929 L
.36514 .05929 L
.36639 .05929 L
.36757 .05929 L
.36864 .05929 L
.37377 .0593 L
.37908 .05931 L
.38412 .05932 L
.40235 .05937 L
.41273 .0594 L
.42247 .05942 L
.43199 .05944 L
.43735 .05944 L
.44225 .05945 L
.44715 .05945 L
.45249 .05945 L
.45519 .05945 L
.45808 .05945 L
.45948 .05945 L
.4608 .05945 L
.46199 .05946 L
.46327 .05946 L
.46452 .05946 L
.46566 .05946 L
.46681 .05946 L
.4679 .05946 L
.46917 .05946 L
.47034 .05946 L
.47163 .05946 L
.47235 .05946 L
.473 .05946 L
.47555 .05945 L
.47699 .05945 L
.47831 .05945 L
.4833 .05945 L
.48758 .05945 L
.49228 .05945 L
.50175 .05944 L
.512 .05943 L
Mistroke
.52132 .05942 L
.54225 .05939 L
.58217 .05932 L
.62057 .05925 L
.64001 .05923 L
.66142 .0592 L
.68196 .05918 L
.70076 .05916 L
.72016 .05915 L
.73086 .05914 L
.7362 .05914 L
.74104 .05914 L
.74564 .05914 L
.75062 .05914 L
.75336 .05914 L
.75588 .05914 L
.75829 .05914 L
.7595 .05914 L
.76083 .05914 L
.76207 .05914 L
.76323 .05914 L
.76428 .05914 L
.76542 .05914 L
.76666 .05914 L
.76798 .05914 L
.7691 .05914 L
.77034 .05914 L
.77254 .05914 L
.77492 .05914 L
.77922 .05914 L
.78417 .05914 L
.78878 .05914 L
.79925 .05914 L
.80945 .05915 L
.82035 .05915 L
.86183 .05918 L
.9018 .05921 L
.94025 .05925 L
.97619 .05929 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03056 L
.03068 .03489 L
.03279 .03782 L
.03527 .04028 L
.03652 .04122 L
.0379 .04209 L
.04033 .0433 L
.04262 .04416 L
.04761 .0455 L
.05217 .04639 L
.06244 .04807 L
.08259 .05164 L
.09399 .05426 L
.10458 .05733 L
.11466 .06111 L
.1238 .06566 L
.12887 .06887 L
.13435 .07315 L
.13953 .07825 L
.14429 .08422 L
.14935 .09248 L
.15414 .10281 L
.15967 .11844 L
.16471 .13516 L
.16701 .14232 L
.16827 .14572 L
.16945 .14841 L
.17046 .15024 L
.17154 .15168 L
.17274 .15262 L
.17384 .15284 L
.17504 .15241 L
.17615 .15143 L
.17738 .14977 L
.17868 .14744 L
.18378 .13476 L
.19401 .10679 L
.19904 .09582 L
.20367 .08779 L
.20788 .08208 L
.21234 .07746 L
.21682 .07405 L
.21937 .07257 L
.22175 .07144 L
.22416 .07052 L
.22673 .06976 L
Mistroke
.22821 .06942 L
.22954 .06916 L
.2309 .06894 L
.23215 .06878 L
.23335 .06867 L
.2346 .06858 L
.23586 .06852 L
.23658 .0685 L
.23725 .06849 L
.23846 .06849 L
.23956 .06851 L
.24083 .06855 L
.24203 .06862 L
.24428 .06879 L
.24665 .06902 L
.25092 .06951 L
.25338 .06981 L
.25596 .07008 L
.25702 .07017 L
.25816 .07026 L
.25941 .07033 L
.26057 .07037 L
.26179 .07039 L
.26311 .07038 L
.26435 .07034 L
.2655 .07027 L
.26653 .07018 L
.26767 .07006 L
.26997 .06975 L
.27249 .0693 L
.2752 .06871 L
.28008 .06747 L
.28958 .06491 L
.29837 .0629 L
.3032 .06204 L
.30853 .06127 L
.31389 .06067 L
.31959 .0602 L
.32458 .05989 L
.32996 .05965 L
.33504 .05949 L
.3397 .05938 L
.34443 .0593 L
.34708 .05927 L
.34949 .05924 L
.35418 .05921 L
.3586 .05918 L
.36377 .05916 L
.36853 .05915 L
.37376 .05914 L
Mistroke
.3793 .05913 L
.38422 .05912 L
.38872 .05912 L
.3912 .05911 L
.39251 .05911 L
.39391 .05911 L
.39525 .05911 L
.39647 .05911 L
.39769 .05911 L
.39885 .05911 L
.39991 .05911 L
.40107 .05911 L
.40229 .05911 L
.40343 .05911 L
.40449 .05911 L
.40546 .05911 L
.40764 .05911 L
.40998 .05912 L
.41253 .05912 L
.41715 .05912 L
.42656 .05914 L
.43694 .05916 L
.45795 .0592 L
.49818 .05931 L
.53688 .0594 L
.57804 .05949 L
.61769 .05959 L
.65582 .05969 L
.6964 .05981 L
.73546 .05994 L
.77698 .06008 L
.81698 .06024 L
.85547 .06039 L
.89641 .06056 L
.93583 .06073 L
.97374 .06089 L
.97619 .0609 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03487 L
.03279 .03779 L
.03527 .04023 L
.03652 .04116 L
.0379 .04202 L
.04033 .04322 L
.04262 .04407 L
.04761 .04539 L
.05217 .04628 L
.06244 .04793 L
.08259 .05146 L
.09399 .05405 L
.10458 .05707 L
.11466 .06079 L
.1238 .06526 L
.12887 .0684 L
.13435 .07258 L
.13953 .07755 L
.14429 .08335 L
.14935 .09133 L
.15414 .10127 L
.15967 .11624 L
.16471 .13229 L
.16701 .13923 L
.16827 .14257 L
.16945 .14525 L
.17054 .14726 L
.17154 .14865 L
.17265 .14966 L
.17384 .15011 L
.17504 .1499 L
.17615 .14915 L
.17738 .14776 L
.17868 .14572 L
.18135 .14018 L
.18378 .13411 L
.19315 .10937 L
.19808 .09838 L
.20331 .08904 L
.20788 .08271 L
.2129 .07748 L
.21747 .07403 L
.22175 .07173 L
.22433 .07069 L
.22673 .06994 L
Mistroke
.22936 .06931 L
.23082 .06905 L
.23215 .06886 L
.23343 .06871 L
.2346 .06861 L
.23589 .06853 L
.23654 .06851 L
.23725 .06849 L
.23844 .06848 L
.23972 .06849 L
.24093 .06853 L
.24203 .06858 L
.24319 .06866 L
.24441 .06875 L
.2466 .06897 L
.25156 .06962 L
.25595 .07025 L
.25835 .07057 L
.26057 .07082 L
.2618 .07094 L
.26292 .07102 L
.26415 .07109 L
.26548 .07114 L
.26659 .07116 L
.26779 .07115 L
.26892 .07112 L
.26997 .07107 L
.27118 .07098 L
.27231 .07088 L
.27488 .07056 L
.27739 .07014 L
.28008 .06959 L
.29837 .06471 L
.30853 .06237 L
.31427 .06135 L
.31959 .0606 L
.32462 .06005 L
.32934 .05964 L
.33426 .05931 L
.3397 .05903 L
.34439 .05886 L
.34952 .05871 L
.35487 .05859 L
.35986 .0585 L
.37836 .05824 L
.39707 .05798 L
.41737 .05772 L
.42846 .05761 L
.43869 .05753 L
.44847 .05747 L
Mistroke
.45884 .05743 L
.46826 .0574 L
.47839 .05738 L
.49669 .05734 L
.50681 .05733 L
.51784 .05732 L
.52289 .05731 L
.52826 .05731 L
.53297 .05731 L
.53794 .0573 L
.54049 .0573 L
.5433 .0573 L
.54453 .0573 L
.54585 .0573 L
.54709 .0573 L
.54823 .0573 L
.54893 .0573 L
.54967 .0573 L
.55041 .0573 L
.55122 .0573 L
.55193 .0573 L
.55268 .0573 L
.5534 .0573 L
.55406 .0573 L
.55529 .0573 L
.55599 .0573 L
.55664 .0573 L
.55795 .0573 L
.55936 .0573 L
.56199 .0573 L
.56448 .0573 L
.56912 .05731 L
.57454 .05731 L
.57954 .05731 L
.59832 .05733 L
.61896 .05735 L
.65932 .0574 L
.69817 .05747 L
.73946 .05756 L
.77924 .05765 L
.81751 .05774 L
.85823 .05784 L
.89743 .05794 L
.93908 .05805 L
.97619 .05815 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04114 L
.0379 .04199 L
.04033 .04317 L
.04262 .04401 L
.04761 .0453 L
.05217 .04616 L
.06244 .04775 L
.08259 .05117 L
.09399 .05367 L
.10458 .05657 L
.11466 .06012 L
.1238 .06433 L
.12887 .06726 L
.13435 .0711 L
.14429 .0807 L
.15372 .09496 L
.15901 .10598 L
.16384 .11727 L
.16656 .12324 L
.168 .12593 L
.16953 .12826 L
.17018 .12903 L
.17087 .12972 L
.17163 .1303 L
.17234 .13065 L
.173 .13082 L
.17369 .13083 L
.17493 .13042 L
.17617 .12948 L
.17686 .12875 L
.1775 .12796 L
.17988 .12409 L
.18529 .11222 L
.19504 .09082 L
.20054 .08175 L
.2056 .07552 L
.21004 .07151 L
.21492 .06836 L
.21737 .06719 L
.22001 .06619 L
.2225 .06546 L
.22478 .06496 L
Mistroke
.22607 .06474 L
.22729 .06457 L
.22839 .06444 L
.22956 .06434 L
.23084 .06426 L
.23201 .06421 L
.23327 .06419 L
.23398 .06419 L
.23465 .0642 L
.23584 .06424 L
.23696 .06429 L
.23797 .06435 L
.23907 .06444 L
.24153 .06468 L
.2438 .06498 L
.24859 .06578 L
.25386 .06688 L
.25907 .06807 L
.26454 .06929 L
.26938 .07019 L
.27211 .07058 L
.27342 .07072 L
.27466 .07083 L
.27579 .07092 L
.27701 .07098 L
.27812 .07102 L
.27914 .07103 L
.28025 .07103 L
.28147 .071 L
.28274 .07095 L
.28393 .07087 L
.28522 .07077 L
.28663 .07062 L
.28919 .07028 L
.29399 .06943 L
.3048 .06691 L
.31411 .06467 L
.32416 .06266 L
.32991 .06177 L
.33518 .06112 L
.34055 .06059 L
.34555 .0602 L
.35467 .05969 L
.35949 .05949 L
.36465 .05931 L
.38478 .05874 L
.40467 .05818 L
.42624 .05759 L
.43633 .05737 L
.44702 .05717 L
Mistroke
.46619 .05689 L
.48574 .05668 L
.50405 .05652 L
.54284 .05625 L
.56399 .05613 L
.58409 .05604 L
.6223 .05591 L
.66296 .05581 L
.70211 .05574 L
.74372 .05569 L
.7838 .05565 L
.82237 .05562 L
.8634 .05559 L
.9029 .05557 L
.9409 .05556 L
.97619 .05554 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04034 L
.03652 .04129 L
.0379 .04216 L
.04033 .04337 L
.04262 .04422 L
.04761 .04554 L
.05217 .04641 L
.06244 .04803 L
.08259 .05149 L
.09399 .05403 L
.10458 .05699 L
.11466 .0606 L
.1238 .06489 L
.12887 .06788 L
.13435 .07178 L
.14429 .08156 L
.15372 .09602 L
.15901 .10714 L
.16384 .11847 L
.16656 .12443 L
.168 .1271 L
.16953 .12938 L
.17018 .13013 L
.17087 .13079 L
.17163 .13133 L
.17234 .13164 L
.173 .13177 L
.17369 .13172 L
.17493 .1312 L
.17617 .13013 L
.17686 .12932 L
.1775 .12845 L
.17988 .12423 L
.18529 .11143 L
.19504 .08865 L
.20054 .07924 L
.2056 .07293 L
.21004 .06899 L
.21256 .06728 L
.21492 .06598 L
.21736 .0649 L
.21967 .06409 L
.22234 .06338 L
Mistroke
.22478 .06291 L
.22603 .06273 L
.22738 .06257 L
.22865 .06246 L
.22982 .06238 L
.23088 .06234 L
.23205 .06231 L
.23326 .0623 L
.23439 .06231 L
.23503 .06232 L
.23572 .06234 L
.23698 .06239 L
.2382 .06246 L
.23933 .06254 L
.24462 .063 L
.24923 .06348 L
.25149 .06368 L
.25355 .06384 L
.25461 .0639 L
.25572 .06394 L
.25684 .06397 L
.25806 .06397 L
.2593 .06394 L
.26 .06391 L
.26063 .06388 L
.26186 .06379 L
.26302 .06369 L
.26543 .06339 L
.26767 .06305 L
.27277 .06209 L
.28308 .06007 L
.29199 .05867 L
.30154 .05753 L
.3117 .05664 L
.31744 .05626 L
.32276 .05598 L
.32739 .05578 L
.33251 .05562 L
.33508 .05555 L
.33785 .05549 L
.34028 .05545 L
.34287 .05541 L
.34546 .05538 L
.34782 .05536 L
.35243 .05532 L
.35501 .05531 L
.35781 .0553 L
.36289 .05528 L
.38398 .0552 L
.40344 .05509 L
Mistroke
.41377 .05504 L
.41956 .05501 L
.42487 .055 L
.42985 .05498 L
.43267 .05498 L
.43402 .05498 L
.43529 .05498 L
.4365 .05498 L
.43781 .05497 L
.439 .05497 L
.44009 .05497 L
.44127 .05497 L
.44257 .05497 L
.44323 .05497 L
.44393 .05497 L
.4452 .05497 L
.44647 .05497 L
.44765 .05498 L
.45031 .05498 L
.45516 .05498 L
.46424 .055 L
.4845 .05503 L
.49443 .05504 L
.50352 .05505 L
.5217 .05507 L
.54129 .05508 L
.58094 .05511 L
.60092 .05512 L
.61907 .05513 L
.63869 .05513 L
.64947 .05514 L
.65965 .05514 L
.66938 .05514 L
.6747 .05514 L
.67968 .05514 L
.68427 .05514 L
.68847 .05514 L
.69086 .05514 L
.69313 .05514 L
.69552 .05514 L
.69688 .05514 L
.69813 .05514 L
.69943 .05514 L
.70008 .05514 L
.70079 .05514 L
.70205 .05514 L
.70323 .05514 L
.70395 .05514 L
.70462 .05514 L
.70589 .05514 L
Mistroke
.70726 .05514 L
.70874 .05514 L
.71125 .05514 L
.71392 .05514 L
.71871 .05514 L
.72329 .05514 L
.72757 .05514 L
.73733 .05514 L
.75757 .05514 L
.77609 .05513 L
.81579 .05512 L
.85397 .05511 L
.8946 .0551 L
.93372 .05509 L
.97529 .05508 L
.97619 .05508 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04443 L
.04761 .04582 L
.05217 .04675 L
.06244 .04849 L
.08259 .05218 L
.09399 .05489 L
.10458 .05808 L
.11466 .06203 L
.1238 .06682 L
.12887 .07022 L
.13435 .07478 L
.13953 .08025 L
.14429 .08675 L
.14935 .09586 L
.15414 .10752 L
.15967 .12581 L
.16471 .1466 L
.16699 .15605 L
.16914 .16381 L
.1703 .16727 L
.17137 .16983 L
.17256 .17192 L
.17384 .17323 L
.17504 .17356 L
.17636 .17299 L
.17702 .17235 L
.17773 .17143 L
.179 .16922 L
.1815 .16323 L
.18378 .15649 L
.19337 .1249 L
.19862 .11 L
.20353 .09875 L
.20771 .09121 L
.21221 .08497 L
.21476 .08217 L
.21719 .07995 L
.22175 .07679 L
.22405 .07562 L
Mistroke
.22651 .07465 L
.22883 .07396 L
.23093 .07351 L
.23222 .0733 L
.2334 .07316 L
.23471 .07305 L
.23536 .07302 L
.23608 .07299 L
.23729 .07298 L
.23859 .07301 L
.23982 .07307 L
.24093 .07315 L
.24222 .07328 L
.24359 .07346 L
.24605 .07385 L
.25162 .07499 L
.26173 .07709 L
.27113 .07873 L
.27606 .07959 L
.27874 .08003 L
.28124 .08039 L
.28363 .08068 L
.2858 .08087 L
.28705 .08096 L
.28822 .08101 L
.28945 .08104 L
.29015 .08105 L
.29079 .08105 L
.29184 .08104 L
.29281 .08101 L
.29389 .08096 L
.29504 .08089 L
.29739 .08068 L
.29953 .08041 L
.30433 .07963 L
.30943 .07858 L
.31859 .07646 L
.32858 .07429 L
.33382 .07331 L
.33935 .07245 L
.34419 .07182 L
.34949 .07126 L
.35431 .07087 L
.35879 .07058 L
.36342 .07035 L
.36762 .0702 L
.37248 .07007 L
.37706 .06998 L
.38168 .06992 L
.38677 .06986 L
Mistroke
.39705 .06977 L
.40658 .06967 L
.4155 .06954 L
.43576 .06912 L
.45429 .06869 L
.49402 .06789 L
.53223 .06723 L
.5729 .06655 L
.61205 .06595 L
.65365 .06541 L
.69373 .06498 L
.73231 .06463 L
.77333 .06434 L
.81284 .06411 L
.85083 .06394 L
.89127 .06379 L
.9302 .06367 L
.97158 .06356 L
.97619 .06355 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04226 L
.04033 .04349 L
.04262 .04436 L
.04761 .04572 L
.05217 .04663 L
.06244 .0483 L
.08259 .05186 L
.09399 .05447 L
.10458 .05753 L
.11466 .06128 L
.1238 .06576 L
.12887 .0689 L
.13435 .07304 L
.14429 .08354 L
.16384 .12558 L
.16659 .13292 L
.16919 .13858 L
.17063 .14082 L
.17144 .14174 L
.17219 .14234 L
.17283 .14266 L
.17352 .14281 L
.17425 .14274 L
.17493 .14246 L
.1762 .14144 L
.17684 .14068 L
.17753 .13968 L
.17992 .13509 L
.18529 .12073 L
.19518 .094 L
.20072 .08303 L
.20575 .0758 L
.21044 .07103 L
.21309 .06902 L
.21554 .06753 L
.21786 .06639 L
.22003 .06554 L
.22229 .06484 L
.22478 .06426 L
.22603 .06404 L
.22736 .06385 L
Mistroke
.22862 .06371 L
.22976 .06361 L
.23041 .06356 L
.2311 .06353 L
.23186 .06349 L
.23256 .06347 L
.23381 .06346 L
.23452 .06346 L
.23519 .06347 L
.23647 .0635 L
.23768 .06355 L
.23877 .06361 L
.23996 .06369 L
.24507 .06415 L
.24974 .06463 L
.2523 .06486 L
.25355 .06495 L
.2547 .06502 L
.2557 .06506 L
.25674 .06508 L
.25779 .06508 L
.25894 .06507 L
.26011 .06502 L
.26136 .06494 L
.26253 .06484 L
.2636 .06473 L
.26847 .064 L
.27361 .06301 L
.28283 .06123 L
.29274 .05969 L
.30364 .05841 L
.31383 .05751 L
.32312 .0569 L
.32826 .05665 L
.33385 .05643 L
.33914 .05628 L
.34403 .05619 L
.34865 .05612 L
.35364 .05606 L
.35835 .05603 L
.36267 .056 L
.38326 .05588 L
.40377 .05573 L
.41376 .05567 L
.42286 .05563 L
.42739 .05561 L
.42978 .0556 L
.43232 .0556 L
.43453 .05559 L
.43697 .05559 L
Mistroke
.43918 .05558 L
.44126 .05558 L
.44247 .05558 L
.4438 .05558 L
.44505 .05558 L
.44621 .05558 L
.44736 .05558 L
.4484 .05558 L
.44961 .05558 L
.45074 .05558 L
.45198 .05558 L
.45329 .05558 L
.45564 .05558 L
.45816 .05558 L
.46093 .05559 L
.48209 .05561 L
.49211 .05562 L
.50138 .05563 L
.51096 .05563 L
.52137 .05564 L
.5403 .05564 L
.57959 .05566 L
.58919 .05566 L
.5993 .05566 L
.60866 .05566 L
.61736 .05567 L
.62661 .05567 L
.6315 .05567 L
.63672 .05567 L
.63942 .05567 L
.64084 .05567 L
.64235 .05567 L
.64366 .05567 L
.64511 .05567 L
.64643 .05567 L
.64766 .05567 L
.64894 .05567 L
.65016 .05567 L
.65125 .05567 L
.65244 .05567 L
.65374 .05567 L
.65446 .05567 L
.65511 .05567 L
.65758 .05567 L
.65992 .05567 L
.66248 .05567 L
.66764 .05567 L
.67243 .05567 L
.67688 .05567 L
.68695 .05567 L
Mistroke
.69772 .05566 L
.71902 .05566 L
.73916 .05566 L
.77756 .05564 L
.81841 .05563 L
.85775 .05562 L
.89557 .0556 L
.93585 .05558 L
.97461 .05557 L
.97619 .05557 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04577 L
.05217 .04668 L
.06244 .04837 L
.08259 .05197 L
.09399 .05461 L
.10458 .05771 L
.11466 .06151 L
.1238 .06608 L
.12887 .06929 L
.13435 .07353 L
.14429 .08439 L
.16384 .12956 L
.16659 .13785 L
.16919 .14444 L
.17063 .14716 L
.17144 .14832 L
.17219 .14914 L
.17283 .14963 L
.17352 .14994 L
.17425 .15002 L
.17493 .14987 L
.1762 .14902 L
.17684 .14833 L
.17753 .14738 L
.17992 .14284 L
.1827 .13566 L
.18529 .12797 L
.19 .11355 L
.19511 .0995 L
.19962 .08942 L
.20438 .08121 L
.20703 .07764 L
.20994 .07442 L
.21241 .07219 L
.21507 .07025 L
.21769 .06873 L
.22009 .06763 L
.22249 .06676 L
Mistroke
.22478 .06614 L
.22603 .06587 L
.22738 .06562 L
.22857 .06545 L
.22982 .06531 L
.23096 .06521 L
.2322 .06513 L
.23334 .06509 L
.23439 .06507 L
.23503 .06507 L
.23572 .06508 L
.23698 .06511 L
.2382 .06516 L
.23933 .06522 L
.2419 .06543 L
.24462 .06571 L
.24884 .06621 L
.25338 .06671 L
.25464 .06683 L
.25598 .06692 L
.25711 .06699 L
.25836 .06703 L
.25953 .06705 L
.26078 .06705 L
.26195 .06703 L
.26302 .06698 L
.26422 .06692 L
.26534 .06684 L
.26789 .06662 L
.27303 .06604 L
.28225 .06484 L
.30306 .06191 L
.31208 .06067 L
.32167 .05954 L
.32667 .05906 L
.33219 .05862 L
.34193 .05805 L
.3472 .05784 L
.35287 .05766 L
.36315 .05742 L
.37364 .05725 L
.38326 .05711 L
.40377 .05686 L
.41376 .05675 L
.42286 .05667 L
.43232 .05661 L
.44126 .05656 L
.45069 .05653 L
.45602 .05651 L
.46093 .0565 L
Mistroke
.47061 .05649 L
.47967 .05647 L
.5003 .05645 L
.53909 .0564 L
.58034 .05637 L
.62007 .05633 L
.65828 .0563 L
.69895 .05627 L
.73809 .05624 L
.7797 .05621 L
.81978 .05618 L
.85835 .05616 L
.89938 .05613 L
.93888 .05611 L
.97619 .05609 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04577 L
.05217 .04669 L
.06244 .04838 L
.08259 .05199 L
.09399 .05463 L
.10458 .05774 L
.11466 .06155 L
.1238 .06613 L
.12887 .06935 L
.13435 .07362 L
.14429 .08456 L
.16384 .13035 L
.16659 .1388 L
.16919 .14554 L
.17063 .14832 L
.17144 .14951 L
.17219 .15035 L
.17283 .15085 L
.17352 .15118 L
.17425 .15128 L
.17493 .15113 L
.1762 .15029 L
.17684 .1496 L
.17753 .14865 L
.17992 .14409 L
.1827 .13687 L
.18529 .12912 L
.19 .11457 L
.19511 .10036 L
.19962 .09015 L
.20438 .08181 L
.20703 .07818 L
.20994 .0749 L
.21241 .07263 L
.21507 .07065 L
.21769 .0691 L
.22009 .06797 L
.22249 .06708 L
Mistroke
.22478 .06644 L
.22603 .06616 L
.22738 .06591 L
.22857 .06573 L
.22982 .06559 L
.23096 .06548 L
.2322 .0654 L
.23334 .06536 L
.23439 .06534 L
.23503 .06533 L
.23572 .06534 L
.23698 .06537 L
.2382 .06542 L
.23933 .06548 L
.2419 .06568 L
.24462 .06597 L
.24931 .06654 L
.25186 .06684 L
.25423 .06709 L
.25626 .06725 L
.2574 .06731 L
.25843 .06735 L
.25957 .06738 L
.2608 .06739 L
.26196 .06737 L
.26302 .06734 L
.26415 .06729 L
.2652 .06723 L
.26759 .06705 L
.27242 .06656 L
.28253 .06533 L
.30083 .0628 L
.31944 .06026 L
.32454 .05971 L
.32996 .05922 L
.3397 .05856 L
.3449 .0583 L
.34978 .05811 L
.35559 .05794 L
.36092 .05781 L
.37059 .05762 L
.38103 .05746 L
.40153 .05718 L
.41153 .05707 L
.42062 .05698 L
.42945 .05691 L
.43903 .05685 L
.44914 .0568 L
.4587 .05677 L
.46815 .05674 L
Mistroke
.47855 .05672 L
.49959 .05668 L
.53989 .05661 L
.57869 .05655 L
.61993 .0565 L
.65966 .05645 L
.69787 .05641 L
.73854 .05637 L
.77769 .05633 L
.81929 .0563 L
.85938 .05626 L
.89795 .05623 L
.93897 .05621 L
.97619 .05618 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04226 L
.04033 .04349 L
.04262 .04437 L
.04761 .04574 L
.05217 .04665 L
.06244 .04835 L
.08259 .05198 L
.09399 .05464 L
.10458 .05776 L
.11466 .06161 L
.1238 .06625 L
.12887 .06952 L
.13435 .07387 L
.13953 .07906 L
.14429 .08513 L
.14935 .09351 L
.15414 .10395 L
.15967 .11966 L
.16471 .13634 L
.16701 .14341 L
.16827 .14674 L
.16945 .14935 L
.17046 .1511 L
.17154 .15245 L
.17274 .15327 L
.17384 .15337 L
.17504 .15279 L
.17615 .15165 L
.17738 .14982 L
.17868 .14727 L
.18378 .13369 L
.18869 .11892 L
.19401 .10436 L
.1987 .0938 L
.20367 .08508 L
.20815 .07916 L
.21052 .07667 L
.21308 .07442 L
.21542 .07271 L
.21756 .0714 L
.22175 .06945 L
Mistroke
.22426 .06862 L
.22653 .06805 L
.22779 .0678 L
.22915 .06758 L
.23033 .06742 L
.23162 .06729 L
.23282 .06721 L
.23394 .06715 L
.23512 .06712 L
.23639 .06711 L
.23757 .06713 L
.23868 .06717 L
.23968 .06722 L
.24077 .06729 L
.25063 .06833 L
.25334 .06863 L
.25476 .06876 L
.25553 .06882 L
.25625 .06887 L
.25756 .06893 L
.25825 .06896 L
.25899 .06897 L
.26031 .06897 L
.26151 .06894 L
.26275 .06888 L
.26406 .06878 L
.26518 .06867 L
.26641 .06853 L
.27171 .06771 L
.28132 .0659 L
.28656 .06502 L
.29219 .06425 L
.30234 .0632 L
.3125 .06245 L
.32356 .06182 L
.32862 .0616 L
.334 .06139 L
.33904 .06124 L
.34367 .06113 L
.34823 .06104 L
.35303 .06098 L
.35552 .06095 L
.35784 .06093 L
.36039 .06091 L
.36181 .0609 L
.36312 .0609 L
.36548 .06089 L
.36672 .06089 L
.36804 .06089 L
.36918 .06088 L
Mistroke
.37025 .06088 L
.37143 .06088 L
.37269 .06088 L
.3738 .06088 L
.37502 .06089 L
.37617 .06089 L
.37723 .06089 L
.38139 .0609 L
.4002 .06096 L
.40535 .06098 L
.4108 .06099 L
.41304 .061 L
.41544 .061 L
.41682 .061 L
.41808 .06101 L
.41925 .06101 L
.42054 .06101 L
.42187 .06101 L
.4226 .06101 L
.42328 .06101 L
.4245 .06101 L
.42581 .06101 L
.42651 .06101 L
.42727 .06101 L
.42807 .06101 L
.4288 .06101 L
.43013 .06101 L
.43155 .06101 L
.43436 .061 L
.43701 .061 L
.44197 .06099 L
.46214 .06095 L
.50063 .06084 L
.54157 .0607 L
.58099 .06053 L
.6189 .06038 L
.65926 .06024 L
.6981 .06013 L
.71786 .06009 L
.7394 .06005 L
.77918 .05999 L
.7989 .05997 L
.8199 .05995 L
.83022 .05995 L
.84136 .05994 L
.85189 .05994 L
.86155 .05993 L
.86627 .05993 L
.87132 .05993 L
.87569 .05993 L
Mistroke
.88043 .05993 L
.88332 .05993 L
.88599 .05993 L
.88855 .05993 L
.88985 .05993 L
.89125 .05993 L
.89252 .05993 L
.89368 .05993 L
.89484 .05993 L
.89594 .05993 L
.89722 .05993 L
.89841 .05993 L
.89972 .05993 L
.90045 .05993 L
.90111 .05993 L
.90343 .05993 L
.90598 .05993 L
.90864 .05993 L
.91113 .05993 L
.92035 .05993 L
.9256 .05993 L
.93039 .05993 L
.94116 .05993 L
.97619 .05994 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .03789 L
.03527 .04037 L
.03652 .04132 L
.0379 .0422 L
.04033 .04342 L
.04262 .04429 L
.04761 .04565 L
.05217 .04655 L
.06244 .04825 L
.08259 .05186 L
.09399 .05452 L
.10458 .05763 L
.11466 .06146 L
.1238 .06608 L
.12887 .06935 L
.13435 .0737 L
.13953 .07889 L
.14429 .08499 L
.14935 .09344 L
.15414 .10402 L
.15967 .12006 L
.16471 .13723 L
.16701 .14456 L
.16827 .14802 L
.16945 .15075 L
.17046 .15259 L
.17154 .15402 L
.17274 .15491 L
.17384 .15507 L
.17504 .15454 L
.17615 .15345 L
.17738 .15165 L
.17868 .14915 L
.18378 .13576 L
.19401 .10675 L
.19904 .09555 L
.20367 .08742 L
.20788 .0817 L
.21234 .07711 L
.21682 .07375 L
.21937 .07231 L
.22175 .07122 L
.22433 .07029 L
.22673 .06962 L
Mistroke
.22936 .0691 L
.23082 .06888 L
.23215 .06873 L
.23343 .06863 L
.2346 .06856 L
.23589 .06852 L
.23654 .06851 L
.23725 .06851 L
.23844 .06852 L
.23972 .06856 L
.24093 .06862 L
.24203 .06869 L
.25103 .06965 L
.25321 .0699 L
.25557 .07012 L
.25692 .07022 L
.25815 .07029 L
.25933 .07033 L
.26057 .07034 L
.26176 .07032 L
.26303 .07027 L
.26423 .07019 L
.26532 .07009 L
.26799 .06975 L
.27051 .06932 L
.27969 .06727 L
.28979 .06506 L
.29488 .06418 L
.30047 .06343 L
.30547 .06291 L
.31084 .06248 L
.3159 .06217 L
.32052 .06195 L
.32506 .06178 L
.33 .06163 L
.33467 .06153 L
.33899 .06146 L
.3414 .06143 L
.34361 .0614 L
.34604 .06139 L
.34728 .06138 L
.3486 .06137 L
.34977 .06137 L
.35083 .06136 L
.3519 .06136 L
.35291 .06136 L
.35409 .06136 L
.35517 .06136 L
.35637 .06136 L
.35763 .06136 L
Mistroke
.3589 .06136 L
.36007 .06137 L
.36269 .06138 L
.36512 .06139 L
.36743 .06141 L
.37822 .0615 L
.39827 .06175 L
.41643 .06197 L
.43612 .06214 L
.44693 .0622 L
.4571 .06225 L
.49567 .06241 L
.51562 .06247 L
.5258 .0625 L
.53669 .06252 L
.55635 .06255 L
.57469 .06257 L
.61607 .06261 L
.65593 .06266 L
.69428 .06272 L
.73508 .06281 L
.77437 .06292 L
.81214 .06304 L
.85236 .06319 L
.89107 .06334 L
.93223 .06351 L
.97187 .06368 L
.97619 .0637 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04035 L
.03652 .0413 L
.0379 .04217 L
.04033 .04339 L
.04262 .04425 L
.04761 .04558 L
.05217 .04647 L
.06244 .04812 L
.08259 .05165 L
.09399 .05424 L
.10458 .05727 L
.11466 .06098 L
.1238 .06541 L
.12887 .06852 L
.13435 .07263 L
.14429 .08309 L
.16384 .12607 L
.16659 .1339 L
.16919 .14015 L
.17063 .14275 L
.17144 .14387 L
.17219 .14468 L
.17283 .14517 L
.17352 .14551 L
.17425 .14564 L
.17493 .14556 L
.1762 .1449 L
.17684 .14433 L
.17753 .14353 L
.17877 .14173 L
.17992 .13966 L
.18529 .12679 L
.19511 .10166 L
.19994 .09182 L
.20438 .08459 L
.20951 .07826 L
.21216 .07572 L
.21507 .07342 L
.21979 .07062 L
.22237 .06951 L
.22478 .06868 L
.22736 .06802 L
.22976 .06757 L
Mistroke
.23114 .06739 L
.23239 .06726 L
.23308 .0672 L
.23383 .06715 L
.23454 .06712 L
.23519 .06709 L
.23637 .06707 L
.23748 .06708 L
.23869 .06711 L
.23999 .06717 L
.24065 .06721 L
.24136 .06726 L
.24265 .06738 L
.24507 .06766 L
.24974 .0684 L
.2547 .06941 L
.2636 .07138 L
.26599 .07185 L
.26851 .07228 L
.27068 .07259 L
.273 .07284 L
.27431 .07294 L
.2755 .073 L
.2767 .07304 L
.27783 .07305 L
.27915 .07304 L
.28037 .073 L
.281 .07296 L
.2817 .07292 L
.28311 .0728 L
.2855 .07252 L
.28768 .07219 L
.29257 .0712 L
.30141 .06889 L
.31143 .06614 L
.32208 .06371 L
.33117 .06222 L
.33635 .06159 L
.34122 .06113 L
.3459 .06077 L
.35083 .06047 L
.35964 .06008 L
.36913 .05977 L
.37952 .05948 L
.40074 .05888 L
.42005 .05835 L
.42967 .05812 L
.4401 .0579 L
.45906 .05761 L
.47891 .05739 L
Mistroke
.49994 .05721 L
.5378 .05695 L
.55722 .05685 L
.57811 .05676 L
.59783 .0567 L
.61935 .05664 L
.65908 .05656 L
.67877 .05653 L
.69975 .0565 L
.71974 .05648 L
.74135 .05646 L
.78143 .05644 L
.80139 .05643 L
.82246 .05642 L
.86045 .05641 L
.87997 .05641 L
.90089 .0564 L
.92072 .0564 L
.94227 .0564 L
.97619 .05639 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03774 L
.03527 .04015 L
.03652 .04106 L
.0379 .0419 L
.04033 .04305 L
.04262 .04385 L
.04517 .04455 L
.04761 .04509 L
.05217 .0459 L
.06244 .0474 L
.07302 .049 L
.08429 .05098 L
.09474 .05321 L
.10458 .05578 L
.1142 .05893 L
.12461 .06337 L
.13407 .06887 L
.14277 .07588 L
.15263 .08731 L
.15805 .09549 L
.16319 .10372 L
.16551 .10703 L
.16678 .10857 L
.16797 .10978 L
.16925 .11078 L
.16994 .11116 L
.17067 .11144 L
.17197 .11161 L
.17317 .11138 L
.17426 .11085 L
.17528 .11009 L
.1764 .10898 L
.1776 .10752 L
.18226 .09988 L
.18717 .09063 L
.19249 .08146 L
.19719 .07489 L
.20215 .06956 L
.20663 .06602 L
.20901 .06457 L
.21156 .06328 L
.2139 .06231 L
.21604 .0616 L
.2182 .06102 L
Mistroke
.22023 .06058 L
.22144 .06037 L
.22274 .06018 L
.22501 .05993 L
.2263 .05983 L
.22701 .05979 L
.22767 .05975 L
.22883 .05971 L
.2301 .05969 L
.23129 .05968 L
.23242 .05969 L
.23343 .05972 L
.23452 .05976 L
.23572 .05981 L
.23698 .05988 L
.23926 .06004 L
.24924 .06095 L
.25198 .06117 L
.25335 .06126 L
.25414 .06129 L
.25485 .06132 L
.25614 .06135 L
.25685 .06136 L
.25752 .06136 L
.25871 .06133 L
.25999 .06128 L
.26121 .0612 L
.26235 .06109 L
.26493 .06078 L
.26745 .06037 L
.27015 .05986 L
.2795 .05787 L
.28411 .05698 L
.289 .05617 L
.2978 .05507 L
.30262 .05464 L
.30795 .05428 L
.31365 .05398 L
.31626 .05388 L
.31901 .05379 L
.32142 .05372 L
.32406 .05366 L
.32648 .05361 L
.32869 .05358 L
.3313 .05355 L
.33273 .05353 L
.33409 .05352 L
.33526 .05352 L
.33651 .05351 L
.33715 .05351 L
Mistroke
.33787 .05351 L
.33912 .0535 L
.34041 .0535 L
.34161 .0535 L
.34293 .0535 L
.34366 .0535 L
.34433 .05351 L
.34555 .05351 L
.34687 .05351 L
.34927 .05352 L
.35855 .05357 L
.36384 .0536 L
.36673 .05361 L
.36943 .05363 L
.37192 .05363 L
.3742 .05364 L
.37672 .05364 L
.37812 .05365 L
.37943 .05365 L
.38057 .05365 L
.3818 .05365 L
.38296 .05365 L
.38403 .05365 L
.38521 .05365 L
.3865 .05365 L
.38784 .05365 L
.3891 .05364 L
.39406 .05363 L
.39936 .05362 L
.40895 .0536 L
.41315 .05359 L
.41778 .05358 L
.41902 .05358 L
.42036 .05358 L
.42151 .05358 L
.42276 .05358 L
.4235 .05358 L
.42418 .05358 L
.42483 .05358 L
.42552 .05357 L
.42684 .05357 L
.42803 .05357 L
.42873 .05358 L
.42947 .05358 L
.43079 .05358 L
.43221 .05358 L
.43376 .05358 L
.43655 .05358 L
.43914 .05359 L
.44424 .0536 L
Mistroke
.44888 .05361 L
.4593 .05364 L
.48005 .05371 L
.49922 .05376 L
.51785 .0538 L
.53762 .05383 L
.57544 .05389 L
.59647 .05392 L
.61572 .05394 L
.65448 .05397 L
.67345 .05399 L
.69417 .054 L
.71384 .054 L
.73481 .05401 L
.74508 .05401 L
.75621 .05401 L
.76671 .05402 L
.77638 .05402 L
.78107 .05402 L
.7861 .05402 L
.79046 .05402 L
.79519 .05402 L
.79807 .05402 L
.80074 .05402 L
.80329 .05402 L
.80459 .05402 L
.806 .05402 L
.80726 .05402 L
.80841 .05402 L
.80952 .05402 L
.81068 .05402 L
.81196 .05402 L
.81315 .05402 L
.81445 .05402 L
.81519 .05402 L
.81585 .05402 L
.81816 .05402 L
.8207 .05402 L
.82335 .05402 L
.82583 .05402 L
.83503 .05402 L
.84026 .05402 L
.84505 .05402 L
.85582 .05402 L
.89557 .05401 L
.9338 .05401 L
.97449 .054 L
.97619 .054 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04669 L
.06244 .04842 L
.08259 .05208 L
.09399 .05478 L
.10458 .05795 L
.11466 .06186 L
.1238 .0666 L
.12887 .06996 L
.13435 .07445 L
.13953 .07984 L
.14429 .0862 L
.14935 .09509 L
.15414 .10636 L
.15967 .12377 L
.16471 .14295 L
.16701 .15137 L
.16827 .15544 L
.16945 .15871 L
.17054 .16115 L
.17154 .16284 L
.17265 .16405 L
.17384 .16458 L
.17504 .1643 L
.17615 .16336 L
.17738 .16165 L
.17868 .15916 L
.18135 .15246 L
.18378 .1452 L
.19315 .11615 L
.19808 .10351 L
.20331 .09293 L
.20788 .08586 L
.2129 .08011 L
.21747 .07637 L
.22175 .0739 L
.22433 .07281 L
.22673 .07203 L
Mistroke
.22936 .0714 L
.23082 .07114 L
.23215 .07095 L
.23343 .07082 L
.2346 .07073 L
.23589 .07067 L
.23654 .07065 L
.23725 .07064 L
.23844 .07065 L
.23972 .07068 L
.24093 .07074 L
.24203 .07081 L
.24441 .07102 L
.2466 .07127 L
.25156 .07191 L
.25382 .07219 L
.25593 .07241 L
.257 .0725 L
.25814 .07257 L
.25941 .07263 L
.26057 .07265 L
.26186 .07265 L
.26306 .07261 L
.26415 .07256 L
.26533 .07249 L
.26797 .07225 L
.2704 .07196 L
.27953 .07071 L
.28474 .07011 L
.2896 .06967 L
.29468 .06932 L
.30025 .069 L
.31886 .06803 L
.32868 .06754 L
.33407 .06731 L
.33912 .06714 L
.34436 .06701 L
.34714 .06696 L
.34857 .06694 L
.35014 .06692 L
.35148 .06691 L
.35273 .0669 L
.35405 .06689 L
.35479 .06689 L
.35546 .06689 L
.35666 .06689 L
.35797 .0669 L
.3592 .0669 L
.36034 .06691 L
.36274 .06693 L
Mistroke
.36499 .06696 L
.37011 .06705 L
.37509 .06716 L
.38045 .06731 L
.40018 .06789 L
.4106 .06815 L
.41631 .06827 L
.4217 .06835 L
.42689 .06842 L
.43251 .06848 L
.43761 .06852 L
.4423 .06854 L
.44674 .06856 L
.45161 .06858 L
.45669 .06859 L
.46143 .0686 L
.47189 .06862 L
.47703 .06862 L
.48179 .06863 L
.48602 .06863 L
.49069 .06864 L
.49311 .06864 L
.49538 .06864 L
.49663 .06864 L
.49777 .06864 L
.49903 .06864 L
.49966 .06864 L
.50035 .06864 L
.50168 .06864 L
.50289 .06864 L
.50353 .06864 L
.50423 .06864 L
.50565 .06864 L
.50689 .06864 L
.50823 .06864 L
.51064 .06863 L
.51314 .06863 L
.51552 .06863 L
.51998 .06862 L
.52519 .06861 L
.53001 .0686 L
.54094 .06857 L
.58014 .0684 L
.62179 .06822 L
.64271 .06814 L
.66193 .06808 L
.68192 .06802 L
.70055 .06798 L
.70967 .06797 L
.71943 .06796 L
Mistroke
.725 .06795 L
.73026 .06794 L
.73495 .06794 L
.74011 .06794 L
.74252 .06794 L
.74511 .06794 L
.74736 .06794 L
.7498 .06793 L
.75123 .06793 L
.75255 .06793 L
.75382 .06793 L
.75453 .06793 L
.75517 .06793 L
.75638 .06793 L
.75769 .06793 L
.75894 .06793 L
.76008 .06793 L
.76114 .06793 L
.76229 .06793 L
.76435 .06793 L
.7668 .06794 L
.76904 .06794 L
.77391 .06794 L
.77851 .06794 L
.78816 .06795 L
.79841 .06796 L
.81683 .06798 L
.83629 .06802 L
.85457 .06806 L
.89325 .06816 L
.93437 .06828 L
.97398 .06841 L
.97619 .06841 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .0379 L
.03527 .04038 L
.03652 .04134 L
.0379 .04222 L
.04033 .04345 L
.04262 .04432 L
.04761 .04569 L
.05217 .0466 L
.06244 .04831 L
.08259 .05195 L
.09399 .05462 L
.10458 .05776 L
.11466 .06163 L
.1238 .06631 L
.12887 .06962 L
.13435 .07405 L
.13953 .07935 L
.14429 .08561 L
.14935 .09432 L
.15414 .10532 L
.15967 .1222 L
.16471 .14057 L
.16701 .14853 L
.16827 .15232 L
.16945 .15535 L
.17046 .15741 L
.17154 .15907 L
.17274 .16016 L
.17384 .16047 L
.17504 .16007 L
.17615 .15906 L
.17738 .15732 L
.17868 .15485 L
.18378 .14132 L
.19401 .1114 L
.19904 .09964 L
.20367 .09101 L
.20788 .08488 L
.21234 .0799 L
.21682 .07622 L
.21937 .07462 L
.22175 .0734 L
.22416 .07241 L
.22673 .07158 L
Mistroke
.22821 .0712 L
.22954 .07092 L
.2309 .07068 L
.23215 .0705 L
.23335 .07037 L
.2346 .07027 L
.23586 .0702 L
.23658 .07017 L
.23725 .07016 L
.23846 .07015 L
.23956 .07017 L
.24083 .07021 L
.24203 .07027 L
.24428 .07044 L
.24665 .07067 L
.25092 .07117 L
.25313 .07143 L
.25551 .07167 L
.25687 .07179 L
.25812 .07187 L
.25932 .07192 L
.26057 .07194 L
.26181 .07193 L
.26251 .07192 L
.26315 .07189 L
.26434 .07182 L
.26559 .07171 L
.26776 .07144 L
.27014 .07105 L
.27542 .06989 L
.28035 .06861 L
.28915 .06639 L
.29873 .06454 L
.30415 .0638 L
.30917 .06327 L
.31396 .06288 L
.31906 .06257 L
.3236 .06235 L
.32787 .0622 L
.33256 .06207 L
.335 .06201 L
.33761 .06196 L
.3402 .06192 L
.34256 .0619 L
.34493 .06187 L
.34716 .06186 L
.34843 .06185 L
.34977 .06184 L
.35092 .06184 L
.35218 .06184 L
Mistroke
.35289 .06183 L
.35354 .06183 L
.35428 .06183 L
.35499 .06183 L
.35625 .06183 L
.35696 .06183 L
.35763 .06183 L
.35895 .06184 L
.36038 .06184 L
.36298 .06185 L
.36551 .06187 L
.36784 .06188 L
.37872 .06199 L
.39756 .06225 L
.41822 .06254 L
.43775 .06275 L
.45867 .06292 L
.50005 .0632 L
.53991 .06341 L
.57826 .06357 L
.61907 .06372 L
.65835 .06388 L
.69612 .06404 L
.73635 .06423 L
.77505 .06443 L
.81621 .06467 L
.85586 .06491 L
.89399 .06515 L
.93457 .06541 L
.97363 .06567 L
.97619 .06568 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04674 L
.06244 .04847 L
.08259 .05216 L
.09399 .05487 L
.10458 .05805 L
.11466 .062 L
.1238 .06677 L
.12887 .07016 L
.13435 .0747 L
.13953 .08016 L
.14429 .08662 L
.14935 .09568 L
.15414 .10722 L
.15967 .12523 L
.16471 .14543 L
.16701 .15449 L
.16827 .15894 L
.16945 .16259 L
.17054 .16537 L
.17154 .16736 L
.17265 .16891 L
.17384 .16976 L
.17504 .16976 L
.17615 .16905 L
.17738 .16755 L
.17868 .16522 L
.18135 .15867 L
.18378 .15136 L
.19315 .12111 L
.19808 .10759 L
.20331 .09614 L
.20788 .08845 L
.2129 .08214 L
.21747 .07804 L
.22175 .07533 L
.22433 .07413 L
.22673 .07327 L
Mistroke
.22936 .07258 L
.23082 .07229 L
.23215 .07209 L
.23343 .07194 L
.2346 .07184 L
.23589 .07178 L
.23654 .07176 L
.23725 .07175 L
.23844 .07176 L
.23972 .0718 L
.24093 .07187 L
.24203 .07196 L
.24441 .0722 L
.2466 .07249 L
.25156 .07327 L
.25385 .07363 L
.25626 .07396 L
.25832 .07419 L
.26057 .07437 L
.26174 .07444 L
.26298 .07449 L
.26415 .07453 L
.26522 .07455 L
.26646 .07456 L
.26715 .07456 L
.2678 .07456 L
.26898 .07455 L
.27022 .07454 L
.2723 .07452 L
.27345 .07451 L
.27454 .07451 L
.27582 .0745 L
.27699 .0745 L
.27808 .07451 L
.27927 .07451 L
.28054 .07453 L
.28174 .07454 L
.28446 .07457 L
.28575 .07459 L
.28712 .0746 L
.28783 .0746 L
.28861 .07461 L
.28932 .07461 L
.28998 .07461 L
.29127 .07461 L
.29249 .0746 L
.29358 .07458 L
.29477 .07456 L
.29606 .07453 L
.29743 .07448 L
Mistroke
.29989 .07437 L
.30241 .07423 L
.30481 .07405 L
.30931 .07366 L
.31944 .07256 L
.32904 .07151 L
.33775 .07071 L
.34269 .07036 L
.34734 .07009 L
.35225 .06989 L
.35502 .06981 L
.35757 .06975 L
.35863 .06973 L
.35977 .06971 L
.36076 .0697 L
.36183 .06969 L
.36309 .06968 L
.36428 .06967 L
.36544 .06967 L
.36651 .06967 L
.36764 .06967 L
.36869 .06967 L
.36985 .06968 L
.37109 .06969 L
.37363 .06971 L
.37596 .06974 L
.38589 .06992 L
.3965 .07013 L
.40165 .07022 L
.40651 .07028 L
.41087 .07033 L
.41333 .07035 L
.4156 .07037 L
.4178 .07038 L
.41904 .07038 L
.42016 .07038 L
.42121 .07039 L
.42235 .07039 L
.42343 .07039 L
.42443 .07039 L
.4257 .07039 L
.42689 .07038 L
.42797 .07038 L
.42913 .07038 L
.43173 .07037 L
.43413 .07036 L
.43868 .07033 L
.44367 .07029 L
.45373 .0702 L
.49423 .06981 L
Mistroke
.53321 .0694 L
.57464 .0689 L
.61456 .06843 L
.65296 .06803 L
.69381 .06769 L
.73315 .06742 L
.77098 .06724 L
.792 .06715 L
.81125 .06709 L
.85001 .067 L
.86899 .06697 L
.88971 .06694 L
.90937 .06692 L
.93034 .06691 L
.94062 .0669 L
.95174 .0669 L
.96224 .06689 L
.97191 .06689 L
.97619 .06689 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .03789 L
.03527 .04036 L
.03652 .04132 L
.0379 .0422 L
.04033 .04342 L
.04262 .04429 L
.04761 .04565 L
.05217 .04656 L
.06244 .04825 L
.08259 .05187 L
.09399 .05453 L
.10458 .05764 L
.11466 .06148 L
.1238 .06612 L
.12887 .0694 L
.13435 .07377 L
.13953 .079 L
.14429 .08516 L
.14935 .09374 L
.15414 .10458 L
.15967 .12135 L
.16471 .14007 L
.16701 .14854 L
.16945 .15624 L
.17046 .15877 L
.17154 .16098 L
.17273 .16271 L
.17384 .16366 L
.17505 .16394 L
.17637 .16341 L
.17703 .16283 L
.17774 .16201 L
.17902 .16003 L
.18151 .15475 L
.18378 .14884 L
.19337 .12115 L
.19862 .10798 L
.20353 .09786 L
.20806 .09041 L
.21221 .08502 L
.21681 .08042 L
.21937 .0784 L
.22175 .07683 L
.22646 .07447 L
Mistroke
.22894 .07356 L
.23159 .07283 L
.2328 .07257 L
.23412 .07233 L
.23527 .07216 L
.23649 .07201 L
.2376 .07191 L
.23881 .07183 L
.23991 .07179 L
.24093 .07177 L
.24223 .07178 L
.24296 .07179 L
.24363 .07182 L
.24487 .07188 L
.24619 .07197 L
.24847 .07218 L
.25098 .07248 L
.25622 .07323 L
.25908 .07364 L
.26173 .07396 L
.26407 .07417 L
.26538 .07426 L
.26657 .07431 L
.26787 .07434 L
.26861 .07434 L
.26929 .07433 L
.27053 .07429 L
.27185 .07422 L
.27295 .07413 L
.27413 .07401 L
.27626 .07372 L
.2788 .07326 L
.28112 .07275 L
.30199 .06645 L
.31122 .06406 L
.32105 .06224 L
.32617 .06156 L
.33182 .06098 L
.33697 .06058 L
.3418 .0603 L
.34648 .06009 L
.35161 .05991 L
.35697 .05977 L
.36196 .05966 L
.38045 .05935 L
.39917 .05905 L
.41947 .05878 L
.43055 .05867 L
.43543 .05863 L
.44079 .05859 L
Mistroke
.45057 .05854 L
.45592 .05852 L
.46093 .05851 L
.4659 .0585 L
.47132 .05849 L
.4738 .05848 L
.47644 .05848 L
.48119 .05848 L
.4836 .05848 L
.4862 .05848 L
.48739 .05848 L
.48866 .05847 L
.48975 .05847 L
.49091 .05847 L
.49205 .05847 L
.49309 .05847 L
.49413 .05847 L
.49512 .05847 L
.49626 .05847 L
.49732 .05847 L
.49849 .05847 L
.49972 .05847 L
.50211 .05848 L
.50462 .05848 L
.5091 .05848 L
.51393 .05848 L
.51921 .05849 L
.52868 .0585 L
.53749 .05851 L
.55797 .05855 L
.57656 .05859 L
.61656 .05871 L
.65505 .05885 L
.69599 .059 L
.73541 .05915 L
.77332 .0593 L
.81368 .05947 L
.85252 .05963 L
.89382 .0598 L
.9336 .05996 L
.97186 .06012 L
.97619 .06014 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .0379 L
.03527 .04038 L
.03652 .04134 L
.0379 .04222 L
.04033 .04345 L
.04262 .04432 L
.04761 .04568 L
.05217 .04659 L
.06244 .04829 L
.08259 .0519 L
.09399 .05455 L
.10458 .05765 L
.11466 .06148 L
.1238 .06609 L
.12887 .06934 L
.13435 .07368 L
.13953 .07884 L
.14429 .08491 L
.14935 .0933 L
.15414 .10385 L
.15967 .12005 L
.16471 .13806 L
.16914 .1529 L
.17021 .1557 L
.17137 .15818 L
.17265 .16017 L
.17384 .1613 L
.17515 .16169 L
.17581 .16156 L
.17653 .16119 L
.17781 .15996 L
.179 .15824 L
.18131 .15362 L
.18378 .14736 L
.19263 .12177 L
.202 .09922 L
.20689 .09059 L
.21227 .08338 L
.21717 .07861 L
.22175 .07539 L
.22451 .07393 L
.22712 .07284 L
.22948 .07208 L
.23204 .07145 L
Mistroke
.2335 .07118 L
.23482 .07099 L
.23555 .0709 L
.23634 .07082 L
.23702 .07076 L
.23777 .07071 L
.23847 .07067 L
.23912 .07065 L
.23981 .07064 L
.24055 .07063 L
.24123 .07063 L
.24188 .07065 L
.24309 .07069 L
.24425 .07076 L
.24553 .07086 L
.24811 .07113 L
.25275 .07182 L
.25787 .07275 L
.26325 .0737 L
.26559 .07404 L
.26808 .07432 L
.26952 .07444 L
.27082 .07451 L
.27213 .07456 L
.27336 .07457 L
.27449 .07456 L
.27568 .07451 L
.2767 .07445 L
.27781 .07436 L
.27902 .07424 L
.2803 .07408 L
.28263 .0737 L
.28823 .07244 L
.29354 .07092 L
.3035 .06778 L
.31314 .06508 L
.31842 .06387 L
.32339 .06293 L
.33213 .06169 L
.33678 .06121 L
.3418 .06081 L
.34675 .0605 L
.35135 .06027 L
.36181 .0599 L
.38291 .05938 L
.40162 .05892 L
.42192 .05846 L
.43301 .05826 L
.44324 .05811 L
.45364 .05799 L
Mistroke
.46338 .0579 L
.48212 .05777 L
.50275 .05766 L
.52131 .05759 L
.54155 .05752 L
.55252 .05749 L
.5627 .05747 L
.57235 .05745 L
.58279 .05744 L
.59337 .05743 L
.60333 .05742 L
.60804 .05742 L
.61302 .05741 L
.6176 .05741 L
.62194 .05741 L
.6269 .05741 L
.63143 .05741 L
.63396 .05741 L
.6363 .05741 L
.63752 .05741 L
.63887 .05741 L
.63954 .05741 L
.64027 .05741 L
.64159 .05741 L
.64275 .05741 L
.64382 .05741 L
.645 .05741 L
.64626 .05741 L
.64758 .05741 L
.64883 .05741 L
.65116 .05741 L
.65537 .05741 L
.65993 .05741 L
.66941 .05741 L
.67982 .05742 L
.70087 .05743 L
.74123 .05746 L
.78007 .0575 L
.82137 .05754 L
.86115 .05759 L
.89942 .05763 L
.94013 .05768 L
.97619 .05773 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04196 L
.04033 .04313 L
.04262 .04396 L
.04761 .04522 L
.05217 .04606 L
.06244 .04762 L
.08259 .05096 L
.09399 .05341 L
.10458 .05624 L
.11466 .05969 L
.1238 .06374 L
.12887 .06654 L
.13435 .07019 L
.13949 .07437 L
.14429 .07916 L
.15379 .09213 L
.15925 .10199 L
.16423 .11156 L
.16673 .11576 L
.16805 .11757 L
.16877 .11841 L
.16945 .11908 L
.17067 .11999 L
.17132 .12029 L
.17202 .12048 L
.17326 .12045 L
.17439 .12001 L
.17571 .11902 L
.17693 .11768 L
.1797 .11343 L
.18529 .10203 L
.19034 .09151 L
.19581 .08187 L
.20098 .07491 L
.20575 .0702 L
.21005 .06712 L
.21249 .06578 L
.21478 .06476 L
.21714 .06391 L
.21939 .06328 L
.22062 .063 L
Mistroke
.22197 .06273 L
.22434 .06238 L
.22567 .06224 L
.2269 .06215 L
.22754 .06211 L
.22825 .06207 L
.22898 .06205 L
.22967 .06203 L
.23093 .06203 L
.23209 .06205 L
.23273 .06206 L
.23342 .06209 L
.23468 .06216 L
.23581 .06224 L
.23704 .06234 L
.23955 .06261 L
.24405 .06327 L
.24926 .06427 L
.25488 .06556 L
.26503 .06806 L
.26968 .06906 L
.27223 .06952 L
.27463 .06988 L
.276 .07005 L
.27748 .0702 L
.27883 .07031 L
.28006 .07038 L
.28123 .07043 L
.28252 .07045 L
.28317 .07046 L
.28386 .07045 L
.28511 .07042 L
.2858 .0704 L
.28652 .07036 L
.28783 .07028 L
.28923 .07016 L
.29078 .07 L
.29615 .06921 L
.30135 .06819 L
.30623 .06709 L
.31514 .06505 L
.32468 .06314 L
.33016 .06224 L
.33514 .06157 L
.34488 .06059 L
.34982 .06024 L
.35517 .05993 L
.3649 .05952 L
.38599 .05887 L
.40545 .05828 L
Mistroke
.42688 .05766 L
.44721 .05719 L
.46625 .05689 L
.48651 .05664 L
.50504 .05646 L
.54477 .05614 L
.58298 .05592 L
.62365 .05576 L
.66279 .05564 L
.7044 .05554 L
.74448 .05547 L
.78305 .05542 L
.82408 .05537 L
.86358 .05533 L
.90158 .0553 L
.94202 .05527 L
.97619 .05524 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04226 L
.04033 .04349 L
.04262 .04436 L
.04761 .04572 L
.05217 .04663 L
.06244 .0483 L
.08259 .05187 L
.09399 .05449 L
.10458 .05756 L
.11466 .06132 L
.1238 .06583 L
.12887 .06899 L
.13435 .07316 L
.14429 .08381 L
.16384 .12758 L
.16659 .13556 L
.16919 .14193 L
.17063 .14456 L
.17144 .1457 L
.17219 .1465 L
.17283 .14698 L
.17352 .14731 L
.17425 .14741 L
.17493 .14729 L
.1762 .14652 L
.17684 .14588 L
.17753 .14501 L
.17992 .14075 L
.1827 .13397 L
.18529 .12669 L
.19 .11298 L
.19511 .09952 L
.19962 .08979 L
.20438 .08177 L
.20703 .07826 L
.20994 .07506 L
.21241 .07284 L
.21507 .07089 L
.21769 .06935 L
.22009 .06823 L
.22249 .06735 L
Mistroke
.22478 .0667 L
.22603 .06642 L
.22738 .06617 L
.22857 .06599 L
.22982 .06583 L
.23096 .06573 L
.2322 .06564 L
.23334 .0656 L
.23439 .06557 L
.23503 .06557 L
.23572 .06557 L
.23698 .0656 L
.2382 .06565 L
.23933 .06572 L
.2419 .06592 L
.24462 .06621 L
.24931 .0668 L
.25186 .06713 L
.25423 .0674 L
.25626 .06759 L
.2573 .06767 L
.25843 .06773 L
.25967 .06779 L
.26084 .06782 L
.26198 .06784 L
.26302 .06784 L
.26415 .06782 L
.2652 .0678 L
.26635 .06776 L
.26759 .06771 L
.27242 .06744 L
.27771 .06703 L
.28253 .06658 L
.29192 .06541 L
.30083 .06398 L
.31902 .06098 L
.32939 .05968 L
.33446 .0592 L
.33912 .05883 L
.34862 .05826 L
.35362 .05805 L
.35887 .05786 L
.3689 .05759 L
.37987 .05735 L
.39946 .05702 L
.4204 .05676 L
.43063 .05667 L
.43602 .05663 L
.44172 .0566 L
.44671 .05658 L
Mistroke
.4522 .05655 L
.46187 .05652 L
.47201 .0565 L
.48129 .05649 L
.50218 .05645 L
.5419 .0564 L
.58012 .05637 L
.62078 .05634 L
.65993 .05631 L
.70153 .05628 L
.74162 .05625 L
.78019 .05623 L
.82121 .0562 L
.86072 .05618 L
.89871 .05615 L
.93916 .05613 L
.97619 .05611 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .03791 L
.03527 .04039 L
.03652 .04135 L
.0379 .04224 L
.04033 .04347 L
.04262 .04435 L
.04761 .04572 L
.05217 .04664 L
.06244 .04836 L
.08259 .05203 L
.09399 .05472 L
.10458 .05789 L
.11466 .0618 L
.1238 .06655 L
.12887 .06992 L
.13435 .07443 L
.13953 .07986 L
.14429 .0863 L
.14935 .09534 L
.15414 .10688 L
.15967 .12494 L
.16471 .14516 L
.16701 .15418 L
.16827 .15859 L
.16945 .16217 L
.17054 .16489 L
.17154 .16682 L
.17265 .16829 L
.17384 .16906 L
.17504 .169 L
.17615 .16825 L
.17738 .16673 L
.17868 .16442 L
.18135 .15802 L
.18378 .15098 L
.19315 .12219 L
.19808 .10934 L
.20331 .09834 L
.20788 .09083 L
.2129 .08455 L
.21747 .08036 L
.22175 .0775 L
.22433 .07619 L
.22673 .07522 L
Mistroke
.22936 .07439 L
.2307 .07405 L
.23215 .07375 L
.23355 .07352 L
.23483 .07335 L
.23605 .07322 L
.23734 .07313 L
.2385 .07307 L
.23958 .07305 L
.24077 .07304 L
.24203 .07306 L
.24328 .07311 L
.24442 .07318 L
.24702 .07338 L
.25174 .07387 L
.25399 .07411 L
.25635 .07433 L
.25733 .07441 L
.25837 .07447 L
.25951 .07452 L
.26057 .07454 L
.26183 .07454 L
.26301 .07451 L
.26407 .07445 L
.26522 .07436 L
.26649 .07423 L
.26783 .07406 L
.27022 .07365 L
.27454 .07269 L
.27927 .07139 L
.29005 .06835 L
.29989 .0662 L
.30468 .06543 L
.30989 .06477 L
.31482 .06429 L
.31938 .06394 L
.32419 .06366 L
.32951 .06342 L
.33218 .06333 L
.33506 .06324 L
.33759 .06318 L
.34028 .06313 L
.34287 .06309 L
.34523 .06306 L
.3476 .06304 L
.34984 .06302 L
.3511 .06302 L
.3518 .06302 L
.35245 .06301 L
.35359 .06301 L
Mistroke
.35486 .06301 L
.35556 .06301 L
.35623 .06301 L
.35748 .06301 L
.35818 .06301 L
.35883 .06302 L
.3603 .06302 L
.36162 .06303 L
.36306 .06304 L
.36566 .06306 L
.37051 .06311 L
.37618 .06318 L
.38139 .06327 L
.4209 .06407 L
.45889 .06468 L
.49933 .06522 L
.53826 .06571 L
.57964 .06617 L
.61951 .06659 L
.65786 .06699 L
.69866 .06742 L
.73795 .06785 L
.77572 .06828 L
.81594 .06875 L
.85465 .06921 L
.89581 .06971 L
.93545 .0702 L
.97358 .07067 L
.97619 .0707 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04441 L
.04761 .04579 L
.05217 .04672 L
.06244 .04843 L
.08259 .05206 L
.09399 .05474 L
.10458 .05787 L
.11466 .06174 L
.1238 .0664 L
.12887 .06969 L
.13435 .07408 L
.13953 .0793 L
.14429 .08543 L
.14935 .09391 L
.15414 .10457 L
.15967 .12092 L
.16471 .13918 L
.16914 .15433 L
.17021 .15722 L
.17137 .15978 L
.17265 .16184 L
.17384 .16301 L
.17515 .16342 L
.17581 .16328 L
.17653 .16288 L
.17781 .16157 L
.179 .15972 L
.18131 .15474 L
.18378 .14797 L
.19263 .1203 L
.19747 .10692 L
.202 .09665 L
.20689 .08801 L
.2097 .08409 L
.21227 .08111 L
.21684 .07701 L
.21936 .07531 L
.22175 .07402 L
.22431 .07294 L
Mistroke
.22572 .07247 L
.22705 .07209 L
.22829 .0718 L
.22963 .07154 L
.23084 .07136 L
.23196 .07124 L
.23261 .07118 L
.2333 .07114 L
.23454 .07109 L
.23531 .07108 L
.23603 .07108 L
.23667 .0711 L
.23738 .07113 L
.23806 .07117 L
.23882 .07122 L
.24035 .07138 L
.24177 .07157 L
.24309 .07178 L
.24816 .0729 L
.2528 .07426 L
.26325 .07792 L
.27242 .08121 L
.27506 .08198 L
.27755 .08257 L
.27864 .08277 L
.27979 .08295 L
.28105 .08309 L
.28221 .08319 L
.28348 .08324 L
.2842 .08325 L
.28485 .08324 L
.28612 .08318 L
.28732 .08309 L
.288 .08301 L
.28872 .08292 L
.29002 .08272 L
.29294 .0821 L
.29769 .08071 L
.30292 .07881 L
.31312 .07476 L
.32387 .07094 L
.33305 .06842 L
.33831 .06728 L
.34309 .06642 L
.35277 .0651 L
.35808 .06455 L
.36311 .06412 L
.37205 .06351 L
.38175 .06301 L
.4016 .06223 L
Mistroke
.42263 .0616 L
.44241 .06112 L
.46049 .06078 L
.47991 .0605 L
.5008 .06027 L
.54053 .05992 L
.57874 .05965 L
.6194 .05941 L
.65855 .05922 L
.70016 .05905 L
.74024 .05891 L
.77881 .0588 L
.81984 .05871 L
.85934 .05862 L
.89733 .05856 L
.93778 .05849 L
.97619 .05844 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .03788 L
.03527 .04036 L
.03652 .04132 L
.0379 .04219 L
.04033 .04341 L
.04262 .04429 L
.04761 .04565 L
.05217 .04656 L
.06244 .04826 L
.08259 .05189 L
.09399 .05456 L
.10458 .05768 L
.11466 .06154 L
.1238 .06621 L
.12887 .06951 L
.13435 .07393 L
.13953 .07923 L
.14429 .08548 L
.14935 .09421 L
.15414 .10529 L
.15967 .12247 L
.16471 .14158 L
.16701 .15012 L
.16827 .1543 L
.16945 .15773 L
.17054 .16034 L
.17154 .16222 L
.17265 .16368 L
.17384 .1645 L
.17504 .16454 L
.17615 .16392 L
.17738 .16258 L
.17868 .16048 L
.18135 .15456 L
.18378 .14795 L
.19315 .12051 L
.19808 .1081 L
.20331 .09739 L
.20788 .09003 L
.2129 .08382 L
.21747 .07964 L
.22175 .07676 L
.22433 .07543 L
.22673 .07444 L
Mistroke
.22936 .07358 L
.2307 .07323 L
.23215 .07291 L
.23355 .07266 L
.23483 .07248 L
.23605 .07234 L
.23734 .07223 L
.2385 .07216 L
.23958 .07212 L
.24077 .0721 L
.24203 .07211 L
.24328 .07215 L
.24442 .0722 L
.24568 .07228 L
.24702 .07239 L
.25174 .07288 L
.25604 .07338 L
.25839 .0736 L
.25953 .07369 L
.26057 .07376 L
.26171 .07381 L
.26292 .07383 L
.26423 .07383 L
.26548 .0738 L
.2666 .07374 L
.26763 .07367 L
.26877 .07356 L
.26997 .07341 L
.27246 .07302 L
.27479 .07254 L
.28008 .07117 L
.29837 .06562 L
.30337 .06439 L
.30881 .06329 L
.3136 .06252 L
.3187 .06186 L
.32328 .0614 L
.32833 .06101 L
.33293 .06074 L
.33725 .06055 L
.34194 .06039 L
.34707 .06027 L
.35242 .06017 L
.35741 .06011 L
.36209 .06007 L
.36635 .06003 L
.37591 .05998 L
.38074 .05995 L
.38587 .05993 L
.3903 .05992 L
Mistroke
.39507 .05991 L
.39774 .0599 L
.40018 .0599 L
.40263 .05989 L
.40496 .05989 L
.40627 .05989 L
.40699 .05989 L
.40766 .05989 L
.40898 .05989 L
.41017 .05989 L
.41086 .05989 L
.41159 .05989 L
.4129 .05989 L
.41363 .05989 L
.41431 .05989 L
.41586 .05989 L
.41846 .05989 L
.42087 .0599 L
.42632 .05991 L
.43112 .05992 L
.43622 .05993 L
.45478 .06001 L
.49255 .06021 L
.53278 .06046 L
.57149 .06072 L
.61265 .061 L
.65229 .06128 L
.69042 .06155 L
.731 .06185 L
.77006 .06214 L
.81158 .06245 L
.85158 .06276 L
.89007 .06305 L
.93101 .06337 L
.97043 .06367 L
.97619 .06372 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04669 L
.06244 .04841 L
.08259 .05208 L
.09399 .05477 L
.10458 .05793 L
.11466 .06184 L
.1238 .06657 L
.12887 .06992 L
.13435 .0744 L
.13953 .07978 L
.14429 .08614 L
.14935 .09504 L
.15414 .10638 L
.15967 .12412 L
.16471 .14433 L
.16914 .16139 L
.17021 .16467 L
.17137 .16761 L
.17265 .17002 L
.17384 .17146 L
.17515 .1721 L
.17581 .17207 L
.17653 .17177 L
.17781 .17063 L
.179 .16892 L
.18021 .16665 L
.18131 .16421 L
.18378 .15772 L
.19337 .12849 L
.19862 .11416 L
.20353 .10298 L
.20806 .09464 L
.21221 .08856 L
.21681 .0833 L
.21937 .08098 L
.22175 .07915 L
.22646 .07638 L
Mistroke
.22894 .07531 L
.23159 .07442 L
.23412 .07379 L
.23535 .07355 L
.23649 .07337 L
.23751 .07324 L
.23863 .07312 L
.23975 .07304 L
.24093 .07298 L
.2416 .07296 L
.24233 .07295 L
.24365 .07296 L
.24494 .07301 L
.24613 .07307 L
.24741 .07317 L
.24883 .0733 L
.2517 .07365 L
.26173 .0752 L
.26429 .07552 L
.26553 .07564 L
.26666 .07574 L
.26786 .07581 L
.26914 .07587 L
.26981 .07588 L
.27053 .07589 L
.27185 .07587 L
.27297 .07583 L
.27419 .07575 L
.27548 .07564 L
.27667 .0755 L
.27882 .07518 L
.28112 .07473 L
.28672 .07326 L
.29203 .07153 L
.30199 .06807 L
.31162 .06518 L
.31691 .06392 L
.32187 .06296 L
.33062 .06171 L
.33527 .06124 L
.34028 .06084 L
.34523 .06054 L
.34984 .06033 L
.3603 .05998 L
.37049 .05974 L
.38139 .0595 L
.40128 .05907 L
.41175 .05886 L
.42286 .05866 L
.43275 .05851 L
Mistroke
.44363 .05839 L
.45353 .0583 L
.46281 .05824 L
.4732 .05819 L
.48307 .05815 L
.5016 .05809 L
.51119 .05807 L
.52142 .05805 L
.53107 .05803 L
.53981 .05802 L
.54469 .05802 L
.54736 .05802 L
.54984 .05802 L
.55215 .05802 L
.55424 .05801 L
.55657 .05801 L
.55786 .05801 L
.55907 .05801 L
.56027 .05801 L
.56159 .05801 L
.56225 .05801 L
.56296 .05801 L
.56425 .05801 L
.56547 .05801 L
.56676 .05801 L
.56785 .05801 L
.56905 .05801 L
.57177 .05801 L
.57467 .05802 L
.5799 .05802 L
.58523 .05802 L
.59015 .05802 L
.60126 .05803 L
.62141 .05806 L
.66084 .05812 L
.69874 .05819 L
.7391 .05827 L
.77795 .05836 L
.81924 .05845 L
.85903 .05854 L
.89729 .05863 L
.93801 .05873 L
.97619 .05882 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04015 L
.03652 .04107 L
.0379 .04191 L
.04033 .04306 L
.04262 .04388 L
.04517 .04458 L
.04761 .04512 L
.05217 .04594 L
.06244 .04746 L
.07302 .04907 L
.08429 .05107 L
.09474 .05331 L
.10458 .05591 L
.1142 .05909 L
.12461 .06359 L
.13407 .06917 L
.14277 .07632 L
.15263 .08807 L
.15805 .09653 L
.16319 .10511 L
.16551 .10858 L
.16678 .11022 L
.16797 .1115 L
.16925 .11257 L
.16994 .11298 L
.17067 .11329 L
.17197 .1135 L
.17317 .11329 L
.17426 .11276 L
.17528 .11198 L
.1764 .11084 L
.1776 .10933 L
.18226 .10136 L
.18717 .09171 L
.19249 .0822 L
.19752 .07503 L
.20215 .07005 L
.20634 .06672 L
.21094 .06411 L
.21325 .06314 L
.21574 .06231 L
.21809 .06171 L
.22023 .06129 L
Mistroke
.22152 .0611 L
.22274 .06095 L
.22383 .06084 L
.22501 .06075 L
.2263 .06068 L
.22695 .06066 L
.22767 .06065 L
.22893 .06064 L
.2301 .06065 L
.23129 .06069 L
.23242 .06074 L
.23343 .0608 L
.23452 .06089 L
.23698 .06112 L
.23926 .0614 L
.24404 .06215 L
.24932 .0632 L
.25999 .06578 L
.26944 .06805 L
.27419 .06893 L
.27688 .06931 L
.27938 .06957 L
.2808 .06967 L
.2815 .06971 L
.28214 .06975 L
.28335 .06979 L
.28465 .0698 L
.28595 .0698 L
.28669 .06978 L
.28738 .06976 L
.28811 .06973 L
.28878 .06969 L
.29027 .06959 L
.29272 .06936 L
.29539 .06902 L
.30025 .06822 L
.31961 .06415 L
.3299 .06233 L
.3353 .06158 L
.341 .06094 L
.34603 .06049 L
.35155 .0601 L
.36123 .0596 L
.37107 .05925 L
.38023 .05896 L
.41925 .05777 L
.43913 .05724 L
.44961 .05702 L
.46071 .05683 L
.48149 .05656 L
Mistroke
.50066 .05635 L
.53852 .05603 L
.57882 .05577 L
.61761 .0556 L
.65886 .05546 L
.69859 .05536 L
.7368 .05529 L
.77747 .05522 L
.81662 .05518 L
.85822 .05513 L
.8983 .05509 L
.93687 .05506 L
.97619 .05503 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04034 L
.03652 .04129 L
.0379 .04216 L
.04033 .04336 L
.04262 .04421 L
.04761 .04553 L
.05217 .0464 L
.06244 .04802 L
.08259 .05149 L
.09399 .05403 L
.10458 .05699 L
.11466 .0606 L
.1238 .0649 L
.12887 .06788 L
.13435 .0718 L
.14429 .08163 L
.15372 .09627 L
.15901 .10764 L
.16384 .11942 L
.16656 .12575 L
.168 .12864 L
.16953 .13119 L
.17087 .13284 L
.17163 .13351 L
.17234 .13395 L
.17359 .13426 L
.17429 .13418 L
.17493 .13395 L
.17618 .13307 L
.17734 .13178 L
.17862 .12991 L
.17998 .12747 L
.18529 .11526 L
.1904 .10266 L
.19593 .09067 L
.20116 .08177 L
.20598 .07561 L
.21033 .0715 L
.21511 .06829 L
.21752 .06709 L
.22011 .06607 L
.22255 .06532 L
.22478 .0648 L
Mistroke
.22607 .06456 L
.22729 .06438 L
.22839 .06424 L
.22956 .06412 L
.23084 .06402 L
.23201 .06396 L
.23327 .06392 L
.23398 .06391 L
.23465 .06391 L
.23584 .06392 L
.23696 .06395 L
.23797 .064 L
.23907 .06405 L
.24153 .06423 L
.2438 .06444 L
.249 .06499 L
.25154 .06525 L
.25386 .06546 L
.25506 .06554 L
.25631 .06561 L
.25757 .06565 L
.25828 .06566 L
.25894 .06567 L
.25967 .06567 L
.26036 .06566 L
.26165 .06562 L
.26237 .06559 L
.26304 .06556 L
.26454 .06546 L
.26699 .06525 L
.26923 .06503 L
.27426 .06444 L
.28334 .06332 L
.304 .06054 L
.31401 .05921 L
.32467 .05804 L
.33376 .0573 L
.33894 .05699 L
.34381 .05676 L
.34849 .05657 L
.35342 .05642 L
.36223 .05621 L
.37172 .05604 L
.38211 .05589 L
.39302 .05574 L
.40333 .05562 L
.41337 .05552 L
.42263 .05546 L
.43172 .05541 L
.4363 .05539 L
Mistroke
.44135 .05538 L
.44399 .05537 L
.4464 .05537 L
.44918 .05537 L
.45183 .05536 L
.45301 .05536 L
.45427 .05536 L
.45535 .05536 L
.45653 .05536 L
.45725 .05536 L
.45791 .05536 L
.45921 .05536 L
.4604 .05536 L
.46165 .05536 L
.46287 .05536 L
.46356 .05536 L
.4642 .05536 L
.46537 .05536 L
.46661 .05536 L
.47113 .05536 L
.4813 .05537 L
.49964 .05538 L
.50902 .05538 L
.51913 .05538 L
.53741 .05539 L
.57857 .05541 L
.59911 .05542 L
.61821 .05542 L
.63665 .05543 L
.64697 .05543 L
.65634 .05543 L
.66633 .05543 L
.67554 .05543 L
.68036 .05543 L
.68565 .05543 L
.68831 .05543 L
.69118 .05543 L
.69388 .05544 L
.69634 .05544 L
.69764 .05544 L
.69886 .05544 L
.69995 .05544 L
.70113 .05544 L
.70242 .05544 L
.70307 .05544 L
.70379 .05544 L
.70505 .05544 L
.70622 .05544 L
.70742 .05544 L
.70854 .05544 L
Mistroke
.71065 .05544 L
.71292 .05543 L
.71538 .05543 L
.72062 .05543 L
.72617 .05543 L
.73612 .05543 L
.74553 .05543 L
.75565 .05543 L
.77395 .05543 L
.81516 .05542 L
.85486 .05541 L
.89304 .0554 L
.93367 .05539 L
.97279 .05538 L
.97619 .05538 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04579 L
.05217 .04672 L
.06244 .04846 L
.08259 .05217 L
.09399 .05489 L
.10458 .0581 L
.11466 .06207 L
.1238 .0669 L
.12887 .07034 L
.13435 .07496 L
.13953 .08054 L
.14429 .08719 L
.14935 .0966 L
.15414 .10874 L
.15967 .12803 L
.16471 .1501 L
.16701 .16014 L
.16827 .1651 L
.16945 .16918 L
.17054 .1723 L
.17154 .17456 L
.17265 .17634 L
.17384 .17737 L
.17504 .1775 L
.17615 .17685 L
.17738 .17538 L
.17868 .17306 L
.18135 .16647 L
.18378 .15912 L
.19315 .12873 L
.19808 .11505 L
.20331 .10328 L
.20788 .0952 L
.2129 .08841 L
.21747 .08386 L
.22175 .08074 L
.22433 .07931 L
.22673 .07825 L
Mistroke
.22936 .07735 L
.2307 .07698 L
.23215 .07665 L
.23355 .0764 L
.23483 .07622 L
.23605 .07609 L
.23734 .07599 L
.2385 .07594 L
.23958 .07591 L
.24077 .07592 L
.24203 .07596 L
.24328 .07602 L
.24442 .0761 L
.24702 .07636 L
.25174 .07696 L
.25399 .07725 L
.25635 .07751 L
.25733 .0776 L
.25837 .07767 L
.25951 .07774 L
.26057 .07777 L
.26183 .07779 L
.26301 .07778 L
.26407 .07775 L
.26522 .0777 L
.26649 .07761 L
.26783 .0775 L
.27022 .07725 L
.27927 .07615 L
.28172 .07589 L
.28435 .07565 L
.28662 .07548 L
.2891 .07533 L
.29199 .07519 L
.29474 .0751 L
.29989 .07496 L
.31925 .07441 L
.32954 .07403 L
.33236 .07394 L
.33533 .07386 L
.3379 .07381 L
.33931 .07378 L
.34064 .07376 L
.3419 .07374 L
.34256 .07374 L
.34326 .07373 L
.3445 .07373 L
.34564 .07372 L
.34679 .07372 L
.34786 .07373 L
Mistroke
.34903 .07373 L
.3503 .07375 L
.35165 .07376 L
.35313 .07379 L
.35582 .07385 L
.35844 .07393 L
.36087 .07402 L
.37007 .0745 L
.37987 .07519 L
.39986 .07679 L
.41038 .07755 L
.42148 .07821 L
.43143 .07867 L
.44236 .07908 L
.46156 .07964 L
.50201 .08065 L
.54094 .08138 L
.56219 .08167 L
.58232 .08191 L
.62067 .08233 L
.66147 .08278 L
.70075 .08324 L
.73852 .08372 L
.77875 .08429 L
.81746 .08489 L
.85862 .08557 L
.89826 .08625 L
.93639 .08691 L
.97619 .0876 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .0468 L
.06244 .04856 L
.08259 .0523 L
.09399 .05505 L
.10458 .05829 L
.11466 .06231 L
.1238 .06721 L
.12887 .07071 L
.13435 .07542 L
.13953 .08114 L
.14429 .08797 L
.14899 .09689 L
.15402 .10998 L
.15878 .12701 L
.16311 .14686 L
.1682 .17156 L
.16959 .17724 L
.17107 .18217 L
.17233 .18531 L
.17305 .18662 L
.17372 .18753 L
.17495 .18839 L
.17625 .18822 L
.17735 .18729 L
.17856 .18554 L
.17987 .18291 L
.18126 .17942 L
.18378 .17184 L
.19345 .13823 L
.19874 .1219 L
.20369 .10932 L
.20904 .09874 L
.21211 .09396 L
.21492 .09034 L
.21991 .08543 L
.22266 .08345 L
.22527 .08198 L
Mistroke
.2278 .0809 L
.23008 .08018 L
.23135 .07988 L
.23272 .07963 L
.23401 .07946 L
.2352 .07937 L
.23631 .07932 L
.23734 .07932 L
.23847 .07936 L
.23968 .07944 L
.24095 .07959 L
.24215 .07977 L
.2444 .08022 L
.24692 .08089 L
.2496 .08177 L
.2544 .08365 L
.26526 .08865 L
.27465 .09366 L
.27958 .09617 L
.28227 .09736 L
.28477 .09829 L
.28716 .09902 L
.28933 .09952 L
.29057 .09973 L
.29174 .09989 L
.29298 .10001 L
.29367 .10006 L
.29431 .10009 L
.29536 .10011 L
.29634 .10009 L
.29741 .10005 L
.29856 .09997 L
.29977 .09984 L
.30091 .09969 L
.30306 .09933 L
.30764 .09828 L
.3127 .09681 L
.32294 .0935 L
.33191 .09088 L
.34136 .08876 L
.34617 .08798 L
.34871 .08764 L
.35143 .08733 L
.35394 .08709 L
.35622 .08691 L
.35839 .08678 L
.36068 .08666 L
.36195 .08661 L
.36335 .08656 L
.36464 .08653 L
Mistroke
.36582 .0865 L
.36721 .08648 L
.36797 .08647 L
.3687 .08646 L
.36999 .08646 L
.37072 .08645 L
.3714 .08645 L
.37204 .08646 L
.37272 .08646 L
.37397 .08646 L
.37519 .08647 L
.3763 .08649 L
.37884 .08652 L
.38153 .08657 L
.39101 .08675 L
.39375 .08679 L
.39633 .08682 L
.39865 .08685 L
.39997 .08686 L
.40118 .08686 L
.40223 .08687 L
.40336 .08687 L
.40443 .08687 L
.40541 .08687 L
.40649 .08686 L
.40768 .08686 L
.40892 .08685 L
.41007 .08684 L
.41247 .08681 L
.41464 .08678 L
.41952 .08667 L
.42437 .08654 L
.42951 .08637 L
.43872 .08601 L
.45952 .08515 L
.49743 .08378 L
.53779 .08241 L
.57663 .08108 L
.61793 .0798 L
.65771 .07874 L
.69597 .07788 L
.73669 .07715 L
.77589 .07659 L
.81755 .07612 L
.85769 .07578 L
.89631 .07551 L
.93738 .07529 L
.97619 .07512 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04585 L
.05217 .04679 L
.06244 .04855 L
.08259 .05229 L
.09399 .05504 L
.10458 .05829 L
.11466 .06232 L
.1238 .06723 L
.12887 .07074 L
.13435 .07548 L
.13953 .08122 L
.14429 .08811 L
.14899 .09712 L
.15402 .11039 L
.15878 .1277 L
.16311 .14789 L
.1682 .17284 L
.16959 .17847 L
.17107 .18328 L
.17233 .18627 L
.17305 .18747 L
.17372 .18827 L
.17495 .18891 L
.17625 .18851 L
.17735 .18739 L
.17856 .18544 L
.17987 .18262 L
.18126 .17897 L
.18378 .17122 L
.19402 .13622 L
.19941 .12047 L
.20512 .10713 L
.21011 .0982 L
.21561 .09093 L
.21801 .08848 L
.2206 .08628 L
.22527 .0833 L
.22782 .08216 L
Mistroke
.22922 .08165 L
.23053 .08126 L
.23176 .08095 L
.23309 .08068 L
.2343 .0805 L
.2354 .08037 L
.23605 .08032 L
.23673 .08027 L
.23797 .08024 L
.23872 .08024 L
.23944 .08025 L
.24008 .08028 L
.24078 .08032 L
.24146 .08037 L
.24221 .08045 L
.24373 .08064 L
.24645 .08112 L
.25144 .08232 L
.25682 .08379 L
.26655 .08625 L
.28624 .09331 L
.29163 .09519 L
.29459 .09602 L
.29738 .09665 L
.29999 .09709 L
.30146 .09728 L
.30281 .09742 L
.30396 .09751 L
.30521 .09759 L
.30652 .09763 L
.30774 .09765 L
.30902 .09764 L
.3102 .09762 L
.3115 .09757 L
.31216 .09754 L
.31288 .0975 L
.31539 .09731 L
.31775 .09709 L
.32688 .09603 L
.33169 .09546 L
.33676 .09495 L
.33941 .09473 L
.34232 .09454 L
.3436 .09448 L
.34496 .09442 L
.34625 .09438 L
.34742 .09435 L
.34861 .09433 L
.34972 .09432 L
.35094 .09432 L
Mistroke
.35226 .09433 L
.35291 .09435 L
.35363 .09436 L
.35494 .0944 L
.35621 .09444 L
.35738 .0945 L
.36184 .09477 L
.36658 .09519 L
.37749 .09648 L
.38737 .09782 L
.39674 .09901 L
.40663 .10004 L
.4118 .10045 L
.41748 .10081 L
.42264 .10105 L
.42745 .10121 L
.43006 .10128 L
.43247 .10133 L
.43511 .10138 L
.43792 .10141 L
.44035 .10143 L
.44263 .10145 L
.44393 .10145 L
.44513 .10146 L
.44644 .10146 L
.4471 .10146 L
.44782 .10147 L
.44908 .10147 L
.45026 .10147 L
.45132 .10147 L
.45247 .10147 L
.45373 .10146 L
.45506 .10146 L
.45744 .10146 L
.4617 .10145 L
.46638 .10143 L
.47637 .10139 L
.48585 .10135 L
.49107 .10132 L
.49677 .10128 L
.50674 .10119 L
.5171 .10106 L
.52647 .10091 L
.54746 .10047 L
.5876 .09948 L
.62622 .09856 L
.6673 .09772 L
.70686 .09709 L
.7449 .09665 L
.76446 .0965 L
Mistroke
.7854 .09637 L
.79561 .09632 L
.80669 .09628 L
.81716 .09625 L
.82182 .09624 L
.82683 .09623 L
.83188 .09622 L
.83649 .09622 L
.83871 .09622 L
.84113 .09621 L
.84341 .09621 L
.84555 .09621 L
.84685 .09621 L
.84826 .09621 L
.84954 .09621 L
.85072 .09621 L
.852 .09621 L
.85273 .09621 L
.8534 .09621 L
.85412 .09621 L
.85477 .09621 L
.85553 .09621 L
.85624 .09621 L
.85744 .09621 L
.85871 .09621 L
.86099 .09621 L
.86345 .09621 L
.86617 .09622 L
.87108 .09622 L
.87626 .09623 L
.88551 .09624 L
.89546 .09626 L
.90636 .09628 L
.94691 .0964 L
.97619 .09651 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04551 L
.05217 .04638 L
.06244 .048 L
.08259 .05146 L
.09399 .054 L
.10458 .05695 L
.11466 .06056 L
.1238 .06484 L
.12887 .06782 L
.13435 .07172 L
.14429 .08151 L
.15372 .09603 L
.15901 .10724 L
.16384 .11876 L
.16656 .12488 L
.168 .12765 L
.16953 .13005 L
.17018 .13086 L
.17087 .13158 L
.17163 .13219 L
.17234 .13257 L
.173 .13275 L
.17369 .13277 L
.17493 .13237 L
.17617 .13143 L
.17686 .13069 L
.1775 .12988 L
.17988 .12591 L
.18529 .11362 L
.19504 .09143 L
.20054 .0821 L
.2056 .07572 L
.21004 .07164 L
.21492 .06846 L
.21737 .06729 L
.22001 .0663 L
.2225 .06558 L
.22478 .06508 L
Mistroke
.22607 .06487 L
.22729 .0647 L
.22838 .06458 L
.22956 .06449 L
.23085 .06441 L
.2315 .06439 L
.23221 .06437 L
.23347 .06436 L
.23465 .06438 L
.23584 .06442 L
.23696 .06448 L
.23797 .06455 L
.23907 .06465 L
.24153 .06492 L
.2438 .06523 L
.24859 .06608 L
.25386 .06724 L
.26454 .06988 L
.26947 .07095 L
.27216 .07142 L
.27466 .07177 L
.2768 .07199 L
.278 .07208 L
.27909 .07214 L
.28028 .07218 L
.28158 .07219 L
.2828 .07218 L
.28393 .07215 L
.28513 .07209 L
.28642 .072 L
.28876 .07176 L
.29154 .07137 L
.29407 .07093 L
.3048 .06845 L
.31481 .06592 L
.32547 .06366 L
.33456 .06225 L
.33974 .06166 L
.34461 .06121 L
.34929 .06086 L
.35422 .06057 L
.36303 .06018 L
.38291 .05955 L
.42098 .05839 L
.44057 .0579 L
.46151 .05753 L
.47174 .05739 L
.48283 .05726 L
.50298 .05706 L
.54386 .05674 L
Mistroke
.58323 .05652 L
.62109 .05637 L
.6614 .05625 L
.70019 .05616 L
.74143 .0561 L
.78116 .05605 L
.81937 .05601 L
.86004 .05597 L
.89919 .05594 L
.94079 .05591 L
.97619 .05589 L
Mfstroke
.862 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03492 L
.03279 .03785 L
.03527 .0403 L
.03652 .04124 L
.0379 .0421 L
.04033 .04329 L
.04262 .04413 L
.04761 .04542 L
.05217 .04628 L
.06244 .04786 L
.08259 .05126 L
.09399 .05374 L
.10458 .05664 L
.11466 .06015 L
.1238 .0643 L
.12887 .06717 L
.13435 .07092 L
.13949 .07522 L
.14429 .08017 L
.15379 .09367 L
.15925 .10404 L
.16423 .11428 L
.16673 .11887 L
.16805 .1209 L
.16945 .12263 L
.17067 .12371 L
.17136 .12412 L
.17202 .12437 L
.17316 .12448 L
.17439 .12412 L
.17572 .1232 L
.17647 .12245 L
.17716 .12161 L
.18008 .11691 L
.18529 .10574 L
.19034 .09462 L
.19581 .08433 L
.20098 .07686 L
.20575 .07178 L
.21005 .06844 L
.21249 .06699 L
.21478 .06587 L
.21714 .06494 L
.21939 .06424 L
.22197 .06363 L
Mistroke
.22434 .06323 L
.22559 .06307 L
.22694 .06294 L
.22821 .06285 L
.22938 .0628 L
.23044 .06278 L
.2316 .06277 L
.23282 .06279 L
.23395 .06283 L
.23459 .06286 L
.23528 .06291 L
.23654 .063 L
.23889 .06322 L
.24164 .06358 L
.24418 .06398 L
.25311 .06584 L
.26258 .06828 L
.26716 .06942 L
.27198 .07044 L
.2745 .07087 L
.27583 .07106 L
.27726 .07123 L
.27857 .07136 L
.27976 .07146 L
.28096 .07153 L
.28209 .07158 L
.28315 .0716 L
.28432 .07161 L
.28553 .07159 L
.28667 .07154 L
.28773 .07149 L
.2887 .07142 L
.29088 .07121 L
.29321 .07092 L
.29576 .07051 L
.30038 .06961 L
.31975 .06507 L
.32505 .064 L
.33077 .06301 L
.33572 .0623 L
.34113 .06168 L
.3511 .06085 L
.35653 .06054 L
.36159 .0603 L
.38037 .05965 L
.41938 .05841 L
.43927 .05788 L
.44975 .05766 L
.46085 .05747 L
.48162 .05719 L
Mistroke
.5008 .05698 L
.53865 .05666 L
.57896 .0564 L
.61775 .05623 L
.659 .05609 L
.69872 .05599 L
.73694 .05592 L
.7776 .05586 L
.81675 .05581 L
.85835 .05577 L
.89844 .05574 L
.93701 .0557 L
.97619 .05567 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04225 L
.04033 .04348 L
.04262 .04435 L
.04761 .0457 L
.05217 .0466 L
.06244 .04827 L
.08259 .05183 L
.09399 .05445 L
.10458 .0575 L
.11466 .06126 L
.1238 .06575 L
.12887 .06889 L
.13435 .07305 L
.14429 .08364 L
.16384 .12724 L
.16659 .13525 L
.16919 .1417 L
.17063 .14442 L
.17144 .14561 L
.17219 .14647 L
.17283 .14701 L
.17352 .14739 L
.17425 .14757 L
.17493 .14752 L
.1762 .1469 L
.17684 .14635 L
.17753 .14556 L
.17877 .14374 L
.17992 .14164 L
.18529 .12837 L
.19511 .10224 L
.19994 .09205 L
.20438 .08462 L
.20951 .07815 L
.21221 .07553 L
.21507 .07325 L
.21969 .07048 L
.22232 .06934 L
.22478 .06851 L
.22736 .06786 L
.22976 .06743 L
Mistroke
.23114 .06725 L
.23239 .06713 L
.23308 .06708 L
.23383 .06703 L
.23454 .067 L
.23519 .06698 L
.23637 .06697 L
.23748 .06699 L
.23869 .06703 L
.23999 .0671 L
.24136 .06721 L
.24265 .06734 L
.24507 .06764 L
.24968 .06843 L
.25395 .06934 L
.2636 .07171 L
.26825 .07275 L
.27069 .0732 L
.27326 .07358 L
.27551 .07384 L
.27679 .07394 L
.27798 .07401 L
.27908 .07405 L
.28007 .07406 L
.28122 .07406 L
.28231 .07403 L
.2835 .07397 L
.28481 .07388 L
.28618 .07374 L
.28746 .07359 L
.2922 .07279 L
.29737 .07158 L
.30292 .07005 L
.31251 .06732 L
.32271 .06484 L
.32802 .06381 L
.33389 .06289 L
.33929 .06223 L
.34425 .06176 L
.35412 .06108 L
.35931 .06083 L
.36478 .06061 L
.38406 .06 L
.42214 .05883 L
.44173 .05836 L
.45269 .05815 L
.46267 .058 L
.50262 .05757 L
.54105 .05728 L
.5609 .05716 L
Mistroke
.58194 .05706 L
.61979 .05692 L
.6601 .05681 L
.69889 .05673 L
.74014 .05668 L
.77987 .05663 L
.81808 .0566 L
.85874 .05658 L
.89789 .05655 L
.9395 .05653 L
.97619 .05651 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04397 L
.04761 .04524 L
.05217 .04607 L
.06244 .04763 L
.08259 .05097 L
.09399 .05342 L
.10458 .05626 L
.11466 .05971 L
.1238 .06376 L
.12887 .06657 L
.13435 .07021 L
.13949 .0744 L
.14429 .07919 L
.15379 .09217 L
.15925 .10203 L
.16423 .11163 L
.16673 .11585 L
.16805 .11768 L
.16877 .11852 L
.16945 .1192 L
.17067 .12012 L
.17132 .12043 L
.17202 .12063 L
.17326 .12061 L
.17439 .12018 L
.17571 .11921 L
.17693 .11789 L
.1797 .11367 L
.18529 .10234 L
.19034 .09183 L
.19581 .08212 L
.20098 .07504 L
.20575 .0702 L
.21005 .067 L
.21478 .06451 L
.21716 .06359 L
.21972 .06282 L
.22213 .06225 L
.22434 .06187 L
Mistroke
.22563 .0617 L
.22685 .06156 L
.22794 .06147 L
.22912 .06139 L
.23041 .06133 L
.23106 .06131 L
.23177 .06129 L
.23303 .06128 L
.23421 .06129 L
.2354 .06132 L
.23652 .06135 L
.23753 .0614 L
.23863 .06146 L
.24336 .0618 L
.24859 .06225 L
.24997 .06236 L
.25145 .06247 L
.25286 .06254 L
.25414 .0626 L
.25524 .06262 L
.25645 .06262 L
.25771 .0626 L
.25888 .06255 L
.25956 .06251 L
.2602 .06246 L
.2614 .06235 L
.2641 .06202 L
.28245 .05842 L
.28748 .05761 L
.29288 .05691 L
.30262 .05596 L
.30796 .05556 L
.31303 .05524 L
.32253 .05479 L
.32777 .05461 L
.33261 .05449 L
.33793 .05439 L
.34062 .05435 L
.34359 .05432 L
.34593 .0543 L
.34849 .05428 L
.35117 .05427 L
.35366 .05426 L
.356 .05425 L
.35813 .05425 L
.36291 .05424 L
.36817 .05423 L
.37375 .05422 L
.37852 .0542 L
.38376 .05419 L
Mistroke
.40292 .0541 L
.40809 .05408 L
.41366 .05406 L
.41635 .05405 L
.41891 .05404 L
.42121 .05404 L
.42371 .05403 L
.42506 .05403 L
.4263 .05403 L
.42749 .05403 L
.42874 .05403 L
.42987 .05403 L
.43092 .05403 L
.43207 .05403 L
.4333 .05403 L
.43462 .05403 L
.43536 .05403 L
.43605 .05403 L
.43865 .05403 L
.44102 .05404 L
.44353 .05404 L
.45227 .05406 L
.46192 .05409 L
.48291 .05415 L
.50214 .0542 L
.54085 .05427 L
.5805 .05433 L
.61862 .05438 L
.63825 .0544 L
.6592 .05442 L
.67913 .05443 L
.70072 .05444 L
.72154 .05445 L
.74072 .05446 L
.7595 .05446 L
.77017 .05446 L
.78015 .05446 L
.79056 .05447 L
.80045 .05447 L
.80932 .05447 L
.81434 .05447 L
.81899 .05447 L
.82409 .05447 L
.82696 .05447 L
.8296 .05447 L
.83191 .05447 L
.83323 .05447 L
.83445 .05447 L
.83574 .05447 L
.83692 .05447 L
Mistroke
.83757 .05447 L
.83828 .05447 L
.83957 .05447 L
.84072 .05447 L
.8418 .05447 L
.84427 .05447 L
.84667 .05447 L
.84925 .05447 L
.85392 .05447 L
.85819 .05447 L
.86803 .05447 L
.87717 .05447 L
.89789 .05447 L
.93701 .05446 L
.97619 .05446 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .0444 L
.04761 .04579 L
.05217 .04672 L
.06244 .04846 L
.08259 .05217 L
.09399 .0549 L
.10458 .0581 L
.11466 .06208 L
.1238 .06691 L
.12887 .07035 L
.13435 .07498 L
.13953 .08058 L
.14429 .08726 L
.14899 .09594 L
.15402 .10864 L
.15878 .12505 L
.16311 .14412 L
.1682 .16787 L
.16959 .17337 L
.17107 .17819 L
.17233 .1813 L
.17305 .18262 L
.17372 .18356 L
.17495 .18451 L
.17625 .18451 L
.17735 .18376 L
.17856 .18225 L
.17987 .17992 L
.18126 .17679 L
.18378 .16996 L
.19345 .13951 L
.20369 .11268 L
.20904 .10233 L
.21492 .09362 L
.22027 .08778 L
.22527 .08381 L
.22775 .0823 L
.23044 .08095 L
.23282 .08 L
Mistroke
.23535 .07921 L
.23664 .07889 L
.23785 .07863 L
.23903 .07842 L
.24012 .07826 L
.24114 .07814 L
.24225 .07803 L
.24337 .07796 L
.24455 .07791 L
.24522 .07789 L
.24594 .07789 L
.24726 .0779 L
.24854 .07793 L
.24972 .07799 L
.251 .07806 L
.25241 .07816 L
.25526 .07839 L
.25775 .07858 L
.25905 .07866 L
.25976 .0787 L
.26042 .07872 L
.26163 .07876 L
.26294 .07877 L
.26406 .07875 L
.26526 .07871 L
.26649 .07863 L
.2672 .07857 L
.26785 .0785 L
.2706 .07812 L
.27298 .07765 L
.27552 .07702 L
.28664 .07322 L
.29711 .06942 L
.30681 .06663 L
.31173 .06556 L
.31696 .06465 L
.32222 .06394 L
.32802 .06336 L
.33301 .06299 L
.33839 .0627 L
.34347 .0625 L
.34813 .06237 L
.35061 .06232 L
.35286 .06228 L
.35529 .06225 L
.35792 .06222 L
.36036 .0622 L
.36143 .0622 L
.36261 .06219 L
.36364 .06218 L
Mistroke
.36476 .06218 L
.36593 .06218 L
.36703 .06217 L
.3677 .06217 L
.36841 .06217 L
.36969 .06217 L
.37047 .06217 L
.3712 .06217 L
.37186 .06217 L
.37258 .06217 L
.37391 .06218 L
.37532 .06218 L
.37784 .06219 L
.38028 .0622 L
.38256 .06221 L
.38773 .06225 L
.39819 .06234 L
.40809 .06246 L
.42665 .06273 L
.465 .06337 L
.50581 .06415 L
.54509 .06495 L
.58286 .06571 L
.62309 .0665 L
.66179 .06724 L
.70295 .068 L
.7426 .06872 L
.78073 .06939 L
.82131 .07009 L
.86037 .07076 L
.90189 .07146 L
.94189 .07213 L
.97619 .0727 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .04441 L
.04761 .0458 L
.05217 .04673 L
.06244 .04846 L
.08259 .05215 L
.09399 .05487 L
.10458 .05806 L
.11466 .06201 L
.1238 .06681 L
.12887 .07021 L
.13435 .07479 L
.13953 .0803 L
.14429 .08685 L
.14899 .09533 L
.15402 .10765 L
.15878 .12343 L
.16311 .14163 L
.1682 .16429 L
.16959 .16958 L
.17107 .17426 L
.17233 .17732 L
.17305 .17865 L
.17372 .1796 L
.17495 .18062 L
.17625 .18073 L
.17735 .1801 L
.17856 .17872 L
.17987 .17654 L
.18126 .17356 L
.18378 .16695 L
.19345 .13677 L
.20369 .10977 L
.20904 .09938 L
.21492 .09068 L
.22027 .08492 L
.22527 .08105 L
.22775 .0796 L
.23044 .07832 L
.23299 .07737 L
Mistroke
.23535 .07669 L
.23655 .07642 L
.23768 .0762 L
.23872 .07603 L
.2398 .07589 L
.24099 .07576 L
.24208 .07568 L
.24326 .07562 L
.24455 .07559 L
.24522 .07559 L
.24594 .0756 L
.24726 .07564 L
.24854 .07571 L
.24972 .07579 L
.25241 .07605 L
.25526 .07638 L
.25781 .0767 L
.26048 .07701 L
.26276 .07723 L
.26405 .07732 L
.26526 .07739 L
.26648 .07742 L
.26764 .07744 L
.26868 .07742 L
.2698 .07739 L
.27103 .07731 L
.27233 .0772 L
.27343 .07707 L
.27465 .0769 L
.27717 .07645 L
.27988 .07582 L
.28477 .07437 L
.30306 .0678 L
.31322 .06493 L
.31896 .06373 L
.32427 .06285 L
.32891 .06226 L
.33402 .06175 L
.33937 .06135 L
.34439 .06107 L
.34907 .06087 L
.3542 .0607 L
.36455 .06046 L
.37412 .0603 L
.38304 .06016 L
.40175 .0599 L
.41161 .05978 L
.42206 .05969 L
.42733 .05965 L
.43314 .05962 L
Mistroke
.43843 .05959 L
.44338 .05958 L
.44598 .05957 L
.44845 .05957 L
.45066 .05957 L
.45192 .05957 L
.45308 .05957 L
.45374 .05957 L
.45445 .05956 L
.45573 .05956 L
.45699 .05956 L
.45814 .05956 L
.45939 .05956 L
.46009 .05957 L
.46076 .05957 L
.46209 .05957 L
.46352 .05957 L
.46609 .05957 L
.46881 .05957 L
.4737 .05958 L
.48478 .05961 L
.5049 .05968 L
.54267 .05985 L
.5829 .06008 L
.6216 .06032 L
.66276 .06058 L
.70241 .06084 L
.74054 .06108 L
.78112 .06134 L
.82018 .06158 L
.8617 .06184 L
.9017 .06208 L
.94019 .06231 L
.97619 .06253 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04585 L
.05217 .04679 L
.06244 .04854 L
.08259 .05226 L
.09399 .055 L
.10458 .05822 L
.11466 .06222 L
.1238 .06708 L
.12887 .07054 L
.13435 .0752 L
.13953 .08083 L
.14429 .08755 L
.14899 .0963 L
.15402 .10912 L
.15878 .12581 L
.16311 .14544 L
.1682 .1707 L
.16959 .1768 L
.17107 .18232 L
.17233 .18606 L
.17301 .18766 L
.17372 .18902 L
.17503 .19062 L
.17622 .19112 L
.1775 .19069 L
.17823 .19004 L
.17891 .1892 L
.18014 .18713 L
.18126 .18473 L
.18378 .17798 L
.19388 .144 L
.19941 .12693 L
.20458 .11373 L
.20935 .10409 L
.21371 .09729 L
.21855 .09172 L
.22122 .08944 L
.22376 .08772 L
Mistroke
.22619 .08646 L
.22838 .08561 L
.2296 .08526 L
.23092 .08497 L
.23216 .08478 L
.23331 .08467 L
.23437 .08463 L
.23536 .08464 L
.23645 .08471 L
.23762 .08485 L
.23884 .08507 L
.24 .08534 L
.24216 .08603 L
.24459 .0871 L
.24716 .08858 L
.25178 .09218 L
.25675 .09745 L
.26222 .10486 L
.27167 .11948 L
.27642 .12566 L
.27911 .12829 L
.28031 .12923 L
.28161 .13007 L
.28235 .13046 L
.28303 .13077 L
.28367 .13102 L
.28437 .13124 L
.28559 .1315 L
.28688 .1316 L
.28761 .13158 L
.28828 .13152 L
.28906 .1314 L
.28979 .13123 L
.29109 .13082 L
.2925 .13022 L
.29501 .1288 L
.29768 .12687 L
.30248 .12267 L
.31206 .11312 L
.32215 .10377 L
.33077 .09736 L
.3402 .0921 L
.34503 .09004 L
.3502 .08821 L
.35952 .08574 L
.36514 .08462 L
.37044 .08376 L
.38037 .08249 L
.4188 .07897 L
.43826 .07738 L
Mistroke
.45969 .07589 L
.49906 .07395 L
.53937 .07251 L
.57816 .07135 L
.6194 .07033 L
.65913 .06953 L
.69735 .06888 L
.73801 .06832 L
.77716 .06788 L
.81876 .06749 L
.85885 .06718 L
.89742 .06693 L
.93844 .0667 L
.97619 .06651 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04585 L
.05217 .0468 L
.06244 .04855 L
.08259 .05229 L
.09399 .05504 L
.10458 .05827 L
.11466 .06229 L
.1238 .06718 L
.12887 .07067 L
.13435 .07537 L
.13953 .08107 L
.14429 .08789 L
.14899 .09679 L
.15402 .10988 L
.15878 .12696 L
.16311 .14705 L
.1682 .17258 L
.16959 .17861 L
.17107 .18398 L
.17233 .18753 L
.17305 .18907 L
.17372 .1902 L
.17495 .19146 L
.17625 .19171 L
.17735 .19111 L
.17856 .18969 L
.17987 .18739 L
.18126 .18419 L
.18378 .17702 L
.19345 .14382 L
.20369 .11426 L
.20904 .10323 L
.21187 .09858 L
.21492 .09441 L
.21771 .09128 L
.22027 .08894 L
.2229 .08701 L
.22527 .08564 L
Mistroke
.22774 .08456 L
.22909 .08411 L
.23037 .08377 L
.23155 .08353 L
.23264 .08336 L
.23383 .08325 L
.23509 .0832 L
.23636 .08321 L
.23708 .08326 L
.23773 .08331 L
.23899 .08348 L
.24019 .0837 L
.24158 .08403 L
.24287 .08442 L
.24578 .08555 L
.25028 .088 L
.25523 .09165 L
.26526 .10153 L
.27471 .11204 L
.27945 .1163 L
.28214 .11812 L
.28464 .11936 L
.28606 .11987 L
.28676 .12007 L
.2874 .12022 L
.28861 .12043 L
.28991 .12054 L
.29121 .12055 L
.29195 .1205 L
.29265 .12043 L
.29337 .12032 L
.29404 .1202 L
.29554 .11984 L
.29799 .11902 L
.30066 .11785 L
.30551 .11517 L
.32487 .1029 L
.33018 .10009 L
.3359 .09752 L
.34085 .09569 L
.34626 .09408 L
.35142 .09287 L
.35622 .092 L
.3613 .09129 L
.36672 .09073 L
.37178 .09035 L
.37655 .09008 L
.38549 .08968 L
.42393 .0876 L
.46482 .08471 L
Mistroke
.50419 .08265 L
.54204 .08096 L
.58235 .0793 L
.62114 .07793 L
.66238 .07669 L
.70211 .07571 L
.74033 .07492 L
.78099 .07425 L
.82014 .07372 L
.86174 .07326 L
.90183 .07289 L
.9404 .07259 L
.97619 .07235 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04858 L
.08259 .05235 L
.09399 .05513 L
.10458 .0584 L
.11466 .06248 L
.1238 .06746 L
.12887 .07103 L
.13435 .07586 L
.13953 .08176 L
.14429 .08887 L
.14899 .09824 L
.15402 .11221 L
.15878 .13072 L
.16311 .15271 L
.1682 .18037 L
.16959 .18668 L
.17107 .19213 L
.17233 .19556 L
.17305 .19698 L
.17372 .19795 L
.17495 .19884 L
.17625 .19862 L
.17735 .1976 L
.17856 .19571 L
.17987 .19293 L
.18126 .18928 L
.18378 .18147 L
.19345 .14769 L
.20369 .11868 L
.20904 .10775 L
.21492 .09878 L
.2175 .09572 L
.22027 .09297 L
.22527 .08921 L
.22793 .08777 L
.2304 .08675 L
Mistroke
.23311 .08593 L
.23462 .0856 L
.23529 .08548 L
.23599 .08538 L
.2373 .08523 L
.23851 .08514 L
.23981 .0851 L
.24055 .08511 L
.24123 .08512 L
.24248 .08519 L
.24362 .08528 L
.24493 .08544 L
.24617 .08562 L
.26526 .08948 L
.27025 .09045 L
.27494 .09169 L
.27982 .09339 L
.2852 .09563 L
.29401 .0993 L
.29867 .10089 L
.30364 .10219 L
.30632 .1027 L
.30875 .10307 L
.30992 .10321 L
.31119 .10333 L
.31238 .10343 L
.3135 .10351 L
.31474 .10357 L
.31546 .1036 L
.31612 .10362 L
.3168 .10364 L
.31746 .10366 L
.31814 .10367 L
.31889 .10367 L
.32014 .10367 L
.32077 .10367 L
.32147 .10366 L
.3227 .10364 L
.32386 .10362 L
.32813 .10349 L
.3327 .10334 L
.33405 .10331 L
.33532 .10328 L
.33647 .10326 L
.33771 .10324 L
.33889 .10324 L
.34014 .10324 L
.3412 .10324 L
.34238 .10326 L
.34365 .10329 L
Mistroke
.34482 .10332 L
.34617 .10337 L
.34745 .10344 L
.34972 .10358 L
.35219 .10378 L
.35756 .10438 L
.36253 .10514 L
.37149 .10693 L
.38103 .10924 L
.40102 .11416 L
.41153 .11627 L
.42263 .11797 L
.43259 .11911 L
.44352 .12006 L
.46272 .12134 L
.48388 .12256 L
.50316 .12353 L
.51274 .12393 L
.52316 .1243 L
.54209 .12479 L
.5515 .12496 L
.56188 .12512 L
.5829 .12537 L
.62312 .12575 L
.66183 .12611 L
.70299 .12657 L
.74263 .12717 L
.78076 .1279 L
.82134 .1288 L
.8604 .12978 L
.90192 .1309 L
.94192 .13201 L
.97619 .13295 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .04441 L
.04761 .0458 L
.05217 .04673 L
.06244 .04847 L
.08259 .05219 L
.09399 .05492 L
.10458 .05813 L
.11466 .06212 L
.1238 .06697 L
.12887 .07042 L
.13435 .07507 L
.13953 .0807 L
.14429 .08742 L
.14935 .09694 L
.15414 .10929 L
.15967 .12906 L
.16471 .15197 L
.16699 .16249 L
.16914 .17114 L
.1703 .175 L
.17137 .17786 L
.17256 .18019 L
.17384 .18168 L
.17504 .18211 L
.17636 .18157 L
.17702 .18094 L
.17773 .18002 L
.179 .17781 L
.1815 .17182 L
.18378 .16513 L
.19337 .13416 L
.19862 .11941 L
.20353 .108 L
.20806 .09952 L
.21221 .09332 L
.21681 .08795 L
.22175 .08368 L
.22646 .0808 L
.22912 .07959 L
Mistroke
.23159 .07872 L
.23396 .07807 L
.23611 .07763 L
.23731 .07745 L
.2386 .07729 L
.23981 .07717 L
.24093 .0771 L
.24214 .07705 L
.24343 .07703 L
.24465 .07703 L
.24576 .07706 L
.24706 .07712 L
.24848 .0772 L
.25105 .07739 L
.25371 .07762 L
.2551 .07773 L
.25656 .07784 L
.25785 .07791 L
.25858 .07794 L
.25926 .07797 L
.26045 .07799 L
.26173 .07797 L
.26295 .07793 L
.26427 .07785 L
.26552 .07773 L
.26667 .07758 L
.26885 .07723 L
.27115 .07673 L
.2761 .07533 L
.28154 .07344 L
.29253 .0696 L
.29734 .06819 L
.30256 .06693 L
.30776 .06594 L
.31257 .06522 L
.31716 .06469 L
.32205 .06425 L
.32717 .06391 L
.33198 .06368 L
.33726 .0635 L
.34023 .06342 L
.34296 .06336 L
.34539 .06332 L
.34769 .0633 L
.34896 .06328 L
.35033 .06327 L
.35148 .06326 L
.35274 .06326 L
.35393 .06325 L
.35504 .06325 L
Mistroke
.35622 .06325 L
.35748 .06325 L
.35865 .06325 L
.35977 .06325 L
.36077 .06325 L
.36186 .06326 L
.36326 .06326 L
.36458 .06327 L
.36705 .06329 L
.37259 .06334 L
.37737 .06341 L
.38255 .06349 L
.4025 .06392 L
.42357 .06445 L
.46156 .06534 L
.50201 .06625 L
.54094 .06713 L
.58232 .06802 L
.62218 .06886 L
.66053 .06965 L
.70133 .07048 L
.74062 .07128 L
.77839 .07204 L
.81861 .07285 L
.85732 .07364 L
.89848 .07448 L
.93812 .07529 L
.97619 .07606 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04669 L
.06244 .04839 L
.08259 .05202 L
.09399 .05469 L
.10458 .05782 L
.11466 .06168 L
.1238 .06633 L
.12887 .06962 L
.13435 .07399 L
.13953 .07921 L
.14429 .08534 L
.14935 .09384 L
.15414 .10453 L
.15967 .12105 L
.16471 .1397 L
.16914 .15558 L
.17137 .16156 L
.17265 .16396 L
.17384 .16547 L
.17514 .16624 L
.17633 .16619 L
.17763 .16534 L
.17828 .16463 L
.179 .16364 L
.18148 .15888 L
.18378 .15303 L
.19315 .12479 L
.19808 .11126 L
.20331 .09937 L
.20788 .09111 L
.2129 .08413 L
.21747 .07941 L
.22175 .07616 L
.22439 .07462 L
.2269 .07345 L
.22915 .07262 L
.23161 .07191 L
Mistroke
.23427 .07137 L
.23576 .07115 L
.23646 .07107 L
.23711 .07101 L
.23837 .07092 L
.23903 .07088 L
.23973 .07086 L
.24091 .07084 L
.2422 .07086 L
.24345 .07091 L
.24464 .07098 L
.2457 .07106 L
.24685 .07118 L
.24944 .0715 L
.25182 .07189 L
.26079 .07371 L
.26544 .07464 L
.26788 .07505 L
.27045 .0754 L
.27154 .07552 L
.2727 .07562 L
.27398 .07571 L
.27517 .07576 L
.27634 .07578 L
.27744 .07577 L
.27843 .07574 L
.2795 .07569 L
.28078 .0756 L
.28198 .07548 L
.28471 .07511 L
.28737 .07461 L
.29023 .07395 L
.30011 .071 L
.3097 .06793 L
.3199 .06519 L
.32521 .06408 L
.33108 .06309 L
.33642 .06239 L
.34144 .06188 L
.3463 .06149 L
.35143 .06117 L
.36059 .06075 L
.37045 .06042 L
.38125 .06011 L
.40248 .05951 L
.42178 .059 L
.4314 .05878 L
.44184 .05859 L
.46079 .05832 L
.47024 .05823 L
Mistroke
.48065 .05814 L
.50168 .05798 L
.52274 .05786 L
.54199 .05777 L
.56188 .0577 L
.58078 .05764 L
.6006 .0576 L
.61899 .05757 L
.63953 .05755 L
.65814 .05753 L
.66818 .05753 L
.6774 .05752 L
.68753 .05752 L
.69823 .05751 L
.70772 .05751 L
.71304 .05751 L
.71788 .05751 L
.7224 .05751 L
.72495 .05751 L
.7273 .05751 L
.72936 .05751 L
.73054 .05751 L
.73163 .05751 L
.73277 .05751 L
.734 .05751 L
.73508 .05751 L
.73622 .05751 L
.73746 .05751 L
.73816 .05751 L
.7388 .05751 L
.73998 .05751 L
.74123 .05751 L
.74339 .05751 L
.74578 .05751 L
.74832 .05751 L
.75105 .05751 L
.75598 .05751 L
.76558 .05751 L
.77435 .05751 L
.79339 .05752 L
.81413 .05752 L
.85485 .05753 L
.89405 .05755 L
.9357 .05757 L
.97584 .05758 L
.97619 .05758 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03776 L
.03527 .04018 L
.03652 .0411 L
.0379 .04194 L
.04033 .04311 L
.04262 .04392 L
.04517 .04463 L
.04761 .04517 L
.05217 .046 L
.06244 .04753 L
.07302 .04914 L
.08429 .05115 L
.09474 .05341 L
.10458 .05602 L
.1142 .05922 L
.12461 .06375 L
.13407 .06938 L
.14277 .0766 L
.15263 .08849 L
.15805 .09709 L
.16319 .10586 L
.16551 .10945 L
.16797 .1125 L
.16925 .11363 L
.16998 .11411 L
.17067 .11443 L
.17187 .1147 L
.17317 .11455 L
.17427 .11405 L
.17548 .11314 L
.17674 .11181 L
.17791 .11026 L
.18226 .10272 L
.1917 .08455 L
.19634 .07743 L
.20062 .07228 L
.20555 .06788 L
.20815 .06613 L
.21089 .06463 L
.21304 .06368 L
.21534 .06285 L
.21787 .06214 L
.22023 .06165 L
.22154 .06144 L
Mistroke
.22278 .06127 L
.2242 .06113 L
.22549 .06103 L
.22671 .06097 L
.22783 .06093 L
.22906 .06092 L
.23036 .06094 L
.23168 .06097 L
.23242 .06101 L
.23309 .06104 L
.23563 .06124 L
.23705 .06138 L
.2386 .06156 L
.24141 .06195 L
.25185 .06401 L
.26151 .06644 L
.27051 .0686 L
.27298 .06908 L
.27558 .0695 L
.27779 .0698 L
.27904 .06993 L
.28021 .07004 L
.28088 .07009 L
.28161 .07013 L
.28288 .0702 L
.2836 .07022 L
.28436 .07023 L
.28501 .07024 L
.28573 .07024 L
.287 .07022 L
.28772 .0702 L
.28838 .07017 L
.28965 .0701 L
.29085 .07001 L
.29333 .06976 L
.29563 .06947 L
.30083 .06859 L
.32106 .06425 L
.33097 .06249 L
.33531 .06188 L
.34006 .06132 L
.3489 .06053 L
.35372 .06021 L
.3582 .05997 L
.36766 .05958 L
.37778 .05924 L
.41925 .05794 L
.44002 .05739 L
.45919 .05701 L
.47786 .05675 L
Mistroke
.49763 .05653 L
.53548 .0562 L
.57579 .05593 L
.61458 .05575 L
.65583 .05561 L
.69556 .05551 L
.73377 .05543 L
.77443 .05537 L
.81358 .05532 L
.85519 .05528 L
.89527 .05524 L
.93384 .05521 L
.97487 .05517 L
.97619 .05517 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04668 L
.06244 .04838 L
.08259 .052 L
.09399 .05466 L
.10458 .05777 L
.11466 .06161 L
.1238 .06622 L
.12887 .06948 L
.13435 .0738 L
.13953 .07895 L
.14429 .08498 L
.14935 .0933 L
.15414 .10371 L
.15967 .11964 L
.16471 .13742 L
.16914 .15231 L
.17021 .15518 L
.17137 .15777 L
.17265 .15989 L
.17384 .16115 L
.17515 .1617 L
.17581 .16164 L
.17653 .16134 L
.17781 .16022 L
.179 .15856 L
.18021 .15636 L
.18131 .15397 L
.18378 .14761 L
.19337 .11886 L
.19862 .1051 L
.20353 .09473 L
.20771 .0878 L
.21221 .08209 L
.21476 .07955 L
.21719 .07754 L
.22175 .07471 L
.22405 .07368 L
Mistroke
.22651 .07283 L
.2277 .0725 L
.22883 .07224 L
.22983 .07204 L
.23093 .07187 L
.23215 .07172 L
.23343 .07161 L
.23463 .07155 L
.23574 .07152 L
.23705 .07154 L
.23825 .07159 L
.23891 .07164 L
.23963 .0717 L
.24093 .07183 L
.24343 .0722 L
.24618 .07274 L
.25174 .07422 L
.26173 .07764 L
.27118 .08135 L
.27593 .08293 L
.27723 .08327 L
.27862 .08358 L
.27992 .08382 L
.28112 .08398 L
.2818 .08406 L
.28253 .08412 L
.28325 .08416 L
.28405 .08418 L
.28475 .08418 L
.28549 .08416 L
.28619 .08413 L
.28683 .08408 L
.2881 .08395 L
.28949 .08374 L
.29201 .08322 L
.29452 .08252 L
.29719 .08163 L
.30199 .07972 L
.31156 .07546 L
.32165 .07127 L
.331 .06817 L
.3397 .066 L
.34893 .06432 L
.35903 .06302 L
.3691 .06208 L
.37987 .06135 L
.3901 .06081 L
.4012 .06035 L
.42134 .05971 L
.44119 .05926 L
Mistroke
.4512 .05909 L
.46223 .05894 L
.48165 .05874 L
.50253 .05858 L
.52226 .05847 L
.54378 .05836 L
.58351 .05822 L
.62417 .0581 L
.66332 .05802 L
.70492 .05794 L
.74501 .05788 L
.78358 .05784 L
.8246 .05779 L
.86411 .05775 L
.9021 .05772 L
.94255 .05769 L
.97619 .05766 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04674 L
.06244 .04848 L
.08259 .05217 L
.09399 .05488 L
.10458 .05807 L
.11466 .06203 L
.1238 .06681 L
.12887 .07022 L
.13435 .07478 L
.13953 .08028 L
.14429 .08681 L
.14899 .09525 L
.15402 .10751 L
.15878 .12324 L
.16311 .1415 L
.1682 .16469 L
.16959 .17026 L
.17107 .17531 L
.17233 .17874 L
.17301 .1802 L
.17372 .18144 L
.17503 .1829 L
.17622 .18334 L
.1775 .18293 L
.17823 .18231 L
.17891 .18152 L
.18014 .17958 L
.18126 .17733 L
.18378 .17103 L
.19388 .13933 L
.19941 .1232 L
.20458 .11044 L
.20935 .10082 L
.21371 .09374 L
.21855 .08758 L
.22107 .08501 L
.22376 .08269 L
Mistroke
.22633 .08084 L
.22866 .07945 L
.23102 .07828 L
.2332 .07742 L
.23575 .07663 L
.23706 .07631 L
.2385 .07602 L
.23967 .07583 L
.24093 .07568 L
.24162 .07561 L
.24226 .07556 L
.24349 .07548 L
.24465 .07545 L
.24589 .07544 L
.24694 .07546 L
.2481 .07551 L
.24935 .07559 L
.25069 .0757 L
.25312 .07596 L
.26222 .07723 L
.26463 .07751 L
.26595 .07764 L
.2672 .07773 L
.26836 .07779 L
.26962 .07783 L
.27077 .07784 L
.27182 .07783 L
.27308 .07778 L
.27425 .0777 L
.27554 .07759 L
.27692 .07742 L
.27973 .07695 L
.2823 .07638 L
.28749 .07489 L
.29314 .07292 L
.30342 .06916 L
.3136 .06601 L
.32317 .06388 L
.32797 .0631 L
.33314 .06244 L
.33889 .06188 L
.34417 .0615 L
.3489 .06123 L
.35395 .06102 L
.36307 .06073 L
.3739 .06048 L
.38376 .06028 L
.40454 .05987 L
.41366 .05971 L
.42371 .05957 L
Mistroke
.43335 .05945 L
.44237 .05937 L
.4519 .05931 L
.45725 .05929 L
.46214 .05927 L
.46691 .05926 L
.472 .05925 L
.47447 .05924 L
.47679 .05924 L
.48114 .05923 L
.48367 .05923 L
.48504 .05923 L
.48633 .05923 L
.48752 .05923 L
.48861 .05923 L
.48981 .05923 L
.4911 .05923 L
.49177 .05923 L
.49248 .05923 L
.49375 .05923 L
.49446 .05923 L
.49512 .05923 L
.49585 .05923 L
.49663 .05923 L
.49796 .05923 L
.49937 .05923 L
.50187 .05923 L
.50445 .05923 L
.50688 .05923 L
.51142 .05924 L
.52163 .05925 L
.53044 .05926 L
.54 .05928 L
.55989 .05933 L
.58094 .0594 L
.61884 .05953 L
.6592 .05969 L
.69805 .05984 L
.73934 .06001 L
.77913 .06016 L
.81739 .06031 L
.85811 .06046 L
.89731 .06061 L
.93896 .06076 L
.97619 .06089 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04214 L
.04033 .04334 L
.04262 .04419 L
.04761 .0455 L
.05217 .04637 L
.06244 .04798 L
.08259 .05144 L
.09399 .05397 L
.10458 .05692 L
.11466 .06051 L
.1238 .06478 L
.12887 .06774 L
.13435 .07163 L
.14429 .08134 L
.15372 .09571 L
.15901 .10678 L
.16384 .1181 L
.16656 .1241 L
.168 .1268 L
.16953 .12914 L
.17018 .12992 L
.17087 .13061 L
.17163 .13119 L
.17234 .13155 L
.173 .13172 L
.17369 .13173 L
.17493 .13131 L
.17617 .13037 L
.17686 .12962 L
.1775 .12882 L
.17988 .12489 L
.18529 .1128 L
.19504 .09094 L
.20054 .08168 L
.2056 .07532 L
.21004 .07123 L
.21492 .06802 L
.21737 .06682 L
.22001 .0658 L
.2225 .06505 L
.22478 .06453 L
Mistroke
.22607 .0643 L
.22729 .06411 L
.22839 .06397 L
.22956 .06386 L
.23084 .06376 L
.23201 .06369 L
.23327 .06365 L
.23398 .06364 L
.23465 .06363 L
.23584 .06364 L
.23696 .06366 L
.23797 .06369 L
.23907 .06374 L
.24153 .06389 L
.2438 .06407 L
.249 .06453 L
.25154 .06473 L
.25265 .0648 L
.25386 .06487 L
.25506 .06491 L
.25631 .06493 L
.25697 .06493 L
.25767 .06492 L
.25894 .06489 L
.25967 .06485 L
.26045 .0648 L
.26188 .06469 L
.26454 .06441 L
.28406 .06152 L
.30551 .05901 L
.31535 .05797 L
.32591 .05704 L
.33102 .05669 L
.33587 .05641 L
.34497 .05603 L
.34955 .05588 L
.3546 .05576 L
.36485 .05556 L
.38326 .05531 L
.40259 .0551 L
.40788 .05506 L
.41346 .05502 L
.41868 .05498 L
.42343 .05496 L
.42833 .05494 L
.43296 .05493 L
.4355 .05493 L
.43785 .05492 L
.43908 .05492 L
.44042 .05492 L
Mistroke
.4411 .05492 L
.44183 .05492 L
.44315 .05492 L
.44437 .05492 L
.4455 .05492 L
.44675 .05492 L
.44744 .05492 L
.44807 .05492 L
.44923 .05492 L
.45048 .05492 L
.45274 .05492 L
.45731 .05493 L
.46151 .05493 L
.50102 .055 L
.53901 .05505 L
.57945 .0551 L
.61838 .05514 L
.63821 .05516 L
.65976 .05518 L
.69963 .0552 L
.71942 .0552 L
.74043 .05521 L
.75992 .05521 L
.7782 .05522 L
.78804 .05522 L
.7984 .05522 L
.80724 .05522 L
.81691 .05522 L
.8222 .05522 L
.82719 .05522 L
.83168 .05522 L
.8342 .05522 L
.83653 .05522 L
.83774 .05522 L
.83904 .05522 L
.84016 .05522 L
.84138 .05522 L
.84213 .05522 L
.84281 .05522 L
.84347 .05522 L
.84417 .05522 L
.84486 .05522 L
.84551 .05522 L
.84672 .05522 L
.84803 .05522 L
.84869 .05522 L
.84942 .05522 L
.8519 .05522 L
.85329 .05522 L
.85479 .05522 L
Mistroke
.85749 .05522 L
.8628 .05522 L
.8677 .05522 L
.87879 .05522 L
.89892 .05522 L
.93826 .05522 L
.97608 .05521 L
.97619 .05521 L
Mfstroke
.53 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04585 L
.05217 .0468 L
.06244 .04856 L
.08259 .05232 L
.09399 .05508 L
.10458 .05834 L
.11466 .06239 L
.1238 .06734 L
.12887 .07088 L
.13435 .07566 L
.13953 .08148 L
.14429 .08848 L
.14899 .09766 L
.15402 .11127 L
.15878 .12914 L
.16311 .15019 L
.1682 .17645 L
.16959 .18244 L
.17107 .1876 L
.17233 .19085 L
.17305 .19219 L
.17372 .1931 L
.17495 .19393 L
.17625 .19369 L
.17735 .19269 L
.17856 .19085 L
.17987 .18814 L
.18126 .18459 L
.18378 .17701 L
.19345 .14419 L
.20369 .11598 L
.20904 .1053 L
.21492 .09643 L
.22027 .09058 L
.22527 .08665 L
.22775 .08518 L
.23044 .08388 L
.23299 .08292 L
Mistroke
.23535 .08223 L
.23655 .08195 L
.23768 .08173 L
.2398 .0814 L
.24099 .08127 L
.24208 .08119 L
.24328 .08112 L
.24455 .08108 L
.24584 .08107 L
.24702 .08109 L
.24767 .08111 L
.24838 .08113 L
.24966 .08119 L
.25443 .08147 L
.25584 .08155 L
.25716 .08159 L
.25782 .08161 L
.25854 .08161 L
.25933 .08161 L
.26006 .0816 L
.26127 .08155 L
.26195 .08151 L
.26259 .08146 L
.26388 .08132 L
.26526 .08113 L
.26785 .08065 L
.2706 .07995 L
.27552 .07835 L
.28664 .07413 L
.29625 .07114 L
.30171 .06991 L
.30681 .06903 L
.3118 .06839 L
.31724 .06788 L
.32238 .06753 L
.32713 .06729 L
.3314 .06714 L
.33384 .06707 L
.33612 .06702 L
.33852 .06697 L
.34072 .06694 L
.34187 .06693 L
.34314 .06692 L
.34445 .06691 L
.34568 .06691 L
.34695 .06691 L
.3476 .06691 L
.3483 .06691 L
.34955 .06691 L
.35072 .06692 L
Mistroke
.3521 .06693 L
.35336 .06694 L
.35619 .06697 L
.35862 .06701 L
.36128 .06707 L
.36611 .06719 L
.37575 .06752 L
.38469 .06793 L
.42384 .07016 L
.46545 .07223 L
.50553 .07411 L
.5441 .07589 L
.58513 .07767 L
.62463 .07933 L
.66263 .08088 L
.70307 .0825 L
.742 .08403 L
.78338 .08565 L
.82324 .0872 L
.86159 .0887 L
.9024 .09029 L
.94168 .09182 L
.97619 .09314 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04346 L
.04262 .04432 L
.04761 .04566 L
.05217 .04655 L
.06244 .0482 L
.08259 .05172 L
.09399 .0543 L
.10458 .05731 L
.11466 .061 L
.1238 .0654 L
.12887 .06846 L
.13435 .07249 L
.14429 .08266 L
.16384 .12256 L
.16659 .12947 L
.16919 .13485 L
.17063 .13701 L
.17144 .13792 L
.17219 .13853 L
.17283 .13888 L
.17352 .13908 L
.17425 .13907 L
.17493 .13888 L
.1762 .13804 L
.17684 .13739 L
.17753 .13653 L
.17992 .1325 L
.18529 .11964 L
.19518 .09527 L
.20072 .08501 L
.20575 .07807 L
.21044 .07334 L
.21309 .0713 L
.21554 .06976 L
.22003 .06765 L
.22229 .06689 L
.22478 .06625 L
.22727 .06579 L
.22868 .0656 L
.22999 .06547 L
Mistroke
.23125 .06538 L
.23239 .06533 L
.2337 .0653 L
.23494 .0653 L
.23607 .06533 L
.23727 .06539 L
.23829 .06545 L
.2394 .06554 L
.2419 .06581 L
.24423 .06613 L
.24951 .0671 L
.25432 .0682 L
.26512 .07101 L
.26994 .07212 L
.27258 .07262 L
.27506 .073 L
.27716 .07324 L
.27834 .07334 L
.27943 .07342 L
.28055 .07347 L
.28177 .0735 L
.28305 .0735 L
.28424 .07348 L
.28554 .07342 L
.28628 .07337 L
.28695 .07332 L
.28951 .07306 L
.29184 .07272 L
.29429 .07229 L
.30502 .06969 L
.3152 .06695 L
.32485 .06472 L
.33352 .06322 L
.33842 .06257 L
.34296 .06209 L
.3524 .06135 L
.35717 .06108 L
.36244 .06084 L
.38335 .06012 L
.4043 .05944 L
.42352 .05884 L
.44234 .05836 L
.46217 .058 L
.48189 .05774 L
.50025 .05754 L
.53926 .05721 L
.55915 .05708 L
.58073 .05696 L
.62068 .05679 L
.66156 .05667 L
Mistroke
.70094 .05658 L
.73879 .05651 L
.7791 .05645 L
.81789 .05641 L
.85913 .05637 L
.89886 .05634 L
.93708 .05631 L
.97619 .05628 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04347 L
.04262 .04434 L
.04761 .04569 L
.05217 .04658 L
.06244 .04825 L
.08259 .0518 L
.09399 .0544 L
.10458 .05745 L
.11466 .06119 L
.1238 .06566 L
.12887 .06879 L
.13435 .07292 L
.14429 .08344 L
.16384 .12666 L
.16659 .1346 L
.16919 .14098 L
.17063 .14367 L
.17144 .14485 L
.17219 .14571 L
.17283 .14624 L
.17352 .14663 L
.17425 .14681 L
.17493 .14677 L
.1762 .14617 L
.17684 .14563 L
.17753 .14486 L
.17877 .14309 L
.17992 .14103 L
.18529 .12802 L
.19511 .10219 L
.19994 .09205 L
.20438 .08463 L
.20951 .07817 L
.21221 .07555 L
.21507 .07328 L
.21969 .07055 L
.22232 .06943 L
.22478 .06862 L
.22603 .06829 L
.22736 .06799 L
Mistroke
.22976 .06758 L
.23123 .0674 L
.23195 .06734 L
.23261 .06728 L
.23385 .06721 L
.2345 .06719 L
.23519 .06717 L
.23636 .06716 L
.23763 .06718 L
.23882 .06722 L
.2399 .06728 L
.24117 .06736 L
.24255 .06748 L
.24507 .06775 L
.24967 .06834 L
.25463 .06898 L
.25692 .06921 L
.25932 .0694 L
.26136 .06952 L
.2636 .06962 L
.26597 .0697 L
.26849 .06977 L
.27067 .06983 L
.27303 .06988 L
.27449 .0699 L
.27513 .06991 L
.27583 .06992 L
.27712 .06992 L
.27782 .06992 L
.27847 .06992 L
.27972 .06991 L
.28086 .06989 L
.28217 .06985 L
.28342 .0698 L
.28462 .06973 L
.28595 .06964 L
.28864 .0694 L
.29114 .0691 L
.29348 .06876 L
.30444 .06658 L
.32289 .0625 L
.33335 .06075 L
.33845 .06009 L
.34309 .05959 L
.35277 .05878 L
.35808 .05844 L
.36311 .05817 L
.37335 .05773 L
.3842 .05738 L
.39371 .05712 L
Mistroke
.40419 .0569 L
.41365 .05673 L
.42263 .05661 L
.43278 .05651 L
.44206 .05643 L
.45205 .05638 L
.4577 .05636 L
.46294 .05634 L
.47352 .05631 L
.48348 .0563 L
.50209 .05627 L
.51186 .05626 L
.52218 .05626 L
.53185 .05625 L
.54066 .05625 L
.54554 .05624 L
.55015 .05624 L
.55502 .05624 L
.55754 .05624 L
.56032 .05624 L
.56254 .05624 L
.56494 .05624 L
.56747 .05624 L
.5686 .05624 L
.56984 .05624 L
.57093 .05624 L
.57208 .05624 L
.5733 .05624 L
.57444 .05624 L
.57558 .05624 L
.57665 .05624 L
.57761 .05624 L
.57865 .05624 L
.57989 .05624 L
.58101 .05624 L
.58232 .05624 L
.58355 .05624 L
.58813 .05624 L
.59311 .05624 L
.59854 .05624 L
.60959 .05624 L
.61959 .05624 L
.62976 .05624 L
.63932 .05624 L
.64458 .05624 L
.64941 .05624 L
.65194 .05624 L
.65472 .05624 L
.65612 .05624 L
.65688 .05624 L
Mistroke
.65761 .05624 L
.65829 .05624 L
.65902 .05624 L
.66031 .05624 L
.66153 .05624 L
.66266 .05624 L
.66395 .05624 L
.66518 .05624 L
.66631 .05624 L
.66736 .05624 L
.66974 .05624 L
.67238 .05624 L
.67477 .05624 L
.68014 .05624 L
.68534 .05624 L
.69096 .05624 L
.70116 .05624 L
.71066 .05624 L
.72109 .05624 L
.74216 .05624 L
.78257 .05623 L
.82146 .05622 L
.86281 .05622 L
.90265 .05621 L
.94096 .0562 L
.97619 .05619 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04585 L
.05217 .04678 L
.06244 .04853 L
.08259 .05224 L
.09399 .05497 L
.10458 .05818 L
.11466 .06216 L
.1238 .06699 L
.12887 .07043 L
.13435 .07505 L
.13953 .08063 L
.14429 .08727 L
.14899 .0959 L
.15402 .10851 L
.15878 .12488 L
.16311 .14415 L
.1682 .16918 L
.16959 .17532 L
.17107 .18096 L
.17233 .18486 L
.17301 .18656 L
.17372 .18804 L
.17503 .18987 L
.17622 .19061 L
.1775 .19045 L
.17823 .18994 L
.17891 .18924 L
.18014 .1874 L
.18126 .18521 L
.18378 .17887 L
.19388 .14589 L
.19941 .12903 L
.20458 .11591 L
.20935 .10629 L
.21371 .09948 L
.21855 .0939 L
.22122 .09161 L
.22376 .08991 L
Mistroke
.22619 .08867 L
.22838 .08786 L
.2296 .08754 L
.23092 .08728 L
.23216 .08713 L
.23331 .08707 L
.23437 .08708 L
.23536 .08715 L
.23645 .08728 L
.23762 .0875 L
.23884 .08782 L
.24 .0882 L
.24216 .08915 L
.24459 .09058 L
.24716 .09258 L
.25178 .09759 L
.25675 .10521 L
.26222 .11597 L
.26712 .12645 L
.27167 .13529 L
.27416 .13924 L
.27642 .14211 L
.27763 .14334 L
.27893 .14443 L
.27965 .14491 L
.28031 .14529 L
.28161 .14585 L
.28291 .14615 L
.28413 .14622 L
.28483 .14617 L
.28547 .14607 L
.28621 .14589 L
.2869 .14565 L
.2883 .14502 L
.28959 .14424 L
.2925 .14191 L
.29734 .1367 L
.30248 .13008 L
.31206 .11716 L
.32215 .10519 L
.33077 .09715 L
.3402 .09053 L
.3502 .0855 L
.35952 .08214 L
.3696 .07949 L
.38037 .07741 L
.39059 .07589 L
.40169 .07455 L
.42183 .07257 L
.44169 .071 L
Mistroke
.46272 .06974 L
.48227 .06887 L
.50058 .06826 L
.53937 .06729 L
.58061 .06652 L
.62034 .06596 L
.65855 .06554 L
.69922 .06518 L
.73837 .0649 L
.77997 .06467 L
.82006 .06448 L
.85863 .06433 L
.89965 .06419 L
.93916 .06407 L
.97619 .06398 L
Mfstroke
.435 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04858 L
.08259 .05236 L
.09399 .05513 L
.10458 .05841 L
.11466 .06248 L
.1238 .06747 L
.12887 .07105 L
.13435 .07589 L
.13953 .0818 L
.14429 .08893 L
.14899 .09834 L
.15402 .1124 L
.15878 .13106 L
.16311 .15331 L
.1682 .18144 L
.16959 .1879 L
.17107 .1935 L
.17233 .19706 L
.17305 .19853 L
.17372 .19956 L
.17495 .20055 L
.17625 .20042 L
.17735 .19947 L
.17856 .19766 L
.17987 .19495 L
.18126 .19138 L
.18378 .18372 L
.19345 .15047 L
.20369 .12179 L
.20904 .11087 L
.21492 .10176 L
.22027 .09572 L
.22527 .09169 L
.22775 .09019 L
.23044 .08889 L
.23299 .08794 L
Mistroke
.2342 .08758 L
.23535 .08729 L
.23647 .08705 L
.23768 .08684 L
.23879 .0867 L
.2398 .0866 L
.2409 .08652 L
.24211 .08648 L
.24337 .08648 L
.24455 .08651 L
.24584 .08658 L
.24657 .08663 L
.24724 .08669 L
.24978 .08698 L
.25455 .08762 L
.25584 .08778 L
.25723 .08793 L
.25846 .08805 L
.25974 .08814 L
.2604 .08818 L
.26111 .08821 L
.26237 .08825 L
.26309 .08826 L
.26386 .08827 L
.26459 .08827 L
.26526 .08826 L
.26645 .08825 L
.26757 .08822 L
.26891 .08819 L
.27012 .08816 L
.27139 .08814 L
.2726 .08812 L
.27388 .08812 L
.2746 .08813 L
.27526 .08814 L
.27636 .08817 L
.27739 .08821 L
.27851 .08827 L
.27973 .08836 L
.28221 .08859 L
.28448 .08887 L
.29526 .0907 L
.30051 .09158 L
.30529 .09224 L
.30754 .09249 L
.30999 .09271 L
.3121 .09287 L
.31442 .09301 L
.31689 .09312 L
.31824 .09316 L
Mistroke
.3195 .09319 L
.32066 .09322 L
.32176 .09324 L
.32303 .09326 L
.32419 .09327 L
.32549 .09328 L
.32668 .09329 L
.32932 .0933 L
.3305 .09331 L
.33178 .09332 L
.33409 .09334 L
.33539 .09336 L
.33682 .09338 L
.33832 .09342 L
.33971 .09345 L
.34221 .09354 L
.34488 .09368 L
.34745 .09384 L
.35017 .09405 L
.35507 .09455 L
.36033 .09527 L
.36614 .09625 L
.38626 .10083 L
.40725 .10592 L
.42649 .1096 L
.44535 .11231 L
.46519 .11471 L
.50332 .11901 L
.5439 .12288 L
.58297 .12595 L
.62449 .1289 L
.66449 .13159 L
.70297 .13411 L
.74391 .13679 L
.78334 .1394 L
.82124 .14193 L
.8616 .14466 L
.90045 .14729 L
.94174 .15006 L
.97619 .15231 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04443 L
.04761 .04583 L
.05217 .04677 L
.06244 .04852 L
.08259 .05226 L
.09399 .05501 L
.10458 .05825 L
.11466 .06228 L
.1238 .06718 L
.12887 .07069 L
.13435 .07541 L
.13953 .08115 L
.14429 .08803 L
.14899 .09703 L
.15402 .11028 L
.15878 .12754 L
.16311 .14766 L
.1682 .1724 L
.16959 .17795 L
.17107 .18269 L
.17233 .18561 L
.17305 .18678 L
.17372 .18754 L
.17495 .18814 L
.17625 .18771 L
.17735 .18658 L
.17856 .18464 L
.17987 .18185 L
.18126 .17825 L
.18378 .17066 L
.19402 .13664 L
.19941 .12137 L
.20512 .10837 L
.21011 .09955 L
.21561 .09224 L
.2206 .08741 L
.22527 .08417 L
.22786 .08283 L
.23025 .08183 L
Mistroke
.23288 .08098 L
.23423 .08063 L
.23568 .08033 L
.23707 .08009 L
.23835 .07992 L
.23958 .0798 L
.24087 .07971 L
.24202 .07966 L
.24311 .07964 L
.24429 .07965 L
.24556 .07968 L
.25024 .07998 L
.2528 .0802 L
.2552 .08039 L
.25619 .08045 L
.25723 .0805 L
.25838 .08054 L
.25943 .08055 L
.26059 .08054 L
.26166 .08051 L
.26284 .08043 L
.2641 .08032 L
.26542 .08017 L
.26685 .07996 L
.26945 .07947 L
.2743 .07828 L
.28538 .07523 L
.29047 .07406 L
.29586 .07308 L
.30046 .07245 L
.30551 .07191 L
.31074 .0715 L
.3157 .0712 L
.32021 .07098 L
.325 .0708 L
.32747 .07072 L
.33019 .07065 L
.3327 .07059 L
.33501 .07055 L
.33771 .07051 L
.33913 .0705 L
.33985 .07049 L
.34062 .07049 L
.34193 .07048 L
.34314 .07048 L
.34389 .07048 L
.34459 .07048 L
.3459 .07049 L
.34705 .0705 L
.34829 .07051 L
Mistroke
.35052 .07053 L
.35318 .07058 L
.35561 .07064 L
.36088 .07081 L
.36589 .07102 L
.37471 .07151 L
.38434 .07218 L
.425 .07528 L
.46415 .07744 L
.50575 .07948 L
.54584 .08129 L
.58441 .08284 L
.62543 .08441 L
.66494 .08588 L
.70293 .08726 L
.74338 .08872 L
.78231 .09014 L
.82369 .09165 L
.86355 .09312 L
.9019 .09455 L
.9427 .09605 L
.97619 .09727 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04862 L
.08259 .05241 L
.09399 .0552 L
.10458 .0585 L
.11466 .0626 L
.1238 .06764 L
.12887 .07126 L
.13435 .07616 L
.13953 .08217 L
.14429 .08945 L
.14899 .09911 L
.15157 .10592 L
.15402 .11365 L
.15878 .13319 L
.16311 .15686 L
.16791 .1859 L
.17034 .19808 L
.17171 .20331 L
.17301 .20687 L
.17369 .2082 L
.17441 .20919 L
.1757 .20997 L
.17642 .20988 L
.17709 .20949 L
.17782 .20875 L
.1786 .20763 L
.18 .20492 L
.18131 .20165 L
.18378 .19426 L
.19261 .16311 L
.20209 .13357 L
.20753 .12054 L
.2125 .11119 L
.2175 .10406 L
.22224 .09918 L
.22463 .09734 L
Mistroke
.22718 .0958 L
.22841 .0952 L
.22958 .09471 L
.23061 .09435 L
.23175 .09403 L
.23302 .09375 L
.23371 .09363 L
.23435 .09355 L
.2355 .09346 L
.23673 .09344 L
.23743 .09346 L
.23818 .09352 L
.23889 .0936 L
.23955 .09369 L
.2408 .09394 L
.24212 .09428 L
.24461 .09518 L
.24728 .09648 L
.25213 .09968 L
.25789 .10463 L
.26316 .11025 L
.27311 .12444 L
.28373 .14142 L
.28888 .14809 L
.29142 .15071 L
.29375 .15271 L
.29583 .15415 L
.29811 .15539 L
.30041 .15627 L
.30166 .15661 L
.30284 .15684 L
.30407 .15701 L
.3052 .15709 L
.30645 .15711 L
.30708 .15709 L
.30778 .15705 L
.30894 .15694 L
.31019 .15677 L
.31246 .15633 L
.31469 .15576 L
.31704 .15506 L
.32125 .15364 L
.33079 .15035 L
.33569 .14897 L
.33845 .14834 L
.341 .14787 L
.34358 .14752 L
.34488 .14738 L
.34562 .14731 L
.34631 .14726 L
Mistroke
.34756 .14719 L
.34824 .14717 L
.3489 .14715 L
.35006 .14713 L
.35132 .14715 L
.35256 .14718 L
.35368 .14724 L
.35498 .14733 L
.3562 .14744 L
.35837 .14768 L
.36071 .14802 L
.36537 .14889 L
.37028 .15002 L
.37907 .15235 L
.38856 .15483 L
.39378 .15602 L
.39873 .15698 L
.40332 .15769 L
.40575 .158 L
.40832 .15827 L
.41048 .15846 L
.41286 .15863 L
.41503 .15874 L
.41707 .15882 L
.41824 .15885 L
.4195 .15888 L
.42069 .15889 L
.42177 .1589 L
.42304 .1589 L
.42375 .15889 L
.42441 .15889 L
.42562 .15887 L
.42691 .15884 L
.42946 .15877 L
.43184 .15868 L
.43726 .15841 L
.45577 .15713 L
.49462 .15429 L
.53591 .15066 L
.57569 .14658 L
.61396 .14287 L
.65468 .13939 L
.69388 .13656 L
.73553 .13413 L
.77567 .13229 L
.81429 .13091 L
.85537 .12976 L
.89493 .12891 L
.93297 .12824 L
.97347 .12765 L
Mistroke
.97619 .12761 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04862 L
.08259 .05241 L
.09399 .0552 L
.10458 .0585 L
.11466 .06261 L
.1238 .06765 L
.12887 .07128 L
.13435 .07619 L
.13953 .08222 L
.14429 .08952 L
.14899 .09922 L
.15157 .10606 L
.15402 .11383 L
.15878 .1335 L
.16311 .15733 L
.16791 .18649 L
.17034 .19862 L
.17171 .20379 L
.17301 .20726 L
.17369 .20854 L
.17441 .20948 L
.1757 .21015 L
.17642 .21001 L
.17709 .20956 L
.17782 .20877 L
.1786 .20759 L
.18 .20478 L
.18131 .20145 L
.18378 .19398 L
.19261 .16305 L
.20209 .13423 L
.20753 .1216 L
.2125 .11252 L
.2175 .10557 L
.22224 .10074 L
.22463 .0989 L
Mistroke
.22718 .09733 L
.22958 .09621 L
.23175 .09547 L
.23309 .09514 L
.23432 .09493 L
.23496 .09485 L
.23567 .09478 L
.23641 .09474 L
.23709 .09473 L
.23836 .09477 L
.23952 .09487 L
.24016 .09496 L
.24085 .09508 L
.24212 .09535 L
.24342 .09571 L
.24464 .09613 L
.24742 .09733 L
.25306 .10079 L
.25792 .1047 L
.26316 .10986 L
.28285 .13895 L
.28824 .14656 L
.2912 .15005 L
.294 .15282 L
.2966 .15495 L
.29943 .15677 L
.30199 .158 L
.30323 .15847 L
.30435 .15882 L
.30545 .15911 L
.30664 .15936 L
.30791 .15956 L
.3091 .15969 L
.31022 .15977 L
.31141 .15981 L
.31242 .15982 L
.31354 .15979 L
.31485 .15972 L
.31605 .15962 L
.31875 .15933 L
.32364 .15864 L
.32878 .15789 L
.33129 .15758 L
.33357 .15736 L
.33481 .15727 L
.33598 .1572 L
.33722 .15714 L
.33792 .15712 L
.33856 .15711 L
.33983 .15711 L
Mistroke
.34054 .15712 L
.34122 .15714 L
.34192 .15716 L
.34257 .1572 L
.34403 .1573 L
.34532 .15741 L
.34653 .15755 L
.3488 .15789 L
.35124 .15835 L
.35388 .15896 L
.36303 .1619 L
.38376 .171 L
.39408 .17521 L
.40371 .17829 L
.40856 .1795 L
.41376 .18054 L
.41953 .18142 L
.42478 .18202 L
.42959 .18243 L
.4347 .18275 L
.43907 .18295 L
.44388 .18311 L
.44904 .18325 L
.45459 .18337 L
.46465 .18356 L
.47504 .18372 L
.4801 .18379 L
.4847 .18384 L
.48721 .18386 L
.48958 .18388 L
.49088 .18388 L
.49208 .18389 L
.49339 .18389 L
.49405 .18389 L
.49478 .18389 L
.49552 .18389 L
.49622 .18389 L
.49753 .18389 L
.49826 .18389 L
.49894 .18389 L
.50048 .18388 L
.50183 .18387 L
.50306 .18386 L
.50581 .18383 L
.50814 .1838 L
.5107 .18376 L
.51587 .18365 L
.52511 .18338 L
.53589 .18296 L
.54594 .18248 L
Mistroke
.58493 .18032 L
.62636 .17801 L
.66628 .17602 L
.70468 .17445 L
.72412 .1738 L
.74553 .17321 L
.76607 .17275 L
.78487 .17241 L
.80427 .17214 L
.81509 .17202 L
.82515 .17192 L
.8351 .17185 L
.84412 .17179 L
.85415 .17174 L
.85935 .17172 L
.86484 .17171 L
.86962 .17169 L
.87486 .17168 L
.87963 .17167 L
.88408 .17167 L
.88678 .17167 L
.8881 .17167 L
.88933 .17167 L
.89042 .17166 L
.89163 .17166 L
.89284 .17166 L
.89412 .17166 L
.8948 .17166 L
.89552 .17166 L
.8968 .17166 L
.89751 .17166 L
.89817 .17166 L
.89968 .17166 L
.901 .17167 L
.9022 .17167 L
.9049 .17167 L
.90974 .17167 L
.91487 .17168 L
.92407 .17169 L
.93397 .17172 L
.94487 .17174 L
.97619 .17185 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .0486 L
.08259 .05236 L
.09399 .05513 L
.10458 .0584 L
.11466 .06247 L
.1238 .06743 L
.12887 .07099 L
.13435 .07581 L
.13953 .08167 L
.14429 .08874 L
.14899 .09807 L
.15402 .11201 L
.15878 .13066 L
.16311 .15337 L
.1682 .18383 L
.17088 .19766 L
.17223 .20309 L
.17301 .20563 L
.17372 .20757 L
.17502 .21011 L
.1757 .21095 L
.17642 .21148 L
.17762 .21161 L
.17895 .21074 L
.18016 .20916 L
.18145 .20677 L
.18378 .20106 L
.19345 .16937 L
.20369 .1382 L
.20904 .12576 L
.21187 .12035 L
.21492 .11544 L
.21771 .11172 L
.22027 .10896 L
.22284 .10676 L
.22527 .1052 L
Mistroke
.22657 .10456 L
.2278 .10409 L
.22889 .10377 L
.23008 .10354 L
.23138 .10342 L
.23203 .10341 L
.23275 .10345 L
.23402 .10361 L
.2352 .1039 L
.2364 .10431 L
.23753 .10483 L
.23964 .10615 L
.24193 .10812 L
.2444 .11101 L
.2469 .11483 L
.24966 .12026 L
.25524 .13564 L
.26526 .17451 L
.27019 .19323 L
.27288 .20163 L
.27537 .20787 L
.27752 .2119 L
.27872 .21361 L
.2798 .21483 L
.281 .2158 L
.28229 .21644 L
.28352 .21667 L
.28464 .21656 L
.28585 .21614 L
.28714 .21535 L
.28836 .21431 L
.28947 .21314 L
.2922 .20947 L
.29479 .20514 L
.30551 .18262 L
.31426 .16383 L
.32371 .14662 L
.33407 .13232 L
.34381 .12275 L
.34882 .11898 L
.35411 .11568 L
.36356 .11109 L
.37358 .10753 L
.38456 .10454 L
.42509 .09631 L
.4438 .09323 L
.4641 .09054 L
.48542 .08841 L
.50557 .08684 L
.54645 .08433 L
Mistroke
.58582 .08241 L
.62368 .08094 L
.66399 .07967 L
.70278 .07868 L
.74402 .07783 L
.78375 .07716 L
.82196 .07663 L
.86263 .07616 L
.90178 .07577 L
.94338 .07541 L
.97619 .07516 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04585 L
.05217 .04679 L
.06244 .04856 L
.08259 .05231 L
.09399 .05507 L
.10458 .05833 L
.11466 .06237 L
.1238 .06731 L
.12887 .07085 L
.13435 .07562 L
.13953 .08143 L
.14429 .08841 L
.14899 .09758 L
.15402 .11117 L
.15878 .12905 L
.16311 .1502 L
.1682 .17694 L
.16959 .18315 L
.17107 .18859 L
.17233 .19209 L
.17305 .19359 L
.17372 .19465 L
.17495 .19574 L
.17625 .19578 L
.17735 .195 L
.17856 .19339 L
.17987 .19092 L
.18126 .18759 L
.18378 .18034 L
.19345 .14817 L
.20369 .11981 L
.20904 .10881 L
.21492 .09949 L
.22027 .09318 L
.22527 .08884 L
.22775 .08718 L
.23044 .08568 L
.23282 .08461 L
Mistroke
.23535 .0837 L
.23785 .08302 L
.24012 .08257 L
.24122 .08241 L
.2424 .08227 L
.24352 .08217 L
.24455 .0821 L
.24575 .08204 L
.24704 .08202 L
.24825 .08202 L
.24936 .08204 L
.25065 .08207 L
.25206 .08213 L
.25462 .08225 L
.25601 .0823 L
.25731 .08234 L
.25796 .08235 L
.25866 .08236 L
.25944 .08236 L
.26015 .08234 L
.26134 .0823 L
.26264 .08222 L
.2633 .08217 L
.264 .0821 L
.26526 .08194 L
.26785 .08149 L
.2706 .08084 L
.27552 .07928 L
.28664 .07495 L
.29637 .07159 L
.30183 .07015 L
.30681 .06912 L
.31163 .06833 L
.31687 .06768 L
.32183 .06722 L
.32642 .0669 L
.33064 .06667 L
.3353 .06649 L
.33764 .06642 L
.34017 .06637 L
.34256 .06632 L
.34475 .0663 L
.34602 .06629 L
.34722 .06628 L
.3483 .06627 L
.34948 .06627 L
.35075 .06627 L
.3514 .06627 L
.35211 .06627 L
.35336 .06628 L
Mistroke
.35453 .06629 L
.35571 .06629 L
.35683 .06631 L
.35892 .06633 L
.36365 .06641 L
.36878 .06654 L
.37354 .06668 L
.38434 .06711 L
.42349 .06913 L
.46509 .07113 L
.50518 .07303 L
.54375 .07485 L
.58477 .07669 L
.62428 .07841 L
.66227 .08001 L
.70271 .08166 L
.74164 .0832 L
.78302 .08481 L
.82289 .08635 L
.86124 .08782 L
.90204 .08937 L
.94132 .09086 L
.97619 .09215 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .0414 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04585 L
.05217 .04679 L
.06244 .04855 L
.08259 .05229 L
.09399 .05504 L
.10458 .05827 L
.11466 .0623 L
.1238 .0672 L
.12887 .0707 L
.13435 .07542 L
.13953 .08115 L
.14429 .08802 L
.14899 .09701 L
.15402 .11029 L
.15878 .12775 L
.16311 .14856 L
.1682 .17573 L
.16959 .18238 L
.17107 .18847 L
.17233 .19265 L
.17301 .19447 L
.17372 .19604 L
.17503 .19801 L
.17622 .1988 L
.1775 .19867 L
.17823 .19818 L
.17891 .19748 L
.18014 .19566 L
.18126 .19349 L
.18378 .18727 L
.19388 .15514 L
.20458 .12459 L
.21371 .10563 L
.2189 .09771 L
.22376 .09198 L
.22873 .08759 L
.23118 .08591 L
.23345 .08461 L
Mistroke
.23768 .08278 L
.23992 .08209 L
.2423 .08155 L
.24365 .08133 L
.24489 .08117 L
.24625 .08103 L
.24694 .08099 L
.24769 .08094 L
.24896 .0809 L
.24967 .08089 L
.25031 .08089 L
.25157 .08091 L
.25276 .08095 L
.2539 .081 L
.25512 .08106 L
.25729 .08119 L
.2597 .08133 L
.26091 .08138 L
.26222 .08142 L
.26345 .08144 L
.26477 .08143 L
.266 .0814 L
.26713 .08134 L
.26824 .08126 L
.26944 .08114 L
.27162 .08083 L
.27418 .08034 L
.27689 .07966 L
.28173 .0781 L
.30003 .07079 L
.30949 .06773 L
.3148 .06642 L
.31964 .06545 L
.32414 .06473 L
.32905 .06412 L
.33368 .06367 L
.33797 .06334 L
.34259 .06308 L
.34758 .06287 L
.35229 .06272 L
.35661 .06263 L
.35909 .06259 L
.36139 .06256 L
.36414 .06253 L
.36663 .06251 L
.36926 .06249 L
.37174 .06248 L
.3731 .06247 L
.37436 .06247 L
.37574 .06247 L
Mistroke
.37643 .06247 L
.3772 .06247 L
.37849 .06247 L
.37969 .06247 L
.381 .06247 L
.38174 .06247 L
.3824 .06247 L
.38363 .06247 L
.38495 .06247 L
.38735 .06248 L
.3897 .06249 L
.39218 .0625 L
.39662 .06252 L
.40658 .0626 L
.41751 .0627 L
.43703 .06295 L
.45795 .06327 L
.49933 .06405 L
.5392 .06487 L
.57755 .06566 L
.61835 .06647 L
.65764 .06723 L
.69541 .06791 L
.73563 .06859 L
.77434 .06921 L
.8155 .06985 L
.85514 .07044 L
.89327 .071 L
.93385 .07158 L
.97292 .07213 L
.97619 .07217 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04135 L
.0379 .04223 L
.04033 .04345 L
.04262 .04432 L
.04761 .04565 L
.05217 .04654 L
.06244 .04818 L
.08259 .05169 L
.09399 .05426 L
.10458 .05726 L
.11466 .06093 L
.1238 .0653 L
.12887 .06835 L
.13435 .07235 L
.14429 .08241 L
.16384 .12161 L
.16659 .1284 L
.16919 .1337 L
.17063 .13584 L
.17144 .13675 L
.17219 .13737 L
.17283 .13773 L
.17352 .13795 L
.17425 .13797 L
.17493 .1378 L
.1762 .13701 L
.17684 .1364 L
.17753 .13557 L
.17992 .13168 L
.1827 .12557 L
.18529 .11908 L
.19 .10696 L
.19511 .09515 L
.19962 .08663 L
.20438 .07959 L
.20703 .07648 L
.20994 .07365 L
.21241 .07166 L
.21507 .06991 L
.21769 .06852 L
.22009 .0675 L
.22249 .0667 L
Mistroke
.22478 .06612 L
.22603 .06586 L
.22738 .06564 L
.22857 .06548 L
.22982 .06535 L
.23096 .06526 L
.2322 .06519 L
.23334 .06516 L
.23439 .06516 L
.23503 .06516 L
.23572 .06518 L
.23698 .06523 L
.2382 .0653 L
.23933 .06539 L
.2419 .06566 L
.24462 .06604 L
.24914 .06687 L
.25338 .06783 L
.26302 .07035 L
.26813 .07164 L
.27288 .07263 L
.27528 .07301 L
.27784 .07332 L
.27854 .07339 L
.2793 .07345 L
.27996 .07349 L
.28067 .07353 L
.28131 .07356 L
.28201 .07358 L
.28325 .07359 L
.28449 .07358 L
.28566 .07354 L
.28672 .07348 L
.28786 .07339 L
.28911 .07327 L
.29044 .07312 L
.29282 .07277 L
.29707 .07195 L
.30176 .07083 L
.31196 .06808 L
.32271 .06541 L
.33189 .06366 L
.33709 .06291 L
.34193 .06234 L
.34697 .06187 L
.35172 .06151 L
.36062 .06102 L
.3702 .06063 L
.38059 .06029 L
.40005 .05965 L
Mistroke
.42148 .05895 L
.44181 .05841 L
.46085 .05805 L
.48111 .05778 L
.49964 .05758 L
.53937 .05724 L
.57758 .057 L
.61825 .05682 L
.6574 .0567 L
.699 .0566 L
.73908 .05652 L
.77765 .05647 L
.81868 .05642 L
.85819 .05639 L
.89618 .05636 L
.93662 .05632 L
.97555 .0563 L
.97619 .0563 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05238 L
.09399 .05516 L
.10458 .05844 L
.11466 .06253 L
.1238 .06752 L
.12887 .07111 L
.13435 .07596 L
.13953 .08189 L
.14429 .08905 L
.14899 .09852 L
.15157 .10518 L
.15402 .11274 L
.15878 .13183 L
.16311 .1551 L
.16791 .18442 L
.16918 .19153 L
.17054 .19833 L
.17174 .20335 L
.17301 .20751 L
.17367 .20919 L
.1744 .21064 L
.17567 .21222 L
.1764 .2126 L
.17719 .2126 L
.17793 .21224 L
.1786 .21165 L
.17988 .20987 L
.18126 .20715 L
.18378 .20064 L
.19317 .16931 L
.20326 .13876 L
.20905 .12554 L
.21433 .11641 L
.21688 .11297 L
.21965 .1099 L
Mistroke
.22227 .10762 L
.22469 .10601 L
.22599 .10535 L
.22718 .10486 L
.22848 .10445 L
.22914 .1043 L
.22986 .10417 L
.23107 .10405 L
.23237 .10406 L
.23359 .10419 L
.23471 .10442 L
.23587 .10478 L
.23694 .10522 L
.23937 .10664 L
.24151 .1084 L
.24378 .11087 L
.24618 .11425 L
.24877 .11889 L
.25344 .13022 L
.25901 .14836 L
.2641 .16757 L
.26885 .18508 L
.27146 .19356 L
.27393 .20043 L
.27623 .2057 L
.27744 .208 L
.27871 .21007 L
.27979 .21152 L
.28098 .21282 L
.28205 .21374 L
.28306 .21437 L
.28434 .21487 L
.28507 .21501 L
.28574 .21506 L
.28697 .21492 L
.28828 .2145 L
.28945 .21389 L
.29055 .21313 L
.29305 .21084 L
.29821 .20414 L
.30377 .19513 L
.3234 .16323 L
.32877 .15643 L
.33452 .15033 L
.34488 .14215 L
.35 .13924 L
.35554 .13674 L
.36043 .13499 L
.36562 .13351 L
.37542 .13136 L
Mistroke
.38447 .12975 L
.42233 .12252 L
.44338 .1182 L
.46264 .11483 L
.50143 .1098 L
.54116 .10578 L
.57937 .10243 L
.62003 .09945 L
.65918 .09707 L
.70079 .09498 L
.74087 .09334 L
.77944 .09205 L
.82047 .09092 L
.85997 .09002 L
.89797 .08928 L
.93841 .0886 L
.97619 .08805 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .0524 L
.09399 .05518 L
.10458 .05847 L
.11466 .06256 L
.1238 .06758 L
.12887 .07118 L
.13435 .07606 L
.13953 .08202 L
.14429 .08923 L
.14899 .09879 L
.15157 .10552 L
.15402 .11315 L
.15878 .13242 L
.16311 .15581 L
.16791 .18485 L
.16918 .19174 L
.17054 .19822 L
.17174 .2029 L
.17301 .20665 L
.17367 .20811 L
.1744 .2093 L
.17567 .21043 L
.1764 .21054 L
.17719 .21027 L
.17793 .20966 L
.1786 .20884 L
.17988 .20667 L
.18126 .20356 L
.18378 .19646 L
.19317 .16409 L
.20326 .13359 L
.20905 .12057 L
.21433 .11158 L
.21688 .10818 L
.21965 .1051 L
Mistroke
.22207 .10292 L
.22469 .10108 L
.22609 .1003 L
.22737 .0997 L
.22857 .09925 L
.22989 .09887 L
.23108 .09863 L
.23218 .09849 L
.23335 .09843 L
.2346 .09848 L
.2353 .09855 L
.23596 .09865 L
.23667 .09879 L
.23743 .09898 L
.23871 .09939 L
.24012 .09999 L
.24271 .10151 L
.24514 .10344 L
.24746 .1058 L
.24991 .10885 L
.25427 .1158 L
.2641 .13753 L
.27367 .16182 L
.27892 .17279 L
.2815 .17699 L
.28388 .1801 L
.28613 .18235 L
.28726 .18323 L
.28851 .18401 L
.28975 .18461 L
.29046 .18486 L
.2911 .18504 L
.29234 .18526 L
.29351 .18533 L
.29457 .18527 L
.29569 .18509 L
.29664 .18485 L
.2977 .1845 L
.30005 .18344 L
.30226 .18213 L
.32071 .16631 L
.32577 .16214 L
.33117 .15826 L
.33584 .15548 L
.34091 .15307 L
.34372 .15201 L
.3463 .15119 L
.34873 .15056 L
.3514 .15001 L
.35379 .14962 L
Mistroke
.35603 .14936 L
.35726 .14924 L
.35839 .14916 L
.35969 .14908 L
.36093 .14903 L
.36161 .14901 L
.36226 .149 L
.36346 .14898 L
.36476 .14898 L
.36549 .14899 L
.36616 .149 L
.36729 .14902 L
.36852 .14906 L
.37102 .14916 L
.37667 .14947 L
.38202 .14978 L
.38439 .1499 L
.38692 .15001 L
.38823 .15006 L
.38968 .1501 L
.391 .15013 L
.39224 .15015 L
.39338 .15016 L
.39457 .15016 L
.3956 .15016 L
.39672 .15015 L
.39793 .15013 L
.39922 .15009 L
.40044 .15006 L
.40155 .15001 L
.40423 .14988 L
.40671 .14972 L
.41231 .14923 L
.42247 .14801 L
.46189 .14205 L
.4998 .13739 L
.54016 .13273 L
.579 .12839 L
.6203 .12432 L
.66008 .12096 L
.69834 .11824 L
.73906 .11586 L
.77826 .114 L
.81992 .1124 L
.86005 .11115 L
.89868 .11014 L
.93975 .10924 L
.97619 .10854 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04351 L
.04262 .04439 L
.04761 .04576 L
.05217 .04667 L
.06244 .04836 L
.08259 .05196 L
.09399 .0546 L
.10458 .0577 L
.11466 .06151 L
.1238 .06608 L
.12887 .06929 L
.13435 .07355 L
.14429 .08448 L
.16384 .13136 L
.16659 .14056 L
.16919 .14829 L
.17063 .15172 L
.17139 .15322 L
.17219 .15454 L
.17287 .15543 L
.17362 .15615 L
.17493 .15677 L
.17559 .15677 L
.17627 .15656 L
.1775 .15565 L
.17819 .15487 L
.17883 .15398 L
.18028 .15144 L
.1827 .14592 L
.18529 .13886 L
.19593 .10854 L
.20116 .0966 L
.20598 .08794 L
.21036 .08187 L
.215 .07704 L
.21966 .07356 L
.2223 .07208 L
.22478 .07098 L
.22736 .07009 L
.22976 .06947 L
Mistroke
.23114 .06919 L
.23239 .06899 L
.23383 .06881 L
.23448 .06874 L
.23519 .06869 L
.23639 .06861 L
.23766 .06857 L
.23884 .06857 L
.23994 .06859 L
.24123 .06864 L
.24241 .06872 L
.24378 .06884 L
.24507 .06897 L
.24968 .06967 L
.25395 .07054 L
.2636 .07289 L
.26825 .07394 L
.27069 .07441 L
.27326 .07481 L
.27551 .07507 L
.27679 .07518 L
.27798 .07525 L
.27908 .07529 L
.28007 .07531 L
.28122 .0753 L
.28231 .07527 L
.2835 .07521 L
.28481 .07511 L
.28618 .07497 L
.28746 .0748 L
.2922 .07395 L
.29737 .07266 L
.30292 .07103 L
.31251 .0681 L
.32271 .06545 L
.32802 .06436 L
.33389 .06339 L
.33923 .06269 L
.34425 .06218 L
.34911 .06178 L
.35424 .06146 L
.3634 .06102 L
.38406 .06033 L
.42214 .05914 L
.44173 .05866 L
.45269 .05846 L
.46267 .05831 L
.48183 .05808 L
.50262 .05789 L
.52208 .05773 L
Mistroke
.5435 .05759 L
.58288 .0574 L
.6023 .05733 L
.62318 .05726 L
.64291 .05721 L
.66443 .05716 L
.70416 .0571 L
.74482 .05705 L
.78397 .05702 L
.82557 .05699 L
.86566 .05697 L
.90423 .05695 L
.94525 .05693 L
.97619 .05692 L
Mfstroke
.174 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03492 L
.03279 .03786 L
.03527 .04031 L
.03652 .04125 L
.0379 .04211 L
.04033 .0433 L
.04262 .04414 L
.04761 .04544 L
.05217 .04629 L
.06244 .04788 L
.08259 .05128 L
.09399 .05377 L
.10458 .05666 L
.11466 .06018 L
.1238 .06434 L
.12887 .06721 L
.13435 .07096 L
.14429 .08022 L
.15372 .09364 L
.16384 .11383 L
.16682 .11953 L
.16828 .12185 L
.16964 .12357 L
.17087 .1247 L
.17217 .12541 L
.17349 .12557 L
.17423 .12541 L
.17493 .12509 L
.1762 .12414 L
.17684 .12348 L
.17753 .12264 L
.17992 .11889 L
.18529 .10758 L
.19518 .08697 L
.20072 .0785 L
.20575 .07286 L
.21044 .06907 L
.21309 .06746 L
.21554 .06625 L
.21786 .06533 L
.22003 .06464 L
.22229 .06408 L
.22478 .06363 L
.22603 .06346 L
.22736 .06332 L
Mistroke
.22862 .06322 L
.22976 .06316 L
.23046 .06313 L
.2311 .06312 L
.23181 .06311 L
.23256 .06312 L
.23381 .06314 L
.23452 .06316 L
.23519 .0632 L
.23647 .06327 L
.23768 .06337 L
.23996 .0636 L
.24241 .06392 L
.24507 .06435 L
.2547 .06643 L
.2636 .06875 L
.26825 .0699 L
.27069 .07044 L
.27326 .07094 L
.27551 .07131 L
.27798 .07163 L
.27906 .07173 L
.28022 .07183 L
.28131 .0719 L
.28231 .07194 L
.28359 .07197 L
.28424 .07198 L
.28496 .07197 L
.28622 .07195 L
.2874 .0719 L
.28811 .07186 L
.28879 .07181 L
.29006 .0717 L
.29292 .07137 L
.2954 .07099 L
.29771 .07058 L
.30292 .06946 L
.31265 .06706 L
.32315 .06465 L
.32798 .06372 L
.33306 .06289 L
.34216 .06176 L
.34666 .06134 L
.35148 .06098 L
.36016 .06049 L
.37049 .06008 L
.37987 .05977 L
.41982 .05848 L
.43812 .05798 L
.45826 .05757 L
Mistroke
.47811 .05729 L
.49914 .05706 L
.53945 .05671 L
.57824 .05647 L
.61949 .05629 L
.65922 .05616 L
.69743 .05606 L
.73809 .05599 L
.77724 .05593 L
.81885 .05589 L
.85893 .05585 L
.8975 .05581 L
.93853 .05578 L
.97619 .05576 L
Mfstroke
.15 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04016 L
.03652 .04108 L
.0379 .04192 L
.04033 .04307 L
.04262 .04389 L
.04517 .04459 L
.04761 .04513 L
.05217 .04595 L
.06244 .04747 L
.07302 .04908 L
.08429 .05107 L
.09474 .05332 L
.10458 .05591 L
.1142 .05908 L
.12461 .06357 L
.13407 .06914 L
.14277 .07625 L
.15263 .0879 L
.15805 .09627 L
.16319 .10476 L
.16551 .1082 L
.16797 .11112 L
.16925 .1122 L
.16998 .11265 L
.17067 .11295 L
.17187 .11319 L
.17317 .11302 L
.17427 .11252 L
.17548 .11162 L
.17674 .11031 L
.17791 .1088 L
.18226 .10142 L
.1917 .08371 L
.19634 .07677 L
.20062 .07176 L
.20555 .06748 L
.20815 .06577 L
.21089 .0643 L
.21304 .06338 L
.21534 .06258 L
.21787 .06189 L
.22023 .06141 L
.22157 .0612 L
Mistroke
.22278 .06104 L
.22417 .06091 L
.22549 .06081 L
.22671 .06075 L
.22783 .06072 L
.22906 .06071 L
.23036 .06073 L
.23168 .06077 L
.23242 .0608 L
.23309 .06084 L
.23563 .06103 L
.23705 .06117 L
.2386 .06135 L
.24141 .06174 L
.25185 .06379 L
.26151 .06621 L
.27051 .06838 L
.27298 .06887 L
.27558 .0693 L
.27782 .06961 L
.28021 .06985 L
.28159 .06996 L
.28285 .07002 L
.28411 .07007 L
.2853 .07008 L
.28597 .07008 L
.28668 .07008 L
.28796 .07004 L
.28867 .07001 L
.28934 .06998 L
.29085 .06988 L
.29337 .06964 L
.29566 .06935 L
.30083 .06851 L
.3215 .0641 L
.33059 .06249 L
.33543 .0618 L
.34064 .06118 L
.34563 .06071 L
.35021 .06036 L
.3592 .05984 L
.36881 .05944 L
.37894 .05911 L
.41701 .05791 L
.43824 .05732 L
.45754 .05694 L
.4776 .05665 L
.49656 .05644 L
.53499 .0561 L
.57588 .05583 L
Mistroke
.61525 .05565 L
.6531 .05552 L
.69341 .05541 L
.7322 .05534 L
.77345 .05528 L
.81317 .05523 L
.85139 .05519 L
.89205 .05515 L
.9312 .05512 L
.9728 .05509 L
.97619 .05509 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04682 L
.06244 .0486 L
.08259 .05238 L
.09399 .05516 L
.10458 .05844 L
.11466 .06253 L
.1238 .06754 L
.12887 .07113 L
.13435 .076 L
.13953 .08194 L
.14429 .08913 L
.14899 .09865 L
.15402 .11291 L
.15878 .13198 L
.16311 .15495 L
.1682 .18458 L
.16959 .19155 L
.17107 .19772 L
.17233 .20174 L
.17305 .20349 L
.17372 .20475 L
.17495 .20615 L
.17625 .20643 L
.17735 .20579 L
.17856 .20429 L
.17987 .20188 L
.18126 .19859 L
.18378 .19134 L
.19345 .15891 L
.20369 .13 L
.20904 .11857 L
.21492 .10869 L
.22027 .10184 L
.22527 .097 L
.22775 .09511 L
.23044 .09338 L
.23282 .09213 L
Mistroke
.23535 .09105 L
.23785 .09022 L
.24012 .08967 L
.24122 .08946 L
.2424 .08928 L
.24352 .08914 L
.24455 .08904 L
.24575 .08897 L
.24704 .08892 L
.24825 .0889 L
.24936 .0889 L
.25065 .08893 L
.25139 .08895 L
.25206 .08897 L
.25339 .08902 L
.25462 .08906 L
.25581 .08909 L
.25708 .08911 L
.25777 .08911 L
.25849 .0891 L
.25978 .08906 L
.26044 .08903 L
.26114 .08899 L
.2624 .08889 L
.2639 .08873 L
.26526 .08855 L
.27539 .08637 L
.28092 .08507 L
.2861 .08408 L
.29051 .08345 L
.29298 .08319 L
.29524 .08299 L
.29771 .08281 L
.3004 .08266 L
.30529 .08246 L
.3099 .08232 L
.31498 .0822 L
.31994 .0821 L
.32255 .08206 L
.32529 .08202 L
.32767 .082 L
.32832 .08199 L
.32901 .08199 L
.33027 .08198 L
.3315 .08198 L
.33266 .08198 L
.33371 .08198 L
.33484 .08199 L
.33592 .08199 L
.3371 .08201 L
Mistroke
.33834 .08203 L
.3395 .08205 L
.34158 .0821 L
.34381 .08218 L
.34635 .08229 L
.34905 .08244 L
.35392 .08278 L
.35971 .08333 L
.36496 .08396 L
.38505 .08735 L
.42514 .09507 L
.46371 .1009 L
.50473 .10681 L
.54424 .11225 L
.58223 .11708 L
.62268 .12196 L
.6616 .12644 L
.70299 .131 L
.74285 .13525 L
.7812 .13926 L
.822 .14345 L
.86129 .14743 L
.89906 .15121 L
.93928 .15517 L
.97619 .15872 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04857 L
.08259 .05232 L
.09399 .05507 L
.10458 .05832 L
.11466 .06235 L
.1238 .06727 L
.12887 .07079 L
.13435 .07553 L
.13953 .08128 L
.14429 .08819 L
.14899 .09724 L
.15402 .11066 L
.15878 .12843 L
.16311 .14989 L
.1682 .17878 L
.17088 .19224 L
.17234 .19809 L
.17372 .20232 L
.17492 .20491 L
.17621 .2066 L
.1769 .20706 L
.17763 .2072 L
.17895 .20669 L
.18014 .20544 L
.18125 .20371 L
.18378 .19817 L
.20251 .13874 L
.20764 .12475 L
.21308 .11225 L
.21778 .10343 L
.22282 .09592 L
.22807 .09005 L
.23299 .08614 L
.23598 .0844 L
.23883 .08314 L
.24138 .0823 L
Mistroke
.24283 .08193 L
.24417 .08166 L
.24544 .08146 L
.2461 .08137 L
.24681 .08129 L
.2481 .08118 L
.24929 .08112 L
.25043 .08109 L
.2515 .08109 L
.25267 .08111 L
.25393 .08116 L
.25462 .08119 L
.25527 .08123 L
.25672 .08133 L
.25937 .08153 L
.26195 .08172 L
.26308 .08179 L
.26432 .08184 L
.26549 .08188 L
.26658 .0819 L
.26774 .08189 L
.26897 .08186 L
.26962 .08183 L
.27032 .08179 L
.27159 .08169 L
.27283 .08155 L
.27397 .08139 L
.27607 .08102 L
.27837 .0805 L
.28302 .07911 L
.2938 .07477 L
.30364 .07068 L
.30843 .06896 L
.31364 .06735 L
.32312 .06515 L
.32838 .06428 L
.33398 .06357 L
.33875 .06312 L
.34403 .06274 L
.34894 .06247 L
.35411 .06226 L
.35852 .06213 L
.36335 .06201 L
.36857 .06191 L
.37415 .06183 L
.3842 .06171 L
.39443 .06162 L
.39981 .06158 L
.40552 .06155 L
.41051 .06153 L
Mistroke
.41315 .06152 L
.416 .06151 L
.41734 .0615 L
.41861 .0615 L
.41984 .0615 L
.42099 .0615 L
.42207 .0615 L
.42323 .0615 L
.42451 .0615 L
.42567 .0615 L
.42687 .0615 L
.42799 .0615 L
.42923 .0615 L
.43055 .0615 L
.43193 .0615 L
.43324 .0615 L
.4357 .06151 L
.44012 .06152 L
.44493 .06154 L
.45575 .06161 L
.46575 .06168 L
.50504 .06208 L
.54281 .06253 L
.58303 .06301 L
.62174 .06347 L
.6629 .06392 L
.70254 .06432 L
.74067 .06467 L
.78125 .06501 L
.82032 .06532 L
.86184 .06562 L
.90184 .06591 L
.94032 .06617 L
.97619 .0664 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .0414 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04583 L
.05217 .04676 L
.06244 .04849 L
.08259 .05216 L
.09399 .05485 L
.10458 .05802 L
.11466 .06194 L
.1238 .06667 L
.12887 .07002 L
.13435 .0745 L
.13953 .07986 L
.14429 .08619 L
.14899 .0943 L
.15402 .10594 L
.15878 .12067 L
.16311 .13755 L
.1682 .15895 L
.16959 .16415 L
.17107 .16892 L
.17233 .17221 L
.17301 .17363 L
.17372 .17486 L
.17503 .17634 L
.17622 .17685 L
.1775 .17653 L
.17823 .17597 L
.17891 .17522 L
.18014 .17336 L
.18126 .17116 L
.18378 .16485 L
.19388 .13217 L
.19941 .11559 L
.20458 .1028 L
.20935 .09346 L
.21371 .08683 L
.21855 .08129 L
.22107 .07906 L
.22376 .0771 L
Mistroke
.22633 .07559 L
.22866 .07448 L
.23102 .0736 L
.2332 .07297 L
.23575 .07244 L
.23709 .07224 L
.23777 .07215 L
.2385 .07208 L
.23973 .07199 L
.24088 .07194 L
.24158 .07192 L
.24225 .07192 L
.24349 .07194 L
.24457 .07198 L
.24576 .07205 L
.247 .07216 L
.24816 .07228 L
.25247 .07292 L
.25717 .07386 L
.26222 .07499 L
.26687 .07597 L
.26942 .07642 L
.27182 .07675 L
.27319 .0769 L
.27391 .07697 L
.27467 .07702 L
.27531 .07706 L
.27602 .0771 L
.27725 .07713 L
.27851 .07713 L
.27922 .07712 L
.27986 .07709 L
.28112 .07702 L
.2823 .07692 L
.28351 .07679 L
.28485 .0766 L
.28755 .07612 L
.29241 .07493 L
.30342 .07131 L
.31283 .06816 L
.32274 .06546 L
.32793 .06438 L
.33361 .06343 L
.33878 .06276 L
.34359 .06227 L
.34863 .06187 L
.35409 .06153 L
.36402 .06108 L
.3826 .06048 L
.40206 .05989 L
Mistroke
.42349 .05928 L
.43328 .05905 L
.44382 .05884 L
.46286 .05856 L
.47297 .05845 L
.48401 .05835 L
.5041 .0582 L
.52543 .05806 L
.54477 .05796 L
.56493 .05788 L
.58392 .05782 L
.62249 .05773 L
.64244 .0577 L
.66351 .05767 L
.68316 .05765 L
.7015 .05764 L
.72187 .05762 L
.74043 .05762 L
.75953 .05761 L
.7803 .0576 L
.80009 .0576 L
.8102 .0576 L
.8211 .0576 L
.83127 .0576 L
.84058 .0576 L
.84943 .0576 L
.85887 .0576 L
.86868 .05759 L
.87781 .05759 L
.88339 .05759 L
.88866 .05759 L
.89339 .05759 L
.89605 .05759 L
.89851 .05759 L
.90096 .05759 L
.90319 .05759 L
.90443 .05759 L
.90512 .05759 L
.90577 .05759 L
.90696 .05759 L
.90822 .05759 L
.9094 .05759 L
.91067 .05759 L
.91187 .05759 L
.91298 .05759 L
.91508 .05759 L
.91729 .05759 L
.91975 .05759 L
.92239 .05759 L
.92714 .05759 L
Mistroke
.93279 .05759 L
.93794 .05759 L
.95628 .05759 L
.96663 .0576 L
.97619 .0576 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04114 L
.0379 .04199 L
.04033 .04316 L
.04262 .044 L
.04761 .04528 L
.05217 .04613 L
.06244 .0477 L
.08259 .05108 L
.09399 .05356 L
.10458 .05643 L
.11466 .05993 L
.1238 .06406 L
.12887 .06692 L
.13435 .07065 L
.13949 .07495 L
.14429 .07991 L
.15379 .09348 L
.15925 .10398 L
.16423 .11438 L
.16673 .11904 L
.16805 .1211 L
.16945 .12285 L
.17067 .12393 L
.17136 .12435 L
.17202 .1246 L
.17316 .12471 L
.17439 .12434 L
.17572 .12341 L
.17647 .12265 L
.17716 .12181 L
.18008 .11711 L
.18529 .10604 L
.19034 .09502 L
.19581 .08476 L
.20098 .07723 L
.20575 .07203 L
.21005 .06857 L
.21478 .06584 L
.21716 .06482 L
.21972 .06395 L
.22213 .06332 L
.22434 .06287 L
Mistroke
.22563 .06266 L
.22685 .0625 L
.22795 .06238 L
.22912 .06228 L
.23039 .06219 L
.23156 .06214 L
.23283 .06211 L
.23354 .0621 L
.23421 .06209 L
.2354 .0621 L
.23652 .06212 L
.23753 .06216 L
.23863 .0622 L
.24109 .06234 L
.24336 .0625 L
.24586 .0627 L
.24855 .06291 L
.25093 .06306 L
.25212 .06313 L
.25342 .06317 L
.25409 .06319 L
.2548 .0632 L
.25607 .06319 L
.25735 .06316 L
.2585 .0631 L
.25922 .06305 L
.25988 .06299 L
.26138 .06284 L
.2641 .06245 L
.27394 .06046 L
.27936 .05938 L
.28449 .05851 L
.29446 .05728 L
.30355 .05648 L
.31236 .05587 L
.32172 .05535 L
.3266 .05513 L
.33199 .05494 L
.33689 .0548 L
.34149 .0547 L
.34618 .05463 L
.35131 .05456 L
.35666 .05452 L
.36165 .05448 L
.38015 .05437 L
.39886 .05426 L
.40872 .0542 L
.41369 .05418 L
.41916 .05416 L
.42192 .05416 L
Mistroke
.42344 .05416 L
.42489 .05415 L
.42623 .05415 L
.42769 .05415 L
.42833 .05415 L
.42902 .05415 L
.43025 .05415 L
.43094 .05415 L
.43158 .05415 L
.43228 .05415 L
.43301 .05415 L
.43426 .05415 L
.43496 .05415 L
.43562 .05415 L
.43685 .05415 L
.43797 .05415 L
.44048 .05415 L
.44306 .05416 L
.44544 .05416 L
.45083 .05417 L
.46063 .0542 L
.48089 .05427 L
.49991 .05432 L
.53768 .05439 L
.57639 .05446 L
.61755 .05452 L
.65719 .05456 L
.69532 .05459 L
.71495 .0546 L
.7359 .05461 L
.75726 .05462 L
.77742 .05462 L
.79745 .05463 L
.81591 .05463 L
.83469 .05463 L
.84548 .05464 L
.85533 .05464 L
.87479 .05464 L
.88552 .05464 L
.89569 .05464 L
.90531 .05464 L
.91059 .05464 L
.91555 .05464 L
.9202 .05464 L
.92521 .05464 L
.92944 .05464 L
.93396 .05464 L
.93654 .05464 L
.93889 .05464 L
.94129 .05464 L
Mistroke
.9435 .05464 L
.94472 .05464 L
.94607 .05464 L
.94743 .05464 L
.94817 .05464 L
.94887 .05464 L
.95015 .05464 L
.95131 .05464 L
.95196 .05464 L
.95266 .05464 L
.95395 .05464 L
.95463 .05464 L
.95538 .05464 L
.95672 .05464 L
.95924 .05464 L
.96218 .05464 L
.96488 .05464 L
.97503 .05464 L
.97619 .05464 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04042 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04578 L
.05217 .04669 L
.06244 .0484 L
.08259 .05203 L
.09399 .0547 L
.10458 .05782 L
.11466 .06168 L
.1238 .06633 L
.12887 .06961 L
.13435 .07397 L
.13953 .07918 L
.14429 .08529 L
.14935 .09376 L
.15414 .10442 L
.15967 .12088 L
.16471 .13951 L
.16914 .15542 L
.17137 .16143 L
.17265 .16387 L
.17384 .1654 L
.17514 .16623 L
.17633 .16622 L
.17763 .16543 L
.17828 .16474 L
.179 .16379 L
.18148 .15914 L
.18378 .15339 L
.19315 .12543 L
.19808 .11201 L
.20331 .10028 L
.20788 .09222 L
.2129 .08552 L
.21747 .0811 L
.22175 .07817 L
.22439 .07685 L
.2269 .0759 L
.22915 .07527 L
.23043 .07501 L
Mistroke
.23161 .07481 L
.23228 .07473 L
.233 .07465 L
.2343 .07455 L
.23557 .07451 L
.23674 .07452 L
.23801 .07458 L
.23873 .07463 L
.2394 .07469 L
.24075 .07486 L
.2422 .07509 L
.2446 .07561 L
.2472 .07635 L
.25193 .07812 L
.26079 .08276 L
.26572 .08592 L
.27102 .08938 L
.27346 .09081 L
.27602 .09211 L
.27821 .09299 L
.27944 .09339 L
.28061 .09369 L
.28192 .09395 L
.28311 .0941 L
.2844 .09419 L
.28512 .09419 L
.28579 .09418 L
.2869 .0941 L
.28813 .09394 L
.28941 .09369 L
.2906 .0934 L
.29339 .09249 L
.29592 .09142 L
.30163 .08841 L
.31165 .08227 L
.3223 .07621 L
.33139 .07208 L
.34144 .06868 L
.35094 .06638 L
.36119 .0646 L
.37086 .06337 L
.37974 .06251 L
.38952 .06177 L
.39864 .06123 L
.40928 .06071 L
.41933 .06032 L
.42913 .06 L
.43976 .05972 L
.45834 .05934 L
.46779 .0592 L
Mistroke
.47819 .05908 L
.49923 .05889 L
.51865 .05876 L
.53954 .05866 L
.56069 .05858 L
.58078 .05853 L
.6006 .05849 L
.61899 .05845 L
.65814 .05841 L
.67957 .05839 L
.69975 .05837 L
.73832 .05835 L
.77934 .05833 L
.81885 .05831 L
.85684 .0583 L
.89728 .05828 L
.93621 .05827 L
.97619 .05826 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04859 L
.08259 .05236 L
.09399 .05513 L
.10458 .0584 L
.11466 .06247 L
.1238 .06745 L
.12887 .07102 L
.13435 .07585 L
.13953 .08175 L
.14429 .08886 L
.14899 .09826 L
.15402 .1123 L
.15878 .13106 L
.16311 .15376 L
.1682 .18362 L
.16959 .19089 L
.17107 .19748 L
.17233 .20197 L
.17301 .2039 L
.17372 .20555 L
.17503 .20758 L
.17622 .20835 L
.1775 .20813 L
.17823 .20757 L
.17891 .2068 L
.18014 .20484 L
.18126 .20254 L
.18378 .19606 L
.19388 .16365 L
.20458 .13337 L
.21371 .11428 L
.2189 .10608 L
.22376 .09997 L
.22873 .09514 L
.23345 .09175 L
.23768 .08959 L
Mistroke
.24008 .08869 L
.2423 .08804 L
.24356 .08775 L
.24491 .08749 L
.24611 .08731 L
.24737 .08715 L
.24851 .08704 L
.24976 .08695 L
.25089 .0869 L
.25195 .08686 L
.25454 .0868 L
.25596 .08678 L
.25665 .08677 L
.25729 .08676 L
.25842 .08673 L
.25964 .08668 L
.2609 .0866 L
.26222 .0865 L
.26347 .08636 L
.26462 .08621 L
.26725 .08576 L
.26989 .08514 L
.2727 .08432 L
.28262 .08058 L
.29228 .0768 L
.30118 .07403 L
.30618 .07285 L
.31145 .07185 L
.31675 .07107 L
.32257 .07043 L
.3276 .07002 L
.33037 .06985 L
.333 .06971 L
.33543 .06961 L
.33809 .06952 L
.33926 .06949 L
.3405 .06947 L
.34166 .06944 L
.34273 .06943 L
.34387 .06941 L
.34511 .0694 L
.34632 .0694 L
.34761 .0694 L
.34882 .0694 L
.34996 .0694 L
.35098 .06941 L
.35209 .06942 L
.3533 .06944 L
.35464 .06946 L
.35734 .06952 L
Mistroke
.36218 .06967 L
.36673 .06986 L
.37162 .07012 L
.38045 .07068 L
.4217 .07415 L
.46143 .07733 L
.49964 .08037 L
.5403 .08361 L
.57945 .08656 L
.62106 .08952 L
.66114 .0922 L
.69971 .09461 L
.74074 .09703 L
.78024 .09926 L
.81824 .10132 L
.85868 .10345 L
.89761 .10546 L
.93899 .10756 L
.97619 .10939 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04584 L
.05217 .04678 L
.06244 .04852 L
.08259 .05223 L
.09399 .05495 L
.10458 .05815 L
.11466 .06211 L
.1238 .06693 L
.12887 .07035 L
.13435 .07493 L
.13953 .08046 L
.14429 .08704 L
.14899 .09555 L
.15402 .10793 L
.15878 .12393 L
.16311 .14272 L
.1682 .1673 L
.17088 .17848 L
.17223 .18292 L
.17301 .18501 L
.17372 .18661 L
.17502 .18869 L
.1757 .18937 L
.17642 .18978 L
.17762 .18978 L
.17895 .18888 L
.18016 .18732 L
.18145 .18498 L
.18378 .17941 L
.19345 .14811 L
.20369 .11728 L
.20904 .1049 L
.21492 .09438 L
.22027 .08732 L
.22527 .08254 L
.22775 .08074 L
.23044 .07914 L
.23282 .07801 L
Mistroke
.23535 .07708 L
.23664 .0767 L
.23785 .07639 L
.23903 .07614 L
.24012 .07596 L
.24114 .07581 L
.24225 .07569 L
.24337 .0756 L
.24455 .07555 L
.24522 .07553 L
.24594 .07552 L
.24726 .07554 L
.24854 .07559 L
.24972 .07567 L
.251 .07579 L
.25241 .07594 L
.25526 .07633 L
.26004 .07712 L
.26274 .07758 L
.26526 .07797 L
.26784 .0783 L
.26897 .07841 L
.27019 .07851 L
.27148 .07859 L
.2727 .07863 L
.27338 .07864 L
.27409 .07864 L
.27537 .07861 L
.27648 .07856 L
.27766 .07847 L
.27877 .07836 L
.27979 .07824 L
.28228 .07783 L
.28464 .07733 L
.28983 .07587 L
.29463 .07421 L
.30551 .07013 L
.31448 .06718 L
.32415 .06478 L
.32969 .06378 L
.33477 .06305 L
.33963 .06251 L
.34475 .06207 L
.34974 .06174 L
.35427 .0615 L
.36446 .06111 L
.38282 .06061 L
.4036 .06009 L
.42277 .05968 L
.43241 .05952 L
Mistroke
.44143 .05939 L
.45084 .05929 L
.4612 .05921 L
.4716 .05915 L
.48147 .05911 L
.49033 .05907 L
.5 .05905 L
.51014 .05903 L
.51968 .05901 L
.52497 .059 L
.53069 .059 L
.53588 .05899 L
.53838 .05899 L
.54066 .05899 L
.54292 .05899 L
.54537 .05899 L
.54671 .05899 L
.54796 .05899 L
.54914 .05899 L
.55041 .05899 L
.55148 .05899 L
.55264 .05899 L
.55373 .05899 L
.55473 .05899 L
.55584 .05899 L
.55706 .05899 L
.55832 .05899 L
.5595 .05899 L
.5622 .05899 L
.56474 .05899 L
.5695 .05899 L
.57462 .05899 L
.58017 .059 L
.60006 .05902 L
.62111 .05905 L
.65902 .05911 L
.69938 .05918 L
.73822 .05926 L
.77952 .05933 L
.8193 .0594 L
.85756 .05947 L
.89828 .05953 L
.93748 .05959 L
.97619 .05965 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .05242 L
.09399 .05522 L
.10458 .05853 L
.11466 .06265 L
.1238 .0677 L
.12887 .07134 L
.13435 .07629 L
.13953 .08235 L
.14429 .08971 L
.14899 .0995 L
.15157 .10643 L
.15402 .11431 L
.15878 .13432 L
.16311 .15866 L
.16791 .18855 L
.17034 .20101 L
.17171 .20631 L
.17301 .20989 L
.17369 .21121 L
.17441 .21218 L
.1757 .21289 L
.17642 .21276 L
.17709 .21233 L
.17782 .21154 L
.1786 .21038 L
.18 .20758 L
.18131 .20426 L
.18378 .19684 L
.19261 .1662 L
.20209 .13773 L
.20753 .12516 L
.2125 .11602 L
.2175 .10889 L
.22224 .1038 L
.22463 .1018 L
Mistroke
.22718 .10004 L
.22938 .09882 L
.23175 .09779 L
.23321 .0973 L
.23455 .09694 L
.23584 .09668 L
.23648 .09658 L
.23719 .09649 L
.23842 .09639 L
.23974 .09636 L
.24099 .09639 L
.24212 .09649 L
.24343 .09666 L
.24481 .09692 L
.2473 .09757 L
.24998 .0985 L
.25293 .09975 L
.25792 .10223 L
.26316 .10531 L
.268 .10887 L
.27328 .1138 L
.28255 .12439 L
.28818 .13085 L
.29349 .13617 L
.29826 .13999 L
.30071 .14157 L
.30342 .14302 L
.30582 .14406 L
.30839 .14495 L
.31111 .14565 L
.31232 .1459 L
.31365 .14613 L
.31496 .14632 L
.31617 .14646 L
.31731 .14657 L
.31857 .14668 L
.32075 .14681 L
.32194 .14686 L
.32307 .1469 L
.32798 .14703 L
.33045 .1471 L
.33185 .14716 L
.33315 .14722 L
.33589 .14741 L
.33743 .14754 L
.33882 .14769 L
.3413 .14802 L
.34403 .14848 L
.34887 .14959 L
.35399 .15117 L
Mistroke
.36319 .15503 L
.38398 .16665 L
.39478 .17269 L
.40503 .17764 L
.41502 .18155 L
.42429 .18443 L
.44284 .18877 L
.46308 .19255 L
.50223 .19902 L
.52366 .20176 L
.54383 .20378 L
.5824 .2067 L
.62342 .20924 L
.66293 .2114 L
.70092 .21343 L
.74137 .21566 L
.7803 .21793 L
.82168 .22045 L
.86154 .22297 L
.89989 .22542 L
.94069 .22799 L
.97619 .23014 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04583 L
.05217 .04677 L
.06244 .0485 L
.08259 .05219 L
.09399 .0549 L
.10458 .05808 L
.11466 .06202 L
.1238 .06679 L
.12887 .07018 L
.13435 .07471 L
.13953 .08016 L
.14429 .08661 L
.14899 .09493 L
.15402 .10695 L
.15878 .12231 L
.16311 .14008 L
.1682 .1627 L
.16959 .16819 L
.17107 .17319 L
.17233 .17662 L
.17301 .1781 L
.17372 .17937 L
.17503 .1809 L
.17622 .18142 L
.1775 .18109 L
.17823 .18053 L
.17891 .17977 L
.18014 .17789 L
.18126 .17567 L
.18378 .16934 L
.19388 .13661 L
.19941 .12001 L
.20458 .10723 L
.20898 .09861 L
.21371 .0915 L
.2164 .08834 L
.21896 .08586 L
.22148 .08387 L
Mistroke
.22376 .08242 L
.22614 .08122 L
.22838 .08037 L
.22954 .08002 L
.23075 .07973 L
.23208 .07948 L
.23331 .07932 L
.23436 .07923 L
.23549 .07919 L
.23656 .07919 L
.23753 .07923 L
.23867 .07933 L
.23991 .07949 L
.24108 .07969 L
.24216 .07993 L
.24455 .0806 L
.24679 .08142 L
.2519 .084 L
.25687 .08745 L
.26222 .09219 L
.26726 .09739 L
.27263 .1029 L
.27524 .1052 L
.2777 .107 L
.27991 .10824 L
.28116 .10877 L
.2823 .10915 L
.28351 .10944 L
.28464 .10959 L
.28588 .10964 L
.28657 .10962 L
.28721 .10957 L
.28848 .10937 L
.2892 .1092 L
.28987 .10902 L
.29239 .10806 L
.29493 .10672 L
.29774 .1049 L
.30342 .10046 L
.31362 .09169 L
.32436 .0835 L
.33354 .0781 L
.34359 .07377 L
.35326 .0708 L
.3636 .06852 L
.37337 .06696 L
.38224 .06588 L
.4014 .06424 L
.41222 .06357 L
.42219 .06305 L
Mistroke
.44093 .06228 L
.45171 .06193 L
.46156 .06167 L
.48099 .06127 L
.50187 .06096 L
.52087 .06075 L
.5416 .06057 L
.56293 .06042 L
.58226 .06031 L
.62141 .06013 L
.6615 .06 L
.70007 .0599 L
.74109 .05982 L
.7806 .05976 L
.81859 .05971 L
.85904 .05966 L
.89797 .05962 L
.93935 .05959 L
.97619 .05956 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04681 L
.06244 .04858 L
.08259 .05231 L
.09399 .05506 L
.10458 .0583 L
.11466 .06232 L
.1238 .06722 L
.12887 .07071 L
.13435 .07542 L
.13953 .08113 L
.14429 .08796 L
.14899 .09691 L
.15402 .11012 L
.15878 .12758 L
.16311 .14868 L
.1682 .17745 L
.17088 .19121 L
.17234 .19734 L
.17372 .2019 L
.17492 .20482 L
.17621 .20687 L
.1769 .20752 L
.17763 .20786 L
.17895 .20768 L
.18014 .2067 L
.18125 .20518 L
.18247 .20294 L
.18378 .19998 L
.20369 .13517 L
.20914 .12008 L
.21492 .10704 L
.21985 .09831 L
.22527 .09105 L
.22794 .08829 L
.23048 .0861 L
.23523 .08301 L
.23789 .08179 L
Mistroke
.24035 .08093 L
.24174 .08056 L
.24305 .08027 L
.24456 .08001 L
.24527 .07992 L
.24593 .07984 L
.24705 .07974 L
.24829 .07968 L
.24949 .07965 L
.25077 .07965 L
.25197 .07969 L
.2531 .07975 L
.25412 .07982 L
.25522 .07991 L
.2604 .08049 L
.26293 .08078 L
.26526 .081 L
.2664 .08109 L
.26747 .08116 L
.26858 .08121 L
.26979 .08125 L
.27103 .08125 L
.27216 .08122 L
.27346 .08116 L
.27468 .08107 L
.27594 .08093 L
.27728 .08075 L
.27967 .08032 L
.28224 .07971 L
.28507 .07888 L
.30609 .07056 L
.31609 .06725 L
.32558 .06503 L
.33081 .06415 L
.33651 .06342 L
.34169 .06292 L
.34648 .06257 L
.35111 .0623 L
.35609 .06208 L
.36512 .06179 L
.37035 .06167 L
.37586 .06155 L
.38572 .06137 L
.40566 .06107 L
.41436 .06096 L
.42379 .06087 L
.42903 .06083 L
.43386 .0608 L
.43848 .06078 L
.44081 .06078 L
Mistroke
.44338 .06077 L
.44477 .06077 L
.4461 .06076 L
.44731 .06076 L
.44859 .06076 L
.44932 .06076 L
.44998 .06076 L
.45127 .06076 L
.45199 .06076 L
.45278 .06076 L
.45351 .06076 L
.45419 .06076 L
.45541 .06076 L
.45654 .06076 L
.45779 .06076 L
.45912 .06076 L
.46184 .06076 L
.46432 .06077 L
.46913 .06078 L
.47424 .0608 L
.48342 .06083 L
.50419 .06093 L
.54196 .06116 L
.58218 .06143 L
.62089 .06168 L
.66205 .06193 L
.70169 .06213 L
.73982 .06231 L
.7804 .06247 L
.81947 .0626 L
.86098 .06273 L
.90099 .06285 L
.93947 .06295 L
.97619 .06304 L
Mfstroke
0 1 .111 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04127 L
.0379 .04214 L
.04033 .04334 L
.04262 .04418 L
.04761 .04549 L
.05217 .04636 L
.06244 .04797 L
.08259 .05142 L
.09399 .05395 L
.10458 .05689 L
.11466 .06048 L
.1238 .06473 L
.12887 .06769 L
.13435 .07157 L
.14429 .08125 L
.15372 .09555 L
.15901 .10653 L
.16384 .11772 L
.16656 .12361 L
.168 .12624 L
.16953 .12851 L
.17018 .12926 L
.17087 .12992 L
.17163 .13046 L
.17234 .13079 L
.173 .13093 L
.17369 .1309 L
.17493 .13044 L
.17617 .12945 L
.17686 .12868 L
.1775 .12787 L
.17988 .1239 L
.18529 .11187 L
.19504 .09035 L
.20054 .08128 L
.2056 .07505 L
.21004 .07103 L
.21492 .06788 L
.21737 .0667 L
.22001 .06569 L
.2225 .06495 L
.22478 .06444 L
Mistroke
.22607 .0642 L
.22729 .06402 L
.22839 .06388 L
.22956 .06376 L
.23084 .06366 L
.23201 .06359 L
.23327 .06354 L
.23398 .06353 L
.23465 .06352 L
.23584 .06352 L
.23696 .06354 L
.23797 .06357 L
.23907 .06361 L
.24153 .06375 L
.2438 .06391 L
.249 .06433 L
.25023 .06442 L
.25154 .0645 L
.25265 .06456 L
.25386 .06461 L
.25513 .06463 L
.25631 .06463 L
.25758 .0646 L
.2583 .06457 L
.25894 .06454 L
.26033 .06444 L
.26182 .06429 L
.26454 .06393 L
.27396 .06228 L
.28406 .06071 L
.29515 .05943 L
.30551 .05838 L
.3161 .0574 L
.32614 .05663 L
.33515 .05612 L
.34025 .0559 L
.34497 .05574 L
.34959 .05561 L
.35458 .0555 L
.36361 .05534 L
.3842 .05508 L
.39457 .05497 L
.40422 .05489 L
.41429 .05482 L
.41961 .05479 L
.42238 .05478 L
.42531 .05477 L
.42784 .05476 L
.43063 .05476 L
.43185 .05475 L
Mistroke
.43316 .05475 L
.43439 .05475 L
.43553 .05475 L
.43696 .05475 L
.43771 .05475 L
.43851 .05475 L
.43927 .05475 L
.43999 .05475 L
.44063 .05475 L
.44133 .05475 L
.44197 .05475 L
.44267 .05475 L
.44341 .05475 L
.44409 .05475 L
.44663 .05475 L
.44788 .05475 L
.44924 .05475 L
.45172 .05476 L
.45635 .05476 L
.46677 .05479 L
.50758 .05488 L
.54686 .05494 L
.58463 .055 L
.62486 .05505 L
.66356 .05509 L
.68323 .0551 L
.70472 .05511 L
.74437 .05513 L
.76399 .05514 L
.78495 .05515 L
.80631 .05515 L
.82647 .05515 L
.84649 .05516 L
.86495 .05516 L
.88373 .05516 L
.89452 .05516 L
.90437 .05516 L
.92384 .05516 L
.93456 .05516 L
.94473 .05516 L
.96106 .05516 L
.97619 .05516 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05245 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06778 L
.12887 .07144 L
.13435 .07642 L
.13953 .08253 L
.14429 .08999 L
.14899 .09996 L
.15162 .10719 L
.15402 .11515 L
.15869 .13554 L
.16311 .16196 L
.16791 .19518 L
.16918 .20323 L
.17054 .2109 L
.17174 .21653 L
.17301 .22117 L
.17367 .22304 L
.1744 .22465 L
.17567 .22642 L
.1764 .22687 L
.17719 .22692 L
.17793 .2266 L
.1786 .22602 L
.17988 .22429 L
.18126 .22163 L
.18378 .21532 L
.19317 .18609 L
.20326 .15862 L
.20905 .14682 L
.21433 .13871 L
.21688 .13572 L
.21965 .13314 L
Mistroke
.22092 .1322 L
.22227 .13137 L
.22354 .13074 L
.22469 .13031 L
.22588 .13001 L
.22717 .12985 L
.22782 .12984 L
.22852 .12987 L
.22978 .13008 L
.23104 .13048 L
.23223 .13103 L
.23329 .13169 L
.23445 .13258 L
.23711 .13543 L
.23845 .13733 L
.23993 .13985 L
.24255 .1455 L
.245 .15248 L
.24734 .16096 L
.2498 .17204 L
.2542 .19761 L
.2641 .27028 L
.26902 .30244 L
.27144 .31499 L
.27367 .32434 L
.27624 .33246 L
.27759 .33562 L
.27902 .33818 L
.28022 .33974 L
.28134 .34075 L
.28256 .3414 L
.28388 .3416 L
.28511 .34136 L
.28624 .34082 L
.28749 .33989 L
.28881 .33858 L
.29103 .3357 L
.29349 .33176 L
.30226 .31392 L
.31246 .29191 L
.32321 .2724 L
.33238 .2602 L
.33759 .25513 L
.34243 .25148 L
.34746 .24866 L
.35221 .24674 L
.35648 .2455 L
.36111 .24453 L
.36615 .24376 L
.3715 .24309 L
Mistroke
.37651 .24243 L
.38108 .24173 L
.39051 .23972 L
.3957 .23824 L
.40063 .2366 L
.41894 .22904 L
.45715 .21285 L
.49782 .20055 L
.53697 .19074 L
.57857 .18148 L
.61866 .1739 L
.65723 .16771 L
.69825 .16219 L
.73776 .15781 L
.77575 .15431 L
.81619 .15122 L
.85512 .14873 L
.8965 .14647 L
.93637 .1446 L
.97472 .14302 L
.97619 .14296 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05523 L
.10458 .05854 L
.11466 .06267 L
.1238 .06773 L
.12887 .07138 L
.13435 .07634 L
.13953 .08242 L
.14429 .08981 L
.14899 .09967 L
.15157 .10665 L
.15402 .11461 L
.15878 .13486 L
.16311 .15965 L
.16791 .19035 L
.17034 .20329 L
.17171 .20886 L
.17301 .21268 L
.17369 .21412 L
.17441 .21521 L
.1757 .21612 L
.17642 .21609 L
.17709 .21575 L
.17782 .21506 L
.1786 .21398 L
.18 .21134 L
.18131 .20816 L
.18378 .20096 L
.19261 .17104 L
.20209 .14303 L
.20753 .13049 L
.2125 .1212 L
.21756 .11368 L
.22224 .10824 L
.22712 .10398 L
Mistroke
.2297 .10225 L
.23244 .10077 L
.23506 .09969 L
.23634 .09927 L
.23752 .09895 L
.23857 .09872 L
.23973 .09851 L
.24089 .09836 L
.24212 .09825 L
.2428 .09822 L
.24353 .0982 L
.24423 .0982 L
.24487 .09821 L
.24609 .09827 L
.24738 .09838 L
.24876 .09855 L
.25006 .09875 L
.25301 .09928 L
.26316 .10126 L
.26563 .10176 L
.26827 .10239 L
.27302 .10391 L
.27797 .10615 L
.28338 .10924 L
.29302 .11521 L
.3019 .11972 L
.30689 .12151 L
.31217 .12285 L
.31491 .12336 L
.31747 .12374 L
.32329 .12436 L
.33294 .12517 L
.3384 .12578 L
.34345 .12658 L
.34851 .12766 L
.35388 .12916 L
.36378 .1329 L
.38233 .14248 L
.42005 .16177 L
.43937 .16889 L
.46022 .17554 L
.50132 .18804 L
.54092 .19869 L
.57899 .20754 L
.61952 .21614 L
.65853 .2238 L
.7 .23146 L
.73995 .23853 L
.77838 .24513 L
.81927 .25199 L
Mistroke
.85864 .25845 L
.89649 .26451 L
.9368 .27075 L
.97559 .27649 L
.97619 .27657 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04225 L
.04033 .04348 L
.04262 .04435 L
.04761 .04571 L
.05217 .04661 L
.06244 .04827 L
.08259 .05182 L
.09399 .05443 L
.10458 .05747 L
.11466 .06121 L
.1238 .06568 L
.12887 .0688 L
.13435 .07293 L
.14429 .08342 L
.16384 .12666 L
.16659 .13481 L
.16919 .14156 L
.17063 .14451 L
.17139 .14578 L
.17219 .14689 L
.17287 .1476 L
.17362 .14817 L
.17493 .14858 L
.17559 .1485 L
.17627 .14822 L
.1775 .14725 L
.17819 .14646 L
.17883 .14558 L
.18028 .14311 L
.18529 .13113 L
.19511 .10485 L
.19994 .09431 L
.20438 .0865 L
.20951 .07961 L
.21216 .07683 L
.21507 .0743 L
.21979 .07121 L
.22237 .06997 L
.22478 .06906 L
.22736 .06831 L
.22976 .0678 L
Mistroke
.23114 .06758 L
.23239 .06743 L
.23308 .06736 L
.23383 .0673 L
.23454 .06725 L
.23519 .06722 L
.23637 .06719 L
.23748 .06718 L
.23869 .0672 L
.23999 .06726 L
.24065 .06729 L
.24136 .06734 L
.24265 .06746 L
.24507 .06774 L
.24974 .06851 L
.2547 .06958 L
.2636 .07186 L
.26818 .07297 L
.273 .07392 L
.27552 .07428 L
.27695 .07444 L
.27828 .07455 L
.27951 .07463 L
.28062 .07467 L
.2819 .07469 L
.28311 .07468 L
.28417 .07465 L
.28534 .07459 L
.28655 .07449 L
.28769 .07438 L
.28972 .07412 L
.2919 .07377 L
.29687 .0727 L
.30141 .0715 L
.31143 .06856 L
.32208 .06575 L
.33117 .06393 L
.33635 .06314 L
.34122 .06254 L
.3459 .06208 L
.35083 .06169 L
.35964 .06118 L
.36913 .06079 L
.37952 .06044 L
.40074 .05974 L
.42005 .05912 L
.4401 .0586 L
.45906 .05824 L
.47905 .05798 L
.49749 .05779 L
Mistroke
.53686 .05747 L
.57472 .05725 L
.59414 .05717 L
.61503 .05709 L
.65627 .05698 L
.696 .0569 L
.73421 .05684 L
.77488 .05679 L
.81403 .05675 L
.85563 .05672 L
.89571 .0567 L
.93429 .05667 L
.97531 .05665 L
.97619 .05665 L
Mfstroke
0 1 .206 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05522 L
.10458 .05853 L
.11466 .06265 L
.1238 .0677 L
.12887 .07133 L
.13435 .07627 L
.13953 .08233 L
.14429 .0897 L
.14899 .09953 L
.15157 .1065 L
.15402 .11446 L
.15878 .13488 L
.16311 .16033 L
.16791 .19322 L
.17054 .20917 L
.17183 .21541 L
.17301 .21999 L
.17429 .22363 L
.17496 .225 L
.17567 .22605 L
.17639 .22673 L
.17707 .22702 L
.17781 .22699 L
.1786 .22659 L
.17927 .22598 L
.18 .22507 L
.18131 .22286 L
.18378 .21722 L
.19317 .1891 L
.20326 .16175 L
.20905 .14991 L
.21433 .14182 L
.21688 .13888 L
.21822 .13759 L
Mistroke
.21965 .13641 L
.22102 .13547 L
.22227 .13478 L
.22352 .13426 L
.22469 .13392 L
.22588 .13374 L
.22699 .13371 L
.2282 .13386 L
.2295 .13422 L
.23015 .13449 L
.23086 .13485 L
.23215 .13569 L
.23341 .13676 L
.23457 .13799 L
.23666 .14085 L
.23897 .14513 L
.24138 .15111 L
.24364 .15846 L
.24614 .16908 L
.24878 .1836 L
.25349 .21902 L
.25905 .27064 L
.26147 .29237 L
.2641 .31315 L
.26666 .32979 L
.26902 .34153 L
.27128 .34957 L
.27242 .3525 L
.27367 .35491 L
.27435 .35589 L
.275 .35661 L
.27621 .35744 L
.27752 .35762 L
.27826 .35743 L
.27895 .35707 L
.28008 .35613 L
.28134 .35463 L
.28388 .35032 L
.28844 .33942 L
.29335 .3249 L
.30226 .29625 L
.31262 .26493 L
.32227 .24076 L
.33234 .2213 L
.33763 .21325 L
.34337 .20596 L
.35387 .19574 L
.3638 .18872 L
.38238 .1791 L
.42327 .16086 L
Mistroke
.4436 .15286 L
.46264 .14686 L
.48088 .1424 L
.50049 .13858 L
.54174 .1322 L
.58146 .12735 L
.61968 .12365 L
.66034 .12048 L
.69949 .11801 L
.74109 .11589 L
.78118 .11424 L
.81975 .11291 L
.86077 .11173 L
.90028 .11075 L
.93827 .10992 L
.97619 .10919 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04684 L
.06244 .04864 L
.08259 .05245 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06778 L
.12887 .07144 L
.13435 .07642 L
.13953 .08253 L
.14429 .08998 L
.14899 .09993 L
.15157 .10698 L
.15402 .11505 L
.15878 .13566 L
.16311 .16107 L
.16791 .19286 L
.17034 .20641 L
.17171 .21231 L
.17301 .2164 L
.17369 .21798 L
.17441 .2192 L
.1757 .22033 L
.17642 .22041 L
.17709 .22016 L
.17782 .21956 L
.1786 .21858 L
.17927 .2175 L
.18 .21609 L
.18131 .21302 L
.18378 .20599 L
.19317 .17439 L
.20326 .14518 L
.20905 .13257 L
.21433 .12371 L
.21688 .12031 L
.21965 .11722 L
Mistroke
.22207 .11501 L
.22469 .11314 L
.22609 .11236 L
.22737 .11177 L
.2286 .11133 L
.22989 .11098 L
.23105 .11078 L
.23214 .11069 L
.23333 .11069 L
.2346 .11082 L
.2353 .11096 L
.23596 .11111 L
.23743 .11161 L
.23873 .11221 L
.24012 .11303 L
.24251 .1149 L
.24514 .1177 L
.2476 .1211 L
.24985 .12495 L
.25492 .13638 L
.2594 .14972 L
.2641 .16693 L
.27367 .20753 L
.27892 .22793 L
.2815 .23637 L
.28388 .24303 L
.28608 .24822 L
.28851 .25282 L
.29094 .25635 L
.29229 .25786 L
.29351 .25899 L
.29456 .25977 L
.2957 .26044 L
.2969 .26097 L
.29803 .2613 L
.2991 .26149 L
.30023 .26156 L
.30119 .26152 L
.30226 .2614 L
.30347 .26115 L
.3046 .26082 L
.30716 .25983 L
.31234 .25709 L
.32158 .25165 L
.32676 .24913 L
.32931 .24816 L
.33166 .24745 L
.33294 .24713 L
.33436 .24685 L
.33579 .24664 L
Mistroke
.33657 .24656 L
.3373 .2465 L
.33859 .24644 L
.33977 .24643 L
.34042 .24645 L
.34113 .24649 L
.34243 .2466 L
.34308 .24667 L
.34376 .24677 L
.34499 .24698 L
.34775 .24762 L
.35014 .24836 L
.35276 .24935 L
.36212 .25397 L
.37309 .26032 L
.38309 .26549 L
.3879 .26746 L
.39312 .26916 L
.39552 .26977 L
.39806 .27031 L
.40044 .27071 L
.40262 .271 L
.40509 .27124 L
.40639 .27133 L
.40705 .27136 L
.40775 .2714 L
.40894 .27144 L
.41005 .27146 L
.41137 .27146 L
.41257 .27145 L
.41325 .27143 L
.41398 .27141 L
.41528 .27136 L
.41667 .27129 L
.41821 .27119 L
.42354 .27072 L
.43371 .26943 L
.443 .26808 L
.4639 .26516 L
.50368 .2598 L
.54194 .25311 L
.58266 .24546 L
.62186 .23862 L
.66352 .23214 L
.70366 .2268 L
.74228 .22253 L
.78336 .21881 L
.82291 .21589 L
.86096 .21357 L
.90146 .21151 L
Mistroke
.94044 .20981 L
.97619 .20843 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04443 L
.04761 .04582 L
.05217 .04675 L
.06244 .04848 L
.08259 .05214 L
.09399 .05483 L
.10458 .05799 L
.11466 .0619 L
.1238 .06662 L
.12887 .06997 L
.13435 .07443 L
.13953 .07978 L
.14429 .08608 L
.14899 .09417 L
.15402 .10579 L
.15878 .12054 L
.16311 .13757 L
.1682 .15947 L
.17088 .16935 L
.17223 .17324 L
.17301 .17506 L
.17372 .17644 L
.17502 .17821 L
.1757 .17875 L
.17642 .17904 L
.17762 .17889 L
.17895 .17788 L
.18016 .17626 L
.18145 .1739 L
.18378 .16835 L
.19345 .13783 L
.20369 .10871 L
.20904 .0974 L
.21492 .08803 L
.2175 .08483 L
.22027 .08193 L
.22527 .07793 L
.22793 .07637 L
.2304 .07521 L
Mistroke
.23311 .07424 L
.23449 .07385 L
.23599 .0735 L
.23743 .07324 L
.23874 .07305 L
.24 .07292 L
.24064 .07287 L
.24133 .07283 L
.24254 .07279 L
.24383 .07278 L
.24505 .0728 L
.24617 .07285 L
.24735 .07294 L
.24861 .07305 L
.25087 .07333 L
.25598 .07421 L
.26526 .07616 L
.26765 .0766 L
.27016 .077 L
.27231 .07726 L
.27352 .07737 L
.27465 .07745 L
.27597 .07751 L
.27722 .07753 L
.27833 .07752 L
.27954 .07749 L
.28087 .07741 L
.28153 .07735 L
.28226 .07728 L
.28477 .07695 L
.28715 .07651 L
.28933 .07602 L
.29422 .07466 L
.30306 .07166 L
.3123 .06852 L
.32212 .06579 L
.32724 .06468 L
.33289 .06371 L
.33804 .06301 L
.34287 .06249 L
.34756 .0621 L
.35269 .06176 L
.36303 .06127 L
.37261 .06094 L
.38153 .06067 L
.42054 .05958 L
.43077 .05935 L
.44186 .05915 L
.45145 .05901 L
.46201 .05889 L
Mistroke
.48186 .05872 L
.50289 .05859 L
.52232 .0585 L
.5432 .05842 L
.55331 .05839 L
.56435 .05836 L
.57489 .05834 L
.58444 .05832 L
.60413 .0583 L
.61494 .05829 L
.62511 .05828 L
.63488 .05827 L
.6452 .05827 L
.65487 .05826 L
.66368 .05826 L
.67317 .05826 L
.67804 .05825 L
.68333 .05825 L
.68823 .05825 L
.69275 .05825 L
.69741 .05825 L
.70167 .05825 L
.70631 .05825 L
.70875 .05825 L
.71131 .05825 L
.71239 .05825 L
.71355 .05825 L
.71454 .05825 L
.71563 .05825 L
.7169 .05825 L
.7181 .05825 L
.71927 .05825 L
.72035 .05825 L
.72154 .05825 L
.72281 .05825 L
.72402 .05825 L
.72512 .05825 L
.72781 .05825 L
.73036 .05825 L
.73543 .05825 L
.74096 .05825 L
.75131 .05825 L
.76068 .05825 L
.78168 .05826 L
.82181 .05826 L
.86044 .05827 L
.90151 .05827 L
.94107 .05828 L
.97619 .05829 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .0379 L
.03527 .04037 L
.03652 .04133 L
.0379 .0422 L
.04033 .04342 L
.04262 .04428 L
.04761 .04562 L
.05217 .04651 L
.06244 .04816 L
.08259 .05169 L
.09399 .05428 L
.10458 .0573 L
.11466 .06101 L
.1238 .06543 L
.12887 .06853 L
.13435 .07261 L
.14429 .08299 L
.16384 .1253 L
.16659 .13302 L
.16919 .13922 L
.17063 .14183 L
.17144 .14297 L
.17219 .1438 L
.17283 .14432 L
.17352 .14469 L
.17425 .14486 L
.17493 .14482 L
.1762 .14424 L
.17684 .14372 L
.17753 .14297 L
.17877 .14126 L
.17992 .13927 L
.18529 .12674 L
.19511 .10189 L
.19994 .09208 L
.20438 .08485 L
.20951 .07852 L
.21221 .07593 L
.21507 .07368 L
.21969 .07095 L
.22232 .06982 L
.22478 .069 L
.22736 .06835 L
.22976 .06793 L
Mistroke
.23114 .06776 L
.23239 .06764 L
.23308 .06759 L
.23383 .06754 L
.23454 .06751 L
.23519 .06749 L
.23637 .06748 L
.23748 .06749 L
.23869 .06753 L
.23999 .06759 L
.24136 .06769 L
.24265 .0678 L
.24507 .06806 L
.25388 .06927 L
.2589 .06985 L
.2636 .07023 L
.26866 .07058 L
.27328 .07088 L
.27565 .071 L
.2769 .07106 L
.27823 .0711 L
.27893 .07112 L
.27957 .07113 L
.28082 .07114 L
.2815 .07114 L
.28223 .07114 L
.28292 .07112 L
.28355 .07111 L
.28462 .07107 L
.28576 .07101 L
.28782 .07085 L
.29027 .07059 L
.29251 .07028 L
.29737 .06941 L
.30199 .06838 L
.32018 .06384 L
.33054 .06174 L
.34028 .06029 L
.34978 .05927 L
.36003 .0585 L
.37098 .05791 L
.38103 .0575 L
.39993 .05695 L
.41065 .05673 L
.42062 .05657 L
.43113 .05644 L
.44106 .05635 L
.44997 .0563 L
.45496 .05627 L
.45964 .05625 L
Mistroke
.46909 .05622 L
.4741 .05621 L
.47949 .0562 L
.49048 .05619 L
.50052 .05618 L
.51038 .05617 L
.51952 .05616 L
.52479 .05616 L
.52956 .05616 L
.53221 .05616 L
.53507 .05616 L
.53638 .05616 L
.53777 .05616 L
.53906 .05616 L
.54025 .05616 L
.54147 .05616 L
.54212 .05616 L
.5428 .05616 L
.54395 .05616 L
.54522 .05616 L
.54634 .05616 L
.54755 .05616 L
.54869 .05616 L
.54974 .05616 L
.55211 .05616 L
.55469 .05616 L
.55991 .05616 L
.5645 .05616 L
.56941 .05616 L
.57824 .05616 L
.61976 .05618 L
.65976 .0562 L
.69825 .05622 L
.71775 .05622 L
.73919 .05623 L
.77861 .05624 L
.79807 .05624 L
.81897 .05624 L
.84016 .05625 L
.8499 .05625 L
.86027 .05625 L
.87069 .05625 L
.88013 .05625 L
.88909 .05625 L
.89853 .05625 L
.90859 .05625 L
.91783 .05625 L
.92778 .05625 L
.93342 .05625 L
.93867 .05625 L
Mistroke
.94351 .05625 L
.94624 .05625 L
.94877 .05625 L
.95097 .05625 L
.9534 .05625 L
.95462 .05625 L
.95594 .05625 L
.95718 .05625 L
.95831 .05625 L
.95941 .05625 L
.96058 .05625 L
.96169 .05625 L
.96269 .05625 L
.96388 .05625 L
.96516 .05625 L
.96636 .05625 L
.96748 .05625 L
.97171 .05625 L
.97619 .05625 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .0486 L
.08259 .05237 L
.09399 .05514 L
.10458 .05841 L
.11466 .06248 L
.1238 .06745 L
.12887 .07102 L
.13435 .07584 L
.13953 .08173 L
.14429 .08883 L
.14899 .09822 L
.15157 .10482 L
.15402 .1123 L
.15878 .13125 L
.16311 .15451 L
.16791 .18447 L
.17054 .19922 L
.17183 .2051 L
.17301 .20949 L
.17429 .21308 L
.17496 .21446 L
.17567 .21556 L
.17639 .21631 L
.17707 .21668 L
.17781 .21675 L
.1786 .21646 L
.17927 .21595 L
.18 .21514 L
.18131 .21309 L
.18378 .20766 L
.19317 .17899 L
.20326 .14992 L
.20905 .13711 L
.21433 .12822 L
.21688 .1249 L
.21965 .12198 L
Mistroke
.22092 .12089 L
.22227 .11989 L
.22343 .11917 L
.22469 .11853 L
.22599 .11804 L
.2267 .11784 L
.22736 .1177 L
.22855 .11756 L
.22982 .11757 L
.23053 .11765 L
.2313 .1178 L
.23204 .11801 L
.23271 .11826 L
.23399 .11888 L
.23535 .11977 L
.23653 .12076 L
.23781 .12207 L
.24012 .12513 L
.24286 .13018 L
.24537 .13646 L
.24763 .14376 L
.24974 .1522 L
.2545 .17774 L
.2641 .2437 L
.26656 .25868 L
.26916 .27187 L
.27052 .27752 L
.27202 .28267 L
.27339 .28644 L
.27465 .28908 L
.27592 .291 L
.27713 .29215 L
.2784 .2927 L
.27912 .29272 L
.27979 .29257 L
.2809 .29197 L
.28212 .29083 L
.2834 .28918 L
.2846 .28722 L
.28926 .2767 L
.29354 .26429 L
.3032 .23283 L
.31233 .20436 L
.3221 .1788 L
.33281 .15731 L
.34279 .14262 L
.35301 .13157 L
.36411 .12287 L
.37458 .11683 L
.38425 .11253 L
Mistroke
.40299 .10614 L
.42362 .10066 L
.44305 .09654 L
.46393 .09319 L
.48508 .09076 L
.50518 .08907 L
.54339 .08671 L
.58405 .08488 L
.6232 .08361 L
.66481 .08259 L
.70489 .08185 L
.74346 .08129 L
.78449 .08082 L
.82399 .08045 L
.86198 .08014 L
.90243 .07987 L
.94136 .07963 L
.97619 .07944 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05526 L
.10458 .05858 L
.11466 .06273 L
.1238 .06782 L
.12887 .07149 L
.13435 .07648 L
.13953 .08263 L
.14429 .09011 L
.14899 .10013 L
.15162 .1074 L
.15402 .11539 L
.15869 .1358 L
.16311 .16202 L
.16791 .19424 L
.17034 .20793 L
.17171 .21386 L
.17301 .21796 L
.17369 .21952 L
.17441 .22073 L
.1757 .22182 L
.17642 .22188 L
.17709 .22161 L
.17782 .22098 L
.1786 .21997 L
.18 .21743 L
.18131 .21433 L
.18378 .20727 L
.19261 .17772 L
.20209 .14996 L
.20753 .13756 L
.2125 .12847 L
.2175 .12136 L
.22224 .11637 L
.22463 .11446 L
Mistroke
.22718 .11288 L
.22841 .11227 L
.22958 .1118 L
.23061 .11145 L
.23175 .11116 L
.23302 .11094 L
.23371 .11087 L
.23435 .11084 L
.2355 .11085 L
.23673 .11098 L
.23743 .1111 L
.23818 .11127 L
.23955 .1117 L
.24089 .11227 L
.24212 .11293 L
.24462 .11471 L
.24697 .11694 L
.24955 .12009 L
.25233 .12434 L
.25798 .13607 L
.26316 .15069 L
.27311 .18706 L
.27858 .20759 L
.28373 .22432 L
.28854 .2365 L
.29125 .24178 L
.29375 .24567 L
.29585 .24828 L
.29817 .25052 L
.29933 .25141 L
.30058 .25221 L
.30165 .25278 L
.30284 .2533 L
.30407 .25371 L
.30538 .25403 L
.3066 .25424 L
.30774 .25435 L
.30839 .25439 L
.30908 .25441 L
.31031 .25439 L
.31163 .25432 L
.31238 .25425 L
.31308 .25418 L
.31817 .25345 L
.32038 .25311 L
.32279 .25278 L
.32393 .25266 L
.32514 .25255 L
.32618 .25247 L
.32731 .25242 L
Mistroke
.32838 .25241 L
.32952 .25242 L
.3306 .25247 L
.33159 .25254 L
.33279 .25267 L
.3339 .25283 L
.33641 .25334 L
.33863 .25398 L
.341 .25484 L
.34636 .25753 L
.35129 .26082 L
.36242 .27043 L
.37286 .28062 L
.3826 .28949 L
.39246 .29679 L
.40144 .30167 L
.40656 .30375 L
.41142 .30531 L
.41654 .30662 L
.42211 .30772 L
.43152 .30908 L
.4419 .31024 L
.46291 .31242 L
.47314 .31348 L
.4839 .3145 L
.49309 .31521 L
.49835 .31553 L
.50313 .31577 L
.50812 .31596 L
.51041 .31603 L
.51283 .31609 L
.51542 .31614 L
.5178 .31617 L
.51913 .31618 L
.52037 .31619 L
.52108 .3162 L
.52173 .3162 L
.52248 .3162 L
.52319 .3162 L
.52437 .3162 L
.52543 .3162 L
.52666 .31619 L
.52782 .31619 L
.5289 .31618 L
.52989 .31617 L
.53211 .31614 L
.53685 .31607 L
.54184 .31596 L
.55135 .31569 L
.56153 .31534 L
Mistroke
.57988 .31461 L
.62132 .31273 L
.66123 .3108 L
.69964 .30912 L
.74049 .30768 L
.7608 .30711 L
.77983 .30666 L
.81765 .30597 L
.83789 .3057 L
.85641 .3055 L
.87699 .30533 L
.89611 .3052 L
.93429 .30501 L
.97341 .30485 L
.97619 .30484 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04588 L
.05217 .04684 L
.06244 .04864 L
.08259 .05244 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06777 L
.12887 .07143 L
.13435 .07641 L
.13953 .08252 L
.14429 .08995 L
.14899 .09989 L
.15157 .10694 L
.15402 .11499 L
.15878 .13557 L
.16311 .16096 L
.16791 .19286 L
.16918 .20044 L
.17054 .20757 L
.17174 .21271 L
.17301 .21683 L
.17367 .21843 L
.1744 .21975 L
.17567 .22103 L
.1764 .22121 L
.17719 .22098 L
.17793 .2204 L
.1786 .21961 L
.17988 .21748 L
.18126 .21443 L
.18378 .20751 L
.19317 .17679 L
.20326 .14815 L
.20905 .13531 L
.21433 .12571 L
.21971 .1178 L
.22469 .11199 L
Mistroke
.22938 .10775 L
.23437 .10442 L
.23722 .10304 L
.2399 .10206 L
.24231 .10143 L
.24366 .10116 L
.24491 .10098 L
.24602 .10085 L
.24721 .10076 L
.24834 .1007 L
.24936 .10068 L
.25057 .10067 L
.25187 .10068 L
.25311 .1007 L
.25425 .10073 L
.25534 .10075 L
.25652 .10077 L
.25781 .10077 L
.25903 .10075 L
.26032 .10071 L
.26097 .10068 L
.26167 .10064 L
.2641 .10045 L
.26664 .10021 L
.2694 .09994 L
.27067 .09982 L
.272 .09972 L
.27314 .09965 L
.2744 .0996 L
.27562 .09957 L
.27673 .09957 L
.27801 .0996 L
.27923 .09966 L
.28035 .09974 L
.28139 .09984 L
.28375 .10013 L
.28624 .10053 L
.28857 .10098 L
.29391 .10216 L
.29906 .10333 L
.30471 .10447 L
.30945 .10524 L
.31453 .10588 L
.31988 .10637 L
.32487 .10672 L
.32954 .10704 L
.33449 .10742 L
.33871 .10783 L
.34337 .10841 L
.34865 .10929 L
Mistroke
.35359 .11035 L
.36469 .11362 L
.37439 .11741 L
.38483 .12218 L
.42608 .14122 L
.4658 .15605 L
.50402 .17013 L
.54468 .18457 L
.58383 .19755 L
.62543 .21065 L
.66552 .2226 L
.70409 .23351 L
.74511 .24463 L
.78462 .25495 L
.82261 .26459 L
.86306 .27459 L
.90199 .28395 L
.94337 .29357 L
.97619 .30092 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .0414 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04584 L
.05217 .04678 L
.06244 .04852 L
.08259 .05223 L
.09399 .05496 L
.10458 .05816 L
.11466 .06214 L
.1238 .06697 L
.12887 .07041 L
.13435 .07503 L
.13953 .08061 L
.14429 .08726 L
.14899 .09592 L
.15402 .10859 L
.15878 .12512 L
.16311 .14473 L
.1682 .17059 L
.17088 .18234 L
.17223 .18699 L
.17301 .18918 L
.17372 .19085 L
.17502 .19304 L
.1757 .19376 L
.17642 .19421 L
.17762 .19427 L
.17895 .19343 L
.18016 .19194 L
.18145 .18969 L
.18378 .18432 L
.19345 .15449 L
.20369 .12577 L
.20904 .11456 L
.21187 .10973 L
.21492 .10537 L
.21771 .10207 L
.22027 .09961 L
.22284 .09765 L
.22527 .09623 L
Mistroke
.22657 .09565 L
.2278 .0952 L
.22889 .09489 L
.23008 .09465 L
.23138 .09449 L
.23203 .09446 L
.23275 .09446 L
.23402 .09454 L
.2352 .09472 L
.2364 .09501 L
.23753 .09539 L
.23964 .09638 L
.24083 .09711 L
.24193 .0979 L
.2444 .10016 L
.24689 .10317 L
.24922 .10678 L
.25452 .11827 L
.25969 .13358 L
.26526 .15201 L
.2699 .16591 L
.27245 .17208 L
.27485 .17668 L
.27622 .17872 L
.2777 .18044 L
.27836 .18105 L
.27905 .18158 L
.28029 .18228 L
.28153 .18265 L
.28269 .18271 L
.28397 .18246 L
.28468 .1822 L
.28534 .18188 L
.28664 .18102 L
.28803 .17982 L
.29052 .177 L
.29617 .16827 L
.30645 .14857 L
.31603 .13073 L
.32612 .11526 L
.33473 .10511 L
.34417 .09673 L
.35417 .09022 L
.36349 .08577 L
.37356 .08219 L
.38434 .07936 L
.39456 .07732 L
.40566 .07555 L
.4258 .07306 L
.44565 .07124 L
Mistroke
.45579 .0705 L
.46669 .06985 L
.48624 .06896 L
.50454 .06836 L
.52569 .06785 L
.54579 .06747 L
.584 .06695 L
.60369 .06675 L
.62467 .06659 L
.64466 .06646 L
.66627 .06636 L
.70636 .06621 L
.72631 .06616 L
.74738 .06611 L
.78537 .06605 L
.82581 .066 L
.86474 .06596 L
.90612 .06592 L
.94599 .06589 L
.97619 .06586 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05522 L
.10458 .05853 L
.11466 .06265 L
.1238 .0677 L
.12887 .07134 L
.13435 .07628 L
.13953 .08234 L
.14429 .0897 L
.14899 .09951 L
.15157 .10644 L
.15402 .11436 L
.15878 .13455 L
.16311 .15945 L
.16791 .191 L
.16918 .19862 L
.17054 .20588 L
.17174 .21121 L
.17301 .21558 L
.17367 .21734 L
.1744 .21884 L
.17567 .22046 L
.1764 .22084 L
.17719 .22082 L
.17793 .22044 L
.1786 .21982 L
.17988 .21801 L
.18126 .21527 L
.18378 .20883 L
.20326 .15003 L
.2086 .13756 L
.21433 .12627 L
.22469 .11098 L
.22975 .10571 L
.23242 .10347 L
Mistroke
.23526 .10148 L
.23799 .09992 L
.24046 .0988 L
.24295 .09792 L
.24528 .0973 L
.24758 .09686 L
.24873 .09669 L
.25 .09654 L
.25224 .09633 L
.25433 .09618 L
.25675 .096 L
.25905 .09578 L
.26169 .09542 L
.2641 .09498 L
.27289 .09256 L
.28235 .08971 L
.28778 .08849 L
.29015 .08807 L
.29274 .08769 L
.29749 .08719 L
.30008 .08699 L
.30248 .08685 L
.30507 .08673 L
.30751 .08663 L
.31207 .08651 L
.31462 .08645 L
.31698 .08641 L
.31956 .08637 L
.32086 .08636 L
.32229 .08635 L
.32297 .08634 L
.3237 .08634 L
.32439 .08634 L
.32503 .08633 L
.32625 .08633 L
.32754 .08634 L
.3282 .08634 L
.32891 .08634 L
.33021 .08636 L
.33096 .08636 L
.33175 .08638 L
.33316 .0864 L
.33567 .08646 L
.33801 .08654 L
.34057 .08666 L
.34331 .08682 L
.34863 .08723 L
.35354 .08776 L
.35893 .08851 L
.36463 .08949 L
Mistroke
.38478 .09434 L
.42263 .10533 L
.46294 .11547 L
.50173 .1251 L
.54298 .13511 L
.58271 .14408 L
.62092 .15216 L
.66158 .16015 L
.70073 .16726 L
.74234 .1743 L
.78242 .18069 L
.82099 .18656 L
.86202 .19257 L
.90152 .19817 L
.93952 .20339 L
.97619 .20827 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05238 L
.09399 .05516 L
.10458 .05843 L
.11466 .06251 L
.1238 .0675 L
.12887 .07108 L
.13435 .07593 L
.13953 .08184 L
.14429 .08899 L
.14899 .09844 L
.15157 .10508 L
.15402 .11261 L
.15878 .13168 L
.16311 .15507 L
.16791 .18517 L
.17054 .20003 L
.17183 .20598 L
.17301 .21044 L
.17429 .21409 L
.17496 .2155 L
.17567 .21663 L
.17639 .21741 L
.17707 .21781 L
.17781 .21791 L
.1786 .21765 L
.17927 .21716 L
.18 .21638 L
.18131 .21436 L
.18259 .21179 L
.18378 .20899 L
.19359 .17884 L
.20413 .14664 L
.21325 .12387 L
.22318 .10566 L
.22845 .09884 L
Mistroke
.23334 .09413 L
.238 .09092 L
.24061 .08961 L
.24298 .08868 L
.24531 .08798 L
.24746 .08751 L
.24858 .08733 L
.24981 .08716 L
.2511 .08702 L
.2523 .08693 L
.25344 .08686 L
.25451 .08681 L
.25548 .08678 L
.25653 .08675 L
.2589 .08668 L
.25993 .08665 L
.26107 .08661 L
.26221 .08655 L
.26341 .08647 L
.26472 .08635 L
.26593 .08622 L
.26814 .0859 L
.27049 .08543 L
.27329 .08471 L
.27594 .08388 L
.28088 .08197 L
.2911 .07733 L
.3019 .07284 L
.31146 .06991 L
.31688 .06869 L
.32195 .0678 L
.32661 .06717 L
.33086 .06672 L
.33577 .06632 L
.33817 .06617 L
.34042 .06605 L
.345 .06587 L
.34743 .06579 L
.34868 .06576 L
.35006 .06574 L
.35131 .06572 L
.35266 .0657 L
.35408 .06568 L
.3554 .06567 L
.35672 .06567 L
.35797 .06566 L
.35909 .06566 L
.3603 .06567 L
.36145 .06567 L
.36252 .06568 L
Mistroke
.36369 .06569 L
.36495 .0657 L
.36753 .06574 L
.36988 .06577 L
.37872 .06598 L
.38857 .0663 L
.39772 .06665 L
.41844 .06755 L
.45759 .06932 L
.4992 .07129 L
.53928 .07322 L
.57785 .07495 L
.61888 .07664 L
.65838 .07812 L
.69638 .07939 L
.73682 .0806 L
.77575 .08166 L
.81713 .0827 L
.857 .08363 L
.89534 .08449 L
.93615 .08537 L
.97543 .08618 L
.97619 .0862 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .03789 L
.03527 .04036 L
.03652 .04131 L
.0379 .04218 L
.04033 .04339 L
.04262 .04425 L
.04761 .04557 L
.05217 .04644 L
.06244 .04807 L
.08259 .05153 L
.09399 .05407 L
.10458 .05704 L
.11466 .06065 L
.1238 .06494 L
.12887 .06793 L
.13435 .07184 L
.14429 .08163 L
.16384 .11936 L
.16659 .12589 L
.16919 .13106 L
.17063 .13319 L
.17144 .13411 L
.17219 .13477 L
.17283 .13516 L
.17352 .13542 L
.17425 .1355 L
.17493 .1354 L
.1762 .13477 L
.17684 .13424 L
.17753 .13352 L
.17992 .12999 L
.1827 .12433 L
.18529 .11822 L
.19511 .09521 L
.19994 .0863 L
.20438 .07982 L
.20951 .07421 L
.21221 .07195 L
.21507 .07 L
.21969 .06766 L
.22232 .06672 L
.22478 .06604 L
.22603 .06577 L
.22736 .06553 L
Mistroke
.22851 .06536 L
.22976 .06521 L
.23052 .06514 L
.23123 .06509 L
.23188 .06504 L
.23261 .06501 L
.23386 .06497 L
.23455 .06497 L
.23519 .06497 L
.23647 .065 L
.23768 .06505 L
.23877 .06511 L
.23996 .06521 L
.24261 .06549 L
.24507 .06584 L
.24934 .06661 L
.25406 .06766 L
.2636 .07012 L
.26854 .07133 L
.27122 .07191 L
.27372 .07236 L
.27604 .07271 L
.27815 .07294 L
.27936 .07304 L
.28049 .07311 L
.28169 .07316 L
.28299 .07318 L
.28429 .07317 L
.28551 .07314 L
.2862 .0731 L
.28684 .07307 L
.28827 .07295 L
.28964 .07281 L
.29114 .07263 L
.29385 .0722 L
.29905 .07112 L
.30386 .0699 L
.31359 .06727 L
.32409 .06476 L
.32891 .06382 L
.334 .06299 L
.34309 .06188 L
.3476 .06148 L
.35242 .06113 L
.3611 .06066 L
.37142 .06025 L
.38081 .05994 L
.40159 .05926 L
.42076 .05864 L
.44061 .05812 L
Mistroke
.45919 .05777 L
.47793 .05752 L
.49857 .0573 L
.53736 .05697 L
.55708 .05684 L
.5786 .05672 L
.61833 .05656 L
.659 .05644 L
.69815 .05635 L
.73975 .05628 L
.77983 .05623 L
.8184 .05619 L
.85943 .05615 L
.89894 .05612 L
.93693 .0561 L
.97619 .05607 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05523 L
.10458 .05853 L
.11466 .06265 L
.1238 .06771 L
.12887 .07135 L
.13435 .0763 L
.13953 .08237 L
.14429 .08977 L
.14899 .09964 L
.15162 .1068 L
.15402 .11469 L
.15869 .13491 L
.16311 .16134 L
.16791 .19543 L
.17054 .21232 L
.17183 .21906 L
.17301 .2241 L
.17429 .22824 L
.17496 .22987 L
.17567 .23118 L
.17639 .23213 L
.17707 .23267 L
.17781 .2329 L
.1786 .23277 L
.17927 .23239 L
.18 .23172 L
.18131 .22993 L
.18259 .22761 L
.18378 .22507 L
.19359 .19872 L
.199 .18497 L
.20413 .17394 L
.20889 .1657 L
.21141 .16217 L
Mistroke
.21409 .15906 L
.21656 .15681 L
.2188 .15531 L
.21989 .15478 L
.22106 .15437 L
.22216 .15412 L
.22318 .15403 L
.22433 .15409 L
.22538 .15431 L
.22659 .15475 L
.22773 .15539 L
.22879 .15617 L
.22976 .15707 L
.23197 .15982 L
.2342 .16373 L
.23665 .16969 L
.23921 .17825 L
.24161 .18908 L
.244 .20332 L
.2465 .22306 L
.24864 .24456 L
.25098 .27322 L
.25582 .34396 L
.25837 .38027 L
.26107 .41253 L
.26238 .42529 L
.26383 .43689 L
.26516 .44537 L
.26637 .45136 L
.26762 .4559 L
.2683 .45775 L
.26895 .4591 L
.27011 .46061 L
.27137 .46108 L
.27249 .46059 L
.27372 .45916 L
.27501 .45683 L
.27622 .45395 L
.28072 .43903 L
.30168 .34506 L
.31149 .30641 L
.32184 .27267 L
.34033 .22814 L
.34986 .21151 L
.36005 .19738 L
.37841 .17889 L
.38864 .17112 L
.39973 .16387 L
.41988 .15269 L
.43973 .14385 L
Mistroke
.46076 .13687 L
.48031 .13227 L
.49862 .12912 L
.53741 .12439 L
.55856 .12246 L
.57865 .12097 L
.61687 .11882 L
.63655 .11799 L
.65753 .11724 L
.69913 .11608 L
.73922 .11527 L
.77779 .11467 L
.81881 .11416 L
.85832 .11374 L
.89631 .11338 L
.93676 .11303 L
.97569 .11273 L
.97619 .11273 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05528 L
.10458 .0586 L
.11466 .06275 L
.1238 .06785 L
.12887 .07154 L
.13435 .07655 L
.13953 .08273 L
.14429 .09028 L
.14899 .10042 L
.15162 .1078 L
.15402 .11596 L
.15869 .137 L
.16311 .16454 L
.16791 .1996 L
.16918 .20816 L
.17054 .21634 L
.17174 .22239 L
.17301 .22741 L
.17367 .22946 L
.1744 .23125 L
.17567 .2333 L
.1764 .23389 L
.17719 .23409 L
.17793 .2339 L
.1786 .23344 L
.17988 .23193 L
.1806 .23075 L
.18126 .2295 L
.18378 .22366 L
.19359 .19558 L
.199 .18167 L
.20413 .17071 L
.20889 .16262 L
.21141 .15916 L
Mistroke
.21409 .1561 L
.21656 .15387 L
.2188 .15236 L
.21989 .15181 L
.22106 .15136 L
.22216 .15107 L
.22318 .15093 L
.22433 .15091 L
.22538 .15104 L
.22659 .15138 L
.22773 .15188 L
.22879 .15251 L
.22976 .15326 L
.23197 .15555 L
.23312 .15712 L
.2342 .15884 L
.23665 .16383 L
.23904 .17038 L
.24161 .17977 L
.24398 .19108 L
.24656 .20706 L
.25177 .25281 L
.26107 .35632 L
.26361 .37932 L
.26637 .39893 L
.26763 .40601 L
.26897 .41222 L
.27013 .41656 L
.27137 .42023 L
.27257 .42287 L
.27367 .42454 L
.27477 .42557 L
.27582 .426 L
.27704 .42588 L
.27816 .42525 L
.2794 .42404 L
.28072 .42224 L
.28319 .41767 L
.28585 .41141 L
.29068 .39795 L
.30168 .36464 L
.31204 .33669 L
.3217 .31599 L
.33176 .29997 L
.33709 .29356 L
.34279 .28806 L
.35301 .2809 L
.35878 .27792 L
.36411 .27556 L
.38425 .267 L
Mistroke
.42362 .24331 L
.46148 .22192 L
.4809 .214 L
.50179 .20705 L
.54303 .19564 L
.58276 .18661 L
.62097 .17952 L
.66164 .17329 L
.70079 .16834 L
.74239 .16403 L
.78248 .16062 L
.82105 .15787 L
.86207 .1554 L
.90158 .15336 L
.93957 .15164 L
.97619 .15016 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05527 L
.10458 .05859 L
.11466 .06273 L
.1238 .06783 L
.12887 .0715 L
.13435 .0765 L
.13953 .08266 L
.14429 .09016 L
.14899 .1002 L
.15162 .10748 L
.15402 .1155 L
.15869 .13597 L
.16311 .16229 L
.16791 .19464 L
.17034 .20838 L
.17171 .21433 L
.17301 .21843 L
.17369 .22 L
.17441 .22121 L
.1757 .22229 L
.17642 .22235 L
.17709 .22207 L
.17782 .22144 L
.1786 .22043 L
.18 .21788 L
.18131 .21477 L
.18378 .2077 L
.19261 .1782 L
.20209 .15047 L
.20753 .13796 L
.2125 .12865 L
.21756 .1211 L
.22224 .11569 L
.22712 .11155 L
Mistroke
.2297 .10994 L
.23101 .10927 L
.23244 .10866 L
.2338 .10818 L
.23506 .10784 L
.23625 .10759 L
.23752 .10742 L
.23865 .10735 L
.23971 .10734 L
.24087 .10741 L
.24212 .10756 L
.2428 .10769 L
.24353 .10785 L
.24483 .10821 L
.24623 .1087 L
.24778 .10937 L
.25313 .11266 L
.25831 .11716 L
.26316 .12279 L
.26787 .12997 L
.27302 .13981 L
.28338 .16273 L
.28796 .1722 L
.29291 .18093 L
.29759 .18742 L
.3019 .1919 L
.30429 .19381 L
.30691 .19551 L
.30964 .19688 L
.3122 .19787 L
.31456 .19857 L
.31671 .19908 L
.32155 .19994 L
.32683 .20073 L
.32972 .20123 L
.33243 .20179 L
.33722 .20309 L
.34251 .20515 L
.3473 .20763 L
.35168 .21045 L
.36158 .21856 L
.38233 .23972 L
.39223 .2494 L
.40283 .25825 L
.42192 .27009 L
.44186 .27886 L
.45999 .28581 L
.49994 .29984 L
.53838 .31005 L
.57927 .31815 L
Mistroke
.61864 .3246 L
.65649 .3299 L
.6968 .33493 L
.73559 .3394 L
.77683 .3439 L
.81656 .34805 L
.85478 .35187 L
.89544 .35574 L
.93459 .35922 L
.97619 .36261 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04113 L
.0379 .04198 L
.04033 .04315 L
.04262 .04398 L
.04517 .04469 L
.04761 .04524 L
.05217 .04607 L
.06244 .04762 L
.07302 .04924 L
.08429 .05127 L
.09474 .05354 L
.10458 .05618 L
.1142 .05941 L
.12461 .064 L
.13407 .06971 L
.14277 .07706 L
.15263 .08928 L
.15805 .09822 L
.16319 .10753 L
.16551 .11142 L
.16797 .11484 L
.16925 .11618 L
.16998 .11677 L
.17067 .1172 L
.17187 .11765 L
.17317 .11768 L
.17427 .11732 L
.17548 .11655 L
.17674 .11533 L
.17791 .11387 L
.18226 .10644 L
.1917 .08775 L
.19634 .08022 L
.20062 .07469 L
.20555 .06988 L
.20815 .06793 L
.21089 .06624 L
.21534 .06421 L
.21787 .06338 L
.22023 .06278 L
.22148 .06253 L
.22282 .0623 L
Mistroke
.22397 .06214 L
.22521 .062 L
.22598 .06193 L
.22668 .06187 L
.22734 .06183 L
.22806 .0618 L
.22931 .06176 L
.23 .06175 L
.23064 .06174 L
.23192 .06176 L
.23314 .0618 L
.23423 .06185 L
.23541 .06192 L
.23807 .06216 L
.24052 .06245 L
.2448 .06312 L
.24951 .06404 L
.25906 .06634 L
.26851 .0687 L
.27325 .06967 L
.27594 .0701 L
.27844 .0704 L
.27986 .07053 L
.2812 .07063 L
.28241 .07069 L
.28371 .07072 L
.28439 .07073 L
.28514 .07073 L
.28591 .07073 L
.28664 .07071 L
.28794 .07066 L
.28867 .07062 L
.28934 .07057 L
.29179 .07035 L
.29446 .07002 L
.29931 .06921 L
.31867 .06485 L
.32896 .06287 L
.33437 .06205 L
.34006 .06135 L
.3451 .06086 L
.35061 .06044 L
.36029 .0599 L
.37013 .05951 L
.3793 .05921 L
.41831 .05797 L
.4382 .05743 L
.44867 .05721 L
.45977 .05701 L
.48055 .05673 L
Mistroke
.49972 .05653 L
.53758 .05621 L
.57789 .05596 L
.61668 .05579 L
.65792 .05565 L
.69765 .05556 L
.73586 .05549 L
.77653 .05543 L
.81568 .05539 L
.85728 .05535 L
.89737 .05532 L
.93594 .05529 L
.97619 .05526 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05528 L
.10458 .05861 L
.11466 .06277 L
.1238 .06788 L
.12887 .07157 L
.13435 .0766 L
.13953 .08279 L
.14429 .09036 L
.14899 .10053 L
.15162 .10793 L
.15402 .11612 L
.15869 .13715 L
.16311 .16454 L
.16791 .19883 L
.16918 .20704 L
.17054 .21477 L
.17174 .22038 L
.17301 .2249 L
.17367 .22668 L
.1744 .22817 L
.17567 .22971 L
.1764 .23001 L
.17719 .22991 L
.17793 .22944 L
.1786 .22873 L
.17988 .22678 L
.18126 .2239 L
.18378 .21732 L
.19317 .18819 L
.20326 .16185 L
.20905 .15068 L
.21433 .14298 L
.21688 .14012 L
.21965 .13763 L
Mistroke
.22092 .13672 L
.22227 .1359 L
.22343 .13534 L
.22469 .13486 L
.22599 .13453 L
.2267 .13442 L
.22736 .13436 L
.22855 .13437 L
.22982 .13456 L
.23053 .13474 L
.2313 .13501 L
.23271 .13568 L
.23408 .13658 L
.23535 .13765 L
.23766 .14025 L
.24021 .14422 L
.24288 .14985 L
.24537 .15675 L
.25008 .17504 L
.25439 .19849 L
.2641 .26949 L
.27327 .33783 L
.27591 .35312 L
.2784 .36498 L
.28064 .37344 L
.28306 .38035 L
.28435 .38315 L
.28578 .38556 L
.28649 .38653 L
.28726 .38739 L
.28793 .38799 L
.28865 .38851 L
.28937 .38889 L
.29003 .38913 L
.29134 .3893 L
.29253 .38915 L
.2938 .3887 L
.29497 .38805 L
.29624 .38712 L
.29854 .38497 L
.30377 .37856 L
.31414 .36445 L
.31919 .35851 L
.32379 .35412 L
.32866 .35067 L
.33133 .34932 L
.33386 .34839 L
.33519 .34803 L
.33592 .34787 L
.33661 .34775 L
Mistroke
.33782 .34759 L
.33846 .34753 L
.33915 .34749 L
.33988 .34747 L
.34068 .34748 L
.34144 .34752 L
.34214 .34757 L
.34284 .34764 L
.34347 .34773 L
.34488 .34797 L
.34721 .34853 L
.34976 .34934 L
.35492 .3515 L
.36414 .35622 L
.36974 .35905 L
.37504 .36136 L
.3798 .36298 L
.38248 .36366 L
.38368 .36391 L
.38497 .36414 L
.38618 .36431 L
.38729 .36445 L
.38835 .36454 L
.38947 .36461 L
.3907 .36466 L
.39184 .36467 L
.3931 .36464 L
.3938 .36461 L
.39444 .36457 L
.39573 .36447 L
.39692 .36435 L
.39961 .36396 L
.40198 .3635 L
.40449 .36291 L
.41446 .35973 L
.42541 .35532 L
.46577 .33932 L
.50462 .3261 L
.54591 .31118 L
.58569 .29726 L
.62396 .28516 L
.66468 .27381 L
.70388 .26446 L
.74553 .25616 L
.78567 .24954 L
.82429 .24422 L
.86537 .23945 L
.90493 .23552 L
.94297 .23223 L
.97619 .22966 L
Mistroke
Mfstroke
0 1 .585 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .05242 L
.09399 .05521 L
.10458 .0585 L
.11466 .06261 L
.1238 .06765 L
.12887 .07127 L
.13435 .07619 L
.13953 .08221 L
.14429 .08951 L
.14899 .09923 L
.15157 .10609 L
.15402 .11391 L
.15878 .13386 L
.16311 .15854 L
.16791 .19032 L
.17054 .20581 L
.17183 .21191 L
.17301 .21642 L
.17429 .22003 L
.17496 .2214 L
.17567 .22245 L
.17639 .22315 L
.17707 .22346 L
.17781 .22345 L
.1786 .22307 L
.17927 .22249 L
.18 .2216 L
.18131 .21941 L
.18378 .2138 L
.20326 .15541 L
.21433 .12913 L
.21965 .1191 L
.22469 .11122 L
.22944 .10525 L
.23462 .10028 L
Mistroke
.2369 .09857 L
.23933 .09705 L
.2416 .09588 L
.24369 .09501 L
.24634 .09416 L
.24771 .09382 L
.24921 .09351 L
.25173 .0931 L
.2544 .0928 L
.25905 .09233 L
.26167 .09199 L
.2641 .09158 L
.26665 .09102 L
.26936 .09028 L
.27433 .08855 L
.28365 .08464 L
.29372 .08071 L
.29901 .07908 L
.30457 .0777 L
.30944 .07675 L
.31476 .07594 L
.31959 .07538 L
.32408 .07499 L
.32647 .07482 L
.32872 .07469 L
.33077 .07459 L
.33293 .07451 L
.33406 .07447 L
.3353 .07444 L
.33643 .07442 L
.33747 .0744 L
.33869 .07438 L
.34001 .07438 L
.34122 .07437 L
.34238 .07438 L
.34351 .07438 L
.34474 .0744 L
.34589 .07442 L
.34696 .07444 L
.34942 .07451 L
.35201 .07461 L
.35691 .07486 L
.36226 .07523 L
.3718 .07614 L
.38067 .07722 L
.41969 .08309 L
.46115 .08885 L
.5011 .09428 L
.53954 .09934 L
.58042 .10423 L
Mistroke
.61979 .10848 L
.65765 .11213 L
.69796 .11557 L
.73675 .1185 L
.77799 .12131 L
.81772 .12378 L
.85593 .12601 L
.8966 .12825 L
.93575 .13032 L
.97619 .13237 L
Mfstroke
0 1 .609 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05238 L
.09399 .05515 L
.10458 .05842 L
.11466 .0625 L
.1238 .06748 L
.12887 .07104 L
.13435 .07587 L
.13953 .08176 L
.14429 .08886 L
.14899 .09825 L
.15157 .10483 L
.15402 .1123 L
.15878 .13122 L
.16311 .15454 L
.16791 .18506 L
.17054 .20061 L
.17301 .21197 L
.17429 .21619 L
.17501 .21803 L
.17567 .21937 L
.17635 .22043 L
.1771 .22122 L
.17788 .22164 L
.1786 .22169 L
.17991 .22102 L
.1811 .21968 L
.18176 .21868 L
.18248 .2174 L
.18378 .21466 L
.20326 .15321 L
.21359 .1244 L
.21939 .11177 L
.22469 .10269 L
.22969 .09618 L
.23233 .09349 L
Mistroke
.23514 .09112 L
.23784 .08929 L
.24028 .08798 L
.24274 .08695 L
.24505 .08622 L
.24737 .08569 L
.24854 .0855 L
.24982 .08533 L
.25092 .08522 L
.25209 .08514 L
.2532 .08509 L
.25421 .08506 L
.25547 .08504 L
.25664 .08505 L
.25793 .08506 L
.25929 .08508 L
.26039 .0851 L
.26158 .08512 L
.26288 .08512 L
.2641 .08511 L
.26536 .08507 L
.2665 .08502 L
.26783 .08493 L
.26907 .08481 L
.27129 .08452 L
.27369 .08408 L
.27635 .08343 L
.27915 .08257 L
.28418 .08065 L
.29436 .07601 L
.30529 .07134 L
.31055 .06953 L
.31555 .0681 L
.3204 .06698 L
.3249 .06614 L
.32907 .06552 L
.33368 .06498 L
.33831 .06456 L
.34323 .06422 L
.34814 .06398 L
.3506 .06389 L
.35331 .0638 L
.35562 .06374 L
.35809 .06369 L
.36041 .06365 L
.36255 .06363 L
.36525 .0636 L
.36666 .06359 L
.36817 .06358 L
.36947 .06358 L
Mistroke
.37069 .06357 L
.37139 .06357 L
.37203 .06357 L
.37277 .06357 L
.37347 .06357 L
.37466 .06357 L
.37593 .06357 L
.37713 .06358 L
.37822 .06358 L
.38089 .06359 L
.3834 .0636 L
.38806 .06364 L
.39317 .06369 L
.40349 .06382 L
.42197 .06412 L
.46242 .06497 L
.50134 .06596 L
.54272 .06703 L
.58259 .06799 L
.62094 .06883 L
.66174 .06962 L
.70103 .07026 L
.7388 .07079 L
.77902 .07128 L
.81773 .07169 L
.85889 .07208 L
.89853 .07243 L
.93666 .07274 L
.97619 .07305 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04576 L
.05217 .04667 L
.06244 .04836 L
.08259 .05195 L
.09399 .05459 L
.10458 .05768 L
.11466 .06148 L
.1238 .06604 L
.12887 .06925 L
.13435 .0735 L
.14429 .0844 L
.16384 .13149 L
.16659 .14095 L
.16919 .14906 L
.17063 .15278 L
.17139 .15444 L
.17219 .15595 L
.17287 .15699 L
.17362 .15789 L
.17493 .15884 L
.17559 .159 L
.17627 .15895 L
.1775 .15833 L
.17819 .15769 L
.17883 .15694 L
.18028 .15467 L
.1827 .14948 L
.18529 .14263 L
.19593 .11184 L
.20116 .0993 L
.20598 .09006 L
.21036 .08352 L
.215 .07827 L
.21966 .07445 L
.2223 .07282 L
.22478 .0716 L
.22736 .0706 L
.22976 .06989 L
Mistroke
.23239 .06934 L
.23386 .06912 L
.2345 .06904 L
.23519 .06897 L
.23646 .06887 L
.23763 .06881 L
.23889 .06879 L
.23961 .06879 L
.24028 .0688 L
.24149 .06884 L
.24259 .0689 L
.24386 .069 L
.24507 .06912 L
.24731 .0694 L
.24968 .06979 L
.25395 .07064 L
.2636 .07303 L
.26818 .07411 L
.273 .07502 L
.27552 .07536 L
.27695 .0755 L
.27763 .07555 L
.27828 .07559 L
.27951 .07565 L
.28062 .07567 L
.28182 .07567 L
.28311 .07563 L
.28425 .07557 L
.28532 .07549 L
.28649 .07537 L
.28774 .07521 L
.2903 .07481 L
.29264 .07434 L
.30141 .07197 L
.31143 .06881 L
.32208 .06587 L
.33117 .064 L
.33635 .0632 L
.34122 .0626 L
.3459 .06214 L
.35083 .06176 L
.35964 .06125 L
.36913 .06085 L
.37952 .0605 L
.40074 .0598 L
.42005 .05919 L
.42967 .05893 L
.4401 .05869 L
.45906 .05835 L
.46851 .05823 L
Mistroke
.47891 .05811 L
.49994 .05791 L
.521 .05774 L
.54025 .05761 L
.57904 .05741 L
.59804 .05734 L
.61877 .05728 L
.65944 .05718 L
.69859 .05711 L
.74019 .05706 L
.78028 .05702 L
.81885 .05699 L
.85987 .05696 L
.89938 .05694 L
.93737 .05692 L
.97619 .0569 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .0486 L
.08259 .05236 L
.09399 .05512 L
.10458 .05837 L
.11466 .06243 L
.1238 .06737 L
.12887 .07091 L
.13435 .07568 L
.13953 .08149 L
.14429 .08848 L
.14899 .09768 L
.15402 .11138 L
.15878 .12968 L
.16311 .15209 L
.1682 .18303 L
.17088 .19794 L
.17234 .20464 L
.17372 .20965 L
.17492 .21289 L
.17621 .21524 L
.1769 .21603 L
.17763 .21651 L
.17895 .21653 L
.18014 .2157 L
.18125 .21432 L
.18247 .2122 L
.18378 .20938 L
.20369 .14492 L
.20914 .12916 L
.21492 .11515 L
.21991 .10541 L
.22527 .09731 L
.23041 .0916 L
.23511 .08791 L
.23737 .08658 L
.23983 .08542 L
Mistroke
.24216 .08457 L
.24431 .08399 L
.24563 .08372 L
.24706 .08349 L
.24771 .0834 L
.2484 .08333 L
.24964 .08322 L
.25083 .08316 L
.25194 .08313 L
.25315 .08313 L
.25446 .08315 L
.25518 .08318 L
.25585 .0832 L
.25736 .08328 L
.26011 .08343 L
.26261 .08356 L
.26387 .08361 L
.26458 .08363 L
.26526 .08364 L
.26644 .08364 L
.2677 .08362 L
.26889 .08357 L
.26997 .0835 L
.27124 .08339 L
.27262 .08323 L
.27511 .08282 L
.27774 .08224 L
.28051 .08147 L
.28548 .07972 L
.304 .07197 L
.31346 .06882 L
.31877 .06747 L
.32361 .06648 L
.32811 .06575 L
.33302 .06512 L
.33765 .06466 L
.34193 .06433 L
.34656 .06407 L
.34899 .06396 L
.35155 .06386 L
.35379 .06379 L
.35625 .06373 L
.35848 .06368 L
.36058 .06365 L
.36327 .06361 L
.36573 .06359 L
.3671 .06358 L
.36837 .06357 L
.36976 .06356 L
.37047 .06356 L
Mistroke
.37124 .06356 L
.37253 .06355 L
.37371 .06355 L
.37436 .06355 L
.37507 .06355 L
.37637 .06356 L
.37757 .06356 L
.37886 .06356 L
.38117 .06357 L
.38378 .06358 L
.38653 .0636 L
.39146 .06364 L
.4026 .06377 L
.42277 .06408 L
.46076 .06484 L
.50121 .06581 L
.54014 .06674 L
.58152 .06764 L
.62138 .06838 L
.65973 .06898 L
.70053 .06949 L
.73982 .06988 L
.77759 .07018 L
.81781 .07043 L
.85652 .07064 L
.89768 .07082 L
.93732 .07098 L
.97545 .07111 L
.97619 .07112 L
Mfstroke
0 1 .68 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03488 L
.03279 .0378 L
.03527 .04024 L
.03652 .04118 L
.0379 .04204 L
.04033 .04323 L
.04262 .04407 L
.04761 .04538 L
.05217 .04624 L
.06244 .04785 L
.08259 .05129 L
.09399 .05381 L
.10458 .05675 L
.11466 .06033 L
.1238 .06459 L
.12887 .06755 L
.13435 .07144 L
.14429 .08121 L
.15372 .09579 L
.15901 .10715 L
.16384 .11896 L
.16656 .12532 L
.168 .12824 L
.16953 .13081 L
.17087 .1325 L
.17163 .13319 L
.17234 .13366 L
.17359 .13402 L
.17429 .13397 L
.17493 .13377 L
.17618 .13296 L
.17734 .13175 L
.17862 .12997 L
.17998 .12764 L
.18529 .11593 L
.1904 .10375 L
.19593 .09206 L
.20081 .08376 L
.20598 .07705 L
.21064 .07258 L
.21311 .07074 L
.21576 .0691 L
.2182 .06788 L
.22042 .06697 L
.22267 .06622 L
Mistroke
.22478 .06567 L
.22729 .06517 L
.22956 .06484 L
.23084 .06471 L
.23201 .06462 L
.23329 .06455 L
.23394 .06452 L
.23465 .0645 L
.23585 .06449 L
.23694 .06449 L
.2382 .06452 L
.23939 .06456 L
.24049 .06461 L
.2415 .06466 L
.2438 .06482 L
.249 .06525 L
.25154 .06544 L
.25265 .06551 L
.25386 .06557 L
.25506 .06561 L
.25631 .06563 L
.25697 .06563 L
.25767 .06563 L
.25894 .06559 L
.25967 .06556 L
.26045 .06552 L
.26188 .06542 L
.26454 .06517 L
.30551 .06069 L
.31535 .05939 L
.32591 .05816 L
.33587 .05726 L
.34497 .05668 L
.34981 .05644 L
.35429 .05625 L
.36444 .05593 L
.37339 .05571 L
.38291 .05552 L
.39226 .05536 L
.40235 .05522 L
.41188 .05511 L
.42062 .05504 L
.42535 .05501 L
.43041 .05499 L
.43518 .05497 L
.43952 .05496 L
.44218 .05495 L
.44463 .05495 L
.44732 .05494 L
.44867 .05494 L
Mistroke
.45016 .05494 L
.45147 .05494 L
.45267 .05494 L
.45332 .05494 L
.45404 .05494 L
.45536 .05494 L
.45658 .05494 L
.45788 .05494 L
.4591 .05494 L
.46022 .05494 L
.46254 .05494 L
.4651 .05494 L
.47025 .05495 L
.47948 .05496 L
.5003 .05498 L
.54075 .05503 L
.57968 .05508 L
.62106 .05513 L
.66092 .05517 L
.69927 .0552 L
.74007 .05522 L
.77936 .05524 L
.81713 .05525 L
.85735 .05526 L
.89606 .05527 L
.93722 .05527 L
.97619 .05528 L
Mfstroke
0 1 .704 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04857 L
.08259 .05231 L
.09399 .05506 L
.10458 .0583 L
.11466 .06232 L
.1238 .06723 L
.12887 .07074 L
.13435 .07546 L
.13953 .0812 L
.14429 .08809 L
.14899 .09713 L
.15402 .11055 L
.15878 .12838 L
.16311 .15002 L
.1682 .17941 L
.17088 .19324 L
.17234 .19931 L
.17372 .20376 L
.17492 .20656 L
.17621 .20849 L
.1769 .20908 L
.17763 .20937 L
.17895 .20912 L
.18014 .20813 L
.18125 .20664 L
.18247 .20447 L
.18378 .20165 L
.19345 .17316 L
.20369 .14346 L
.20904 .13112 L
.21492 .12058 L
.2175 .11697 L
.22027 .11376 L
.22269 .1115 L
.22527 .10967 L
.22667 .10891 L
Mistroke
.22793 .10838 L
.22921 .10797 L
.2304 .10773 L
.23108 .10764 L
.2318 .1076 L
.23309 .10764 L
.23381 .10773 L
.23447 .10786 L
.23521 .10805 L
.23599 .10832 L
.2373 .10891 L
.23873 .10976 L
.23998 .11072 L
.24132 .11196 L
.24384 .11501 L
.24617 .11877 L
.24842 .12342 L
.25085 .1297 L
.25525 .14481 L
.26047 .16868 L
.26526 .19375 L
.27001 .21755 L
.27262 .22861 L
.27508 .23714 L
.27738 .2432 L
.27868 .24578 L
.27987 .2476 L
.28088 .24875 L
.28198 .2496 L
.28314 .25003 L
.28422 .25005 L
.2855 .24959 L
.28623 .24912 L
.2869 .24855 L
.28813 .24719 L
.28944 .24533 L
.29171 .24122 L
.29421 .23558 L
.30493 .20414 L
.31513 .17298 L
.32588 .14602 L
.33506 .12878 L
.3451 .11497 L
.35478 .10537 L
.36512 .09796 L
.37488 .09289 L
.38376 .08942 L
.39372 .08641 L
.40292 .08418 L
.42371 .08028 L
Mistroke
.44245 .07766 L
.45322 .07648 L
.46308 .07558 L
.4825 .07425 L
.49321 .07371 L
.50339 .0733 L
.52321 .07267 L
.5416 .07223 L
.56214 .07186 L
.58075 .07161 L
.60001 .07143 L
.61086 .07135 L
.62083 .07129 L
.62993 .07125 L
.63967 .07121 L
.65037 .07118 L
.66034 .07116 L
.66563 .07115 L
.67053 .07114 L
.6759 .07114 L
.67864 .07113 L
.6816 .07113 L
.68417 .07113 L
.68653 .07113 L
.68879 .07113 L
.69004 .07113 L
.69117 .07113 L
.69243 .07113 L
.69312 .07113 L
.69378 .07113 L
.69495 .07113 L
.69621 .07113 L
.69687 .07113 L
.6976 .07113 L
.69837 .07113 L
.69908 .07113 L
.70035 .07113 L
.70172 .07113 L
.70427 .07113 L
.70699 .07113 L
.71186 .07113 L
.71766 .07114 L
.72291 .07114 L
.74302 .07116 L
.78316 .07122 L
.82178 .07129 L
.86286 .07135 L
.90242 .07141 L
.94046 .07146 L
.97619 .0715 L
Mistroke
Mfstroke
0 1 .727 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05246 L
.09399 .05527 L
.10458 .05859 L
.11466 .06274 L
.1238 .06784 L
.12887 .07151 L
.13435 .07652 L
.13953 .08269 L
.14429 .09022 L
.14899 .10034 L
.15162 .1077 L
.15402 .11584 L
.15869 .13685 L
.16311 .16445 L
.16791 .1999 L
.17054 .21711 L
.17183 .22383 L
.17301 .22874 L
.17429 .23266 L
.17496 .23414 L
.17567 .23529 L
.17639 .23605 L
.17707 .23642 L
.17781 .23646 L
.1786 .23613 L
.17927 .23558 L
.18 .23475 L
.18131 .23268 L
.18378 .22743 L
.19317 .20219 L
.19835 .1896 L
.20326 .17973 L
.20603 .17513 L
.20905 .17091 L
.21182 .16778 L
Mistroke
.21433 .16558 L
.21559 .16472 L
.21694 .16397 L
.21768 .16364 L
.21837 .1634 L
.21902 .16321 L
.21971 .16306 L
.22094 .16295 L
.22209 .16301 L
.22335 .16328 L
.22405 .16353 L
.22469 .16382 L
.22586 .16451 L
.22714 .16553 L
.22848 .16692 L
.22974 .16855 L
.23198 .17236 L
.2344 .178 L
.23708 .18665 L
.2399 .19932 L
.24231 .21404 L
.24494 .23557 L
.24746 .26294 L
.24975 .29428 L
.25487 .38076 L
.25715 .41828 L
.25962 .45199 L
.26075 .46441 L
.26195 .47538 L
.26307 .48365 L
.2641 .48975 L
.26531 .49517 L
.26596 .49732 L
.26664 .49913 L
.26778 .50112 L
.26905 .50197 L
.27016 .50172 L
.27137 .50053 L
.27251 .49866 L
.27356 .4964 L
.27592 .48978 L
.2785 .48075 L
.28371 .45947 L
.30204 .38523 L
.3123 .35416 L
.32162 .33306 L
.32679 .32393 L
.33239 .31577 L
.34257 .30467 L
.35202 .29733 L
Mistroke
.36242 .29096 L
.38345 .27863 L
.42376 .2504 L
.44231 .23889 L
.46255 .22916 L
.4837 .22168 L
.5038 .21615 L
.54446 .20733 L
.58361 .20096 L
.62521 .19595 L
.6653 .19225 L
.70387 .18942 L
.74489 .18701 L
.7844 .18511 L
.82239 .18356 L
.86284 .18213 L
.90177 .1809 L
.94315 .17974 L
.97619 .1789 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05528 L
.10458 .05861 L
.11466 .06277 L
.1238 .06788 L
.12887 .07158 L
.13435 .07661 L
.13953 .08281 L
.14429 .09039 L
.14899 .10059 L
.15162 .10802 L
.15402 .11624 L
.15869 .13745 L
.16311 .16521 L
.16791 .20036 L
.16918 .20887 L
.17054 .21696 L
.17174 .22289 L
.17301 .22774 L
.17367 .2297 L
.1744 .23138 L
.17567 .23324 L
.1764 .23371 L
.17719 .23379 L
.17793 .23349 L
.1786 .23293 L
.17988 .23124 L
.18126 .22864 L
.18378 .22254 L
.19317 .19519 L
.20326 .17099 L
.20905 .16116 L
.21433 .15476 L
.21688 .15258 L
.21822 .15167 L
Mistroke
.21965 .1509 L
.22036 .15059 L
.22102 .15034 L
.22227 .15001 L
.22343 .14985 L
.22469 .14986 L
.22589 .15004 L
.22716 .15043 L
.22837 .151 L
.22946 .15171 L
.23075 .15278 L
.23215 .15427 L
.23469 .15795 L
.23735 .16342 L
.24017 .17151 L
.24257 .18083 L
.24523 .19438 L
.24768 .21066 L
.24992 .22927 L
.25497 .28365 L
.25975 .34241 L
.2641 .38953 L
.26638 .40924 L
.26885 .42602 L
.27021 .43324 L
.27146 .4387 L
.27274 .44315 L
.27393 .44638 L
.27495 .44849 L
.27604 .45013 L
.27726 .45126 L
.27837 .45173 L
.27952 .45171 L
.28078 .45116 L
.28196 .45019 L
.28306 .44897 L
.28552 .44525 L
.28783 .44083 L
.2931 .42872 L
.30377 .40255 L
.31359 .3827 L
.31853 .37514 L
.32393 .36883 L
.32856 .36501 L
.33115 .36346 L
.33351 .3624 L
.33571 .36169 L
.33695 .3614 L
.3381 .36119 L
.3391 .36107 L
Mistroke
.3402 .36098 L
.34135 .36094 L
.34243 .36095 L
.34368 .36101 L
.34437 .36107 L
.34501 .36113 L
.3474 .36149 L
.34874 .36175 L
.35019 .36208 L
.35282 .36276 L
.36269 .36568 L
.36739 .36686 L
.36975 .36733 L
.37111 .36755 L
.37234 .36772 L
.37341 .36784 L
.37456 .36794 L
.37578 .36802 L
.37694 .36806 L
.37802 .36807 L
.37916 .36805 L
.38014 .36801 L
.38122 .36794 L
.38244 .36783 L
.38357 .36769 L
.38614 .36728 L
.38865 .36673 L
.39132 .36601 L
.40058 .36254 L
.42144 .35178 L
.44137 .34163 L
.46296 .33286 L
.50296 .32021 L
.5439 .30817 L
.58333 .29773 L
.62123 .28898 L
.66159 .28081 L
.70044 .27402 L
.74173 .26789 L
.78151 .2629 L
.81978 .25878 L
.8605 .255 L
.8997 .25182 L
.94135 .24883 L
.97619 .24659 L
Mfstroke
0 1 .775 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05528 L
.10458 .05861 L
.11466 .06276 L
.1238 .06787 L
.12887 .07156 L
.13435 .07659 L
.13953 .08278 L
.14429 .09035 L
.14899 .10051 L
.15162 .1079 L
.15402 .11607 L
.15869 .13707 L
.16311 .16441 L
.16791 .19866 L
.16918 .20686 L
.17054 .2146 L
.17174 .22021 L
.17301 .22475 L
.17367 .22653 L
.1744 .22804 L
.17567 .22959 L
.1764 .2299 L
.17719 .22981 L
.17793 .22935 L
.1786 .22865 L
.17988 .2267 L
.18126 .22384 L
.18378 .21727 L
.19317 .18824 L
.20326 .16211 L
.20905 .15107 L
.21433 .14345 L
.21688 .14061 L
.21965 .13813 L
Mistroke
.22092 .13721 L
.22227 .13639 L
.22343 .13581 L
.22469 .13531 L
.22599 .13497 L
.2267 .13484 L
.22736 .13478 L
.22855 .13477 L
.22982 .13493 L
.23053 .13509 L
.2313 .13535 L
.23271 .13599 L
.23408 .13687 L
.23535 .13792 L
.23766 .14051 L
.24021 .14453 L
.24288 .15033 L
.24537 .15762 L
.24767 .16628 L
.25008 .17779 L
.25439 .20543 L
.25903 .24483 L
.2641 .29441 L
.2694 .3441 L
.272 .36477 L
.2744 .3808 L
.27654 .3925 L
.27889 .40254 L
.28125 .40987 L
.28254 .41281 L
.28375 .41495 L
.28505 .41666 L
.28578 .41737 L
.28646 .41787 L
.28771 .41845 L
.28834 .41859 L
.28903 .41862 L
.29023 .41844 L
.29152 .41792 L
.29274 .41717 L
.29386 .4163 L
.29914 .41052 L
.30471 .40315 L
.30961 .3969 L
.31424 .39188 L
.3168 .38961 L
.31958 .38762 L
.3208 .3869 L
.3221 .38625 L
.32332 .38575 L
Mistroke
.32443 .38538 L
.32554 .3851 L
.3266 .3849 L
.32772 .38479 L
.32894 .38475 L
.33 .3848 L
.33113 .38494 L
.3322 .38514 L
.33317 .38539 L
.33555 .38624 L
.33812 .38751 L
.34279 .39067 L
.36235 .40957 L
.36771 .41443 L
.37345 .41877 L
.37623 .42048 L
.37887 .42186 L
.38122 .42288 L
.38381 .42379 L
.38627 .42446 L
.38858 .42491 L
.38985 .4251 L
.39102 .42523 L
.3923 .42533 L
.39294 .42536 L
.39364 .42539 L
.39484 .42541 L
.39592 .42539 L
.39718 .42535 L
.39836 .42528 L
.39945 .42519 L
.40046 .42509 L
.40274 .4248 L
.4075 .42399 L
.41274 .42286 L
.42332 .42029 L
.4333 .418 L
.44278 .4162 L
.4537 .41461 L
.46368 .41349 L
.50194 .40913 L
.52167 .40602 L
.54266 .40237 L
.58431 .39527 L
.62445 .38888 L
.66308 .38311 L
.70415 .37758 L
.74371 .3729 L
.78175 .36896 L
.82225 .36528 L
Mistroke
.86123 .36216 L
.90267 .3592 L
.94258 .35663 L
.97619 .35463 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05527 L
.10458 .05859 L
.11466 .06274 L
.1238 .06784 L
.12887 .07151 L
.13435 .07652 L
.13953 .08268 L
.14429 .09019 L
.14899 .10025 L
.15162 .10755 L
.15402 .1156 L
.15869 .13619 L
.16311 .16278 L
.16791 .19578 L
.16918 .20364 L
.17054 .21103 L
.17174 .21637 L
.17301 .22064 L
.17367 .22231 L
.1744 .22369 L
.17567 .22506 L
.1764 .22527 L
.17719 .22507 L
.17793 .22451 L
.1786 .22374 L
.17988 .22164 L
.18126 .21862 L
.18378 .21175 L
.19317 .18135 L
.20326 .1531 L
.20905 .14044 L
.21433 .13097 L
.21971 .12323 L
.22469 .1176 L
Mistroke
.22938 .11361 L
.232 .11191 L
.23437 .11068 L
.23698 .10968 L
.23845 .10928 L
.23915 .10912 L
.2398 .109 L
.24098 .10884 L
.24228 .10875 L
.24355 .10874 L
.24426 .10878 L
.24491 .10883 L
.2461 .10897 L
.24736 .1092 L
.24844 .10945 L
.24963 .10979 L
.25477 .11185 L
.25958 .11456 L
.2641 .11788 L
.26881 .1224 L
.27396 .12862 L
.28432 .14313 L
.2889 .14915 L
.29385 .15476 L
.29822 .15876 L
.30284 .16201 L
.30539 .16341 L
.3082 .16467 L
.31058 .16554 L
.31314 .16632 L
.31797 .16743 L
.32249 .16826 L
.32811 .16926 L
.33345 .17043 L
.33824 .17182 L
.34345 .17381 L
.35283 .17887 L
.3632 .18654 L
.3842 .20588 L
.42437 .23732 L
.46303 .25866 L
.50413 .27985 L
.54373 .29738 L
.5818 .3118 L
.62233 .32529 L
.66134 .33666 L
.70281 .34734 L
.74276 .35657 L
.78119 .36467 L
.82208 .3726 L
Mistroke
.86145 .37967 L
.89931 .386 L
.93961 .39223 L
.97619 .39744 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05526 L
.10458 .05858 L
.11466 .06272 L
.1238 .06781 L
.12887 .07148 L
.13435 .07647 L
.13953 .08261 L
.14429 .0901 L
.14899 .10012 L
.15162 .10738 L
.15402 .11539 L
.15869 .13587 L
.16311 .16238 L
.16791 .19558 L
.16918 .20359 L
.17054 .21119 L
.17174 .21675 L
.17301 .2213 L
.17367 .22311 L
.1744 .22467 L
.17567 .22632 L
.1764 .2267 L
.17719 .22667 L
.17793 .22628 L
.1786 .22564 L
.17988 .2238 L
.18126 .22102 L
.18378 .21453 L
.19317 .18495 L
.20326 .15676 L
.20905 .14375 L
.21433 .13374 L
.21971 .12523 L
.22469 .11876 L
Mistroke
.22938 .11389 L
.23437 .10995 L
.23722 .10826 L
.2399 .10703 L
.24231 .1062 L
.24366 .10584 L
.24491 .10558 L
.24602 .10539 L
.24721 .10524 L
.24834 .10514 L
.24936 .10508 L
.25057 .10503 L
.25187 .10502 L
.25311 .10503 L
.25425 .10505 L
.25671 .10511 L
.25792 .10513 L
.25903 .10515 L
.26019 .10516 L
.26144 .10516 L
.26273 .10515 L
.26339 .10515 L
.2641 .10514 L
.26474 .10514 L
.26542 .10514 L
.26664 .10514 L
.26796 .10515 L
.2687 .10517 L
.2694 .10519 L
.27066 .10525 L
.27181 .10533 L
.27314 .10545 L
.2744 .1056 L
.27672 .10598 L
.27887 .10643 L
.28375 .10781 L
.29456 .11172 L
.29985 .11353 L
.30471 .11493 L
.30899 .11593 L
.31368 .11679 L
.31839 .11745 L
.32335 .11803 L
.3289 .11864 L
.33414 .1193 L
.33884 .12005 L
.34394 .1211 L
.34889 .1224 L
.35413 .12413 L
.36353 .12814 L
Mistroke
.38447 .14047 L
.42233 .16436 L
.46264 .18518 L
.50143 .20479 L
.54267 .22447 L
.5824 .2416 L
.62061 .25665 L
.66128 .27108 L
.70043 .28357 L
.74203 .29557 L
.78212 .30613 L
.82069 .31553 L
.86171 .32485 L
.90122 .33326 L
.93921 .34085 L
.97619 .34778 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04856 L
.08259 .05228 L
.09399 .05501 L
.10458 .05823 L
.11466 .06222 L
.1238 .06707 L
.12887 .07053 L
.13435 .07517 L
.13953 .08078 L
.14429 .08747 L
.14899 .09618 L
.15402 .10894 L
.15878 .12563 L
.16311 .14562 L
.1682 .17265 L
.17088 .18557 L
.17234 .19135 L
.17372 .19564 L
.17492 .19838 L
.17621 .2003 L
.1769 .20088 L
.17763 .20118 L
.17895 .20092 L
.18014 .19988 L
.18125 .1983 L
.18247 .196 L
.18378 .19297 L
.20369 .1271 L
.20914 .11244 L
.21492 .1002 L
.21985 .0923 L
.22263 .08877 L
.22527 .08596 L
.22776 .08375 L
.23048 .08179 L
.23297 .08034 L
Mistroke
.23523 .0793 L
.23792 .07835 L
.2394 .07795 L
.24078 .07765 L
.24207 .07743 L
.24326 .07727 L
.24456 .07715 L
.24521 .07711 L
.24593 .07707 L
.24723 .07704 L
.24846 .07706 L
.24956 .0771 L
.25076 .07717 L
.25206 .07728 L
.25345 .07742 L
.25593 .07775 L
.26048 .07847 L
.26526 .07922 L
.2676 .07952 L
.26884 .07965 L
.27016 .07975 L
.27138 .07983 L
.27249 .07987 L
.2736 .07988 L
.27465 .07987 L
.27588 .07983 L
.27718 .07974 L
.27829 .07964 L
.27951 .07949 L
.28223 .07904 L
.28477 .07848 L
.28938 .07713 L
.29359 .07565 L
.30306 .07194 L
.3123 .06859 L
.32212 .06585 L
.32724 .06479 L
.33289 .06386 L
.33804 .06321 L
.34287 .06274 L
.34756 .06238 L
.35269 .06208 L
.35804 .06184 L
.36303 .06165 L
.38153 .06117 L
.40024 .06078 L
.42054 .06043 L
.43163 .06029 L
.4365 .06024 L
.44186 .0602 L
Mistroke
.44657 .06016 L
.45164 .06014 L
.45699 .06011 L
.46201 .0601 L
.46455 .06009 L
.46725 .06009 L
.46981 .06008 L
.47212 .06008 L
.47354 .06008 L
.47485 .06008 L
.47629 .06008 L
.47701 .06008 L
.4778 .06008 L
.4785 .06008 L
.47914 .06008 L
.47988 .06008 L
.48057 .06008 L
.48181 .06008 L
.48251 .06008 L
.48315 .06008 L
.48431 .06008 L
.48555 .06008 L
.48779 .06008 L
.49046 .06008 L
.4929 .06008 L
.50325 .0601 L
.51306 .06011 L
.52219 .06013 L
.54289 .06018 L
.58196 .06029 L
.62348 .06042 L
.66348 .06053 L
.70196 .06062 L
.7429 .0607 L
.78233 .06076 L
.82023 .0608 L
.86059 .06084 L
.89944 .06086 L
.94073 .06089 L
.97619 .06091 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04443 L
.04761 .04582 L
.05217 .04675 L
.06244 .04847 L
.08259 .05213 L
.09399 .05482 L
.10458 .05797 L
.11466 .06187 L
.1238 .06658 L
.12887 .06991 L
.13435 .07435 L
.13953 .07967 L
.14429 .08594 L
.14899 .09396 L
.15402 .10545 L
.15878 .12002 L
.16311 .1368 L
.1682 .15841 L
.17088 .16822 L
.17223 .17211 L
.17301 .17395 L
.17372 .17535 L
.17502 .17716 L
.1757 .17773 L
.17642 .17805 L
.17762 .17796 L
.17895 .17702 L
.18016 .17546 L
.18145 .17315 L
.18378 .16766 L
.19345 .1369 L
.20369 .10724 L
.20904 .09579 L
.21492 .08643 L
.2175 .08327 L
.22027 .08043 L
.22527 .07658 L
.22793 .0751 L
.2304 .07402 L
Mistroke
.23311 .07313 L
.23462 .07275 L
.23599 .07247 L
.2373 .07226 L
.23851 .07212 L
.2392 .07205 L
.23984 .072 L
.2405 .07196 L
.24123 .07193 L
.24248 .07191 L
.24362 .07192 L
.24493 .07197 L
.24617 .07205 L
.24726 .07214 L
.24847 .07227 L
.25092 .07261 L
.25532 .07341 L
.26526 .07563 L
.27019 .07656 L
.27267 .0769 L
.27407 .07705 L
.27537 .07715 L
.27658 .07722 L
.27773 .07725 L
.27875 .07725 L
.27986 .07723 L
.28107 .07718 L
.28235 .07708 L
.28344 .07697 L
.28464 .07682 L
.28736 .07638 L
.28985 .07584 L
.29543 .07428 L
.30551 .07084 L
.31475 .06778 L
.32457 .0652 L
.32969 .06418 L
.33535 .06329 L
.34049 .06266 L
.34532 .06219 L
.35514 .06152 L
.36008 .06128 L
.36548 .06106 L
.38398 .06046 L
.40521 .05982 L
.42451 .05931 L
.43413 .0591 L
.44457 .05891 L
.46352 .05867 L
.47297 .05857 L
Mistroke
.48337 .05849 L
.50441 .05835 L
.52546 .05824 L
.54471 .05816 L
.56461 .05809 L
.58351 .05804 L
.62172 .05797 L
.64141 .05794 L
.66238 .05792 L
.70399 .05789 L
.74407 .05786 L
.78264 .05785 L
.82367 .05783 L
.86317 .05781 L
.90117 .0578 L
.94161 .05779 L
.97619 .05777 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03774 L
.03527 .04015 L
.03652 .04106 L
.0379 .0419 L
.04033 .04305 L
.04262 .04385 L
.04517 .04455 L
.04761 .04508 L
.05217 .04589 L
.06244 .04739 L
.07302 .04898 L
.08429 .05095 L
.09474 .05317 L
.10458 .05573 L
.1142 .05886 L
.12461 .06327 L
.13407 .06871 L
.14277 .07561 L
.15263 .08679 L
.15805 .09471 L
.16319 .10261 L
.16551 .10577 L
.16678 .10724 L
.16797 .1084 L
.16925 .10934 L
.16994 .1097 L
.17067 .10996 L
.17197 .11012 L
.17317 .10989 L
.17426 .10936 L
.17528 .10862 L
.1764 .10754 L
.1776 .10611 L
.18226 .09864 L
.18717 .08962 L
.19249 .08073 L
.19719 .07442 L
.20215 .06935 L
.20663 .06602 L
.20918 .06457 L
.21156 .06347 L
.21574 .06201 L
.21809 .06144 L
.22023 .06103 L
Mistroke
.22152 .06084 L
.22274 .0607 L
.22385 .06059 L
.22501 .06051 L
.22629 .06044 L
.22746 .06041 L
.22872 .0604 L
.22944 .0604 L
.2301 .06041 L
.23129 .06044 L
.23242 .06049 L
.23343 .06055 L
.23452 .06063 L
.23698 .06086 L
.23926 .06113 L
.24404 .06186 L
.24932 .06289 L
.25999 .06542 L
.26944 .06766 L
.27419 .06854 L
.27688 .06892 L
.27938 .06918 L
.2808 .06929 L
.2815 .06933 L
.28214 .06936 L
.28335 .0694 L
.28465 .06942 L
.28595 .06942 L
.28669 .0694 L
.28738 .06938 L
.28811 .06935 L
.28878 .06932 L
.29027 .06922 L
.29272 .06899 L
.29539 .06865 L
.30025 .06786 L
.31961 .06379 L
.3299 .06196 L
.33569 .06117 L
.341 .06058 L
.35085 .05979 L
.3558 .0595 L
.36123 .05925 L
.38023 .0586 L
.42076 .05735 L
.43947 .05687 L
.45977 .05649 L
.47086 .05634 L
.48109 .05622 L
.50124 .05601 L
Mistroke
.54061 .05569 L
.57846 .05546 L
.61877 .05529 L
.65756 .05517 L
.69881 .05508 L
.73854 .05501 L
.77675 .05496 L
.81742 .05492 L
.85657 .05489 L
.89817 .05486 L
.93825 .05483 L
.97619 .05481 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04138 L
.0379 .04226 L
.04033 .0435 L
.04262 .04437 L
.04761 .04574 L
.05217 .04666 L
.06244 .04836 L
.08259 .05198 L
.09399 .05463 L
.10458 .05775 L
.11466 .06159 L
.1238 .06621 L
.12887 .06947 L
.13435 .07381 L
.13953 .07899 L
.14429 .08506 L
.14935 .09347 L
.15414 .10406 L
.15967 .12044 L
.16471 .13902 L
.16914 .15502 L
.17137 .16114 L
.17265 .16365 L
.17384 .16529 L
.17514 .16623 L
.17633 .16634 L
.17763 .16569 L
.17828 .16508 L
.179 .16421 L
.1802 .16235 L
.18148 .15986 L
.18378 .1544 L
.19263 .12894 L
.202 .10543 L
.20689 .09627 L
.21227 .08864 L
.21463 .08601 L
.21717 .08362 L
.22175 .08032 L
.22449 .0789 L
.22593 .07829 L
.22747 .07775 L
Mistroke
.22895 .07733 L
.23029 .07703 L
.23163 .07679 L
.2329 .07664 L
.23414 .07654 L
.23546 .07649 L
.23657 .07651 L
.2378 .07657 L
.23849 .07662 L
.23912 .07669 L
.24054 .07688 L
.24185 .07712 L
.24309 .0774 L
.24553 .07809 L
.24811 .07905 L
.25275 .08132 L
.25774 .08457 L
.26325 .08909 L
.2727 .09771 L
.27499 .09949 L
.27744 .10108 L
.27885 .10182 L
.28013 .10238 L
.28142 .10282 L
.28263 .10313 L
.28326 .10325 L
.28395 .10335 L
.28468 .10341 L
.28535 .10344 L
.28656 .1034 L
.28786 .10326 L
.28859 .10313 L
.28938 .10295 L
.29082 .10253 L
.29353 .10145 L
.2987 .09848 L
.3035 .09508 L
.31323 .08762 L
.32373 .0804 L
.33364 .0751 L
.34273 .0715 L
.3515 .06892 L
.3611 .06684 L
.37112 .06525 L
.38045 .06414 L
.39096 .06319 L
.40089 .06248 L
.41947 .0615 L
.42917 .0611 L
.43946 .06075 L
Mistroke
.4579 .06028 L
.46732 .06009 L
.47745 .05994 L
.49576 .05972 L
.50587 .05963 L
.5169 .05955 L
.537 .05944 L
.55669 .05936 L
.57766 .0593 L
.58796 .05928 L
.59909 .05926 L
.60871 .05925 L
.61927 .05924 L
.62959 .05923 L
.63922 .05922 L
.64939 .05922 L
.65509 .05922 L
.66029 .05921 L
.6651 .05921 L
.67021 .05921 L
.67458 .05921 L
.67706 .05921 L
.67939 .05921 L
.68193 .05921 L
.68321 .05921 L
.68394 .05921 L
.68461 .05921 L
.6858 .05921 L
.68708 .05921 L
.68827 .05921 L
.68939 .05921 L
.69069 .05921 L
.69135 .05921 L
.69208 .05921 L
.69455 .05921 L
.69595 .05921 L
.69745 .05921 L
.70016 .05921 L
.70542 .05921 L
.7103 .05921 L
.72135 .05921 L
.74145 .05922 L
.78065 .05923 L
.82231 .05924 L
.86245 .05925 L
.90107 .05926 L
.94215 .05927 L
.97619 .05928 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .0486 L
.08259 .05237 L
.09399 .05515 L
.10458 .05842 L
.11466 .0625 L
.1238 .06748 L
.12887 .07106 L
.13435 .0759 L
.13953 .08181 L
.14429 .08895 L
.14899 .09842 L
.15157 .10509 L
.15402 .11267 L
.15878 .13196 L
.16311 .15586 L
.16791 .18705 L
.17054 .20268 L
.17183 .20902 L
.17301 .21382 L
.17429 .21784 L
.17496 .21945 L
.17567 .22077 L
.17639 .22175 L
.17707 .22233 L
.17781 .22262 L
.1786 .22257 L
.17927 .22225 L
.18 .22165 L
.18131 .21997 L
.18259 .21771 L
.18378 .21521 L
.19359 .18782 L
.199 .17279 L
.20413 .16033 L
.20889 .15073 L
.21141 .14647 L
Mistroke
.21409 .14257 L
.21656 .13957 L
.2188 .13736 L
.21989 .13647 L
.22106 .13564 L
.22217 .13498 L
.22318 .1345 L
.22432 .13409 L
.22555 .13381 L
.22669 .13371 L
.22776 .13376 L
.22901 .13401 L
.23017 .13442 L
.23144 .1351 L
.23279 .1361 L
.23399 .13725 L
.23528 .13879 L
.23761 .14248 L
.24038 .14869 L
.24292 .15661 L
.24511 .16562 L
.24715 .17622 L
.25177 .20982 L
.26107 .30346 L
.26353 .32547 L
.26613 .34453 L
.26749 .35254 L
.26899 .35975 L
.27035 .36489 L
.27162 .36852 L
.2729 .3711 L
.27413 .3726 L
.27522 .3732 L
.27642 .37314 L
.27771 .37229 L
.27837 .37158 L
.27909 .37059 L
.28156 .36578 L
.28397 .35936 L
.28618 .35232 L
.29115 .33374 L
.30016 .29625 L
.31007 .25636 L
.32067 .21972 L
.32982 .19398 L
.33976 .17175 L
.35001 .15401 L
.3597 .14119 L
.36913 .13165 L
.37783 .12486 L
Mistroke
.39657 .11448 L
.40723 .11011 L
.4172 .10662 L
.43575 .10128 L
.45599 .09695 L
.46696 .09518 L
.47714 .09384 L
.49724 .09184 L
.51778 .09039 L
.53639 .08939 L
.55727 .0885 L
.57647 .08787 L
.59524 .08739 L
.61505 .087 L
.6347 .08671 L
.65304 .08651 L
.6734 .08634 L
.69197 .08623 L
.71107 .08614 L
.72185 .08611 L
.73183 .08608 L
.75051 .08604 L
.76114 .08602 L
.77112 .08601 L
.78096 .086 L
.79131 .086 L
.80982 .08598 L
.81938 .08598 L
.82958 .08598 L
.84795 .08597 L
.88947 .08596 L
.92947 .08595 L
.96796 .08594 L
.97619 .08593 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05527 L
.10458 .05859 L
.11466 .06274 L
.1238 .06783 L
.12887 .07151 L
.13435 .07652 L
.13953 .08267 L
.14429 .09019 L
.14899 .10026 L
.15162 .10757 L
.15402 .11564 L
.15869 .1363 L
.16311 .16307 L
.16791 .19649 L
.16918 .2045 L
.17054 .21206 L
.17174 .21754 L
.17301 .22198 L
.17367 .22373 L
.1744 .2252 L
.17567 .2267 L
.1764 .22699 L
.17719 .22687 L
.17793 .22639 L
.1786 .22568 L
.17988 .22369 L
.18126 .22078 L
.18378 .21409 L
.19317 .18414 L
.20326 .15631 L
.20905 .144 L
.21433 .135 L
.21965 .128 L
.2223 .12527 L
Mistroke
.22469 .12321 L
.22697 .12163 L
.22943 .12034 L
.23079 .11982 L
.23203 .11946 L
.23322 .11923 L
.23448 .11911 L
.23556 .11911 L
.23672 .11923 L
.23781 .11944 L
.2388 .11974 L
.23997 .1202 L
.24124 .12087 L
.24355 .12254 L
.24601 .12505 L
.24873 .12884 L
.25157 .13411 L
.25423 .14046 L
.25898 .15563 L
.2641 .17775 L
.27362 .22887 L
.27885 .2556 L
.28378 .27614 L
.28659 .28536 L
.28963 .29334 L
.29239 .2989 L
.29493 .30277 L
.29733 .30547 L
.29869 .30665 L
.29997 .30754 L
.30128 .30829 L
.30253 .30885 L
.30398 .30933 L
.30529 .30965 L
.30646 .30985 L
.30756 .30997 L
.30877 .31005 L
.31007 .31009 L
.31136 .3101 L
.31201 .31009 L
.31272 .31007 L
.31399 .31004 L
.31515 .31001 L
.31633 .30999 L
.31744 .30999 L
.31861 .31 L
.31988 .31005 L
.32099 .31013 L
.32217 .31025 L
.32318 .31039 L
Mistroke
.32429 .31058 L
.32566 .31088 L
.32697 .31123 L
.32943 .3121 L
.33208 .31333 L
.33497 .31504 L
.34015 .3191 L
.34497 .32392 L
.36378 .34884 L
.37367 .36212 L
.38412 .37364 L
.38944 .37827 L
.39528 .38239 L
.40554 .38767 L
.41058 .38956 L
.41598 .39126 L
.42572 .39382 L
.4671 .40448 L
.48781 .40978 L
.50696 .41366 L
.52556 .41647 L
.54531 .41875 L
.58308 .42211 L
.60245 .42344 L
.62331 .42458 L
.64336 .42541 L
.66447 .42608 L
.68422 .42654 L
.7026 .42687 L
.71313 .42702 L
.72307 .42714 L
.73192 .42723 L
.74166 .4273 L
.75139 .42736 L
.75636 .42739 L
.76169 .42741 L
.76667 .42743 L
.77123 .42744 L
.7758 .42745 L
.78015 .42746 L
.78275 .42746 L
.78403 .42746 L
.7852 .42746 L
.78625 .42746 L
.7874 .42746 L
.78855 .42746 L
.78977 .42746 L
.79046 .42746 L
.79111 .42746 L
.79233 .42746 L
Mistroke
.79364 .42746 L
.79438 .42746 L
.79507 .42746 L
.79747 .42746 L
.79867 .42746 L
.80001 .42746 L
.80458 .42745 L
.80951 .42744 L
.81841 .42742 L
.82851 .42739 L
.83954 .42734 L
.85962 .42723 L
.90026 .4269 L
.93937 .42648 L
.97619 .42599 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .0468 L
.06244 .04855 L
.08259 .05226 L
.09399 .05498 L
.10458 .05819 L
.11466 .06216 L
.1238 .06699 L
.12887 .07042 L
.13435 .07502 L
.13953 .08057 L
.14429 .08716 L
.14899 .09571 L
.15402 .10818 L
.15878 .12438 L
.16311 .1436 L
.1682 .16938 L
.17088 .18163 L
.17234 .18708 L
.17372 .19112 L
.17492 .19368 L
.17621 .19542 L
.1769 .19593 L
.17763 .19615 L
.17895 .19577 L
.18014 .19464 L
.18125 .19299 L
.18247 .1906 L
.18378 .1875 L
.19345 .1552 L
.20369 .12084 L
.20904 .10677 L
.21492 .09493 L
.22027 .08715 L
.22527 .08203 L
.22775 .08013 L
.23044 .07847 L
.23299 .07725 L
Mistroke
.23535 .07638 L
.23768 .07574 L
.2398 .07534 L
.24098 .07517 L
.24225 .07504 L
.24345 .07496 L
.24455 .07493 L
.24575 .07492 L
.24704 .07495 L
.24825 .07501 L
.24936 .07509 L
.25065 .07522 L
.25206 .07539 L
.25462 .07578 L
.26011 .0768 L
.26526 .07779 L
.26747 .07816 L
.26979 .07848 L
.27101 .07862 L
.27234 .07873 L
.27356 .07881 L
.27468 .07885 L
.27533 .07886 L
.27604 .07886 L
.27731 .07884 L
.27856 .07878 L
.27971 .07869 L
.28095 .07856 L
.28231 .07837 L
.28507 .07787 L
.28781 .07722 L
.29031 .0765 L
.29594 .07458 L
.30609 .07071 L
.31533 .06756 L
.32515 .06504 L
.33027 .06407 L
.33593 .06323 L
.34107 .06265 L
.3459 .06222 L
.35059 .0619 L
.35572 .06162 L
.36606 .06121 L
.38456 .06068 L
.40578 .06013 L
.42509 .05972 L
.43471 .05956 L
.44515 .05943 L
.455 .05934 L
.4641 .05927 L
Mistroke
.47378 .05922 L
.48284 .05918 L
.49342 .05914 L
.50347 .05911 L
.51316 .05909 L
.52373 .05907 L
.53328 .05906 L
.54226 .05904 L
.54722 .05904 L
.55259 .05904 L
.55705 .05903 L
.56195 .05903 L
.56727 .05903 L
.57017 .05903 L
.57288 .05903 L
.57418 .05903 L
.57542 .05903 L
.57654 .05903 L
.57773 .05903 L
.57902 .05903 L
.58022 .05903 L
.58151 .05903 L
.58224 .05903 L
.58293 .05903 L
.58411 .05903 L
.58536 .05903 L
.58655 .05903 L
.58763 .05903 L
.59027 .05903 L
.59277 .05903 L
.59774 .05903 L
.60313 .05903 L
.62164 .05903 L
.66257 .05905 L
.68295 .05905 L
.702 .05906 L
.72028 .05906 L
.73054 .05906 L
.7399 .05907 L
.74469 .05907 L
.74979 .05907 L
.75459 .05907 L
.75894 .05907 L
.76162 .05907 L
.76408 .05907 L
.76537 .05907 L
.76678 .05907 L
.7675 .05907 L
.76826 .05907 L
.76898 .05907 L
Mistroke
.76963 .05907 L
.77092 .05907 L
.77211 .05907 L
.77341 .05907 L
.77407 .05907 L
.7748 .05907 L
.77601 .05907 L
.77732 .05907 L
.77968 .05907 L
.78222 .05907 L
.78492 .05907 L
.78978 .05907 L
.79557 .05907 L
.80081 .05907 L
.8209 .05906 L
.84013 .05906 L
.86095 .05906 L
.90194 .05905 L
.94142 .05904 L
.97619 .05903 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04035 L
.03652 .0413 L
.0379 .04218 L
.04033 .04339 L
.04262 .04425 L
.04761 .04559 L
.05217 .04647 L
.06244 .04813 L
.08259 .05165 L
.09399 .05424 L
.10458 .05726 L
.11466 .06096 L
.1238 .06539 L
.12887 .06849 L
.13435 .07259 L
.14429 .08301 L
.16384 .12606 L
.16659 .13408 L
.16919 .1406 L
.17063 .1434 L
.17139 .14458 L
.17219 .14558 L
.17287 .14621 L
.17362 .14669 L
.17493 .14695 L
.17559 .14681 L
.17627 .14648 L
.1775 .14543 L
.17819 .14462 L
.17883 .14372 L
.18028 .14126 L
.18529 .12969 L
.19511 .1047 L
.19994 .09463 L
.20438 .08713 L
.20951 .08047 L
.21216 .07778 L
.21507 .07533 L
.21979 .07234 L
.22237 .07114 L
.22478 .07026 L
.22736 .06954 L
.22976 .06905 L
Mistroke
.23114 .06885 L
.23239 .06871 L
.23308 .06864 L
.23383 .06859 L
.23454 .06854 L
.23519 .06852 L
.23637 .06849 L
.23748 .06849 L
.23869 .06851 L
.23999 .06856 L
.24065 .0686 L
.24136 .06865 L
.24265 .06875 L
.24507 .06901 L
.2636 .07143 L
.27383 .07272 L
.27627 .07302 L
.27883 .0733 L
.27989 .07339 L
.28102 .07347 L
.28226 .07354 L
.28342 .07358 L
.28472 .0736 L
.28594 .07359 L
.28704 .07356 L
.28823 .0735 L
.28954 .0734 L
.29093 .07326 L
.29342 .07292 L
.29613 .07244 L
.29867 .07189 L
.30444 .07039 L
.32305 .06507 L
.33357 .06271 L
.34331 .06111 L
.3536 .05991 L
.35879 .05944 L
.36453 .05901 L
.3749 .0584 L
.38464 .05796 L
.39446 .0576 L
.4048 .05731 L
.41449 .05709 L
.4233 .05694 L
.43283 .0568 L
.44301 .05669 L
.45245 .05661 L
.46137 .05656 L
.47108 .05652 L
.48136 .05648 L
Mistroke
.49014 .05646 L
.49981 .05645 L
.50995 .05643 L
.51923 .05642 L
.52435 .05642 L
.52994 .05642 L
.5325 .05642 L
.53522 .05641 L
.53755 .05641 L
.54012 .05641 L
.54272 .05641 L
.54415 .05641 L
.54483 .05641 L
.54548 .05641 L
.54672 .05641 L
.54786 .05641 L
.54908 .05641 L
.54977 .05641 L
.55041 .05641 L
.55105 .05641 L
.55174 .05641 L
.55298 .05641 L
.55446 .05641 L
.55581 .05641 L
.5586 .05641 L
.56154 .05641 L
.56654 .05642 L
.57118 .05642 L
.58172 .05642 L
.62078 .05645 L
.6623 .05648 L
.7023 .05651 L
.74079 .05653 L
.78173 .05655 L
.82115 .05657 L
.85906 .05658 L
.89942 .05659 L
.93826 .0566 L
.97619 .05661 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04684 L
.06244 .04864 L
.08259 .05244 L
.09399 .05523 L
.10458 .05854 L
.11466 .06266 L
.1238 .06773 L
.12887 .07137 L
.13435 .07633 L
.13953 .08241 L
.14429 .08982 L
.14899 .09974 L
.15162 .10693 L
.15402 .11487 L
.15869 .13527 L
.16311 .16206 L
.16791 .19694 L
.17054 .21442 L
.17183 .22148 L
.17301 .22681 L
.17429 .23126 L
.17496 .23305 L
.17567 .23453 L
.17639 .23565 L
.17707 .23634 L
.17781 .23674 L
.1786 .23679 L
.17927 .23655 L
.18 .23604 L
.18131 .23453 L
.18259 .23248 L
.18378 .23019 L
.19359 .20601 L
.199 .19359 L
.20413 .18383 L
.20889 .17676 L
.21159 .17365 L
Mistroke
.21409 .17136 L
.21528 .17049 L
.2164 .1698 L
.21742 .16929 L
.21849 .16887 L
.21966 .16857 L
.22074 .16845 L
.22191 .16848 L
.22318 .16873 L
.2244 .16919 L
.22509 .16956 L
.22573 .16996 L
.22689 .1709 L
.22814 .17218 L
.23028 .17518 L
.23265 .17985 L
.23517 .18679 L
.23788 .19719 L
.24044 .21072 L
.24279 .22732 L
.24499 .24768 L
.24704 .27157 L
.2517 .34436 L
.25407 .38717 L
.25657 .42968 L
.2589 .46214 L
.26107 .48489 L
.26223 .49411 L
.26348 .50184 L
.26419 .50533 L
.26487 .50806 L
.26613 .51178 L
.26679 .51307 L
.2675 .51397 L
.26876 .51453 L
.26946 .5143 L
.27012 .51376 L
.27084 .51284 L
.27162 .51149 L
.27282 .50876 L
.27414 .50499 L
.2768 .49538 L
.28156 .47383 L
.30016 .38003 L
.31975 .30068 L
.34069 .23672 L
.35092 .21222 L
.36201 .19093 L
.37249 .17557 L
.38216 .16469 L
Mistroke
.4009 .14942 L
.42153 .13747 L
.44095 .12907 L
.46184 .12259 L
.47195 .12026 L
.48299 .11819 L
.50308 .11537 L
.52277 .11336 L
.54375 .11173 L
.56517 .11046 L
.58535 .10957 L
.60544 .10892 L
.62392 .10848 L
.64276 .10815 L
.65357 .108 L
.66343 .10789 L
.68295 .10772 L
.6937 .10766 L
.70387 .10761 L
.71353 .10757 L
.72379 .10754 L
.73256 .10752 L
.73754 .10752 L
.74222 .10751 L
.74692 .10751 L
.75206 .1075 L
.75466 .1075 L
.75743 .1075 L
.76002 .1075 L
.76242 .1075 L
.76481 .1075 L
.76607 .1075 L
.76741 .1075 L
.76857 .1075 L
.76965 .1075 L
.77084 .1075 L
.77212 .1075 L
.77325 .1075 L
.77448 .1075 L
.77564 .1075 L
.77672 .1075 L
.77876 .1075 L
.78093 .1075 L
.78631 .1075 L
.79125 .1075 L
.80239 .10751 L
.82258 .10752 L
.84306 .10753 L
.86214 .10754 L
.87159 .10754 L
Mistroke
.88052 .10754 L
.88546 .10754 L
.89081 .10755 L
.89533 .10755 L
.90019 .10755 L
.90273 .10755 L
.90506 .10755 L
.90742 .10755 L
.90962 .10755 L
.91085 .10755 L
.91217 .10755 L
.91292 .10755 L
.91362 .10755 L
.91495 .10755 L
.91621 .10755 L
.91738 .10755 L
.91866 .10755 L
.9193 .10755 L
.92001 .10755 L
.92142 .10755 L
.92276 .10755 L
.92526 .10755 L
.92795 .10755 L
.93089 .10755 L
.93616 .10755 L
.94104 .10755 L
.95774 .10754 L
.97619 .10754 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .0524 L
.09399 .05519 L
.10458 .05847 L
.11466 .06257 L
.1238 .06758 L
.12887 .07118 L
.13435 .07605 L
.13953 .08201 L
.14429 .08923 L
.14899 .0988 L
.15157 .10555 L
.15402 .11322 L
.15878 .13276 L
.16311 .15695 L
.16791 .18852 L
.17054 .20435 L
.17183 .21077 L
.17301 .21563 L
.17429 .2197 L
.17496 .22132 L
.17567 .22265 L
.17639 .22362 L
.17707 .22419 L
.17781 .22447 L
.1786 .22438 L
.17927 .22402 L
.18 .22337 L
.18131 .22157 L
.18259 .21919 L
.18378 .21654 L
.20413 .15447 L
.21409 .12887 L
.22318 .11127 L
.22766 .10478 L
.23255 .09929 L
Mistroke
.23478 .09728 L
.23716 .09547 L
.24144 .09298 L
.24399 .09192 L
.24534 .09147 L
.24675 .09108 L
.24799 .09079 L
.24935 .09053 L
.2506 .09033 L
.25174 .09019 L
.25407 .08997 L
.25535 .08988 L
.25657 .08981 L
.25873 .08969 L
.26107 .08954 L
.26344 .08933 L
.26567 .08906 L
.26832 .08862 L
.27075 .08809 L
.27575 .08662 L
.28102 .08465 L
.29945 .07722 L
.30902 .07442 L
.31437 .07326 L
.31923 .07243 L
.32377 .07182 L
.32869 .07133 L
.33095 .07115 L
.33333 .07099 L
.33538 .07088 L
.33761 .07078 L
.33893 .07073 L
.34015 .0707 L
.34129 .07067 L
.34256 .07064 L
.34368 .07062 L
.34474 .07061 L
.34586 .07061 L
.34707 .0706 L
.3483 .07061 L
.349 .07061 L
.34965 .07062 L
.35096 .07063 L
.35236 .07065 L
.35491 .07071 L
.35722 .07078 L
.36174 .07097 L
.36665 .07123 L
.37555 .07186 L
.41643 .07591 L
Mistroke
.45581 .07972 L
.49366 .08326 L
.53397 .08688 L
.57276 .08995 L
.614 .09276 L
.65373 .09503 L
.69195 .09682 L
.73261 .09837 L
.77176 .0996 L
.81336 .10069 L
.85345 .10159 L
.89202 .10235 L
.93304 .10309 L
.97255 .10375 L
.97619 .10381 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05245 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06778 L
.12887 .07144 L
.13435 .07642 L
.13953 .08254 L
.14429 .09001 L
.14899 .10003 L
.15162 .10731 L
.15402 .11535 L
.15869 .13608 L
.16311 .16336 L
.16791 .19881 L
.17054 .21644 L
.17183 .22348 L
.17301 .22875 L
.17429 .23311 L
.17496 .23483 L
.17567 .23624 L
.17639 .23727 L
.17707 .23788 L
.17781 .23819 L
.1786 .23815 L
.17927 .23783 L
.18 .23724 L
.18131 .23559 L
.18259 .23342 L
.18378 .23104 L
.19359 .20669 L
.199 .19452 L
.20413 .18515 L
.20889 .17853 L
.21159 .1757 L
Mistroke
.21287 .17459 L
.21409 .17369 L
.2152 .17299 L
.2164 .17239 L
.21749 .17197 L
.21849 .17171 L
.21958 .17157 L
.22077 .17158 L
.22202 .17179 L
.22318 .17219 L
.2244 .17284 L
.22554 .17366 L
.22678 .17483 L
.2281 .17641 L
.23031 .17997 L
.23276 .18545 L
.23492 .19202 L
.23726 .20142 L
.23946 .21311 L
.24148 .22694 L
.24384 .24806 L
.24604 .27368 L
.24845 .30966 L
.25103 .35699 L
.25591 .45508 L
.25837 .49532 L
.25978 .51336 L
.26107 .52648 L
.2624 .53689 L
.26308 .54108 L
.26383 .54481 L
.26452 .54755 L
.26516 .54951 L
.26641 .55192 L
.26755 .55263 L
.2688 .55201 L
.27011 .55003 L
.27134 .54713 L
.27269 .54294 L
.27412 .53763 L
.27668 .52639 L
.28245 .49664 L
.2922 .44511 L
.30262 .39844 L
.31294 .36263 L
.32233 .33756 L
.34069 .30256 L
.35066 .28863 L
.35985 .27781 L
.38064 .25748 L
Mistroke
.40097 .23991 L
.42001 .225 L
.43942 .21241 L
.45787 .20344 L
.46756 .19981 L
.47813 .19655 L
.49666 .19212 L
.51635 .18858 L
.53733 .18565 L
.55875 .18335 L
.57893 .18175 L
.5887 .18116 L
.59902 .18063 L
.6175 .1799 L
.62699 .17962 L
.63715 .17937 L
.64668 .17919 L
.65549 .17905 L
.66567 .17892 L
.67094 .17887 L
.67674 .17882 L
.68144 .17879 L
.68651 .17876 L
.69185 .17874 L
.69428 .17873 L
.69687 .17872 L
.69947 .17871 L
.70183 .17871 L
.70421 .17871 L
.70645 .1787 L
.70772 .1787 L
.70842 .1787 L
.70907 .1787 L
.71022 .1787 L
.71148 .1787 L
.71218 .1787 L
.71285 .1787 L
.71411 .1787 L
.71481 .1787 L
.71546 .1787 L
.71693 .1787 L
.71826 .1787 L
.71969 .17871 L
.72229 .17871 L
.72715 .17872 L
.73282 .17873 L
.73803 .17874 L
.75691 .17881 L
.77759 .1789 L
.81809 .17909 L
Mistroke
.85707 .17925 L
.87693 .17931 L
.8985 .17937 L
.91787 .17941 L
.93842 .17944 L
.97619 .17949 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05522 L
.10458 .05853 L
.11466 .06265 L
.1238 .0677 L
.12887 .07133 L
.13435 .07627 L
.13953 .08232 L
.14429 .08968 L
.14899 .09948 L
.15157 .10642 L
.15402 .11434 L
.15878 .1346 L
.16311 .15974 L
.16791 .19211 L
.17054 .20778 L
.17183 .21391 L
.17301 .21839 L
.17429 .22194 L
.17496 .22326 L
.17567 .22427 L
.17639 .2249 L
.17707 .22515 L
.17781 .22508 L
.1786 .22462 L
.17927 .22397 L
.18 .22302 L
.18131 .22072 L
.18378 .21491 L
.20326 .15657 L
.21433 .13134 L
.21965 .12188 L
.22469 .11449 L
.22944 .10891 L
.23195 .10649 L
Mistroke
.23462 .1043 L
.23709 .10262 L
.23933 .10136 L
.24145 .10039 L
.24369 .09959 L
.24495 .09923 L
.24632 .0989 L
.24759 .09866 L
.24874 .09848 L
.25011 .09832 L
.25081 .09826 L
.25157 .0982 L
.25292 .09812 L
.25421 .09807 L
.25666 .098 L
.25795 .09796 L
.25931 .09792 L
.26051 .09787 L
.26181 .09781 L
.2641 .09766 L
.26898 .09722 L
.27352 .09676 L
.27611 .09653 L
.27855 .09635 L
.2799 .09628 L
.28136 .09621 L
.28201 .09619 L
.28269 .09617 L
.28391 .09614 L
.28522 .09613 L
.28641 .09613 L
.28707 .09614 L
.28778 .09615 L
.28909 .09618 L
.29031 .09621 L
.2916 .09626 L
.29393 .09636 L
.30493 .09699 L
.31451 .09744 L
.31974 .09765 L
.3246 .09786 L
.32877 .09809 L
.33322 .09841 L
.33816 .0989 L
.34265 .09949 L
.34742 .10029 L
.35259 .1014 L
.36197 .10403 L
.38282 .11235 L
.42371 .13041 L
Mistroke
.46308 .14448 L
.50093 .15715 L
.54124 .16911 L
.58003 .17866 L
.62128 .18701 L
.66101 .1934 L
.69922 .19823 L
.73988 .20226 L
.77903 .20532 L
.82064 .20791 L
.86072 .20996 L
.89929 .21164 L
.94032 .2132 L
.97619 .21442 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04674 L
.06244 .04847 L
.08259 .05215 L
.09399 .05485 L
.10458 .05803 L
.11466 .06197 L
.1238 .06673 L
.12887 .07011 L
.13435 .07465 L
.13953 .0801 L
.14429 .08658 L
.14899 .09495 L
.15402 .10711 L
.15878 .12281 L
.16311 .14124 L
.1682 .16532 L
.17088 .17627 L
.17223 .18061 L
.17301 .18267 L
.17372 .18424 L
.17502 .18631 L
.1757 .187 L
.17642 .18743 L
.17762 .1875 L
.17895 .18672 L
.18016 .18531 L
.18145 .18318 L
.18378 .17806 L
.19345 .14939 L
.20369 .12163 L
.20904 .11074 L
.21187 .10603 L
.21492 .10174 L
.21771 .09847 L
.22027 .09602 L
.2229 .09398 L
.22527 .09254 L
Mistroke
.22774 .09143 L
.22909 .09098 L
.23037 .09066 L
.23155 .09046 L
.23264 .09034 L
.23383 .0903 L
.23509 .09034 L
.23636 .09049 L
.23708 .09062 L
.23773 .09077 L
.23899 .09114 L
.24019 .09159 L
.24287 .09298 L
.24439 .09402 L
.24578 .09516 L
.25028 .10018 L
.25283 .10409 L
.25523 .10852 L
.26526 .13412 L
.27037 .14836 L
.27511 .15916 L
.27751 .16316 L
.27874 .16477 L
.28007 .16617 L
.28083 .16681 L
.28153 .1673 L
.28218 .16767 L
.2829 .16798 L
.28416 .16827 L
.28484 .16831 L
.28548 .16827 L
.28663 .16802 L
.28788 .1675 L
.28906 .16678 L
.29015 .16594 L
.29441 .16127 L
.29906 .15436 L
.304 .14588 L
.31357 .12905 L
.32366 .1137 L
.33228 .10341 L
.34171 .09489 L
.35172 .08833 L
.36104 .08388 L
.37111 .08036 L
.38188 .07762 L
.39211 .07566 L
.40321 .07398 L
.42335 .0716 L
.4432 .06985 L
Mistroke
.45334 .06915 L
.46424 .06853 L
.47445 .06807 L
.48379 .06772 L
.50209 .06721 L
.52109 .06683 L
.54182 .06653 L
.56151 .06632 L
.58249 .06617 L
.59278 .06611 L
.60391 .06606 L
.61442 .06603 L
.62409 .06601 L
.62879 .066 L
.63383 .06599 L
.63819 .06598 L
.64293 .06598 L
.64581 .06598 L
.64848 .06597 L
.65098 .06597 L
.65374 .06597 L
.65493 .06597 L
.65621 .06597 L
.65731 .06597 L
.65852 .06597 L
.65981 .06597 L
.66051 .06597 L
.66117 .06597 L
.66234 .06597 L
.6636 .06597 L
.66483 .06597 L
.66553 .06597 L
.66619 .06597 L
.66751 .06597 L
.66893 .06597 L
.6715 .06597 L
.67385 .06597 L
.67955 .06598 L
.68496 .06598 L
.6946 .06599 L
.70511 .066 L
.74583 .06606 L
.78503 .06613 L
.82669 .0662 L
.86683 .06627 L
.90545 .06633 L
.94652 .06639 L
.97619 .06642 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .05241 L
.09399 .0552 L
.10458 .05849 L
.11466 .06259 L
.1238 .06762 L
.12887 .07123 L
.13435 .07613 L
.13953 .08212 L
.14429 .08938 L
.14899 .09904 L
.15157 .10585 L
.15402 .11361 L
.15878 .13342 L
.16311 .15802 L
.16791 .1901 L
.17054 .2061 L
.17183 .21255 L
.17301 .21741 L
.17429 .22144 L
.17496 .22304 L
.17567 .22433 L
.17639 .22527 L
.17707 .22579 L
.17781 .22602 L
.1786 .22588 L
.17927 .22548 L
.18 .22478 L
.18131 .22291 L
.18259 .22047 L
.18378 .21778 L
.20413 .15701 L
.21409 .13244 L
.22318 .11517 L
.22766 .10863 L
.23255 .10297 L
Mistroke
.23716 .09896 L
.24144 .09629 L
.24401 .09511 L
.24643 .09426 L
.2486 .09368 L
.25095 .09321 L
.25351 .09284 L
.25622 .09253 L
.26107 .09199 L
.26362 .09161 L
.26604 .09114 L
.27057 .08994 L
.27545 .0882 L
.28074 .08597 L
.29021 .08187 L
.29909 .0787 L
.30363 .07744 L
.30851 .07635 L
.31394 .07541 L
.3189 .07476 L
.3238 .07429 L
.32657 .07409 L
.32915 .07394 L
.33188 .07382 L
.33436 .07373 L
.33574 .0737 L
.33646 .07369 L
.33723 .07367 L
.3379 .07366 L
.33863 .07366 L
.33992 .07365 L
.34122 .07365 L
.34243 .07365 L
.34375 .07366 L
.34442 .07367 L
.34515 .07368 L
.34638 .07371 L
.34771 .07374 L
.35011 .07382 L
.35247 .07392 L
.35496 .07404 L
.35941 .07432 L
.36939 .07519 L
.38032 .07649 L
.42085 .08264 L
.45986 .08813 L
.50132 .09364 L
.54127 .09854 L
.57971 .10256 L
.62059 .10611 L
Mistroke
.65996 .10882 L
.69782 .11084 L
.73813 .11246 L
.77692 .11362 L
.81816 .11454 L
.85789 .1152 L
.8961 .11571 L
.93677 .11614 L
.97592 .1165 L
.97619 .1165 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03488 L
.03279 .0378 L
.03527 .04024 L
.03652 .04118 L
.0379 .04205 L
.04033 .04324 L
.04262 .04409 L
.04761 .0454 L
.05217 .04627 L
.06244 .04789 L
.08259 .05136 L
.09399 .0539 L
.10458 .05686 L
.11466 .06048 L
.1238 .06479 L
.12887 .0678 L
.13435 .07176 L
.14429 .08178 L
.16384 .122 L
.16659 .12926 L
.16919 .13508 L
.17063 .13754 L
.17144 .13862 L
.17219 .13941 L
.17283 .1399 L
.17352 .14026 L
.17425 .14044 L
.17493 .14042 L
.1762 .1399 L
.17684 .13943 L
.17753 .13875 L
.17877 .13717 L
.17992 .13533 L
.18529 .12364 L
.19511 .10013 L
.19994 .09073 L
.20438 .08377 L
.20951 .07762 L
.21216 .07514 L
.21507 .0729 L
.21979 .07016 L
.22237 .06907 L
.22478 .06827 L
.22736 .06762 L
.22976 .06719 L
Mistroke
.23114 .067 L
.23239 .06687 L
.23308 .06682 L
.23383 .06677 L
.23454 .06673 L
.23519 .06671 L
.23637 .06668 L
.23748 .06668 L
.23869 .0667 L
.23999 .06674 L
.24065 .06678 L
.24136 .06682 L
.24265 .06691 L
.24507 .06712 L
.24967 .06762 L
.25209 .06789 L
.25463 .06814 L
.25687 .06832 L
.25805 .0684 L
.25932 .06846 L
.26048 .06851 L
.26154 .06855 L
.2636 .06861 L
.27303 .06885 L
.27566 .06894 L
.27709 .06899 L
.27844 .06902 L
.27958 .06905 L
.28081 .06906 L
.28151 .06907 L
.28217 .06907 L
.28342 .06906 L
.28471 .06904 L
.2859 .069 L
.28722 .06894 L
.28861 .06885 L
.29128 .06862 L
.29424 .06828 L
.2995 .06743 L
.30444 .06645 L
.32289 .06246 L
.33335 .06066 L
.34309 .05942 L
.35277 .05854 L
.36311 .05787 L
.37416 .05735 L
.3842 .05699 L
.40336 .05649 L
.41417 .0563 L
.42415 .05615 L
Mistroke
.43383 .05605 L
.44289 .05598 L
.45283 .05592 L
.45842 .0559 L
.46352 .05588 L
.46829 .05586 L
.47338 .05585 L
.48252 .05584 L
.48812 .05583 L
.49339 .05583 L
.49813 .05582 L
.5006 .05582 L
.50325 .05582 L
.50582 .05582 L
.50817 .05582 L
.51056 .05582 L
.51276 .05582 L
.51401 .05582 L
.51533 .05582 L
.51666 .05582 L
.51742 .05582 L
.51813 .05582 L
.5194 .05582 L
.52057 .05582 L
.52185 .05582 L
.5225 .05582 L
.5232 .05582 L
.52463 .05582 L
.52597 .05582 L
.52848 .05582 L
.53119 .05582 L
.53412 .05582 L
.5394 .05582 L
.54427 .05582 L
.55398 .05583 L
.56305 .05584 L
.5837 .05586 L
.62254 .0559 L
.66384 .05594 L
.70362 .05598 L
.74188 .05601 L
.7826 .05603 L
.8218 .05606 L
.86346 .05608 L
.90359 .0561 L
.94222 .05611 L
.97619 .05612 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05246 L
.09399 .05526 L
.10458 .05858 L
.11466 .06273 L
.1238 .06782 L
.12887 .07149 L
.13435 .07648 L
.13953 .08262 L
.14429 .09012 L
.14899 .10015 L
.15162 .10743 L
.15402 .11545 L
.15869 .136 L
.16311 .16264 L
.16791 .19611 L
.16918 .2042 L
.17054 .2119 L
.17174 .21754 L
.17301 .22216 L
.17367 .22402 L
.1744 .2256 L
.17567 .22732 L
.1764 .22773 L
.17719 .22774 L
.17793 .22738 L
.1786 .22676 L
.17988 .22496 L
.18126 .22222 L
.18378 .21578 L
.19317 .18627 L
.20326 .15807 L
.20905 .14509 L
.21433 .13515 L
.21971 .12681 L
.22469 .1206 L
Mistroke
.22938 .11606 L
.23178 .11422 L
.23437 .1126 L
.23585 .11184 L
.23722 .11125 L
.2385 .1108 L
.2399 .1104 L
.24116 .11014 L
.24234 .10997 L
.24358 .10988 L
.24427 .10986 L
.24491 .10987 L
.2461 .10994 L
.24736 .1101 L
.24844 .11029 L
.24963 .11057 L
.25228 .11142 L
.25477 .11248 L
.25926 .115 L
.2641 .11872 L
.26907 .12393 L
.27369 .13004 L
.28418 .14631 L
.2894 .15405 L
.29504 .16119 L
.30038 .16645 L
.30529 .17006 L
.31004 .17261 L
.31525 .17466 L
.32579 .17772 L
.33043 .17913 L
.3354 .18098 L
.34439 .18562 L
.34966 .18928 L
.35454 .19331 L
.3656 .20442 L
.38572 .22819 L
.42495 .26618 L
.46267 .29224 L
.50284 .31733 L
.54149 .33676 L
.5826 .35286 L
.62219 .36495 L
.66027 .37383 L
.7008 .38094 L
.73981 .38607 L
.78128 .39014 L
.82123 .39307 L
.85966 .39521 L
.90055 .39692 L
Mistroke
.93992 .39817 L
.97619 .39903 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04346 L
.04262 .04433 L
.04761 .04569 L
.05217 .04658 L
.06244 .04824 L
.08259 .05179 L
.09399 .05439 L
.10458 .05743 L
.11466 .06116 L
.1238 .06562 L
.12887 .06874 L
.13435 .07285 L
.14429 .08333 L
.16384 .12683 L
.16659 .13517 L
.16919 .14216 L
.17063 .14527 L
.17139 .14663 L
.17219 .14784 L
.17287 .14864 L
.17362 .1493 L
.17493 .14988 L
.17559 .14988 L
.17627 .14969 L
.1775 .14886 L
.17819 .14815 L
.17883 .14733 L
.18028 .145 L
.1827 .1399 L
.18529 .13333 L
.19593 .10486 L
.20116 .09356 L
.20598 .08533 L
.21036 .07957 L
.215 .07501 L
.21966 .07174 L
.2223 .07037 L
.22478 .06936 L
.22736 .06855 L
.22976 .068 L
Mistroke
.23114 .06776 L
.23239 .06759 L
.23308 .06751 L
.23383 .06744 L
.23453 .06739 L
.23519 .06735 L
.23638 .0673 L
.23769 .06729 L
.23897 .06731 L
.23968 .06733 L
.24034 .06736 L
.2415 .06743 L
.24277 .06754 L
.24507 .06779 L
.24729 .06811 L
.24974 .06854 L
.2547 .0696 L
.2636 .07183 L
.26854 .07298 L
.27122 .07351 L
.27372 .07392 L
.27587 .07418 L
.27706 .0743 L
.27815 .07438 L
.27935 .07444 L
.28064 .07448 L
.28186 .07448 L
.28299 .07445 L
.28419 .0744 L
.28549 .07431 L
.28671 .07419 L
.28782 .07406 L
.29055 .07365 L
.29313 .07315 L
.30386 .07029 L
.31261 .06768 L
.32205 .06522 L
.32746 .06409 L
.33242 .06323 L
.33707 .06258 L
.34216 .062 L
.35177 .06122 L
.35702 .06092 L
.36191 .06069 L
.38291 .05995 L
.42192 .05872 L
.43214 .05846 L
.44324 .05822 L
.46338 .05789 L
.48324 .05766 L
Mistroke
.50427 .05747 L
.54213 .0572 L
.56155 .05709 L
.58243 .057 L
.62368 .05685 L
.66341 .05675 L
.70162 .05668 L
.74228 .05663 L
.78143 .05659 L
.82304 .05655 L
.86312 .05652 L
.90169 .0565 L
.94272 .05647 L
.97619 .05645 L
Mfstroke
0 .751 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03057 L
.03068 .03491 L
.03279 .03784 L
.03527 .04028 L
.03652 .04121 L
.0379 .04207 L
.04033 .04325 L
.04262 .04408 L
.04761 .04536 L
.05217 .0462 L
.06244 .04776 L
.08259 .05112 L
.09399 .05358 L
.10458 .05643 L
.11466 .0599 L
.1238 .06397 L
.12887 .06679 L
.13435 .07044 L
.13949 .07463 L
.14429 .07943 L
.15379 .09243 L
.15925 .10235 L
.16423 .11213 L
.16673 .11655 L
.16805 .11852 L
.16945 .12023 L
.17067 .12132 L
.17136 .12176 L
.17202 .12204 L
.17316 .12223 L
.17439 .12198 L
.17572 .12121 L
.17647 .12055 L
.17716 .11981 L
.18008 .11553 L
.18529 .10512 L
.19034 .09454 L
.19581 .08461 L
.20098 .07728 L
.20575 .07221 L
.21005 .06882 L
.21478 .06617 L
.21716 .06519 L
.21972 .06435 L
.22213 .06375 L
.22434 .06334 L
Mistroke
.22563 .06316 L
.22685 .06302 L
.22794 .06292 L
.22912 .06285 L
.23041 .0628 L
.23106 .06278 L
.23177 .06277 L
.23303 .06278 L
.23421 .06281 L
.2354 .06286 L
.23652 .06293 L
.23863 .06311 L
.2409 .06336 L
.24336 .0637 L
.24859 .06463 L
.25414 .06587 L
.2641 .06836 L
.26868 .06942 L
.27349 .07033 L
.27602 .07069 L
.27735 .07084 L
.27877 .07097 L
.28009 .07106 L
.28128 .07112 L
.28248 .07115 L
.28361 .07116 L
.28467 .07115 L
.28583 .07112 L
.28705 .07105 L
.28818 .07098 L
.29021 .07079 L
.29239 .07052 L
.29736 .06968 L
.3019 .06871 L
.31192 .06628 L
.32257 .06388 L
.33167 .0623 L
.33685 .06161 L
.34171 .06108 L
.34639 .06067 L
.35132 .06032 L
.36014 .05985 L
.36962 .05949 L
.38001 .05915 L
.40124 .05848 L
.42054 .05789 L
.4406 .05738 L
.45955 .05704 L
.47954 .05679 L
.49799 .0566 L
Mistroke
.53736 .05628 L
.57521 .05605 L
.61552 .05589 L
.65431 .05577 L
.69556 .05567 L
.73528 .05561 L
.7735 .05556 L
.81416 .05552 L
.85331 .05549 L
.89491 .05546 L
.935 .05543 L
.97357 .05541 L
.97619 .05541 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04443 L
.04761 .04582 L
.05217 .04675 L
.06244 .04847 L
.08259 .05213 L
.09399 .05482 L
.10458 .05797 L
.11466 .06187 L
.1238 .06658 L
.12887 .06991 L
.13435 .07435 L
.13953 .07967 L
.14429 .08593 L
.14899 .09395 L
.15402 .10542 L
.15878 .11995 L
.16311 .13663 L
.1682 .15797 L
.17088 .16753 L
.17223 .17128 L
.17301 .17303 L
.17372 .17435 L
.17502 .17601 L
.1757 .17651 L
.17642 .17676 L
.17762 .17655 L
.17895 .17549 L
.18016 .17384 L
.18145 .17145 L
.18378 .16587 L
.19345 .13529 L
.20369 .10627 L
.20904 .09514 L
.21187 .09038 L
.21492 .08607 L
.21771 .08277 L
.22027 .08026 L
.22527 .07654 L
.22774 .0752 L
Mistroke
.23037 .07408 L
.23284 .07328 L
.23509 .07275 L
.23647 .0725 L
.23774 .07233 L
.23913 .07219 L
.23983 .07214 L
.2406 .0721 L
.24189 .07206 L
.24262 .07206 L
.24328 .07206 L
.24457 .07211 L
.24578 .07218 L
.2469 .07227 L
.24814 .07239 L
.25063 .07272 L
.25512 .07351 L
.26006 .07456 L
.26526 .07565 L
.2676 .07608 L
.27009 .07646 L
.27153 .07664 L
.27283 .07677 L
.27414 .07686 L
.27537 .07692 L
.2765 .07695 L
.27769 .07695 L
.27871 .07692 L
.27982 .07686 L
.28103 .07677 L
.28231 .07664 L
.28464 .07631 L
.28732 .0758 L
.29024 .07509 L
.29555 .07351 L
.30551 .07008 L
.31569 .06685 L
.32526 .06454 L
.33006 .06367 L
.33524 .06292 L
.34099 .06227 L
.34626 .06183 L
.35099 .06151 L
.35605 .06125 L
.36516 .06088 L
.38585 .06028 L
.40574 .05976 L
.41622 .05951 L
.42732 .05928 L
.43721 .05911 L
Mistroke
.4481 .05897 L
.458 .05887 L
.46727 .0588 L
.48753 .05868 L
.50606 .05861 L
.52506 .05854 L
.54579 .05849 L
.56548 .05846 L
.57648 .05844 L
.58645 .05843 L
.60572 .05841 L
.62654 .0584 L
.66756 .05838 L
.70707 .05836 L
.74506 .05834 L
.78551 .05832 L
.82444 .0583 L
.86582 .05828 L
.90568 .05826 L
.94403 .05824 L
.97619 .05822 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04673 L
.06244 .04844 L
.08259 .05207 L
.09399 .05474 L
.10458 .05788 L
.11466 .06174 L
.1238 .06639 L
.12887 .06967 L
.13435 .07403 L
.13953 .07924 L
.14429 .08533 L
.14935 .09377 L
.15414 .10438 L
.15967 .12077 L
.16471 .13946 L
.16914 .15587 L
.17137 .16238 L
.17265 .16515 L
.17384 .16703 L
.17514 .16822 L
.17633 .16854 L
.17763 .16806 L
.17828 .16752 L
.179 .16671 L
.1802 .16488 L
.18148 .16238 L
.18378 .1567 L
.19263 .12907 L
.202 .10289 L
.20689 .0927 L
.21227 .08423 L
.21717 .07869 L
.22175 .07501 L
.22451 .07338 L
.22712 .07216 L
.22948 .07133 L
.23204 .07065 L
Mistroke
.2335 .07036 L
.23482 .07015 L
.23555 .07006 L
.23634 .06998 L
.23702 .06992 L
.23777 .06987 L
.23847 .06984 L
.23912 .06982 L
.23981 .06981 L
.24055 .06981 L
.24123 .06982 L
.24188 .06984 L
.24309 .0699 L
.24425 .06998 L
.24553 .0701 L
.24811 .07043 L
.25275 .07126 L
.26325 .07376 L
.26818 .0749 L
.27087 .07542 L
.27336 .0758 L
.27551 .07605 L
.27671 .07614 L
.27779 .07621 L
.27899 .07625 L
.28028 .07626 L
.28151 .07624 L
.28263 .07618 L
.28384 .0761 L
.28513 .07597 L
.28746 .07566 L
.29024 .07515 L
.29277 .07456 L
.3035 .0713 L
.31352 .06802 L
.32417 .06517 L
.33327 .06346 L
.33845 .06275 L
.34331 .06222 L
.34799 .06182 L
.35292 .06148 L
.36174 .06103 L
.37122 .06067 L
.38161 .06032 L
.40284 .05964 L
.42214 .05907 L
.43176 .05883 L
.4422 .05861 L
.46115 .05832 L
.4706 .0582 L
Mistroke
.481 .0581 L
.50204 .05792 L
.52309 .05777 L
.54235 .05766 L
.58114 .05749 L
.60014 .05743 L
.62087 .05737 L
.66153 .05728 L
.70068 .05722 L
.74228 .05717 L
.78237 .05714 L
.82094 .05711 L
.86196 .05708 L
.90147 .05705 L
.93946 .05703 L
.97619 .05701 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .05241 L
.09399 .0552 L
.10458 .0585 L
.11466 .0626 L
.1238 .06764 L
.12887 .07126 L
.13435 .07617 L
.13953 .08219 L
.14429 .08951 L
.14899 .09927 L
.15157 .10618 L
.15402 .11409 L
.15878 .1344 L
.16311 .15993 L
.16791 .19371 L
.17054 .21076 L
.17183 .21769 L
.17301 .22296 L
.17429 .22741 L
.17496 .22921 L
.17567 .23072 L
.17639 .23188 L
.17707 .2326 L
.17781 .23305 L
.1786 .23314 L
.17927 .23295 L
.18 .23248 L
.18131 .23103 L
.18259 .22901 L
.18378 .22674 L
.19359 .20199 L
.199 .1888 L
.20413 .17814 L
.20889 .17011 L
.21141 .16664 L
Mistroke
.21409 .16357 L
.21656 .16132 L
.2188 .15981 L
.21989 .15928 L
.22106 .15885 L
.22216 .1586 L
.22318 .1585 L
.22433 .15856 L
.22538 .15877 L
.22659 .15922 L
.22773 .15986 L
.22879 .16066 L
.22976 .16158 L
.23197 .1644 L
.23312 .16633 L
.2342 .16845 L
.23665 .17465 L
.23904 .18291 L
.24161 .19499 L
.24398 .20991 L
.24656 .23159 L
.24926 .26146 L
.25177 .29605 L
.25661 .37285 L
.26107 .43465 L
.26353 .45926 L
.26477 .46879 L
.26613 .4771 L
.2675 .48329 L
.26827 .48588 L
.26897 .48773 L
.26962 .48903 L
.27033 .49 L
.27162 .4907 L
.27281 .49024 L
.27412 .48863 L
.27478 .48744 L
.27549 .4859 L
.27678 .48249 L
.28156 .46472 L
.30016 .37387 L
.31979 .29399 L
.33017 .26082 L
.34127 .23128 L
.35201 .20815 L
.36177 .19149 L
.37159 .1784 L
.38086 .16866 L
.40085 .15311 L
.4193 .14236 L
Mistroke
.43804 .1338 L
.44881 .12989 L
.45867 .12692 L
.47809 .12253 L
.4888 .12075 L
.49898 .11938 L
.5188 .1173 L
.53719 .11585 L
.55773 .11462 L
.57634 .1138 L
.58637 .11346 L
.5956 .11321 L
.60637 .11297 L
.61642 .1128 L
.62552 .11267 L
.63526 .11258 L
.64082 .11253 L
.64608 .1125 L
.65076 .11248 L
.65593 .11246 L
.65833 .11245 L
.66092 .11244 L
.66315 .11244 L
.6656 .11243 L
.66695 .11243 L
.6682 .11243 L
.66953 .11243 L
.67027 .11243 L
.67095 .11243 L
.67216 .11243 L
.67347 .11243 L
.67471 .11243 L
.67586 .11243 L
.67692 .11243 L
.67806 .11243 L
.68012 .11243 L
.68257 .11243 L
.68481 .11244 L
.68967 .11245 L
.69428 .11246 L
.7039 .1125 L
.71414 .11254 L
.73255 .11265 L
.7742 .11294 L
.81434 .11324 L
.85296 .1135 L
.89404 .11375 L
.9336 .11395 L
.97164 .11412 L
.97619 .11413 L
Mistroke
Mfstroke
0 .656 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .0379 L
.03527 .04038 L
.03652 .04134 L
.0379 .04222 L
.04033 .04344 L
.04262 .04431 L
.04761 .04567 L
.05217 .04657 L
.06244 .04825 L
.08259 .05183 L
.09399 .05445 L
.10458 .05753 L
.11466 .06131 L
.1238 .06584 L
.12887 .06904 L
.13435 .07327 L
.14429 .08417 L
.16384 .13183 L
.16659 .14143 L
.16919 .14962 L
.17063 .15333 L
.17139 .15498 L
.17219 .15646 L
.17287 .15748 L
.17362 .15836 L
.17493 .15926 L
.17559 .15941 L
.17627 .15934 L
.1775 .15871 L
.17819 .15809 L
.17883 .15735 L
.18028 .15516 L
.1827 .1502 L
.18529 .14371 L
.19593 .11474 L
.20116 .10286 L
.20598 .09404 L
.21036 .08775 L
.215 .08267 L
.21966 .07898 L
.2223 .07742 L
.22478 .07626 L
.22736 .07534 L
.22976 .07472 L
Mistroke
.23114 .07446 L
.23239 .07428 L
.23308 .07421 L
.23383 .07414 L
.23454 .07409 L
.23519 .07407 L
.23637 .07405 L
.23748 .07407 L
.23869 .07413 L
.23999 .07424 L
.24065 .07432 L
.24136 .07441 L
.24265 .07462 L
.24507 .07512 L
.24729 .07571 L
.24974 .07651 L
.2547 .07855 L
.2636 .08367 L
.27305 .09043 L
.2778 .09325 L
.2791 .09384 L
.28049 .09439 L
.28179 .0948 L
.28299 .09509 L
.28367 .09522 L
.2844 .09533 L
.28513 .09541 L
.28593 .09545 L
.28662 .09547 L
.28736 .09545 L
.28806 .09541 L
.2887 .09535 L
.28997 .09516 L
.29069 .09501 L
.29136 .09486 L
.29388 .09409 L
.29618 .09317 L
.29872 .09196 L
.30386 .08905 L
.31406 .08267 L
.32481 .07659 L
.33398 .07251 L
.34403 .06918 L
.3537 .06687 L
.36405 .0651 L
.37381 .06389 L
.38268 .06305 L
.40185 .06176 L
.41266 .06123 L
.42263 .06082 L
Mistroke
.44137 .06021 L
.45203 .05995 L
.46201 .05976 L
.4724 .05959 L
.48227 .05947 L
.5008 .05931 L
.51039 .05925 L
.52062 .05919 L
.53901 .05912 L
.54931 .05909 L
.56044 .05906 L
.57095 .05904 L
.58061 .05903 L
.58532 .05903 L
.59036 .05902 L
.59512 .05902 L
.59945 .05902 L
.60209 .05902 L
.60454 .05902 L
.60581 .05902 L
.60722 .05902 L
.60793 .05902 L
.60869 .05902 L
.6094 .05902 L
.61007 .05902 L
.61129 .05902 L
.61193 .05902 L
.61262 .05902 L
.61335 .05902 L
.61403 .05902 L
.61531 .05902 L
.61651 .05902 L
.61762 .05902 L
.62012 .05902 L
.62257 .05902 L
.6248 .05902 L
.62982 .05902 L
.6389 .05903 L
.64949 .05903 L
.65954 .05904 L
.69781 .05907 L
.73852 .05912 L
.77773 .05916 L
.81938 .05921 L
.85952 .05925 L
.89814 .05928 L
.93922 .05931 L
.97619 .05933 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05528 L
.10458 .0586 L
.11466 .06275 L
.1238 .06786 L
.12887 .07154 L
.13435 .07656 L
.13953 .08274 L
.14429 .0903 L
.14899 .10047 L
.15162 .10788 L
.15402 .11608 L
.15869 .13729 L
.16311 .16528 L
.16791 .2014 L
.17054 .21902 L
.17183 .22591 L
.17301 .23098 L
.17429 .23505 L
.17496 .2366 L
.17567 .23782 L
.17639 .23865 L
.17707 .23907 L
.17781 .23918 L
.1786 .23891 L
.17927 .23842 L
.18 .23764 L
.18131 .23568 L
.18378 .23064 L
.19404 .20448 L
.19906 .19356 L
.20365 .18564 L
.20848 .17951 L
.21114 .1771 L
.21247 .17617 L
Mistroke
.21367 .17548 L
.215 .17489 L
.21572 .17465 L
.21641 .17448 L
.21763 .17431 L
.21895 .17432 L
.21964 .17442 L
.2204 .1746 L
.2212 .17488 L
.22194 .17522 L
.22327 .17603 L
.22469 .17723 L
.22592 .17856 L
.22727 .18038 L
.23 .18536 L
.23252 .19191 L
.23489 .20024 L
.23768 .21365 L
.24023 .23064 L
.24303 .25656 L
.24598 .29523 L
.25099 .39528 L
.25572 .50705 L
.25833 .55417 L
.25981 .57318 L
.26116 .58603 L
.26231 .59374 L
.26357 .59936 L
.26488 .60249 L
.26611 .60332 L
.26733 .60246 L
.26803 .60135 L
.26867 .59997 L
.26985 .59666 L
.2711 .59224 L
.27565 .57089 L
.28589 .5141 L
.29547 .46816 L
.30427 .43709 L
.30882 .42517 L
.31362 .41544 L
.31844 .40834 L
.32117 .40538 L
.32372 .40326 L
.32609 .40178 L
.32726 .40122 L
.32834 .40079 L
.3293 .40048 L
.33036 .40021 L
.33142 .40002 L
Mistroke
.33255 .39988 L
.33377 .39982 L
.3349 .39984 L
.33619 .39993 L
.33742 .4001 L
.33855 .4003 L
.3396 .40053 L
.34199 .40119 L
.35256 .40525 L
.35775 .40716 L
.36003 .40785 L
.36252 .40848 L
.36361 .4087 L
.36477 .40889 L
.36578 .40903 L
.36687 .40915 L
.36811 .40923 L
.36928 .40927 L
.37042 .40926 L
.37147 .40922 L
.37262 .40913 L
.3737 .40901 L
.37488 .40883 L
.37616 .40859 L
.37876 .40793 L
.38114 .40716 L
.38588 .40514 L
.39095 .4024 L
.40007 .39638 L
.42078 .38109 L
.44071 .36858 L
.45194 .36317 L
.4623 .35914 L
.48173 .35337 L
.5023 .34873 L
.52211 .34503 L
.54021 .34223 L
.55967 .3399 L
.57052 .3389 L
.58057 .33813 L
.59961 .33706 L
.60965 .33665 L
.62035 .3363 L
.63067 .33603 L
.64182 .33581 L
.65234 .33565 L
.662 .33555 L
.66672 .33551 L
.67177 .33548 L
.67654 .33546 L
Mistroke
.68088 .33544 L
.68353 .33543 L
.68598 .33543 L
.68866 .33542 L
.69002 .33542 L
.69151 .33542 L
.69282 .33542 L
.69401 .33542 L
.69467 .33542 L
.69539 .33542 L
.6967 .33542 L
.69792 .33542 L
.69922 .33542 L
.70045 .33542 L
.70156 .33542 L
.70388 .33542 L
.70643 .33543 L
.71158 .33544 L
.7208 .33546 L
.74162 .33553 L
.76275 .33561 L
.78203 .33568 L
.79159 .3357 L
.802 .33572 L
.80676 .33573 L
.81183 .33574 L
.81615 .33574 L
.81861 .33574 L
.82092 .33574 L
.8221 .33575 L
.82335 .33575 L
.82444 .33575 L
.82562 .33575 L
.82634 .33575 L
.827 .33575 L
.82831 .33575 L
.82949 .33575 L
.83075 .33575 L
.83198 .33575 L
.83329 .33575 L
.83454 .33575 L
.83568 .33575 L
.83846 .33574 L
.8411 .33574 L
.84569 .33574 L
.84995 .33573 L
.8596 .33572 L
.87019 .33569 L
.88015 .33566 L
.89877 .33559 L
Mistroke
.93736 .3354 L
.97619 .33517 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05247 L
.09399 .05529 L
.10458 .05861 L
.11466 .06277 L
.1238 .06789 L
.12887 .07158 L
.13435 .07661 L
.13953 .08282 L
.14429 .09041 L
.14899 .10062 L
.15162 .10806 L
.15402 .11631 L
.15869 .13759 L
.16311 .16554 L
.16791 .20112 L
.16918 .20979 L
.17054 .21805 L
.17174 .22414 L
.17301 .22916 L
.17367 .2312 L
.1744 .23298 L
.17567 .23498 L
.1764 .23554 L
.17719 .2357 L
.17793 .23548 L
.1786 .23499 L
.17988 .23342 L
.1806 .23222 L
.18126 .23095 L
.18378 .22506 L
.19359 .19752 L
.199 .18434 L
.20413 .17427 L
.20889 .1671 L
.21159 .16395 L
Mistroke
.21409 .16162 L
.21528 .16071 L
.2164 .15998 L
.21742 .15942 L
.21849 .15894 L
.21966 .15855 L
.22074 .15832 L
.22191 .15822 L
.22318 .15829 L
.2244 .15854 L
.22509 .15877 L
.22573 .15904 L
.22689 .15969 L
.22814 .16061 L
.23028 .16283 L
.2315 .16449 L
.23265 .16635 L
.2352 .17167 L
.23753 .17832 L
.24009 .18814 L
.24279 .20227 L
.24498 .21755 L
.24731 .23872 L
.25152 .29245 L
.25616 .37269 L
.26107 .45875 L
.26361 .49446 L
.26496 .50985 L
.26641 .52353 L
.26774 .53359 L
.26896 .5408 L
.27018 .5463 L
.27134 .55005 L
.27197 .55156 L
.27267 .55281 L
.27341 .55368 L
.2741 .55413 L
.27533 .55413 L
.27602 .55373 L
.27666 .55313 L
.27736 .55225 L
.278 .55124 L
.27948 .54834 L
.28245 .54059 L
.29212 .50835 L
.30262 .47666 L
.30808 .46453 L
.31048 .4603 L
.31312 .45642 L
.31544 .45369 L
Mistroke
.31794 .45145 L
.31932 .4505 L
.32058 .44982 L
.32185 .44931 L
.32305 .44898 L
.32422 .44879 L
.32528 .44874 L
.3265 .4488 L
.32766 .44899 L
.32873 .44927 L
.32971 .44962 L
.33193 .45067 L
.33418 .45209 L
.33665 .45401 L
.34163 .45881 L
.3525 .47121 L
.35785 .47701 L
.36279 .4816 L
.36727 .4849 L
.36956 .48623 L
.37203 .4874 L
.37331 .4879 L
.37449 .48829 L
.37569 .48862 L
.3768 .48887 L
.37803 .48909 L
.37868 .48918 L
.37937 .48926 L
.3801 .48932 L
.38079 .48935 L
.38207 .48937 L
.38324 .48934 L
.38432 .48927 L
.38552 .48914 L
.3868 .48895 L
.38941 .48843 L
.3918 .4878 L
.40076 .48449 L
.421 .4755 L
.43023 .4721 L
.44004 .46931 L
.45081 .46714 L
.46078 .46571 L
.50244 .461 L
.54258 .45574 L
.5812 .45169 L
.62227 .44826 L
.66183 .44529 L
.69988 .44269 L
.74037 .44013 L
Mistroke
.77935 .43782 L
.82079 .43551 L
.86071 .4334 L
.89911 .43148 L
.93996 .42954 L
.97619 .42792 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04682 L
.06244 .04859 L
.08259 .05234 L
.09399 .0551 L
.10458 .05835 L
.11466 .0624 L
.1238 .06734 L
.12887 .07087 L
.13435 .07564 L
.13953 .08144 L
.14429 .08841 L
.14899 .09758 L
.15402 .11122 L
.15878 .1294 L
.16311 .15152 L
.1682 .18153 L
.17088 .19557 L
.17234 .20168 L
.17372 .2061 L
.17492 .20882 L
.17621 .21061 L
.1769 .2111 L
.17763 .21128 L
.17895 .2108 L
.18014 .20957 L
.18125 .20784 L
.18378 .20232 L
.20251 .14379 L
.20764 .13015 L
.21308 .11789 L
.21778 .10912 L
.22282 .1015 L
.22807 .0954 L
.23299 .09121 L
.23598 .08929 L
.23883 .08787 L
.24138 .08689 L
Mistroke
.24282 .08646 L
.24417 .08611 L
.24544 .08585 L
.24682 .08561 L
.24808 .08545 L
.24923 .08534 L
.25048 .08525 L
.25119 .08521 L
.25186 .08519 L
.25256 .08517 L
.25319 .08516 L
.25393 .08515 L
.25462 .08515 L
.2558 .08516 L
.25704 .08517 L
.25811 .08519 L
.25927 .0852 L
.26051 .0852 L
.26167 .08519 L
.26235 .08518 L
.26305 .08516 L
.26432 .08511 L
.26556 .08503 L
.2669 .08491 L
.26817 .08476 L
.26934 .0846 L
.27155 .0842 L
.27389 .08367 L
.27875 .08221 L
.2841 .0802 L
.29353 .07632 L
.30248 .07306 L
.30736 .07162 L
.31267 .07033 L
.31709 .06946 L
.32197 .0687 L
.32723 .06807 L
.32992 .06782 L
.33282 .06759 L
.33552 .06742 L
.338 .06729 L
.34055 .06719 L
.34287 .06711 L
.34404 .06708 L
.3453 .06705 L
.3464 .06703 L
.3476 .06702 L
.34888 .067 L
.34958 .067 L
.35023 .06699 L
Mistroke
.3514 .06699 L
.35266 .06699 L
.35383 .06699 L
.3551 .067 L
.3563 .06701 L
.35742 .06702 L
.35953 .06705 L
.36177 .0671 L
.36736 .06725 L
.37263 .06745 L
.38246 .06793 L
.42103 .07048 L
.46206 .07315 L
.50156 .07559 L
.53956 .07773 L
.58 .07963 L
.61893 .0811 L
.66031 .08229 L
.68102 .08275 L
.70018 .08311 L
.73852 .08365 L
.7572 .08384 L
.77781 .08401 L
.79717 .08414 L
.81803 .08424 L
.83809 .08431 L
.85919 .08437 L
.87895 .08441 L
.89732 .08443 L
.90786 .08444 L
.9178 .08445 L
.92665 .08446 L
.93639 .08446 L
.94612 .08447 L
.95642 .08447 L
.96595 .08447 L
.97487 .08448 L
.97619 .08448 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04586 L
.05217 .0468 L
.06244 .04856 L
.08259 .0523 L
.09399 .05505 L
.10458 .0583 L
.11466 .06232 L
.1238 .06723 L
.12887 .07074 L
.13435 .07548 L
.13953 .08124 L
.14429 .08815 L
.14899 .09724 L
.15402 .11078 L
.15878 .12885 L
.16311 .15093 L
.1682 .1812 L
.17088 .19555 L
.17234 .20189 L
.17372 .20655 L
.17492 .20951 L
.17621 .21158 L
.1769 .21224 L
.17763 .21259 L
.17895 .21244 L
.18014 .21152 L
.18125 .2101 L
.18247 .20801 L
.18378 .20528 L
.19345 .1779 L
.20369 .15004 L
.20904 .13865 L
.21187 .13362 L
.21492 .12902 L
.21771 .12554 L
.22027 .12297 L
.2215 .12195 L
.22284 .12099 L
Mistroke
.22411 .12024 L
.22527 .11968 L
.22658 .11922 L
.22727 .11904 L
.22799 .11891 L
.22921 .1188 L
.2299 .11881 L
.23055 .11887 L
.23175 .11911 L
.23285 .11948 L
.23412 .12009 L
.23532 .12088 L
.23662 .12196 L
.23799 .1234 L
.24045 .12687 L
.2431 .13212 L
.24602 .14023 L
.24852 .14961 L
.2508 .16057 L
.25595 .19393 L
.26526 .26676 L
.2677 .28281 L
.27001 .29534 L
.27129 .30109 L
.27267 .30633 L
.27382 .3099 L
.27508 .31304 L
.27628 .31526 L
.2774 .31671 L
.27857 .31763 L
.27984 .31796 L
.28101 .31769 L
.28213 .31698 L
.28313 .31599 L
.28422 .31457 L
.28669 .31014 L
.28943 .30371 L
.29497 .28737 L
.30493 .25365 L
.31513 .22065 L
.32588 .19161 L
.33506 .17203 L
.3451 .15551 L
.35478 .14357 L
.36512 .13414 L
.37488 .12752 L
.38376 .12279 L
.40292 .11488 L
.42371 .10805 L
.44356 .1029 L
Mistroke
.4537 .10082 L
.46459 .099 L
.47481 .09762 L
.48414 .09659 L
.50245 .09507 L
.52145 .09394 L
.54218 .09302 L
.56187 .09238 L
.57287 .0921 L
.58284 .0919 L
.59221 .09175 L
.6021 .09163 L
.60728 .09158 L
.61295 .09153 L
.62293 .09147 L
.62818 .09145 L
.63314 .09143 L
.6376 .09142 L
.64012 .09142 L
.64245 .09141 L
.64365 .09141 L
.64494 .09141 L
.64616 .09141 L
.64728 .09141 L
.64852 .09141 L
.64922 .09141 L
.64987 .09141 L
.65119 .09141 L
.65193 .09141 L
.6526 .09141 L
.65398 .09141 L
.65526 .09141 L
.65814 .09142 L
.66068 .09142 L
.66337 .09143 L
.67282 .09145 L
.68296 .09149 L
.70128 .09158 L
.74258 .09186 L
.78236 .09217 L
.82062 .09246 L
.86134 .09276 L
.90054 .09301 L
.9422 .09325 L
.97619 .09343 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05245 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06778 L
.12887 .07144 L
.13435 .07642 L
.13953 .08254 L
.14429 .09001 L
.14899 .10003 L
.15162 .10731 L
.15402 .11535 L
.15869 .13608 L
.16311 .16336 L
.16791 .19882 L
.17054 .21644 L
.17183 .22349 L
.17301 .22876 L
.17429 .23311 L
.17496 .23483 L
.17567 .23623 L
.17639 .23726 L
.17707 .23786 L
.17781 .23816 L
.1786 .23811 L
.17927 .23778 L
.18 .23718 L
.18131 .23551 L
.18259 .23331 L
.18378 .2309 L
.19359 .20626 L
.199 .1939 L
.20413 .18433 L
.20889 .1775 L
.21159 .17453 L
Mistroke
.21409 .17239 L
.21528 .17158 L
.2164 .17096 L
.2174 .17052 L
.21849 .17016 L
.21968 .16994 L
.22093 .16989 L
.222 .17001 L
.22318 .17033 L
.2244 .17088 L
.22509 .1713 L
.22573 .17176 L
.22687 .17277 L
.22814 .17419 L
.23032 .17749 L
.23265 .1824 L
.23517 .18977 L
.23788 .20086 L
.24044 .2154 L
.24279 .23343 L
.24499 .25588 L
.24704 .28276 L
.2517 .36822 L
.25657 .47502 L
.25871 .51412 L
.26107 .54649 L
.26234 .55924 L
.26353 .56833 L
.26478 .57523 L
.26549 .578 L
.26613 .57991 L
.26683 .58136 L
.26748 .58216 L
.26819 .58249 L
.26895 .58228 L
.27022 .58076 L
.27094 .57932 L
.27162 .57764 L
.27411 .56923 L
.2764 .55927 L
.28156 .53284 L
.29055 .48584 L
.30016 .44429 L
.30529 .42685 L
.30995 .41374 L
.31469 .40287 L
.31906 .39483 L
.32417 .38757 L
.3268 .3846 L
.3297 .38188 L
Mistroke
.33458 .37841 L
.33725 .37701 L
.33976 .37597 L
.34216 .37516 L
.34472 .37447 L
.34754 .37388 L
.35015 .37343 L
.35523 .3727 L
.36002 .37197 L
.36469 .37104 L
.36974 .36964 L
.37433 .36792 L
.37855 .36594 L
.38829 .35996 L
.39739 .35292 L
.41805 .33478 L
.43671 .31978 L
.45698 .30746 L
.46803 .30251 L
.47824 .29881 L
.49836 .29324 L
.51704 .28935 L
.53765 .28604 L
.55701 .28378 L
.5679 .28286 L
.57787 .28222 L
.58262 .28198 L
.58769 .28176 L
.59207 .28161 L
.59681 .28147 L
.59972 .2814 L
.6024 .28135 L
.6049 .28131 L
.60766 .28127 L
.60997 .28124 L
.61245 .28122 L
.61382 .28121 L
.61507 .28121 L
.61633 .2812 L
.61752 .2812 L
.61877 .2812 L
.61947 .28119 L
.62012 .28119 L
.62131 .2812 L
.62257 .2812 L
.6237 .2812 L
.62475 .2812 L
.62714 .28121 L
.62973 .28123 L
.63209 .28125 L
Mistroke
.63738 .28131 L
.64684 .28146 L
.65578 .28166 L
.67575 .28222 L
.69418 .28286 L
.73352 .28445 L
.77135 .28604 L
.81162 .28763 L
.85038 .28899 L
.89159 .29023 L
.93129 .29124 L
.96947 .29209 L
.97619 .29222 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05244 L
.09399 .05524 L
.10458 .05854 L
.11466 .06267 L
.1238 .06773 L
.12887 .07138 L
.13435 .07634 L
.13953 .08242 L
.14429 .08982 L
.14899 .09969 L
.15157 .1067 L
.15402 .1147 L
.15878 .13518 L
.16311 .16062 L
.16791 .19316 L
.17054 .20868 L
.17183 .21464 L
.17301 .21893 L
.17429 .22224 L
.17496 .22343 L
.17567 .22429 L
.17639 .22477 L
.17707 .22488 L
.17781 .22464 L
.1786 .22403 L
.17927 .22325 L
.18 .22215 L
.18131 .21961 L
.18378 .21343 L
.20326 .15475 L
.2086 .14221 L
.21433 .13089 L
.21971 .1222 L
.22469 .1157 L
.22975 .11058 L
Mistroke
.23264 .10829 L
.23526 .1066 L
.23759 .10539 L
.24011 .10438 L
.2415 .10396 L
.24278 .10364 L
.244 .10341 L
.24528 .10323 L
.24646 .10312 L
.24753 .10307 L
.24876 .10305 L
.24993 .10308 L
.25101 .10314 L
.252 .10321 L
.25426 .10345 L
.25903 .10412 L
.2615 .10454 L
.2641 .10505 L
.26644 .10563 L
.269 .10642 L
.27349 .10837 L
.27603 .10981 L
.27874 .11162 L
.28361 .11545 L
.29313 .1239 L
.3019 .13093 L
.31217 .13689 L
.31757 .13915 L
.32329 .14115 L
.33301 .14439 L
.33837 .14645 L
.34345 .14877 L
.35371 .15492 L
.36306 .16243 L
.38139 .18126 L
.41969 .22101 L
.46044 .25203 L
.49967 .27771 L
.53739 .29733 L
.55834 .30584 L
.57756 .31239 L
.61622 .32236 L
.63512 .32581 L
.65581 .32864 L
.67539 .33053 L
.68636 .33129 L
.69634 .33182 L
.70117 .33203 L
.7063 .33221 L
.71073 .33234 L
Mistroke
.7155 .33245 L
.71817 .3325 L
.72061 .33253 L
.72309 .33256 L
.72539 .33259 L
.72679 .3326 L
.72806 .3326 L
.72948 .33261 L
.73025 .33261 L
.73098 .33262 L
.73162 .33262 L
.73231 .33262 L
.73353 .33262 L
.73484 .33262 L
.73559 .33261 L
.73629 .33261 L
.73755 .33261 L
.73889 .3326 L
.7413 .33258 L
.74389 .33256 L
.74675 .33252 L
.75186 .33244 L
.75665 .33234 L
.76559 .33211 L
.77521 .33178 L
.79527 .33091 L
.81637 .32974 L
.8545 .32715 L
.89508 .32394 L
.93415 .32064 L
.97567 .31707 L
.97619 .31702 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05238 L
.09399 .05516 L
.10458 .05843 L
.11466 .06251 L
.1238 .0675 L
.12887 .07108 L
.13435 .07592 L
.13953 .08184 L
.14429 .08899 L
.14899 .09844 L
.15157 .10509 L
.15402 .11263 L
.15878 .13172 L
.16311 .15511 L
.16791 .18506 L
.17054 .19966 L
.17183 .20543 L
.17301 .20969 L
.17429 .21311 L
.17496 .2144 L
.17567 .21539 L
.17639 .21603 L
.17707 .2163 L
.17781 .21625 L
.1786 .21584 L
.17927 .21522 L
.18 .2143 L
.18131 .21205 L
.18378 .2063 L
.20326 .14667 L
.2086 .13345 L
.21433 .1215 L
.21971 .11233 L
.22469 .1055 L
.22975 .10009 L
Mistroke
.23264 .09764 L
.23526 .0958 L
.23759 .09443 L
.24011 .09323 L
.24278 .09225 L
.24528 .09157 L
.24756 .09112 L
.24885 .09093 L
.25006 .09079 L
.25249 .09059 L
.25385 .0905 L
.25509 .09044 L
.25731 .09033 L
.25848 .09026 L
.25972 .09017 L
.26199 .08996 L
.2641 .08969 L
.26649 .08927 L
.269 .08871 L
.27349 .08742 L
.28361 .0838 L
.28854 .08209 L
.2932 .0807 L
.29773 .07957 L
.3019 .07875 L
.3065 .07804 L
.30887 .07775 L
.31147 .07748 L
.31643 .07709 L
.31915 .07693 L
.32168 .07682 L
.32406 .07674 L
.32523 .07671 L
.32632 .07668 L
.32728 .07666 L
.32834 .07665 L
.32941 .07664 L
.33055 .07663 L
.33178 .07663 L
.33291 .07664 L
.33415 .07665 L
.33545 .07666 L
.33659 .07668 L
.33765 .07671 L
.34006 .07677 L
.34268 .07687 L
.3451 .07699 L
.35057 .07734 L
.35539 .07775 L
.36049 .0783 L
Mistroke
.36934 .0795 L
.37907 .08118 L
.41938 .08975 L
.45817 .097 L
.49942 .10387 L
.53915 .10967 L
.57736 .11412 L
.61802 .11777 L
.65717 .12028 L
.6786 .12129 L
.69878 .12203 L
.71887 .1226 L
.73735 .12299 L
.75619 .12327 L
.76688 .12339 L
.77685 .12347 L
.78187 .12351 L
.78732 .12354 L
.79212 .12356 L
.79722 .12358 L
.80181 .12359 L
.80442 .1236 L
.80687 .1236 L
.80911 .1236 L
.81116 .12361 L
.81223 .12361 L
.81341 .12361 L
.81464 .12361 L
.81578 .12361 L
.81706 .12361 L
.81771 .12361 L
.81841 .12361 L
.81967 .12361 L
.82084 .12361 L
.82222 .12361 L
.82348 .1236 L
.82632 .1236 L
.82876 .1236 L
.83142 .12359 L
.83626 .12358 L
.84591 .12355 L
.85485 .12352 L
.87543 .12341 L
.89405 .12328 L
.93419 .12296 L
.97281 .12262 L
.97619 .12259 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .0468 L
.06244 .04855 L
.08259 .05226 L
.09399 .055 L
.10458 .05821 L
.11466 .0622 L
.1238 .06704 L
.12887 .07049 L
.13435 .07512 L
.13953 .08071 L
.14429 .08737 L
.14899 .09604 L
.15402 .10872 L
.15878 .12527 L
.16311 .14498 L
.1682 .17134 L
.17088 .1837 L
.17234 .18912 L
.17372 .19308 L
.17492 .19552 L
.17621 .19713 L
.1769 .19755 L
.17763 .19769 L
.17895 .19716 L
.18014 .19592 L
.18125 .19418 L
.18378 .18859 L
.20251 .12805 L
.20764 .11448 L
.21308 .10287 L
.21772 .09513 L
.22282 .08866 L
.22814 .08385 L
.23112 .08188 L
.23385 .08047 L
.23638 .07946 L
.23772 .07904 L
Mistroke
.23914 .07866 L
.24051 .07836 L
.24175 .07814 L
.243 .07797 L
.24417 .07785 L
.24534 .07777 L
.24662 .07773 L
.24727 .07772 L
.24796 .07772 L
.24922 .07775 L
.25046 .07781 L
.25164 .07789 L
.25385 .07811 L
.25883 .07875 L
.26147 .07912 L
.26432 .07948 L
.26559 .07961 L
.26693 .07973 L
.26807 .07981 L
.26931 .07987 L
.27049 .0799 L
.27174 .0799 L
.27293 .07987 L
.274 .07981 L
.27532 .07971 L
.27654 .07959 L
.27787 .07941 L
.27928 .07917 L
.28427 .07802 L
.28881 .0766 L
.29305 .07505 L
.3027 .07135 L
.31314 .06787 L
.31827 .06651 L
.32303 .06548 L
.33191 .06405 L
.33659 .06351 L
.34158 .06307 L
.34646 .06275 L
.35093 .06252 L
.35585 .06233 L
.36102 .06217 L
.36554 .06207 L
.36975 .062 L
.3793 .06187 L
.3898 .06177 L
.39496 .06173 L
.39973 .0617 L
.40397 .06168 L
.40864 .06166 L
Mistroke
.4109 .06165 L
.41333 .06164 L
.41468 .06164 L
.4159 .06164 L
.41706 .06164 L
.41831 .06163 L
.4196 .06163 L
.42081 .06163 L
.42199 .06163 L
.42308 .06163 L
.42426 .06163 L
.42555 .06163 L
.4262 .06164 L
.4269 .06164 L
.42816 .06164 L
.43062 .06164 L
.43295 .06165 L
.43731 .06166 L
.44247 .06168 L
.44724 .06171 L
.45804 .06178 L
.49732 .06213 L
.53509 .06251 L
.57532 .06288 L
.61402 .06319 L
.65518 .06344 L
.67573 .06355 L
.69483 .06362 L
.73296 .06374 L
.75343 .06379 L
.77202 .06382 L
.79122 .06385 L
.80113 .06386 L
.81202 .06387 L
.83191 .06388 L
.84279 .06389 L
.85296 .06389 L
.85795 .06389 L
.86338 .06389 L
.86817 .06389 L
.87326 .06389 L
.87832 .06389 L
.88289 .0639 L
.8851 .0639 L
.88748 .0639 L
.88974 .0639 L
.89181 .0639 L
.89308 .0639 L
.89428 .0639 L
.89536 .0639 L
Mistroke
.89653 .0639 L
.8978 .0639 L
.89844 .0639 L
.89915 .0639 L
.9004 .0639 L
.90158 .0639 L
.90275 .0639 L
.90387 .0639 L
.90596 .0639 L
.90822 .0639 L
.91068 .0639 L
.91587 .06389 L
.92141 .06389 L
.93137 .06389 L
.95277 .06389 L
.97294 .06389 L
.97619 .06389 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03774 L
.03397 .039 L
.03527 .04014 L
.0379 .04189 L
.04033 .04304 L
.04262 .04384 L
.04517 .04454 L
.04761 .04507 L
.05217 .04588 L
.06244 .04737 L
.07302 .04896 L
.08429 .05093 L
.09474 .05314 L
.10458 .0557 L
.1142 .05882 L
.12461 .06322 L
.13407 .06864 L
.14277 .07552 L
.15263 .08664 L
.15805 .0945 L
.16319 .10233 L
.16551 .10544 L
.16678 .10689 L
.16797 .10802 L
.16925 .10894 L
.16994 .10928 L
.17067 .10954 L
.17197 .10967 L
.17317 .10942 L
.17426 .10888 L
.17528 .10813 L
.1764 .10704 L
.1776 .1056 L
.18226 .09815 L
.18717 .0892 L
.19249 .08041 L
.19719 .07417 L
.20215 .06917 L
.20663 .06589 L
.20918 .06446 L
.21156 .06337 L
.21574 .06194 L
.21809 .06137 L
.22023 .06097 L
Mistroke
.22152 .06079 L
.22274 .06064 L
.22383 .06054 L
.22501 .06046 L
.2263 .06039 L
.22695 .06037 L
.22767 .06036 L
.22893 .06035 L
.2301 .06037 L
.23129 .0604 L
.23242 .06045 L
.23343 .06051 L
.23452 .06059 L
.23698 .06082 L
.23926 .06109 L
.24404 .06182 L
.24932 .06284 L
.25999 .06535 L
.26944 .06754 L
.27419 .06839 L
.27688 .06875 L
.27808 .06888 L
.27938 .06899 L
.28012 .06904 L
.2808 .06909 L
.28144 .06912 L
.28214 .06915 L
.28336 .06918 L
.28465 .06919 L
.28538 .06918 L
.28605 .06917 L
.28682 .06915 L
.28756 .06912 L
.28886 .06904 L
.29027 .06894 L
.29278 .06868 L
.29545 .06833 L
.30025 .06752 L
.31992 .0634 L
.32853 .06188 L
.33342 .06118 L
.33797 .06064 L
.34738 .0598 L
.35217 .05948 L
.35729 .05921 L
.36821 .05878 L
.37814 .05846 L
.41809 .05725 L
.43638 .05677 L
.45652 .05639 L
Mistroke
.47637 .05612 L
.49741 .05591 L
.53772 .05558 L
.57651 .05535 L
.59766 .05525 L
.61775 .05518 L
.65596 .05506 L
.69663 .05497 L
.73578 .0549 L
.77738 .05485 L
.81747 .05481 L
.85604 .05478 L
.89706 .05475 L
.93657 .05473 L
.97456 .05471 L
.97619 .05471 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04864 L
.08259 .05245 L
.09399 .05525 L
.10458 .05856 L
.11466 .0627 L
.1238 .06778 L
.12887 .07144 L
.13435 .07642 L
.13953 .08255 L
.14429 .09002 L
.14899 .10003 L
.15162 .1073 L
.15402 .11533 L
.15869 .13596 L
.16311 .16299 L
.16791 .19769 L
.17054 .21462 L
.17183 .22127 L
.17301 .22617 L
.17429 .23009 L
.17496 .23159 L
.17567 .23276 L
.17639 .23355 L
.17707 .23394 L
.17781 .234 L
.1786 .2337 L
.17927 .23317 L
.18 .23235 L
.18131 .23029 L
.18378 .225 L
.19317 .19895 L
.20326 .17474 L
.20905 .16464 L
.21433 .15797 L
.21688 .15566 L
.21822 .1547 L
Mistroke
.21965 .15387 L
.22036 .15354 L
.22102 .15328 L
.22227 .15292 L
.22343 .15275 L
.22469 .15275 L
.22589 .15294 L
.22716 .15336 L
.22837 .15398 L
.22946 .15475 L
.23075 .15592 L
.23215 .15756 L
.23469 .16166 L
.23595 .16433 L
.23735 .16785 L
.24017 .17723 L
.24278 .1894 L
.24523 .20494 L
.24754 .22441 L
.24997 .25107 L
.25432 .31552 L
.25944 .40562 L
.2641 .47482 L
.26646 .50015 L
.26771 .51063 L
.26902 .51967 L
.27018 .526 L
.27144 .53138 L
.27259 .53501 L
.27367 .53741 L
.27499 .53923 L
.27624 .53994 L
.27737 .53987 L
.27859 .53912 L
.27923 .5385 L
.27992 .53764 L
.28134 .53544 L
.28388 .5302 L
.30226 .47868 L
.30716 .46739 L
.31234 .45805 L
.31675 .45228 L
.31925 .44991 L
.32158 .44826 L
.32288 .44757 L
.32357 .44727 L
.32429 .44701 L
.32493 .44681 L
.32563 .44664 L
.32686 .44644 L
Mistroke
.32805 .44637 L
.32934 .44643 L
.33055 .4466 L
.33166 .44685 L
.33303 .44729 L
.3343 .4478 L
.33718 .44933 L
.34243 .45314 L
.35158 .46141 L
.36124 .46959 L
.36629 .47275 L
.36916 .47407 L
.37053 .47458 L
.37184 .47499 L
.37301 .47529 L
.3743 .47555 L
.37546 .47572 L
.37654 .47583 L
.3777 .47589 L
.37898 .47589 L
.37963 .47586 L
.38032 .47582 L
.38158 .47569 L
.38223 .4756 L
.38293 .47549 L
.38418 .47524 L
.38703 .47448 L
.39003 .47341 L
.39276 .47224 L
.40301 .46663 L
.42318 .45419 L
.43251 .44926 L
.44238 .44499 L
.45321 .44138 L
.46318 .43884 L
.48277 .43513 L
.50109 .43224 L
.51968 .42953 L
.53993 .42699 L
.55093 .42588 L
.56112 .42503 L
.57079 .42438 L
.58123 .42383 L
.59184 .4234 L
.60181 .4231 L
.61152 .42288 L
.62043 .42273 L
.62515 .42267 L
.6302 .42262 L
.63497 .42258 L
Mistroke
.63931 .42255 L
.64196 .42254 L
.64441 .42253 L
.64568 .42253 L
.64709 .42253 L
.6478 .42253 L
.64856 .42253 L
.64928 .42252 L
.64994 .42252 L
.65122 .42252 L
.6524 .42252 L
.6537 .42252 L
.65443 .42253 L
.65509 .42253 L
.6563 .42253 L
.65762 .42253 L
.65999 .42254 L
.66236 .42255 L
.6649 .42256 L
.66949 .42258 L
.67992 .42266 L
.69094 .42277 L
.70098 .4229 L
.74082 .42349 L
.77913 .42408 L
.8199 .42465 L
.85916 .42509 L
.8969 .42542 L
.93709 .42567 L
.97576 .42584 L
.97619 .42585 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04114 L
.0379 .04199 L
.04033 .04318 L
.04262 .04401 L
.04761 .0453 L
.05217 .04616 L
.06244 .04776 L
.08259 .05117 L
.09399 .05366 L
.10458 .05657 L
.11466 .06011 L
.1238 .06432 L
.12887 .06724 L
.13435 .07107 L
.14429 .08066 L
.16384 .11763 L
.16659 .12398 L
.16919 .12895 L
.17063 .13098 L
.17144 .13184 L
.17219 .13244 L
.17283 .1328 L
.17352 .13302 L
.17425 .13307 L
.17493 .13295 L
.1762 .13229 L
.17684 .13176 L
.17753 .13104 L
.17992 .12761 L
.1827 .12218 L
.18529 .11635 L
.19511 .09438 L
.19994 .08577 L
.20438 .07945 L
.20951 .07395 L
.21221 .07171 L
.21507 .06977 L
.21969 .06744 L
.22232 .06648 L
.22478 .06578 L
.22736 .06524 L
.22976 .06488 L
Mistroke
.23114 .06474 L
.23239 .06464 L
.23308 .0646 L
.23383 .06456 L
.23454 .06453 L
.23519 .06452 L
.23637 .0645 L
.23748 .06451 L
.23869 .06453 L
.23999 .06458 L
.24136 .06465 L
.24265 .06473 L
.24507 .06491 L
.24938 .06529 L
.25174 .06548 L
.25395 .06562 L
.2551 .06567 L
.25634 .06571 L
.25701 .06572 L
.25771 .06572 L
.25897 .06571 L
.26012 .06568 L
.26118 .06564 L
.26235 .06557 L
.2636 .06549 L
.28499 .06343 L
.30515 .0611 L
.32351 .05871 L
.33393 .05769 L
.34367 .057 L
.35328 .05652 L
.36359 .05615 L
.3746 .05586 L
.38464 .05565 L
.4037 .05535 L
.41448 .05523 L
.41928 .05519 L
.42446 .05515 L
.42947 .05512 L
.43407 .05509 L
.43846 .05508 L
.4431 .05506 L
.44556 .05506 L
.44819 .05505 L
.45046 .05505 L
.45293 .05504 L
.45443 .05504 L
.45583 .05504 L
.45713 .05504 L
.45856 .05504 L
Mistroke
.45985 .05504 L
.46105 .05504 L
.46232 .05504 L
.46304 .05504 L
.46369 .05504 L
.46498 .05504 L
.46619 .05504 L
.46728 .05504 L
.46846 .05504 L
.47111 .05504 L
.47354 .05504 L
.48269 .05505 L
.50342 .05507 L
.54293 .05511 L
.58092 .05517 L
.62136 .05523 L
.66029 .05527 L
.70167 .05532 L
.74154 .05535 L
.77989 .05538 L
.82069 .0554 L
.85997 .05542 L
.89774 .05544 L
.93797 .05546 L
.97619 .05547 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04035 L
.03652 .0413 L
.0379 .04217 L
.04033 .04338 L
.04262 .04424 L
.04761 .04557 L
.05217 .04646 L
.06244 .04811 L
.08259 .05162 L
.09399 .0542 L
.10458 .05721 L
.11466 .0609 L
.1238 .0653 L
.12887 .06839 L
.13435 .07245 L
.14429 .08279 L
.16384 .12549 L
.16659 .13354 L
.16919 .14019 L
.17063 .1431 L
.17139 .14435 L
.17219 .14544 L
.17287 .14615 L
.17362 .14671 L
.17493 .14714 L
.17559 .14709 L
.17627 .14684 L
.1775 .14595 L
.17819 .14522 L
.17883 .1444 L
.18028 .1421 L
.18529 .13089 L
.19511 .10601 L
.19994 .09584 L
.20438 .08822 L
.20951 .08145 L
.21216 .0787 L
.21507 .07619 L
.21979 .07313 L
.22237 .0719 L
.22478 .07099 L
.22736 .07025 L
.22976 .06976 L
Mistroke
.23114 .06955 L
.23239 .06941 L
.23308 .06935 L
.23383 .06929 L
.23454 .06926 L
.23519 .06923 L
.23637 .06921 L
.23748 .06922 L
.23869 .06926 L
.23999 .06933 L
.24065 .06938 L
.24136 .06944 L
.24265 .06957 L
.24507 .0699 L
.24974 .07074 L
.2547 .07185 L
.2636 .07411 L
.273 .0767 L
.27557 .07733 L
.27828 .07787 L
.28059 .07822 L
.2819 .07836 L
.28311 .07845 L
.28426 .0785 L
.2855 .07851 L
.28667 .07849 L
.28775 .07844 L
.28873 .07836 L
.2898 .07825 L
.29196 .07795 L
.29432 .0775 L
.29685 .0769 L
.30141 .07557 L
.32119 .06883 L
.33163 .06593 L
.34273 .06365 L
.35256 .06223 L
.36341 .06111 L
.37328 .06038 L
.38255 .05986 L
.39236 .05942 L
.40271 .05905 L
.4212 .05852 L
.43073 .05831 L
.44092 .05813 L
.45047 .05799 L
.45928 .05788 L
.46951 .05779 L
.4806 .05772 L
.49038 .05767 L
Mistroke
.50074 .05763 L
.51017 .0576 L
.52029 .05758 L
.52986 .05756 L
.5386 .05755 L
.54337 .05754 L
.54845 .05754 L
.55325 .05754 L
.5576 .05753 L
.56027 .05753 L
.56273 .05753 L
.56402 .05753 L
.56543 .05753 L
.56614 .05753 L
.5669 .05753 L
.56762 .05753 L
.56828 .05753 L
.56957 .05753 L
.57025 .05753 L
.57098 .05753 L
.57219 .05753 L
.57289 .05753 L
.57354 .05753 L
.57474 .05753 L
.57584 .05753 L
.57833 .05753 L
.58082 .05753 L
.58307 .05753 L
.58814 .05754 L
.59727 .05754 L
.60792 .05755 L
.61797 .05756 L
.65646 .05759 L
.6974 .05764 L
.73682 .05769 L
.77473 .05774 L
.81509 .05778 L
.85393 .05782 L
.89523 .05785 L
.93501 .05788 L
.97327 .05791 L
.97619 .05791 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04685 L
.06244 .04865 L
.08259 .05246 L
.09399 .05527 L
.10458 .05859 L
.11466 .06274 L
.1238 .06784 L
.12887 .07152 L
.13435 .07653 L
.13953 .08269 L
.14429 .09022 L
.14899 .10032 L
.15162 .10767 L
.15402 .11578 L
.15869 .13664 L
.16311 .16386 L
.16791 .19831 L
.16918 .20668 L
.17054 .21466 L
.17174 .22053 L
.17301 .22537 L
.17367 .22733 L
.1744 .22902 L
.17567 .23091 L
.1764 .23141 L
.17719 .2315 L
.17793 .23122 L
.1786 .23068 L
.17988 .22901 L
.1806 .22775 L
.18126 .22642 L
.18378 .22027 L
.19359 .19096 L
.199 .17632 L
.20413 .16461 L
.20889 .15573 L
.21409 .14816 L
Mistroke
.21637 .14553 L
.2188 .14321 L
.2211 .14149 L
.22318 .14033 L
.22431 .13987 L
.22556 .1395 L
.22686 .13929 L
.22807 .13926 L
.22921 .13937 L
.23024 .13961 L
.23143 .14006 L
.23256 .14065 L
.23379 .14151 L
.23509 .14267 L
.23742 .14551 L
.23993 .14985 L
.2427 .15655 L
.24508 .1644 L
.24726 .17371 L
.24966 .18685 L
.25218 .20459 L
.25643 .24473 L
.26107 .30181 L
.26592 .36826 L
.27118 .43304 L
.27359 .45662 L
.27614 .47641 L
.27832 .48917 L
.27955 .49479 L
.28072 .49915 L
.28215 .50333 L
.28346 .50611 L
.28419 .50728 L
.28486 .50814 L
.28561 .50885 L
.2864 .50935 L
.2877 .50968 L
.28892 .50949 L
.28962 .50919 L
.29026 .50881 L
.29171 .50763 L
.29402 .50496 L
.29656 .50132 L
.30168 .49302 L
.30695 .48481 L
.30955 .48133 L
.31194 .47858 L
.31407 .47654 L
.31641 .47477 L
.31763 .47406 L
Mistroke
.31877 .47352 L
.31997 .47309 L
.32127 .47278 L
.32194 .47269 L
.32266 .47263 L
.32395 .47266 L
.32474 .47275 L
.32548 .47289 L
.32615 .47307 L
.32688 .47329 L
.32823 .47385 L
.32965 .4746 L
.3322 .47636 L
.33697 .48089 L
.34221 .48728 L
.35308 .50252 L
.35842 .50958 L
.36337 .51519 L
.36785 .51928 L
.37261 .52247 L
.37507 .52365 L
.37738 .52449 L
.37871 .52485 L
.37992 .52511 L
.38125 .52531 L
.38192 .52539 L
.38265 .52545 L
.38391 .52551 L
.38463 .52551 L
.38528 .5255 L
.38649 .52544 L
.38776 .52532 L
.38891 .52517 L
.38998 .525 L
.39241 .52449 L
.39743 .52304 L
.40282 .5211 L
.42158 .51399 L
.43172 .51117 L
.43746 .51003 L
.44277 .50924 L
.44788 .50869 L
.45251 .50834 L
.45508 .50819 L
.45785 .50806 L
.46288 .50787 L
.47235 .50762 L
.48248 .5073 L
.4883 .50705 L
.49359 .50677 L
Mistroke
.50395 .50607 L
.54351 .50278 L
.58343 .50026 L
.62183 .49834 L
.66269 .49644 L
.70202 .49477 L
.73985 .49326 L
.78012 .4917 L
.81888 .49023 L
.86009 .48871 L
.89979 .48726 L
.93797 .48589 L
.97619 .48455 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05244 L
.09399 .05524 L
.10458 .05855 L
.11466 .06268 L
.1238 .06775 L
.12887 .07139 L
.13435 .07636 L
.13953 .08245 L
.14429 .08986 L
.14899 .09976 L
.15157 .10678 L
.15402 .11481 L
.15878 .13536 L
.16311 .16084 L
.16791 .19329 L
.16918 .20113 L
.17054 .20859 L
.17174 .21406 L
.17301 .21854 L
.17367 .22034 L
.1744 .22187 L
.17567 .22351 L
.1764 .22389 L
.17719 .22387 L
.17793 .22348 L
.1786 .22284 L
.17988 .22099 L
.18126 .2182 L
.18378 .21165 L
.19317 .18144 L
.20326 .15247 L
.20905 .13934 L
.21433 .12954 L
.21971 .1216 L
.22469 .11595 L
Mistroke
.22938 .11206 L
.232 .11047 L
.23437 .10938 L
.23573 .1089 L
.23698 .10856 L
.23769 .10841 L
.23835 .1083 L
.23904 .10821 L
.2398 .10814 L
.24109 .10811 L
.24227 .10817 L
.24292 .10824 L
.24362 .10834 L
.24491 .10861 L
.2461 .10895 L
.24721 .10934 L
.24975 .11054 L
.25222 .11209 L
.25488 .1142 L
.25969 .11932 L
.2641 .1259 L
.26885 .1355 L
.27393 .14855 L
.28306 .17602 L
.2883 .19125 L
.29384 .20508 L
.29858 .2145 L
.30377 .22235 L
.30908 .22814 L
.31404 .23208 L
.32516 .23874 L
.33481 .24521 L
.34027 .25002 L
.34532 .25543 L
.35576 .26945 L
.36565 .28544 L
.3842 .31619 L
.40284 .34016 L
.41346 .34995 L
.42343 .35732 L
.46209 .37934 L
.48171 .38886 L
.5032 .39745 L
.5237 .40364 L
.54279 .40798 L
.56322 .41155 L
.5818 .41405 L
.60096 .41597 L
.61178 .41677 L
.62175 .41734 L
Mistroke
.62642 .41755 L
.63143 .41774 L
.63576 .41788 L
.64049 .41801 L
.64336 .41807 L
.64602 .41812 L
.64877 .41816 L
.65127 .41819 L
.65245 .4182 L
.65373 .41821 L
.65483 .41821 L
.65604 .41822 L
.65733 .41822 L
.65803 .41823 L
.65869 .41823 L
.65986 .41823 L
.66112 .41823 L
.66234 .41823 L
.66304 .41823 L
.66369 .41822 L
.665 .41822 L
.66641 .41821 L
.66897 .41819 L
.67131 .41817 L
.6767 .41809 L
.68238 .41799 L
.69199 .41774 L
.7025 .41739 L
.72213 .41653 L
.74308 .41534 L
.7846 .41236 L
.8246 .40893 L
.86309 .40529 L
.90403 .4012 L
.94345 .39719 L
.97619 .39387 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .05241 L
.09399 .0552 L
.10458 .05849 L
.11466 .0626 L
.1238 .06763 L
.12887 .07125 L
.13435 .07616 L
.13953 .08217 L
.14429 .08948 L
.14899 .09922 L
.15157 .10612 L
.15402 .114 L
.15878 .13425 L
.16311 .15969 L
.16791 .19336 L
.17054 .21037 L
.17301 .22258 L
.17429 .22704 L
.17501 .22897 L
.17567 .23037 L
.17635 .23148 L
.1771 .23229 L
.17788 .23275 L
.1786 .23283 L
.17991 .23224 L
.1811 .231 L
.18176 .23008 L
.18248 .22891 L
.18378 .22643 L
.19317 .2024 L
.20326 .17822 L
.20905 .16759 L
.21433 .16031 L
.21688 .15771 L
.21822 .1566 L
Mistroke
.21965 .15561 L
.22102 .15488 L
.22227 .1544 L
.22352 .15411 L
.22469 .15402 L
.22588 .15412 L
.22699 .15439 L
.2282 .15492 L
.2295 .15576 L
.23086 .15697 L
.23215 .15847 L
.23457 .16232 L
.23683 .16742 L
.23891 .17372 L
.2412 .18288 L
.24364 .19587 L
.24605 .21315 L
.24866 .23785 L
.25337 .30039 L
.25893 .38885 L
.26164 .42652 L
.2641 .45378 L
.26525 .46396 L
.26649 .47316 L
.26756 .47963 L
.26874 .48523 L
.26999 .48956 L
.27068 .49128 L
.27132 .49249 L
.27246 .4938 L
.27369 .49407 L
.27439 .49376 L
.27504 .49319 L
.27575 .49229 L
.27651 .49104 L
.27778 .48832 L
.27918 .48455 L
.28418 .46651 L
.30529 .37536 L
.32461 .31329 L
.33548 .2882 L
.34546 .27021 L
.36436 .2461 L
.37508 .23608 L
.38505 .22782 L
.42407 .19878 L
.44539 .18643 L
.45517 .18203 L
.46553 .17821 L
.47505 .17535 L
Mistroke
.48552 .17279 L
.50397 .16937 L
.52339 .1667 L
.54427 .16456 L
.55439 .16375 L
.56542 .16301 L
.57596 .16246 L
.58552 .16207 L
.59566 .16175 L
.6052 .16154 L
.61046 .16146 L
.61528 .1614 L
.62059 .16135 L
.62325 .16133 L
.62618 .16131 L
.6287 .1613 L
.63012 .1613 L
.63143 .1613 L
.63257 .1613 L
.63384 .16129 L
.63516 .16129 L
.6364 .16129 L
.63754 .1613 L
.63874 .1613 L
.63976 .1613 L
.64088 .1613 L
.64338 .16131 L
.64571 .16132 L
.65101 .16135 L
.65582 .16139 L
.66663 .1615 L
.68583 .16178 L
.70663 .16217 L
.74757 .16308 L
.78699 .16402 L
.8249 .16488 L
.86526 .16572 L
.9041 .16642 L
.9454 .16708 L
.97619 .16752 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .0435 L
.04262 .04438 L
.04761 .04575 L
.05217 .04666 L
.06244 .04834 L
.08259 .05193 L
.09399 .05456 L
.10458 .05764 L
.11466 .06143 L
.1238 .06598 L
.12887 .06917 L
.13435 .0734 L
.14429 .08424 L
.16384 .13064 L
.16659 .13982 L
.16919 .14761 L
.17063 .15113 L
.17139 .15269 L
.17219 .15408 L
.17287 .15503 L
.17362 .15583 L
.17493 .15661 L
.17559 .15669 L
.17627 .15657 L
.1775 .15582 L
.17819 .15512 L
.17883 .15432 L
.18028 .15196 L
.1827 .14668 L
.18529 .13982 L
.19593 .10952 L
.20116 .09732 L
.20598 .08839 L
.21036 .0821 L
.215 .07709 L
.21966 .07348 L
.2223 .07196 L
.22478 .07082 L
.22736 .06991 L
.22976 .06927 L
Mistroke
.23114 .06899 L
.23239 .06878 L
.23383 .06859 L
.23448 .06853 L
.23519 .06847 L
.23639 .0684 L
.23766 .06836 L
.23884 .06835 L
.23994 .06837 L
.24123 .06842 L
.24241 .0685 L
.24378 .06862 L
.24507 .06876 L
.24968 .06946 L
.25395 .07032 L
.2636 .07266 L
.26825 .07369 L
.27069 .07415 L
.27326 .07453 L
.27435 .07466 L
.27551 .07478 L
.27679 .07487 L
.27798 .07493 L
.27915 .07497 L
.28025 .07497 L
.28124 .07495 L
.28231 .07491 L
.28359 .07483 L
.28479 .07472 L
.28611 .07457 L
.28752 .07437 L
.29041 .07386 L
.29304 .07327 L
.30292 .07044 L
.31294 .06735 L
.32359 .06464 L
.33269 .063 L
.33787 .06231 L
.34273 .0618 L
.34741 .06141 L
.35234 .06108 L
.36116 .06065 L
.37064 .0603 L
.38103 .05997 L
.40226 .0593 L
.42156 .05875 L
.43118 .05851 L
.44162 .0583 L
.46057 .05802 L
.47002 .05791 L
Mistroke
.48043 .05781 L
.50146 .05763 L
.52251 .05749 L
.54177 .05737 L
.58056 .05721 L
.59956 .05714 L
.62029 .05709 L
.66095 .057 L
.7001 .05693 L
.74171 .05688 L
.78179 .05684 L
.82036 .05681 L
.86139 .05678 L
.90089 .05675 L
.93888 .05673 L
.97619 .0567 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05239 L
.09399 .05517 L
.10458 .05846 L
.11466 .06255 L
.1238 .06756 L
.12887 .07116 L
.13435 .07604 L
.13953 .082 L
.14429 .08922 L
.14899 .09879 L
.15157 .10554 L
.15402 .11321 L
.15878 .13266 L
.16311 .15652 L
.16791 .18685 L
.17054 .20136 L
.17183 .20698 L
.17301 .21105 L
.17429 .21422 L
.17496 .21536 L
.17567 .21619 L
.17639 .21666 L
.17707 .21677 L
.17781 .21655 L
.1786 .21596 L
.17927 .21519 L
.18 .21412 L
.18131 .21162 L
.18378 .20548 L
.20326 .14574 L
.2086 .13302 L
.21433 .1217 L
.21971 .11315 L
.22469 .10685 L
.22975 .10193 L
Mistroke
.23264 .09973 L
.23526 .09809 L
.23759 .0969 L
.24011 .09587 L
.2415 .09542 L
.24278 .09506 L
.24399 .09478 L
.24528 .09453 L
.24647 .09435 L
.24754 .09422 L
.24863 .09412 L
.24965 .09405 L
.25084 .09399 L
.25195 .09395 L
.25316 .09393 L
.25444 .09391 L
.25558 .09389 L
.25681 .09388 L
.25797 .09385 L
.25903 .09381 L
.26021 .09376 L
.2615 .09368 L
.26285 .09357 L
.2641 .09345 L
.26916 .0928 L
.27465 .09199 L
.27717 .09168 L
.27854 .09154 L
.27983 .09144 L
.28092 .09136 L
.2821 .09131 L
.2834 .09127 L
.2846 .09126 L
.28575 .09128 L
.28697 .09132 L
.28801 .09137 L
.28917 .09144 L
.29173 .09167 L
.29414 .09195 L
.3032 .09334 L
.32165 .09614 L
.33211 .09755 L
.34185 .09918 L
.35152 .10143 L
.36187 .10477 L
.37291 .10945 L
.38296 .11449 L
.42291 .13526 L
.46134 .15068 L
.50223 .1647 L
Mistroke
.5416 .17552 L
.57945 .18308 L
.59888 .18605 L
.61976 .1886 L
.64091 .19057 L
.65064 .19128 L
.66101 .19191 L
.6714 .19242 L
.68083 .19278 L
.6903 .19307 L
.69922 .19326 L
.70388 .19333 L
.70899 .19339 L
.71157 .19342 L
.71433 .19344 L
.71567 .19344 L
.71694 .19345 L
.71807 .19345 L
.71931 .19346 L
.72046 .19346 L
.72154 .19346 L
.72268 .19346 L
.72391 .19346 L
.72499 .19346 L
.72613 .19346 L
.7271 .19346 L
.72816 .19345 L
.73058 .19344 L
.73315 .19343 L
.73779 .19339 L
.74312 .19333 L
.74804 .19326 L
.75915 .19306 L
.77931 .19255 L
.81873 .19112 L
.85664 .18941 L
.897 .18738 L
.93584 .18535 L
.97619 .18327 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04034 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04552 L
.05217 .04638 L
.06244 .04799 L
.08259 .05144 L
.09399 .05397 L
.10458 .05691 L
.11466 .0605 L
.1238 .06476 L
.12887 .06772 L
.13435 .07159 L
.14429 .08127 L
.16384 .11818 L
.16659 .12446 L
.16919 .12935 L
.17063 .13132 L
.17144 .13215 L
.17219 .13273 L
.17283 .13305 L
.17352 .13325 L
.17425 .13326 L
.17493 .1331 L
.1762 .13238 L
.17684 .13182 L
.17753 .13105 L
.17992 .12747 L
.1827 .12185 L
.18529 .11588 L
.19 .10469 L
.19511 .09371 L
.19962 .0857 L
.20438 .07901 L
.20703 .07602 L
.20994 .07328 L
.21241 .07134 L
.21507 .06962 L
.21769 .06825 L
.22009 .06724 L
.2225 .06644 L
Mistroke
.22478 .06585 L
.22599 .0656 L
.22729 .06538 L
.22837 .06522 L
.22956 .06509 L
.23085 .06498 L
.23156 .06493 L
.23221 .0649 L
.23339 .06486 L
.23465 .06485 L
.23583 .06486 L
.23711 .06491 L
.23832 .06497 L
.23944 .06505 L
.24156 .06526 L
.2438 .06554 L
.24889 .06639 L
.25367 .0674 L
.26454 .07001 L
.26965 .07107 L
.27214 .07147 L
.2744 .07177 L
.27555 .07189 L
.27679 .07199 L
.27811 .07207 L
.27935 .07211 L
.28 .07212 L
.28072 .07213 L
.28147 .07212 L
.28217 .07211 L
.28342 .07206 L
.28412 .07202 L
.28476 .07198 L
.28713 .07176 L
.28931 .07147 L
.29427 .07057 L
.30328 .06835 L
.31301 .06577 L
.32351 .06342 L
.32833 .06257 L
.33342 .06183 L
.34251 .06085 L
.34702 .0605 L
.35184 .06019 L
.36052 .05978 L
.37084 .05942 L
.38023 .05914 L
.40101 .05851 L
.42018 .05796 L
.43884 .05754 L
Mistroke
.44825 .05737 L
.45862 .05722 L
.47804 .057 L
.49892 .05682 L
.51865 .05667 L
.54017 .05654 L
.5799 .05634 L
.59958 .05627 L
.62056 .05621 L
.66216 .05611 L
.70225 .05603 L
.74082 .05598 L
.78184 .05593 L
.82135 .0559 L
.85934 .05587 L
.89979 .05584 L
.93872 .05582 L
.97619 .05579 L
Mfstroke
0 .206 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .0486 L
.08259 .05236 L
.09399 .05513 L
.10458 .0584 L
.11466 .06246 L
.1238 .06743 L
.12887 .07098 L
.13435 .0758 L
.13953 .08167 L
.14429 .08875 L
.14899 .09811 L
.15157 .10469 L
.15402 .11216 L
.15878 .13113 L
.16311 .1546 L
.16791 .18545 L
.17054 .20119 L
.17301 .2127 L
.17429 .21701 L
.17495 .21875 L
.17567 .22028 L
.17641 .22148 L
.1772 .22232 L
.17793 .22275 L
.1786 .22285 L
.17991 .22234 L
.1811 .22115 L
.18176 .22024 L
.18248 .21907 L
.18378 .21655 L
.20326 .16183 L
.2086 .14921 L
.21433 .13828 L
.21711 .13405 L
.21975 .13071 L
.22234 .12807 L
Mistroke
.22469 .12625 L
.22587 .12555 L
.22714 .12496 L
.22833 .12457 L
.22943 .12434 L
.2306 .12426 L
.23189 .12435 L
.23253 .12447 L
.23323 .12467 L
.23448 .12518 L
.23565 .12587 L
.23692 .12685 L
.23922 .12934 L
.24147 .13277 L
.24355 .13701 L
.24599 .14361 L
.24829 .15171 L
.25081 .16316 L
.25352 .1789 L
.25904 .2219 L
.2641 .26963 L
.26885 .31325 L
.27146 .33357 L
.27393 .34926 L
.27623 .36053 L
.27752 .36543 L
.27871 .36903 L
.27972 .37142 L
.28083 .3734 L
.28198 .37476 L
.28306 .37544 L
.28434 .37556 L
.28507 .37532 L
.28574 .37491 L
.28697 .37372 L
.28828 .37191 L
.29055 .36763 L
.29305 .36153 L
.30377 .3266 L
.31397 .29049 L
.32472 .25655 L
.33468 .23118 L
.34394 .21314 L
.35286 .20032 L
.3624 .19044 L
.37298 .18255 L
.3826 .17689 L
.42255 .15633 L
.44084 .14824 L
.45124 .14448 L
Mistroke
.46098 .14156 L
.48084 .13718 L
.49097 .13556 L
.50187 .13414 L
.52302 .13201 L
.54311 .13051 L
.55271 .12994 L
.56294 .12943 L
.57252 .12904 L
.58133 .12875 L
.59162 .12849 L
.59704 .12839 L
.60275 .1283 L
.6074 .12824 L
.61237 .12819 L
.61523 .12817 L
.61783 .12815 L
.62026 .12813 L
.62293 .12812 L
.62412 .12812 L
.62541 .12812 L
.62653 .12811 L
.62774 .12811 L
.62904 .12811 L
.62975 .12811 L
.63041 .12811 L
.63159 .12811 L
.63285 .12811 L
.63404 .12811 L
.63533 .12811 L
.63654 .12811 L
.63766 .12811 L
.63978 .12812 L
.64203 .12813 L
.64714 .12815 L
.65192 .12818 L
.66279 .12826 L
.67321 .12837 L
.6831 .1285 L
.70164 .12878 L
.7399 .12949 L
.78062 .13031 L
.81982 .1311 L
.86148 .13188 L
.90162 .13257 L
.94024 .13316 L
.97619 .13366 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04862 L
.08259 .0524 L
.09399 .05518 L
.10458 .05847 L
.11466 .06256 L
.1238 .06758 L
.12887 .07118 L
.13435 .07606 L
.13953 .08204 L
.14429 .08928 L
.14899 .09891 L
.15157 .10571 L
.15402 .11347 L
.15878 .13329 L
.16311 .15804 L
.16791 .19054 L
.17054 .20689 L
.17183 .21352 L
.17301 .21856 L
.17429 .22278 L
.17496 .22448 L
.17567 .22588 L
.17639 .22693 L
.17707 .22757 L
.17781 .22792 L
.1786 .22791 L
.17927 .22763 L
.18 .22706 L
.18131 .22543 L
.18259 .22321 L
.18378 .22073 L
.19359 .19341 L
.20413 .16548 L
.20924 .1548 L
.21409 .14672 L
.21844 .14131 L
Mistroke
.2209 .13906 L
.22318 .13753 L
.22442 .13694 L
.22556 .13655 L
.22682 .1363 L
.22745 .13624 L
.22814 .13624 L
.22931 .13638 L
.23056 .13674 L
.23174 .13729 L
.23281 .13799 L
.23393 .13892 L
.23496 .13999 L
.23729 .14323 L
.23935 .14719 L
.24153 .15279 L
.24384 .16068 L
.24633 .17207 L
.24867 .18631 L
.25082 .20292 L
.25582 .25538 L
.26107 .32306 L
.26599 .3812 L
.26841 .40361 L
.27064 .4198 L
.27186 .42689 L
.27321 .43324 L
.27456 .4382 L
.27531 .44038 L
.27599 .44203 L
.2772 .44424 L
.2785 .44566 L
.27971 .4462 L
.28085 .4461 L
.2819 .44554 L
.28306 .44447 L
.28428 .4429 L
.28542 .44105 L
.28965 .43189 L
.29923 .40446 L
.30814 .37826 L
.31768 .35416 L
.32316 .34283 L
.32814 .33422 L
.33321 .3271 L
.33788 .32189 L
.34282 .31768 L
.34817 .31438 L
.3529 .31233 L
.3579 .31076 L
Mistroke
.36806 .30843 L
.37367 .30707 L
.37899 .30544 L
.3892 .30111 L
.39854 .29576 L
.41684 .28304 L
.43689 .26954 L
.45506 .2601 L
.4652 .25611 L
.47475 .25304 L
.49572 .24796 L
.51582 .24433 L
.53429 .24165 L
.55313 .23951 L
.56382 .23857 L
.5738 .23787 L
.58426 .23729 L
.59417 .23689 L
.60306 .23662 L
.60808 .23651 L
.61273 .23642 L
.61737 .23636 L
.6198 .23633 L
.62237 .23631 L
.62462 .23629 L
.62708 .23628 L
.62817 .23627 L
.62932 .23627 L
.63042 .23627 L
.63141 .23626 L
.6327 .23626 L
.63334 .23626 L
.63406 .23626 L
.63532 .23626 L
.6365 .23626 L
.63721 .23626 L
.63789 .23627 L
.63916 .23627 L
.64052 .23627 L
.64201 .23628 L
.64453 .23629 L
.6472 .23631 L
.65202 .23635 L
.6574 .23641 L
.66234 .23648 L
.67348 .23667 L
.69367 .23713 L
.73323 .23831 L
.77127 .23959 L
.81177 .24096 L
Mistroke
.85075 .24218 L
.89218 .24337 L
.9321 .24438 L
.9705 .24525 L
.97619 .24538 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04684 L
.06244 .04863 L
.08259 .05243 L
.09399 .05522 L
.10458 .05853 L
.11466 .06265 L
.1238 .0677 L
.12887 .07134 L
.13435 .07628 L
.13953 .08234 L
.14429 .0897 L
.14899 .09953 L
.15157 .10648 L
.15402 .11442 L
.15878 .13472 L
.16311 .15985 L
.16791 .19186 L
.16918 .19961 L
.17054 .20701 L
.17174 .21245 L
.17301 .21692 L
.17367 .21872 L
.1744 .22026 L
.17567 .22194 L
.1764 .22234 L
.17719 .22234 L
.17793 .22198 L
.1786 .22136 L
.17988 .21956 L
.18126 .21681 L
.18378 .21032 L
.19317 .18012 L
.20326 .15128 L
.20905 .1385 L
.21433 .12926 L
.21688 .12562 L
.21965 .12222 L
Mistroke
.22207 .11973 L
.22469 .11753 L
.22609 .11656 L
.22737 .1158 L
.22857 .1152 L
.22989 .11467 L
.23108 .1143 L
.23218 .11406 L
.23335 .11391 L
.2346 .11386 L
.2353 .1139 L
.23596 .11397 L
.23667 .11408 L
.23743 .11426 L
.23871 .11468 L
.24012 .11532 L
.24136 .11606 L
.24271 .11705 L
.24514 .11941 L
.24745 .12241 L
.24996 .12667 L
.25259 .13241 L
.25504 .13914 L
.25942 .15522 L
.2641 .17891 L
.2738 .24572 L
.2791 .28426 L
.28405 .31546 L
.28941 .34108 L
.29225 .35104 L
.29529 .3592 L
.29807 .36466 L
.30071 .36842 L
.30307 .37084 L
.30565 .3727 L
.3148 .37589 L
.3196 .37719 L
.32202 .37807 L
.32467 .37929 L
.32759 .38103 L
.33032 .38306 L
.3355 .38808 L
.34568 .40199 L
.36543 .43512 L
.37558 .44873 L
.38126 .45426 L
.38372 .45618 L
.38643 .45796 L
.39127 .46038 L
.39392 .46133 L
Mistroke
.3964 .46201 L
.39871 .46247 L
.40083 .46278 L
.402 .4629 L
.40327 .463 L
.40448 .46307 L
.40559 .46311 L
.4069 .46313 L
.40764 .46313 L
.40831 .46312 L
.40956 .46309 L
.41087 .46304 L
.41205 .46299 L
.41315 .46292 L
.41566 .46275 L
.42638 .46178 L
.43139 .46136 L
.43404 .46118 L
.43684 .46101 L
.43929 .46089 L
.44059 .46084 L
.44199 .46079 L
.44327 .46075 L
.44444 .46073 L
.44557 .46071 L
.44675 .46069 L
.44791 .46068 L
.44897 .46067 L
.45019 .46067 L
.45134 .46067 L
.45241 .46068 L
.45339 .46069 L
.45447 .4607 L
.45562 .46072 L
.46023 .46082 L
.46531 .46096 L
.47009 .46109 L
.4753 .46123 L
.47768 .46128 L
.48021 .46132 L
.48145 .46133 L
.48261 .46135 L
.48365 .46136 L
.48477 .46136 L
.48609 .46137 L
.48684 .46137 L
.48754 .46136 L
.48828 .46136 L
.48896 .46136 L
.48973 .46135 L
Mistroke
.49047 .46135 L
.49177 .46133 L
.49297 .46131 L
.49569 .46126 L
.498 .4612 L
.50054 .46112 L
.50567 .46091 L
.5158 .46035 L
.52507 .4597 L
.54594 .45807 L
.58564 .45509 L
.62382 .45237 L
.66445 .44944 L
.70357 .44668 L
.74514 .4438 L
.7852 .44104 L
.82373 .43837 L
.86473 .43554 L
.9042 .43281 L
.94216 .4302 L
.97619 .42788 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04673 L
.06244 .04845 L
.08259 .0521 L
.09399 .05479 L
.10458 .05794 L
.11466 .06183 L
.1238 .06652 L
.12887 .06984 L
.13435 .07427 L
.13953 .07957 L
.14429 .0858 L
.14899 .09378 L
.15402 .10519 L
.15878 .11957 L
.16311 .13598 L
.1682 .15665 L
.16959 .16164 L
.17107 .1662 L
.17233 .16932 L
.17301 .17066 L
.17372 .17181 L
.17503 .17318 L
.17622 .17361 L
.1775 .17325 L
.17823 .17268 L
.17891 .17194 L
.18014 .17011 L
.18126 .16796 L
.18378 .16188 L
.19388 .13084 L
.19941 .11518 L
.20458 .10304 L
.20935 .09409 L
.21371 .08767 L
.21855 .08226 L
.22107 .08006 L
.22376 .07811 L
Mistroke
.22633 .0766 L
.22866 .07549 L
.23102 .07459 L
.2332 .07395 L
.23575 .0734 L
.23709 .07319 L
.2385 .07302 L
.23973 .07291 L
.24088 .07285 L
.24214 .07282 L
.24285 .07281 L
.24349 .07282 L
.24465 .07285 L
.24589 .07292 L
.24694 .073 L
.2481 .0731 L
.25069 .07341 L
.25312 .07378 L
.26222 .07544 L
.2645 .07583 L
.26694 .07617 L
.26833 .07633 L
.2696 .07645 L
.27088 .07654 L
.27208 .0766 L
.27334 .07663 L
.27398 .07663 L
.27467 .07662 L
.27591 .07658 L
.27706 .07651 L
.27776 .07646 L
.27842 .0764 L
.27966 .07626 L
.28245 .07582 L
.28468 .07536 L
.28705 .07478 L
.29131 .07353 L
.30096 .07025 L
.31032 .06721 L
.31523 .06586 L
.32041 .06466 L
.32496 .06379 L
.32994 .06302 L
.33413 .0625 L
.33868 .06204 L
.34396 .06164 L
.34894 .06134 L
.35379 .06112 L
.35827 .06096 L
.36844 .06068 L
Mistroke
.37921 .06044 L
.39898 .06008 L
.41707 .05981 L
.42703 .05971 L
.43649 .05963 L
.44167 .0596 L
.44648 .05958 L
.45175 .05956 L
.45449 .05956 L
.45737 .05955 L
.45993 .05954 L
.46274 .05954 L
.46529 .05954 L
.46767 .05954 L
.46911 .05953 L
.47048 .05953 L
.47171 .05953 L
.4724 .05953 L
.47304 .05953 L
.47373 .05953 L
.47437 .05953 L
.47508 .05953 L
.47584 .05953 L
.47659 .05953 L
.47738 .05953 L
.47806 .05953 L
.4788 .05953 L
.48016 .05953 L
.48145 .05953 L
.48386 .05954 L
.48925 .05954 L
.49898 .05955 L
.519 .05957 L
.53746 .0596 L
.57688 .05967 L
.61479 .05973 L
.63425 .05975 L
.65515 .05977 L
.66529 .05978 L
.67634 .05978 L
.6814 .05978 L
.68678 .05979 L
.69148 .05979 L
.69645 .05979 L
.69902 .05979 L
.70183 .05979 L
.70439 .05979 L
.70553 .05979 L
.70677 .05979 L
.70752 .05979 L
Mistroke
.70822 .05979 L
.70887 .05979 L
.70959 .05979 L
.71083 .05979 L
.71215 .05979 L
.7129 .05979 L
.71359 .05979 L
.71438 .05979 L
.71513 .05979 L
.71646 .05979 L
.71792 .05979 L
.72057 .05979 L
.72298 .05979 L
.72838 .05979 L
.73339 .05979 L
.7381 .05979 L
.74786 .05978 L
.75817 .05978 L
.77664 .05977 L
.8146 .05974 L
.85501 .0597 L
.89391 .05966 L
.93526 .05962 L
.97509 .05957 L
.97619 .05957 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04668 L
.06244 .04839 L
.08259 .05202 L
.09399 .05469 L
.10458 .05782 L
.11466 .06168 L
.1238 .06634 L
.12887 .06963 L
.13435 .07402 L
.13953 .07926 L
.14429 .08544 L
.14899 .09333 L
.15402 .10463 L
.15878 .11892 L
.16311 .13532 L
.1682 .15622 L
.16959 .16135 L
.17107 .16607 L
.17235 .1694 L
.17302 .17082 L
.17372 .17207 L
.17501 .17364 L
.17619 .1743 L
.17729 .17427 L
.1785 .17355 L
.17982 .17205 L
.18056 .17092 L
.18123 .16973 L
.18378 .16412 L
.19388 .13497 L
.19941 .12012 L
.20458 .10859 L
.20935 .10012 L
.21371 .09409 L
.21855 .08911 L
.22122 .08704 L
.22376 .08548 L
Mistroke
.22619 .08433 L
.22838 .08356 L
.2296 .08324 L
.23092 .08298 L
.23216 .0828 L
.23331 .08271 L
.23437 .08268 L
.23536 .08271 L
.23645 .08279 L
.23762 .08294 L
.23884 .08317 L
.24 .08346 L
.24216 .08419 L
.24459 .08534 L
.24716 .08698 L
.24936 .08877 L
.25178 .0912 L
.25717 .09851 L
.26222 .10755 L
.27208 .12656 L
.27448 .13033 L
.27704 .13363 L
.27851 .13515 L
.27984 .13629 L
.28118 .13718 L
.28245 .1378 L
.28352 .13817 L
.2847 .1384 L
.28593 .13845 L
.28708 .13834 L
.28815 .1381 L
.28913 .13778 L
.29026 .13728 L
.29134 .1367 L
.29595 .13321 L
.30096 .12807 L
.32033 .10581 L
.33135 .09577 L
.34171 .08877 L
.35156 .08395 L
.36059 .08074 L
.3705 .07817 L
.38095 .07619 L
.40066 .07354 L
.41902 .07163 L
.43774 .07004 L
.45804 .06875 L
.46913 .06823 L
.47936 .06784 L
.48976 .06754 L
Mistroke
.4995 .0673 L
.51824 .06696 L
.53887 .06669 L
.54926 .06658 L
.55914 .0665 L
.56886 .06643 L
.57766 .06638 L
.58726 .06634 L
.59217 .06632 L
.59749 .0663 L
.60242 .06629 L
.60696 .06628 L
.61162 .06627 L
.61588 .06627 L
.62058 .06626 L
.62317 .06626 L
.62436 .06626 L
.62562 .06626 L
.6267 .06626 L
.62789 .06626 L
.62897 .06626 L
.62998 .06626 L
.63117 .06626 L
.63226 .06626 L
.63346 .06626 L
.63472 .06626 L
.63601 .06626 L
.63719 .06626 L
.63983 .06626 L
.64228 .06626 L
.64459 .06626 L
.64977 .06627 L
.65539 .06627 L
.66486 .06629 L
.67528 .06631 L
.69632 .06635 L
.73668 .06646 L
.77553 .06658 L
.81682 .06671 L
.8566 .06682 L
.89487 .06692 L
.93559 .06702 L
.97479 .06711 L
.97619 .06711 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04443 L
.04761 .04583 L
.05217 .04676 L
.06244 .04849 L
.08259 .05218 L
.09399 .05488 L
.10458 .05807 L
.11466 .06201 L
.1238 .06678 L
.12887 .07017 L
.13435 .0747 L
.13953 .08016 L
.14429 .08662 L
.14899 .09497 L
.15402 .10705 L
.15878 .12254 L
.16311 .14055 L
.1682 .16364 L
.16959 .16928 L
.17107 .17444 L
.17233 .178 L
.17301 .17955 L
.17372 .18088 L
.17503 .18252 L
.17622 .18314 L
.1775 .1829 L
.17823 .18238 L
.17891 .18166 L
.18014 .17985 L
.18126 .17771 L
.18378 .17157 L
.19388 .14007 L
.19941 .12403 L
.20458 .11141 L
.20935 .10191 L
.21371 .09493 L
.21855 .08886 L
.22376 .08402 L
.22613 .08232 L
Mistroke
.22866 .0808 L
.23084 .07972 L
.2332 .07877 L
.23598 .07791 L
.23726 .07761 L
.2386 .07734 L
.23982 .07715 L
.24115 .07698 L
.24236 .07687 L
.24349 .0768 L
.24466 .07675 L
.24592 .07674 L
.24712 .07676 L
.24823 .0768 L
.24922 .07686 L
.25032 .07694 L
.25254 .07715 L
.25717 .07771 L
.25979 .07804 L
.26222 .07831 L
.26345 .07842 L
.26461 .07851 L
.26525 .07855 L
.26595 .07858 L
.26716 .07862 L
.26847 .07864 L
.26913 .07863 L
.26986 .07862 L
.27114 .07856 L
.27234 .07848 L
.27354 .07836 L
.27468 .07822 L
.27681 .07788 L
.27911 .07741 L
.28161 .07679 L
.29153 .07353 L
.30248 .06969 L
.30738 .0682 L
.31266 .06683 L
.31723 .06585 L
.32223 .06498 L
.32756 .06426 L
.33318 .0637 L
.33838 .06331 L
.34323 .06305 L
.34827 .06286 L
.35111 .06278 L
.35374 .06273 L
.35622 .06268 L
.35855 .06265 L
Mistroke
.36099 .06263 L
.36228 .06261 L
.36366 .06261 L
.3649 .0626 L
.36604 .0626 L
.3673 .06259 L
.368 .06259 L
.36864 .06259 L
.36981 .06259 L
.37107 .06259 L
.37227 .06259 L
.37337 .0626 L
.37443 .0626 L
.37543 .0626 L
.37768 .06261 L
.38224 .06265 L
.38725 .06269 L
.3927 .06275 L
.40261 .0629 L
.42117 .06322 L
.46197 .06403 L
.50126 .06482 L
.53903 .06549 L
.57925 .06606 L
.61796 .06647 L
.63802 .06663 L
.65912 .06676 L
.67888 .06685 L
.69725 .06691 L
.70778 .06694 L
.71772 .06695 L
.72664 .06697 L
.73168 .06697 L
.73631 .06697 L
.73876 .06697 L
.74099 .06698 L
.74223 .06698 L
.74357 .06698 L
.74486 .06698 L
.74602 .06698 L
.74719 .06698 L
.7483 .06698 L
.74947 .06698 L
.75073 .06698 L
.75183 .06698 L
.753 .06698 L
.754 .06698 L
.75509 .06698 L
.75779 .06698 L
.76025 .06698 L
Mistroke
.76578 .06697 L
.7709 .06697 L
.77574 .06697 L
.78543 .06695 L
.7957 .06694 L
.81414 .06691 L
.85196 .06683 L
.89224 .06672 L
.931 .0666 L
.97221 .06648 L
.97619 .06647 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04357 L
.04262 .04447 L
.04761 .04589 L
.05217 .04684 L
.06244 .04863 L
.08259 .05244 L
.09399 .05523 L
.10458 .05854 L
.11466 .06267 L
.1238 .06773 L
.12887 .07138 L
.13435 .07633 L
.13953 .08241 L
.14429 .08982 L
.14899 .09971 L
.15157 .10673 L
.15402 .11476 L
.15878 .13537 L
.16311 .1611 L
.16791 .19433 L
.17054 .21037 L
.17183 .21661 L
.17301 .22115 L
.17429 .22474 L
.17496 .22606 L
.17567 .22707 L
.17639 .22769 L
.17707 .22793 L
.17781 .22783 L
.1786 .22736 L
.17927 .2267 L
.18 .22572 L
.18131 .22339 L
.18378 .21757 L
.19317 .18904 L
.20326 .16149 L
.20905 .14929 L
.21433 .14058 L
.21688 .13723 L
.21965 .1342 L
Mistroke
.22227 .13195 L
.22469 .1304 L
.22599 .1298 L
.22718 .12939 L
.22848 .1291 L
.22914 .12902 L
.22986 .12898 L
.23107 .12905 L
.23237 .1293 L
.23359 .12972 L
.23471 .13028 L
.23587 .13103 L
.23694 .13191 L
.23937 .13457 L
.24151 .13785 L
.24378 .14246 L
.24618 .14891 L
.24877 .15809 L
.25121 .1694 L
.25344 .18239 L
.25864 .22373 L
.2641 .28335 L
.27367 .40133 L
.27642 .43006 L
.27902 .45277 L
.28138 .4694 L
.28388 .48291 L
.28607 .49159 L
.28731 .49535 L
.28847 .49816 L
.28952 .50018 L
.29051 .50168 L
.29166 .50296 L
.2927 .50375 L
.29386 .50425 L
.29508 .50442 L
.29612 .5043 L
.29728 .50394 L
.29851 .50333 L
.29985 .50246 L
.30226 .5005 L
.30727 .49574 L
.31002 .49321 L
.31262 .49112 L
.31505 .48954 L
.31633 .48887 L
.31768 .48829 L
.31882 .48792 L
.32007 .48763 L
.32121 .48748 L
Mistroke
.32227 .48744 L
.32357 .48753 L
.32481 .48774 L
.32592 .48803 L
.32713 .48848 L
.32844 .48909 L
.32983 .4899 L
.33234 .49171 L
.33813 .49746 L
.34337 .50407 L
.35273 .51707 L
.36263 .52903 L
.3678 .53355 L
.37074 .53547 L
.37348 .53684 L
.37477 .53734 L
.376 .53774 L
.37711 .53803 L
.37829 .53827 L
.37958 .53845 L
.38076 .53855 L
.38204 .53859 L
.38277 .53858 L
.38345 .53854 L
.38463 .53844 L
.38589 .53828 L
.38708 .53807 L
.38815 .53784 L
.3908 .53711 L
.39329 .53625 L
.40365 .53145 L
.42216 .52189 L
.43189 .51784 L
.44219 .51464 L
.45098 .51267 L
.46065 .51108 L
.50101 .50608 L
.53985 .50087 L
.56104 .49865 L
.58115 .49708 L
.60101 .4959 L
.61941 .49502 L
.63826 .49429 L
.65861 .49367 L
.68008 .49319 L
.70027 .49287 L
.72026 .49263 L
.74134 .49245 L
.76104 .49232 L
.77939 .49223 L
Mistroke
.81837 .49206 L
.8598 .4919 L
.89972 .49171 L
.93812 .4915 L
.97619 .49126 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .04861 L
.08259 .05239 L
.09399 .05517 L
.10458 .05846 L
.11466 .06255 L
.1238 .06757 L
.12887 .07117 L
.13435 .07605 L
.13953 .08202 L
.14429 .08925 L
.14899 .09884 L
.15157 .10559 L
.15402 .11327 L
.15878 .13274 L
.16311 .15656 L
.16791 .18658 L
.16918 .19382 L
.17054 .20072 L
.17174 .20578 L
.17301 .20993 L
.17367 .21159 L
.1744 .21301 L
.17567 .2145 L
.1764 .21482 L
.17719 .21474 L
.17793 .21432 L
.1786 .21366 L
.17988 .21178 L
.18126 .20896 L
.18378 .20235 L
.19317 .17157 L
.20326 .14191 L
.20905 .1286 L
.21433 .11878 L
.21965 .11098 L
.22469 .1053 L
Mistroke
.22943 .10133 L
.23208 .09963 L
.23448 .0984 L
.23672 .09749 L
.2379 .0971 L
.23915 .09675 L
.24024 .09651 L
.24144 .09629 L
.24253 .09614 L
.24355 .09605 L
.24483 .09598 L
.24555 .09596 L
.24622 .09597 L
.24744 .09601 L
.24874 .09609 L
.2499 .09621 L
.25099 .09635 L
.25347 .09673 L
.25855 .09772 L
.26123 .0983 L
.2641 .09902 L
.26678 .09983 L
.26921 .10073 L
.27396 .1031 L
.27929 .10683 L
.28432 .11123 L
.30284 .12854 L
.31258 .13503 L
.32289 .13989 L
.34136 .14797 L
.35082 .15373 L
.36097 .16181 L
.3793 .18039 L
.39908 .20139 L
.42062 .21989 L
.4413 .23318 L
.46044 .2434 L
.48067 .25299 L
.49967 .2608 L
.51804 .26702 L
.53739 .27216 L
.55755 .2762 L
.57604 .27896 L
.58557 .28008 L
.59576 .28106 L
.60531 .2818 L
.61412 .28232 L
.61899 .28255 L
.62435 .28276 L
.62973 .28291 L
Mistroke
.63268 .28298 L
.63544 .28303 L
.63804 .28306 L
.63932 .28308 L
.64051 .28309 L
.64159 .28309 L
.64273 .2831 L
.644 .2831 L
.64515 .28311 L
.6458 .28311 L
.64649 .28311 L
.64773 .2831 L
.64842 .2831 L
.64906 .2831 L
.65052 .28309 L
.6518 .28308 L
.65297 .28307 L
.65559 .28304 L
.6604 .28296 L
.66551 .28284 L
.67469 .28256 L
.68456 .28215 L
.69545 .28158 L
.73567 .27866 L
.77438 .27494 L
.81554 .27038 L
.85519 .26567 L
.89331 .26105 L
.9339 .25617 L
.97296 .25162 L
.97619 .25125 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04682 L
.06244 .04859 L
.08259 .05235 L
.09399 .05512 L
.10458 .05838 L
.11466 .06244 L
.1238 .0674 L
.12887 .07095 L
.13435 .07576 L
.13953 .08161 L
.14429 .08865 L
.14899 .09795 L
.15402 .1118 L
.15878 .13028 L
.16311 .15266 L
.1682 .18238 L
.16959 .18972 L
.17107 .19647 L
.17233 .20113 L
.17301 .20317 L
.17372 .20495 L
.17503 .2072 L
.17622 .2082 L
.1775 .2082 L
.17823 .20776 L
.17891 .20709 L
.18014 .2053 L
.18126 .20313 L
.18378 .19682 L
.19388 .16408 L
.20458 .13318 L
.21371 .11412 L
.2189 .10611 L
.22376 .10023 L
.22873 .09564 L
.23345 .09244 L
.23768 .09041 L
Mistroke
.24008 .08958 L
.2423 .08898 L
.24356 .08872 L
.24491 .08848 L
.24611 .08831 L
.24737 .08818 L
.24851 .08808 L
.24976 .08801 L
.25089 .08796 L
.25195 .08793 L
.25454 .08788 L
.25523 .08787 L
.25596 .08786 L
.25661 .08785 L
.25729 .08783 L
.25852 .08779 L
.25964 .08773 L
.26087 .08764 L
.26222 .08752 L
.26348 .08737 L
.26483 .08717 L
.26725 .0867 L
.27011 .08599 L
.2727 .08522 L
.28262 .08173 L
.28721 .0802 L
.29217 .07883 L
.29687 .07784 L
.30118 .07719 L
.30364 .07692 L
.30587 .07672 L
.30846 .07655 L
.30964 .07648 L
.3109 .07643 L
.31198 .07639 L
.31316 .07635 L
.31425 .07632 L
.31525 .0763 L
.31643 .07629 L
.31769 .07627 L
.31881 .07627 L
.31999 .07627 L
.32128 .07627 L
.32245 .07628 L
.3231 .07629 L
.32381 .0763 L
.32509 .07632 L
.32756 .07637 L
.32985 .07643 L
.33509 .07662 L
Mistroke
.34064 .07691 L
.34556 .07725 L
.35006 .07763 L
.36019 .07878 L
.36958 .08023 L
.3785 .08193 L
.41671 .09092 L
.45737 .09908 L
.49652 .10553 L
.53813 .11118 L
.55901 .1134 L
.57821 .11511 L
.59816 .11658 L
.61678 .11768 L
.63562 .11855 L
.64624 .11893 L
.65629 .11923 L
.66605 .11946 L
.67666 .11966 L
.68133 .11972 L
.6863 .11978 L
.69065 .11983 L
.69522 .11986 L
.69756 .11988 L
.70011 .11989 L
.70246 .1199 L
.7046 .11991 L
.70581 .11991 L
.70713 .11991 L
.70785 .11991 L
.70852 .11991 L
.70983 .11992 L
.71096 .11992 L
.7122 .11992 L
.71349 .11992 L
.7147 .11991 L
.71584 .11991 L
.71707 .11991 L
.71931 .11991 L
.7215 .1199 L
.72352 .11989 L
.72811 .11987 L
.73299 .11983 L
.74331 .11974 L
.75446 .11961 L
.77464 .11929 L
.81572 .11839 L
.85528 .11734 L
.89332 .11624 L
.93382 .11505 L
Mistroke
.9728 .11392 L
.97619 .11383 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04444 L
.04761 .04584 L
.05217 .04677 L
.06244 .04852 L
.08259 .05223 L
.09399 .05496 L
.10458 .05817 L
.11466 .06216 L
.1238 .067 L
.12887 .07044 L
.13435 .07508 L
.13953 .08068 L
.14429 .08736 L
.14899 .09604 L
.15402 .10876 L
.15878 .1253 L
.16311 .14476 L
.1682 .16985 L
.16959 .17592 L
.17107 .18145 L
.17233 .18521 L
.17301 .18682 L
.17372 .18819 L
.17503 .18984 L
.17622 .1904 L
.1775 .19005 L
.17823 .18945 L
.17891 .18866 L
.18014 .18671 L
.18126 .18444 L
.18378 .17805 L
.19388 .14627 L
.19941 .13032 L
.20458 .11774 L
.21371 .10111 L
.21855 .09482 L
.22376 .08969 L
.22869 .08613 L
.23148 .08461 L
Mistroke
.23407 .08349 L
.23656 .08264 L
.23881 .08205 L
.24006 .08179 L
.24141 .08157 L
.24269 .0814 L
.24386 .08128 L
.24492 .0812 L
.24606 .08114 L
.24714 .08112 L
.24812 .08111 L
.24927 .08112 L
.25052 .08116 L
.2517 .08121 L
.2528 .08127 L
.25519 .08142 L
.25772 .08157 L
.25876 .08162 L
.25987 .08167 L
.26109 .0817 L
.26222 .08171 L
.26348 .08169 L
.26466 .08165 L
.26572 .08159 L
.26687 .0815 L
.26814 .08136 L
.26948 .08118 L
.27188 .08077 L
.27619 .07975 L
.28093 .07833 L
.29171 .07479 L
.30154 .07215 L
.30633 .0712 L
.31155 .0704 L
.31647 .06983 L
.32103 .06945 L
.32351 .06929 L
.32584 .06917 L
.3284 .06906 L
.32972 .06902 L
.33116 .06898 L
.33248 .06895 L
.3339 .06892 L
.33468 .06891 L
.33539 .0689 L
.33611 .0689 L
.33678 .06889 L
.33805 .06889 L
.33872 .06889 L
.33943 .06889 L
Mistroke
.34062 .06889 L
.34193 .0689 L
.34323 .06892 L
.34442 .06893 L
.34714 .06899 L
.34953 .06905 L
.35208 .06914 L
.35695 .06935 L
.36136 .06959 L
.37211 .07036 L
.38224 .0713 L
.42081 .07556 L
.46184 .07929 L
.50134 .08221 L
.53934 .08448 L
.5605 .08546 L
.57978 .0862 L
.6 .08684 L
.61871 .0873 L
.63781 .08767 L
.64788 .08782 L
.65857 .08795 L
.66795 .08804 L
.67288 .08807 L
.67806 .08811 L
.68262 .08813 L
.6876 .08815 L
.69213 .08817 L
.69634 .08818 L
.69897 .08819 L
.7014 .08819 L
.70267 .08819 L
.70406 .08819 L
.70476 .08819 L
.70552 .08819 L
.70623 .08819 L
.70688 .08819 L
.70814 .08819 L
.70932 .08819 L
.71061 .08819 L
.71133 .08819 L
.71198 .08819 L
.71318 .08819 L
.71447 .08819 L
.71682 .08819 L
.71907 .08818 L
.72153 .08818 L
.72651 .08817 L
.73541 .08813 L
.74565 .08808 L
Mistroke
.75497 .08803 L
.77591 .08786 L
.81582 .08745 L
.85422 .08698 L
.89508 .08644 L
.93442 .0859 L
.97224 .0854 L
.97619 .08535 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04225 L
.04033 .04348 L
.04262 .04435 L
.04761 .04571 L
.05217 .04661 L
.06244 .04829 L
.08259 .05185 L
.09399 .05447 L
.10458 .05754 L
.11466 .0613 L
.1238 .06581 L
.12887 .06897 L
.13435 .07315 L
.14429 .08384 L
.16384 .12891 L
.16659 .13761 L
.16919 .14487 L
.17063 .14807 L
.17139 .14947 L
.17219 .15069 L
.17287 .1515 L
.17362 .15215 L
.17493 .15269 L
.17559 .15266 L
.17627 .15244 L
.1775 .15153 L
.17819 .15077 L
.17883 .14991 L
.18028 .14748 L
.18529 .13551 L
.19511 .10883 L
.19994 .09791 L
.20438 .08972 L
.20951 .08239 L
.21216 .0794 L
.21507 .07665 L
.21979 .07326 L
.22237 .07188 L
.22478 .07084 L
.22736 .06998 L
.22976 .06938 L
Mistroke
.23114 .06911 L
.23239 .06891 L
.23383 .06874 L
.23448 .06868 L
.23519 .06862 L
.23639 .06855 L
.23766 .06852 L
.23884 .06851 L
.23994 .06853 L
.24123 .06859 L
.24241 .06866 L
.24378 .06878 L
.24507 .06891 L
.24968 .06958 L
.25395 .07041 L
.2636 .07254 L
.26825 .07341 L
.27086 .07378 L
.2721 .07392 L
.27326 .07402 L
.27428 .07409 L
.27536 .07415 L
.27657 .07418 L
.27767 .07418 L
.27881 .07416 L
.28005 .07411 L
.28123 .07403 L
.28231 .07394 L
.28477 .07363 L
.28708 .07325 L
.29233 .07207 L
.30292 .06897 L
.31336 .06594 L
.32325 .06367 L
.33213 .06225 L
.33715 .06166 L
.3418 .06122 L
.34642 .06088 L
.35141 .06059 L
.36044 .0602 L
.37118 .05986 L
.38103 .05959 L
.40153 .05905 L
.42062 .0586 L
.43903 .05828 L
.44933 .05815 L
.4587 .05805 L
.47786 .0579 L
.49865 .05779 L
.51811 .0577 L
Mistroke
.53954 .05761 L
.57891 .0575 L
.59833 .05746 L
.61921 .05743 L
.66046 .05737 L
.70019 .05732 L
.7384 .05728 L
.77907 .05724 L
.81822 .0572 L
.85982 .05716 L
.8999 .05713 L
.93847 .0571 L
.97619 .05707 L
Mfstroke
.055 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04018 L
.03652 .04111 L
.0379 .04195 L
.04033 .04312 L
.04262 .04393 L
.04517 .04464 L
.04761 .04519 L
.05217 .04602 L
.06244 .04755 L
.07302 .04917 L
.08429 .05118 L
.09474 .05344 L
.10458 .05606 L
.1142 .05927 L
.12461 .06382 L
.13407 .06948 L
.14277 .07675 L
.15263 .08879 L
.15805 .09756 L
.16319 .1066 L
.16551 .11036 L
.16797 .11361 L
.16925 .11485 L
.16998 .11539 L
.17067 .11578 L
.17187 .11615 L
.17317 .11611 L
.17427 .1157 L
.17548 .11487 L
.17674 .11362 L
.17791 .11214 L
.18226 .10477 L
.1917 .08661 L
.19634 .07936 L
.20062 .07405 L
.20555 .06944 L
.20815 .06757 L
.21089 .06595 L
.21534 .06399 L
.21787 .06319 L
.22023 .06262 L
.22148 .06238 L
.22282 .06216 L
Mistroke
.22397 .062 L
.22521 .06187 L
.22598 .0618 L
.22668 .06175 L
.22734 .06171 L
.22806 .06168 L
.22931 .06164 L
.23 .06163 L
.23064 .06163 L
.23192 .06165 L
.23314 .06169 L
.23423 .06174 L
.23541 .06182 L
.23807 .06205 L
.24052 .06234 L
.2448 .06299 L
.24951 .0639 L
.25906 .06612 L
.26851 .06831 L
.27325 .06915 L
.27455 .06933 L
.27594 .0695 L
.27724 .06963 L
.27844 .06972 L
.27985 .06981 L
.2806 .06984 L
.28138 .06986 L
.2827 .06988 L
.28345 .06987 L
.28415 .06986 L
.28546 .06982 L
.28665 .06976 L
.28803 .06966 L
.28934 .06954 L
.29182 .06925 L
.29411 .0689 L
.29931 .06794 L
.30904 .06574 L
.31954 .06342 L
.32945 .06168 L
.33416 .06104 L
.33855 .06054 L
.34731 .0598 L
.35195 .05951 L
.35691 .05925 L
.36705 .05886 L
.37626 .05857 L
.41621 .05737 L
.43451 .0569 L
.44491 .05669 L
Mistroke
.45465 .05652 L
.4745 .05627 L
.49553 .05606 L
.53433 .05575 L
.55405 .05563 L
.57557 .05552 L
.6153 .05536 L
.65596 .05524 L
.69511 .05516 L
.73672 .0551 L
.7768 .05505 L
.81537 .05501 L
.8564 .05498 L
.8959 .05496 L
.9339 .05493 L
.97434 .05491 L
.97619 .05491 L
Mfstroke
.079 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04127 L
.0379 .04214 L
.04033 .04334 L
.04262 .04419 L
.04761 .0455 L
.05217 .04637 L
.06244 .04799 L
.08259 .05145 L
.09399 .05399 L
.10458 .05694 L
.11466 .06055 L
.1238 .06483 L
.12887 .06782 L
.13435 .07173 L
.14429 .08156 L
.16384 .11986 L
.16659 .12654 L
.16919 .13183 L
.17063 .13401 L
.17144 .13496 L
.17219 .13563 L
.17283 .13603 L
.17352 .1363 L
.17425 .1364 L
.17493 .1363 L
.1762 .13569 L
.17684 .13517 L
.17753 .13445 L
.17992 .13096 L
.1827 .12536 L
.18529 .11931 L
.19511 .09635 L
.19994 .08734 L
.20438 .08074 L
.20951 .07499 L
.21221 .07266 L
.21507 .07064 L
.21969 .06821 L
.22232 .06721 L
.22478 .06649 L
.22603 .0662 L
.22736 .06593 L
Mistroke
.22976 .06557 L
.23123 .06541 L
.23195 .06534 L
.23261 .0653 L
.23385 .06523 L
.2345 .06521 L
.23519 .06519 L
.23636 .06518 L
.23763 .06519 L
.23882 .06522 L
.2399 .06526 L
.24117 .06533 L
.24255 .06543 L
.24507 .06564 L
.24974 .0661 L
.2523 .06634 L
.25355 .06644 L
.2547 .06652 L
.25568 .06658 L
.25674 .06663 L
.25781 .06667 L
.25894 .06669 L
.26011 .06669 L
.26136 .06668 L
.26253 .06665 L
.2636 .06661 L
.26592 .0665 L
.26847 .06633 L
.27361 .06595 L
.28283 .06523 L
.29359 .06412 L
.30364 .06271 L
.32225 .05998 L
.33277 .05879 L
.34251 .05799 L
.3474 .05768 L
.3528 .05739 L
.36373 .05696 L
.3741 .05665 L
.38384 .05643 L
.39366 .05624 L
.404 .05608 L
.41369 .05595 L
.4225 .05586 L
.43203 .05579 L
.43727 .05576 L
.44221 .05574 L
.44649 .05572 L
.45102 .05571 L
.45599 .0557 L
Mistroke
.46057 .05569 L
.4631 .05569 L
.46549 .05568 L
.46765 .05568 L
.46999 .05568 L
.47133 .05568 L
.47254 .05568 L
.47393 .05568 L
.47525 .05568 L
.47647 .05568 L
.47759 .05568 L
.47882 .05568 L
.48012 .05568 L
.48126 .05568 L
.4823 .05568 L
.4835 .05568 L
.48464 .05568 L
.48885 .05568 L
.49344 .05568 L
.49843 .05569 L
.51822 .0557 L
.53923 .05572 L
.577 .05576 L
.61722 .05582 L
.65593 .05587 L
.69709 .05591 L
.73674 .05595 L
.77486 .05599 L
.81545 .05602 L
.85451 .05604 L
.89603 .05606 L
.93603 .05609 L
.97452 .0561 L
.97619 .0561 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .04861 L
.08259 .05239 L
.09399 .05517 L
.10458 .05845 L
.11466 .06254 L
.1238 .06755 L
.12887 .07114 L
.13435 .07602 L
.13953 .08197 L
.14429 .08918 L
.14899 .09873 L
.15157 .10545 L
.15402 .11308 L
.15878 .1324 L
.16311 .15595 L
.16791 .18547 L
.16918 .19256 L
.17054 .19928 L
.17174 .20419 L
.17301 .20818 L
.17367 .20976 L
.1744 .21108 L
.17567 .21243 L
.1764 .21267 L
.17719 .21251 L
.17793 .21202 L
.1786 .21129 L
.17988 .2093 L
.18126 .20636 L
.18378 .19955 L
.19317 .16816 L
.20326 .13823 L
.20905 .12505 L
.21433 .11555 L
.21965 .10824 L
.2223 .10536 L
Mistroke
.22469 .10315 L
.22943 .09981 L
.23203 .09852 L
.23322 .09805 L
.23448 .09764 L
.23556 .09734 L
.23675 .09709 L
.23783 .09692 L
.23884 .09682 L
.24003 .09675 L
.24111 .09676 L
.24236 .09683 L
.24355 .09697 L
.24473 .09717 L
.24603 .09747 L
.24867 .0983 L
.25111 .09935 L
.2534 .10055 L
.25855 .10409 L
.26145 .10671 L
.2641 .10962 L
.26885 .11638 L
.27393 .12593 L
.28306 .14753 L
.29384 .17298 L
.29858 .18205 L
.30377 .19011 L
.30877 .19613 L
.31404 .20108 L
.32516 .20899 L
.3357 .21652 L
.34532 .2255 L
.36481 .25123 L
.38572 .28187 L
.39495 .29298 L
.40478 .30234 L
.41555 .30995 L
.42553 .31513 L
.44498 .32236 L
.46325 .3276 L
.47306 .33005 L
.48341 .33229 L
.49309 .33404 L
.5019 .3353 L
.51143 .33631 L
.51667 .33673 L
.52162 .33704 L
.5262 .33726 L
.53043 .3374 L
.53263 .33746 L
Mistroke
.53506 .33751 L
.53629 .33753 L
.5376 .33755 L
.53883 .33756 L
.53998 .33757 L
.54062 .33758 L
.54131 .33758 L
.54252 .33759 L
.5432 .33759 L
.54393 .33759 L
.54523 .33759 L
.54643 .33758 L
.54755 .33758 L
.54878 .33757 L
.55009 .33755 L
.55306 .33751 L
.55587 .33747 L
.56113 .33735 L
.57076 .33704 L
.58122 .33659 L
.60101 .33546 L
.62203 .33389 L
.6598 .33032 L
.70002 .32581 L
.73873 .32107 L
.77989 .31578 L
.81953 .31057 L
.85766 .30554 L
.89824 .30026 L
.9373 .29531 L
.97619 .29056 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04586 L
.05217 .04681 L
.06244 .04857 L
.08259 .05233 L
.09399 .05509 L
.10458 .05835 L
.11466 .06241 L
.1238 .06735 L
.12887 .0709 L
.13435 .07568 L
.13953 .08151 L
.14429 .08853 L
.14899 .09777 L
.15402 .11151 L
.15878 .12974 L
.16311 .1516 L
.1682 .18 L
.16959 .18681 L
.17107 .19294 L
.17233 .19703 L
.17305 .19885 L
.17372 .20021 L
.17495 .20183 L
.17625 .20236 L
.17735 .20196 L
.17856 .20071 L
.17987 .19855 L
.18126 .19549 L
.18378 .18855 L
.19345 .15613 L
.20369 .12648 L
.20904 .11482 L
.21492 .10493 L
.22027 .09827 L
.22527 .09374 L
.22775 .09203 L
.23044 .09052 L
.23299 .0894 L
Mistroke
.23535 .08861 L
.23655 .08829 L
.23768 .08804 L
.23872 .08785 L
.2398 .08769 L
.24099 .08756 L
.24208 .08749 L
.24326 .08744 L
.24455 .08744 L
.24522 .08745 L
.24594 .08748 L
.24726 .08756 L
.24854 .08768 L
.24972 .08781 L
.25526 .0886 L
.26008 .0893 L
.26526 .08997 L
.26771 .09034 L
.27029 .09081 L
.2725 .09133 L
.27491 .09205 L
.2796 .09396 L
.28396 .09633 L
.29457 .10365 L
.30457 .11059 L
.31442 .11605 L
.32507 .12052 L
.34367 .12779 L
.35316 .13268 L
.36359 .13947 L
.38464 .15648 L
.40576 .17302 L
.42503 .18426 L
.43459 .18849 L
.44499 .19237 L
.46391 .19817 L
.48327 .203 L
.49356 .20516 L
.50466 .20713 L
.51521 .20865 L
.52489 .20976 L
.53414 .21058 L
.53925 .21094 L
.54389 .21121 L
.54847 .21144 L
.55342 .21164 L
.55866 .21181 L
.56102 .21187 L
.56361 .21192 L
.56585 .21196 L
Mistroke
.56825 .21199 L
.56957 .21201 L
.57078 .21202 L
.57202 .21203 L
.57316 .21204 L
.57421 .21204 L
.57532 .21204 L
.57656 .21205 L
.57768 .21205 L
.57874 .21205 L
.57989 .21204 L
.58097 .21204 L
.58197 .21203 L
.58443 .21202 L
.58668 .212 L
.59172 .21193 L
.59639 .21184 L
.60081 .21173 L
.61071 .21142 L
.62148 .21098 L
.64127 .20992 L
.66228 .20849 L
.70005 .20535 L
.74027 .20149 L
.77898 .19751 L
.82014 .19315 L
.85979 .18897 L
.89791 .18505 L
.93849 .18104 L
.97619 .17752 L
Mfstroke
.15 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04588 L
.05217 .04683 L
.06244 .04861 L
.08259 .05239 L
.09399 .05517 L
.10458 .05845 L
.11466 .06254 L
.1238 .06754 L
.12887 .07114 L
.13435 .076 L
.13953 .08196 L
.14429 .08916 L
.14899 .09872 L
.15157 .10546 L
.15402 .11312 L
.15878 .13263 L
.16311 .15675 L
.16791 .18792 L
.17054 .20323 L
.17183 .20932 L
.17301 .21383 L
.17429 .2175 L
.17496 .2189 L
.17567 .22 L
.17639 .22075 L
.17707 .22111 L
.17781 .22115 L
.1786 .22083 L
.17927 .22029 L
.18 .21945 L
.18131 .21733 L
.18378 .2118 L
.19317 .18315 L
.20326 .1543 L
.20905 .14137 L
.21433 .13215 L
.21688 .12861 L
.21965 .12541 L
Mistroke
.22227 .12301 L
.22469 .12134 L
.22599 .12067 L
.22718 .12019 L
.22848 .11983 L
.22914 .1197 L
.22986 .11962 L
.23107 .1196 L
.23237 .11975 L
.23359 .12006 L
.23471 .12051 L
.23587 .12113 L
.23694 .12187 L
.23937 .12418 L
.24151 .12706 L
.24378 .13115 L
.24618 .13692 L
.24877 .14519 L
.25121 .15544 L
.25344 .16726 L
.25864 .20458 L
.2641 .25623 L
.27367 .34888 L
.27642 .36965 L
.27902 .38558 L
.28135 .39679 L
.28266 .40184 L
.28388 .4058 L
.2861 .4113 L
.28727 .4134 L
.28853 .41508 L
.28985 .41628 L
.2911 .41693 L
.29222 .41716 L
.29345 .41707 L
.2945 .41675 L
.29566 .41615 L
.29688 .4153 L
.29802 .41432 L
.30226 .40958 L
.31207 .39641 L
.31743 .39018 L
.32004 .38769 L
.32242 .3858 L
.32446 .38447 L
.32668 .38335 L
.3279 .38287 L
.32903 .38253 L
.33011 .38228 L
.33125 .3821 L
Mistroke
.33239 .38202 L
.33362 .38202 L
.33479 .38211 L
.33585 .38227 L
.33709 .38254 L
.33845 .38294 L
.34091 .38392 L
.34347 .38527 L
.34623 .38703 L
.35124 .39085 L
.3606 .39883 L
.36592 .403 L
.37153 .40657 L
.37384 .40772 L
.37632 .40872 L
.37774 .40918 L
.37904 .40953 L
.38035 .40981 L
.38158 .41001 L
.38268 .41014 L
.38387 .41022 L
.38518 .41025 L
.38639 .41022 L
.38758 .41013 L
.38888 .40998 L
.39024 .40976 L
.3915 .40949 L
.39594 .40818 L
.40068 .40621 L
.42144 .39405 L
.44137 .38268 L
.45261 .37771 L
.46296 .37403 L
.4824 .36874 L
.50296 .3642 L
.54087 .35695 L
.56033 .35408 L
.58123 .35178 L
.59137 .35092 L
.60242 .35015 L
.61298 .34955 L
.62253 .34909 L
.63201 .34872 L
.64225 .34841 L
.65307 .34815 L
.65834 .34805 L
.66324 .34798 L
.66824 .34792 L
.67278 .34788 L
.67521 .34786 L
Mistroke
.67783 .34785 L
.68061 .34783 L
.68197 .34783 L
.68324 .34782 L
.68446 .34782 L
.68577 .34782 L
.68651 .34782 L
.68722 .34782 L
.68786 .34782 L
.68856 .34782 L
.6893 .34782 L
.68997 .34782 L
.69075 .34782 L
.69148 .34782 L
.69279 .34782 L
.69352 .34782 L
.6942 .34782 L
.69654 .34783 L
.69912 .34784 L
.70432 .34786 L
.70956 .3479 L
.71452 .34794 L
.72382 .34804 L
.74473 .34833 L
.78305 .34901 L
.82382 .34983 L
.86307 .35061 L
.90081 .3513 L
.941 .35196 L
.97619 .35246 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04346 L
.04262 .04433 L
.04761 .04568 L
.05217 .04657 L
.06244 .04823 L
.08259 .05178 L
.09399 .05438 L
.10458 .05742 L
.11466 .06114 L
.1238 .0656 L
.12887 .06872 L
.13435 .07284 L
.14429 .08333 L
.16384 .12696 L
.16659 .13529 L
.16919 .14224 L
.17063 .14531 L
.17139 .14664 L
.17219 .14782 L
.17287 .14859 L
.17362 .14923 L
.17493 .14975 L
.17559 .14973 L
.17627 .14952 L
.1775 .14866 L
.17819 .14794 L
.17883 .14712 L
.18028 .14478 L
.1827 .1397 L
.18529 .13321 L
.19593 .10527 L
.20116 .09425 L
.20598 .08629 L
.21036 .08074 L
.215 .07636 L
.21966 .07326 L
.2223 .07197 L
.22478 .07102 L
.22736 .07028 L
.22976 .06979 L
Mistroke
.23114 .06958 L
.23239 .06944 L
.23308 .06938 L
.23383 .06932 L
.23454 .06929 L
.23519 .06926 L
.23637 .06924 L
.23748 .06926 L
.23869 .0693 L
.23999 .06937 L
.24065 .06943 L
.24136 .06949 L
.24265 .06963 L
.24507 .06996 L
.24974 .07084 L
.2547 .07201 L
.2636 .07442 L
.273 .07715 L
.27557 .0778 L
.27828 .07837 L
.28059 .07873 L
.2819 .07888 L
.28311 .07898 L
.28426 .07904 L
.2855 .07906 L
.28667 .07905 L
.28775 .079 L
.28873 .07893 L
.2898 .07883 L
.29196 .07854 L
.29432 .07811 L
.29685 .07752 L
.30141 .07623 L
.32119 .06962 L
.33163 .06675 L
.34273 .0645 L
.35256 .06309 L
.35815 .06247 L
.36341 .06199 L
.37261 .06132 L
.38255 .06078 L
.40256 .05999 L
.42366 .05938 L
.43318 .05916 L
.44337 .05896 L
.45292 .0588 L
.46173 .05869 L
.47196 .05859 L
.48305 .0585 L
.49283 .05845 L
Mistroke
.5032 .0584 L
.51262 .05837 L
.52275 .05834 L
.53231 .05832 L
.54105 .05831 L
.54582 .0583 L
.55091 .05829 L
.5553 .05829 L
.56005 .05829 L
.56297 .05829 L
.56565 .05828 L
.56822 .05828 L
.56953 .05828 L
.57093 .05828 L
.5722 .05828 L
.57336 .05828 L
.57452 .05828 L
.57563 .05828 L
.57691 .05828 L
.5781 .05828 L
.5794 .05828 L
.58006 .05828 L
.58078 .05828 L
.582 .05828 L
.58313 .05828 L
.58438 .05828 L
.5857 .05828 L
.58842 .05828 L
.59088 .05828 L
.59565 .05829 L
.60014 .05829 L
.61016 .05829 L
.621 .0583 L
.66194 .05835 L
.70137 .0584 L
.73927 .05846 L
.77963 .05851 L
.81848 .05856 L
.85977 .05861 L
.89955 .05866 L
.93782 .0587 L
.97619 .05873 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04229 L
.04033 .04353 L
.04262 .04441 L
.04761 .04579 L
.05217 .04671 L
.06244 .04843 L
.08259 .05207 L
.09399 .05475 L
.10458 .0579 L
.11466 .06178 L
.1238 .06646 L
.12887 .06977 L
.13435 .07419 L
.13953 .07947 L
.14429 .08568 L
.14935 .09431 L
.15414 .10522 L
.15967 .12213 L
.16471 .14121 L
.16914 .15727 L
.17021 .16036 L
.17137 .16314 L
.17265 .16541 L
.17384 .16677 L
.17515 .16736 L
.17581 .16731 L
.17653 .16701 L
.17781 .16586 L
.179 .16417 L
.18021 .16192 L
.18131 .1595 L
.18378 .1531 L
.19337 .12458 L
.19862 .11098 L
.20353 .1006 L
.20806 .09298 L
.21221 .08748 L
.21681 .08277 L
.21937 .08069 L
.22175 .07907 L
.22646 .07661 L
Mistroke
.22894 .07566 L
.23159 .07488 L
.2328 .07459 L
.23412 .07433 L
.23527 .07414 L
.23649 .07398 L
.2376 .07386 L
.23881 .07377 L
.23991 .07371 L
.24093 .07368 L
.24223 .07367 L
.24296 .07368 L
.24363 .0737 L
.24487 .07376 L
.24619 .07384 L
.24847 .07404 L
.25098 .07434 L
.25622 .07509 L
.25908 .0755 L
.26173 .07583 L
.26293 .07595 L
.26407 .07604 L
.26538 .07613 L
.26657 .07617 L
.26789 .0762 L
.2691 .07618 L
.26974 .07617 L
.27044 .07613 L
.27117 .07609 L
.27185 .07604 L
.27305 .07592 L
.27419 .07579 L
.27632 .07545 L
.27862 .07499 L
.28112 .07438 L
.29103 .07127 L
.30199 .06773 L
.30688 .06641 L
.31217 .06522 L
.31674 .06438 L
.32174 .06366 L
.32707 .06307 L
.33269 .06262 L
.33789 .06232 L
.34273 .06213 L
.34536 .06205 L
.34777 .06199 L
.35043 .06194 L
.35324 .0619 L
.35568 .06187 L
Mistroke
.35797 .06185 L
.35927 .06184 L
.36047 .06184 L
.36113 .06183 L
.36185 .06183 L
.36317 .06183 L
.36443 .06183 L
.36561 .06183 L
.36668 .06183 L
.36783 .06183 L
.36909 .06183 L
.37042 .06183 L
.3728 .06184 L
.37501 .06186 L
.37707 .06187 L
.38175 .06191 L
.39221 .06203 L
.40212 .06219 L
.42068 .06254 L
.45903 .06329 L
.49983 .064 L
.53911 .06456 L
.57688 .06495 L
.59625 .06509 L
.61711 .06522 L
.63716 .0653 L
.64725 .06533 L
.65292 .06534 L
.65827 .06535 L
.6632 .06536 L
.66855 .06537 L
.67341 .06538 L
.67789 .06538 L
.6804 .06538 L
.68274 .06538 L
.68409 .06538 L
.68531 .06538 L
.68599 .06538 L
.68673 .06538 L
.68743 .06538 L
.68807 .06538 L
.68875 .06538 L
.68949 .06538 L
.69018 .06538 L
.69081 .06538 L
.69202 .06538 L
.69329 .06538 L
.69594 .06538 L
.69885 .06538 L
.70411 .06537 L
Mistroke
.70909 .06537 L
.71841 .06536 L
.72845 .06534 L
.73934 .06532 L
.7802 .0652 L
.81954 .06504 L
.85736 .06488 L
.89764 .06469 L
.9364 .06451 L
.97619 .06433 L
Mfstroke
.221 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .0402 L
.03652 .04113 L
.0379 .04198 L
.04033 .04316 L
.04262 .04399 L
.04761 .04527 L
.05217 .04612 L
.06244 .0477 L
.08259 .05108 L
.09399 .05355 L
.10458 .05643 L
.11466 .05993 L
.1238 .06407 L
.12887 .06693 L
.13435 .07068 L
.14429 .07999 L
.15372 .09364 L
.15901 .10406 L
.16384 .11472 L
.16656 .1204 L
.168 .12299 L
.16953 .12527 L
.17087 .12676 L
.17163 .12736 L
.17234 .12777 L
.17359 .12806 L
.17429 .128 L
.17493 .1278 L
.17618 .12703 L
.17734 .1259 L
.17862 .12424 L
.17998 .12205 L
.18529 .11104 L
.1904 .09954 L
.19593 .08847 L
.20081 .08064 L
.20598 .07433 L
.21064 .07017 L
.21328 .06836 L
.21576 .06696 L
.22011 .06513 L
.22255 .06439 L
.22478 .06386 L
Mistroke
.22607 .06362 L
.22729 .06343 L
.22956 .06315 L
.23084 .06305 L
.23201 .06297 L
.23329 .06292 L
.23394 .0629 L
.23465 .06289 L
.23585 .06288 L
.23694 .0629 L
.2382 .06293 L
.23939 .06297 L
.2415 .06308 L
.2438 .06324 L
.24903 .06365 L
.25041 .06376 L
.2519 .06385 L
.25258 .06389 L
.2533 .06392 L
.25458 .06397 L
.25575 .06399 L
.25684 .06399 L
.25804 .06397 L
.25932 .06391 L
.25999 .06387 L
.26073 .06382 L
.26206 .06369 L
.26454 .06339 L
.28406 .05994 L
.29515 .05848 L
.30551 .05743 L
.31528 .05662 L
.32455 .05601 L
.32966 .05575 L
.33522 .05551 L
.34025 .05534 L
.34497 .05522 L
.35435 .05503 L
.35934 .05496 L
.36472 .05489 L
.38572 .05467 L
.39608 .05458 L
.40573 .05451 L
.41101 .05448 L
.4158 .05445 L
.42113 .05443 L
.42406 .05442 L
.42682 .05442 L
.42921 .05441 L
.43144 .05441 L
Mistroke
.43272 .05441 L
.43389 .05441 L
.43454 .05441 L
.43525 .0544 L
.43653 .0544 L
.43723 .0544 L
.43788 .0544 L
.43911 .0544 L
.44043 .0544 L
.44118 .0544 L
.44186 .0544 L
.44301 .05441 L
.44427 .05441 L
.44681 .05441 L
.45142 .05442 L
.45635 .05442 L
.46526 .05445 L
.50664 .05455 L
.5465 .05462 L
.58485 .05469 L
.62566 .05476 L
.66494 .05481 L
.70271 .05485 L
.74294 .05488 L
.78164 .0549 L
.8228 .05493 L
.86245 .05494 L
.90058 .05496 L
.94116 .05498 L
.97619 .05499 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04443 L
.04761 .04583 L
.05217 .04677 L
.06244 .04853 L
.08259 .05226 L
.09399 .055 L
.10458 .05823 L
.11466 .06224 L
.1238 .06713 L
.12887 .07062 L
.13435 .07532 L
.13953 .08102 L
.14429 .08785 L
.14899 .09679 L
.15402 .10997 L
.15878 .12728 L
.16311 .14782 L
.1682 .17431 L
.16959 .18066 L
.17107 .18638 L
.17233 .19021 L
.17301 .19183 L
.17372 .1932 L
.17503 .19476 L
.17622 .1952 L
.1775 .1947 L
.17823 .194 L
.17891 .19312 L
.18014 .191 L
.18126 .18858 L
.18378 .1819 L
.19388 .14941 L
.19941 .13327 L
.20458 .12059 L
.21371 .1039 L
.21855 .09763 L
.22376 .09255 L
.22869 .08908 L
.23148 .0876 L
Mistroke
.23407 .08653 L
.23656 .08573 L
.23881 .08518 L
.24006 .08495 L
.24141 .08476 L
.24269 .08462 L
.24386 .08453 L
.24492 .08447 L
.24606 .08444 L
.24714 .08444 L
.24812 .08445 L
.24927 .08449 L
.25052 .08455 L
.2528 .08469 L
.25517 .08485 L
.25648 .08493 L
.2577 .08499 L
.25873 .08503 L
.25985 .08506 L
.26109 .08507 L
.26222 .08506 L
.26351 .08503 L
.26472 .08497 L
.2658 .0849 L
.26698 .08481 L
.27205 .08425 L
.27641 .0837 L
.27871 .08344 L
.28119 .08321 L
.2826 .08311 L
.2839 .08304 L
.2852 .08299 L
.28643 .08297 L
.2871 .08296 L
.28781 .08296 L
.28908 .08298 L
.28979 .083 L
.29045 .08302 L
.29197 .0831 L
.29318 .08317 L
.29446 .08327 L
.29675 .08348 L
.3019 .08407 L
.32184 .08673 L
.33998 .08918 L
.35005 .09102 L
.35956 .09334 L
.38051 .10045 L
.41894 .11494 L
.43879 .12053 L
Mistroke
.45983 .12524 L
.49768 .13209 L
.5171 .13486 L
.53799 .13718 L
.55914 .13892 L
.56887 .13955 L
.57923 .14011 L
.58963 .14058 L
.59905 .14092 L
.60853 .14119 L
.61745 .14138 L
.62211 .14145 L
.62722 .14152 L
.6298 .14154 L
.63256 .14157 L
.63516 .14158 L
.63632 .14159 L
.63754 .14159 L
.63866 .1416 L
.6399 .1416 L
.64103 .1416 L
.64209 .14161 L
.64333 .14161 L
.64447 .14161 L
.64572 .1416 L
.64703 .1416 L
.64811 .1416 L
.64925 .1416 L
.65132 .14159 L
.65378 .14157 L
.65602 .14156 L
.66087 .14152 L
.66601 .14146 L
.67522 .14132 L
.68512 .14112 L
.69602 .14086 L
.73638 .13953 L
.77522 .13787 L
.81652 .13586 L
.8563 .13381 L
.89456 .13182 L
.93528 .12974 L
.97448 .12783 L
.97619 .12775 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04135 L
.0379 .04224 L
.04033 .04346 L
.04262 .04433 L
.04761 .04568 L
.05217 .04658 L
.06244 .04824 L
.08259 .0518 L
.09399 .05441 L
.10458 .05746 L
.11466 .06121 L
.1238 .0657 L
.12887 .06885 L
.13435 .07301 L
.14429 .08364 L
.16384 .12821 L
.16659 .13663 L
.16919 .14349 L
.17063 .14644 L
.17139 .14767 L
.17219 .14873 L
.17287 .14939 L
.17362 .14989 L
.17493 .15015 L
.17559 .15 L
.17627 .14964 L
.1775 .14853 L
.17819 .14767 L
.17883 .14672 L
.18028 .14414 L
.18529 .1321 L
.19511 .10661 L
.19994 .09647 L
.20438 .08892 L
.20951 .08218 L
.21216 .07943 L
.21507 .07691 L
.21979 .07377 L
.22237 .07248 L
.22478 .07151 L
.22736 .0707 L
.22976 .07013 L
Mistroke
.23111 .06988 L
.23239 .06969 L
.23386 .06952 L
.23449 .06946 L
.23519 .06941 L
.23639 .06934 L
.23766 .0693 L
.23884 .06929 L
.23994 .06931 L
.24123 .06936 L
.24241 .06942 L
.24378 .06953 L
.24507 .06965 L
.24968 .07027 L
.25395 .07101 L
.25899 .07196 L
.2636 .07275 L
.26587 .07306 L
.26825 .0733 L
.26949 .07339 L
.27064 .07345 L
.27191 .07349 L
.27261 .07349 L
.27326 .07349 L
.27442 .07346 L
.27549 .07342 L
.27667 .07334 L
.27791 .07322 L
.28001 .07296 L
.28231 .07258 L
.28745 .07145 L
.29296 .06992 L
.30292 .06694 L
.31308 .06433 L
.31844 .06324 L
.32414 .06232 L
.3291 .06169 L
.33458 .06115 L
.33957 .06078 L
.34425 .06051 L
.34894 .0603 L
.35407 .06013 L
.36441 .05988 L
.37399 .05971 L
.38291 .05958 L
.40162 .05934 L
.41218 .05923 L
.42192 .05916 L
.42685 .05913 L
.43227 .0591 L
Mistroke
.435 .05909 L
.43794 .05909 L
.44324 .05907 L
.44582 .05907 L
.44864 .05906 L
.44992 .05906 L
.45129 .05906 L
.45258 .05906 L
.45376 .05906 L
.45501 .05906 L
.45567 .05906 L
.45636 .05906 L
.45753 .05906 L
.45881 .05906 L
.45995 .05906 L
.46118 .05906 L
.46233 .05906 L
.46338 .05906 L
.46567 .05906 L
.4682 .05906 L
.47331 .05907 L
.48248 .05908 L
.50325 .05911 L
.54347 .05916 L
.56196 .05918 L
.58218 .0592 L
.59188 .05921 L
.60224 .05922 L
.60797 .05922 L
.61317 .05922 L
.61811 .05922 L
.62081 .05923 L
.62334 .05923 L
.62583 .05923 L
.6281 .05923 L
.63062 .05923 L
.63201 .05923 L
.63333 .05923 L
.63444 .05923 L
.63562 .05923 L
.63673 .05923 L
.63774 .05923 L
.63893 .05923 L
.64021 .05923 L
.64143 .05923 L
.64254 .05923 L
.64504 .05923 L
.64737 .05923 L
.65266 .05923 L
.65782 .05922 L
Mistroke
.66334 .05922 L
.67355 .05922 L
.68464 .05921 L
.70477 .05919 L
.74563 .05914 L
.78497 .05908 L
.82279 .05902 L
.86307 .05894 L
.90183 .05887 L
.94304 .05879 L
.97619 .05873 L
Mfstroke
.292 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04127 L
.0379 .04214 L
.04033 .04334 L
.04262 .04418 L
.04761 .04549 L
.05217 .04635 L
.06244 .04796 L
.08259 .05139 L
.09399 .05391 L
.10458 .05684 L
.11466 .06041 L
.1238 .06464 L
.12887 .06757 L
.13435 .07141 L
.14429 .08098 L
.15372 .09505 L
.15901 .10581 L
.16384 .11677 L
.16656 .12255 L
.168 .12515 L
.16953 .1274 L
.17018 .12816 L
.17087 .12883 L
.17163 .12938 L
.17234 .12973 L
.173 .12989 L
.17369 .1299 L
.17493 .12949 L
.17617 .12858 L
.17686 .12786 L
.1775 .12708 L
.17988 .12329 L
.18529 .11165 L
.19504 .09078 L
.20054 .08197 L
.2056 .0759 L
.21004 .07197 L
.21492 .06887 L
.21737 .06771 L
.22001 .06672 L
.2225 .06599 L
.22478 .06548 L
Mistroke
.22607 .06526 L
.22729 .06509 L
.22839 .06496 L
.22956 .06485 L
.23084 .06477 L
.23201 .06472 L
.23327 .06469 L
.23398 .06469 L
.23465 .0647 L
.23584 .06473 L
.23696 .06478 L
.23797 .06484 L
.23907 .06492 L
.24153 .06516 L
.2438 .06546 L
.24859 .06625 L
.25386 .06733 L
.25907 .0685 L
.26454 .06966 L
.26688 .07009 L
.26938 .07048 L
.27081 .07067 L
.27211 .07081 L
.27344 .07092 L
.27466 .071 L
.27577 .07105 L
.27695 .07108 L
.27813 .07108 L
.27943 .07105 L
.28055 .07101 L
.28175 .07093 L
.28289 .07084 L
.28393 .07073 L
.28659 .07038 L
.28905 .06997 L
.29464 .06877 L
.3048 .06616 L
.31376 .06395 L
.32344 .06206 L
.32897 .06124 L
.33405 .06064 L
.33887 .06018 L
.34403 .0598 L
.34916 .05951 L
.35382 .0593 L
.36293 .05898 L
.38362 .05843 L
.4044 .05789 L
.42357 .05746 L
.44223 .05715 L
Mistroke
.45164 .05703 L
.46201 .05693 L
.48143 .05678 L
.50231 .05665 L
.52204 .05654 L
.54356 .05645 L
.58329 .05631 L
.62395 .05622 L
.6631 .05614 L
.7047 .05608 L
.74479 .05603 L
.78336 .05598 L
.82438 .05594 L
.86389 .05591 L
.90188 .05588 L
.94233 .05585 L
.97619 .05582 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03777 L
.03527 .0402 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04397 L
.04761 .04524 L
.05217 .04607 L
.06244 .04762 L
.08259 .05096 L
.09399 .0534 L
.10458 .05623 L
.11466 .05966 L
.1238 .06369 L
.12887 .06648 L
.13435 .07009 L
.13949 .07423 L
.14429 .07896 L
.15379 .09169 L
.15925 .10128 L
.16423 .11052 L
.16673 .11455 L
.16805 .11628 L
.16877 .11708 L
.16945 .11772 L
.17067 .11856 L
.17132 .11884 L
.17202 .11901 L
.17326 .11895 L
.17439 .11849 L
.17571 .11751 L
.17693 .11619 L
.1797 .11203 L
.18529 .10098 L
.19034 .09085 L
.19581 .08159 L
.20098 .0749 L
.20575 .07035 L
.21005 .06735 L
.21249 .06604 L
.21478 .06503 L
.21714 .06419 L
.21939 .06356 L
.22197 .063 L
Mistroke
.22434 .06264 L
.22559 .0625 L
.22624 .06244 L
.22694 .06239 L
.22821 .06231 L
.22938 .06227 L
.23051 .06225 L
.23156 .06225 L
.23271 .06227 L
.23395 .06232 L
.23527 .06239 L
.2367 .0625 L
.2393 .06275 L
.24418 .06343 L
.24882 .06428 L
.25375 .06534 L
.26258 .0674 L
.26716 .06836 L
.26966 .06881 L
.27198 .06915 L
.2745 .06944 L
.27583 .06956 L
.27652 .0696 L
.27726 .06965 L
.27856 .0697 L
.27979 .06972 L
.28099 .06972 L
.28209 .0697 L
.28315 .06966 L
.28428 .0696 L
.28535 .06952 L
.28633 .06943 L
.28872 .06916 L
.29098 .06883 L
.30038 .06692 L
.31858 .06276 L
.32357 .06185 L
.32894 .06102 L
.33868 .05992 L
.3437 .05951 L
.34898 .05918 L
.35843 .05874 L
.36846 .05841 L
.37943 .05809 L
.40066 .05749 L
.41996 .05697 L
.42958 .05674 L
.44002 .05654 L
.45897 .05626 L
.47883 .05605 L
Mistroke
.49986 .05587 L
.53772 .05562 L
.57802 .05543 L
.61681 .0553 L
.65806 .05519 L
.69779 .05512 L
.736 .05507 L
.77667 .05502 L
.81582 .05499 L
.85742 .05496 L
.8975 .05493 L
.93607 .05491 L
.97619 .05489 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04683 L
.06244 .0486 L
.08259 .05238 L
.09399 .05515 L
.10458 .05843 L
.11466 .06251 L
.1238 .0675 L
.12887 .07108 L
.13435 .07593 L
.13953 .08185 L
.14429 .089 L
.14899 .09846 L
.15157 .10512 L
.15402 .11267 L
.15878 .13176 L
.16311 .1551 L
.16791 .18468 L
.17054 .19882 L
.17183 .20429 L
.17301 .20825 L
.17429 .21132 L
.17496 .21242 L
.17567 .21321 L
.17639 .21365 L
.17707 .21372 L
.17781 .21347 L
.1786 .21285 L
.17927 .21206 L
.18 .21096 L
.18131 .20841 L
.18378 .20214 L
.19317 .1715 L
.20326 .14164 L
.20905 .1285 L
.21433 .11915 L
.21688 .11553 L
.21965 .11219 L
Mistroke
.22207 .10977 L
.22469 .10765 L
.22609 .10674 L
.22737 .10602 L
.22857 .10546 L
.22989 .10496 L
.23108 .10462 L
.23218 .10439 L
.23335 .10425 L
.2346 .10421 L
.2353 .10424 L
.23596 .10431 L
.23667 .10441 L
.23743 .10457 L
.23871 .10494 L
.24012 .10551 L
.24136 .10616 L
.24271 .10704 L
.24514 .1091 L
.24745 .11169 L
.24996 .11536 L
.25259 .12028 L
.25504 .12604 L
.25942 .1399 L
.2641 .16066 L
.2738 .22187 L
.28405 .29039 L
.28941 .3169 L
.29245 .32808 L
.29529 .33611 L
.29791 .34165 L
.30029 .34538 L
.30161 .34699 L
.30304 .3484 L
.30429 .3494 L
.30565 .35026 L
.30693 .35089 L
.30812 .35133 L
.30924 .35166 L
.31043 .35191 L
.31174 .35211 L
.31296 .35224 L
.31366 .3523 L
.31429 .35234 L
.31572 .35241 L
.31701 .35247 L
.31836 .35254 L
.31907 .35258 L
.31985 .35264 L
.32123 .35277 L
Mistroke
.32253 .35295 L
.32392 .3532 L
.32523 .3535 L
.32643 .35385 L
.32888 .35475 L
.33115 .35585 L
.3363 .35935 L
.34084 .36359 L
.34568 .36917 L
.36567 .39703 L
.37115 .40371 L
.37693 .40941 L
.38187 .41303 L
.38467 .41455 L
.38728 .41564 L
.38978 .41638 L
.39118 .41669 L
.39248 .4169 L
.39362 .41703 L
.39487 .41711 L
.39618 .41714 L
.39741 .41711 L
.39854 .41705 L
.39973 .41694 L
.40074 .41681 L
.40185 .41664 L
.40433 .41614 L
.40664 .41556 L
.41666 .4121 L
.42737 .40768 L
.4473 .40022 L
.46889 .39449 L
.50889 .38614 L
.54983 .37766 L
.58925 .37131 L
.62716 .36687 L
.66752 .36334 L
.70636 .36083 L
.74766 .3588 L
.78744 .3572 L
.82571 .35587 L
.86642 .35455 L
.90562 .35332 L
.94728 .35204 L
.97619 .35115 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04682 L
.06244 .04859 L
.08259 .05235 L
.09399 .05512 L
.10458 .05838 L
.11466 .06244 L
.1238 .06741 L
.12887 .07096 L
.13435 .07577 L
.13953 .08163 L
.14429 .08868 L
.14899 .09799 L
.15402 .11186 L
.15878 .13034 L
.16311 .15262 L
.1682 .1818 L
.16959 .18886 L
.17107 .19524 L
.17233 .19955 L
.17301 .20138 L
.17372 .20294 L
.17503 .20478 L
.17622 .20538 L
.1775 .20498 L
.17823 .20431 L
.17891 .20344 L
.18014 .20129 L
.18126 .19882 L
.18378 .19191 L
.19388 .15784 L
.19941 .14068 L
.20458 .12713 L
.20935 .11691 L
.21371 .10941 L
.21855 .10295 L
.22107 .10029 L
.22376 .09795 L
Mistroke
.22633 .09614 L
.22866 .09484 L
.231 .09385 L
.23205 .0935 L
.2332 .09318 L
.23445 .09292 L
.23514 .09281 L
.23578 .09273 L
.23692 .09263 L
.23815 .0926 L
.23884 .09262 L
.23958 .09266 L
.24029 .09273 L
.24094 .09281 L
.24218 .09303 L
.24349 .09334 L
.24571 .09407 L
.24809 .09513 L
.2524 .0978 L
.2549 .09983 L
.25753 .10239 L
.26222 .10842 L
.26481 .11275 L
.26724 .11761 L
.27179 .12879 L
.28201 .16119 L
.29076 .18924 L
.2954 .20147 L
.30038 .21187 L
.30542 .21968 L
.31013 .22496 L
.31552 .22935 L
.32044 .23248 L
.32939 .23778 L
.3389 .24492 L
.3488 .25523 L
.35796 .26719 L
.36795 .28137 L
.37872 .29563 L
.38365 .30119 L
.38886 .30618 L
.39368 .30996 L
.39816 .31277 L
.40238 .31482 L
.40689 .31646 L
.40946 .31716 L
.41189 .31768 L
.41407 .31806 L
.41643 .31836 L
.41879 .31858 L
Mistroke
.42011 .31867 L
.42131 .31873 L
.42244 .31877 L
.42366 .31881 L
.42481 .31882 L
.42588 .31882 L
.42654 .31882 L
.42724 .31881 L
.42853 .31879 L
.42977 .31876 L
.43092 .31872 L
.43353 .31861 L
.43629 .31847 L
.45732 .31704 L
.4772 .31571 L
.49531 .3142 L
.51484 .31193 L
.53576 .30891 L
.57562 .30285 L
.61397 .29757 L
.65477 .29249 L
.69406 .28805 L
.73183 .28416 L
.77205 .2803 L
.81076 .27679 L
.85192 .27321 L
.89157 .2699 L
.92969 .26683 L
.97027 .26369 L
.97619 .26324 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04034 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04552 L
.05217 .04639 L
.06244 .048 L
.08259 .05146 L
.09399 .05399 L
.10458 .05694 L
.11466 .06055 L
.1238 .06482 L
.12887 .06779 L
.13435 .07169 L
.14429 .08145 L
.16384 .11909 L
.16659 .12559 L
.16919 .13072 L
.17063 .13282 L
.17144 .13372 L
.17219 .13436 L
.17283 .13473 L
.17352 .13498 L
.17425 .13504 L
.17493 .13493 L
.1762 .13427 L
.17684 .13373 L
.17753 .13299 L
.17992 .12944 L
.1827 .12378 L
.18529 .11767 L
.19511 .09465 L
.19994 .08571 L
.20438 .07921 L
.20951 .07361 L
.21221 .07136 L
.21507 .06942 L
.21969 .06711 L
.22232 .06617 L
.22478 .06551 L
.22603 .06523 L
.22736 .06499 L
Mistroke
.22851 .06481 L
.22976 .06466 L
.23052 .06458 L
.23123 .06452 L
.23188 .06447 L
.23261 .06443 L
.23386 .06437 L
.23455 .06435 L
.23519 .06434 L
.23647 .06434 L
.23768 .06436 L
.23877 .0644 L
.23996 .06445 L
.24125 .06453 L
.24261 .06462 L
.24507 .06483 L
.24931 .06523 L
.25154 .06544 L
.25388 .06562 L
.25514 .06569 L
.2558 .06573 L
.2565 .06575 L
.25775 .06578 L
.2589 .06579 L
.26017 .06577 L
.26137 .06573 L
.26244 .06568 L
.2636 .06561 L
.26597 .06541 L
.26851 .06515 L
.27309 .06459 L
.28352 .06327 L
.30457 .06062 L
.31416 .05943 L
.32436 .05837 L
.32968 .05791 L
.33555 .05749 L
.34095 .05718 L
.3459 .05695 L
.35578 .05659 L
.36096 .05645 L
.36643 .05633 L
.38572 .05599 L
.39524 .05586 L
.40543 .05574 L
.41498 .05565 L
.42379 .05559 L
.42866 .05556 L
.43402 .05553 L
.43941 .05551 L
Mistroke
.44239 .05551 L
.44511 .0555 L
.44751 .0555 L
.45013 .05549 L
.45156 .05549 L
.45289 .05549 L
.45424 .05549 L
.45552 .05549 L
.45671 .05549 L
.45799 .05549 L
.45916 .05549 L
.46023 .05549 L
.4614 .05549 L
.46268 .05549 L
.46332 .05549 L
.46401 .05549 L
.46526 .05549 L
.46648 .05549 L
.46782 .05549 L
.47055 .05549 L
.47544 .05549 L
.48651 .0555 L
.50664 .05552 L
.54686 .05557 L
.58557 .05563 L
.62673 .05569 L
.66637 .05574 L
.7045 .05578 L
.74508 .05582 L
.78415 .05585 L
.82567 .05588 L
.86567 .0559 L
.90415 .05593 L
.94509 .05595 L
.97619 .05596 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04446 L
.04761 .04587 L
.05217 .04682 L
.06244 .04859 L
.08259 .05234 L
.09399 .05509 L
.10458 .05835 L
.11466 .06239 L
.1238 .06732 L
.12887 .07084 L
.13435 .07561 L
.13953 .08139 L
.14429 .08836 L
.14899 .09752 L
.15402 .11117 L
.15878 .12941 L
.16311 .15176 L
.1682 .18257 L
.17088 .19734 L
.17234 .20394 L
.17372 .20887 L
.17492 .21206 L
.17621 .21437 L
.1769 .21515 L
.17763 .21562 L
.17895 .21566 L
.18014 .21489 L
.18125 .21357 L
.18247 .21155 L
.18378 .20884 L
.20369 .14882 L
.20914 .13517 L
.21492 .1237 L
.21985 .11643 L
.22265 .1133 L
.22527 .11103 L
.22775 .10945 L
.22914 .1088 L
.23044 .10835 L
Mistroke
.23169 .10807 L
.23282 .10793 L
.23412 .10793 L
.23535 .10807 L
.23647 .10834 L
.23765 .10876 L
.23866 .10925 L
.23977 .10991 L
.24224 .11196 L
.24455 .11467 L
.24724 .11897 L
.24978 .12442 L
.25207 .13065 L
.25455 .13907 L
.26011 .16487 L
.26526 .19638 L
.27426 .255 L
.27673 .26832 L
.27932 .28002 L
.28154 .28795 L
.28396 .2944 L
.28536 .29709 L
.28663 .29891 L
.28733 .29967 L
.28809 .30031 L
.28881 .30073 L
.28947 .30097 L
.29066 .30107 L
.29196 .30072 L
.29262 .30037 L
.29333 .29988 L
.2946 .29869 L
.29588 .29714 L
.29728 .2951 L
.29981 .29058 L
.30457 .28002 L
.32394 .23035 L
.33496 .20776 L
.34001 .19972 L
.34532 .19277 L
.35002 .18781 L
.35517 .18348 L
.3642 .17804 L
.36929 .17582 L
.37474 .17383 L
.38456 .1707 L
.42602 .15477 L
.4468 .14697 L
.45593 .14421 L
.46597 .14169 L
Mistroke
.48463 .1382 L
.49485 .13678 L
.50441 .13566 L
.52296 .13387 L
.5432 .13234 L
.55417 .13168 L
.56435 .13116 L
.574 .13075 L
.58444 .13039 L
.59502 .13012 L
.59987 .13002 L
.60498 .12993 L
.6096 .12986 L
.61468 .1298 L
.61895 .12976 L
.62359 .12973 L
.62632 .12971 L
.62884 .1297 L
.63125 .12969 L
.63248 .12969 L
.63381 .12968 L
.635 .12968 L
.63609 .12968 L
.63714 .12968 L
.63823 .12968 L
.63944 .12967 L
.64057 .12967 L
.6418 .12967 L
.64312 .12968 L
.6438 .12968 L
.64453 .12968 L
.64582 .12968 L
.64722 .12968 L
.64876 .12969 L
.65151 .12969 L
.65408 .1297 L
.65888 .12973 L
.66404 .12976 L
.67418 .12984 L
.68523 .12996 L
.70533 .13023 L
.74605 .13092 L
.78525 .13166 L
.82691 .13246 L
.86705 .13319 L
.90567 .13383 L
.94674 .13446 L
.97619 .13487 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04229 L
.04033 .04353 L
.04262 .04442 L
.04761 .04581 L
.05217 .04675 L
.06244 .04849 L
.08259 .0522 L
.09399 .05493 L
.10458 .05814 L
.11466 .06212 L
.1238 .06695 L
.12887 .0704 L
.13435 .07503 L
.13953 .08064 L
.14429 .08732 L
.14899 .09602 L
.15402 .10874 L
.15878 .12523 L
.16311 .14444 L
.1682 .16853 L
.16959 .17414 L
.17107 .17908 L
.17233 .18229 L
.17305 .18366 L
.17372 .18464 L
.17495 .18566 L
.17625 .1857 L
.17735 .18498 L
.17856 .18346 L
.17987 .18111 L
.18126 .17793 L
.18378 .17095 L
.19345 .13962 L
.20369 .11231 L
.20904 .10204 L
.21492 .0936 L
.2175 .09072 L
.22027 .08811 L
.22527 .08451 L
.22793 .08309 L
.2304 .08206 L
Mistroke
.23311 .08119 L
.23462 .08081 L
.23599 .08054 L
.23722 .08034 L
.23851 .08018 L
.23919 .08012 L
.23993 .08006 L
.24123 .07999 L
.24247 .07996 L
.24379 .07996 L
.24503 .08 L
.24617 .08006 L
.25543 .08096 L
.25768 .08115 L
.25894 .08123 L
.2601 .08129 L
.2614 .08132 L
.26205 .08133 L
.26276 .08133 L
.26405 .08132 L
.26526 .08128 L
.26655 .08123 L
.26778 .08116 L
.27006 .08101 L
.27274 .08083 L
.27391 .08076 L
.27519 .0807 L
.2763 .08066 L
.27734 .08064 L
.27843 .08063 L
.2796 .08064 L
.28089 .08068 L
.2821 .08074 L
.28319 .08082 L
.28438 .08093 L
.28686 .08125 L
.28961 .08173 L
.29517 .08301 L
.30515 .08582 L
.3261 .09089 L
.33528 .0927 L
.34532 .09486 L
.36415 .10044 L
.38398 .10858 L
.40521 .11746 L
.42451 .1236 L
.43413 .12587 L
.44457 .12787 L
.46352 .13067 L
.48337 .13291 L
Mistroke
.49351 .13385 L
.50441 .13468 L
.51462 .1353 L
.52396 .13573 L
.52845 .13589 L
.53334 .13604 L
.53763 .13614 L
.54226 .13623 L
.54503 .13627 L
.54758 .1363 L
.55002 .13632 L
.55126 .13633 L
.55259 .13634 L
.5538 .13635 L
.5549 .13635 L
.55601 .13635 L
.55705 .13635 L
.55827 .13636 L
.5594 .13636 L
.56064 .13636 L
.56195 .13635 L
.56324 .13635 L
.56443 .13634 L
.5671 .13633 L
.56945 .13631 L
.57192 .13629 L
.57718 .13623 L
.58293 .13615 L
.59321 .13596 L
.60255 .13574 L
.62351 .1351 L
.66351 .13348 L
.702 .13156 L
.74294 .12932 L
.78236 .12708 L
.82027 .1249 L
.86063 .12262 L
.89947 .1205 L
.94077 .11835 L
.97619 .11662 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04584 L
.05217 .04678 L
.06244 .04852 L
.08259 .05222 L
.09399 .05494 L
.10458 .05815 L
.11466 .06211 L
.1238 .06692 L
.12887 .07035 L
.13435 .07495 L
.13953 .08049 L
.14429 .0871 L
.14899 .09567 L
.15402 .10823 L
.15878 .12461 L
.16311 .14415 L
.1682 .17034 L
.17088 .18265 L
.17234 .18807 L
.17372 .19204 L
.17492 .19452 L
.17621 .19618 L
.1769 .19665 L
.17763 .19684 L
.17895 .19643 L
.18014 .19531 L
.18125 .19372 L
.18247 .19144 L
.18378 .1885 L
.19345 .15923 L
.20369 .1296 L
.20904 .11768 L
.21492 .10766 L
.2175 .10425 L
.22027 .10119 L
.22269 .09902 L
.22527 .09719 L
.22667 .09641 L
Mistroke
.22793 .09581 L
.22922 .09532 L
.2304 .09497 L
.23108 .09482 L
.23179 .09469 L
.2325 .09459 L
.23328 .09453 L
.23396 .09451 L
.23468 .09452 L
.23599 .09464 L
.2373 .09489 L
.23804 .09509 L
.23873 .09531 L
.23996 .0958 L
.24132 .0965 L
.24367 .09811 L
.24617 .10045 L
.24864 .10353 L
.25091 .10711 L
.25602 .11835 L
.26052 .13222 L
.26526 .15017 L
.27018 .17017 L
.27483 .18725 L
.2774 .195 L
.28018 .20161 L
.28141 .2039 L
.28271 .2059 L
.28382 .20725 L
.28504 .20838 L
.28627 .20915 L
.28743 .20955 L
.28848 .20965 L
.28962 .2095 L
.29086 .20904 L
.29217 .20824 L
.2933 .20734 L
.29454 .20611 L
.29912 .19993 L
.30342 .19248 L
.32187 .15699 L
.33233 .14061 L
.34207 .12912 L
.35175 .12094 L
.35716 .11751 L
.36209 .11496 L
.37293 .11078 L
.38318 .10792 L
.42161 .09934 L
.44107 .09549 L
Mistroke
.4514 .09379 L
.4625 .09229 L
.47312 .09113 L
.48283 .09028 L
.50187 .08904 L
.52087 .08816 L
.5416 .08743 L
.56129 .08691 L
.57229 .0867 L
.58226 .08654 L
.5923 .08642 L
.60153 .08634 L
.61165 .08627 L
.61676 .08625 L
.61944 .08624 L
.62235 .08623 L
.62508 .08622 L
.6276 .08622 L
.63001 .08621 L
.63124 .08621 L
.63257 .08621 L
.63376 .08621 L
.63485 .08621 L
.63589 .08621 L
.63699 .08621 L
.6382 .08621 L
.63932 .08621 L
.64056 .08621 L
.64188 .08621 L
.64328 .08621 L
.64458 .08621 L
.64752 .08621 L
.6501 .08622 L
.65284 .08622 L
.66279 .08625 L
.67224 .08629 L
.68238 .08634 L
.7007 .08645 L
.742 .08676 L
.78178 .08711 L
.82004 .08744 L
.86076 .08778 L
.89996 .08808 L
.94162 .08838 L
.97619 .0886 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .0423 L
.04033 .04354 L
.04262 .04444 L
.04761 .04584 L
.05217 .04678 L
.06244 .04854 L
.08259 .05228 L
.09399 .05502 L
.10458 .05826 L
.11466 .06228 L
.1238 .06718 L
.12887 .07068 L
.13435 .0754 L
.13953 .08112 L
.14429 .08799 L
.14899 .09698 L
.15402 .11025 L
.15878 .12766 L
.16311 .14826 L
.1682 .1746 L
.16959 .18083 L
.17107 .18637 L
.17233 .19002 L
.17305 .19162 L
.17372 .19278 L
.17495 .19408 L
.17625 .19435 L
.17735 .19375 L
.17856 .19234 L
.17987 .19003 L
.18126 .18686 L
.18378 .17978 L
.19345 .14745 L
.20369 .11865 L
.20904 .10763 L
.21492 .09849 L
.2175 .09536 L
.22027 .09252 L
.22527 .0886 L
.22793 .08707 L
.2304 .08596 L
Mistroke
.23311 .08505 L
.23462 .08467 L
.23599 .0844 L
.2373 .08421 L
.23851 .08408 L
.23914 .08404 L
.23984 .084 L
.24056 .08398 L
.24123 .08397 L
.24248 .084 L
.24362 .08406 L
.24493 .08417 L
.24617 .08431 L
.24847 .08467 L
.25092 .08515 L
.25532 .08619 L
.2605 .08755 L
.26526 .08901 L
.26984 .0909 L
.27465 .09372 L
.27949 .09752 L
.28477 .10261 L
.29418 .11265 L
.30306 .12111 L
.308 .12493 L
.31336 .12832 L
.32271 .13287 L
.3327 .13697 L
.34367 .14204 L
.35397 .14822 L
.36359 .15535 L
.38464 .17301 L
.39508 .18089 L
.40497 .18698 L
.41385 .19121 L
.42352 .19462 L
.4329 .19701 L
.44327 .19892 L
.4541 .20042 L
.46427 .20155 L
.47408 .20244 L
.48443 .20319 L
.49326 .20366 L
.49826 .20385 L
.50292 .20398 L
.50554 .20404 L
.50796 .20407 L
.50923 .20409 L
.51062 .2041 L
.51132 .2041 L
Mistroke
.51207 .20411 L
.51278 .20411 L
.51343 .20411 L
.51469 .20411 L
.51586 .2041 L
.51715 .2041 L
.51787 .20409 L
.51852 .20409 L
.52101 .20406 L
.52336 .20402 L
.52801 .20391 L
.53228 .20378 L
.54194 .2034 L
.56078 .20237 L
.58144 .20097 L
.62189 .19782 L
.66082 .19447 L
.7022 .19077 L
.74206 .1872 L
.78041 .18381 L
.82121 .18028 L
.8605 .17699 L
.89827 .17394 L
.93849 .17085 L
.97619 .16811 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .04231 L
.04033 .04356 L
.04262 .04445 L
.04761 .04586 L
.05217 .0468 L
.06244 .04856 L
.08259 .0523 L
.09399 .05504 L
.10458 .05828 L
.11466 .0623 L
.1238 .06719 L
.12887 .07069 L
.13435 .07539 L
.13953 .08111 L
.14429 .08795 L
.14899 .09692 L
.15402 .11019 L
.15878 .12775 L
.16311 .14897 L
.1682 .17759 L
.17088 .19093 L
.17223 .19631 L
.17301 .19889 L
.17372 .2009 L
.17502 .20364 L
.1757 .20461 L
.17642 .2053 L
.17762 .20572 L
.17895 .20519 L
.18016 .20391 L
.18145 .20184 L
.18378 .19666 L
.19345 .16636 L
.20369 .13575 L
.20904 .1233 L
.21492 .11279 L
.2175 .10919 L
.22027 .10597 L
.22269 .10368 L
.22527 .10176 L
.22667 .10093 L
Mistroke
.22793 .10031 L
.22922 .09981 L
.2304 .09946 L
.23108 .0993 L
.23179 .09918 L
.2325 .09909 L
.23328 .09904 L
.23396 .09903 L
.23468 .09906 L
.23599 .09923 L
.2373 .09954 L
.23804 .09978 L
.23873 .10005 L
.23996 .10064 L
.24132 .10146 L
.24367 .10336 L
.24617 .10614 L
.24864 .10982 L
.25091 .11415 L
.2534 .12015 L
.25602 .12804 L
.26043 .14515 L
.26526 .16849 L
.27011 .19414 L
.27537 .22008 L
.27778 .23027 L
.28033 .23947 L
.28254 .24601 L
.2849 .25155 L
.28632 .25415 L
.28761 .25607 L
.28891 .25758 L
.29014 .25865 L
.29084 .2591 L
.29157 .25947 L
.2922 .2597 L
.2929 .25986 L
.29364 .25993 L
.29444 .2599 L
.2952 .25976 L
.2959 .25956 L
.2971 .25904 L
.29821 .25838 L
.30075 .25633 L
.30587 .25048 L
.32458 .22427 L
.32971 .21841 L
.33514 .21339 L
.33978 .21011 L
.34239 .20866 L
Mistroke
.34488 .20753 L
.34765 .20655 L
.35019 .20588 L
.3516 .20559 L
.35292 .20537 L
.35436 .20519 L
.35516 .20511 L
.35589 .20505 L
.35653 .20501 L
.35723 .20497 L
.35794 .20494 L
.35868 .20492 L
.35933 .20491 L
.36004 .20491 L
.3613 .20492 L
.36262 .20496 L
.36387 .20501 L
.3662 .20514 L
.37088 .20545 L
.37345 .20562 L
.37585 .20575 L
.3771 .20579 L
.37774 .20581 L
.37845 .20583 L
.37917 .20584 L
.37994 .20585 L
.38065 .20585 L
.38131 .20585 L
.38258 .20583 L
.38374 .20579 L
.38439 .20576 L
.38508 .20572 L
.38635 .20564 L
.38871 .20542 L
.39124 .2051 L
.39582 .20429 L
.40127 .20296 L
.40624 .20144 L
.42729 .19328 L
.44793 .18553 L
.45798 .1825 L
.46707 .1802 L
.48561 .17659 L
.50533 .17371 L
.52626 .1712 L
.54547 .16927 L
.56427 .16775 L
.57385 .16713 L
.58409 .16656 L
.5944 .1661 L
Mistroke
.60379 .16574 L
.62214 .16523 L
.63209 .16504 L
.64127 .1649 L
.65136 .16479 L
.65645 .16475 L
.65913 .16474 L
.66205 .16472 L
.66475 .16471 L
.66725 .1647 L
.66964 .1647 L
.67097 .16469 L
.67218 .16469 L
.67338 .16469 L
.67448 .16469 L
.67568 .16469 L
.67696 .16469 L
.67807 .16469 L
.6791 .16469 L
.68024 .16469 L
.68145 .16469 L
.68285 .16469 L
.68414 .1647 L
.68706 .1647 L
.68964 .16471 L
.69237 .16472 L
.70233 .16478 L
.71169 .16485 L
.72179 .16494 L
.74007 .16515 L
.7812 .16572 L
.82081 .16632 L
.8589 .1669 L
.89945 .16747 L
.93849 .16797 L
.97619 .16841 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .0379 L
.03527 .04039 L
.03652 .04135 L
.0379 .04223 L
.04033 .04346 L
.04262 .04434 L
.04761 .0457 L
.05217 .04662 L
.06244 .04832 L
.08259 .05195 L
.09399 .05462 L
.10458 .05775 L
.11466 .06162 L
.1238 .06628 L
.12887 .06958 L
.13435 .07399 L
.13953 .07927 L
.14429 .0855 L
.14935 .09419 L
.15414 .10521 L
.15967 .12236 L
.16471 .14171 L
.16699 .15049 L
.16914 .15772 L
.1703 .16096 L
.17137 .16337 L
.17256 .16535 L
.17384 .16662 L
.17504 .16698 L
.17636 .16651 L
.17702 .16596 L
.17773 .16515 L
.179 .16318 L
.1815 .1578 L
.18378 .15174 L
.19337 .12356 L
.19862 .11031 L
.20353 .10022 L
.20806 .09284 L
.21221 .08753 L
.21681 .08301 L
.21937 .08103 L
.22175 .07949 L
.22646 .07718 L
Mistroke
.22894 .0763 L
.23159 .07559 L
.2328 .07534 L
.23412 .07511 L
.23527 .07495 L
.23649 .07481 L
.2376 .07472 L
.23881 .07464 L
.23991 .07461 L
.24093 .07459 L
.24223 .0746 L
.24296 .07462 L
.24363 .07465 L
.24487 .07471 L
.24619 .0748 L
.24847 .07501 L
.25098 .07528 L
.25622 .07585 L
.25749 .07596 L
.25885 .07606 L
.25963 .0761 L
.26034 .07613 L
.26106 .07615 L
.26173 .07616 L
.26296 .07616 L
.26426 .07612 L
.26537 .07607 L
.26659 .07598 L
.2679 .07586 L
.26931 .0757 L
.27185 .07533 L
.28112 .0736 L
.28672 .07264 L
.28947 .07227 L
.29203 .07199 L
.29434 .0718 L
.29679 .07166 L
.29807 .07161 L
.29926 .07157 L
.30057 .07154 L
.30131 .07154 L
.30199 .07153 L
.30326 .07153 L
.30446 .07154 L
.30554 .07155 L
.30671 .07157 L
.30799 .0716 L
.30935 .07164 L
.31177 .07172 L
.32089 .07215 L
Mistroke
.33086 .07273 L
.34158 .07347 L
.35179 .07439 L
.36113 .07548 L
.37943 .07832 L
.40004 .08205 L
.41916 .08506 L
.43766 .0872 L
.45737 .0888 L
.4788 .0901 L
.49898 .09107 L
.50875 .09145 L
.51907 .09178 L
.52874 .09204 L
.53755 .09222 L
.54703 .09236 L
.55226 .09242 L
.5572 .09247 L
.56176 .0925 L
.56599 .09252 L
.57062 .09254 L
.57296 .09255 L
.57429 .09255 L
.57554 .09256 L
.57668 .09256 L
.57789 .09256 L
.57858 .09256 L
.57924 .09256 L
.58046 .09256 L
.58175 .09256 L
.58295 .09256 L
.58426 .09256 L
.58492 .09256 L
.58564 .09256 L
.58795 .09255 L
.59043 .09255 L
.5949 .09253 L
.60049 .09251 L
.6058 .09248 L
.61576 .0924 L
.63562 .09219 L
.65403 .09193 L
.69323 .09121 L
.73488 .09028 L
.77502 .0893 L
.81364 .08832 L
.85472 .08727 L
.89428 .08629 L
.93232 .08537 L
.97282 .08446 L
Mistroke
.97619 .08438 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .0435 L
.04262 .04439 L
.04761 .04576 L
.05217 .04669 L
.06244 .0484 L
.08259 .05206 L
.09399 .05474 L
.10458 .0579 L
.11466 .0618 L
.1238 .06651 L
.12887 .06985 L
.13435 .07431 L
.13953 .07966 L
.14429 .08599 L
.14935 .09484 L
.15414 .10611 L
.15967 .12375 L
.16471 .14386 L
.16914 .16081 L
.17021 .16405 L
.17137 .16695 L
.17265 .16931 L
.17384 .17069 L
.17515 .17127 L
.17581 .17121 L
.17653 .17087 L
.17781 .16967 L
.179 .16791 L
.18131 .16311 L
.18378 .15659 L
.19263 .12999 L
.202 .1067 L
.20689 .09777 L
.21227 .09025 L
.21717 .08517 L
.22175 .08167 L
.22451 .08005 L
.22712 .07881 L
.2295 .0779 L
.23204 .07715 L
Mistroke
.23348 .07681 L
.23478 .07655 L
.23611 .07634 L
.23733 .07618 L
.23876 .07604 L
.23951 .07599 L
.2403 .07595 L
.24099 .07592 L
.24163 .0759 L
.24234 .07589 L
.24309 .07589 L
.24375 .0759 L
.24444 .07592 L
.24569 .07597 L
.24638 .07601 L
.24703 .07605 L
.24851 .07617 L
.25364 .07669 L
.2559 .07694 L
.25827 .07716 L
.25951 .07725 L
.26016 .07729 L
.26087 .07733 L
.2621 .07737 L
.26325 .07738 L
.26448 .07737 L
.26519 .07734 L
.26584 .07731 L
.26654 .07727 L
.26717 .07723 L
.26859 .07709 L
.2698 .07694 L
.27112 .07675 L
.27351 .07632 L
.28463 .07345 L
.29421 .07097 L
.29967 .06989 L
.3048 .06913 L
.30721 .06885 L
.30975 .0686 L
.3143 .06826 L
.31683 .06813 L
.31919 .06803 L
.32178 .06795 L
.32323 .06792 L
.32455 .0679 L
.32585 .06788 L
.32651 .06787 L
.32724 .06787 L
.32852 .06786 L
Mistroke
.32972 .06786 L
.33045 .06786 L
.33114 .06786 L
.33243 .06787 L
.33315 .06787 L
.33382 .06788 L
.33534 .0679 L
.33793 .06794 L
.34028 .06799 L
.34555 .06815 L
.35043 .06835 L
.35558 .06861 L
.36481 .06922 L
.38563 .07117 L
.42362 .07529 L
.44315 .07694 L
.46407 .07835 L
.48389 .07948 L
.50545 .08053 L
.5244 .08129 L
.54531 .08194 L
.5651 .08239 L
.57594 .08258 L
.58612 .08272 L
.59596 .08283 L
.60631 .08292 L
.61516 .08298 L
.62017 .083 L
.62482 .08302 L
.62728 .08303 L
.62988 .08303 L
.63124 .08304 L
.63273 .08304 L
.6341 .08304 L
.63536 .08304 L
.63663 .08304 L
.63783 .08304 L
.63911 .08304 L
.63983 .08304 L
.64049 .08304 L
.64171 .08304 L
.64282 .08304 L
.6441 .08304 L
.6453 .08304 L
.64756 .08304 L
.64996 .08303 L
.65424 .08302 L
.65884 .08301 L
.66389 .08299 L
.67413 .08293 L
Mistroke
.68345 .08287 L
.70438 .08268 L
.7443 .0822 L
.7827 .08162 L
.82356 .08094 L
.8629 .08026 L
.90072 .0796 L
.94099 .07892 L
.97619 .07836 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04576 L
.05217 .04668 L
.06244 .04838 L
.08259 .05202 L
.09399 .05469 L
.10458 .05782 L
.11466 .06168 L
.1238 .06634 L
.12887 .06963 L
.13435 .07402 L
.13953 .07926 L
.14429 .08542 L
.14935 .09396 L
.15414 .10473 L
.15967 .12133 L
.16471 .13985 L
.16699 .14821 L
.16914 .15509 L
.1703 .15816 L
.17137 .16045 L
.17256 .16233 L
.17384 .16353 L
.17504 .16386 L
.17636 .16338 L
.17702 .16283 L
.17773 .16203 L
.179 .16008 L
.1815 .15476 L
.18378 .14876 L
.19337 .12085 L
.19862 .10782 L
.20353 .09799 L
.20806 .09085 L
.21221 .08574 L
.21681 .0814 L
.21937 .0795 L
.22175 .07803 L
.22646 .07581 L
Mistroke
.22894 .07497 L
.23159 .07429 L
.2328 .07404 L
.23412 .07382 L
.23527 .07367 L
.23649 .07354 L
.2376 .07345 L
.23881 .07338 L
.23991 .07334 L
.24093 .07333 L
.24223 .07335 L
.24296 .07337 L
.24363 .07339 L
.24487 .07346 L
.24619 .07356 L
.24847 .07378 L
.25098 .07408 L
.25622 .0748 L
.25908 .07516 L
.26047 .0753 L
.26173 .07541 L
.26293 .0755 L
.26407 .07555 L
.26527 .07559 L
.26657 .07559 L
.2672 .07558 L
.2679 .07556 L
.26863 .07552 L
.26932 .07548 L
.27054 .07538 L
.27185 .07523 L
.27434 .07486 L
.27669 .07439 L
.28112 .07326 L
.29123 .07007 L
.30199 .06696 L
.30653 .06593 L
.31143 .06503 L
.31681 .06426 L
.32187 .06373 L
.32655 .06337 L
.3291 .06322 L
.33147 .0631 L
.33568 .06294 L
.3379 .06288 L
.34028 .06283 L
.34286 .06279 L
.34417 .06277 L
.3456 .06276 L
.34682 .06275 L
Mistroke
.34814 .06274 L
.34937 .06274 L
.35051 .06274 L
.35119 .06274 L
.35192 .06274 L
.35323 .06274 L
.35403 .06274 L
.35479 .06275 L
.3562 .06275 L
.3588 .06278 L
.3616 .06281 L
.36671 .06289 L
.3721 .06299 L
.38175 .06324 L
.41974 .06459 L
.46018 .06588 L
.49911 .06683 L
.51894 .06723 L
.54049 .06758 L
.56121 .06784 L
.58036 .06803 L
.59904 .06817 L
.60967 .06823 L
.61964 .06827 L
.62949 .06831 L
.63443 .06832 L
.63984 .06833 L
.64448 .06834 L
.64703 .06834 L
.64943 .06834 L
.65168 .06834 L
.65286 .06834 L
.65411 .06835 L
.65516 .06835 L
.65632 .06835 L
.65737 .06835 L
.65835 .06835 L
.65961 .06835 L
.66031 .06835 L
.66094 .06835 L
.66218 .06835 L
.66334 .06835 L
.6647 .06835 L
.66595 .06834 L
.66877 .06834 L
.67107 .06834 L
.67358 .06834 L
.67865 .06833 L
.68825 .06831 L
.6972 .06829 L
Mistroke
.7176 .06822 L
.73618 .06814 L
.77609 .06792 L
.8145 .06766 L
.85535 .06737 L
.89469 .06707 L
.93251 .0668 L
.97279 .06651 L
.97619 .06649 L
Mfstroke
.601 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04225 L
.04033 .04347 L
.04262 .04434 L
.04761 .0457 L
.05217 .0466 L
.06244 .04827 L
.08259 .05185 L
.09399 .05447 L
.10458 .05754 L
.11466 .06132 L
.1238 .06584 L
.12887 .06902 L
.13435 .07323 L
.14429 .08401 L
.16384 .12928 L
.16659 .13764 L
.16919 .14429 L
.17063 .14704 L
.17144 .14822 L
.17219 .14906 L
.17283 .14956 L
.17352 .1499 L
.17425 .15002 L
.17493 .14991 L
.1762 .14917 L
.17684 .14855 L
.17753 .14769 L
.17992 .14358 L
.1827 .1371 L
.18529 .13021 L
.19511 .10466 L
.19994 .09479 L
.20438 .08756 L
.20951 .08122 L
.21216 .07866 L
.21507 .07633 L
.21979 .07346 L
.22237 .0723 L
.22478 .07144 L
.22736 .07073 L
.22976 .07024 L
Mistroke
.23114 .07002 L
.23239 .06987 L
.23308 .0698 L
.23383 .06974 L
.23453 .06969 L
.23519 .06965 L
.23638 .06961 L
.23769 .06959 L
.23897 .06961 L
.23968 .06963 L
.24034 .06965 L
.2415 .06972 L
.24277 .06981 L
.24507 .07003 L
.24974 .07067 L
.2547 .0715 L
.25904 .07223 L
.26141 .07257 L
.2636 .07283 L
.26483 .07294 L
.26595 .07302 L
.26719 .07308 L
.26851 .07312 L
.26962 .07312 L
.27082 .0731 L
.27195 .07305 L
.273 .07298 L
.27421 .07287 L
.27534 .07274 L
.27792 .07235 L
.28042 .07186 L
.28311 .07122 L
.30141 .06591 L
.31156 .06357 L
.3173 .0626 L
.32262 .06191 L
.32725 .06146 L
.33237 .06107 L
.33771 .06078 L
.34273 .06059 L
.34742 .06046 L
.35008 .06041 L
.35255 .06036 L
.35755 .0603 L
.36035 .06027 L
.36289 .06025 L
.36745 .06022 L
.37003 .06021 L
.3724 .0602 L
.37466 .06019 L
Mistroke
.37677 .06019 L
.37897 .06018 L
.38013 .06018 L
.38139 .06018 L
.38208 .06018 L
.38272 .06018 L
.38393 .06018 L
.38523 .06018 L
.38596 .06018 L
.38664 .06018 L
.38777 .06018 L
.389 .06018 L
.3903 .06019 L
.3915 .06019 L
.39429 .06019 L
.39683 .0602 L
.40254 .06022 L
.40748 .06025 L
.41286 .06028 L
.42263 .06035 L
.46344 .06067 L
.50272 .06093 L
.52243 .06103 L
.54049 .06111 L
.55985 .06117 L
.57002 .06119 L
.58072 .06121 L
.59027 .06123 L
.59552 .06123 L
.60047 .06124 L
.60509 .06124 L
.60753 .06124 L
.6101 .06124 L
.61227 .06124 L
.61465 .06125 L
.6157 .06125 L
.61682 .06125 L
.61786 .06125 L
.61884 .06125 L
.61949 .06125 L
.62018 .06125 L
.62139 .06125 L
.62208 .06125 L
.62281 .06125 L
.62411 .06125 L
.62531 .06125 L
.62644 .06125 L
.62767 .06125 L
.62899 .06125 L
.63196 .06125 L
Mistroke
.63477 .06124 L
.64003 .06124 L
.64505 .06124 L
.64967 .06123 L
.66014 .06122 L
.67886 .06119 L
.69948 .06115 L
.73975 .06104 L
.77851 .06092 L
.81973 .06077 L
.85942 .06062 L
.8976 .06048 L
.93824 .06033 L
.97619 .0602 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04585 L
.05217 .04679 L
.06244 .04854 L
.08259 .05227 L
.09399 .05501 L
.10458 .05824 L
.11466 .06225 L
.1238 .06713 L
.12887 .07061 L
.13435 .07529 L
.13953 .08096 L
.14429 .08775 L
.14899 .0966 L
.15402 .10961 L
.15878 .1266 L
.16311 .14664 L
.1682 .17232 L
.16959 .17846 L
.17107 .18397 L
.17233 .18765 L
.17305 .18928 L
.17372 .19049 L
.17495 .19189 L
.17625 .19229 L
.17735 .19181 L
.17856 .19051 L
.17987 .18834 L
.18126 .18528 L
.18378 .17836 L
.19345 .14612 L
.20369 .11721 L
.20904 .10622 L
.21492 .09722 L
.2175 .09417 L
.22027 .09145 L
.22269 .08949 L
.22527 .08779 L
.22793 .08643 L
Mistroke
.2304 .0855 L
.23191 .08507 L
.23333 .08477 L
.23461 .08457 L
.23533 .08449 L
.23599 .08443 L
.23721 .08438 L
.23835 .08438 L
.2396 .08445 L
.2403 .08451 L
.24094 .08459 L
.24223 .08479 L
.24363 .08508 L
.24617 .0858 L
.24846 .08666 L
.25098 .08784 L
.25609 .09099 L
.26082 .09506 L
.26526 .10032 L
.26997 .10785 L
.27511 .11831 L
.28548 .14282 L
.29012 .15304 L
.29508 .16223 L
.29975 .16896 L
.304 .17346 L
.30631 .17536 L
.30886 .17704 L
.31134 .17834 L
.314 .17945 L
.31877 .18089 L
.32322 .18191 L
.3288 .18316 L
.3341 .18464 L
.33885 .18639 L
.34403 .18888 L
.35341 .1949 L
.36378 .20323 L
.37473 .21233 L
.37953 .21593 L
.38478 .21937 L
.38933 .22185 L
.39419 .22395 L
.39688 .22486 L
.39932 .22554 L
.40164 .22606 L
.4041 .22648 L
.40538 .22665 L
.40678 .2268 L
.40805 .2269 L
Mistroke
.40924 .22697 L
.40996 .227 L
.41065 .22702 L
.41193 .22703 L
.41265 .22703 L
.41331 .22702 L
.41404 .22701 L
.41482 .22698 L
.41614 .22692 L
.41756 .22683 L
.42014 .2266 L
.42495 .22602 L
.43446 .22444 L
.4449 .22245 L
.46597 .21868 L
.50642 .21277 L
.54535 .20704 L
.58673 .20174 L
.62659 .19782 L
.66494 .19484 L
.70574 .19232 L
.74503 .19034 L
.7828 .18872 L
.82302 .18717 L
.86173 .18581 L
.90289 .18443 L
.94254 .18317 L
.97619 .18213 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03057 L
.03068 .03492 L
.03279 .03785 L
.03527 .04029 L
.03652 .04123 L
.0379 .04209 L
.04033 .04327 L
.04262 .04411 L
.04761 .04539 L
.05217 .04624 L
.06244 .04782 L
.08259 .05121 L
.09399 .05369 L
.10458 .05657 L
.11466 .06008 L
.1238 .06422 L
.12887 .06708 L
.13435 .07081 L
.13949 .0751 L
.14429 .08003 L
.15379 .09349 L
.15925 .1038 L
.16423 .11388 L
.16673 .11832 L
.16805 .12024 L
.16877 .12113 L
.16945 .12184 L
.17067 .1228 L
.17132 .12312 L
.17202 .12332 L
.17326 .12329 L
.17439 .12282 L
.17571 .1218 L
.17693 .12041 L
.1797 .11603 L
.18529 .10445 L
.19034 .09389 L
.19581 .08425 L
.20098 .07726 L
.20575 .07248 L
.21005 .0693 L
.21478 .06682 L
.21716 .0659 L
.21972 .06512 L
.22213 .06456 L
.22434 .06418 L
Mistroke
.22563 .06401 L
.22685 .06388 L
.22794 .06379 L
.22912 .06372 L
.23041 .06368 L
.23106 .06366 L
.23177 .06366 L
.23303 .06367 L
.23421 .0637 L
.2354 .06375 L
.23652 .06382 L
.23863 .06399 L
.2409 .06423 L
.24336 .06456 L
.25414 .06655 L
.25893 .06756 L
.2641 .06853 L
.26655 .06891 L
.26789 .06908 L
.26914 .06922 L
.27029 .06932 L
.27134 .0694 L
.27251 .06947 L
.27375 .06951 L
.27491 .06953 L
.27599 .06953 L
.27716 .0695 L
.27841 .06944 L
.27949 .06937 L
.2805 .06928 L
.2828 .06903 L
.28547 .06864 L
.288 .06818 L
.29275 .06715 L
.30342 .0645 L
.31305 .06233 L
.31834 .06136 L
.3233 .06061 L
.33205 .05962 L
.3367 .05924 L
.34171 .05891 L
.34666 .05867 L
.35127 .05849 L
.36173 .05818 L
.38282 .05773 L
.40153 .05733 L
.42183 .05696 L
.43292 .05681 L
.44316 .05669 L
.4633 .05654 L
Mistroke
.48204 .05643 L
.50267 .05634 L
.54298 .05618 L
.58177 .05608 L
.62301 .05599 L
.66274 .05592 L
.70096 .05586 L
.74162 .0558 L
.78077 .05575 L
.82237 .0557 L
.86246 .05566 L
.90103 .05562 L
.94205 .05558 L
.97619 .05554 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .0404 L
.03652 .04136 L
.0379 .04225 L
.04033 .04347 L
.04262 .04434 L
.04761 .04569 L
.05217 .04658 L
.06244 .04823 L
.08259 .05177 L
.09399 .05436 L
.10458 .05739 L
.11466 .0611 L
.1238 .06553 L
.12887 .06862 L
.13435 .0727 L
.14429 .08303 L
.16384 .12493 L
.16659 .13269 L
.16919 .13905 L
.17063 .14181 L
.17139 .14299 L
.17219 .144 L
.17287 .14465 L
.17362 .14515 L
.17493 .14546 L
.17559 .14534 L
.17627 .14503 L
.1775 .14402 L
.17819 .14322 L
.17883 .14234 L
.18028 .13987 L
.18529 .12805 L
.19511 .10222 L
.19994 .09192 L
.20438 .08436 L
.20951 .07779 L
.21221 .07513 L
.21507 .07283 L
.21969 .07005 L
.22232 .06892 L
.22478 .0681 L
.22736 .06745 L
.22976 .06703 L
Mistroke
.23114 .06685 L
.23239 .06673 L
.23308 .06668 L
.23383 .06663 L
.23454 .0666 L
.23519 .06658 L
.23637 .06656 L
.23748 .06657 L
.23869 .0666 L
.23999 .06666 L
.24136 .06674 L
.24265 .06684 L
.24507 .06708 L
.25388 .06819 L
.2563 .06846 L
.2589 .06869 L
.26136 .06886 L
.2636 .06898 L
.26586 .06906 L
.26832 .06913 L
.27092 .0692 L
.27328 .06924 L
.27452 .06927 L
.27586 .06928 L
.27659 .06929 L
.27727 .0693 L
.27792 .0693 L
.27861 .0693 L
.27982 .0693 L
.28096 .06928 L
.28221 .06926 L
.28291 .06924 L
.28355 .06922 L
.28469 .06918 L
.2859 .06912 L
.28808 .06898 L
.29043 .06877 L
.29301 .06849 L
.30199 .06709 L
.31219 .0651 L
.32293 .0631 L
.33289 .0616 L
.34216 .06054 L
.35107 .0598 L
.36061 .05924 L
.37119 .05879 L
.38081 .05849 L
.39997 .05804 L
.42076 .05768 L
.44061 .05743 L
Mistroke
.45062 .05734 L
.46165 .05727 L
.47179 .05723 L
.48107 .0572 L
.48619 .05718 L
.49178 .05717 L
.50195 .05715 L
.50727 .05715 L
.51228 .05714 L
.51684 .05714 L
.52164 .05714 L
.52415 .05714 L
.52689 .05713 L
.52942 .05713 L
.53172 .05713 L
.53444 .05713 L
.53594 .05713 L
.53736 .05713 L
.53867 .05713 L
.53988 .05713 L
.54051 .05713 L
.54121 .05713 L
.54194 .05713 L
.54262 .05713 L
.5438 .05713 L
.54506 .05713 L
.54624 .05713 L
.54732 .05713 L
.54997 .05713 L
.55246 .05713 L
.55743 .05713 L
.56282 .05714 L
.57245 .05714 L
.58133 .05715 L
.62075 .05719 L
.65866 .05723 L
.69902 .05728 L
.73786 .05733 L
.77916 .05738 L
.81894 .05742 L
.8572 .05746 L
.89792 .0575 L
.93712 .05753 L
.97619 .05756 L
Mfstroke
.696 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04585 L
.05217 .04679 L
.06244 .04854 L
.08259 .05224 L
.09399 .05496 L
.10458 .05817 L
.11466 .06214 L
.1238 .06697 L
.12887 .0704 L
.13435 .07501 L
.13953 .08057 L
.14429 .08719 L
.14899 .09579 L
.15402 .10837 L
.15878 .12477 L
.16311 .14428 L
.1682 .17036 L
.17088 .18258 L
.17234 .18795 L
.17372 .19187 L
.17492 .19431 L
.17621 .19593 L
.1769 .19638 L
.17763 .19654 L
.17895 .19607 L
.18014 .19489 L
.18125 .19323 L
.18247 .19087 L
.18378 .18782 L
.19345 .15731 L
.20369 .1261 L
.20904 .11354 L
.21492 .10304 L
.2175 .09946 L
.22027 .09625 L
.22269 .09394 L
.22527 .09196 L
.22793 .0904 L
Mistroke
.2304 .08935 L
.23191 .0889 L
.23265 .08872 L
.23333 .08859 L
.23461 .08842 L
.23528 .08836 L
.23599 .08834 L
.2372 .08835 L
.2385 .08847 L
.23973 .08866 L
.24085 .08892 L
.24216 .08931 L
.24358 .08986 L
.24617 .0912 L
.24846 .09278 L
.25098 .095 L
.25344 .09769 L
.25609 .10128 L
.26082 .10981 L
.26526 .12062 L
.27566 .15274 L
.28073 .16716 L
.28294 .17232 L
.28534 .17694 L
.28664 .17901 L
.28785 .18062 L
.28907 .18197 L
.29022 .18297 L
.29142 .18376 L
.29206 .18407 L
.29275 .18432 L
.29347 .1845 L
.29415 .18459 L
.29543 .18456 L
.29606 .18445 L
.29675 .18426 L
.29748 .18399 L
.29817 .18367 L
.3007 .182 L
.30347 .17943 L
.30645 .176 L
.32607 .14861 L
.33145 .14214 L
.3372 .13626 L
.34258 .13175 L
.34756 .12841 L
.35267 .12569 L
.35822 .12347 L
.36311 .122 L
.36829 .12083 L
Mistroke
.37727 .11937 L
.38715 .11808 L
.42745 .11061 L
.44601 .10684 L
.46625 .10371 L
.47722 .10246 L
.4874 .10152 L
.50749 .10011 L
.52803 .09901 L
.54664 .09821 L
.5659 .09757 L
.57583 .09731 L
.58673 .09708 L
.59636 .09692 L
.60668 .09678 L
.61238 .09672 L
.61758 .09668 L
.62251 .09664 L
.62775 .09661 L
.63247 .09658 L
.63767 .09656 L
.63995 .09656 L
.64241 .09655 L
.64471 .09655 L
.64685 .09654 L
.64937 .09654 L
.65071 .09654 L
.65213 .09654 L
.65285 .09654 L
.65363 .09654 L
.65436 .09654 L
.65504 .09654 L
.65633 .09654 L
.65697 .09654 L
.65769 .09654 L
.65898 .09654 L
.66016 .09654 L
.66152 .09654 L
.66282 .09654 L
.66762 .09655 L
.67022 .09655 L
.67267 .09656 L
.67724 .09657 L
.68748 .09661 L
.70588 .09671 L
.7445 .09701 L
.78558 .09739 L
.82514 .09777 L
.86318 .09812 L
.90368 .09848 L
Mistroke
.94266 .09879 L
.97619 .09904 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04445 L
.04761 .04585 L
.05217 .04679 L
.06244 .04854 L
.08259 .05227 L
.09399 .05501 L
.10458 .05824 L
.11466 .06224 L
.1238 .06711 L
.12887 .07059 L
.13435 .07526 L
.13953 .08093 L
.14429 .0877 L
.14899 .09654 L
.15402 .10956 L
.15878 .12663 L
.16311 .14694 L
.1682 .17355 L
.16959 .1801 L
.17107 .18613 L
.17233 .19029 L
.17301 .19211 L
.17372 .1937 L
.17503 .19569 L
.17622 .19652 L
.1775 .19642 L
.17823 .19594 L
.17891 .19525 L
.18014 .19344 L
.18126 .19126 L
.18378 .18495 L
.19388 .15219 L
.19941 .13531 L
.20458 .12196 L
.20935 .11195 L
.21371 .1047 L
.21855 .09857 L
.22122 .09598 L
.22376 .09399 L
Mistroke
.22619 .09248 L
.22838 .09144 L
.2296 .09098 L
.23092 .09059 L
.23216 .09031 L
.23331 .09014 L
.23437 .09004 L
.23536 .09 L
.23645 .09003 L
.23762 .09013 L
.23884 .09033 L
.24 .09059 L
.24103 .0909 L
.24216 .09131 L
.24457 .09247 L
.24722 .09424 L
.24999 .09671 L
.25259 .09969 L
.25723 .10699 L
.25984 .11241 L
.26222 .11829 L
.27217 .15107 L
.27764 .17139 L
.28279 .18874 L
.2876 .20172 L
.29031 .2074 L
.29281 .21156 L
.29492 .21431 L
.29723 .2166 L
.29839 .21748 L
.29964 .21823 L
.30082 .21879 L
.3019 .21916 L
.30302 .21944 L
.30426 .21961 L
.30555 .21966 L
.30677 .2196 L
.3079 .21947 L
.30894 .21928 L
.31128 .21869 L
.31625 .21691 L
.32149 .21482 L
.32577 .2133 L
.32813 .21263 L
.33036 .21212 L
.33162 .21189 L
.33299 .2117 L
.33423 .21157 L
.33538 .2115 L
.33646 .21147 L
Mistroke
.33765 .21149 L
.3389 .21155 L
.34006 .21165 L
.34131 .21182 L
.34264 .21204 L
.34503 .21259 L
.34787 .21346 L
.35045 .21444 L
.36032 .21938 L
.36934 .22454 L
.37885 .22925 L
.38364 .23099 L
.38635 .23176 L
.38889 .23231 L
.39008 .23252 L
.39122 .23269 L
.39225 .23282 L
.39334 .23292 L
.39453 .23301 L
.39563 .23306 L
.39681 .23308 L
.39811 .23307 L
.39943 .23303 L
.40009 .233 L
.40081 .23295 L
.40209 .23284 L
.40329 .23271 L
.40598 .23233 L
.40886 .2318 L
.41894 .22917 L
.43887 .22261 L
.46046 .21643 L
.48127 .21211 L
.50046 .20892 L
.53988 .20316 L
.57779 .19888 L
.59725 .19727 L
.61815 .1959 L
.63791 .19487 L
.65945 .19398 L
.68009 .19333 L
.69923 .19286 L
.7198 .19249 L
.73843 .19223 L
.75773 .19203 L
.77857 .19186 L
.79856 .19174 L
.81964 .19163 L
.85769 .19149 L
.89818 .19135 L
Mistroke
.93716 .1912 L
.97619 .19104 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04111 L
.0379 .04196 L
.04033 .04312 L
.04262 .04394 L
.04517 .04466 L
.04761 .0452 L
.05217 .04603 L
.06244 .04757 L
.07302 .0492 L
.08429 .05122 L
.09474 .05349 L
.10458 .05612 L
.1142 .05935 L
.12461 .06394 L
.13407 .06965 L
.14277 .077 L
.15263 .0892 L
.15805 .09809 L
.16319 .10718 L
.16551 .11088 L
.16678 .11262 L
.16797 .11399 L
.16925 .11513 L
.16994 .11557 L
.17067 .1159 L
.17197 .11613 L
.17317 .11591 L
.17426 .11535 L
.17528 .11454 L
.1764 .11335 L
.1776 .11177 L
.18226 .10355 L
.18717 .09372 L
.19249 .08411 L
.19719 .0773 L
.20215 .07182 L
.20663 .06821 L
.20901 .06672 L
.21156 .0654 L
.2139 .06442 L
.21604 .06369 L
.2182 .0631 L
Mistroke
.22023 .06266 L
.22144 .06244 L
.22274 .06225 L
.22382 .06212 L
.22501 .06201 L
.2263 .06192 L
.22701 .06188 L
.22767 .06185 L
.22884 .06182 L
.2301 .06181 L
.23128 .06183 L
.23256 .06186 L
.23377 .06192 L
.23489 .06199 L
.23701 .06217 L
.23926 .06241 L
.24435 .06314 L
.24912 .06402 L
.25999 .06638 L
.2651 .06742 L
.26759 .06784 L
.26985 .06816 L
.27225 .06842 L
.27356 .06853 L
.2748 .06861 L
.27546 .06864 L
.27616 .06866 L
.2774 .06869 L
.2781 .06869 L
.27874 .06868 L
.27945 .06867 L
.28022 .06865 L
.28145 .06859 L
.28259 .06851 L
.28385 .0684 L
.28519 .06826 L
.2899 .06757 L
.2941 .06676 L
.29873 .06572 L
.30893 .06334 L
.31968 .0612 L
.32886 .05988 L
.33406 .05933 L
.3389 .05893 L
.34393 .0586 L
.34869 .05835 L
.35758 .058 L
.36716 .05773 L
.37756 .05746 L
.39702 .05697 L
Mistroke
.41844 .05645 L
.42824 .05625 L
.43878 .05607 L
.45782 .05583 L
.46793 .05574 L
.47897 .05565 L
.49906 .0555 L
.53973 .05527 L
.57887 .05512 L
.62048 .055 L
.66056 .05491 L
.69913 .05485 L
.74016 .0548 L
.77966 .05476 L
.81766 .05472 L
.8581 .05469 L
.89703 .05467 L
.93841 .05464 L
.97619 .05462 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04578 L
.05217 .04669 L
.06244 .04838 L
.08259 .05199 L
.09399 .05464 L
.10458 .05775 L
.11466 .06157 L
.1238 .06616 L
.12887 .0694 L
.13435 .07369 L
.13953 .07879 L
.14429 .08475 L
.14935 .09297 L
.15414 .10324 L
.15967 .119 L
.16471 .1368 L
.16914 .15224 L
.17137 .15828 L
.17265 .16081 L
.17384 .1625 L
.17514 .16353 L
.17633 .16374 L
.17763 .16319 L
.17828 .16263 L
.179 .16181 L
.1802 .16001 L
.18148 .15757 L
.18378 .15211 L
.19263 .12611 L
.202 .10215 L
.20689 .09298 L
.21227 .08544 L
.21463 .08287 L
.21717 .08055 L
.22175 .07736 L
.22449 .07599 L
.22593 .0754 L
.22747 .07488 L
Mistroke
.22895 .07447 L
.23029 .07417 L
.23163 .07393 L
.2329 .07376 L
.23414 .07365 L
.23546 .07359 L
.23657 .07358 L
.2378 .07361 L
.23849 .07364 L
.23912 .07369 L
.24054 .07383 L
.24185 .07401 L
.24309 .07422 L
.24553 .07477 L
.24811 .07551 L
.25275 .0773 L
.25774 .07987 L
.26325 .08352 L
.2727 .09114 L
.27519 .09306 L
.27785 .09489 L
.28031 .09629 L
.28263 .09732 L
.28394 .09777 L
.28463 .09796 L
.28536 .09813 L
.28665 .09836 L
.28784 .09848 L
.28851 .09851 L
.28924 .09852 L
.29055 .09846 L
.29135 .09838 L
.2921 .09827 L
.29353 .098 L
.29473 .09769 L
.296 .09731 L
.2983 .09646 L
.3035 .094 L
.32317 .08287 L
.33179 .07882 L
.34122 .07536 L
.35063 .07283 L
.35576 .07178 L
.36054 .07096 L
.37062 .06965 L
.37626 .0691 L
.38139 .06867 L
.42134 .06621 L
.43963 .06529 L
.45003 .06486 L
Mistroke
.45977 .06452 L
.47963 .06401 L
.48976 .06383 L
.50066 .06367 L
.52181 .06344 L
.5419 .06329 L
.5515 .06323 L
.56173 .06318 L
.57131 .06315 L
.58012 .06312 L
.59041 .0631 L
.59583 .06309 L
.60154 .06308 L
.60395 .06308 L
.60652 .06308 L
.60875 .06307 L
.61116 .06307 L
.61264 .06307 L
.614 .06307 L
.6153 .06307 L
.61597 .06307 L
.61669 .06307 L
.61792 .06307 L
.61908 .06307 L
.61975 .06307 L
.62046 .06307 L
.62172 .06307 L
.62296 .06307 L
.62365 .06307 L
.6243 .06307 L
.62673 .06307 L
.62894 .06307 L
.63127 .06307 L
.63613 .06308 L
.64148 .06308 L
.65097 .06309 L
.65985 .0631 L
.69869 .06317 L
.73999 .06327 L
.77977 .06337 L
.81803 .06347 L
.85875 .06357 L
.89795 .06366 L
.93961 .06375 L
.97619 .06382 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04443 L
.04761 .04583 L
.05217 .04676 L
.06244 .04851 L
.08259 .05222 L
.09399 .05495 L
.10458 .05816 L
.11466 .06215 L
.1238 .06699 L
.12887 .07043 L
.13435 .07507 L
.13953 .08067 L
.14429 .08734 L
.14899 .09602 L
.15402 .10869 L
.15878 .12507 L
.16311 .1441 L
.1682 .16789 L
.16959 .17341 L
.17107 .17827 L
.17233 .1814 L
.17305 .18273 L
.17372 .18367 L
.17495 .18462 L
.17625 .18459 L
.17735 .18379 L
.17856 .1822 L
.17987 .17976 L
.18126 .17648 L
.18378 .1693 L
.19345 .13729 L
.20369 .10967 L
.20904 .09943 L
.21187 .09509 L
.21492 .09117 L
.21771 .08818 L
.22027 .08592 L
.22527 .08259 L
.22774 .08142 L
Mistroke
.23037 .08047 L
.23164 .08011 L
.23284 .07983 L
.23391 .07962 L
.23509 .07944 L
.23639 .07929 L
.2371 .07923 L
.23777 .07919 L
.23896 .07915 L
.24023 .07915 L
.24095 .07917 L
.24172 .07921 L
.24246 .07926 L
.24314 .07932 L
.24442 .07946 L
.24578 .07964 L
.25056 .08056 L
.25505 .08166 L
.25993 .08298 L
.26526 .08466 L
.27037 .08692 L
.27511 .08988 L
.28013 .09399 L
.28548 .0992 L
.29512 .10902 L
.304 .11649 L
.30899 .11966 L
.31426 .12227 L
.32538 .12614 L
.33511 .12901 L
.34555 .13276 L
.3558 .13768 L
.36516 .14316 L
.38348 .15459 L
.39272 .15947 L
.40255 .16341 L
.40767 .16492 L
.41332 .16617 L
.4158 .1666 L
.41846 .16698 L
.4233 .16749 L
.42569 .16767 L
.42825 .16782 L
.42949 .16787 L
.43066 .16791 L
.4317 .16794 L
.43285 .16797 L
.43412 .16799 L
.43481 .168 L
.43546 .16801 L
Mistroke
.43662 .16801 L
.43787 .16801 L
.43857 .16801 L
.43933 .16801 L
.44005 .168 L
.44071 .16799 L
.44197 .16798 L
.44331 .16795 L
.44605 .16789 L
.44901 .16781 L
.45438 .16763 L
.46441 .16723 L
.48397 .16633 L
.50543 .16509 L
.54494 .16194 L
.58538 .15842 L
.62431 .15537 L
.66569 .15249 L
.70555 .15001 L
.7439 .14786 L
.78471 .14575 L
.82399 .14386 L
.86176 .14214 L
.90199 .1404 L
.94069 .13881 L
.97619 .13742 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .0402 L
.03652 .04113 L
.0379 .04198 L
.04033 .04316 L
.04262 .04399 L
.04761 .04527 L
.05217 .04611 L
.06244 .04769 L
.08259 .05106 L
.09399 .05352 L
.10458 .05638 L
.11466 .05986 L
.1238 .06397 L
.12887 .06682 L
.13435 .07052 L
.14429 .07971 L
.15372 .09306 L
.15901 .10318 L
.16384 .11343 L
.16656 .11885 L
.168 .12131 L
.16953 .12346 L
.17087 .12485 L
.17163 .12541 L
.17234 .12577 L
.17359 .12601 L
.17429 .12592 L
.17493 .12569 L
.17618 .12489 L
.17734 .12373 L
.17862 .12206 L
.17998 .11986 L
.18529 .10887 L
.1904 .09745 L
.19593 .08655 L
.20116 .07842 L
.20598 .07279 L
.21033 .06904 L
.21511 .06609 L
.21752 .065 L
.22011 .06407 L
.22255 .06339 L
.22478 .06291 L
Mistroke
.22607 .0627 L
.22729 .06253 L
.22839 .0624 L
.22956 .06229 L
.23084 .0622 L
.23201 .06215 L
.23327 .06211 L
.23398 .0621 L
.23465 .0621 L
.23584 .0621 L
.23696 .06213 L
.23797 .06216 L
.23907 .06221 L
.24153 .06235 L
.2438 .06252 L
.249 .06296 L
.25154 .06315 L
.25265 .06322 L
.25386 .06328 L
.25506 .06332 L
.25631 .06334 L
.25697 .06334 L
.25767 .06333 L
.25894 .06329 L
.25967 .06326 L
.26045 .06321 L
.26188 .06309 L
.26326 .06293 L
.26454 .06276 L
.27438 .06081 L
.28494 .05861 L
.29005 .05776 L
.2949 .0571 L
.304 .05616 L
.30857 .0558 L
.31343 .05548 L
.32216 .05505 L
.327 .05487 L
.33156 .05474 L
.33655 .05464 L
.33915 .05459 L
.34193 .05456 L
.34453 .05453 L
.34688 .0545 L
.35149 .05447 L
.35687 .05444 L
.36195 .05442 L
.38304 .05433 L
.40134 .05423 L
.40635 .05421 L
Mistroke
.41174 .05419 L
.41435 .05418 L
.41682 .05418 L
.41926 .05417 L
.42148 .05417 L
.42386 .05416 L
.42517 .05416 L
.4264 .05416 L
.42754 .05416 L
.4286 .05416 L
.42975 .05416 L
.43097 .05416 L
.4322 .05416 L
.43353 .05416 L
.43477 .05416 L
.43591 .05417 L
.43869 .05417 L
.44133 .05417 L
.44656 .05418 L
.45141 .0542 L
.46236 .05423 L
.50165 .05435 L
.53942 .05444 L
.57964 .05452 L
.61835 .05459 L
.65951 .05464 L
.69915 .05468 L
.73728 .05471 L
.77786 .05474 L
.81693 .05476 L
.85845 .05478 L
.89845 .05479 L
.93693 .05481 L
.97619 .05482 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04127 L
.0379 .04214 L
.04033 .04333 L
.04262 .04418 L
.04761 .04549 L
.05217 .04636 L
.06244 .04797 L
.08259 .05143 L
.09399 .05396 L
.10458 .05691 L
.11466 .06051 L
.1238 .06479 L
.12887 .06777 L
.13435 .07168 L
.14429 .08147 L
.15372 .09605 L
.15901 .10731 L
.16384 .11884 L
.16656 .1249 L
.168 .1276 L
.16953 .12989 L
.17018 .13065 L
.17087 .13131 L
.17163 .13184 L
.17234 .13215 L
.173 .13227 L
.17369 .13222 L
.17493 .13169 L
.17617 .13064 L
.17686 .12984 L
.1775 .129 L
.17988 .12494 L
.18529 .11287 L
.19504 .09177 L
.20054 .08298 L
.2056 .07695 L
.21004 .07305 L
.21492 .06997 L
.21737 .06882 L
.22001 .06782 L
.2225 .0671 L
.22478 .06659 L
Mistroke
.22607 .06636 L
.22729 .06619 L
.22839 .06605 L
.22956 .06594 L
.23084 .06585 L
.23201 .0658 L
.23327 .06577 L
.23398 .06576 L
.23465 .06577 L
.23584 .06579 L
.23696 .06583 L
.23797 .06589 L
.23907 .06596 L
.24153 .06618 L
.2438 .06645 L
.25451 .06827 L
.25974 .06923 L
.26204 .06959 L
.26454 .06992 L
.26564 .07004 L
.26682 .07014 L
.26792 .07022 L
.26893 .07027 L
.27007 .07031 L
.27131 .07033 L
.27247 .07031 L
.27355 .07028 L
.27471 .07022 L
.27579 .07014 L
.27698 .07003 L
.27826 .06988 L
.28086 .0695 L
.28324 .06906 L
.29395 .06647 L
.30386 .06395 L
.3131 .06205 L
.31776 .06131 L
.32292 .06065 L
.32807 .06014 L
.33362 .05973 L
.33886 .05944 L
.34367 .05925 L
.3484 .05911 L
.35346 .05899 L
.35823 .05891 L
.36257 .05885 L
.38326 .05863 L
.40242 .05847 L
.40767 .05844 L
.41324 .05841 L
Mistroke
.41845 .05839 L
.42321 .05837 L
.42772 .05836 L
.43263 .05835 L
.43533 .05834 L
.43783 .05834 L
.44037 .05834 L
.44276 .05833 L
.445 .05833 L
.44741 .05833 L
.44961 .05833 L
.45163 .05833 L
.45382 .05833 L
.45506 .05833 L
.45622 .05833 L
.45744 .05833 L
.45856 .05833 L
.45985 .05833 L
.46107 .05833 L
.46221 .05833 L
.46344 .05833 L
.4646 .05833 L
.46566 .05833 L
.46813 .05833 L
.47073 .05833 L
.47605 .05833 L
.47864 .05833 L
.48099 .05833 L
.48204 .05833 L
.48318 .05833 L
.48417 .05833 L
.48525 .05833 L
.4864 .05833 L
.48761 .05833 L
.48874 .05833 L
.48979 .05833 L
.49104 .05833 L
.49222 .05833 L
.49328 .05833 L
.49444 .05833 L
.49702 .05833 L
.49942 .05833 L
.50452 .05833 L
.51002 .05833 L
.52 .05832 L
.5297 .05832 L
.53862 .05831 L
.5591 .05829 L
.57818 .05827 L
.61622 .05822 L
Mistroke
.6552 .05814 L
.69664 .05806 L
.73655 .05796 L
.77496 .05787 L
.81581 .05776 L
.85515 .05766 L
.89297 .05757 L
.93325 .05747 L
.97201 .05739 L
.97619 .05738 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04347 L
.04262 .04435 L
.04761 .04573 L
.05217 .04665 L
.06244 .04836 L
.08259 .05201 L
.09399 .05469 L
.10458 .05784 L
.11466 .06172 L
.1238 .06643 L
.12887 .06976 L
.13435 .07421 L
.13953 .07956 L
.14429 .08588 L
.14935 .09472 L
.15414 .10598 L
.15967 .12358 L
.16471 .14355 L
.16699 .15264 L
.16914 .16012 L
.1703 .16347 L
.17137 .16596 L
.17256 .168 L
.17384 .16929 L
.17504 .16965 L
.17636 .16915 L
.17702 .16856 L
.17773 .16771 L
.179 .16566 L
.1815 .16008 L
.18378 .1538 L
.19337 .12462 L
.19862 .11087 L
.20353 .1004 L
.20806 .09275 L
.21221 .08727 L
.21681 .08264 L
.21937 .08063 L
.22175 .07908 L
.22422 .07775 L
Mistroke
.22646 .07678 L
.22894 .07593 L
.23032 .07555 L
.23159 .07526 L
.2339 .07485 L
.23512 .07469 L
.2364 .07457 L
.23752 .07449 L
.23856 .07445 L
.23971 .07443 L
.24093 .07444 L
.24161 .07446 L
.24233 .07449 L
.24361 .07456 L
.245 .07466 L
.24653 .07481 L
.25182 .07547 L
.26173 .07644 L
.26305 .07648 L
.2643 .0765 L
.26499 .0765 L
.26574 .0765 L
.26704 .07648 L
.26829 .07645 L
.26961 .07641 L
.27197 .07635 L
.27324 .07633 L
.27443 .07631 L
.27573 .07631 L
.27645 .07632 L
.27712 .07633 L
.27784 .07635 L
.2785 .07637 L
.27923 .0764 L
.28001 .07645 L
.28131 .07654 L
.28274 .07668 L
.28523 .07699 L
.28752 .07735 L
.29266 .07841 L
.30199 .08075 L
.34072 .08787 L
.38032 .09781 L
.39057 .10093 L
.40026 .10358 L
.40969 .10571 L
.41839 .10724 L
.42779 .10846 L
.43274 .10895 L
.43798 .10937 L
Mistroke
.44795 .10998 L
.45361 .11023 L
.45892 .11043 L
.46931 .11074 L
.47918 .11096 L
.48805 .1111 L
.49047 .11113 L
.49306 .11115 L
.49528 .11117 L
.49771 .11119 L
.50032 .1112 L
.50175 .11121 L
.50243 .11121 L
.50308 .11121 L
.50432 .11121 L
.50546 .11121 L
.50668 .11121 L
.50737 .11121 L
.50801 .11121 L
.50865 .11121 L
.50933 .11121 L
.51058 .11121 L
.51205 .1112 L
.51341 .11119 L
.5162 .11118 L
.51914 .11115 L
.52413 .11109 L
.52878 .11103 L
.53932 .11083 L
.55979 .1103 L
.57838 .10972 L
.61838 .10836 L
.65687 .10697 L
.69781 .10548 L
.73723 .10406 L
.77514 .10272 L
.8155 .10135 L
.85434 .10008 L
.89564 .09879 L
.93542 .09761 L
.97368 .09654 L
.97619 .09647 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04215 L
.04033 .04336 L
.04262 .04422 L
.04761 .04555 L
.05217 .04643 L
.06244 .04808 L
.08259 .05161 L
.09399 .0542 L
.10458 .05722 L
.11466 .06093 L
.1238 .06536 L
.12887 .06847 L
.13435 .07258 L
.14429 .08308 L
.16384 .12654 L
.16659 .13441 L
.16919 .14057 L
.17063 .14306 L
.17144 .1441 L
.17219 .14482 L
.17283 .14524 L
.17352 .14549 L
.17425 .14552 L
.17493 .14535 L
.1762 .14451 L
.17684 .14386 L
.17753 .14299 L
.17992 .1389 L
.18529 .12599 L
.19518 .10168 L
.20072 .09124 L
.20575 .08401 L
.21044 .07894 L
.21292 .07682 L
.21554 .07495 L
.21783 .07358 L
.22035 .07234 L
.22265 .07141 L
.22478 .07072 L
.22727 .07008 L
.2287 .0698 L
Mistroke
.22999 .06958 L
.23114 .06943 L
.23239 .06929 L
.2337 .06919 L
.23494 .06912 L
.23606 .06909 L
.2373 .06907 L
.23858 .06909 L
.23978 .06913 L
.2409 .06918 L
.24193 .06925 L
.24423 .06945 L
.25509 .07095 L
.25738 .07127 L
.25986 .07157 L
.26128 .07171 L
.26257 .07181 L
.26381 .07188 L
.26512 .07192 L
.26623 .07194 L
.26742 .07193 L
.26854 .07189 L
.26955 .07183 L
.27075 .07175 L
.27205 .07162 L
.2744 .07131 L
.27689 .07089 L
.27952 .07036 L
.28424 .06925 L
.29426 .06674 L
.29978 .06553 L
.30502 .06459 L
.30993 .06389 L
.31527 .06331 L
.32013 .06292 L
.32463 .06266 L
.32885 .06249 L
.33125 .06242 L
.33351 .06237 L
.33588 .06232 L
.33805 .0623 L
.33919 .06229 L
.34044 .06228 L
.34174 .06227 L
.34296 .06227 L
.34423 .06227 L
.34487 .06227 L
.34558 .06227 L
.34683 .06228 L
.348 .06229 L
Mistroke
.34937 .0623 L
.35063 .06231 L
.35346 .06234 L
.35855 .06242 L
.36339 .06252 L
.37227 .06276 L
.38197 .06308 L
.4033 .06391 L
.42263 .06462 L
.4428 .06519 L
.46178 .06558 L
.48018 .06589 L
.50035 .06615 L
.52031 .06635 L
.53121 .06643 L
.54138 .06649 L
.54639 .06651 L
.55184 .06653 L
.55664 .06655 L
.56175 .06656 L
.56633 .06657 L
.56877 .06658 L
.57139 .06658 L
.57379 .06658 L
.57599 .06659 L
.57809 .06659 L
.58031 .06659 L
.58154 .06659 L
.58219 .06659 L
.58288 .06659 L
.58415 .06659 L
.58531 .06659 L
.58643 .06659 L
.58748 .06659 L
.58863 .06659 L
.58986 .06659 L
.59117 .06659 L
.5926 .06659 L
.59519 .06659 L
.59772 .06658 L
.60006 .06658 L
.60896 .06657 L
.61394 .06656 L
.61843 .06655 L
.63773 .06649 L
.65857 .0664 L
.69965 .06617 L
.73921 .0659 L
.77725 .06562 L
.81775 .0653 L
Mistroke
.85673 .06499 L
.89816 .06466 L
.93808 .06436 L
.97619 .06409 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04044 L
.03652 .04141 L
.0379 .0423 L
.04033 .04355 L
.04262 .04444 L
.04761 .04584 L
.05217 .04678 L
.06244 .04852 L
.08259 .05223 L
.09399 .05495 L
.10458 .05815 L
.11466 .06212 L
.1238 .06694 L
.12887 .07037 L
.13435 .07496 L
.13953 .08051 L
.14429 .0871 L
.14899 .09566 L
.15402 .10813 L
.15878 .12427 L
.16311 .14325 L
.1682 .16796 L
.17088 .17905 L
.17223 .18339 L
.17301 .18541 L
.17372 .18694 L
.17502 .18889 L
.1757 .18949 L
.17642 .18981 L
.17762 .18968 L
.17895 .18864 L
.18016 .18695 L
.18145 .1845 L
.18378 .17876 L
.19345 .14723 L
.20369 .11702 L
.20904 .10533 L
.21187 .1003 L
.21492 .09576 L
.21771 .09229 L
.22027 .08967 L
.2229 .08746 L
.22527 .08586 L
Mistroke
.22774 .08455 L
.229 .08401 L
.23037 .08352 L
.23163 .08315 L
.2328 .08288 L
.23391 .08269 L
.23509 .08254 L
.23636 .08245 L
.23708 .08243 L
.23773 .08243 L
.23899 .08249 L
.24019 .08261 L
.24087 .0827 L
.24158 .08282 L
.24287 .08309 L
.24426 .08345 L
.24578 .08396 L
.24831 .08501 L
.25062 .08623 L
.25311 .08783 L
.25583 .08996 L
.26043 .09465 L
.26526 .10143 L
.27621 .12287 L
.28159 .13398 L
.28655 .14277 L
.29106 .14886 L
.29333 .15114 L
.29583 .15305 L
.29713 .15381 L
.29833 .15436 L
.29899 .1546 L
.29971 .15483 L
.30102 .15513 L
.30224 .15529 L
.30354 .15534 L
.30464 .15529 L
.30587 .15515 L
.30704 .15493 L
.30833 .1546 L
.31093 .15373 L
.31557 .15163 L
.32603 .14599 L
.33077 .14364 L
.33583 .14154 L
.33829 .1407 L
.34062 .14002 L
.34271 .13952 L
.34497 .13908 L
.34621 .13889 L
Mistroke
.34735 .13874 L
.34851 .13861 L
.34959 .13852 L
.35083 .13844 L
.35149 .13841 L
.35219 .13839 L
.35349 .13837 L
.35467 .13838 L
.35532 .1384 L
.356 .13842 L
.35722 .13848 L
.35853 .13857 L
.35997 .13869 L
.36496 .13929 L
.37443 .14082 L
.37909 .14157 L
.3834 .14216 L
.38573 .14243 L
.38829 .14266 L
.38954 .14275 L
.39088 .14283 L
.39161 .14287 L
.39229 .1429 L
.39293 .14292 L
.39362 .14294 L
.39474 .14296 L
.39578 .14297 L
.39702 .14296 L
.39815 .14294 L
.39933 .1429 L
.40061 .14284 L
.40292 .14269 L
.40544 .14247 L
.40821 .14215 L
.41381 .14132 L
.42384 .13936 L
.44494 .13463 L
.4642 .13097 L
.48414 .12822 L
.50305 .12626 L
.54131 .12312 L
.56269 .12174 L
.58203 .12075 L
.60223 .11996 L
.62123 .11941 L
.64137 .11897 L
.65986 .11869 L
.66963 .11857 L
.67873 .11849 L
.68872 .11841 L
Mistroke
.69428 .11838 L
.69942 .11835 L
.70427 .11833 L
.70963 .11832 L
.71501 .1183 L
.71795 .1183 L
.72071 .11829 L
.72331 .11829 L
.72459 .11829 L
.72578 .11829 L
.72694 .11829 L
.72799 .11829 L
.72916 .11829 L
.73041 .11829 L
.73106 .11829 L
.73175 .11829 L
.73299 .11829 L
.73368 .11829 L
.73432 .11829 L
.73503 .11829 L
.73578 .11829 L
.73714 .11829 L
.73843 .11829 L
.74085 .11829 L
.74321 .11829 L
.74543 .11829 L
.7505 .1183 L
.76075 .11832 L
.76961 .11835 L
.77917 .11838 L
.82029 .11854 L
.85991 .11873 L
.898 .11891 L
.93855 .11908 L
.97619 .11922 L
Mfstroke
.933 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04034 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04552 L
.05217 .04639 L
.06244 .048 L
.08259 .05145 L
.09399 .05398 L
.10458 .05692 L
.11466 .06051 L
.1238 .06476 L
.12887 .06772 L
.13435 .07159 L
.14429 .08126 L
.16384 .1181 L
.16659 .1244 L
.16919 .12933 L
.17063 .13135 L
.17144 .13221 L
.17219 .13281 L
.17283 .13315 L
.17352 .13337 L
.17425 .13341 L
.17493 .13328 L
.1762 .13259 L
.17684 .13204 L
.17753 .13129 L
.17992 .1277 L
.1827 .12201 L
.18529 .11589 L
.19 .10433 L
.19511 .09291 L
.19962 .08458 L
.20438 .07768 L
.20703 .07463 L
.20994 .07185 L
.21241 .06991 L
.21507 .06819 L
.21769 .06684 L
.22009 .06585 L
.22249 .06507 L
Mistroke
.22478 .0645 L
.22603 .06425 L
.22738 .06403 L
.22857 .06387 L
.22982 .06373 L
.23096 .06363 L
.2322 .06356 L
.23334 .06351 L
.23439 .06349 L
.23503 .06348 L
.23572 .06348 L
.23698 .0635 L
.2382 .06353 L
.23933 .06358 L
.2419 .06374 L
.24462 .06396 L
.24884 .06435 L
.25105 .06455 L
.25338 .06473 L
.25462 .0648 L
.25528 .06483 L
.25598 .06486 L
.25721 .06488 L
.25836 .06489 L
.25962 .06486 L
.2608 .06481 L
.26187 .06475 L
.26302 .06466 L
.26539 .06441 L
.26793 .06406 L
.27251 .0633 L
.28294 .06147 L
.304 .05871 L
.31415 .05773 L
.31951 .0573 L
.32521 .05692 L
.33017 .05664 L
.33565 .05639 L
.34532 .05607 L
.35023 .05596 L
.3554 .05586 L
.36465 .05573 L
.38549 .05552 L
.39502 .05543 L
.40521 .05535 L
.41476 .05529 L
.42357 .05524 L
.42854 .05523 L
.4338 .05521 L
.43652 .05521 L
Mistroke
.43908 .0552 L
.44054 .0552 L
.44188 .0552 L
.44262 .0552 L
.44342 .0552 L
.44413 .0552 L
.44489 .0552 L
.4456 .0552 L
.44626 .0552 L
.44755 .0552 L
.44872 .0552 L
.44995 .0552 L
.45059 .0552 L
.45128 .0552 L
.45252 .0552 L
.45534 .0552 L
.45795 .0552 L
.46041 .05521 L
.46504 .05521 L
.50339 .05528 L
.54419 .05534 L
.58347 .05541 L
.62124 .05547 L
.66147 .05552 L
.70018 .05556 L
.74134 .05559 L
.78098 .05562 L
.81911 .05565 L
.85969 .05567 L
.89875 .0557 L
.94027 .05572 L
.97619 .05573 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04225 L
.04033 .04347 L
.04262 .04434 L
.04761 .0457 L
.05217 .04659 L
.06244 .04825 L
.08259 .05178 L
.09399 .05437 L
.10458 .0574 L
.11466 .06111 L
.1238 .06554 L
.12887 .06864 L
.13435 .07272 L
.14429 .08304 L
.16384 .1249 L
.16659 .13268 L
.16919 .13909 L
.17063 .14188 L
.17139 .14307 L
.17219 .14411 L
.17287 .14478 L
.17362 .1453 L
.17493 .14564 L
.17559 .14554 L
.17627 .14524 L
.1775 .14425 L
.17819 .14346 L
.17883 .14258 L
.18028 .14011 L
.18529 .12818 L
.19511 .10193 L
.19994 .09146 L
.20438 .08381 L
.20951 .07718 L
.21221 .07452 L
.21507 .07222 L
.21969 .06947 L
.22232 .06834 L
.22478 .06753 L
.22603 .0672 L
.22736 .0669 L
Mistroke
.22976 .06649 L
.23123 .06631 L
.23195 .06624 L
.23261 .06619 L
.23385 .06611 L
.2345 .06608 L
.23519 .06606 L
.23636 .06605 L
.23763 .06606 L
.23882 .06609 L
.2399 .06614 L
.24117 .06622 L
.24255 .06632 L
.24507 .06657 L
.24967 .06711 L
.25463 .06771 L
.25692 .06793 L
.25816 .06803 L
.25932 .0681 L
.26039 .06816 L
.26136 .06821 L
.26245 .06824 L
.2636 .06827 L
.26482 .06828 L
.26593 .06829 L
.26716 .06829 L
.26845 .06828 L
.26958 .06827 L
.27063 .06825 L
.27303 .06821 L
.27804 .06808 L
.28085 .06798 L
.28342 .06786 L
.2861 .0677 L
.28858 .0675 L
.29421 .06691 L
.29917 .06623 L
.30444 .06539 L
.31402 .06374 L
.32411 .06214 L
.33345 .06094 L
.34216 .0601 L
.35138 .05945 L
.35626 .05919 L
.36148 .05895 L
.3724 .05859 L
.38233 .05834 L
.40149 .05797 L
.42228 .05766 L
.44213 .05743 L
Mistroke
.45214 .05736 L
.46316 .05729 L
.47331 .05725 L
.48259 .05722 L
.48771 .05721 L
.4933 .0572 L
.50347 .05718 L
.50879 .05718 L
.5138 .05717 L
.51835 .05717 L
.52316 .05717 L
.52841 .05716 L
.53324 .05716 L
.53593 .05716 L
.53843 .05716 L
.53987 .05716 L
.54119 .05716 L
.54191 .05716 L
.5427 .05716 L
.54345 .05716 L
.54414 .05716 L
.54532 .05716 L
.54656 .05716 L
.54762 .05716 L
.54877 .05716 L
.55003 .05716 L
.55136 .05716 L
.55377 .05716 L
.55621 .05716 L
.55851 .05716 L
.56281 .05716 L
.57271 .05717 L
.58342 .05718 L
.62436 .05722 L
.66378 .05726 L
.70169 .05731 L
.74205 .05735 L
.78089 .0574 L
.82219 .05744 L
.86197 .05748 L
.90024 .05752 L
.94095 .05755 L
.97619 .05758 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04138 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04669 L
.06244 .04841 L
.08259 .05207 L
.09399 .05476 L
.10458 .05791 L
.11466 .06181 L
.1238 .06653 L
.12887 .06987 L
.13435 .07433 L
.13953 .07968 L
.14429 .08599 L
.14935 .0948 L
.15414 .10599 L
.15967 .12337 L
.16471 .14288 L
.16701 .15172 L
.16945 .15973 L
.17046 .16234 L
.17154 .1646 L
.17273 .16634 L
.17384 .16725 L
.17505 .16744 L
.17637 .16676 L
.17703 .16608 L
.17774 .16514 L
.17902 .16292 L
.18151 .1571 L
.18378 .15066 L
.19315 .12165 L
.19808 .10851 L
.20331 .09728 L
.20788 .08965 L
.2129 .08332 L
.21747 .07915 L
.22175 .07634 L
.22433 .07508 L
.22673 .07416 L
Mistroke
.22936 .07339 L
.23082 .07306 L
.23215 .07282 L
.23335 .07265 L
.2346 .07251 L
.23526 .07245 L
.23598 .0724 L
.23725 .07234 L
.23844 .07232 L
.23972 .07232 L
.24093 .07235 L
.24203 .07241 L
.24319 .07248 L
.24441 .07258 L
.2466 .07281 L
.25156 .07345 L
.26057 .07433 L
.27019 .07425 L
.27139 .07422 L
.27253 .07419 L
.27384 .07418 L
.27502 .07419 L
.27634 .07422 L
.27708 .07424 L
.27776 .07427 L
.279 .07435 L
.28031 .07446 L
.28245 .0747 L
.28476 .07504 L
.28892 .07587 L
.29837 .07835 L
.30833 .08096 L
.31776 .08286 L
.32867 .08442 L
.33863 .08565 L
.34827 .08701 L
.35851 .08886 L
.37693 .09315 L
.3865 .09552 L
.3966 .09774 L
.40521 .09926 L
.41015 .09995 L
.41465 .10046 L
.41948 .10088 L
.42196 .10105 L
.42465 .10121 L
.42714 .10133 L
.42944 .10141 L
.43164 .10148 L
.43397 .10153 L
Mistroke
.43526 .10155 L
.43644 .10157 L
.43709 .10158 L
.4378 .10158 L
.43909 .10159 L
.4403 .1016 L
.44158 .1016 L
.44279 .1016 L
.44389 .1016 L
.44458 .10159 L
.4453 .10159 L
.4466 .10158 L
.44952 .10155 L
.45204 .10152 L
.45482 .10147 L
.47434 .10103 L
.49526 .10047 L
.53664 .09902 L
.57651 .09739 L
.61486 .09595 L
.65566 .0946 L
.69494 .09346 L
.73272 .09249 L
.77294 .09155 L
.81165 .09072 L
.85281 .08989 L
.89245 .08915 L
.93058 .08848 L
.97116 .0878 L
.97619 .08772 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04015 L
.03652 .04107 L
.0379 .04191 L
.04033 .04306 L
.04262 .04387 L
.04517 .04458 L
.04761 .04511 L
.05217 .04593 L
.06244 .04745 L
.07302 .04906 L
.08429 .05106 L
.09474 .0533 L
.10458 .0559 L
.1142 .05907 L
.12461 .06357 L
.13407 .06915 L
.14277 .07629 L
.14747 .0813 L
.15251 .08782 L
.1616 .10218 L
.16426 .10628 L
.16566 .10817 L
.16715 .10987 L
.16845 .111 L
.16918 .11148 L
.16988 .11181 L
.17109 .11209 L
.17241 .11195 L
.1736 .11142 L
.17491 .11041 L
.17628 .10893 L
.17755 .10721 L
.18226 .09901 L
.18731 .08938 L
.19278 .08027 L
.19795 .07361 L
.20272 .06909 L
.20702 .06612 L
.20946 .06482 L
.21175 .06382 L
.21411 .06299 L
.21635 .06236 L
.21894 .06181 L
Mistroke
.22131 .06144 L
.22255 .0613 L
.2239 .06118 L
.22518 .0611 L
.22635 .06105 L
.22741 .06102 L
.22857 .06101 L
.22979 .06102 L
.23092 .06105 L
.23155 .06108 L
.23225 .06111 L
.2335 .06118 L
.23586 .06137 L
.23861 .06167 L
.24115 .06201 L
.25008 .06358 L
.25955 .06557 L
.26413 .06644 L
.26663 .06683 L
.26895 .06713 L
.27027 .06727 L
.27147 .06737 L
.2728 .06746 L
.27354 .0675 L
.27423 .06753 L
.27543 .06756 L
.27655 .06756 L
.27777 .06754 L
.27906 .0675 L
.2802 .06743 L
.28123 .06736 L
.28357 .06713 L
.28573 .06686 L
.28778 .06654 L
.29735 .06459 L
.30611 .0626 L
.31555 .06072 L
.32095 .05986 L
.32591 .05921 L
.33056 .05872 L
.33565 .0583 L
.34063 .05797 L
.34527 .05773 L
.3554 .05736 L
.36555 .0571 L
.3764 .05686 L
.39629 .0564 L
.41787 .05593 L
.42795 .05575 L
.43864 .05559 L
Mistroke
.45782 .05539 L
.47737 .05524 L
.49567 .05512 L
.53446 .05492 L
.57571 .05476 L
.61544 .05466 L
.65365 .05457 L
.69431 .05451 L
.73346 .05446 L
.77507 .05441 L
.81515 .05438 L
.85372 .05435 L
.89475 .05432 L
.93425 .05429 L
.97224 .05427 L
.97619 .05427 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .04441 L
.04761 .04579 L
.05217 .04671 L
.06244 .04843 L
.08259 .05208 L
.09399 .05476 L
.10458 .05791 L
.11466 .06179 L
.1238 .06649 L
.12887 .06981 L
.13435 .07424 L
.13953 .07954 L
.14429 .08579 L
.14935 .0945 L
.15414 .10554 L
.15967 .12278 L
.16471 .1425 L
.16914 .1595 L
.17137 .16595 L
.17265 .16856 L
.17384 .17022 L
.17514 .17113 L
.17633 .17116 L
.17763 .17036 L
.17828 .16966 L
.179 .16868 L
.18148 .1639 L
.18378 .15798 L
.19315 .12924 L
.19808 .11538 L
.20331 .10318 L
.20788 .09471 L
.2129 .08757 L
.21747 .08279 L
.22175 .07957 L
.22439 .07808 L
.2269 .07699 L
.22915 .07624 L
.23161 .07565 L
Mistroke
.23301 .07541 L
.23427 .07526 L
.23497 .07519 L
.23573 .07514 L
.23645 .07511 L
.23711 .07509 L
.23829 .0751 L
.23959 .07515 L
.24024 .07519 L
.24094 .07525 L
.2422 .07539 L
.24345 .07556 L
.2446 .07576 L
.2472 .07632 L
.25193 .07771 L
.25623 .07933 L
.26079 .08149 L
.2657 .08454 L
.27019 .08814 L
.2803 .09826 L
.28915 .10652 L
.2917 .10836 L
.2941 .1098 L
.29629 .11087 L
.2986 .11175 L
.29977 .1121 L
.30105 .11242 L
.30222 .11265 L
.30332 .11281 L
.3046 .11294 L
.30578 .11301 L
.30643 .11303 L
.30714 .11303 L
.30842 .113 L
.30952 .11294 L
.31072 .11284 L
.31198 .11271 L
.31317 .11255 L
.31756 .1118 L
.32764 .10968 L
.33315 .10868 L
.33583 .10828 L
.33827 .10799 L
.34066 .10777 L
.34176 .10769 L
.34292 .10762 L
.34416 .10757 L
.34531 .10753 L
.34654 .10751 L
.34724 .10751 L
Mistroke
.3479 .10751 L
.34855 .10752 L
.34925 .10753 L
.35055 .10756 L
.3518 .10762 L
.35297 .10768 L
.35561 .10787 L
.35843 .10814 L
.36813 .10946 L
.37693 .11084 L
.38181 .11154 L
.38696 .11216 L
.39136 .11255 L
.39386 .11272 L
.39619 .11283 L
.39748 .11288 L
.39817 .11289 L
.39889 .11291 L
.39952 .11292 L
.40022 .11293 L
.40145 .11294 L
.40264 .11293 L
.40392 .11292 L
.40513 .11289 L
.40624 .11286 L
.40875 .11276 L
.41149 .11261 L
.41701 .11219 L
.4273 .11111 L
.43664 .10995 L
.45759 .10744 L
.47679 .10565 L
.4976 .10417 L
.53854 .10184 L
.55891 .10088 L
.57796 .10013 L
.59741 .09951 L
.61587 .09904 L
.63617 .09863 L
.65471 .09833 L
.67457 .09808 L
.69297 .09791 L
.71355 .09776 L
.73218 .09767 L
.75148 .0976 L
.76234 .09757 L
.77231 .09754 L
.79119 .09751 L
.8019 .0975 L
.81187 .09749 L
Mistroke
.82236 .09748 L
.83228 .09748 L
.85086 .09747 L
.86054 .09747 L
.87082 .09746 L
.88926 .09746 L
.92708 .09745 L
.94648 .09744 L
.96736 .09743 L
.97619 .09743 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04443 L
.04761 .04582 L
.05217 .04675 L
.06244 .04848 L
.08259 .05217 L
.09399 .05488 L
.10458 .05806 L
.11466 .06201 L
.1238 .06678 L
.12887 .07018 L
.13435 .07472 L
.13953 .08019 L
.14429 .08667 L
.14935 .09577 L
.15414 .10742 L
.15967 .12578 L
.16471 .14683 L
.16914 .16455 L
.17021 .16792 L
.17137 .17091 L
.17265 .17332 L
.17384 .1747 L
.17515 .17522 L
.17581 .17509 L
.17653 .17469 L
.17781 .17331 L
.179 .17136 L
.18131 .16613 L
.18378 .15908 L
.19263 .13041 L
.202 .10536 L
.20689 .09584 L
.21227 .08797 L
.21717 .08281 L
.22175 .07938 L
.22451 .07787 L
.22712 .07675 L
.22948 .07599 L
.23204 .07539 L
Mistroke
.2335 .07514 L
.23482 .07498 L
.23555 .07491 L
.23634 .07485 L
.23709 .07481 L
.23777 .07478 L
.23901 .07477 L
.23971 .07478 L
.24036 .0748 L
.24168 .07486 L
.24242 .07492 L
.24309 .07497 L
.24567 .07527 L
.24806 .07563 L
.25345 .07663 L
.26325 .07846 L
.26789 .07944 L
.2729 .08093 L
.27762 .08293 L
.28195 .08527 L
.29263 .09207 L
.29784 .09522 L
.30256 .09769 L
.30697 .09958 L
.31174 .10119 L
.31678 .10247 L
.32153 .10338 L
.3314 .10485 L
.33663 .10562 L
.34224 .1066 L
.35254 .10897 L
.36216 .11192 L
.38321 .11945 L
.39337 .12253 L
.39911 .12389 L
.40443 .12487 L
.40906 .1255 L
.4117 .12577 L
.41417 .12598 L
.41544 .12606 L
.41678 .12614 L
.41793 .12619 L
.41916 .12624 L
.42049 .12628 L
.42173 .12631 L
.42249 .12632 L
.4232 .12633 L
.42384 .12633 L
.42454 .12633 L
.42577 .12633 L
Mistroke
.42689 .12632 L
.42819 .1263 L
.42942 .12628 L
.43161 .12622 L
.43399 .12613 L
.43939 .12588 L
.44439 .12558 L
.46543 .12413 L
.50458 .12154 L
.54618 .11868 L
.58626 .1161 L
.62484 .11409 L
.66586 .11236 L
.70537 .11099 L
.74336 .10989 L
.7838 .10887 L
.82273 .108 L
.86411 .10714 L
.90398 .10637 L
.94233 .10566 L
.97619 .10507 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04111 L
.0379 .04196 L
.04033 .04312 L
.04262 .04394 L
.04517 .04465 L
.04761 .0452 L
.05217 .04603 L
.06244 .04758 L
.07302 .04921 L
.08429 .05124 L
.09474 .05352 L
.10458 .05617 L
.1142 .05942 L
.12461 .06404 L
.13407 .06981 L
.14277 .07728 L
.15263 .08976 L
.15805 .09893 L
.16319 .10836 L
.16551 .11221 L
.16678 .11401 L
.16797 .11543 L
.16925 .1166 L
.16994 .11704 L
.17067 .11738 L
.17197 .11759 L
.17317 .11734 L
.17426 .11674 L
.17528 .11589 L
.1764 .11465 L
.1776 .11301 L
.18226 .10458 L
.18717 .09461 L
.19249 .08492 L
.19752 .07763 L
.20215 .07254 L
.20634 .06909 L
.21094 .06635 L
.21325 .06531 L
.21574 .0644 L
.2181 .06373 L
.22023 .06325 L
Mistroke
.22278 .06284 L
.22417 .06267 L
.22549 .06254 L
.22671 .06246 L
.22783 .06241 L
.22906 .06237 L
.23036 .06236 L
.23168 .06238 L
.23242 .0624 L
.23309 .06243 L
.2344 .06249 L
.23563 .06258 L
.2384 .06283 L
.24141 .06319 L
.24648 .06398 L
.25185 .065 L
.25689 .06601 L
.26151 .06687 L
.26388 .06725 L
.26609 .06754 L
.26839 .06777 L
.26961 .06787 L
.2709 .06794 L
.27221 .06798 L
.27295 .06799 L
.27363 .068 L
.27488 .06798 L
.27621 .06794 L
.27739 .06787 L
.2785 .06779 L
.28102 .06753 L
.28339 .0672 L
.28563 .06682 L
.28984 .06598 L
.29931 .06376 L
.30895 .06162 L
.31423 .06065 L
.3192 .05989 L
.32794 .05888 L
.33259 .0585 L
.33761 .05818 L
.34256 .05794 L
.34716 .05776 L
.35763 .05748 L
.36782 .05729 L
.37872 .05709 L
.3986 .05674 L
.40908 .05657 L
.42018 .05641 L
.43007 .0563 L
Mistroke
.44096 .0562 L
.46013 .05607 L
.47956 .05598 L
.50044 .0559 L
.54168 .05575 L
.58141 .05564 L
.61962 .05555 L
.66029 .05547 L
.69944 .0554 L
.74104 .05533 L
.78113 .05527 L
.8197 .05521 L
.86072 .05516 L
.90023 .05511 L
.93822 .05507 L
.97619 .05502 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04578 L
.05217 .0467 L
.06244 .04841 L
.08259 .05204 L
.09399 .05471 L
.10458 .05784 L
.11466 .06171 L
.1238 .06636 L
.12887 .06965 L
.13435 .07403 L
.13953 .07926 L
.14429 .0854 L
.14935 .09393 L
.15414 .10471 L
.15967 .12147 L
.16471 .14067 L
.16914 .15749 L
.17137 .16407 L
.17265 .16683 L
.17384 .16867 L
.17514 .1698 L
.17633 .17004 L
.17763 .16948 L
.17828 .1689 L
.179 .16805 L
.1802 .16618 L
.18148 .16363 L
.18378 .15797 L
.19263 .13106 L
.202 .10599 L
.20689 .09624 L
.21227 .08814 L
.21717 .08283 L
.22175 .07933 L
.22451 .0778 L
.22712 .07669 L
.22948 .07596 L
.23081 .07564 L
Mistroke
.23204 .07541 L
.23273 .0753 L
.23349 .07521 L
.23415 .07514 L
.23485 .07508 L
.23548 .07505 L
.23617 .07502 L
.23739 .07502 L
.23814 .07504 L
.23882 .07508 L
.2396 .07513 L
.24034 .0752 L
.24166 .07537 L
.24309 .07561 L
.24551 .07615 L
.24818 .07694 L
.25357 .07918 L
.25856 .08206 L
.26325 .08562 L
.2722 .09462 L
.28176 .10461 L
.28459 .10695 L
.28726 .10874 L
.28965 .10999 L
.29089 .11049 L
.29224 .11094 L
.29352 .11126 L
.29471 .11148 L
.29597 .11162 L
.29667 .11167 L
.29732 .11168 L
.29846 .11166 L
.29971 .11157 L
.30089 .11142 L
.30199 .11123 L
.30437 .11068 L
.30661 .11 L
.31172 .10804 L
.32206 .1034 L
.33234 .09923 L
.33752 .09757 L
.34318 .09614 L
.34822 .09521 L
.35105 .09481 L
.35362 .09453 L
.35601 .09432 L
.35728 .09423 L
.35861 .09415 L
.35978 .09409 L
.36107 .09404 L
Mistroke
.36215 .094 L
.36333 .09397 L
.36457 .09394 L
.36574 .09393 L
.36688 .09392 L
.36794 .09391 L
.3692 .09391 L
.37033 .09391 L
.37165 .09392 L
.37289 .09393 L
.37751 .09398 L
.37977 .09401 L
.38183 .09402 L
.38299 .09403 L
.38408 .09403 L
.38524 .09404 L
.38649 .09403 L
.38778 .09403 L
.38843 .09402 L
.38915 .09402 L
.39042 .094 L
.39161 .09398 L
.3942 .09392 L
.39657 .09384 L
.39918 .09374 L
.40193 .0936 L
.41075 .09298 L
.4204 .09208 L
.44167 .08982 L
.46098 .08805 L
.48108 .08672 L
.50005 .08582 L
.53854 .08448 L
.55843 .08395 L
.57947 .08352 L
.59906 .08322 L
.61738 .08303 L
.6278 .08294 L
.63768 .08288 L
.64742 .08283 L
.65623 .08279 L
.66585 .08276 L
.67112 .08275 L
.67609 .08274 L
.67833 .08274 L
.6807 .08274 L
.68275 .08274 L
.68493 .08273 L
.68617 .08273 L
.6873 .08273 L
Mistroke
.68844 .08273 L
.68949 .08273 L
.69073 .08273 L
.69137 .08273 L
.69206 .08273 L
.69322 .08273 L
.69449 .08273 L
.69578 .08273 L
.69697 .08273 L
.69828 .08273 L
.69968 .08273 L
.70227 .08273 L
.70462 .08274 L
.70939 .08274 L
.71389 .08274 L
.72392 .08276 L
.73477 .08278 L
.77576 .0829 L
.81523 .08304 L
.85319 .08319 L
.8936 .08333 L
.9325 .08346 L
.97385 .08359 L
.97619 .0836 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03056 L
.03068 .03489 L
.03279 .03781 L
.03527 .04026 L
.03652 .0412 L
.0379 .04207 L
.04033 .04326 L
.04262 .04412 L
.04761 .04544 L
.05217 .04632 L
.06244 .04796 L
.08259 .05147 L
.09399 .05405 L
.10458 .05705 L
.11466 .06074 L
.1238 .06516 L
.12887 .06825 L
.13435 .07235 L
.14429 .08284 L
.16384 .12646 L
.16659 .13434 L
.16919 .14049 L
.17063 .14294 L
.17144 .14397 L
.17219 .14466 L
.17283 .14505 L
.17352 .14528 L
.17425 .14529 L
.17493 .14509 L
.1762 .14421 L
.17684 .14354 L
.17753 .14264 L
.17992 .13848 L
.18529 .12549 L
.19518 .1011 L
.20072 .09061 L
.20575 .08333 L
.21044 .07822 L
.21292 .0761 L
.21554 .07422 L
.21783 .07285 L
.22035 .07161 L
.22265 .07069 L
.22478 .07 L
.22727 .06938 L
.2287 .0691 L
Mistroke
.22999 .0689 L
.23114 .06875 L
.23239 .06862 L
.2337 .06852 L
.23494 .06846 L
.23606 .06843 L
.2373 .06842 L
.23858 .06844 L
.23978 .06848 L
.2409 .06853 L
.24193 .0686 L
.24423 .06879 L
.2495 .06941 L
.25238 .06978 L
.25509 .07012 L
.25738 .07035 L
.25868 .07045 L
.25986 .07053 L
.26108 .07058 L
.26178 .0706 L
.26242 .0706 L
.26373 .0706 L
.26446 .07058 L
.26512 .07056 L
.26631 .07049 L
.26758 .07039 L
.26985 .07016 L
.27228 .06982 L
.27496 .06937 L
.28424 .0676 L
.28942 .06673 L
.29228 .06634 L
.29498 .06603 L
.29749 .0658 L
.30023 .0656 L
.30271 .06547 L
.30502 .06538 L
.30619 .06534 L
.30743 .06531 L
.30848 .0653 L
.30964 .06528 L
.31089 .06527 L
.31159 .06526 L
.31222 .06526 L
.31346 .06526 L
.31463 .06526 L
.31572 .06527 L
.31688 .06527 L
.31787 .06528 L
.31896 .0653 L
Mistroke
.32366 .06538 L
.32878 .06549 L
.33429 .06565 L
.34425 .06601 L
.35437 .06651 L
.3654 .06721 L
.38549 .06884 L
.40683 .0706 L
.4169 .07126 L
.42616 .07174 L
.43585 .07212 L
.44632 .07242 L
.45556 .0726 L
.46531 .07275 L
.4748 .07286 L
.48496 .07295 L
.48989 .07299 L
.49456 .07302 L
.49907 .07304 L
.5033 .07306 L
.5079 .07307 L
.51034 .07308 L
.51159 .07308 L
.51297 .07308 L
.51432 .07309 L
.51557 .07309 L
.51627 .07309 L
.5169 .07309 L
.51763 .07309 L
.51832 .07309 L
.51955 .07309 L
.52067 .07309 L
.52191 .07309 L
.52323 .07309 L
.52437 .07309 L
.52541 .07308 L
.52776 .07308 L
.532 .07307 L
.53695 .07305 L
.54165 .07303 L
.55127 .07298 L
.56151 .07291 L
.57992 .07276 L
.62157 .07234 L
.66171 .07188 L
.70033 .07141 L
.74141 .07091 L
.78097 .07043 L
.81901 .06998 L
.85951 .06951 L
Mistroke
.89849 .06907 L
.93992 .06864 L
.97619 .06828 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04397 L
.04761 .04524 L
.05217 .04609 L
.06244 .04766 L
.08259 .05104 L
.09399 .05351 L
.10458 .05638 L
.11466 .05988 L
.1238 .06402 L
.12887 .06688 L
.13435 .07063 L
.13949 .07496 L
.14429 .07995 L
.15379 .0937 L
.15925 .10436 L
.16423 .11487 L
.16673 .11951 L
.16805 .12151 L
.16877 .12243 L
.16945 .12316 L
.17067 .12414 L
.17132 .12447 L
.17202 .12467 L
.17326 .12462 L
.17439 .12413 L
.17571 .12306 L
.17693 .12163 L
.1797 .11715 L
.18529 .10544 L
.19034 .09481 L
.19581 .08509 L
.20098 .07802 L
.20575 .07317 L
.21005 .06994 L
.21478 .06741 L
.21716 .06646 L
.21972 .06566 L
.22213 .06508 L
.22434 .06469 L
Mistroke
.22563 .06451 L
.22685 .06437 L
.22794 .06427 L
.22912 .0642 L
.23041 .06414 L
.23106 .06412 L
.23177 .06411 L
.23303 .06411 L
.23421 .06413 L
.2354 .06418 L
.23652 .06424 L
.23863 .06439 L
.2409 .06461 L
.24336 .06491 L
.25322 .06654 L
.25846 .06745 L
.26121 .06785 L
.26271 .06803 L
.2641 .06818 L
.26544 .06829 L
.26665 .06836 L
.26734 .0684 L
.268 .06842 L
.26869 .06844 L
.26944 .06845 L
.27067 .06844 L
.27198 .0684 L
.2731 .06834 L
.27432 .06825 L
.27557 .06814 L
.27671 .06801 L
.27928 .06764 L
.28391 .06678 L
.29483 .06418 L
.30493 .06192 L
.31417 .06039 L
.31884 .05982 L
.32399 .05933 L
.32914 .05896 L
.33184 .05881 L
.33469 .05868 L
.33993 .05849 L
.34475 .05836 L
.34974 .05827 L
.35427 .05821 L
.35951 .05816 L
.36446 .05813 L
.37327 .05808 L
.38282 .05803 L
.39227 .058 L
Mistroke
.39764 .05799 L
.40005 .05798 L
.40267 .05798 L
.40539 .05797 L
.40664 .05797 L
.40797 .05797 L
.40929 .05797 L
.41048 .05797 L
.41168 .05797 L
.41281 .05797 L
.41344 .05797 L
.41414 .05797 L
.41486 .05797 L
.41554 .05797 L
.41675 .05797 L
.41805 .05797 L
.41957 .05797 L
.42101 .05797 L
.42371 .05797 L
.4283 .05798 L
.43337 .05798 L
.44363 .058 L
.45261 .05801 L
.46206 .05802 L
.46688 .05802 L
.47216 .05803 L
.47696 .05803 L
.4791 .05803 L
.48142 .05803 L
.48283 .05803 L
.48414 .05803 L
.48536 .05803 L
.48671 .05803 L
.48791 .05803 L
.48904 .05803 L
.49023 .05803 L
.49151 .05803 L
.49223 .05803 L
.49289 .05803 L
.49362 .05803 L
.4944 .05803 L
.49584 .05803 L
.49714 .05803 L
.49979 .05803 L
.50228 .05803 L
.50696 .05803 L
.51208 .05803 L
.52241 .05802 L
.53198 .05801 L
.5409 .058 L
Mistroke
.57988 .05793 L
.62132 .05784 L
.66123 .05773 L
.69964 .05763 L
.74049 .05751 L
.77983 .05739 L
.81765 .05727 L
.85793 .05716 L
.89669 .05705 L
.9379 .05694 L
.97619 .05684 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .0414 L
.0379 .04229 L
.04033 .04354 L
.04262 .04442 L
.04761 .04581 L
.05217 .04673 L
.06244 .04844 L
.08259 .05208 L
.09399 .05475 L
.10458 .05789 L
.11466 .06175 L
.1238 .06641 L
.12887 .06971 L
.13435 .07409 L
.13953 .07932 L
.14429 .08545 L
.14899 .09328 L
.15402 .10442 L
.15878 .11842 L
.16311 .13436 L
.1682 .15454 L
.16959 .15947 L
.17107 .16401 L
.17233 .16716 L
.17301 .16853 L
.17372 .16972 L
.17503 .17119 L
.17622 .17174 L
.1775 .1715 L
.17823 .171 L
.17891 .17033 L
.18014 .1686 L
.18126 .16654 L
.18378 .16058 L
.19388 .12941 L
.19941 .1137 L
.20458 .1017 L
.20898 .09366 L
.21371 .08705 L
.2164 .0841 L
.21896 .08179 L
.22148 .07993 L
Mistroke
.22376 .07856 L
.22598 .07749 L
.22838 .07659 L
.22971 .07621 L
.23092 .07592 L
.23216 .07568 L
.23331 .07551 L
.2343 .0754 L
.23536 .07533 L
.23654 .07529 L
.23762 .07529 L
.23874 .07533 L
.23995 .07542 L
.2411 .07555 L
.24216 .07571 L
.24455 .07618 L
.24679 .07677 L
.2519 .07866 L
.25687 .08125 L
.26222 .085 L
.27175 .09427 L
.27698 .09979 L
.28191 .10418 L
.28472 .10607 L
.2863 .10689 L
.28775 .1075 L
.28898 .10789 L
.28969 .10807 L
.29033 .1082 L
.29101 .10831 L
.29174 .10839 L
.29306 .10844 L
.29438 .10839 L
.2956 .10824 L
.29624 .10813 L
.29695 .10799 L
.29838 .10761 L
.30097 .1067 L
.30342 .1056 L
.32411 .09305 L
.33317 .08824 L
.33797 .08613 L
.34309 .08422 L
.3482 .08266 L
.35284 .0815 L
.36191 .07984 L
.36681 .0792 L
.37211 .07865 L
.38175 .0779 L
.42263 .07504 L
Mistroke
.44297 .0735 L
.45291 .07286 L
.46201 .07236 L
.48025 .07159 L
.4903 .07127 L
.49986 .07102 L
.51991 .0706 L
.53807 .07031 L
.55776 .07006 L
.56869 .06995 L
.57874 .06987 L
.58792 .06981 L
.598 .06976 L
.60813 .06972 L
.61362 .0697 L
.61882 .06969 L
.62372 .06968 L
.62904 .06967 L
.63139 .06967 L
.63388 .06966 L
.63621 .06966 L
.63835 .06966 L
.64082 .06966 L
.64212 .06966 L
.64348 .06966 L
.64467 .06966 L
.64578 .06966 L
.647 .06966 L
.6483 .06966 L
.64903 .06966 L
.64972 .06966 L
.65046 .06966 L
.65125 .06966 L
.65258 .06966 L
.65405 .06966 L
.65675 .06966 L
.65927 .06966 L
.66425 .06967 L
.66969 .06967 L
.67957 .06969 L
.69811 .06972 L
.71784 .06978 L
.73883 .06984 L
.78048 .06999 L
.82062 .07014 L
.85925 .07028 L
.90032 .07042 L
.93988 .07055 L
.97619 .07065 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03777 L
.03527 .0402 L
.03652 .04113 L
.0379 .04198 L
.04033 .04315 L
.04262 .04398 L
.04761 .04526 L
.05217 .0461 L
.06244 .04766 L
.08259 .05102 L
.09399 .05347 L
.10458 .05632 L
.11466 .05978 L
.1238 .06386 L
.12887 .06668 L
.13435 .07035 L
.14429 .0794 L
.15372 .09248 L
.16384 .11218 L
.16682 .11781 L
.16828 .12013 L
.16964 .12188 L
.17087 .12307 L
.17217 .12386 L
.17349 .12412 L
.17423 .12402 L
.17493 .12377 L
.1762 .12294 L
.17684 .12235 L
.17753 .12158 L
.17992 .11807 L
.18529 .10711 L
.19518 .08645 L
.20072 .07776 L
.20575 .07192 L
.21044 .06798 L
.21309 .06629 L
.21554 .06504 L
.21786 .06407 L
.22003 .06334 L
.22229 .06274 L
.22478 .06224 L
.22603 .06204 L
.22736 .06188 L
Mistroke
.22862 .06175 L
.22976 .06167 L
.23041 .06163 L
.2311 .06159 L
.23186 .06156 L
.23256 .06155 L
.23381 .06153 L
.23452 .06153 L
.23519 .06154 L
.23647 .06157 L
.23768 .06161 L
.23877 .06167 L
.23996 .06174 L
.24507 .06214 L
.24974 .06256 L
.2523 .06276 L
.25355 .06283 L
.2547 .06289 L
.2557 .06292 L
.25674 .06294 L
.25779 .06294 L
.25894 .06292 L
.26011 .06287 L
.26136 .06278 L
.26253 .06268 L
.2636 .06256 L
.26592 .06222 L
.26847 .06176 L
.27361 .06062 L
.28283 .05846 L
.28802 .05742 L
.29359 .05652 L
.29884 .05586 L
.30364 .05539 L
.30843 .05502 L
.31353 .05472 L
.31789 .05453 L
.3227 .05436 L
.32785 .05424 L
.33074 .05419 L
.3334 .05416 L
.33573 .05413 L
.33829 .05411 L
.33958 .0541 L
.34096 .0541 L
.34227 .05409 L
.34345 .05409 L
.34464 .05409 L
.34575 .05409 L
.34698 .05408 L
Mistroke
.34829 .05408 L
.34895 .05408 L
.34966 .05408 L
.35097 .05408 L
.35224 .05409 L
.35342 .05409 L
.35815 .05409 L
.36261 .0541 L
.36515 .0541 L
.36584 .0541 L
.36658 .0541 L
.36789 .0541 L
.36907 .0541 L
.37017 .0541 L
.37138 .0541 L
.37268 .0541 L
.37339 .0541 L
.37406 .0541 L
.37556 .0541 L
.37688 .0541 L
.37829 .0541 L
.3834 .05409 L
.393 .05406 L
.40311 .05402 L
.40728 .05401 L
.41174 .054 L
.4143 .05399 L
.41663 .05399 L
.41775 .05399 L
.41896 .05399 L
.42003 .05399 L
.42117 .05399 L
.42238 .05399 L
.4235 .05399 L
.42419 .05399 L
.42484 .05399 L
.42607 .05399 L
.42735 .05399 L
.42855 .05399 L
.42985 .05399 L
.43125 .05399 L
.43376 .05399 L
.43612 .054 L
.44053 .05401 L
.45056 .05404 L
.46139 .05407 L
.48099 .05415 L
.50247 .05422 L
.54203 .05431 L
.58253 .05439 L
Mistroke
.62151 .05446 L
.66294 .05451 L
.70286 .05455 L
.74126 .05458 L
.78211 .0546 L
.82145 .05462 L
.85927 .05464 L
.89955 .05465 L
.93831 .05467 L
.97619 .05468 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04577 L
.05217 .04668 L
.06244 .04837 L
.08259 .05195 L
.09399 .05459 L
.10458 .05767 L
.11466 .06146 L
.1238 .066 L
.12887 .06919 L
.13435 .07341 L
.14429 .0842 L
.16384 .13012 L
.16659 .13918 L
.16919 .1469 L
.17063 .1504 L
.17139 .15195 L
.17219 .15334 L
.17287 .15429 L
.17362 .1551 L
.17493 .1559 L
.17559 .15599 L
.17627 .15587 L
.1775 .15514 L
.17819 .15445 L
.17883 .15364 L
.18028 .15127 L
.1827 .14592 L
.18529 .13892 L
.19593 .10793 L
.20116 .09563 L
.20598 .0868 L
.21036 .08072 L
.215 .07599 L
.21741 .07412 L
.21966 .07267 L
.22231 .07129 L
.22478 .07029 L
.22719 .06955 L
Mistroke
.22976 .06898 L
.23123 .06874 L
.23261 .06857 L
.23385 .06846 L
.23454 .06841 L
.23519 .06838 L
.23637 .06834 L
.23748 .06833 L
.23869 .06835 L
.23999 .0684 L
.24065 .06844 L
.24136 .06849 L
.24265 .0686 L
.24507 .06886 L
.2636 .07166 L
.27383 .07322 L
.27883 .07401 L
.28102 .07431 L
.28226 .07445 L
.28342 .07457 L
.28465 .07467 L
.28576 .07475 L
.28696 .07481 L
.28823 .07484 L
.28951 .07485 L
.29023 .07484 L
.2909 .07482 L
.29212 .07477 L
.29342 .07468 L
.29473 .07457 L
.29613 .07441 L
.29867 .07406 L
.30444 .07296 L
.32422 .06812 L
.33467 .066 L
.34039 .06507 L
.34577 .06435 L
.35559 .06335 L
.36081 .06296 L
.36644 .06263 L
.37642 .06218 L
.38558 .06187 L
.42517 .06084 L
.44511 .0604 L
.46325 .0601 L
.47332 .05998 L
.48283 .05989 L
.493 .05981 L
.50378 .05975 L
.52377 .05966 L
Mistroke
.54221 .0596 L
.55163 .05958 L
.56176 .05956 L
.57132 .05954 L
.58007 .05954 L
.58484 .05953 L
.58745 .05953 L
.58992 .05953 L
.59223 .05953 L
.59472 .05953 L
.59582 .05953 L
.59698 .05953 L
.59805 .05953 L
.59907 .05953 L
.60036 .05953 L
.60153 .05953 L
.6028 .05953 L
.60352 .05953 L
.60418 .05953 L
.60528 .05953 L
.60649 .05953 L
.60776 .05953 L
.60895 .05953 L
.61167 .05953 L
.61417 .05953 L
.61979 .05953 L
.62454 .05953 L
.62961 .05954 L
.63873 .05954 L
.65944 .05956 L
.70096 .05962 L
.74096 .05968 L
.77944 .05974 L
.82038 .0598 L
.85981 .05986 L
.89771 .05992 L
.93807 .05997 L
.97619 .06002 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03486 L
.03279 .03776 L
.03527 .04017 L
.03652 .0411 L
.0379 .04194 L
.04033 .04311 L
.04262 .04394 L
.04761 .04522 L
.05217 .04607 L
.06244 .04765 L
.08259 .05105 L
.09399 .05353 L
.10458 .05642 L
.11466 .05994 L
.1238 .06413 L
.12887 .06703 L
.13435 .07085 L
.14429 .0804 L
.15372 .09458 L
.15901 .1055 L
.16384 .11658 L
.16656 .1223 L
.168 .12481 L
.16879 .12597 L
.16953 .1269 L
.17023 .12762 L
.17087 .12814 L
.17157 .12856 L
.17234 .12881 L
.1736 .12877 L
.17424 .12854 L
.17493 .12813 L
.17563 .12756 L
.17629 .12688 L
.17753 .1253 L
.1803 .12052 L
.18529 .1097 L
.1945 .09058 L
.19914 .08318 L
.20424 .07691 L
.2069 .07433 L
.20976 .07203 L
.21241 .07028 L
.21493 .06891 L
.21739 .06782 L
Mistroke
.22007 .06688 L
.22252 .06622 L
.22478 .06575 L
.22607 .06554 L
.22743 .06536 L
.2286 .06524 L
.22987 .06514 L
.23059 .06509 L
.23125 .06506 L
.232 .06504 L
.23272 .06502 L
.23399 .06501 L
.23471 .06502 L
.23537 .06503 L
.23656 .06507 L
.23767 .06513 L
.2389 .06521 L
.24021 .06531 L
.24534 .06589 L
.25001 .06658 L
.25499 .06737 L
.25741 .06771 L
.25969 .06799 L
.26174 .06818 L
.2629 .06827 L
.26396 .06832 L
.26511 .06836 L
.26618 .06838 L
.26736 .06837 L
.26863 .06833 L
.26926 .0683 L
.26995 .06826 L
.2712 .06817 L
.27356 .06791 L
.2762 .06753 L
.279 .06702 L
.28404 .06591 L
.2942 .06352 L
.29953 .06242 L
.30515 .06147 L
.30999 .06083 L
.31529 .06029 L
.32011 .05993 L
.3246 .05969 L
.32698 .05959 L
.32922 .05952 L
.33343 .05941 L
.33579 .05937 L
.33796 .05934 L
.34034 .05931 L
Mistroke
.34155 .0593 L
.34287 .0593 L
.34416 .05929 L
.34536 .05929 L
.34667 .05929 L
.34741 .05929 L
.34807 .05929 L
.3493 .05929 L
.35062 .05929 L
.35187 .05929 L
.35302 .0593 L
.35517 .05931 L
.35753 .05932 L
.3623 .05936 L
.3731 .05947 L
.38318 .05961 L
.40183 .05992 L
.42211 .06024 L
.43315 .06038 L
.44336 .06048 L
.45312 .06055 L
.46349 .06061 L
.47287 .06066 L
.48297 .06069 L
.48762 .0607 L
.49252 .06071 L
.49701 .06072 L
.50126 .06073 L
.50366 .06073 L
.50627 .06073 L
.50843 .06073 L
.51081 .06074 L
.51339 .06074 L
.5148 .06074 L
.51612 .06074 L
.51736 .06074 L
.51848 .06074 L
.51978 .06074 L
.52102 .06074 L
.52218 .06074 L
.52323 .06074 L
.52444 .06074 L
.52558 .06074 L
.52761 .06074 L
.52981 .06073 L
.5348 .06073 L
.53939 .06072 L
.54916 .06071 L
.55826 .06069 L
.57895 .06063 L
Mistroke
.61793 .06049 L
.65936 .06031 L
.69928 .06013 L
.73768 .05994 L
.77853 .05974 L
.81787 .05955 L
.8557 .05937 L
.89597 .05918 L
.93473 .05902 L
.97594 .05885 L
.97619 .05885 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04042 L
.03652 .04139 L
.0379 .04227 L
.04033 .04351 L
.04262 .04439 L
.04761 .04577 L
.05217 .04669 L
.06244 .04841 L
.08259 .05206 L
.09399 .05474 L
.10458 .05789 L
.11466 .06177 L
.1238 .06647 L
.12887 .06979 L
.13435 .07423 L
.13953 .07954 L
.14429 .0858 L
.14935 .09454 L
.15414 .10562 L
.15967 .12289 L
.16471 .14248 L
.16914 .15895 L
.17021 .1621 L
.17137 .16491 L
.17265 .1672 L
.17384 .16853 L
.17515 .16907 L
.17581 .16899 L
.17653 .16864 L
.17781 .16741 L
.179 .16563 L
.18131 .16079 L
.18378 .1542 L
.19263 .1272 L
.202 .10347 L
.20689 .09442 L
.21227 .08691 L
.21717 .08199 L
.22175 .07873 L
.22451 .0773 L
.22712 .07625 L
.22948 .07555 L
.23081 .07525 L
Mistroke
.23204 .07502 L
.23273 .07491 L
.23349 .07481 L
.23415 .07474 L
.23485 .07468 L
.23548 .07464 L
.23617 .0746 L
.23739 .07458 L
.23814 .07458 L
.23882 .0746 L
.2396 .07463 L
.24034 .07467 L
.24166 .07479 L
.24309 .07496 L
.24551 .07535 L
.24818 .07591 L
.25357 .0774 L
.26325 .08107 L
.26818 .08371 L
.27336 .08728 L
.28263 .09506 L
.29273 .10303 L
.29563 .10482 L
.29838 .10624 L
.30087 .10731 L
.3035 .10822 L
.30586 .10886 L
.30845 .10938 L
.30958 .10956 L
.3108 .10972 L
.313 .10995 L
.31432 .11004 L
.31502 .11008 L
.31576 .11011 L
.3164 .11014 L
.31712 .11016 L
.31838 .11019 L
.31959 .11021 L
.32091 .11021 L
.32214 .11021 L
.32328 .1102 L
.32535 .11019 L
.32648 .11018 L
.32755 .11018 L
.32882 .11017 L
.32998 .11018 L
.33106 .11018 L
.33223 .1102 L
.33336 .11022 L
.33461 .11026 L
Mistroke
.33592 .11031 L
.33714 .11037 L
.33932 .11051 L
.34166 .11071 L
.3442 .11098 L
.34691 .11135 L
.35178 .11218 L
.36281 .1148 L
.38291 .1203 L
.38791 .12141 L
.3932 .12235 L
.39597 .12274 L
.399 .12309 L
.40176 .12333 L
.40433 .1235 L
.40559 .12356 L
.40695 .12361 L
.40824 .12364 L
.40943 .12366 L
.4105 .12367 L
.41168 .12367 L
.41291 .12366 L
.41407 .12364 L
.41535 .12361 L
.41669 .12357 L
.4191 .12346 L
.42168 .12332 L
.42451 .12313 L
.44413 .12126 L
.46509 .11918 L
.50661 .11602 L
.54661 .11337 L
.58509 .11125 L
.62603 .10961 L
.66546 .10845 L
.70336 .10762 L
.74372 .10696 L
.78257 .10645 L
.82386 .10601 L
.86364 .10562 L
.90191 .10528 L
.94263 .10494 L
.97619 .10466 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .04039 L
.03652 .04135 L
.0379 .04223 L
.04033 .04345 L
.04262 .04431 L
.04761 .04566 L
.05217 .04656 L
.06244 .04822 L
.08259 .05178 L
.09399 .05439 L
.10458 .05744 L
.11466 .06119 L
.1238 .06567 L
.12887 .06882 L
.13435 .07298 L
.14429 .08361 L
.16384 .12786 L
.16659 .13599 L
.16919 .14247 L
.17063 .14515 L
.17144 .14631 L
.17219 .14713 L
.17283 .14763 L
.17352 .14797 L
.17425 .1481 L
.17493 .148 L
.1762 .14729 L
.17684 .14669 L
.17753 .14586 L
.17992 .14185 L
.1827 .1355 L
.18529 .12871 L
.19511 .10325 L
.19994 .09329 L
.20438 .08595 L
.20951 .07949 L
.21216 .0769 L
.21507 .07454 L
.21979 .07168 L
.22237 .07054 L
.22478 .0697 L
.22736 .06902 L
.22976 .06857 L
Mistroke
.23114 .06838 L
.23239 .06825 L
.23308 .0682 L
.23383 .06815 L
.23454 .06811 L
.23519 .06809 L
.23637 .06807 L
.23748 .06807 L
.23869 .0681 L
.23999 .06816 L
.24065 .0682 L
.24136 .06825 L
.24265 .06836 L
.24507 .06862 L
.2636 .07092 L
.28303 .07302 L
.29334 .07475 L
.29616 .07514 L
.29913 .07548 L
.30167 .0757 L
.30309 .0758 L
.30444 .07588 L
.30572 .07594 L
.30639 .07597 L
.30711 .07599 L
.30837 .07602 L
.30953 .07604 L
.31017 .07604 L
.31086 .07604 L
.31211 .07604 L
.31288 .07603 L
.3136 .07602 L
.31496 .076 L
.31613 .07597 L
.31739 .07593 L
.31964 .07586 L
.32473 .07564 L
.32908 .07546 L
.33377 .07528 L
.33645 .0752 L
.33763 .07518 L
.33892 .07515 L
.34014 .07513 L
.34127 .07512 L
.34247 .07511 L
.34376 .07511 L
.34499 .07511 L
.34568 .07512 L
.34634 .07512 L
.34766 .07514 L
Mistroke
.3484 .07515 L
.34907 .07516 L
.35159 .07522 L
.35398 .0753 L
.35929 .07554 L
.36508 .0759 L
.37564 .07667 L
.38522 .07735 L
.39009 .07765 L
.39536 .0779 L
.39778 .07799 L
.40034 .07807 L
.40252 .07813 L
.40366 .07815 L
.40491 .07817 L
.40564 .07818 L
.40632 .07819 L
.40695 .07819 L
.40765 .0782 L
.40886 .0782 L
.41015 .07821 L
.41088 .0782 L
.41154 .0782 L
.41227 .0782 L
.41304 .0782 L
.41434 .07818 L
.41576 .07817 L
.4183 .07813 L
.42101 .07807 L
.42589 .07794 L
.43614 .07757 L
.44725 .0771 L
.4674 .07629 L
.50834 .07507 L
.54777 .07413 L
.58567 .07341 L
.60514 .07312 L
.62603 .07287 L
.6458 .07267 L
.66733 .07249 L
.70711 .07225 L
.72684 .07216 L
.74783 .07208 L
.78948 .07196 L
.82962 .07187 L
.86824 .0718 L
.90932 .07173 L
.94888 .07167 L
.97619 .07163 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04226 L
.04033 .04349 L
.04262 .04437 L
.04761 .04574 L
.05217 .04665 L
.06244 .04835 L
.08259 .05198 L
.09399 .05464 L
.10458 .05777 L
.11466 .06162 L
.1238 .06626 L
.12887 .06953 L
.13435 .0739 L
.13953 .07911 L
.14429 .08522 L
.14935 .09369 L
.15414 .10431 L
.15967 .12058 L
.16471 .13846 L
.16701 .14642 L
.16827 .15033 L
.16945 .15353 L
.17054 .15597 L
.17154 .15773 L
.17265 .1591 L
.17384 .15985 L
.17504 .15986 L
.17615 .15922 L
.17738 .15787 L
.17868 .15577 L
.18135 .14983 L
.18378 .14317 L
.19315 .11556 L
.19808 .10325 L
.20331 .09282 L
.20788 .0858 L
.2129 .08003 L
.21747 .07625 L
.22175 .07375 L
.22433 .07264 L
.22673 .07184 L
Mistroke
.22936 .07118 L
.23082 .07091 L
.23215 .07072 L
.23343 .07057 L
.2346 .07048 L
.23589 .07041 L
.23654 .07038 L
.23725 .07037 L
.23844 .07037 L
.23972 .0704 L
.24093 .07045 L
.24203 .07052 L
.24441 .07073 L
.2466 .07097 L
.25156 .07164 L
.26057 .07259 L
.29989 .07637 L
.33769 .08031 L
.37795 .08533 L
.38691 .08677 L
.39646 .08809 L
.40196 .0887 L
.40695 .08914 L
.40935 .08931 L
.41196 .08947 L
.41669 .08969 L
.41911 .08977 L
.42177 .08984 L
.42311 .08986 L
.42385 .08987 L
.42455 .08988 L
.4252 .08988 L
.4259 .08989 L
.42714 .0899 L
.42829 .0899 L
.42956 .08989 L
.4302 .08989 L
.43089 .08989 L
.43214 .08988 L
.43331 .08987 L
.43455 .08985 L
.43677 .08981 L
.44199 .0897 L
.44685 .08956 L
.45788 .08919 L
.49689 .08783 L
.53836 .08641 L
.57831 .08507 L
.61674 .08399 L
.65763 .08308 L
Mistroke
.697 .08235 L
.73485 .08178 L
.77516 .08125 L
.81395 .08081 L
.8552 .08038 L
.89493 .07999 L
.93314 .07964 L
.97381 .07929 L
.97619 .07927 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03494 L
.03279 .03788 L
.03527 .04036 L
.03652 .04131 L
.0379 .04218 L
.04033 .0434 L
.04262 .04426 L
.04761 .04561 L
.05217 .0465 L
.06244 .04817 L
.08259 .05174 L
.09399 .05436 L
.10458 .05742 L
.11466 .06119 L
.1238 .06571 L
.12887 .06889 L
.13435 .0731 L
.14429 .08395 L
.16384 .13014 L
.16659 .13869 L
.16919 .14541 L
.17063 .14813 L
.17144 .14927 L
.17219 .15007 L
.17283 .15052 L
.17352 .15081 L
.17425 .15086 L
.17493 .15068 L
.1762 .14981 L
.17684 .14912 L
.17753 .14819 L
.17992 .14383 L
.18529 .13005 L
.19518 .10395 L
.20072 .09267 L
.20575 .08482 L
.21044 .07932 L
.21292 .07703 L
.21554 .075 L
.21783 .07353 L
.22035 .07219 L
.22265 .0712 L
.22478 .07046 L
.22727 .06979 L
.2287 .06949 L
Mistroke
.22999 .06927 L
.23114 .0691 L
.23239 .06896 L
.2337 .06885 L
.23494 .06878 L
.23606 .06874 L
.2373 .06873 L
.23858 .06874 L
.23978 .06878 L
.2409 .06883 L
.24193 .0689 L
.24423 .06909 L
.2495 .06968 L
.25238 .07003 L
.25509 .07032 L
.25621 .07042 L
.25738 .07051 L
.25868 .07058 L
.25986 .07062 L
.26116 .07064 L
.26237 .07062 L
.26307 .0706 L
.2637 .07058 L
.26443 .07054 L
.26512 .0705 L
.26744 .0703 L
.2699 .07002 L
.2743 .06941 L
.27944 .0687 L
.28195 .06841 L
.28424 .06819 L
.28542 .0681 L
.28669 .06802 L
.2879 .06797 L
.28902 .06793 L
.2902 .0679 L
.2915 .06788 L
.29216 .06788 L
.29286 .06788 L
.29414 .0679 L
.29546 .06793 L
.29621 .06795 L
.2969 .06798 L
.29981 .06811 L
.30502 .06843 L
.34403 .07087 L
.36535 .07264 L
.38549 .07495 L
.40379 .07689 L
.4088 .07731 L
Mistroke
.41419 .07768 L
.41885 .07794 L
.42393 .07817 L
.42925 .07835 L
.43169 .07841 L
.4343 .07847 L
.43688 .07852 L
.43922 .07855 L
.44157 .07857 L
.44378 .07859 L
.445 .0786 L
.44634 .0786 L
.44702 .07861 L
.44774 .07861 L
.44905 .07861 L
.45035 .07861 L
.45158 .07861 L
.45269 .07861 L
.45389 .07861 L
.4552 .07861 L
.45664 .07861 L
.45957 .0786 L
.46227 .07858 L
.46482 .07857 L
.48501 .0784 L
.50352 .0782 L
.52246 .07793 L
.54317 .07757 L
.58375 .0768 L
.62281 .07609 L
.66433 .0754 L
.70433 .0748 L
.74282 .07427 L
.78376 .07375 L
.82318 .07328 L
.86109 .07286 L
.90145 .07243 L
.94029 .07205 L
.97619 .07171 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04214 L
.04033 .04334 L
.04262 .04419 L
.04761 .0455 L
.05217 .04636 L
.06244 .04797 L
.08259 .0514 L
.09399 .05392 L
.10458 .05685 L
.11466 .06041 L
.1238 .06464 L
.12887 .06757 L
.13435 .0714 L
.14429 .08093 L
.16384 .11684 L
.16659 .1229 L
.16919 .12763 L
.17063 .12955 L
.17144 .13036 L
.17219 .13092 L
.17283 .13125 L
.17352 .13144 L
.17425 .13147 L
.17493 .13132 L
.1762 .13062 L
.17684 .13006 L
.17753 .12932 L
.17992 .12576 L
.1827 .12014 L
.18529 .1141 L
.19 .10269 L
.19511 .09145 L
.19962 .08327 L
.20438 .07651 L
.20703 .07354 L
.20994 .07083 L
.21241 .06895 L
.21507 .0673 L
.21769 .066 L
.22009 .06506 L
.22249 .06432 L
Mistroke
.22478 .06378 L
.22603 .06355 L
.22738 .06334 L
.22857 .06319 L
.22982 .06307 L
.23096 .06299 L
.2322 .06292 L
.23334 .06288 L
.23439 .06287 L
.23503 .06287 L
.23572 .06287 L
.23698 .0629 L
.2382 .06294 L
.23933 .06299 L
.2419 .06316 L
.24462 .06339 L
.24884 .0638 L
.25105 .064 L
.25338 .06418 L
.25462 .06426 L
.25528 .06429 L
.25598 .06432 L
.25721 .06435 L
.25836 .06436 L
.25962 .06434 L
.2608 .06429 L
.26187 .06422 L
.26302 .06413 L
.26539 .06387 L
.26793 .06349 L
.27251 .06264 L
.28294 .06053 L
.29395 .05875 L
.304 .05759 L
.31389 .05676 L
.32306 .05621 L
.32784 .056 L
.33311 .05581 L
.33863 .05566 L
.34381 .05556 L
.34849 .05549 L
.35362 .05543 L
.35898 .05538 L
.36397 .05535 L
.38246 .05524 L
.40118 .05512 L
.41103 .05507 L
.41643 .05505 L
.42148 .05503 L
.42675 .05501 L
Mistroke
.42955 .05501 L
.43099 .05501 L
.43257 .055 L
.43399 .055 L
.43531 .055 L
.43657 .055 L
.43721 .055 L
.43791 .055 L
.43923 .055 L
.44047 .055 L
.44168 .055 L
.4428 .055 L
.44396 .055 L
.44521 .055 L
.44639 .055 L
.44747 .055 L
.4501 .055 L
.4526 .05501 L
.46294 .05502 L
.50129 .0551 L
.54209 .05517 L
.58138 .05523 L
.61915 .05529 L
.65937 .05534 L
.69808 .05538 L
.73924 .05541 L
.77888 .05544 L
.81701 .05547 L
.85759 .05549 L
.89666 .05551 L
.93818 .05553 L
.97619 .05555 L
Mfstroke
1 0 .617 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04346 L
.04262 .04433 L
.04761 .04567 L
.05217 .04656 L
.06244 .04821 L
.08259 .05173 L
.09399 .05431 L
.10458 .05732 L
.11466 .061 L
.1238 .06539 L
.12887 .06845 L
.13435 .07248 L
.14429 .08264 L
.16384 .12309 L
.16659 .13044 L
.16919 .13644 L
.17063 .13902 L
.17139 .1401 L
.17219 .14103 L
.17287 .14162 L
.17362 .14206 L
.17493 .14228 L
.17559 .14213 L
.17627 .14178 L
.1775 .14073 L
.17819 .13991 L
.17883 .139 L
.18028 .13651 L
.18529 .12465 L
.19511 .09892 L
.19994 .08877 L
.20438 .0814 L
.20951 .07507 L
.21221 .07255 L
.21507 .07038 L
.21969 .06781 L
.22232 .06678 L
.22478 .06604 L
.22603 .06574 L
.22736 .06547 L
Mistroke
.22851 .06527 L
.22976 .0651 L
.23123 .06495 L
.2319 .06489 L
.23261 .06484 L
.23325 .06481 L
.23395 .06478 L
.23519 .06474 L
.23648 .06474 L
.23766 .06475 L
.23831 .06477 L
.23901 .0648 L
.2403 .06486 L
.24278 .06503 L
.24507 .06523 L
.24971 .06571 L
.25198 .06594 L
.25406 .06612 L
.25511 .0662 L
.25625 .06626 L
.25739 .06631 L
.2586 .06634 L
.25985 .06635 L
.26056 .06634 L
.26119 .06633 L
.26243 .06629 L
.2636 .06622 L
.26476 .06615 L
.266 .06604 L
.26825 .06581 L
.27335 .06518 L
.28366 .06387 L
.30212 .06176 L
.32191 .05958 L
.32733 .05911 L
.33309 .05867 L
.33808 .05836 L
.34345 .05809 L
.34854 .05788 L
.3532 .05772 L
.36237 .05749 L
.36722 .05739 L
.37254 .0573 L
.38326 .05716 L
.40449 .05692 L
.42379 .05674 L
.43341 .05667 L
.44385 .05661 L
.44864 .05659 L
.45371 .05657 L
Mistroke
.46281 .05655 L
.46773 .05654 L
.47223 .05653 L
.47742 .05653 L
.48235 .05652 L
.4869 .05652 L
.49111 .05652 L
.49573 .05651 L
.49832 .05651 L
.50066 .05651 L
.50299 .05651 L
.50554 .05651 L
.50683 .05651 L
.50821 .05651 L
.50951 .05651 L
.51069 .05651 L
.51187 .05651 L
.51297 .05651 L
.51416 .05651 L
.51543 .05651 L
.51653 .05651 L
.51757 .05651 L
.51992 .05651 L
.52247 .05651 L
.52515 .05651 L
.52995 .05651 L
.53511 .05651 L
.54075 .05652 L
.55103 .05652 L
.56037 .05653 L
.58133 .05654 L
.62133 .05659 L
.65982 .05663 L
.70075 .05667 L
.74018 .05671 L
.77808 .05675 L
.81844 .05678 L
.85729 .05682 L
.89858 .05685 L
.93837 .05688 L
.97619 .0569 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03793 L
.03527 .04043 L
.03652 .04139 L
.0379 .04228 L
.04033 .04352 L
.04262 .0444 L
.04761 .04578 L
.05217 .04669 L
.06244 .04838 L
.08259 .05198 L
.09399 .05462 L
.10458 .05772 L
.11466 .06153 L
.1238 .0661 L
.12887 .06931 L
.13435 .07357 L
.14429 .0845 L
.16384 .13165 L
.16659 .14107 L
.16919 .14912 L
.17063 .15278 L
.17139 .1544 L
.17219 .15586 L
.17287 .15686 L
.17362 .15772 L
.17493 .15858 L
.17559 .15869 L
.17627 .15858 L
.1775 .15785 L
.17819 .15716 L
.17883 .15634 L
.18028 .15393 L
.1827 .14848 L
.18529 .14133 L
.19593 .10962 L
.20116 .09699 L
.20598 .0879 L
.21036 .08163 L
.215 .07673 L
.21741 .07478 L
.21966 .07328 L
.22231 .07184 L
.22478 .07081 L
.22719 .07003 L
Mistroke
.22976 .06942 L
.23123 .06917 L
.23261 .06899 L
.23385 .06887 L
.23454 .06882 L
.23519 .06878 L
.23637 .06874 L
.23748 .06873 L
.23869 .06875 L
.23999 .06879 L
.24065 .06883 L
.24136 .06888 L
.24265 .06898 L
.24507 .06925 L
.24974 .06994 L
.2547 .07081 L
.2636 .07229 L
.273 .07405 L
.27793 .07511 L
.28311 .07615 L
.28532 .07651 L
.28768 .07681 L
.28903 .07695 L
.29026 .07704 L
.2915 .07711 L
.29266 .07714 L
.29372 .07715 L
.29485 .07714 L
.29581 .07711 L
.29686 .07707 L
.29799 .07699 L
.29921 .07689 L
.30141 .07665 L
.30396 .07629 L
.30668 .07582 L
.31156 .07484 L
.32262 .07239 L
.3323 .07045 L
.33738 .06962 L
.34273 .06888 L
.34758 .06834 L
.35288 .06787 L
.35769 .06755 L
.36218 .06732 L
.36681 .06714 L
.37101 .06702 L
.37587 .06692 L
.38045 .06684 L
.38927 .06671 L
.39875 .06653 L
Mistroke
.40915 .06628 L
.41889 .06598 L
.43874 .0653 L
.45977 .06468 L
.46989 .06445 L
.48092 .06424 L
.50102 .06396 L
.52071 .06375 L
.54168 .06358 L
.56311 .06344 L
.57292 .06339 L
.58329 .06335 L
.59287 .06332 L
.60338 .06329 L
.61294 .06327 L
.62186 .06326 L
.62687 .06325 L
.63232 .06324 L
.63746 .06324 L
.64222 .06324 L
.6465 .06324 L
.64894 .06324 L
.65123 .06324 L
.6524 .06323 L
.65363 .06323 L
.65468 .06323 L
.65583 .06323 L
.65707 .06323 L
.65776 .06323 L
.6584 .06323 L
.65962 .06323 L
.66078 .06323 L
.66194 .06324 L
.66318 .06324 L
.66542 .06324 L
.66808 .06324 L
.67052 .06324 L
.6758 .06324 L
.68081 .06324 L
.68965 .06325 L
.69927 .06326 L
.73999 .06331 L
.77919 .06338 L
.82084 .06346 L
.86098 .06353 L
.89961 .0636 L
.94068 .06367 L
.97619 .06373 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04225 L
.04033 .04347 L
.04262 .04435 L
.04761 .0457 L
.05217 .04659 L
.06244 .04826 L
.08259 .0518 L
.09399 .0544 L
.10458 .05743 L
.11466 .06116 L
.1238 .0656 L
.12887 .06871 L
.13435 .07281 L
.14429 .08322 L
.16384 .12595 L
.16659 .13404 L
.16919 .14078 L
.17063 .14377 L
.17139 .14506 L
.17219 .14619 L
.17287 .14694 L
.17362 .14755 L
.17493 .14803 L
.17559 .14799 L
.17627 .14775 L
.1775 .14684 L
.17819 .14608 L
.17883 .14522 L
.18028 .1428 L
.1827 .13752 L
.18529 .13077 L
.1904 .11633 L
.19593 .10175 L
.20081 .09116 L
.20598 .0825 L
.21064 .07674 L
.21311 .07437 L
.21576 .07227 L
.2182 .0707 L
.22042 .06953 L
.22267 .06858 L
Mistroke
.22478 .06786 L
.22729 .06721 L
.22956 .06678 L
.23084 .06661 L
.23201 .06648 L
.23329 .06638 L
.23394 .06634 L
.23465 .06631 L
.23585 .06628 L
.23694 .06627 L
.2382 .06629 L
.23939 .06634 L
.24049 .06639 L
.2415 .06646 L
.2438 .06666 L
.24896 .06728 L
.25451 .068 L
.25706 .06829 L
.25974 .06853 L
.26204 .06867 L
.26333 .06874 L
.26454 .06879 L
.26698 .06886 L
.26928 .06891 L
.27359 .06898 L
.27584 .06902 L
.27822 .06905 L
.27947 .06906 L
.28018 .06907 L
.28084 .06907 L
.282 .06908 L
.28324 .06907 L
.28391 .06907 L
.28462 .06906 L
.28589 .06904 L
.2866 .06902 L
.28726 .069 L
.28878 .06895 L
.29009 .06889 L
.2913 .06882 L
.29402 .06862 L
.29881 .06812 L
.30386 .06744 L
.3238 .06421 L
.3325 .06304 L
.34193 .06206 L
.34717 .06164 L
.35201 .06134 L
.36152 .06089 L
.36636 .06073 L
Mistroke
.37169 .06059 L
.38246 .06037 L
.42277 .05969 L
.44132 .05938 L
.46156 .05912 L
.47253 .05902 L
.48271 .05895 L
.50281 .05885 L
.51338 .05881 L
.52334 .05878 L
.54196 .05873 L
.55173 .05871 L
.56205 .05869 L
.57086 .05868 L
.57549 .05868 L
.58053 .05868 L
.58577 .05867 L
.58818 .05867 L
.59074 .05867 L
.59304 .05867 L
.59558 .05867 L
.59669 .05867 L
.59789 .05867 L
.59893 .05867 L
.60005 .05867 L
.60137 .05867 L
.60259 .05867 L
.60334 .05867 L
.60405 .05867 L
.60537 .05867 L
.60605 .05867 L
.60677 .05867 L
.60806 .05867 L
.60944 .05867 L
.61097 .05867 L
.61346 .05867 L
.61614 .05867 L
.62097 .05867 L
.62623 .05867 L
.63111 .05868 L
.64216 .05868 L
.66227 .0587 L
.70147 .05874 L
.74312 .05879 L
.78326 .05884 L
.82189 .05889 L
.86296 .05895 L
.90252 .05899 L
.94056 .05903 L
.97619 .05907 L
Mistroke
Mfstroke
1 0 .545 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .0379 L
.03527 .04039 L
.03652 .04135 L
.0379 .04223 L
.04033 .04345 L
.04262 .04432 L
.04761 .04567 L
.05217 .04657 L
.06244 .04825 L
.08259 .05181 L
.09399 .05443 L
.10458 .05749 L
.11466 .06125 L
.1238 .06575 L
.12887 .06891 L
.13435 .0731 L
.14429 .0838 L
.16384 .12885 L
.16659 .13738 L
.16919 .14434 L
.17063 .14733 L
.17139 .14859 L
.17219 .14966 L
.17287 .15034 L
.17362 .15085 L
.17493 .15113 L
.17559 .15098 L
.17627 .15062 L
.1775 .1495 L
.17819 .14862 L
.17883 .14766 L
.18028 .14503 L
.18529 .13265 L
.19511 .10609 L
.19994 .09546 L
.20438 .08759 L
.20951 .08064 L
.21216 .07785 L
.21507 .07531 L
.21979 .07223 L
.22237 .071 L
.22478 .07009 L
.22736 .06936 L
.22976 .06886 L
Mistroke
.23114 .06866 L
.23239 .06851 L
.23308 .06845 L
.23383 .06839 L
.23454 .06835 L
.23519 .06832 L
.23637 .06829 L
.23748 .06829 L
.23869 .06831 L
.23999 .06837 L
.24065 .06841 L
.24136 .06845 L
.24265 .06856 L
.24507 .06883 L
.2636 .07151 L
.28303 .07469 L
.28835 .07566 L
.29114 .07608 L
.29408 .07643 L
.29533 .07655 L
.29666 .07665 L
.29743 .07669 L
.29813 .07673 L
.29883 .07676 L
.29949 .07679 L
.30071 .07681 L
.30135 .07682 L
.30203 .07682 L
.30318 .07682 L
.30444 .07679 L
.3057 .07675 L
.30707 .07668 L
.30956 .07652 L
.31424 .07611 L
.32476 .0749 L
.32947 .07437 L
.33456 .07385 L
.33904 .07347 L
.34376 .07317 L
.34609 .07305 L
.34865 .07295 L
.34977 .07291 L
.35097 .07288 L
.3521 .07286 L
.35314 .07284 L
.35448 .07282 L
.35518 .07281 L
.35593 .07281 L
.35719 .0728 L
.3579 .0728 L
Mistroke
.35857 .07281 L
.35981 .07281 L
.36095 .07282 L
.36226 .07284 L
.36351 .07286 L
.36603 .07291 L
.36872 .07297 L
.37355 .07311 L
.37926 .0733 L
.38451 .07346 L
.38951 .07359 L
.39204 .07364 L
.3948 .07368 L
.39626 .07369 L
.39758 .07371 L
.39831 .07371 L
.39911 .07371 L
.39986 .07372 L
.40056 .07372 L
.4018 .07372 L
.4025 .07371 L
.40317 .07371 L
.40386 .07371 L
.4045 .0737 L
.40593 .07369 L
.40711 .07368 L
.40837 .07366 L
.41063 .07362 L
.41576 .0735 L
.42118 .07334 L
.42611 .07316 L
.44693 .07227 L
.46611 .07152 L
.48481 .07096 L
.5046 .0705 L
.5425 .06979 L
.5636 .06947 L
.58286 .06924 L
.60279 .06905 L
.62171 .0689 L
.64157 .06879 L
.65997 .06871 L
.67058 .06867 L
.68055 .06864 L
.69917 .0686 L
.70897 .06859 L
.71931 .06857 L
.72813 .06857 L
.7378 .06856 L
.74306 .06856 L
Mistroke
.74804 .06855 L
.75251 .06855 L
.75503 .06855 L
.75736 .06855 L
.75856 .06855 L
.75986 .06855 L
.76108 .06855 L
.76219 .06855 L
.7635 .06855 L
.76424 .06855 L
.76492 .06855 L
.76618 .06855 L
.76688 .06855 L
.76752 .06855 L
.76819 .06855 L
.76891 .06855 L
.77018 .06855 L
.77156 .06855 L
.77307 .06855 L
.77577 .06855 L
.77829 .06855 L
.7833 .06855 L
.78874 .06856 L
.79864 .06856 L
.81719 .06857 L
.85796 .06859 L
.89721 .06862 L
.93495 .06865 L
.97514 .06867 L
.97619 .06867 L
Mfstroke
1 0 .522 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03788 L
.03527 .04034 L
.03652 .04129 L
.0379 .04216 L
.04033 .04337 L
.04262 .04423 L
.04761 .04556 L
.05217 .04644 L
.06244 .04809 L
.08259 .05161 L
.09399 .05419 L
.10458 .0572 L
.11466 .0609 L
.1238 .06532 L
.12887 .06841 L
.13435 .0725 L
.14429 .0829 L
.16384 .1253 L
.16659 .13279 L
.16919 .13856 L
.17063 .14083 L
.17144 .14177 L
.17219 .14238 L
.17283 .14272 L
.17352 .14288 L
.17425 .14283 L
.17493 .14259 L
.1762 .14164 L
.17684 .14093 L
.17753 .14001 L
.17992 .13578 L
.18529 .12276 L
.19518 .09856 L
.20072 .08824 L
.20575 .08111 L
.21044 .07615 L
.21292 .0741 L
.21554 .07229 L
.21783 .07099 L
.22035 .06981 L
.22265 .06895 L
.22478 .06832 L
.22727 .06775 L
.22859 .06752 L
Mistroke
.22999 .06733 L
.23133 .06718 L
.23259 .06708 L
.23372 .06702 L
.23494 .06698 L
.23606 .06697 L
.2373 .06698 L
.23858 .06702 L
.23978 .06708 L
.2409 .06715 L
.24193 .06723 L
.24423 .06744 L
.2495 .06809 L
.25238 .06847 L
.25509 .06879 L
.25738 .06901 L
.25868 .0691 L
.25986 .06917 L
.26108 .06922 L
.26178 .06924 L
.26242 .06925 L
.26373 .06926 L
.26446 .06925 L
.26512 .06924 L
.26631 .06921 L
.26758 .06916 L
.26985 .06905 L
.27496 .06875 L
.2771 .06864 L
.27938 .06855 L
.2807 .06852 L
.2819 .06849 L
.2831 .06848 L
.28424 .06847 L
.28543 .06848 L
.28675 .06849 L
.28741 .0685 L
.28812 .06852 L
.28941 .06856 L
.2919 .06864 L
.29419 .06875 L
.29942 .06901 L
.30502 .06928 L
.31014 .06948 L
.3148 .06961 L
.31705 .06966 L
.31949 .06971 L
.32392 .06978 L
.32866 .06984 L
.33377 .06991 L
Mistroke
.33669 .06996 L
.33937 .07002 L
.34461 .07018 L
.34948 .07037 L
.35479 .07063 L
.36446 .07126 L
.38549 .0729 L
.39564 .07358 L
.40061 .07384 L
.40518 .07403 L
.41047 .07419 L
.41325 .07425 L
.41467 .07428 L
.41619 .0743 L
.41747 .07432 L
.41865 .07433 L
.41983 .07434 L
.42094 .07434 L
.42224 .07435 L
.42344 .07435 L
.42476 .07435 L
.42543 .07434 L
.42616 .07434 L
.42738 .07433 L
.42851 .07433 L
.43108 .0743 L
.43359 .07428 L
.43626 .07424 L
.44552 .07406 L
.46638 .07359 L
.5079 .07272 L
.5479 .07193 L
.58639 .07125 L
.62733 .07068 L
.66675 .07025 L
.70466 .06992 L
.74502 .06964 L
.78386 .06941 L
.82516 .0692 L
.86494 .06902 L
.9032 .06886 L
.94392 .06869 L
.97619 .06857 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .0379 L
.03527 .04039 L
.03652 .04135 L
.0379 .04223 L
.04033 .04345 L
.04262 .04432 L
.04761 .04568 L
.05217 .04658 L
.06244 .04825 L
.08259 .05182 L
.09399 .05443 L
.10458 .05749 L
.11466 .06125 L
.1238 .06575 L
.12887 .06891 L
.13435 .07309 L
.14429 .08376 L
.16384 .12858 L
.16659 .13709 L
.16919 .14409 L
.17063 .14712 L
.17139 .14841 L
.17219 .14952 L
.17287 .15024 L
.17362 .15078 L
.17493 .15113 L
.17559 .15102 L
.17627 .15069 L
.1775 .14962 L
.17819 .14877 L
.17883 .14784 L
.18028 .14523 L
.18529 .1328 L
.19511 .10572 L
.19994 .09486 L
.20438 .08684 L
.20951 .07981 L
.21221 .07694 L
.21507 .07445 L
.21969 .07143 L
.22232 .07018 L
.22478 .06927 L
.22736 .06855 L
.22976 .06806 L
Mistroke
.23114 .06786 L
.23239 .06772 L
.23308 .06765 L
.23383 .0676 L
.23454 .06756 L
.23519 .06753 L
.23637 .0675 L
.23748 .0675 L
.23869 .06752 L
.23999 .06757 L
.24065 .06761 L
.24136 .06765 L
.24265 .06775 L
.24507 .068 L
.25463 .06931 L
.25932 .06987 L
.2636 .07025 L
.26814 .07057 L
.27303 .07094 L
.27799 .07139 L
.28342 .07193 L
.28599 .07216 L
.28873 .07237 L
.29006 .07245 L
.29132 .07252 L
.29244 .07256 L
.29366 .0726 L
.29496 .07262 L
.2957 .07263 L
.29639 .07263 L
.29712 .07263 L
.29778 .07262 L
.29855 .07261 L
.29927 .07259 L
.30056 .07254 L
.30175 .07249 L
.30444 .07232 L
.30685 .07213 L
.30906 .07191 L
.31405 .07135 L
.32308 .07019 L
.33374 .06893 L
.33894 .06843 L
.34367 .06806 L
.34837 .06778 L
.35281 .06757 L
.35524 .06749 L
.35749 .06742 L
.35996 .06737 L
.36132 .06735 L
Mistroke
.36257 .06733 L
.36374 .06731 L
.36502 .0673 L
.36572 .0673 L
.36637 .06729 L
.36766 .06729 L
.36887 .06728 L
.36996 .06728 L
.37123 .06728 L
.37242 .06728 L
.37374 .06728 L
.37441 .06729 L
.37513 .06729 L
.37763 .0673 L
.38326 .06733 L
.38578 .06734 L
.3871 .06735 L
.38851 .06735 L
.38974 .06735 L
.39044 .06735 L
.39109 .06735 L
.39224 .06736 L
.39348 .06735 L
.39461 .06735 L
.39585 .06735 L
.39714 .06734 L
.39834 .06733 L
.40049 .06732 L
.40279 .0673 L
.4055 .06726 L
.40843 .06722 L
.41375 .06711 L
.42371 .06685 L
.44321 .06623 L
.46465 .06561 L
.48502 .06518 L
.50407 .06488 L
.54291 .06443 L
.5641 .06425 L
.58421 .06411 L
.60407 .06401 L
.62248 .06394 L
.63308 .06391 L
.64305 .06389 L
.65194 .06387 L
.66168 .06386 L
.67148 .06385 L
.67683 .06385 L
.68181 .06384 L
.68421 .06384 L
Mistroke
.68649 .06384 L
.68855 .06384 L
.69074 .06384 L
.69312 .06384 L
.69532 .06384 L
.69655 .06384 L
.69769 .06384 L
.69895 .06384 L
.69965 .06384 L
.7003 .06384 L
.70159 .06384 L
.7028 .06384 L
.70388 .06384 L
.70506 .06384 L
.70635 .06384 L
.70771 .06384 L
.71014 .06384 L
.71449 .06384 L
.71928 .06384 L
.72999 .06385 L
.74 .06386 L
.76034 .06387 L
.77889 .06389 L
.81873 .06394 L
.85704 .064 L
.89781 .06405 L
.93707 .0641 L
.9748 .06415 L
.97619 .06415 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03495 L
.03279 .0379 L
.03527 .04038 L
.03652 .04134 L
.0379 .04222 L
.04033 .04344 L
.04262 .04431 L
.04761 .04566 L
.05217 .04656 L
.06244 .04822 L
.08259 .05177 L
.09399 .05437 L
.10458 .05741 L
.11466 .06114 L
.1238 .06561 L
.12887 .06873 L
.13435 .07286 L
.14429 .08338 L
.16384 .12691 L
.16659 .13509 L
.16919 .1418 L
.17063 .14471 L
.17139 .14594 L
.17219 .14701 L
.17287 .14769 L
.17362 .14821 L
.17493 .14852 L
.17559 .1484 L
.17627 .14807 L
.1775 .14701 L
.17819 .14617 L
.17883 .14524 L
.18028 .14267 L
.18529 .13039 L
.19511 .10367 L
.19994 .09301 L
.20438 .08517 L
.20951 .07835 L
.21221 .07558 L
.21507 .07319 L
.21969 .0703 L
.22232 .06912 L
.22478 .06826 L
.22736 .06758 L
.22976 .06714 L
Mistroke
.23114 .06695 L
.23239 .06682 L
.23308 .06677 L
.23383 .06672 L
.23454 .06669 L
.23519 .06666 L
.23637 .06664 L
.23748 .06665 L
.23869 .06668 L
.23999 .06673 L
.24065 .06677 L
.24136 .06682 L
.24265 .06692 L
.24507 .06717 L
.24967 .06776 L
.25463 .06844 L
.25692 .06871 L
.25932 .06896 L
.26139 .06912 L
.2636 .06926 L
.26594 .06938 L
.26811 .06946 L
.27303 .06964 L
.27802 .06984 L
.28342 .07006 L
.28485 .07011 L
.28637 .07016 L
.28767 .07019 L
.28841 .0702 L
.28909 .07021 L
.28977 .07022 L
.29042 .07022 L
.29111 .07023 L
.29185 .07022 L
.2925 .07022 L
.2932 .07021 L
.29444 .07019 L
.29562 .07016 L
.29689 .07011 L
.29919 .07 L
.30193 .06982 L
.30444 .06962 L
.32494 .06727 L
.33494 .06623 L
.34403 .06555 L
.34857 .0653 L
.35096 .0652 L
.35349 .0651 L
.3557 .06503 L
.35814 .06497 L
Mistroke
.36034 .06493 L
.36243 .06489 L
.36499 .06486 L
.36733 .06484 L
.36863 .06483 L
.36984 .06483 L
.37117 .06482 L
.37191 .06482 L
.37259 .06482 L
.37383 .06481 L
.37448 .06481 L
.37516 .06481 L
.37632 .06481 L
.37758 .06481 L
.37871 .06481 L
.37992 .06481 L
.38105 .06481 L
.38211 .06481 L
.38333 .06481 L
.38397 .06481 L
.38467 .06481 L
.38536 .06481 L
.38609 .06481 L
.3874 .06481 L
.38861 .06481 L
.38973 .06481 L
.39097 .0648 L
.39229 .0648 L
.39372 .06479 L
.39527 .06478 L
.39809 .06476 L
.40083 .06474 L
.40336 .06471 L
.41314 .06455 L
.42349 .06431 L
.46139 .06338 L
.48086 .06304 L
.50175 .06277 L
.52294 .06257 L
.54305 .06241 L
.56314 .06228 L
.58132 .06219 L
.60104 .06212 L
.61186 .06209 L
.62203 .06207 L
.63183 .06205 L
.64217 .06204 L
.65099 .06203 L
.65599 .06203 L
.66066 .06202 L
Mistroke
.66568 .06202 L
.66852 .06202 L
.67114 .06202 L
.67343 .06202 L
.67596 .06202 L
.67723 .06202 L
.67793 .06202 L
.67859 .06202 L
.67988 .06202 L
.68106 .06202 L
.68223 .06202 L
.68329 .06202 L
.68451 .06202 L
.68567 .06202 L
.68772 .06202 L
.68994 .06202 L
.6924 .06202 L
.69499 .06202 L
.69964 .06202 L
.70911 .06203 L
.71926 .06203 L
.7376 .06205 L
.77894 .06209 L
.81878 .06215 L
.85709 .0622 L
.89786 .06225 L
.93712 .0623 L
.97486 .06235 L
.97619 .06235 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .04021 L
.03652 .04115 L
.0379 .042 L
.04033 .04319 L
.04262 .04402 L
.04761 .04532 L
.05217 .04619 L
.06244 .04779 L
.08259 .05124 L
.09399 .05377 L
.10458 .05671 L
.11466 .0603 L
.1238 .06459 L
.12887 .06757 L
.13435 .07151 L
.14429 .08143 L
.15372 .09641 L
.15901 .10817 L
.16384 .12033 L
.16656 .12675 L
.168 .12962 L
.16953 .13206 L
.17018 .13286 L
.17087 .13356 L
.17163 .13413 L
.17234 .13446 L
.173 .13458 L
.17369 .13454 L
.17493 .134 L
.17617 .13292 L
.17686 .1321 L
.1775 .13122 L
.17988 .12705 L
.18529 .11466 L
.19504 .09289 L
.20054 .0837 L
.2056 .07733 L
.21004 .07319 L
.21492 .0699 L
.21737 .06866 L
.22001 .06759 L
.2225 .06679 L
.22478 .06623 L
Mistroke
.22607 .06598 L
.22729 .06578 L
.22839 .06562 L
.22956 .06549 L
.23084 .06538 L
.23201 .0653 L
.23327 .06525 L
.23398 .06523 L
.23465 .06522 L
.23584 .06523 L
.23696 .06525 L
.23797 .06528 L
.23907 .06533 L
.24026 .0654 L
.24153 .0655 L
.2438 .0657 L
.24867 .06625 L
.25379 .06684 L
.25509 .06697 L
.25647 .06708 L
.25727 .06713 L
.25799 .06717 L
.25872 .0672 L
.2594 .06722 L
.26069 .06724 L
.26187 .06723 L
.26317 .06719 L
.26382 .06715 L
.26454 .06711 L
.26585 .067 L
.26708 .06687 L
.26941 .06656 L
.27463 .06563 L
.28405 .06375 L
.2883 .06304 L
.29281 .06246 L
.29516 .06222 L
.29776 .06201 L
.30012 .06187 L
.30234 .06176 L
.30352 .06172 L
.30477 .06168 L
.30585 .06165 L
.30703 .06163 L
.30775 .06162 L
.30841 .06161 L
.30972 .06159 L
.3109 .06158 L
.31216 .06158 L
.31338 .06158 L
Mistroke
.3147 .06158 L
.31594 .06159 L
.31708 .0616 L
.31986 .06162 L
.3225 .06165 L
.33135 .0618 L
.341 .062 L
.36069 .06258 L
.37169 .06301 L
.38166 .06346 L
.39182 .06393 L
.40255 .06438 L
.4117 .06469 L
.41696 .06483 L
.42175 .06494 L
.4267 .06503 L
.43138 .06509 L
.43395 .06511 L
.43633 .06513 L
.43893 .06515 L
.44038 .06516 L
.4417 .06516 L
.4439 .06517 L
.44505 .06517 L
.44627 .06517 L
.44733 .06517 L
.44832 .06517 L
.4494 .06518 L
.45055 .06518 L
.45182 .06517 L
.45253 .06517 L
.45319 .06517 L
.45439 .06517 L
.45567 .06517 L
.45789 .06516 L
.46032 .06516 L
.47049 .06511 L
.47978 .06507 L
.50068 .06494 L
.54046 .06463 L
.57873 .06428 L
.61944 .06393 L
.65865 .06362 L
.7003 .06333 L
.74044 .06308 L
.77906 .06286 L
.82014 .06264 L
.8597 .06244 L
.89774 .06227 L
.93824 .06209 L
Mistroke
.97619 .06193 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03496 L
.03279 .03792 L
.03527 .04041 L
.03652 .04137 L
.0379 .04226 L
.04033 .04348 L
.04262 .04436 L
.04761 .04572 L
.05217 .04662 L
.06244 .04829 L
.08259 .05185 L
.09399 .05447 L
.10458 .05752 L
.11466 .06128 L
.1238 .06577 L
.12887 .06891 L
.13435 .07307 L
.14429 .08366 L
.16384 .12771 L
.16659 .13609 L
.16919 .14304 L
.17063 .14609 L
.17139 .14741 L
.17219 .14855 L
.17287 .1493 L
.17362 .14989 L
.17493 .15032 L
.17559 .15025 L
.17627 .14997 L
.1775 .14897 L
.17819 .14816 L
.17883 .14725 L
.18028 .1447 L
.18529 .13223 L
.19511 .10466 L
.19994 .09362 L
.20438 .08553 L
.20951 .0785 L
.21221 .07567 L
.21507 .07322 L
.21969 .07028 L
.22232 .06908 L
.22478 .06821 L
.22736 .06753 L
.22976 .06708 L
Mistroke
.23114 .06689 L
.23239 .06676 L
.23308 .06671 L
.23383 .06666 L
.23454 .06662 L
.23519 .0666 L
.23637 .06658 L
.23748 .06658 L
.23869 .06661 L
.23999 .06667 L
.24065 .06671 L
.24136 .06676 L
.24265 .06686 L
.24507 .0671 L
.24967 .06769 L
.25463 .06837 L
.25692 .06864 L
.25932 .06887 L
.26136 .06903 L
.2636 .06916 L
.26597 .06926 L
.26849 .06934 L
.27303 .06946 L
.27802 .06959 L
.28064 .06967 L
.28342 .06973 L
.28482 .06975 L
.28562 .06977 L
.28637 .06977 L
.28768 .06978 L
.28842 .06978 L
.28909 .06978 L
.2904 .06977 L
.29115 .06975 L
.29183 .06974 L
.2931 .0697 L
.29444 .06965 L
.29689 .06953 L
.29919 .06938 L
.30444 .06891 L
.32289 .06662 L
.33335 .06545 L
.33845 .065 L
.34309 .06466 L
.34807 .06437 L
.35277 .06416 L
.35773 .06401 L
.36053 .06394 L
.36311 .06389 L
.36563 .06386 L
Mistroke
.36798 .06383 L
.37057 .06381 L
.37335 .06379 L
.37626 .06378 L
.37902 .06377 L
.3842 .06375 L
.38679 .06374 L
.38923 .06373 L
.3938 .0637 L
.39871 .06365 L
.40402 .06358 L
.4136 .06342 L
.42241 .06323 L
.44285 .06275 L
.46192 .06236 L
.48026 .06209 L
.49991 .06189 L
.52117 .06172 L
.54129 .06159 L
.56122 .06149 L
.57964 .06142 L
.59832 .06137 L
.60895 .06134 L
.61893 .06133 L
.62877 .06132 L
.63372 .06131 L
.63913 .06131 L
.64377 .06131 L
.64631 .06131 L
.64872 .06131 L
.65096 .06131 L
.65339 .0613 L
.6556 .0613 L
.65764 .0613 L
.65889 .0613 L
.66008 .0613 L
.66115 .0613 L
.66232 .0613 L
.66358 .0613 L
.66428 .0613 L
.66492 .0613 L
.66617 .0613 L
.66734 .0613 L
.66845 .0613 L
.66961 .0613 L
.6717 .0613 L
.67395 .0613 L
.67641 .06131 L
.68158 .06131 L
.6871 .06131 L
Mistroke
.69706 .06132 L
.71836 .06133 L
.73849 .06135 L
.77689 .0614 L
.81775 .06146 L
.85709 .06151 L
.89491 .06156 L
.93519 .06161 L
.97394 .06166 L
.97619 .06166 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04034 L
.03652 .04129 L
.0379 .04216 L
.04033 .04336 L
.04262 .04421 L
.04761 .04553 L
.05217 .0464 L
.06244 .04803 L
.08259 .05151 L
.09399 .05406 L
.10458 .05703 L
.11466 .06066 L
.1238 .06499 L
.12887 .068 L
.13435 .07196 L
.14429 .08192 L
.15372 .09685 L
.15901 .10849 L
.16384 .12055 L
.16656 .12698 L
.168 .12989 L
.16953 .13242 L
.17018 .13327 L
.17087 .13403 L
.17163 .13467 L
.17234 .13507 L
.173 .13527 L
.17369 .1353 L
.17493 .1349 L
.17617 .13395 L
.17686 .13319 L
.1775 .13237 L
.17988 .12834 L
.18529 .11594 L
.19504 .09351 L
.20054 .08391 L
.2056 .07725 L
.21004 .07293 L
.21492 .0695 L
.21737 .06821 L
.22001 .0671 L
.2225 .06628 L
.22478 .0657 L
Mistroke
.22607 .06544 L
.22729 .06523 L
.22839 .06507 L
.22956 .06494 L
.23084 .06482 L
.23201 .06475 L
.23327 .06469 L
.23398 .06467 L
.23465 .06466 L
.23584 .06466 L
.23696 .06468 L
.23797 .06472 L
.23907 .06477 L
.24026 .06484 L
.24153 .06493 L
.2438 .06513 L
.24867 .06567 L
.25379 .06622 L
.25509 .06634 L
.25647 .06643 L
.25727 .06648 L
.25799 .06651 L
.25872 .06654 L
.2594 .06655 L
.26069 .06656 L
.26187 .06655 L
.26317 .0665 L
.26382 .06647 L
.26454 .06643 L
.26708 .06623 L
.26941 .06599 L
.27463 .06534 L
.27914 .06479 L
.28405 .06428 L
.28893 .06392 L
.29344 .06368 L
.29776 .06351 L
.30234 .06336 L
.32201 .06271 L
.33063 .06244 L
.33551 .06231 L
.3379 .06226 L
.34006 .06222 L
.34224 .06219 L
.34461 .06216 L
.34591 .06214 L
.34711 .06213 L
.34833 .06212 L
.34947 .06212 L
.35057 .06211 L
Mistroke
.35176 .06211 L
.35308 .06211 L
.35428 .06211 L
.35553 .06211 L
.35624 .06212 L
.3569 .06212 L
.35938 .06213 L
.36069 .06214 L
.36211 .06216 L
.36468 .06219 L
.36948 .06225 L
.38023 .06244 L
.38521 .06252 L
.39055 .0626 L
.39559 .06266 L
.39798 .06269 L
.40019 .0627 L
.40266 .06272 L
.40396 .06273 L
.40463 .06273 L
.40535 .06273 L
.40654 .06273 L
.40767 .06273 L
.40832 .06273 L
.40901 .06273 L
.41023 .06273 L
.41155 .06273 L
.41229 .06273 L
.41296 .06273 L
.4155 .06272 L
.41692 .06271 L
.41846 .0627 L
.42126 .06267 L
.43073 .06256 L
.44115 .06241 L
.46219 .06207 L
.50255 .06156 L
.5414 .06121 L
.56116 .06106 L
.58269 .06092 L
.62248 .06073 L
.6422 .06066 L
.66319 .06061 L
.68466 .06056 L
.70485 .06053 L
.72498 .0605 L
.74347 .06049 L
.76235 .06048 L
.77305 .06047 L
.78303 .06047 L
Mistroke
.79352 .06046 L
.80344 .06046 L
.81227 .06046 L
.82201 .06046 L
.8317 .06046 L
.83665 .06046 L
.84197 .06046 L
.84694 .06046 L
.85149 .06046 L
.85617 .06045 L
.86041 .06045 L
.86517 .06045 L
.86779 .06045 L
.87025 .06045 L
.87254 .06045 L
.87464 .06045 L
.87574 .06045 L
.87695 .06045 L
.87821 .06045 L
.87939 .06045 L
.88067 .06045 L
.8814 .06045 L
.88207 .06045 L
.88331 .06045 L
.88462 .06045 L
.88579 .06045 L
.88688 .06045 L
.88939 .06045 L
.89208 .06045 L
.89455 .06045 L
.90011 .06045 L
.90991 .06045 L
.91902 .06045 L
.93972 .06046 L
.97619 .06046 L
Mfstroke
1 0 .379 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04111 L
.0379 .04196 L
.04033 .04313 L
.04262 .04395 L
.04761 .04522 L
.05217 .04605 L
.06244 .04761 L
.08259 .05094 L
.09399 .05337 L
.10458 .05619 L
.11466 .05962 L
.1238 .06364 L
.12887 .06642 L
.13435 .07003 L
.14429 .0789 L
.15372 .09158 L
.16384 .11041 L
.16682 .11571 L
.16828 .11788 L
.16964 .1195 L
.17087 .12059 L
.17217 .12128 L
.17349 .12148 L
.17423 .12136 L
.17493 .1211 L
.1762 .12026 L
.17684 .11967 L
.17753 .11891 L
.17992 .11547 L
.18529 .10485 L
.19518 .08489 L
.20072 .07651 L
.20575 .07089 L
.21044 .06711 L
.21309 .0655 L
.21554 .0643 L
.21786 .06338 L
.22003 .06269 L
.22229 .06213 L
.22478 .06166 L
.22603 .06149 L
.22736 .06133 L
Mistroke
.22862 .06122 L
.22976 .06115 L
.23046 .06111 L
.2311 .06109 L
.23181 .06107 L
.23256 .06105 L
.23381 .06105 L
.23452 .06106 L
.23519 .06107 L
.23647 .0611 L
.23768 .06116 L
.23996 .06129 L
.24241 .06148 L
.24507 .06172 L
.24974 .06216 L
.2523 .06238 L
.25355 .06247 L
.2547 .06253 L
.2557 .06258 L
.25674 .06261 L
.25779 .06262 L
.25894 .06261 L
.26011 .06258 L
.26136 .06251 L
.26253 .06242 L
.2636 .06231 L
.26592 .062 L
.26847 .06156 L
.27361 .06043 L
.28283 .05819 L
.28802 .05709 L
.29359 .05612 L
.29884 .05542 L
.30364 .05493 L
.30843 .05456 L
.31353 .05428 L
.31789 .0541 L
.3227 .05396 L
.32538 .0539 L
.32785 .05386 L
.33055 .05383 L
.33191 .05382 L
.3334 .05381 L
.33472 .0538 L
.33591 .05379 L
.33658 .05379 L
.3373 .05379 L
.3386 .05379 L
.33983 .05379 L
.34112 .05379 L
Mistroke
.34223 .05379 L
.34345 .05379 L
.34474 .05379 L
.34594 .0538 L
.34865 .05381 L
.3536 .05383 L
.36287 .05387 L
.36561 .05388 L
.36818 .05389 L
.37049 .05389 L
.37178 .05389 L
.37298 .0539 L
.37429 .0539 L
.37498 .0539 L
.37571 .0539 L
.37649 .0539 L
.37722 .0539 L
.37788 .0539 L
.3786 .0539 L
.3799 .0539 L
.38055 .0539 L
.38128 .0539 L
.38256 .0539 L
.38376 .05389 L
.38619 .05389 L
.38846 .05389 L
.3936 .05387 L
.40396 .05385 L
.40856 .05384 L
.41291 .05383 L
.41531 .05383 L
.41667 .05383 L
.41792 .05383 L
.41897 .05383 L
.42013 .05382 L
.42134 .05382 L
.42247 .05382 L
.42372 .05382 L
.42442 .05382 L
.42505 .05383 L
.42629 .05383 L
.42745 .05383 L
.43006 .05383 L
.43288 .05383 L
.43804 .05384 L
.44277 .05386 L
.46131 .05392 L
.48179 .054 L
.50087 .05406 L
.53891 .05415 L
Mistroke
.57789 .05422 L
.61933 .05429 L
.65924 .05434 L
.69765 .05437 L
.7385 .0544 L
.77784 .05443 L
.81566 .05445 L
.85594 .05446 L
.8947 .05448 L
.93591 .0545 L
.9756 .05451 L
.97619 .05451 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03057 L
.03068 .03492 L
.03279 .03785 L
.03527 .0403 L
.03652 .04124 L
.0379 .0421 L
.04033 .04329 L
.04262 .04412 L
.04761 .04542 L
.05217 .04628 L
.06244 .04788 L
.08259 .05131 L
.09399 .05383 L
.10458 .05675 L
.11466 .06032 L
.1238 .06455 L
.12887 .06749 L
.13435 .07135 L
.14429 .08098 L
.15372 .0952 L
.15901 .1061 L
.16384 .1171 L
.16656 .12278 L
.168 .12527 L
.16879 .12642 L
.16953 .12735 L
.17023 .12806 L
.17087 .12858 L
.17157 .12899 L
.17234 .12924 L
.1736 .12919 L
.17424 .12895 L
.17493 .12854 L
.17563 .12796 L
.17629 .12727 L
.17753 .12566 L
.1803 .12078 L
.18529 .10969 L
.1945 .09007 L
.19914 .08247 L
.20424 .07603 L
.2069 .07339 L
.20976 .07103 L
.21241 .06923 L
.21493 .06783 L
.21739 .06671 L
Mistroke
.22007 .06574 L
.22252 .06506 L
.22478 .06458 L
.22607 .06436 L
.22743 .06418 L
.22861 .06405 L
.22987 .06394 L
.23058 .0639 L
.23123 .06386 L
.2325 .06382 L
.23321 .0638 L
.23398 .06379 L
.2347 .0638 L
.23537 .0638 L
.23656 .06383 L
.23767 .06388 L
.2389 .06394 L
.24021 .06403 L
.24534 .06452 L
.25008 .06506 L
.25266 .06534 L
.25506 .06556 L
.25612 .06564 L
.25712 .0657 L
.25827 .06574 L
.25931 .06577 L
.26048 .06577 L
.26155 .06576 L
.26272 .06572 L
.26396 .06565 L
.26518 .06555 L
.2665 .06543 L
.26891 .06513 L
.27342 .06444 L
.27834 .06362 L
.28357 .06281 L
.2881 .06225 L
.2905 .062 L
.29309 .06179 L
.29546 .06162 L
.29763 .0615 L
.3019 .06131 L
.30438 .06122 L
.30663 .06116 L
.31169 .06105 L
.31637 .06097 L
.3208 .06091 L
.32596 .06086 L
.32842 .06084 L
.33073 .06082 L
Mistroke
.33321 .06081 L
.33453 .0608 L
.33527 .0608 L
.33595 .0608 L
.33666 .0608 L
.33744 .0608 L
.33812 .0608 L
.33885 .0608 L
.33956 .0608 L
.34023 .0608 L
.34149 .0608 L
.34266 .0608 L
.3439 .06081 L
.34615 .06082 L
.34883 .06084 L
.35127 .06086 L
.35657 .06093 L
.36159 .06101 L
.38006 .06141 L
.38973 .06162 L
.39502 .06172 L
.39999 .0618 L
.4042 .06185 L
.40637 .06187 L
.40875 .06189 L
.41121 .0619 L
.41255 .06191 L
.41379 .06191 L
.41496 .06191 L
.41603 .06191 L
.41725 .06192 L
.41841 .06192 L
.41957 .06192 L
.42081 .06191 L
.42198 .06191 L
.42305 .06191 L
.42566 .0619 L
.42814 .06188 L
.43307 .06185 L
.43844 .0618 L
.4569 .06159 L
.49762 .06115 L
.53682 .0608 L
.57847 .06048 L
.61861 .06025 L
.65723 .0601 L
.69831 .05997 L
.73787 .05989 L
.77591 .05983 L
.81641 .05978 L
Mistroke
.85539 .05974 L
.89682 .0597 L
.93674 .05967 L
.97514 .05964 L
.97619 .05964 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03492 L
.03279 .03785 L
.03527 .04031 L
.03652 .04125 L
.0379 .04211 L
.04033 .0433 L
.04262 .04414 L
.04761 .04544 L
.05217 .0463 L
.06244 .04789 L
.08259 .0513 L
.09399 .0538 L
.10458 .0567 L
.11466 .06023 L
.1238 .06441 L
.12887 .0673 L
.13435 .07108 L
.14429 .08045 L
.15372 .09414 L
.15901 .10459 L
.16384 .11532 L
.16656 .12109 L
.168 .12375 L
.16953 .12613 L
.17087 .12771 L
.17163 .12838 L
.17234 .12884 L
.17359 .12924 L
.17429 .12924 L
.17493 .12908 L
.17618 .1284 L
.17734 .12732 L
.17862 .12569 L
.17998 .12352 L
.18529 .11225 L
.1904 .10024 L
.19593 .0886 L
.20116 .07988 L
.20598 .07382 L
.21033 .0698 L
.21511 .06666 L
.21752 .06549 L
.22011 .0645 L
.22255 .06378 L
.22478 .06329 L
Mistroke
.22607 .06306 L
.22729 .06288 L
.22839 .06275 L
.22956 .06264 L
.23084 .06255 L
.23201 .06249 L
.23327 .06245 L
.23398 .06244 L
.23465 .06244 L
.23584 .06245 L
.23696 .06248 L
.23797 .06252 L
.23907 .06257 L
.24153 .06274 L
.2438 .06293 L
.249 .06344 L
.25154 .06369 L
.25386 .06388 L
.25506 .06395 L
.25631 .06401 L
.25757 .06405 L
.25828 .06406 L
.25894 .06406 L
.25967 .06405 L
.26036 .06404 L
.26165 .06398 L
.26237 .06394 L
.26304 .06389 L
.26454 .06375 L
.26699 .06344 L
.26923 .06308 L
.27426 .06211 L
.28334 .06023 L
.28842 .05931 L
.29394 .05847 L
.29913 .05782 L
.304 .0573 L
.31338 .05654 L
.31837 .05623 L
.32375 .05597 L
.32908 .05577 L
.3347 .05561 L
.33949 .05551 L
.34475 .05543 L
.34727 .0554 L
.35002 .05537 L
.355 .05534 L
.35985 .05531 L
.36433 .0553 L
.38527 .05521 L
Mistroke
.40561 .05511 L
.41555 .05506 L
.42464 .05503 L
.42912 .05502 L
.43148 .05502 L
.434 .05502 L
.43642 .05501 L
.43861 .05501 L
.43967 .05501 L
.44081 .05501 L
.44189 .05501 L
.44289 .05501 L
.44402 .05501 L
.44524 .05501 L
.44639 .05501 L
.44744 .05501 L
.44866 .05501 L
.45 .05501 L
.45243 .05501 L
.45496 .05501 L
.45766 .05502 L
.4625 .05502 L
.50027 .05508 L
.54049 .05513 L
.5792 .05518 L
.62036 .05524 L
.66 .05528 L
.69813 .05532 L
.73871 .05535 L
.77778 .05538 L
.8193 .0554 L
.8593 .05543 L
.89778 .05545 L
.93872 .05547 L
.97619 .05549 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03792 L
.03527 .0404 L
.03652 .04136 L
.0379 .04225 L
.04033 .04347 L
.04262 .04434 L
.04761 .04569 L
.05217 .04658 L
.06244 .04823 L
.08259 .05176 L
.09399 .05435 L
.10458 .05738 L
.11466 .06109 L
.1238 .0655 L
.12887 .06859 L
.13435 .07266 L
.14429 .08294 L
.16384 .12431 L
.16659 .1319 L
.16919 .13808 L
.17063 .14075 L
.17139 .14187 L
.17219 .14283 L
.17287 .14344 L
.17362 .14389 L
.17493 .14412 L
.17559 .14396 L
.17627 .14361 L
.1775 .14252 L
.17819 .14168 L
.17883 .14075 L
.18028 .13819 L
.18529 .12602 L
.19511 .09968 L
.19994 .08931 L
.20438 .08178 L
.20951 .07533 L
.21221 .07275 L
.21507 .07055 L
.21969 .06793 L
.22232 .06688 L
.22478 .06613 L
.22603 .06582 L
.22736 .06555 L
Mistroke
.22851 .06535 L
.22976 .06518 L
.23123 .06502 L
.2319 .06496 L
.23261 .06491 L
.23325 .06487 L
.23395 .06484 L
.23519 .06481 L
.23648 .06481 L
.23766 .06483 L
.23831 .06484 L
.23901 .06487 L
.2403 .06494 L
.24278 .06511 L
.24507 .06532 L
.24971 .06583 L
.25406 .06627 L
.25625 .06644 L
.25747 .06651 L
.2586 .06655 L
.25977 .06657 L
.26104 .06657 L
.26168 .06656 L
.26237 .06654 L
.2636 .06649 L
.26484 .06642 L
.2662 .06632 L
.26895 .06605 L
.27387 .06545 L
.28499 .06406 L
.30515 .06204 L
.31599 .06101 L
.32627 .06016 L
.3355 .05958 L
.34072 .05933 L
.34555 .05914 L
.34985 .059 L
.3545 .05888 L
.3596 .05879 L
.36439 .05872 L
.36947 .05866 L
.37483 .05861 L
.38442 .05855 L
.4225 .05822 L
.44372 .05801 L
.46303 .05787 L
.47265 .05782 L
.48309 .05778 L
.50204 .05772 L
.52189 .05767 L
Mistroke
.53203 .05766 L
.54293 .05764 L
.55314 .05763 L
.56248 .05762 L
.56696 .05761 L
.57186 .05761 L
.57615 .05761 L
.58078 .05761 L
.58355 .05761 L
.5861 .0576 L
.58849 .0576 L
.59111 .0576 L
.59346 .0576 L
.59566 .0576 L
.59688 .0576 L
.59798 .0576 L
.59926 .0576 L
.60047 .0576 L
.60167 .0576 L
.60236 .0576 L
.603 .0576 L
.6043 .0576 L
.60502 .0576 L
.60569 .0576 L
.60804 .0576 L
.61052 .0576 L
.61322 .0576 L
.61574 .0576 L
.62145 .05761 L
.63198 .05761 L
.64192 .05761 L
.66051 .05762 L
.699 .05765 L
.73994 .05769 L
.77936 .05773 L
.81727 .05776 L
.85763 .0578 L
.89647 .05784 L
.93777 .05787 L
.97619 .05791 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03786 L
.03527 .04033 L
.03652 .04127 L
.0379 .04214 L
.04033 .04334 L
.04262 .04419 L
.04761 .04551 L
.05217 .04639 L
.06244 .04801 L
.08259 .05147 L
.09399 .05401 L
.10458 .05697 L
.11466 .06059 L
.1238 .06488 L
.12887 .06787 L
.13435 .0718 L
.14429 .08165 L
.16384 .11991 L
.16659 .12657 L
.16919 .13181 L
.17063 .13397 L
.17144 .13489 L
.17219 .13554 L
.17283 .13592 L
.17352 .13617 L
.17425 .13623 L
.17493 .13611 L
.1762 .13542 L
.17684 .13486 L
.17753 .13409 L
.17992 .1304 L
.1827 .12451 L
.18529 .11817 L
.19511 .09426 L
.19994 .08503 L
.20438 .07837 L
.20951 .07268 L
.21221 .07042 L
.21507 .06848 L
.2173 .06726 L
.21969 .0662 L
.22232 .06528 L
.22478 .06464 L
.22733 .06416 L
Mistroke
.22875 .06396 L
.23004 .06382 L
.23124 .06372 L
.23255 .06364 L
.23378 .0636 L
.23491 .06359 L
.23555 .06359 L
.23624 .06359 L
.23747 .06362 L
.23823 .06365 L
.23894 .06368 L
.24028 .06375 L
.243 .06396 L
.24595 .06425 L
.25102 .06479 L
.2538 .06505 L
.25516 .06515 L
.2564 .06523 L
.25748 .06527 L
.25861 .0653 L
.25975 .06531 L
.26099 .0653 L
.26226 .06525 L
.26297 .06522 L
.26362 .06518 L
.26606 .06496 L
.26837 .06468 L
.27092 .0643 L
.27606 .06341 L
.28528 .06186 L
.29047 .06114 L
.29604 .06051 L
.30609 .05963 L
.31625 .05896 L
.32161 .05867 L
.3273 .05841 L
.33227 .05823 L
.33775 .05806 L
.34273 .05795 L
.34742 .05787 L
.3521 .05781 L
.35476 .05778 L
.35723 .05776 L
.3598 .05775 L
.36223 .05773 L
.36503 .05772 L
.36758 .05772 L
.36982 .05771 L
.37219 .05771 L
.37645 .0577 L
Mistroke
.38148 .05769 L
.38607 .05769 L
.3909 .05768 L
.39549 .05766 L
.40034 .05764 L
.40562 .05762 L
.42393 .0575 L
.44526 .05734 L
.46459 .05722 L
.47428 .05718 L
.48476 .05714 L
.50374 .05708 L
.5237 .05703 L
.54477 .05699 L
.55425 .05698 L
.56442 .05697 L
.57395 .05696 L
.58276 .05695 L
.59294 .05694 L
.59821 .05694 L
.60401 .05694 L
.60871 .05694 L
.61378 .05694 L
.61657 .05694 L
.61912 .05693 L
.62175 .05693 L
.62414 .05693 L
.62531 .05693 L
.62658 .05693 L
.62768 .05693 L
.62889 .05693 L
.63017 .05693 L
.63087 .05693 L
.63152 .05693 L
.63269 .05693 L
.63395 .05693 L
.63512 .05693 L
.6364 .05693 L
.63761 .05693 L
.63872 .05693 L
.64083 .05693 L
.64308 .05693 L
.64868 .05694 L
.65395 .05694 L
.66378 .05694 L
.67358 .05694 L
.68392 .05695 L
.70241 .05695 L
.74045 .05698 L
.78095 .05701 L
Mistroke
.81993 .05703 L
.86136 .05707 L
.90128 .0571 L
.93968 .05712 L
.97619 .05715 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04214 L
.04033 .04334 L
.04262 .04419 L
.04761 .0455 L
.05217 .04636 L
.06244 .04797 L
.08259 .05141 L
.09399 .05392 L
.10458 .05685 L
.11466 .06042 L
.1238 .06465 L
.12887 .06759 L
.13435 .07143 L
.14429 .08099 L
.16384 .11712 L
.16659 .12325 L
.16919 .12805 L
.17063 .13001 L
.17144 .13084 L
.17219 .13142 L
.17283 .13176 L
.17352 .13197 L
.17425 .132 L
.17493 .13187 L
.1762 .13118 L
.17684 .13064 L
.17753 .1299 L
.17992 .12635 L
.1827 .12071 L
.18529 .11462 L
.19 .10309 L
.19511 .0917 L
.19962 .0834 L
.20438 .07654 L
.20703 .07352 L
.20994 .07078 L
.21241 .06887 L
.21507 .0672 L
.21769 .06589 L
.22009 .06494 L
.22249 .06419 L
Mistroke
.22478 .06365 L
.22603 .06342 L
.22738 .06322 L
.22857 .06307 L
.22982 .06295 L
.23096 .06286 L
.2322 .0628 L
.23334 .06277 L
.23439 .06275 L
.23503 .06275 L
.23572 .06276 L
.23698 .06279 L
.2382 .06284 L
.23933 .0629 L
.2419 .06307 L
.24462 .06332 L
.24884 .06375 L
.25105 .06397 L
.25338 .06418 L
.25462 .06427 L
.25528 .06432 L
.25598 .06435 L
.25721 .0644 L
.25836 .06443 L
.25962 .06443 L
.2608 .0644 L
.26187 .06436 L
.26302 .06429 L
.26426 .06418 L
.26539 .06406 L
.26793 .06372 L
.27251 .0629 L
.28294 .06074 L
.28811 .05979 L
.29375 .05892 L
.29903 .05825 L
.304 .05773 L
.31338 .05698 L
.31837 .05668 L
.32375 .05641 L
.32908 .05621 L
.3347 .05605 L
.33949 .05595 L
.34475 .05587 L
.34727 .05584 L
.35002 .05581 L
.355 .05577 L
.35985 .05574 L
.36433 .05572 L
.38527 .05564 L
Mistroke
.40561 .05554 L
.41555 .05549 L
.42464 .05546 L
.42912 .05544 L
.434 .05543 L
.43866 .05542 L
.44289 .05541 L
.44781 .05541 L
.45051 .0554 L
.45175 .0554 L
.45306 .0554 L
.45419 .0554 L
.45542 .0554 L
.45655 .0554 L
.4576 .0554 L
.45883 .0554 L
.45996 .0554 L
.46127 .0554 L
.4625 .0554 L
.46364 .0554 L
.46487 .0554 L
.46603 .0554 L
.46709 .0554 L
.47216 .0554 L
.47716 .0554 L
.48242 .05541 L
.50085 .05542 L
.53898 .05544 L
.57956 .05548 L
.61862 .05552 L
.66014 .05555 L
.70014 .05559 L
.73863 .05562 L
.77957 .05565 L
.81899 .05568 L
.8569 .0557 L
.89726 .05573 L
.9361 .05575 L
.97619 .05577 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03059 L
.03068 .03495 L
.03279 .03791 L
.03527 .0404 L
.03652 .04136 L
.0379 .04224 L
.04033 .04346 L
.04262 .04433 L
.04761 .04567 L
.05217 .04656 L
.06244 .04821 L
.08259 .05173 L
.09399 .05431 L
.10458 .05733 L
.11466 .06101 L
.1238 .06541 L
.12887 .06848 L
.13435 .07251 L
.14429 .08268 L
.16384 .12299 L
.16659 .13019 L
.16919 .13596 L
.17063 .13838 L
.17144 .13944 L
.17219 .1402 L
.17283 .14067 L
.17352 .141 L
.17425 .14114 L
.17493 .14107 L
.1762 .14045 L
.17684 .1399 L
.17753 .13914 L
.17877 .13739 L
.17992 .13535 L
.18529 .12244 L
.19511 .0968 L
.19994 .08687 L
.20438 .07973 L
.20951 .07365 L
.21221 .07124 L
.21507 .06918 L
.2173 .06789 L
.21969 .06676 L
.22232 .0658 L
.22478 .06512 L
.22733 .0646 L
Mistroke
.22875 .06439 L
.23004 .06424 L
.23124 .06414 L
.23255 .06405 L
.23378 .064 L
.23491 .06398 L
.23555 .06398 L
.23624 .06399 L
.23747 .06401 L
.23823 .06404 L
.23894 .06407 L
.24028 .06414 L
.243 .06434 L
.24595 .06462 L
.25102 .06515 L
.25236 .06528 L
.2538 .06541 L
.25507 .0655 L
.25576 .06554 L
.2564 .06557 L
.25755 .06562 L
.2588 .06564 L
.25986 .06563 L
.26099 .06561 L
.26165 .06558 L
.26236 .06554 L
.26365 .06545 L
.2649 .06534 L
.26606 .06521 L
.2759 .06351 L
.28645 .06156 L
.29642 .06023 L
.30551 .05938 L
.31484 .05871 L
.31976 .05843 L
.32499 .05817 L
.32954 .05799 L
.33457 .05782 L
.33881 .0577 L
.34345 .0576 L
.34836 .05752 L
.35353 .05746 L
.35832 .05742 L
.36277 .05739 L
.36805 .05736 L
.37285 .05735 L
.38362 .05731 L
.40278 .05723 L
.42357 .05711 L
.44303 .05699 L
Mistroke
.45336 .05694 L
.46446 .0569 L
.47508 .05687 L
.48479 .05685 L
.50383 .05681 L
.52283 .05679 L
.5337 .05678 L
.54356 .05677 L
.5537 .05677 L
.55834 .05676 L
.56324 .05676 L
.5685 .05676 L
.57332 .05676 L
.57601 .05676 L
.57852 .05676 L
.57996 .05676 L
.58127 .05676 L
.582 .05676 L
.58279 .05676 L
.58349 .05676 L
.58422 .05676 L
.58544 .05676 L
.58656 .05676 L
.58776 .05676 L
.58908 .05676 L
.59022 .05676 L
.59144 .05676 L
.59363 .05676 L
.59643 .05676 L
.59907 .05676 L
.60401 .05676 L
.6141 .05676 L
.62502 .05677 L
.64492 .05677 L
.66596 .05678 L
.70387 .05681 L
.74423 .05684 L
.78307 .05687 L
.82437 .0569 L
.86415 .05693 L
.90242 .05696 L
.94313 .05699 L
.97619 .05702 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04396 L
.04761 .04524 L
.05217 .04608 L
.06244 .04766 L
.08259 .05104 L
.09399 .05351 L
.10458 .05639 L
.11466 .05989 L
.1238 .06403 L
.12887 .0669 L
.13435 .07066 L
.13949 .075 L
.14429 .08001 L
.15379 .09383 L
.15925 .10456 L
.16423 .11514 L
.16673 .1198 L
.16805 .12181 L
.16877 .12273 L
.16945 .12347 L
.17067 .12445 L
.17132 .12477 L
.17202 .12497 L
.17326 .12491 L
.17439 .1244 L
.17571 .12331 L
.17693 .12186 L
.1797 .11731 L
.18529 .10547 L
.19034 .09471 L
.19581 .08483 L
.20098 .07761 L
.20575 .07262 L
.21005 .06927 L
.21478 .06663 L
.21716 .06564 L
.21972 .06479 L
.22213 .06417 L
.22434 .06374 L
Mistroke
.22563 .06354 L
.22685 .06338 L
.22795 .06327 L
.22912 .06317 L
.23039 .0631 L
.23156 .06305 L
.23283 .06303 L
.23354 .06303 L
.23421 .06303 L
.2354 .06305 L
.23652 .06309 L
.23753 .06314 L
.23863 .0632 L
.24109 .06338 L
.24336 .0636 L
.24855 .06418 L
.25342 .06471 L
.25587 .06491 L
.25654 .06495 L
.25724 .06499 L
.2585 .06504 L
.25917 .06505 L
.25989 .06506 L
.26118 .06505 L
.26196 .06503 L
.26271 .06499 L
.26337 .06496 L
.2641 .06491 L
.26646 .06467 L
.269 .06433 L
.27359 .0635 L
.28401 .06137 L
.28966 .06043 L
.29245 .06006 L
.29502 .05977 L
.29983 .05936 L
.30237 .0592 L
.30507 .05907 L
.30744 .05898 L
.30995 .05891 L
.31208 .05887 L
.31442 .05883 L
.31575 .05882 L
.31695 .05881 L
.31834 .0588 L
.31965 .05879 L
.32086 .05879 L
.32198 .05878 L
.32321 .05878 L
.32452 .05878 L
Mistroke
.32565 .05879 L
.32668 .05879 L
.32787 .05879 L
.32901 .0588 L
.33321 .05882 L
.33779 .05886 L
.34279 .05891 L
.35312 .05905 L
.36247 .05921 L
.38345 .05964 L
.39282 .05983 L
.40271 .06 L
.40789 .06007 L
.41356 .06013 L
.41605 .06016 L
.41872 .06017 L
.42101 .06019 L
.42354 .0602 L
.42486 .0602 L
.4261 .06021 L
.42742 .06021 L
.42815 .06021 L
.42883 .06021 L
.42997 .06021 L
.43121 .06021 L
.43251 .06021 L
.43372 .06021 L
.43442 .06021 L
.43517 .06021 L
.43653 .06021 L
.43908 .0602 L
.44205 .06019 L
.44479 .06018 L
.45457 .06012 L
.46492 .06006 L
.50283 .05978 L
.54319 .05951 L
.58203 .05926 L
.62333 .05904 L
.66311 .05887 L
.70137 .05874 L
.74209 .05863 L
.78129 .05854 L
.82295 .05846 L
.86309 .05839 L
.90171 .05833 L
.94278 .05827 L
.97619 .05823 L
Mfstroke
1 0 .19 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02737 L
.02846 .03056 L
.03068 .03489 L
.03279 .03782 L
.03527 .04028 L
.03652 .04122 L
.0379 .04208 L
.04033 .04328 L
.04262 .04413 L
.04761 .04545 L
.05217 .04632 L
.06244 .04794 L
.08259 .05141 L
.09399 .05395 L
.10458 .05691 L
.11466 .06052 L
.1238 .06483 L
.12887 .06783 L
.13435 .07177 L
.14429 .0817 L
.16384 .12064 L
.16659 .1274 L
.16919 .13267 L
.17063 .1348 L
.17144 .1357 L
.17219 .13632 L
.17283 .13667 L
.17352 .13688 L
.17425 .1369 L
.17493 .13674 L
.1762 .13597 L
.17684 .13538 L
.17753 .13457 L
.17992 .13078 L
.1827 .12485 L
.18529 .11853 L
.19511 .09501 L
.19994 .08594 L
.20438 .07937 L
.20951 .0737 L
.21221 .07142 L
.21507 .06946 L
.21969 .06713 L
.22232 .06619 L
.22478 .06551 L
.22603 .06524 L
.22736 .065 L
Mistroke
.22851 .06482 L
.22976 .06467 L
.23052 .06459 L
.23123 .06453 L
.23188 .06448 L
.23261 .06444 L
.23386 .06439 L
.23455 .06438 L
.23519 .06437 L
.23647 .06437 L
.23768 .0644 L
.23877 .06444 L
.23996 .0645 L
.24261 .06469 L
.24507 .06492 L
.24971 .06544 L
.25406 .06589 L
.25625 .06606 L
.25747 .06613 L
.2586 .06617 L
.25977 .0662 L
.26104 .06621 L
.26168 .0662 L
.26237 .06618 L
.2636 .06614 L
.26484 .06607 L
.2662 .06598 L
.26895 .06573 L
.27387 .06516 L
.27924 .06453 L
.28499 .06394 L
.29541 .06317 L
.30515 .0626 L
.32494 .06146 L
.33036 .06119 L
.33613 .06095 L
.34111 .06079 L
.34372 .06071 L
.34648 .06065 L
.34891 .0606 L
.35157 .06056 L
.35401 .06053 L
.35623 .06051 L
.35853 .06049 L
.35979 .06048 L
.36098 .06048 L
.36208 .06047 L
.3631 .06047 L
.36422 .06047 L
.3654 .06047 L
Mistroke
.36669 .06047 L
.36787 .06047 L
.36853 .06047 L
.36924 .06047 L
.37053 .06048 L
.37303 .06048 L
.37534 .06049 L
.38061 .06052 L
.3863 .06055 L
.38898 .06056 L
.39044 .06056 L
.39181 .06057 L
.39307 .06057 L
.39422 .06057 L
.3955 .06057 L
.39621 .06057 L
.39687 .06057 L
.39808 .06057 L
.39935 .06057 L
.40044 .06057 L
.40164 .06057 L
.40293 .06057 L
.40432 .06056 L
.40683 .06055 L
.40909 .06054 L
.41156 .06052 L
.41654 .06048 L
.42544 .06038 L
.44671 .06009 L
.46603 .05984 L
.48613 .05964 L
.50509 .05949 L
.54358 .05926 L
.56347 .05917 L
.58452 .05909 L
.6041 .05904 L
.62242 .059 L
.63284 .05898 L
.64273 .05897 L
.66127 .05895 L
.67089 .05894 L
.68113 .05893 L
.68611 .05893 L
.69079 .05893 L
.69531 .05893 L
.69953 .05893 L
.70421 .05893 L
.70668 .05893 L
.70933 .05893 L
.71066 .05893 L
Mistroke
.71137 .05893 L
.71211 .05893 L
.71276 .05893 L
.71348 .05893 L
.71474 .05893 L
.71597 .05893 L
.71728 .05893 L
.71853 .05893 L
.71967 .05893 L
.7208 .05893 L
.72201 .05893 L
.7242 .05893 L
.72914 .05893 L
.73387 .05893 L
.73815 .05893 L
.74817 .05893 L
.75739 .05894 L
.77821 .05894 L
.81768 .05897 L
.85564 .05899 L
.89606 .05902 L
.93495 .05904 L
.97619 .05907 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04016 L
.03652 .04107 L
.0379 .04192 L
.04033 .04307 L
.04262 .04389 L
.04761 .04514 L
.05217 .04597 L
.06244 .04751 L
.08259 .05084 L
.09399 .05327 L
.10458 .05609 L
.11466 .0595 L
.1238 .06353 L
.12887 .06631 L
.13435 .06992 L
.13949 .07407 L
.14429 .07882 L
.15379 .09165 L
.15925 .10132 L
.16423 .11052 L
.16673 .11441 L
.16814 .11613 L
.16945 .1173 L
.17059 .11794 L
.17185 .11822 L
.17316 .11799 L
.17439 .11731 L
.17503 .1168 L
.17573 .11611 L
.17713 .11437 L
.17964 .11032 L
.18529 .09907 L
.19013 .08958 L
.19538 .08092 L
.20033 .07457 L
.2049 .07017 L
.21023 .06648 L
.21292 .06511 L
.21588 .06392 L
.21836 .06314 L
.22103 .0625 L
.22232 .06226 L
.22355 .06206 L
Mistroke
.22585 .06177 L
.2271 .06166 L
.22776 .06161 L
.22845 .06157 L
.22973 .06152 L
.2309 .06149 L
.23202 .06148 L
.23308 .06148 L
.23423 .06151 L
.23546 .06155 L
.23678 .06161 L
.23822 .0617 L
.24082 .0619 L
.2457 .0624 L
.25034 .06292 L
.25288 .06318 L
.25412 .06329 L
.25526 .06337 L
.25623 .06343 L
.25729 .06348 L
.25835 .06351 L
.25946 .06353 L
.26063 .06351 L
.26187 .06347 L
.26304 .06341 L
.2641 .06333 L
.26642 .06307 L
.26896 .06269 L
.27411 .06167 L
.28332 .05957 L
.28851 .05853 L
.29408 .05764 L
.29678 .05731 L
.29934 .05704 L
.30181 .05682 L
.30413 .05665 L
.30871 .0564 L
.31114 .0563 L
.31377 .05622 L
.31637 .05616 L
.31911 .05611 L
.32145 .05608 L
.32278 .05606 L
.32402 .05605 L
.32517 .05605 L
.32641 .05604 L
.32759 .05603 L
.32868 .05603 L
.32966 .05603 L
.33073 .05603 L
Mistroke
.33186 .05603 L
.33292 .05603 L
.33414 .05603 L
.33531 .05603 L
.33636 .05603 L
.3375 .05604 L
.34243 .05606 L
.36212 .05616 L
.38309 .05628 L
.39339 .05633 L
.3988 .05636 L
.40452 .05638 L
.40953 .05639 L
.41238 .0564 L
.41503 .05641 L
.41629 .05641 L
.41747 .05641 L
.41855 .05641 L
.4197 .05641 L
.42094 .05641 L
.42209 .05641 L
.42333 .05641 L
.42404 .05641 L
.4247 .05641 L
.42587 .05641 L
.42713 .05641 L
.42832 .05641 L
.4294 .05641 L
.43204 .05641 L
.43454 .0564 L
.43951 .05639 L
.44489 .05638 L
.4634 .0563 L
.50434 .05612 L
.54377 .05597 L
.58167 .05585 L
.62203 .05575 L
.66088 .05567 L
.70217 .05562 L
.74195 .05558 L
.78022 .05556 L
.82094 .05554 L
.86014 .05552 L
.90179 .05551 L
.94193 .0555 L
.97619 .05549 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02738 L
.02846 .03058 L
.03068 .03493 L
.03279 .03787 L
.03527 .04033 L
.03652 .04128 L
.0379 .04215 L
.04033 .04335 L
.04262 .0442 L
.04761 .04551 L
.05217 .04638 L
.06244 .04799 L
.08259 .05143 L
.09399 .05396 L
.10458 .0569 L
.11466 .06048 L
.1238 .06473 L
.12887 .06768 L
.13435 .07154 L
.14429 .08119 L
.16384 .11777 L
.16659 .12397 L
.16919 .12881 L
.17063 .13076 L
.17144 .13159 L
.17219 .13216 L
.17283 .13248 L
.17352 .13267 L
.17425 .13268 L
.17493 .13252 L
.1762 .13178 L
.17684 .13121 L
.17753 .13043 L
.17992 .12677 L
.1827 .12099 L
.18529 .11479 L
.19 .10311 L
.19511 .09162 L
.19962 .08328 L
.20438 .0764 L
.20703 .07339 L
.20994 .07065 L
.21241 .06875 L
.21507 .06708 L
.21769 .06578 L
.22009 .06483 L
.22249 .06409 L
Mistroke
.22478 .06356 L
.22603 .06333 L
.22738 .06313 L
.22857 .06298 L
.22982 .06286 L
.23096 .06278 L
.2322 .06272 L
.23334 .06269 L
.23439 .06268 L
.23503 .06268 L
.23572 .06269 L
.23698 .06272 L
.2382 .06276 L
.23933 .06282 L
.2419 .063 L
.24462 .06325 L
.24884 .06368 L
.25105 .0639 L
.25338 .06411 L
.25462 .06419 L
.25528 .06423 L
.25598 .06427 L
.25721 .06432 L
.25836 .06434 L
.25962 .06433 L
.2608 .0643 L
.26187 .06425 L
.26302 .06417 L
.26426 .06405 L
.26539 .06392 L
.26793 .06355 L
.27251 .06266 L
.28294 .06029 L
.28811 .05926 L
.29375 .05835 L
.29907 .05767 L
.304 .05719 L
.30862 .05682 L
.31361 .05652 L
.31792 .05631 L
.32264 .05612 L
.32787 .05597 L
.33053 .05591 L
.33338 .05585 L
.33605 .05581 L
.33848 .05578 L
.34323 .05573 L
.34553 .05572 L
.34807 .0557 L
.35072 .05569 L
Mistroke
.35319 .05568 L
.35763 .05567 L
.36011 .05567 L
.36239 .05566 L
.36761 .05566 L
.37317 .05565 L
.37842 .05564 L
.38318 .05563 L
.40218 .05556 L
.41298 .05552 L
.42291 .05549 L
.43228 .05546 L
.43699 .05545 L
.44217 .05545 L
.44737 .05544 L
.45028 .05544 L
.45294 .05543 L
.45542 .05543 L
.45811 .05543 L
.46065 .05543 L
.46299 .05543 L
.46417 .05543 L
.46541 .05543 L
.46647 .05543 L
.46763 .05543 L
.46889 .05543 L
.46959 .05543 L
.47022 .05543 L
.47146 .05543 L
.47263 .05543 L
.47373 .05543 L
.47489 .05543 L
.47697 .05543 L
.48167 .05543 L
.50228 .05543 L
.52209 .05544 L
.54019 .05544 L
.55017 .05545 L
.55965 .05545 L
.58055 .05547 L
.61881 .05549 L
.65953 .05552 L
.69873 .05555 L
.74039 .05558 L
.78052 .0556 L
.81915 .05563 L
.86022 .05566 L
.89978 .05568 L
.93783 .0557 L
.97619 .05572 L
Mistroke
Mfstroke
1 0 .119 r
.02381 .01472 m
.02499 .01988 L
.02605 .02382 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03778 L
.03527 .0402 L
.03652 .04113 L
.0379 .04198 L
.04033 .04316 L
.04262 .04399 L
.04761 .04526 L
.05217 .04611 L
.06244 .04768 L
.08259 .05107 L
.09399 .05354 L
.10458 .05641 L
.11466 .05991 L
.1238 .06404 L
.12887 .06691 L
.13435 .07065 L
.13949 .07497 L
.14429 .07994 L
.15379 .0936 L
.15925 .10416 L
.16423 .11456 L
.16673 .11918 L
.16805 .12119 L
.16877 .12212 L
.16945 .12286 L
.17067 .12387 L
.17132 .12422 L
.17202 .12445 L
.17326 .12445 L
.17439 .12401 L
.17571 .12299 L
.17693 .12161 L
.1797 .1172 L
.18529 .10544 L
.19034 .0946 L
.19581 .08458 L
.20098 .07722 L
.20575 .07213 L
.21005 .06873 L
.21478 .06605 L
.21716 .06505 L
.21972 .0642 L
.22213 .06357 L
.22434 .06314 L
Mistroke
.22563 .06294 L
.22685 .06279 L
.22795 .06267 L
.22912 .06258 L
.23039 .0625 L
.23156 .06246 L
.23283 .06243 L
.23354 .06243 L
.23421 .06243 L
.2354 .06246 L
.23652 .06249 L
.23753 .06254 L
.23863 .0626 L
.24109 .06278 L
.24336 .06298 L
.24855 .06354 L
.25342 .06403 L
.25461 .06413 L
.25587 .06421 L
.25652 .06424 L
.25724 .06427 L
.2585 .0643 L
.25924 .06431 L
.2599 .06431 L
.26067 .06429 L
.2614 .06427 L
.2627 .0642 L
.26343 .06415 L
.2641 .0641 L
.26655 .06383 L
.26879 .0635 L
.27382 .06257 L
.2829 .06071 L
.28797 .05983 L
.2935 .05908 L
.29872 .05856 L
.30355 .05821 L
.30818 .05797 L
.31316 .05778 L
.31787 .05764 L
.32219 .05755 L
.32698 .05747 L
.33222 .0574 L
.33487 .05738 L
.33769 .05736 L
.34036 .05734 L
.34279 .05733 L
.34509 .05732 L
.3464 .05732 L
.34763 .05732 L
Mistroke
.34892 .05732 L
.3501 .05732 L
.35075 .05732 L
.35146 .05732 L
.35275 .05732 L
.35396 .05732 L
.35506 .05732 L
.35633 .05732 L
.35752 .05732 L
.36195 .05733 L
.36715 .05735 L
.37194 .05737 L
.38274 .05743 L
.39183 .05747 L
.39693 .05749 L
.39934 .0575 L
.40158 .05751 L
.40421 .05751 L
.40559 .05751 L
.4063 .05752 L
.40707 .05752 L
.40834 .05752 L
.40954 .05752 L
.41023 .05752 L
.41096 .05752 L
.41227 .05752 L
.41346 .05752 L
.41474 .05752 L
.41594 .05751 L
.41703 .05751 L
.41971 .05751 L
.42224 .0575 L
.42688 .05748 L
.43198 .05746 L
.44227 .0574 L
.46073 .05728 L
.50109 .05704 L
.53993 .05687 L
.5597 .05679 L
.58123 .05672 L
.62101 .05663 L
.64074 .05659 L
.66173 .05656 L
.6832 .05654 L
.70338 .05652 L
.72352 .05651 L
.74201 .0565 L
.76088 .05649 L
.77159 .05649 L
.78157 .05649 L
Mistroke
.79206 .05649 L
.79721 .05649 L
.80197 .05649 L
.81088 .05649 L
.81557 .05648 L
.81812 .05648 L
.82055 .05648 L
.82289 .05648 L
.82546 .05648 L
.82659 .05648 L
.82779 .05648 L
.82891 .05648 L
.82995 .05648 L
.83126 .05648 L
.83195 .05648 L
.83268 .05648 L
.83391 .05648 L
.83461 .05648 L
.83526 .05648 L
.83647 .05648 L
.83758 .05648 L
.83886 .05648 L
.84007 .05648 L
.84228 .05648 L
.84462 .05648 L
.84883 .05648 L
.85337 .05648 L
.85837 .05648 L
.87771 .05649 L
.89856 .05649 L
.93969 .05649 L
.97619 .0565 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03485 L
.03279 .03775 L
.03527 .04016 L
.03652 .04107 L
.0379 .04191 L
.04033 .04307 L
.04262 .04388 L
.04517 .04459 L
.04761 .04513 L
.05217 .04596 L
.06244 .04749 L
.07302 .0491 L
.08429 .0511 L
.09474 .05336 L
.10458 .05596 L
.1142 .05916 L
.12461 .06369 L
.13407 .06933 L
.14277 .07658 L
.15263 .08863 L
.15805 .0975 L
.16319 .10682 L
.16551 .1108 L
.16797 .11439 L
.16925 .11584 L
.16994 .11647 L
.17067 .11702 L
.17196 .11765 L
.17317 .11783 L
.17427 .11763 L
.17548 .11702 L
.17674 .11598 L
.17791 .11467 L
.18001 .11163 L
.18226 .10764 L
.19249 .08736 L
.19752 .07913 L
.20215 .07317 L
.20637 .06903 L
.21083 .06579 L
.21314 .0645 L
.21531 .0635 L
.21769 .06261 L
.22023 .06186 L
.22282 .0613 L
Mistroke
.22521 .06092 L
.22668 .06075 L
.22806 .06063 L
.2293 .06055 L
.23 .06051 L
.23064 .06049 L
.23183 .06046 L
.23293 .06046 L
.23415 .06047 L
.23545 .0605 L
.2361 .06052 L
.23681 .06055 L
.2381 .06062 L
.24052 .06078 L
.24513 .06119 L
.25009 .06168 L
.25237 .06188 L
.25361 .06197 L
.25477 .06205 L
.25576 .06209 L
.25682 .06213 L
.25799 .06215 L
.25906 .06215 L
.26027 .06212 L
.26139 .06207 L
.26261 .06198 L
.26391 .06186 L
.26609 .06158 L
.26848 .06118 L
.27887 .05875 L
.28451 .05738 L
.28986 .05625 L
.29507 .05537 L
.29989 .05474 L
.30441 .05429 L
.30922 .05394 L
.31405 .05369 L
.31679 .05358 L
.31938 .05351 L
.32193 .05344 L
.32462 .0534 L
.32692 .05337 L
.32822 .05336 L
.32943 .05335 L
.33011 .05334 L
.33084 .05334 L
.33149 .05334 L
.33218 .05333 L
.33348 .05333 L
.33468 .05333 L
Mistroke
.33534 .05333 L
.33605 .05333 L
.33734 .05333 L
.33813 .05333 L
.33888 .05334 L
.34028 .05334 L
.35061 .05341 L
.36033 .05348 L
.36457 .05351 L
.36906 .05353 L
.3714 .05354 L
.37397 .05355 L
.3751 .05355 L
.37631 .05355 L
.37737 .05355 L
.3785 .05355 L
.37981 .05355 L
.38103 .05356 L
.38234 .05356 L
.38309 .05356 L
.38379 .05356 L
.38504 .05355 L
.3862 .05355 L
.38746 .05355 L
.3888 .05355 L
.39328 .05354 L
.39818 .05354 L
.40344 .05353 L
.40633 .05352 L
.40905 .05352 L
.4116 .05351 L
.41293 .05351 L
.41435 .05351 L
.41554 .05351 L
.41685 .05351 L
.41805 .05351 L
.41916 .05351 L
.42041 .05351 L
.42111 .05351 L
.42175 .05351 L
.42298 .05351 L
.42415 .05351 L
.42551 .05351 L
.42676 .05351 L
.42958 .05352 L
.43439 .05353 L
.43946 .05354 L
.458 .0536 L
.49605 .05374 L
.51561 .0538 L
Mistroke
.53654 .05384 L
.57798 .05392 L
.6179 .05399 L
.6563 .05403 L
.69715 .05407 L
.73649 .05409 L
.77431 .05412 L
.81459 .05413 L
.85335 .05415 L
.89456 .05417 L
.93426 .05418 L
.97244 .0542 L
.97619 .0542 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04111 L
.0379 .04196 L
.04033 .04313 L
.04262 .04395 L
.04761 .04522 L
.05217 .04605 L
.06244 .0476 L
.08259 .05093 L
.09399 .05337 L
.10458 .05619 L
.11466 .05961 L
.1238 .06364 L
.12887 .06642 L
.13435 .07003 L
.14429 .07889 L
.15372 .09159 L
.16384 .11042 L
.16682 .11573 L
.16828 .1179 L
.16964 .11953 L
.17087 .12061 L
.17217 .12132 L
.17349 .12152 L
.17423 .12141 L
.17493 .12115 L
.1762 .12032 L
.17684 .11973 L
.17753 .11897 L
.17992 .11555 L
.18529 .10493 L
.19518 .08492 L
.20072 .0765 L
.20575 .07084 L
.21044 .06704 L
.21309 .06542 L
.21554 .06422 L
.21786 .0633 L
.22003 .0626 L
.22229 .06204 L
.22478 .06158 L
.22603 .0614 L
.22736 .06125 L
Mistroke
.22862 .06114 L
.22976 .06107 L
.23046 .06103 L
.2311 .06101 L
.23181 .06099 L
.23256 .06098 L
.23381 .06097 L
.23452 .06098 L
.23519 .06099 L
.23647 .06103 L
.23768 .06109 L
.23996 .06123 L
.24507 .06167 L
.24938 .06211 L
.25174 .06233 L
.25395 .0625 L
.2551 .06257 L
.25634 .06263 L
.25701 .06265 L
.25771 .06267 L
.25897 .06267 L
.26012 .06265 L
.26118 .06261 L
.26235 .06254 L
.2636 .06243 L
.26484 .0623 L
.2662 .06211 L
.26895 .06165 L
.27387 .06057 L
.28499 .05787 L
.29002 .05683 L
.29541 .05593 L
.30051 .05528 L
.30515 .05483 L
.30995 .05448 L
.31258 .05433 L
.31505 .05422 L
.3194 .05406 L
.32172 .05399 L
.32421 .05394 L
.32673 .05389 L
.32948 .05386 L
.33087 .05385 L
.33236 .05384 L
.33376 .05383 L
.33504 .05382 L
.33631 .05382 L
.33749 .05382 L
.33878 .05382 L
.33943 .05382 L
Mistroke
.34014 .05382 L
.34134 .05382 L
.34263 .05382 L
.34385 .05382 L
.34497 .05383 L
.35494 .05387 L
.36042 .0539 L
.3631 .05391 L
.36557 .05392 L
.36787 .05393 L
.37039 .05393 L
.3717 .05393 L
.37293 .05394 L
.37422 .05394 L
.37494 .05394 L
.3756 .05394 L
.37677 .05394 L
.37784 .05394 L
.37902 .05394 L
.38027 .05394 L
.38136 .05394 L
.38238 .05394 L
.38469 .05393 L
.38693 .05393 L
.38937 .05393 L
.39429 .05391 L
.40309 .05389 L
.40806 .05388 L
.41078 .05387 L
.41336 .05387 L
.41576 .05387 L
.41702 .05387 L
.41836 .05386 L
.41949 .05386 L
.42073 .05386 L
.42185 .05386 L
.42291 .05386 L
.42416 .05386 L
.42486 .05386 L
.4255 .05386 L
.42673 .05386 L
.42789 .05386 L
.42925 .05386 L
.43051 .05387 L
.43333 .05387 L
.43562 .05387 L
.43814 .05388 L
.44321 .05389 L
.46175 .05394 L
.48295 .054 L
Mistroke
.50225 .05405 L
.54123 .05413 L
.58115 .05419 L
.61955 .05425 L
.6604 .05429 L
.69974 .05432 L
.73756 .05435 L
.77784 .05437 L
.8166 .05439 L
.85781 .05441 L
.89751 .05443 L
.93569 .05445 L
.97619 .05446 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03054 L
.03068 .03486 L
.03279 .03776 L
.03527 .04017 L
.03652 .0411 L
.0379 .04195 L
.04033 .04312 L
.04262 .04394 L
.04761 .04522 L
.05217 .04606 L
.06244 .04763 L
.08259 .051 L
.09399 .05346 L
.10458 .05632 L
.11466 .05979 L
.1238 .0639 L
.12887 .06674 L
.13435 .07046 L
.14429 .07967 L
.15372 .09313 L
.15901 .10335 L
.16384 .11374 L
.16656 .11924 L
.168 .12173 L
.16953 .12391 L
.17087 .1253 L
.17163 .12586 L
.17234 .12622 L
.17359 .12645 L
.17429 .12635 L
.17493 .12612 L
.17618 .1253 L
.17734 .12412 L
.17862 .12242 L
.17998 .1202 L
.18529 .10909 L
.1904 .09755 L
.19593 .08651 L
.20116 .07828 L
.20598 .07258 L
.21033 .06878 L
.21511 .06582 L
.21752 .06472 L
.22011 .06379 L
.22255 .06311 L
.22478 .06264 L
Mistroke
.22607 .06243 L
.22729 .06226 L
.22839 .06214 L
.22956 .06204 L
.23084 .06196 L
.23201 .06191 L
.23327 .06188 L
.23398 .06187 L
.23465 .06187 L
.23584 .06189 L
.23696 .06192 L
.23797 .06196 L
.23907 .06202 L
.24153 .06219 L
.2438 .06238 L
.249 .0629 L
.25154 .06315 L
.25386 .06335 L
.25506 .06343 L
.25631 .06349 L
.25757 .06353 L
.25828 .06354 L
.25894 .06355 L
.25967 .06354 L
.26036 .06353 L
.26165 .06347 L
.26237 .06343 L
.26304 .06338 L
.26454 .06324 L
.26699 .06293 L
.26923 .06256 L
.27426 .06153 L
.28334 .05949 L
.28842 .05851 L
.29394 .05765 L
.29916 .05703 L
.304 .0566 L
.30862 .05628 L
.31361 .05603 L
.31832 .05584 L
.32264 .05572 L
.32742 .05561 L
.33014 .05557 L
.33266 .05553 L
.33529 .0555 L
.33777 .05548 L
.34063 .05546 L
.34323 .05545 L
.34562 .05544 L
.34785 .05543 L
Mistroke
.34913 .05543 L
.3503 .05543 L
.35165 .05542 L
.35293 .05542 L
.35417 .05542 L
.35549 .05542 L
.35673 .05542 L
.35785 .05542 L
.35854 .05542 L
.35918 .05542 L
.36062 .05542 L
.36322 .05542 L
.36546 .05542 L
.36786 .05542 L
.36902 .05543 L
.37013 .05543 L
.37111 .05543 L
.37219 .05543 L
.37333 .05543 L
.37454 .05543 L
.37557 .05543 L
.37671 .05543 L
.37794 .05543 L
.37926 .05542 L
.38166 .05542 L
.38406 .05542 L
.38663 .05542 L
.39124 .05541 L
.39673 .0554 L
.40172 .05539 L
.42282 .05533 L
.44364 .05527 L
.45278 .05525 L
.46283 .05523 L
.48152 .05521 L
.50131 .05519 L
.52241 .05517 L
.54167 .05515 L
.55121 .05515 L
.55624 .05515 L
.5616 .05515 L
.56676 .05514 L
.57142 .05514 L
.57611 .05514 L
.58052 .05514 L
.58277 .05514 L
.58519 .05514 L
.58658 .05514 L
.58784 .05514 L
.58904 .05514 L
Mistroke
.59031 .05514 L
.59164 .05514 L
.59286 .05514 L
.59418 .05514 L
.59492 .05514 L
.59563 .05514 L
.59689 .05514 L
.59805 .05514 L
.59868 .05514 L
.59938 .05514 L
.60065 .05514 L
.60308 .05514 L
.60529 .05514 L
.61023 .05514 L
.61482 .05514 L
.61914 .05514 L
.6289 .05514 L
.63921 .05515 L
.65768 .05515 L
.69564 .05516 L
.73605 .05518 L
.77494 .0552 L
.81629 .05522 L
.85613 .05525 L
.89444 .05527 L
.93521 .05529 L
.97447 .05531 L
.97619 .05531 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03487 L
.03279 .03777 L
.03527 .0402 L
.03652 .04113 L
.0379 .04198 L
.04033 .04315 L
.04262 .04398 L
.04761 .04525 L
.05217 .04609 L
.06244 .04766 L
.08259 .05101 L
.09399 .05346 L
.10458 .05631 L
.11466 .05976 L
.1238 .06384 L
.12887 .06665 L
.13435 .07032 L
.14429 .07936 L
.15372 .09241 L
.16384 .11204 L
.16682 .11764 L
.16828 .11995 L
.16964 .1217 L
.17087 .12288 L
.17217 .12366 L
.17349 .12391 L
.17423 .12382 L
.17493 .12357 L
.1762 .12274 L
.17684 .12215 L
.17753 .12138 L
.17992 .11787 L
.18529 .10691 L
.19518 .08615 L
.20072 .07741 L
.20575 .07153 L
.21044 .06757 L
.21309 .06589 L
.21554 .06464 L
.21786 .06368 L
.22003 .06295 L
.22229 .06236 L
.22478 .06188 L
.22603 .06169 L
.22736 .06153 L
Mistroke
.22862 .06141 L
.22976 .06133 L
.23046 .0613 L
.2311 .06127 L
.23181 .06125 L
.23256 .06123 L
.23381 .06123 L
.23452 .06123 L
.23519 .06124 L
.23647 .06128 L
.23768 .06133 L
.23996 .06147 L
.24241 .06166 L
.24507 .06191 L
.24974 .06239 L
.2523 .06263 L
.25355 .06273 L
.2547 .06281 L
.25568 .06286 L
.25674 .06291 L
.25781 .06293 L
.25894 .06294 L
.26011 .06292 L
.26136 .06287 L
.26253 .0628 L
.2636 .06271 L
.26592 .06243 L
.26847 .06201 L
.27361 .0609 L
.28283 .0586 L
.28802 .05743 L
.29359 .05641 L
.29884 .05567 L
.30364 .05516 L
.30843 .05478 L
.31353 .05449 L
.31789 .05432 L
.32037 .05424 L
.3227 .05418 L
.32523 .05414 L
.3279 .0541 L
.33018 .05407 L
.33148 .05406 L
.33268 .05405 L
.33408 .05405 L
.33477 .05404 L
.33541 .05404 L
.3366 .05404 L
.33789 .05404 L
.33917 .05404 L
Mistroke
.3399 .05404 L
.34059 .05404 L
.34131 .05404 L
.34197 .05404 L
.34345 .05404 L
.35343 .05408 L
.3589 .0541 L
.36159 .05411 L
.36406 .05412 L
.36636 .05413 L
.36888 .05413 L
.37019 .05413 L
.37141 .05414 L
.3727 .05414 L
.37343 .05414 L
.37409 .05414 L
.37525 .05414 L
.37633 .05414 L
.37751 .05414 L
.37876 .05414 L
.37984 .05414 L
.38086 .05414 L
.38318 .05413 L
.38541 .05413 L
.38786 .05412 L
.39278 .05411 L
.40157 .05409 L
.40654 .05408 L
.41184 .05406 L
.41442 .05406 L
.41685 .05406 L
.41903 .05405 L
.42026 .05405 L
.42139 .05405 L
.42252 .05405 L
.42375 .05405 L
.42505 .05405 L
.42629 .05405 L
.42744 .05405 L
.42866 .05405 L
.42982 .05405 L
.43087 .05405 L
.43221 .05405 L
.43345 .05405 L
.43623 .05405 L
.43869 .05406 L
.44128 .05406 L
.45133 .05408 L
.46233 .0541 L
.48353 .05415 L
Mistroke
.50283 .05419 L
.54181 .05425 L
.58173 .0543 L
.62013 .05434 L
.66098 .05438 L
.70032 .05441 L
.73814 .05444 L
.77842 .05446 L
.81718 .05448 L
.85839 .0545 L
.89809 .05452 L
.93627 .05454 L
.97619 .05455 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .01988 L
.02605 .02381 L
.02721 .02736 L
.02846 .03055 L
.03068 .03486 L
.03279 .03777 L
.03527 .04019 L
.03652 .04112 L
.0379 .04197 L
.04033 .04314 L
.04262 .04397 L
.04761 .04525 L
.05217 .04609 L
.06244 .04766 L
.08259 .05103 L
.09399 .05349 L
.10458 .05634 L
.11466 .05981 L
.1238 .06391 L
.12887 .06675 L
.13435 .07045 L
.14429 .07961 L
.15372 .09291 L
.16384 .11314 L
.16682 .11897 L
.16828 .12138 L
.16964 .1232 L
.17087 .12444 L
.17217 .12527 L
.17349 .12556 L
.17423 .12548 L
.17493 .12524 L
.1762 .12441 L
.17684 .12381 L
.17753 .12303 L
.17992 .11947 L
.18529 .10831 L
.19518 .08715 L
.20072 .07821 L
.20575 .07218 L
.21044 .06812 L
.21309 .06639 L
.21554 .06509 L
.21786 .0641 L
.22003 .06335 L
.22229 .06273 L
.22478 .06223 L
.22603 .06203 L
.22736 .06186 L
Mistroke
.22862 .06173 L
.22976 .06165 L
.23041 .06161 L
.2311 .06157 L
.23186 .06155 L
.23256 .06153 L
.23381 .06152 L
.23452 .06152 L
.23519 .06153 L
.23647 .06156 L
.23768 .06161 L
.23877 .06167 L
.23996 .06174 L
.24507 .06218 L
.24974 .06266 L
.2523 .0629 L
.25355 .063 L
.2547 .06308 L
.25568 .06313 L
.25674 .06318 L
.25781 .06321 L
.25894 .06321 L
.26011 .0632 L
.26136 .06315 L
.26253 .06308 L
.2636 .06299 L
.26592 .06272 L
.26847 .06231 L
.27361 .06122 L
.28283 .05898 L
.28802 .05786 L
.29359 .05687 L
.29884 .05616 L
.30364 .05568 L
.30843 .05532 L
.31353 .05504 L
.31789 .05487 L
.3227 .05474 L
.32538 .05468 L
.32785 .05464 L
.33055 .05461 L
.33193 .0546 L
.3334 .05459 L
.3347 .05458 L
.33588 .05457 L
.33709 .05457 L
.3382 .05456 L
.33949 .05456 L
.34017 .05456 L
.3409 .05456 L
Mistroke
.34211 .05456 L
.3428 .05456 L
.34345 .05456 L
.3447 .05456 L
.3454 .05456 L
.34603 .05456 L
.34726 .05456 L
.34842 .05456 L
.35384 .05457 L
.35898 .05459 L
.36124 .05459 L
.36371 .0546 L
.3658 .0546 L
.36804 .0546 L
.36928 .0546 L
.37041 .0546 L
.37154 .05461 L
.37262 .05461 L
.37378 .05461 L
.37501 .05461 L
.37607 .05461 L
.37723 .0546 L
.37847 .0546 L
.37981 .0546 L
.38224 .0546 L
.38721 .05459 L
.39182 .05458 L
.4023 .05455 L
.41316 .05453 L
.41849 .05452 L
.4234 .05451 L
.42818 .0545 L
.43058 .0545 L
.43323 .0545 L
.43588 .0545 L
.43737 .0545 L
.43808 .0545 L
.43873 .0545 L
.43999 .0545 L
.44066 .0545 L
.44137 .0545 L
.44268 .0545 L
.44387 .0545 L
.44504 .0545 L
.44628 .0545 L
.44733 .0545 L
.44848 .0545 L
.45106 .0545 L
.45346 .0545 L
.46247 .0545 L
Mistroke
.50145 .05454 L
.54288 .05456 L
.5828 .05459 L
.6212 .05461 L
.66205 .05464 L
.70139 .05466 L
.73922 .05469 L
.77949 .05471 L
.81825 .05473 L
.85946 .05475 L
.89916 .05477 L
.93734 .05479 L
.97619 .05481 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 370.812},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001LR000`400?l00000o`00003ooooooooo
oooooe[ooooo001looooo`?o00001?ooool2o`0000Cooooo0_l0001Oooooo`Go00000oooool2o`00
00Cooooo0_l0001Qooooo`?o00001?ooool2o`0000Cooooo0_l0001Qooooo`?o00000oooool2o`00
00Cooooo0_l0001Qooooo`?o00001?ooool2o`0000Cooooo0_l0000?ooooo`00OOooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Goooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000Goooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0001Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00003_ooool007gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00063ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
06?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo05cooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000Hoooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool03?ooool007gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00067ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0Goooool2o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001Nooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0001Sooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0<ooooo`00OOooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000G_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0001Sooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0001Oooooo`Co00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000kooooo001looooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0005kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Goooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Pooooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005oooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo000D
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0001P
ooooo`?o00001?ooool2o`0000Cooooo0_l0001Qooooo`?o00001?ooool2o`0000Cooooo0_l0001R
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000H?ooool5o`0000?ooooo0_l00004
ooooo`;o00003oooool001Cooooo00?o0000ooooooooool0oooooooooooood?ooooo000Dooooo`03
o`000?oooooooooo0?oooooooooooom3ooooo`005?ooool00ol0003oooooooooo`3ooooooooooooo
@oooool001Cooooo00?o0000ooooooooool0oooooooooooood?ooooo000Dooooo`03o`000?oooooo
oooo0?oooooooooooom3ooooo`005?ooool00ol0003oooooooooo`3ooooooooooooo@oooool001Co
oooo00?o0000ooooooooool0oooooooooooood?ooooo000Dooooo`03o`000?oooooooooo0?oooooo
oooooom3ooooo`001_ooool>o`000003ool00?l0003o00000?oo0000ool0000lo`0000Oooooo000D
ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ool0
0?ooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003oo`00ooooo`1]ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ool00?ooool0
KOooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`000?oo
003ooooo0?oooooooooooom3ooooo`005?ooool00ol0003oo`00ooooo`3ooooooooooooo@oooool0
01Cooooo00?o0000oooooooo0000oooooooooooood?ooooo000Dooooo`03o`000?ooooooo`000?oo
oooooooooom3ooooo`005?ooool01?l0003ooooooooooooo003ooooooooooooo@_ooool001Cooooo
00Co0000ooooooooooooo`00oooooooooooood;ooooo000Dooooo`?o000000?oooooool00?ooool0
oooooooooooood3ooooo000Dooooo`05o`000?oooooooooooooooooo0000oooooooooooood7ooooo
000Dooooo`06o`000?oooooooooooooooooo003oof40oooooooooooood3ooooo000Dooooo`03o`00
0?oooooooooo00;ooooo0_oo003ooooooooooooo?oooool001Cooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`3ooooooooooooo??ooool001Cooooo00?o0000ooooooooool01?ooool0
0ooo02Coo`00ool0003ooooooooooooo??ooool001Cooooo00?o0000ooooooooool01oooool4ool0
0?oooooooooooolhooooo`005?ooool00ol0003oooooooooo`0:ooooo`03ool06?oo003oo`0000Go
o`00oooooooooooooc7ooooo000Dooooo`03o`000?oooooooooo00kooooo1?oo02@6ool00?oooooo
ooooool[ooooo`005?ooool00ol0003oooooooooo`0Booooo`Koo`0T1Ooo00000ooo01Sooooooooo
o`3ooooooooooooo8oooool001Cooooo00?o0000ooooooooool06?ooool5ool090Goo`0000?oo`0H
oomQ0?ooool0oooooooooooooakooooo000Dooooo`?o00007Oooool5ool090?oo`0000Coo`0HoomQ
0?ooH@3oof40MooooomVoomQ0?oooooo??ooool001Cooooo00?o0000ooooooooool08_ooool2ool0
lP03ool09?oo003oo`0000?oo`0000?oo`0HoomQ0?ooool0J_ooool7oomQ00Goo`0H2?oo00Koool0
07Ooo`002ooo00HEooooo`005?ooool00ol0003oooooooooo`0Uooooo`Coo`3b00?oo`0Tool00?oo
00000ooo001Sooooo`Goof4000?ookH0ool06?oo01P00ooo00H>ool00?ooo`0<Mooo00`;ool001Go
oooo000Dooooo`03o`000?oooooooooo02Wooooo00?o^03oool0l_oo0?800ooo02@3ool003oooooo
2_ooH@0Booooo`?oof401?oo]P000ooo01Soo`0Bool04P06ool000Koo`0<n_oo01j?ool0?1Gooooo
000Dooooo`03o`000?oooooooooo02cooooo0_nh0?l01?oo0;coo`0Tool09?oo02@2ool00003o`1a
oooooooooooo03Gooooo1OooH@000oooooooodP0oom80007oonf01;oof400_oo]P03ool060Goo`00
0ooo00`6ool07SWoo`0f5?oo04h>ool0TOooo`0`<_oo030Eooooo`005?ooool00ol0003ooooooooo
o`0_ooooo`03okP0oooo0;coo`2l00;oo`0T0_oo0002o`1aoc7ooooo0oooH@001_ooB03ookH0o`1a
ool0LOooo`3nool060;oo`0B0_oo00H5ool000;oo`060_oo0183ool060WookH00ooo01P4ool00003
ool03?oo01koo`0N00;oo`0N1?oo03H5ool0?0Goo`1K0ooo04iCool0<13oo`0fROoo05^Hool0IaGo
oooo000Dooooo`03o`000?oooooooooo03;ooooo0_oo0;`01?oo03coo`0Tool00?oo0002o`1ao`03
oomQ0?oooooooooo02Wooooo0oooH@02ooooo`03oonf0?oo0?koo`3n00;oo`0B00?oo`06ool00?oo
00001?oo0004ool031?oo`0000Coo`0<ool07_oo01koo`0N0_oo03H2ool0?0;oo`1800?oo`1Kool0
<?oo03003Ooo030^ool0Ib3oo`1K5?oo06LLool0KEOoo`1iXooo07<<ool0KAGooooo000Dooooo`03
o`000?oooooooooo03Cooooo00Coo`3bool0_?oo03coo`0l0_oo00000ooo00Koof40ooooo`0Xoooo
o`04oomQ0?ooooooooooooooo`?oo`3n00?oo`0Hool01_oo00000_oo00000ooo01koo`0Tool0900=
ool0<0?oo`0N1_oo00`4ool07P?oo`0f00?oo`0lool0<?oo03001Ooo0303ool0CP[oo`1W1?od0?l6
ool0T@Co01Ko<?oo06d8ool0LaOoo`1i2ooo09M_ool0Ljooo`1o5Oooool001Cooooo00?o0000oooo
ooooool0=_ooool2ool0lP;oo`0l00Coo`00ool01_oo01;oof409_ooool01oooH@3oooooooooool0
LOooo`3nokh0oooo01P00ooo00000ooo01koo`0Tool0B003ool0<0?oo`1>00?oo`1cool0KOoo06d0
0ooo06d4ool0CQ7oo`0`00?oo`1>oa@0oooo0<800ooo0<82ool0fP[oo`3P1Ooo094;ool0K@_oo`1i
1?oo0>04o`2Wo`Co0?oZ1_l0of/Kool0Ub;oo`1c0ooo07o9on80o`03o`0Lool0g_oo0=ko017o0=ko
;ol05_l?oi<0oaGooooo000Dooooo`03o`000?oooooooooo03Sooooo0_oo0?801Ooo03coo`00ool0
0?oo01;oof4002Cooooo00coof40oooooooooooo077oool0o_nn0?ooo`0Hool00?oo00coo`3Jool0
9?oo03`2ool0<003ool0C_oo06goo`1]00Coo`1]00Coo`1iool0Oooo07ooo`1o2_oo06d7ool0L`Oo
o`322Ooo0:T7ool0T@Goo`1]1ooo07T5ohd0ocSoo`1o1?l0of/>ooooo`[o01cooonC0?lEoi<0o`Co
01co2ooo0>0Eooooo`005?ooool3o`0003[ooooo00Ooo`3bool0??oo03coo`00ool04_oo01Soof40
027ooooo00Goof40oooooooooooo077oool0oP02ool06004ool01_oo003oo`0Tool090;oo`0`00?o
m03oool0QOoo06d00ooo07l3ool0R`Goo`2G1_oo08/3ool0Oakoo`1]0ooo07T9ool0Q@Goo`1o1?oo
08D00ooo09Oo0P3oo`80o`03o`80o`KoS@3o1oo40?l<ool0h0Wo09Go2_m@o`0Do`0Lo`?o0=ko1ol0
of/9o`3oGa3oolP0Gooo08^[ool0QAGooooo000Dooooo`03o`000?oooooooooo03_ooooo00?oo`3b
ool0/?oo03`00_oo00000ooo01Soof40ooooo`0Nooooo`0;oomQ0?oooooooooooooooooo0?koo`0H
ool0:_oo00Koo`00ool09?oo03000_oo04h01?oo08Goo`1]ool0KOoo07l2ool0Ua3oo`2`00?oo`2G
ool0Rooo08/00_oo08/<ool0O`;oV@3o00?oT`3oool0NOoo07T00ooo07T6ohL0o`?oo`382_oo07l4
ool0U`Goo`2Y4ooo08D:ohd0o`;ooooo5Ooo0>06o`2Eo`So0?mO9ooo08/>ool0e0;ooooo2_l0okA5
ool0QD?oo`3P6?l0ok@5ool0e43oo`2f2ooo0:TEooooo`005?ooool00ol0003oooooooooo`0loooo
o`07oil0oooo0;3oo`0lool09?oo003oo`0HoomQ000Nooooo`0<oomQ0?ooooooooooool0o_oo01So
D03oool04_oo003oo`1Dool0B?oo033om03o0_oo06d2ool0R`04oiT0oooo0;3o0;Coo`2doa7onP3o
0_oo0;05ool0U`Koo`2;0_oo0;HAool0O`03ob`0ool0l?oo0?3o00Koo`2G1_n70?lGool0R`Woo`25
00?o0P3oohd0oon=0?l01On=0?l3o`0Lo`;o0=ko6Ooo08/8ool0e0[oo`3P;ooo08F:ool0]U_oo`2Y
2ol0oi/Eooooo`005?ooool00ol0003oooooooooo`0mooooo`07oil0oooo09Ooo`0lool09?oo003o
o`0HoomQ000Looooo`0@oomQ0?ooooooooooool0o_oo02[oo`0Hool04_oo003oo`0Tool0B?oo033o
o`1>ool0KOoo07ooo`2;on80o`;oo`2`0ooj0?l00oo40?ooo`2lool0_007ool0_003ool0l_oL0?oo
g03o00CoT`3o1ooj0?l6ool0U`Goo`2;0_oo0;04ool0]P;oo`3800Go0_l0ob`0ool/0?oo;03oo`3`
o`04ool0U`03o`3Hoooo08_oo`2;00Woo`2;2Ooo0;H3ohL0o`_o0=So1ooo0:T2ool0RcSoo`25;_oo
0;HDo`3oJc7oooooA_oo0:TEokSo02oo[?l05_ooool2onko00[oEol05Oooool001Cooooo00?o0000
ooooooooool0?_ooool01ooX0?ooo`2Gool0??oo02Coo`00ool06?ooH@006_ooool03OooH@3ooooo
oooooooo0?ko077oool06?oo01;oo`00ool09?oo04Soo`0`ool0C_oo06d00_oo08/2ool0/0;onP3o
00?oa03oom`0oooo0;`00_oo0;`8ool0e0Coo`2l1Ooo0?8=om`0o`?oo`2G4_oo08/8ool0]PCo00Co
0_o40?l2o`04o`Cooooo4Ooo0;H2o`0Lo`04o`3Hool0g_oo0=koo`3No`?oo`3D1ooo0:T2ool0e0;o
0?3o00?o0P3oohd0oon=0?l05?n=0?l00ol0okCoo`2fool0]P0@ool0]P?ooooo4Ol0UOl3oooooaGo
Qol0Aooo0:TFokSo01Gooooo6oo^o`1LoeOo00[o[?l05Oooool001Cooooo00?o0000ooooooooool0
?_ooool02?l04?ooj03oool0Uooo03coo`0Tool00?ooooooof406?ooool04_ooH@3ooooooooooooo
0?ko077oool0:_oo01Soo`00ool0E?oo02Coo`0`ool0C_oo06goo`1oool0Uooo0;3o0;CoooX0o`;o
a03o0_oo0;`01Ooo0?SoS@3oohd0oon=0?oo0?ol00Co01Ko1Ol0Mol01?oo0>Koo`2lool0_?oo0;`2
ohd0o`Coo`3b00?oS@3oo`0Fool05_l01?l/0?l3o`80o`?og03o1_oo09L2ooX0o`03o`3Hool0OOoo
07go00;o07go2ooo0;02o`3o40?oa03o0oooool00ol0OOoo00Coo`04o`04o`04o`Ko07go00?ooooo
o`0Loooo0=@01_oo0=@@ool0]U[oo`2Y0_oooolHohOo01CoD?l05_l0of/3onko04KoEol0Foooool;
ohd0oaGooooo000Dooooo`03o`000?oooooooooo03oooooo00So013oonP0oooo09Ooo`0lool09?oo
003ooooooomQ01Oooooo01;oof40oooooooo0?ko077oo`h0oooo01Soo`0Bool00?oo02Coo`0`ool0
C_oo08Goo`1]ool0Rooo0;3oVOl0ooX0ooo40?l2ool0_0?oS@3o00?o0?l@o`0Fooo:0?l02_o:0?l0
1?m_0?oo0?lFool0i_oo0=@3ool0_0?o07Oo0ooo0?801?l0Mooo0P3oo`80ool20?l7ob`0o`;o00Co
00Go07goom`0oooL0?oog03oo`1mo`03ooX0o`Cooooo00Co2?l0o`2Wool0Yooooooo0_l0onX00ooo
oooo0?l@ol@0o`09ool0/0Kooooo00?o00Coool0e?oo0=@01Ooo0=@4o`04o`?ooooo0_l0oel6ohL0
o`03o`3oUOl0f?oo0=So00Co0=So00?ooooookko0?nno`001?nno`08o`3o]0?ooooo1Oodo`04o`3`
o`co0P3o00?om?l0ohd0oon=0?l02_n=0?l9o`;o00WoJOl05?oooolHo`2Eo`?ok_l05On7o`000omG
o`3oD?l0oe3o000Boe3o01Oo0?m[A?oooomDool0/1Gooooo000Dooooo`03o`000?oooooooooo043o
oooo00So013oool0_?oo09Ooo`0lool00?oo01SooooooomQ01Gooooo017oof40ooooooooooooo`3n
oioo0?oo02[oo`0Bool00?oo02Coo`18ool0<?oo08Goo`1]ool0Oom40?ooo`2`ooX0o`02ool0_004
om`0oon=0?ooa?l0o`3oo0?obP3o0om_0?l00ol0oaKo0P3oo`80o`05o`80o`CobP3o0_oo0=@01?oo
0?Soo`2lool0_?oo0;`3ofl0o`?oo`3b2_m_0?l01?l0oiGoVOl0oiWo0?ooR`04om`0o`ConP3o00Go
0:OooooooolPo`3o0?oZob3o0003ol@0o`So8?l00_ooool8ool0/0;o01co00?oMOl0o`3Nool0g_l0
1?ooool00ol0OOoo00Coo`04o`02o`04o`Cooooo0onno`06ohL0o`03o`3oUOl0f?oo0=So00Co0=So
00?o0?ndooooooooool06_ooool4o`3`o`_o0P3o0_odo`0Tohd0o`GoJOl04_o^o`03ooCo01Oo09Go
00?oEol0oooooon7o`005_n7o`000om@o`3o0?m<o`3oC00@o`3oC4Goo`2`1_n=0?mSooooo`005?oo
ool00ol0003oooooooooo`11ooooo`08olX0oooo0;coo`2Gool09?oo003oo`0HooooooooH@0Coooo
o`0FoomQ0?ooooooooooool0o_l0LOooo`3/ool04_oo003oo`0Tool0B?oo033oo`1>ool0KOoo07oo
o`2;ool0/?oj0?ooo`2lool0i_oo0=Coooooojco00;obP3o0_m_0?l9onP0o`Ko0?nW00So0?oZo`3o
Yooo0>Koo`3DolX0oooo0?So0?nWool0_0;o0?nW00?o09Gooch0ooln0?l00_oo0?88och0o`?oK`3o
00?o?P3oob3o0?lPo`000_lPo`04om`0o`KonP3o2_ooool2ob3o00?oo`3D00Go8?l0o`0Lool07?oo
01coob3o0007ool0/0?o0?mO1?nno`04o`04o`03o`1moooooooooooo00Kooooo1_n70?l00ol0oiGo
0=Soo`3Ho`05o`3Hoacooooo1?o^o`000onho`3o0?3oo`3`o`02o`3`oa7o0P3o00?o^?l0onko0?o^
o`000oo^o`0<o`;o00?ok_l01on=0?lWool0iRooo`2`VOoo0>HEooooo`005?ooool00ol0003ooooo
ooooo`11ooooo`09o`0@ooo:0?ooo`2lool0??oo02Coo`00o`1aooooooooof4001;ooooo017oof40
ooooooooooooo`3nool0k?oo01;oo`00ool03?oo02Coo`0`ool0C_oo07Woo`1]ool0Rooo0;3oa03o
ool0_002ool0e003ooooool0oa3obP3o00;oK`3o0_oX0?l9oil0o`?oj03o0omk0?l3och0o`06ool0
i_oo0=CobP3oool0n?o:0?ooo`2l0_ln0?l01?l01?oo0?m[o`1mool0OOl2ool0lP03o`3oUOlPo`3o
VOl000Kooooo0om_0?l5och0o`;ooooo00?oa03oom`0oooL0?l00_oL0?l6ooX0o`?ooooo0ooo0=@0
1OooooooMOl0o`0Lool07?ooMOl000?ooooo0_l0g_l00onno`3o8?l0o`3oG`02o`3oG`Ooo`2`1?oo
ool3o`04o`?o07go0ol0ok@6ooooo`SoQ`3o1ol0f?l4ooooo`?ok_l04_nho`0<ooooo`Wo0?3o5_oo
0>H^ool0/0KoJOl0;_ooool?ohOo05oo09Go9_n70?lEooooo`005?ooool00ol0003oooooooooo`12
ooooo`09o`0@ooo:0?ooo`2Gool09?oo003oo`0Bo`1aooooooooof40013ooooo01Woof40oooooooo
ooooo`3no`h0oooo02[oo`00ool03?oo02Coo`0`ool0C_oo08Goo`1]ool0Rooo09OoVOl0ool0_?oo
0=Coo`3ho`3o@?l0oa3obP3oofl0ool0omSoj03o00;oW`3o00?oN`3ooa[o0?ln0?l00_ln0?l01?m_
o`3o09Goo`2Eool0UOl3oil0o`03onP0ool0of_o0?m[00?oN`3o00So0?m[ool0e?oo0>Ko00Coool0
n?o:0?ooo`2lob3o00;o07go0ol0f?l00oooooooo`3bool0lP04ooooo`Ko0?mU0om_0?l2o`3oI@;o
a03o1_ln0?l5om`0o`?oo`3D2?oj0?l3o`3No`04okko0?l0oeoo0?mOo`3oG`?ok_l01_lPo`000oo^
o`3oo`2`ool0/004ool0/003o`3o]?l01?oo00Co00;o00Co1?l0OOl<onko00_oQ`3o0ol0f?l00ol0
oiGoooooooooo`07oooooa_oo`3V6?oo0;2@ogD0oa?o0?o`5ol20?lFohL0oaSo0P3o3_l0oo0Eoooo
o`005?ooool3o`0004?ooooo00SoE`3oool0_?oo03coo`0Tool00?oo01SooooooomQ013ooooo01Ko
of40ooooooooooooo`3nool0:_oo01;oo`00ool03?oo04Soo`0`ool0C_oo07Woo`1]ool0Uooo0;3o
nP3oool0_?oo0=Co0?oNo`3o4?o:0?ooK`3o0_oX0?l01?nO0?ooB_l0o`3o5_ln0?l6ok80o`Go803o
00?oW`3oonP0oooX0?l00_lP0?l02?l01?ooN`3oog/0oooo0=Coo`3Vo`1moooo0?So07go0_oo0;`0
0ol0f?ooKol0ofoo0002ofoo00;o0?mU00Coo`3bo`3oIOl0ofGo0?mU0oooool2o`So0006ooooool0
Yooooooooooooom_0?ooa03o0_m_0?l00ol0oa3oooooooooo`04ooooo`05och0oooo0=Coo`3Dool0
e?ln0?l01OoL0?l00oo^o`3o0?mUo`3No`02o`3No`GonP3o2oooool3ob3o00?o0?nd00?oooooool0
/?oo0;001Ooo0;02o`04o`Go07go2Onho`09ooooo`;oQ`3o2ooo0>H2ooooo`;oEol05ooo0;0DogD0
o`So0?3o6?l0oo04o`;o06_o0P3o;on70?lEogD0obOonP3o5Oooool001Cooooo00?o0000oooooooo
ool0A?ooool02?o:0?ooo`1]ool09?oo003oo`0Bo`1aooooooooof403_ooool05oooH@3ooooooooo
oooo0?koo`0Zool0k?oo003oo`0<ool09?oo033oo`1>ool0NOoo06goo`2;ool0Uooj0?ooo`2lool0
e?oo0?So0?m0olX0oom_0?ooj03o00;oW`3o00?oB_l0ok80oonb0?l01onh0?l2ok80o`08ob3o0?oo
oooo0?3oo`0Lool0OOooW`3oonP0ool0OOl3ob00o`09og/0oooo0=Coo`3Vo`3Hoooo0?So0:OoolX0
oooo0;coj?l000?o0?mU0oooool2ool0lP05ofoo0?oooooo2?l0o`So0?ooool00_l0Yol2ooooo`;o
a03o0_ooool00ol0oa3oK`3oofl0o`02ofl0o`;ooooo0_oo0=@2ooooo`;ok_l01Oln0?l4om`0o`;o
0?mO1?ooool4ooX0o`Oo^?l00ol0ok@3okSo00Ko8?l000?o^?l0oooooooo0;00:Ooo0;08ohL0o`co
M@3o5Ol0oo0:ooooo`co0?3o4?oooolBo`;o02[ooooo;on70?l6ofWo013ooooo;_oj0?l4ocko00Co
D?l0=?ooool001Cooooo00?o0000ooooooooool0A?ooool02OmG0?ooo`2Gool0??oo02Coo`00ool0
4_l0LOoooooooomQ000<ooooo`0LoomQ0?oooooooooooooooooo0?koo`0Zool06?oo003oo`0<ool0
<?oo03coo`1>ool0KOoo08_oo`2Go`3oXOoo0;coo`3Dool0n?l0omkobP3oofl0oooX0?ooW`3oog/0
oom:o`3o/P3oob00o`;o^03o0_l0UOl00ol01?oo0=koo`3No`02okP0o`03o`1moonb0?oo/P3o00;o
07go00Co01cooooooonO0?ooj03o1Ol0f?l01?oo0=Coo`3Vog/0oooo0?P2ob00o`;oo`2l1ol0@?l2
ool0lP;o043o00?o0:Ooofoo0?m_o`000_o40?l01?l0on[oooooo`3o4?l0oa05ooooo`03ofl0oooo
0=CoK`3o00;oK`3o00?ok_l0ooooool07?l00onno`000ooooooo0=kooch0o`03och0o`Cog03o1_nh
o`03ooX0o`04o`3oIOl0okCo0?ndo`3o]0cooooo1OlPo`02ooooo`03o`04oooo0>Koo`3V00Ooo`3V
0_l0OOl8ooooo`GoEol03?me0?l3o`3oU@Go0=So7on70?l>ooooob;o08oo=?n70?lFo`2?oboonP3o
1Olno`03ofWo02kooooo7om@o`0Eooooo`005?ooool00ol0003oooooooooo`15ooooo`09onP0oooo
06goo`0Tool0E?oo003oo`0Ho`1aooooooooof4000_ooooo01Woof40ooooooooooooo`3nool0:_oo
0>coo`0Bool00?oo02Coo`0`ool0C_oo06goo`1oool0Uol0oj7onP3oool0_?oo0?So02;oolX0oom_
0?ooj03ooil0oomk0?ooKol000?o^03o00?o0?nWoed0oomM0?l01_mM0?l2okP0o`04o`3Hoonb0?oo
043oo`0Lo`?o043o00?oj03oo`10ool0@?l00ol0@?l02ooo0=Coo`3Vo`3oIOoo0?Soa03oo`2Wooo:
0?ooo`2lok;o0?ooooooj?l000Co2?l000Co0:Ooool0l_oooooo043o0_o40?l3o`10o`03o`3o4?m_
o`3oKol000CoKol00_oo0=@4ofoo00GoK`3o00CoKol0o`3Noom_o`3oKol00_l0oel2ofoo0004oooo
ooln0?oo?P3oom`0ob3oo`3V0olPo`000ooooooo00Coo`04o`04o`04o`03ooooool0OOoo07go00Co
07go00?oEol0ogD0oome0?l01?me0?l00ooooooo0?m<o`3oC006o`3oC0Wo0?o`1Ol0oiD8o`3Ho`03
ooooool0Sooo08oo017o08oo<?n70?l6o`3`oaGooooo0_l2o`0]ooX0o`Go?_l06OoooomVo`2?oaGo
oooo000Dooooo`03o`000?oooooooooo04Gooooo00WobP3oool0Uooo03coo`0Tool00?oo01;oo`3n
o`1aooooH@002_ooool07OooH@3ooooooooooooo0?ko9_l0ool0:_oo01Soo`00ool03?oo033oo`0l
ool0C_oo06goo`2Yool0Uooj0?ooo`2lool0e?l08_oobP3oo`0FoooX0?ooW`3oo`80oom@o`3o/P3o
okP0oolJo`3o0?nW00OoM@3o00CoGOl0o`10ool0@?ooG@3o0_nh0?l01onb0?ooooooo`0Loooooooo
^?l0oooooooX0?l01?l0ofD02?l0on[oo`3Dool0i_ooooooo`3hol@0ooo:0?oo803o0_oo0;`5o`2W
o`;ooooo00Coo`3bol@0ool0on[o0?oZ0_ooool00ol0oa3o043oo`10o`03o`10o`;oo`3D1?ooool2
onSo0005o`0LoooXo`3oj?l0onSo0?nho`000om_0?l9ool0iP;oKol01?oL0?l00ol0okCooooooooo
o`03ooooo`03o`3oIOoj0?oonP3o00;onP3o4_ooool6ob3o0003oeOo0?l01?oo00Co00KoM@3o1?l0
OOl3o`3oC0;ooooo1_l0oo0<ooooo`_o08oo1ol0f?m1oooooaSonP3o0oooool6ocko01;o0_l0Gooo
oolGofWo03Gooooo000Dooooo`03o`000?oooooooooo04Gooooo00[oE`3oonP0oooo04koo`0Tool0
E?oo003oo`0Ho`1aooooooooof402?ooool06OooH@3oooooooooooooooooo`3nokh0oooo02[oo`0B
ool00?oo00coo`0`ool0C_oo06goo`1oool0Uooj0?ooa03oool0_?oo0?So02;oolX0oom_0?ooj03o
og/0ool20?l00_nh0?l01olJo`3oM@3oogD0oome0?oo0?nKooooool0OOl00olJ0?l2ogD0o`06oaX0
ool02_oo00[oo`0:oonh0?oo/P3o0ol02_l00ol0ofGoj03oooooo`02ooooo`?o0>Co00Woo`3Do`3T
ool0i?ooo`3hol@0ooo:0?ooa03oob00oooo0;`01?l0i?l3ol@0o`03ool0l_l0i?oo0>Co00Oo0>Co
00?oo`3Do`10ool0@?l01?l0@?l2o`0Lo`?ooooo00?o^?l0o`3Noooo0>H00_oo0>H2ooooo`CoK`3o
1Oooool01?m_o`3o0?ndo`3o]?ln0?l4om`0o`?oj?l00oooool01?l0ofGonP3oooX0oooj0?l?oooo
o`GoEol01?me0?l01?lPo`3o0?m<o`3oC?l0od`6o`04o`Ko07go2Oooool8o`2?o`[ooooo1ol0oiD0
0ooooooo0=Soo`3Ho`05o`3Ho`cooooo;_oj0?mUok80ob;oj?l0@_oo0?PEooooo`005?ooool00ol0
003oooooooooo`16ooooo`09olX0oooo07ooo`0lool09?oo003oo`0Bool06?l0LOoooooo00;oof40
1Oooool08OooH@3oooooooooooooooooo`3nobKo0?oo02[oo`0Hool00?oo00coo`0`ool0??oo04ko
o`1]ool0b?oo09OonP3oool0_?oo0=Co02;oolX0oom_0?ooj03ooil0ool20?oo^03oob00ool0oeoo
M@3oo`04ool0UOoo0?m[oaX0o`03oh40o`05o`0:ool0f?oo0?mUo`3oIOme0?l00olJ0?l01Onh0?oo
G@3ook80ool0i?oo01co00;o00[o00Coj03oo`0:ool0i?oo0?l@0_ooool01ol0on[oo`3Doooooooo
ooooo`3hooooooo:0?l00_o40?l00ooo0;coa03ool@0o`02ol@0o`;o0?oZ00Coooooool0l_oo0?;o
o`3b1?oXo`02ool0e003ooooool0i?oo0>Co00?o0>Co00?o01coo`10ool0@?l00_l0@?l3ool0iP03
o`3Toooooooooooo00Kooooo0om_0?l00ooooooo0?ndo`3o]004ooooo`03ofoo0?ln0?oo?P3o00Co
g03o1_oXo`04ooX0o`03onSo0?oooooooooo00?ooooo1OmGo`02ooooo`?oM@3o1Ol0od`2ooooo`;o
8?l01?l0oo000ooooooo00Coo`04o`04o`04o`Ko07go0ol0SolEoooooaSonP3o2Onb0?lEoooooiOo
o`3h1_nb0?l_om`0o`go/P3o5Oooool001Cooooo00?o0000ooooooooool0A_ooool02OmY0?ooo`2G
ool0C_oo033oo`0Tool00?oo01Soo`3no`1ao`02ooooo`04oomQ0?ooooooooooooooo`;oof400ooo
ool06ooo0?ko_P3oool06?oo01;oo`00ool03?oo033oo`1>ool0KOoo07ooo`2GooX0oooo0;coo`3V
ool0e?l0^_oobP3oonP0oonO0?ooN`3ook80oonh0?oo803oogD0ool01?oo09Goo`3o2P03oh40o`03
o`3oUOn10?ooP@3o00;oP@3o0_l0i?l02?me0?oo0?mIo`3oFOlJ0?oo^03ook80oomM0?oo01co0_l0
oeT00ooX0?ooW`3oo`0:o`03o`0:o`07o`3oFOl0on[oo`3Dool0e?l0oeWoo`3ho`3oF@02olX0o`06
oooooooo0;cok_l0ok;o0?l0on[o/_l00_o^o`02o`3o4003oooooooo0?;oo`3b00;oo`3D1oooool0
0ol07?ooMOl0okSo0003ool0iP03o`3Noooooooo043o00Co043o0ol0i?l5ooooo`?oK`3o2?ooool2
och0o`04ofoo0?oL0?oog03oom`0o`Oooooo2ooj0?l2ogD0o`;o0?m<1_ooool4o`3ol0?ooooo00?o
8?l0o`2?ool0Sol00_l0Sol00olPo`3oooooooooo`06o`04o`Ko07go4_oj0?l00onb0?oooooooooo
o`08ooooo`Wo0?nE8_oo0?P=ocko04Wooooo<?l0l?lGom`0oe7ooooo0008ooooo`?o00002Oooool0
0ol0003oooooooooo`16ooooo`0:o`0@oooX0?ooo`1]ool0??oo02Coo`00ool04_oo01Soo`3no`1a
o`;ooooo0oooH@04ooooo`0Fool0o_lVo`3oo`0Zool06?oo00Koo`00ool09?oo033oo`1>ool0KOm4
0?ooo`2GooX0oooo0;coo`3Do`0Rool0od3obP3oonP0oonO0?oo?P3ookP0o`;oM@3o00_o0?nWo`04
oon10?ooP@3oo`0:ool0@?oo0?nEo`3Hool0ofGoooooo`3To`02oh40o`0:o`3oFOl0oeooM@3ooooo
ool0g_oo^03ooego0?nb0?ooG@3oo`0Lo`;o0?lX00?oj03oo`3o:?l0obP00_l0obP01ol02_oooooo
oooooooo0>Koo`3Doooooooo0?P00_ooool01?o:0?oo0?oZool0_?lP0?l2o`3oF@03ok;o0?l0oa3o
/_l000;o/_l000?oooooool0e?ooool01Ooo0?82ooooo`04o`0Loooo0>Koo`3Vool0iP;ooooo00?o
0=koooooool0oel01Oooool5o`10o`;o0>Co00Co0?ndoooooooooooooooo0om_0?l7ooooo`?o?P3o
00?oooooom`0oooL0?l00_oL0?l4oeOo00;ooooo00?o0?mUogD0oome0?l00ome0?l2o`3oC2GonP3o
2?nb0?l<onSo01;oo`3h00?oooooo`3oUOl0oiD02_l0oiD:o`3Ho`Oo?_l0L_oooolHom`0obko0?3o
>_ooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17ooooo`09okP0oooo
09Ooo`1>ool0<?oo02Coo`00ool04_oo01So077o00Sooooo01Woo`3noonf0?nn0?ooo`0Hoe00oooo
003oo`0<ool0<?oo03coo`1iool0KOoo0;3oo`2Gool0_?oo0>Koo`3Do`3og_o:0?ooj03ooil0ooln
0?oo^03oogD0oomM0?oo8?l000;oP@3o00Go6P3oo`0:ool0@?oo0?nEo`3Ho`02oeL0o`05o`3Toooo
ooooooooo`23oon10?l00_l0Pol02ome0?oo08?oo`23oonh0?oo/P3ooed0oolJ0?oo01cooooooooX
0?ooW`3o00?ooooo00So0?lXo`0:ool02_ooooooool0i_oo0=Co0?oZool0n0;o0?oZ00?obP3ooooo
oooo0;`00_lP0?l3o`3oF@03oooooooo0=Coo`3D00Oo/_l00ooo0>H01ooo0?;o/_l0ok;o0?nbo`3o
0=kook;o0?l0oel02onbo`03o`10o`;o0>Co1?ooool2ofl0o`Oooooo00?oEol0och0ooln0?l00_mG
o`000ooooooog03oom`0o`04om`0o`04ogD0oooooooo0?m<o`3oC0Co0?mU0_ooool4o`3ol0Gooooo
1?l0Sol8ooooo`Oo/P3o1_lPo`03o`04oa;oo`3h4oooool;ocko0003ooooool0oiGo0?nE00So0?nE
2?l0f?m4ooooobgog03o6_oooolHo`;o01Cooooo9Ol0l?lEooooo`002Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo04Oooooo00[oJ@3oonP0oooo06goo`0`ool09?oo003oo`06ool0
6?oo0?ko077o1_ooool07_l0LOooo`3nobKo0?oo02[oo`0Hool04_oo003oo`0Tool0<?oo04koo`1]
ool0Rooo09OonP3oool0_?oo0=Co02;oolX0oom_0?ooj03ooil0oonh0?oo/P3oogD0oolJo`3oP@3o
oaX0ool0of_o00[oo`10o`?oE`3o00?o0>CooeL0oomG0?l00_mG0?l03?ooooooP@3oo`3od_l0om;o
M@3oo`3od_l0g_oo0?oBokP0oonb0?ooG@3oo`0Lo`;o08?o00?oj03ooil0ool0om801?l0om801_l0
2_ooooooool0i_oo0=Coooooool0n0;ooooo00KobP3ooooooooo0;coo`2lob00ooooool2ool0e0Oo
0?mI0_oo0>H01?l07?ooMOl0ooooooooool8ool0lPSooooo00Co0?ndok;o0?nbo`3o/_l00_l0@?l3
o`3To`?ooooo0_m_0?l5oeOo00?ooooo0_ln0?l4ogD0o`;ooooo00?o0?m<om`0oooL0?l00ooL0?l2
ooooo`?o0?o`0_l0ofD3ooooo`Co08oo1_ooool6ok80o`Cooooo3?oo0?P3ob3o00Ko00Co0_ooool6
o`1mo`[ooooo2_lno`0Fooooo`So0?nE2?l0f?lToooooaSog03oB_oooom>ool0_1Gooooo0009oooo
o`03o`000?oooooooooo00Sooooo1Ol00015ooooo`0;o`2KoooX0?ooo`2Gool0??oo033oo`0Tool0
0?oo01;oo`0Hoonf0?l0LOl01?ooool07Ol0LOooo`3nobKo0?oo02[oo`0Hom3o0?oo00Koo`00ool0
9?oo033oo`1>ool0KOoo0;3oo`2Gool0_?oo0>Koo`3Do`3o@?o:0?oo01KoonP0ooln0?oo^03oogD0
oolJo`3oP@3oo`2EoolJ0?oo00[o00;oE`3o00?o0=Soo`3Tool0i?l00_l0Pol00ol0oh?o0?oBoeL0
o`02oeL0o`0>oh40oolho`3o0?mOogD0oooooooo0=koogGo0?nh0?oo/P3ooed0ool07?ooooooonP0
oonO0?l2o`23o`?ooooo00Co0?oBo`0:ool0om;ooooo0ooo0=@01Ooo0?SoooooolX0ool0oa3ooooo
00?oo`2l1_ooool2ool0iP03okSo0?l0oeWo01co00Go0?mI00?o0=koo`3oFOl0oel00_l0oeT00ooo
ooooo`3bool0lP03ool0lP?oo`3h1_ooool3o`10o`;o0>Co0omGo`03ofl0o`;ooooo1Ome0?l01?oo
oooo?P3ooch0ooln0?l2o`3oC0Cooooo00?oKol0o`3ol?oL0?l01?oL0?l00ooooooo08ooo`2?o`02
o`2?o`04o`3oIOooooooooooooooo`Ko/P3o00?oooooool0n?oo0?P01ooo0?PCooooo`;o8?l01_l0
1?l2ooooo`Go07go1Olno`0Xooooo`Oo0?nE00?oooooo`3Hool0f?l02ol0f?lGom`0o`CoooooG_oo
0;`^ool0lR3o0?Ko5Oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`18
ooooo`09okP0oooo09Ooo`1]ool0<?oo02Coo`00ool01_oo01Soo`3n00?o077o027oooooo`1aoooo
0?ko9_l0okh0oooo02[oo`0Hool04_oo003oo`0Tool0<?oo03coo`1iool0KOoo0;3oo`2Gool0_?oo
0=Co02;oolX0oom_0?ooj03ooil0oonh0?oo/P3oogD0oon10?oo00CooaX0ool02_ooE`3oo`10ool0
f?l01omY0?l3o`1Bo`04oeL0oon10?oo0?n3ogD0o`;ooooo00[o0=kookP0oonb0?ooGOl0oed0oonn
o`3oooooonP0oonO0?oo^?l00_l0Pol2ooooo`05o`3o4?l02_oo0?oBo`3od_oo0>H01_oo0=@2oooo
o`03ob00oooo0;coo`2l00;oo`2l0_oo0>H2okSo0003okko0?l07?ooMOl000Cooooo00?o0=koool0
n?oo0?P01Ooo0?P4o`3oF@Coo`3b1Ooo0?P00oooooooEol0oeOo0002o`10o`;o0>Co00?oooooogD0
oome0?l00ome0?l3ooooo`Co0?m<0_ooool2och0o`;ooooo0ol0oo03ooooo`03ofoo0?l0Sooo08oo
00[og03o1_oo0?PQooooo`?o?_l01_l01?l00olPo`3o07goo`1mo`04o`1mob?ooooo0_l0m_lGom`0
o`?o0?Ko0_l0f?lFool0_0;o0?Ko;Oooool^ool0lRgooooo5_lho`0<o`3o=1Gooooo0008ooooo`;o
00002_ooool00ol0003oooooooooo`18ooooo`09ofT0oooX0?ooo`1oool0??oo033oo`0Tool00?oo
01;oo`0H00;oo`3n0ol0LOl07Ooo0?ko9_l0ool0:_oo01Soo`0Bool01_oo003oo`0Tool0<?oo04ko
o`1]ool0/?oo09OonP3oool0_?oo0=CobP3oofl0ool05_ooj03ooch0oonh0?ooM@3ooa[o0?n10?oo
09GooaX0oomG0?oo043o00;oJ@3o00Co0>Coo`1Bool0D_oo0?oB0_l0ol`05ol0c?ooJ@3oo`3<ool0
c?ooE`3oo`3<oon10?oo05;oogD0oooooooo0=kooooooonh0?oo/P3ooed0oolJ0?oo__l0oooooooX
0?oooooookSo0?oooooo08?o00?ooooo00Co00[oo`3o4?l0obSo0?oB0_oo0>H3ool0n0?ooooo0ooo
0>HFool0_0;ooooo00Co0?ndooooool0oeWo0?mI0ooo0?82oeOo00[oo`3h0_ooool01?nbo`3oK`3o
ofl0oom_0?l7ooooo`04o`3ol?ln0?oo?P3ooch0o`?ooooo0ol0Sol<ool0n0;o0?mU6_oL0?l3oooo
o`So?_l02?ooool]om`0o`Cooooo6?oo0;`2o`3oUA;ooooo0ol0f?l^ool0lTCooooo;Ol0oc@Qoooo
o`002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Sooooo00[o09_oolX0oooo
09Ooo`1]ool0<?oo02Coo`00ool01_oo01So_P3o1?oo0?h08_lVo`3o_P3oool0:_oo01Soo`06ool0
0?oo05Coo`0Tool0<?oo04koo`1]ool0/?oo09Ooo`2lool0i_oo0=CobP3oo`0FoooX0?ooN`3ookP0
oonb0?ooM@3ooh40ool0UOoo6P3ooeL0ool0@?oo0?3oofT0ool0i?oo05;oo`3od_l0ol`3o`3<o`09
o`3oD_l0okCoJ@3oocko0?ooooooE`3ooh40ool0oeooM@3o00;o0<co00co0=kookP0oonb0?ooGOl0
oed0oonno`3oooooonP0oonO0?oooooookSo0?ooool2o`23o`;ooooo00Go00[oooooool0obSo0?lX
ooooo`06ool0iP05ool0n?oooooo803oob00oonho`001_oo0?P2ooooo`03o`3Noooooooo0?mO00Wo
oooo1_oo0;`00ooooooo0?mIo`3oF@03ool0lP?oM@3o0oooool3o`10o`Woo`3h00Co/_l0o`3ol?l0
oo3o0?o`0_ooool8ool0n003ok80oooooooooooo00Oooooo1Om_o`04o`3oIA3ooooo1Olno`0Com`0
o`Oooooo2_l01?l9o`1moaOoo`2l0ooooolDo`2^oaSoo`3b:Ol0[_l2o`3HoaOooooo6?lho`0Ho`3o
=2gooooo3?l0ogLEooooo`005?ooool00ol0003oooooooooo`19ooooo`0:okP0oooo09Ooo`1]ool0
??oo033oo`0Nool00?oo01;oo`0Hoioo00?o9_l0023o_P3oool0:_oo01Soo`0Bool00?oo00coo`0T
ool0<?oo03coo`1iool0KOoo09OonP3oool0_?oo0=CobP3oofl0oooX0?ooW`3ooch0oonh0?ooM@3o
o`04oon10?oo6P3ooeL0ool0@?ooooooofT0ool0f?oo05;oo`3odPGo02So01Ooooooo`3o>_mY0?oo
ooooocko0?ooooooE`3ooh40ool0oeooM@3oooooool0c?oo^03oogGo0?nb0?ooG@3ooaX0oonno`3o
ooooonP0ool0o`[ooooookSo0002ooooo`04o`23ooooooooooooo`0:o`;ooooo00Ko0?lXoooooooo
ooooN`3oooooooo:0?l2o`3odPCoo`3h00?o803oo`0Loomeo`001?ooool00ol0g_ooooooo`3oG`0:
ooooo`03o`3o]?oooooooooo00?ooooo0ooo0;`00oooooooM@3oogD0o`03ool0lPCooooo0_l0od`2
o`10o`;o0>Co0oooool00ol0oo3oK`3oool0n005ool0n0Co/P3o0oln0?lCooooo`03ofoo0?l0ofGo
0?mU00;o0?mU00?oKol0ooooooooool00_ooool7ocko01?ooooo2?l0m_lGool0_0?o00Co2_l0OOl:
o`2^oaOoo`3b3_ooool<o`3oUBOoooooM?l0[_l>o`04oaGooooo000Dooooo`03o`000?oooooooooo
04Wooooo00[oJ@3oonP0oooo09Ooo`1>ool0<?oo02Coo`00ool01_oo01;oo`0H0onn0?l07_oo02[o
o`0Hool04_oo00Koo`00ool0E?oo02Coo`0`ool0C_oo06goo`2`ool0Uooj0?ooo`2lool0e?o:0?oo
01KoonP0ool20?oo^03ook80oome0?ooP@3ooaX0oomG0?oo07goo`10oomY0?oo0=Soo`1Bo`?o02So
1?ooool2o`0Xo`0Fo`3o>_mY0?oo0?mBoeOo0?ooooooP@3oo`3oGome0?oo05;oo`3Nool0c?oo^03o
ok80ooooooooG@3ooaX0ooooooooj03ooil0ool0o`[ooooookSo00;ooooo0_l0Pol01?oooooo00[o
ooooooooool2o`3o:005oooooomk0?ooooooolX0oonho`001?l0om800ol07?oo803oob00o`04oooo
o`03o`3Nool0oeoooooo00Wooooo00?o0?ndooooooooool00_ooool2oeOo00;ooooo00?oM@3oool0
_?oo0;`00_oo0;`2o`3oF@?oo`3b00?o0?m<ooooooooool00_ooool2o`10o`;o0>Co00Co0?o`oooo
oooooooooooo1?nb0?l3ok;o00Gooooo0oln0?lCooooo`;o?_l01?l0ofD00olno`3oKol0ofoo0003
ofoo00_ooooo4_oo0;`00ooooooo0:koo`2^o`0Eo`2^o`;o8?l00ol01?lAool0lP;o07go:Oooool6
o`3oM`co0?nE=?l0ogL/o`3Hoboo00Co0ol0f?lPooooo`005?ooool00ol0003oooooooooo`19oooo
o`0:obH0ooo:0?ooo`2Gool0KOoo03coo`0`ool09?oo003oo`06ool04PCoo`0H01cod?l0ool01_oo
003oo`0<ool0E?oo02Coo`0`ool0C_oo06goo`2`ool0Uooo0;coo`3Do`0Rooo:0?ooj03oog/0ooln
0?oo^03oogD0ool01?ooP@3ooaX0oomG0?oo043oofT0ool0oiGo0=So0_l0:?l00ol0c?oo0?m<o`3o
C005ooooo`;o02So01GoJ@3oo`3oD_ooooooE`3ooh40oome0?ooooooo`1Bool0g_oo^03ook80ool0
olco01cooed0oolJ0?ooooooonP0oooooooo0?l:oooooonho`000oooool00ol0Poooooooo`0:o`03
ooooo`;o0?lX00SoN`3ookSo0?o:0?oobP3ookko0?oooooo01coogGo00;o0?oB0olP0?l00ol0g_oo
ooooo`3oG`0:ooooo`03o`3o]?oooooooooo00;oEol000CoooooogD0oome0?ooM@3o1Oooool4ool0
_004o`3oFOoo0?;oo`3bool0lPCooooo00?o043ook80oonb0?l00onb0?l00ol0Soooooooooooo`03
ofl0o`03oooooonbo`3o/_l000?o/_l00oooool4och0o`[ooooo1Olno`06ooooo`Co0?mU00?ooooo
ool0_?oo0;`02_oo0;`00ol0m_ooooooooooo`04ooooo`co0:ko4?ooool<ool0lPSo8?l05_l01?l0
0ol0OOooooooooooo`08oooooa?o0?mg4Oooool00olho`3o0?nEo`3oU@09o`3oU@03o`3o=?oooooo
oooo03cooooo5_l01?lbooooo`_oK`3o5Oooool001Cooooo00?o0000ooooooooool0BOooool02ol0
4?oo^03oool0l_oo07ooo`1>ool0<?oo02Coo`0fool00?oo01;oD03o00;oo`0Z01kod?l0ool04_oo
003o3_l0ool03?oo02Coo`0`ool0??oo07Woo`1]ool0Uooj0?ooo`2lool0e?o:0?ooK`3oonP0ool2
0?oo^03ook80oome0?ooP@3ooaX0oomG0?oo043oo`3oD_mY0?oo0=Soo`0Xool0om82o`2?o`03obH0
ool0Sooo0?of00;o0?of1?ooool05Ol0:?ooJ@3oocko0?ooooooP@3oo`3oGome0?ooooooo`1Boooo
oooo^03ook80ool0olcoG@3ooaX0oonno`3oooooonP0oooooooo0?l:ooooo`03okSo0004ooooool0
Poooooooo`0:o`;ooooo0_nho`002?l0obSoN`3ooooooonno`3obP3oo`0LooooooooMOl01?ooool0
0ol0g_oo803oob00o`08o`3odP;ooooo00Co0?ndoooooomGo`3oEol00_ooool00ome0?oooooooooo
o`06ooooo`?o0?m<00Go/P3oool0_?oo0;coo`2lok80o`04ool0lP05ok80ool0Sooo043oo`2?oooo
ool00_l0i?l5ooooo`?oK`3o0oooool7ok;o00?o?P3o00?o/_l0ocko0?lno`001?lno`04ooooo`co
o`2l00?o0?mUo`3fool0m_l01?l0m_l3ooooo`Wo0:ko1?m_o`0<ooooo`coo`3b5?ooool4ob3o00Wo
0?mge_oX0?lEooooo`005?ooool00ol0003oooooooooo`19ooooo`0:o`2KoomY0?ooj03oool0Uooo
06goo`0lool0<?oo02Coo`00ool01P;oo`0B01goo`1Qool04_oo00Koo`00ool03?oo02Coo`1Wool0
<?oo04koo`1]ool0/?oo09OonP3oool0_?oo0=CobP3oonP0oomk0?oo?P3ookP0oome0?oo00Cooh40
oolJ0?ooE`3oo`10oomY0?oo0=Soo`0Xo`04obH0o`05o`3om_lV0?oo9P3oobH0ool0od`00ol0ooH0
4ooooooo02SoofT0ool0oe;ooooooeL0oon10?ooM@3oooooool0D_oo0?n3okP0oonb0?oo0<cooed0
oomMo`3o6P3ooooooooX0?l00_ooool01?l0o`[oooooooooooooool2okSo0004o`23oonho`3o00[o
okSo00?ooooo00Co0?lXog/0ool0obSo01co0oo:0?l4ooooo`03o`3Nool0oeoooooo00;o803o1_oo
ool5o`3odP03oooooome0?ooM@3o00Oooooo00?o0?m<ok80oonb0?l00_nb0?l4ooooo`Coo`2l00Co
08ooool0l_oo0?;oo`3b0_l0@?l2ooooo`;o0>Co1_ooool3ofl0o`Cooooo1_lno`000oln0?ooo`2l
ool0_008ool0_0Oo/_l01_l0m_l2ooooo`03o`3oIOl0[_oo0:ko00Co0:ko3Oooool<ool0lQ?ooooo
0ol0ogLGonP0o`?o8?l04_ooool?o`1mobco00Co1_oooolBo`3oUCGooooo5om_0?lgooooo`005?oo
ool00ol0003oooooooooo`1:ooooo`0[oeL0ooo:0?ooo`2Gool0Oooo04koo`0`ool09?oo00coo`00
ool01_l0`?ooo`0Bool01_oo003oo`0<ool0Fooo02Coo`0`ool0??oo04koo`1]ool0/?oo09Ooo`2l
ool0e?l08_oobP3oonP0ool20?oo^03oob00oome0?oo00Cooh40oomG0?oo043oofT0ool0l?oo02So
obH0ool0om;o0<coo`3omP05ooooo`0HobH0ooooooooooooooooool0ooKoooooo`0XoomY0?oo0?mB
oeL0oon10?oo0?mOogD0oooooooo05;ookP0oonb0?ooMOl0o`3<oomM0?ooGOl0oaX0ooooooooj03o
0_ooool00ol0o`[oooooooooo`03ooooo`03o`23oooooooo00[o00?ooooo00?o__l0oooooomk0?l0
1?l0obP3olX0o`03o`3Noooooooo0?mO00?ooooo0olP0?l3ooooo`03o`3o]?ooooooEol000;ooooo
00?oM@3oo`3od_l0om801Oooool3ok80o`Sooooo00Co0?o`o`2?ool0Sooo0?mI1ooo0;`00ol0@?oo
ooooooooo`02o`3To`Gooooo0_lno`03ofl0o`03ocko0?oooooooooo00Goo`2l0oooool4och0o`Go
oooo1Ol0m_l4ooooo`Go0:ko0_nbo`0Aool0lPcooooo1om_o`03o`3oM`coj03o6_ooool7ob3o00co
0?ld6?oooolRo`1moaSooooo2ol0oiDHoooooa;oK`3o5?oooolUo`1moaGooooo000Dooooo`03o`00
0?oooooooooo04[ooooo00So013ookP0oooo0?;oo`2Gool0KOoo03coo`0`ool090;oo`000_oo00H2
ool0000Mool0Fooo02Coo`18ool0<?oo03coo`1iool0KOoo09OonP3oool0_?oo0=CobP3oofl0oooX
0?oo?P3ookP0oome0?oo00Cooh40oolJ0?ooE`3oofT0ool0l?oo02Soo`1BoolV0?oo0<coo`3om_oo
ool01?l0=?l00ooooooo08ooobH0o`02ooooo`0Do`3om_oooooo02SoofT0oolno`3o0?mBoh40ool0
oeooM@3oooooool0g_oo05;ookP0oonb0?oooooooed0oomMo`3o6P3ookko0?oX0?l3ooooo`03o`3o
2_oooooooooo00?ooooo0_l0Pol01ol02_oooooookko0?oooooo01cooooooomk0?l01?ooool00ol0
obSo0=koolX0o`02olX0o`?o0?lX0oooool2ob00o`06ooooool0okCooooooeOo0?ooooooM@3o0ooo
ool2o`3odP?o/P3o2_ooool2o`2?o`Cooooo0_l0oeT4oooooa;oo`2l00?oK`3oooooooooool02Ooo
ool3och0oa;oo`3b1?ooool4o`3oI@go/_l04_oX0?l2ooooo`_oKol05Oooool;o`3o=0?ooooo2olP
o`0hoooooc3o07go2om_0?lVo`1moc[ooooo000Dooooo`?o0000B_ooool02_l04?ooJ@3oonP0oooo
09Ooo`1]ool0C_oo033oo`0Tool0E?oo00`3ool0000Kool0Fooo04;oo`0Tool0<?oo03coo`1>ool0
KOoo0;3oo`2GooX0oooo0;coo`3DolX0oooX0?ooN`3ookP0oome0?ooG@3oo`04oon10?ooE`3oo`10
oomY0?oo02Soo`1BoolV0?oo0<co00?o03Co0oooool2o`0do`03ooooool0Sooo9P3o00;ooooo01Co
0?ofoooooomY0?ooEol0o`3oD_mG0?ooP@3oogD0oolho`3o0=kooooooonh0?oo/P3oogGo0?mM0?oo
0?o<oego0?lJ0?oo__l0onP0o`;ooooo00?o0?l:ooooooooool01Oooool01?l0Pooo00[oooooool0
7?l2ooooo`03ogGo0?mk0?ooN`3o00?ooooo00Co0=koo`3oGooooooooooo0oo:0?l5o`3o:0?o803o
00?oooooogD0ooooool00_ooool3ok80o`04ooooool0om;o0?oBo`3odPOooooo00?o0?o`o`2?oooo
ool01oooool2o`3oF@03oooooolno`3o?_l000;o?_l07_oo0?800ooooooo?P3ooch0o`03och0o`03
o`2^oooooooooooo013ooooo3_oX0?l5o`3oM`?ooooo5onbo`0:ofoo00_o0?ld00?o>?l0ok;o0?nb
o`005_nbo`0:ob3o00So/_l0AOoooolAofl0o`Gooooo4Ol0oiEEooooo`005?ooool00ol0003ooooo
ooooo`1:ooooo`0:o`2KoomM0?ooj03oool0l_oo07ooo`1]ool0??oo033oo`0Tool0E0;o>03o01co
o`1Kool0E?oo02Coo`18ool0<?oo03coo`1>ool0KOoo0;3oo`2Gool0_?oo0=CobP3oofl0oooX0?oo
?P3ookP0oome0?oo0?lFoh40oolJ0?ooE`3oofT0ool0l?oo02SoobH0ool0c?oo03Co2?ooool01?l0
=?ooooooo`2?oolV0?l2ooooo`0Co`3om_l0oc[oJ@3oocko0?mG0?ooP@3oo`3oGome0?ooooooo`3N
oonh0?oo/P3oogGo0?ooooooG@3oo`3oc?lJ0?ooooooonP0o`03ooooo`03o`3o2_oooooooooo00Co
oooo00?o__l0o`23ool02_l00_ooool02Omeo`3oooooooooooooooooN`3oooooool0g_ooooooo`3o
G`05ooooo`?obP3o00Ooooooo`3o]?ooooooEol0oooooome0?oo803o00;o0?lX00Go/P3oo`3o:?oo
ooooooooo`3oC003ooooo`;o0?oB1?ooool2o`2?o`Oooooo1?lno`03o`3oF@Cooooo0_l0@?l3oooo
o`;o0>Co3Oooool6ofl0o`03ooooool0[_oo0:ko00?o0:ko0_ooool6och0o`Sooooo1OoX0?l4oooo
o`Oo0?mg8_ooool:o`3o=0Co>?l01om_o`0Lo`0do`Oooooo2?lPo`0^ok;o01OoK`3o9oooool;o`3o
UBOooooo00?oHol0och0ooln0?l02oln0?lEooooo`005?ooool00ol0003oooooooooo`1;ooooo`09
oeL0ooo:0?ooo`3bool0Uooo06goo`0lool0<?oo02Coo`1K00?oo`1D01coo`12ool09?oo033oo`0l
ool0C_oo07Woo`1]ool0Uooj0?ooo`2lool0e?o:0?oo01KoonP0ooln0?oo^03ooed0ool01?ooP@3o
oeL0ool0@?ooJ@3oo`0XoolV0?oo0?oBo`3<ool0=?oooooo1_l04?l2ooooo`03o`0dool0Sooo9P3o
00?ooooo01?o0?ofofT0oolno`3o0?mBoh40ool0oeooM@3oooooool0g_oooooookP0oonb0?ooMOl0
oed0ool07?oo0?o<oaX0oonO0?ooj03o00?ooooo00Co0?l:oooooooooooooooo0_nno`000ooooooo
01coo`23o`02o`0:o`Gooooo0_mk0?l00ol0oeooooooooooo`07ooooo`?obP3o00CoooooogD0oooo
oooooooo0_nb0?l2ooooo`03o`3o:?l0odco0?lX00Gooooo00Co0?oBoooooooooooo08oo1?ooool5
ocko00Oooooo0_l0oeT4ooooo`;o043o0oooool2o`3To`Wooooo0ol0m_l2ooooo`?o0:ko1Om_0?l8
ooooo`Woj03o0_ooool7o`3oM`Gooooo1?l0ofDFoooooago03Co;?mY0?lGo`0doaSoK`3o5ooooolC
ok;o01ooHol04_l0oiD4of?o01;o?P3o8_ooool001Cooooo00?o0000ooooooooool0Boooool09ol0
4?oo^03oonP0oooo09Ooo`1oool0C_oo03coo`0`ool09?oo04;oo`2Sool0@_oo02Coo`0`odCo0?oo
03coo`1>ool0KOoo0;3oo`2GooX0oooo0;coo`3DolX0oooX0?ooN`3ookP0oome0?oo>?l0oh40oolJ
0?ooE`3oofT0ool0l?oo02SoobH0ool0c?oo03Coo`3o8P02o`0@o`;ooooo0_l0ob801ooooooo013o
oooooooooooo03Coo`2?oolV0?l00_ooool04ol0ooKo0?ndofT0oolno`3oP@3oo`3oGome0?oo>?l0
o`3Noooooooo^03ook80oomeo`3oG@3oo`3<ool07?oo6P3ooooooooX0?l01?nno`000ol0o`[o__l0
okko0002ooooo`03o`0Loooooooooooo00;o08?o00?o00[oooooooooool00_ooool00ol0g_oo0?mO
og/0o`02og/0o`Oooooo00?o0?ndoeOo0?ooool00oo:0?l00onb0?ooooooooooo`02ob00o`03o`3o
C?oooooooooo00?o0?lX0oooool2o`2?o`03oooooolno`3o?_l000;o?_l03_ooool2o`3oF@Cooooo
00?o043oooooooooool00_ooool2o`3To`Gooooo0_l0m_l3ooooo`;o0:ko1oooool9onP0o`03ofl0
oooooooooooo00?ooooo1_ln0?l?ooooo`Co0?mU0oooool?o`0do`03o`3o=?mY0?ooJ@3o01[oJ@3o
5ooooolAofoo00Cooooo1_mY0?lAofl0oa_oJ@3o;?l0=?lGooooo`go/_l03?ln0?lCo`3oUB7ooooo
000Dooooo`03o`000?oooooooooo04_ooooo00Wo013oofT0oooX0?ooo`2lool0Uooo06goo`0lool0
<?oo06L00ooo02@06ooo06Ooo`0`ool0??oo04koo`2fool0KOoo0;3oo`2Gool0_?oo0=CobP3oofl0
oooX0?oo?P3ookP0oomM0?ooP@3ooaX0oomG0?oo07goofT0ool0:?oo9P3oo`3<ool0=?oo0?lRo`0@
o`06ooooo`03o`3o8_oooooo013o00;ooooo00?o03CoobH0ooooool00_ooool04_l0ooKoJ@3oocko
0?mG0?ooP@3oo`3oGome0?ooooooo`3Noonh0?oo/P3oogGo0?mM0?oo0<coo`0LoolJ0?ooGOl0onP0
o`Gooooo00Co0?l:oooooooooooo01co0_ooool01?meo`3oooooooooool0Pol2o`0:o`04ooooool0
g_ooooooo`3oG`?ooooo0_mk0?l4ooooo`05o`3o]?mGo`3ooooooooooome0?l00_nb0?l3olX0o`;o
oooo0_lP0?l4ooooo`;o0?lX00Co08ooo`3ol?lno`3o0?oB5?ooool2o`3oF@?ooooo0_l0@?l4oooo
o`?o0>Co0_l0m_l3ooooo`;o0:ko1?ooool5onP0o`[ooooo2?m_0?l3ooooo`Wo?P3o00?oooooo`0d
ool0=?l02_l0=?l@ofT0od?ooooo2om_0?l00om_o`3oooooooooo`08ooooo`So8?l04_ooool7of?o
04OoJ@3o2Oln0?lQo`0do`[o0?nE5Oooool001Cooooo00?o0000ooooooooool0Boooool09_l0Vooo
G@3oolX0oooo0?;oo`2Gool0KOoo04koo`0lool0<?oo06Ooo`1cool0Iooo033oA?l0ool0??oo04ko
o`1iool0KOoo09OonP3oool0_?oo0=CobP3oo`0FoooX0?oo?P3ookP0oomM0?ooP@3oo`2EoomG0?oo
0?nKofT0ool0:?oo9P3oo`0dool0ob;o013o1_l0oo002?l0ohooooooo`3o8_oooooo013oooooool0
=?oo9P3o0oooool04ol0ooKoJ@3oocko0?l0oe;oP@3oo`3oGome0?oo>?l0o`3Noooooooo^03ook80
oomeo`3oG@3oo`3<ool07?oo6P3ooego0?oX0?l01Oooool01Ol0o`[o01coooooooooooooMOl000Co
oooo0_l0Pol00ol02_ooooooo`3oG`06ooooo`;oN`3o0_ooool01Ol0okCoEol0oooooome0?oo/P3o
00Gooooo0_o:0?l2ooooo`03ob00oolno`3o?_l000;o?_l000?o08ooo`3ol?l0obP00_ooool2o`3o
dQCooooo0_l0oeT3ooooo`;o043o0_ooool2o`3fo`04ooooool0i?oo0>Coo`3To`;o0:ko00?ooooo
onP0oooX0?l00ooX0?l;ooooo`Co0?mg2?ooool=ofl0o`03och0oomY0?ooJ@3o00WoJ@3o00?o0?ld
o`3oIOl0ofD00_l0ofDloooooa;oK`3o3?ooool<ofoo00KoHol01olPo`0;of?o02oooooo5oln0?l8
ooooocCoJ@3o5Oooool001Cooooo00?o0000ooooooooool0C?ooool01omG0?oo^03oool0l_oo0;3o
o`1oool0KOoo03`00_oo03006ooo04Soo`0`ool0<?oo03coo`2Mool0C_oo06goo`2`ool0Uooj0?oo
o`2lool0e?o:0?ooj03oog/0oonh0?ooM@3ooh40oolJ0?ooE`3oo`1moomY0?oo02SoobH0ool0c?oo
03Coo`0@o`02o`3ol00>o`3oa_l0;_oo02koo`0^ool0olKo0?o`o`3oSooooooo0?lRooooool04?oo
ooooo`0doolV0?l2ooooo`0Co`3om_l0:?ooJ@3oocko0?n10?oo0?mOogD0oolho`3o0=kooooooonh
0?oo/P3oo`3oPomM0?ooooooo`3<oolJ0?oo01coonP0o`05ooooo`04o`0Lool0o`[o0?l:ogGo00Oo
oooo00Co08?oo`0:ool02_oo00[o1oooool2og/0o`04oeOo0?ooooooM@3ook80o`Kooooo00Go0?m<
ooooooo:0?oobP3oocko0002ob00o`03ooooool0Sooo0?o`00;ooooo0_l0obP2ooooo`03o`3od_oo
oooooooo01?ooooo0ol0oeT2ooooo`;o043o1?ooool5onP0o`gooooo0ol0ogL:ooooo`Ko03Co0_oo
ool7ofT0odgoK`3o6?oooolBof?o00coKol000?oooooob3o0?lPo`002?lPo`0HoooooaSo?P3oJ?oo
ool001Cooooo00?o0000ooooooooool0C?ooool02Ol04?ooP@3oonP0oooo0;coo`2Gool0KOoo04ko
o`0lodCo0002ool0<00Joh7o0?oo03coo`1>ool0NOoo06goo`2`ool0Uooo0;coo`3DolX0oom_0?oo
j03ooch0oonh0?ooG@3ooh40oomG0?oo00[oo`3oVomY0?oo9P3oo`3om_l0=?oo013oo`3ol?l0olH3
o`0^o`;ooooo0_l0;_l02?l0oo3o0?o6ooooool0ob;oooooo`0@ool0=?oo9P3o0oooool03Ol0ooKo
J@3oocko0?mG0?ooP@3ooooooome0?oo>?l0o`3Noonh0?oo05;ook80oomM0?l00_ooool01?l0c?oo
6P3oo`0LoooX0?l4o`0Lo`?ooooo00?o0?l:ooooooooool01?ooool00ol0g_ooooooo`23o`02o`23
o`?o00[o1Oooool01?l0okCoN`3oog/0oonb0?l6ooooo`03o`3oC?ooooooj03o00?oj03o00CobP3o
oooooolP0?oo0?o`1Oooool00ol0obSoooooooooo`02o`3odQKooooo0_l0m_l2ooooo`Coj03o1Ooo
ool3o`3To`Oooooo0ol0ogL7ooooo`;o03Co3?mY0?l3ocSo00Ko0?ld2oooool:och0o`?o0?mU@?oo
ool;of?o01kooooo2om_o`000olPo`3o?P3ooch0o`0Eoch0of3ooooo2oo:0?lEooooo`005?ooool0
0ol0003oooooooooo`1<ooooo`0Vo`0@oomY0?ooj03oool0_?oo09Ooo`1]ool0C_oo03co0=;ooh7o
0?l0d_ooo`0lool0WOoo04koo`1]o`P0oooo09OonP3oool0_?oo0=CobP3oo`0FoooX0?oo?P3ookP0
oon10?oo6P3ooeL0ool0@?ooJ@3oo`0XoolV0?oo0<coo`0dool04?oo0?o6o`0^ooooool6o`1Io`;o
02ko0_ooool01?l0ob;o013oo`0doolV0?l3ooooo`0>o`3om_mY0?oo0?ljoooooon10?oo0?mOogD0
oolho`3o0=kooooooonh0?oo/P3oo`3oPomM0?l2ooooo`05oaX0ool0olcoW`3oonP0ool07?l01?oo
ool00omeo`3oooooo`3o2P05ooooo`03o`3Noooooooo0?mO00;ooooo0ol0Pol2o`0:o`;ooooo00Co
0?ndoooooooooooo/P3o0_mk0?l8onP0o`;ooooo2OoX0?l2ooooo`;o0?lX0_ooool00ol0om;ooooo
ooooo`0Aooooo`;o0?Ko1?oX0?l00ol0[_ooooooooooo`02o`10o`Oooooo0ol0i?l01?oooooo0?mg
o`3oMol0ogL4ooooo`?o03Co1OmY0?l00ooooooo>?l0ocSo0005ocSo0003ooooool0ocCo0?ld00Co
0?ld6ooooolEoch0ob;ooooo3?mSo`0NoooooaOo?P3o1_ooool4ofoo00co8?l000?oKol0oooooooo
ool0B?oooolFolX0ob3ooooo000Dooooo`03o`000?oooooooooo04cooooo00So05Wooed0ooo:0?oo
o`3bool0/?oo07ooo`1]ool0CP?oo`0l0_oo04h05ooo097oo`1]ool0/?oo09OonP3oool0_?oo0=Co
bP3oonP0oomk0?oo^03oogD0oon10?ooE`3oo`0:ool0oh?oJ@3oobH0ool0c?oo03Coo`0@ool0olKo
02ko00?o05Wo1?ooool2o`1Io`08o`0^ool0olKoooooo`3o8_oooooo013oo`2?oolV0?l3ooooo`0=
ofT0ool0oc[o?_l0oh40ool0oeooM@3oooooool0g_oooooookP0oonb0?oo0?n3oed0o`02ooooo`04
oaX0ooooooooW`3oonP0o`Cooooo00CoMOl0oooooooooooooooo0_l0o`X2ooooo`03o`3Noooooooo
0?mO00Kooooo0_l0Pol2o`0:o`03o`3o]?oooooo/P3o00?oj03o0_mk0?l00ooooooo0?m<ocko0006
ooooo`06o`2?ool0oo3oooooolX0oooooooo803o0_ooool7onP0o`;o0?oB3_ooool5onP0o`04oooo
ool0[_oo0:koooooo`;o0?mI0oooool3o`10o`Gooooo0_l0ogL3o`3To`04ooooool0=?oo03Coo`0d
o`CoJ@3o1_lho`03ooooo`Go0?ld:Oooool4o`3oI@WoooooC?ln0?l]ooooo`co8?l0:?oooolGolX0
ocKooooo000Dooooo`?o0000C?ooool01ol0VoooE`3ookP0oooo0?;oo`2`ool0Uooo06d00_oo04h2
ool0Q@0Iool0C_oo0;Koo`1iool0KOoo0;3oo`2Gool0_?oo0=CobP3oofl0oooX0?oo?P3ookP0oomM
0?ooP@3ooeL0ool0@?ooJ@3oo`0XoolV0?oo0<coo`0dool04?oo02koo`1Io`09ooooo`08o`1Iool0
;_oo0?o6o`3o8_oooooo013oo`0doolV0?l3ooooo`0=ofT0ool0:?oo?_l0oeL0oon10?ooM@3ooooo
oolho`3o0=kookP0oooooooo/P3ooed0o`02ogGo0005oooooolJ0?ooHol0oil0oooX0?l00_ooool0
0omeo`3oooooooooo`04ooooo`05o`3o2_l0g_ooooooooooool0oel02Oooool01?l0Pooo00[ook80
oooX0?l5ooooo`;oN`3o1_ooool00ol0Soooooooo`3ol002ooooo`;obP3o00?o803oooooooooool0
1Oooool00ol0obSoj03oonP0o`0>onP0o`;o0?Ko0_ooool2o`2^o`Gooooo0ol0oeT3ooooo`;o043o
0ol0ogL3ooooo`?o03Co0omY0?l3ocSo00Cooooo1_l0oc@booooo`Go0?mU3_ooool<of?o06oooooo
2_lPo`07ofoo01OobP3o:oooool=o`3o8QGooooo000Dooooo`03o`000?oooooooooo04gooooo00So
9P3ooh40oooX0?ooo`2lool0Uooo06goo`1iool0h0;oo`1>01Wom03oool0NOoo06go203oool0Uooj
0?ooo`2lool0e?o:0?oo01KoonP0ooln0?oo^03ooh40oomG0?oo00[oo`10oomY0?oo9P3oo`3<ool0
=?oo013oo`0^oooooooo05Wo00Wooooo00Wo05Woo`0^ool0ocCo0?o6o`3o8_l04?oo03Coo`2?oolV
0?l00oooool03OmY0?oo0?ljoooooon10?ooM@3ooooooolho`3o0=kooooooonh0?oo/P3oo`3oPomM
0?l00_meo`001?lJ0?oo0<cooil0oooX0?l2ogGo00Sooooo00?o0=koo`3o2_l0oel02Oooool01OmG
o`3o0?ndonP0oooX0?oo08?o00;o00[o0_ooool00olno`3o0?m<ooooo`02og/0o`?ooooo00?o08oo
ooooool0oo001Oooool00oo:0?oo803oooooo`07ooooo`;o0?lX0_l0om89ooooo`;o0?Ko0_ooool2
o`2^o`[ooooo0_l0oeT3o`3oM`;o043o00Co>?l0o`0dool0=?oo03Co0omY0?l2ooooo`?o0>Co1Ol0
oc@mooooo`Co0?mU2_mSo`1foooooaKobP3o00?o8?l0ofoo0?m_o`003om_o`0IoooooaOo0?lR8_oo
ool001Cooooo00?o0000ooooooooool0COooool08?l04?ooP@3oonP0oooo0;coo`2`ool0Oooo06go
o`2Aool0h?od0?ooo`1iool0ZOoo06goo`2`ool0Uooj0?ooo`2lool0e?o:0?ooj03oog/0oonh0?oo
M@3ooh40oomG0?oo043oofT0ool0:?oo9P3oo`0dool04?oo02ko0_l0FOl;ooooo`08o`1Iool0;_oo
0?o6o`3o8_l04?oo03Coo`2?oolV0?l3ooooo`0DofT0ool0oc[o?_l0oh40ool0oeooM@3oooooool0
g_oooooookP0oonb0?oooooooed0ooooooooMOl0oaX0oomeo`3o0<cooil0oooX0?l8ooooo`04o`3N
ooooooooooooo`3oG`So0?l:0ooX0?l00ome0?ooooooooooo`02ooooo`;o00[o00?o0?m<oooooooo
ool00_ooool2og/0o`03ooooool0Sooo0?o`00Oooooo0_o:0?l9ooooo`;o0?lX0_l0om86ooooo`03
o`3foooooooooooo00;o0:ko2Oooool2ocSo00?o0?mg0ol0oeT3o`0do`?oJ@3o1?ooool4o`3o=0?o
0>Co>?ooool:of?o0003ooooool0ofGo0?mU00?o0?mUHooooolHolX0oaOooooo1olPo`0:ooooo`Oo
Kol04_l0ob8iooooo`005?ooool00ol0003oooooooooo`1=ooooo`06o`0@oomY0?oobP3oool0l_oo
0;3oo`2G0_oo06d2ool0N@;oo`1]01Co203oool0UonC0?ooo`2lool0e?l07?oobP3oonP0ooln0?oo
^03ooed0oon10?ooE`3oo`10oomY0?oo9P3oo`3<ool0=?oo013oo`0^o`kooooo00Oo02koooooool0
olKoooooo`0@ool0=?oo9P3o00?ooooo00goJ@3oo`0Xoolno`3oP@3oo`3oGome0?ooooooocSo0?l0
g_oo^03ooooooonb0?ooG@3o00?ooooo00Go6P3oo`3<oonO0?ooHol0onP0o`07ooooo`03o`3Noooo
oooo0?mO00Oooooo0_oX0?l01?mGo`3o/P3oo`3o2_me0?l5o`3o2P03o`3oC?l02_oo00[o00;o0?l:
0omSo`02og/0o`GoHol01Oooool2olX0o`Wooooo0_l0obP01?l0om;oooooooooooooool2o`3fo`;o
oooo00?o0:koooooooooool00_ooool7ocSo00;o0?mg0oooool3o`0do`03o`3oFOmY0?ooJ@3o00;o
oooo0_l0@?l3o`3o=0Oooooo0ol0i?l]ooooo`SoHol04?ooool5o`3oIDOooooo5oo:0?lfooooo`Go
8?l03?l0ob84oooooa;oKol0=Oooool001Cooooo00?o0000ooooooooool0COooool01ol0FOooG@3o
okP0oooo0?;oo`2lool0Uooo0:T01?oo06d05Ol80?ooo`2`ool0Uooj0?ooo`2lool0e?o:0?ooK`3o
onP0ooln0?oo^03ooh40oomG0?oo00[oofT0ool0:?oo9P3oo`0dool04?oo02koo`1Io`04ooooo`?o
0?o01oooool01ol0;_oo05Woo`3oa_l0ob;o013oo`0doolV0?l00oooool03_mY0?oo02Soo`3o>_n1
0?oo0?mBogD0oooooooo>?l0o`3Noooooooo^03ook80ool0oh?oG@3o0_ooool01_lJ0?ooooooo`3<
oonO0?ooHol0onP0o`Gooooo00Co0=kooooooooooooo0?mO1Oooool2onP0o`05oooooomGo`3o0?nd
ok80oome0?l00omSo`001_lno`3oHol0ooooool0odcoooooo`23o`;o00[o0_l0o`X01?l0Sooo>?l0
o`3ol?mk0?l;ocSo0003olX0oolho`3o>?l000So>?l000Co0?lXo`3od_l0m_oo0?Ko0_lho`02o`2^
o`Go>?l01Oooool2o`3oM`?ooooo0_l0=?l01?ooooooJ@3oofT0oomY0?l2ooooo`;o0?mI0_l0oc@3
o`10o`[ooooo1?l0i?lRooooo`OoHol07Oooool4o`3oIC7ooooo4_o:0?m1oooooa7o0?lR1Oooool;
ob3o01;ooooo4Om_o`04ooooo`_o0?mm5Oooool001Cooooo00?o0000ooooooooool0COooool02?l0
VoooE`3ookP0oooo0?;oo`2lool0Uooo0<Soo`2Y0_oo07l05Ol80?ooooooool0/?oo09OonP3oool0
_?oo0=CobP3ooil0oooX0?oo^03oogD0oon10?ooE`3oo`10oomY0?oo9P3oo`3<ool0=?oo013oo`0^
o`03ooooo`;o0?o00ol0ogd2o`3o`0Kooooo00Oo02koo`3oa_l0ob;o013oooooool0=?oo9P3o00;o
oooo00KoJ@3oo`0Xool0oc[ooooooh40oome0?l2ooooo`06ocSo0?l0g_oo^03ook80ooooooooG@3o
0oooool01_lJ0?oooooooil0ool0olcoGOl0onP0o`?ooooo00Co0=kooooooooooooo0?mO1?ooool2
onP0o`;ooooo00GoEol0oooooonb0?ooM@3oof?o0003ooooo`03ocko0?oooooo0?m<00;ooooo0_lh
o`001Ol0Pooo00[oo`0:oooooooo0?o`00;o0?l:0_mk0?l7ooooo`?oHol00_o:0?l9ooooo`03o`3f
ool0obSo0?oB00;o0:ko2Oooool3o`3oM`?ooooo0_l0=?l3ofT0o`?ooooo0ol0oc@01?oooooo0?mI
o`3oFOl0oeT2ooooo`?o043o2oooool3o`3ToaGooooo2_mSo`0Xooooo`Go0?mU8Oooool;olX0od7o
oooo4_l0ob8Qooooo`_o8?l01_oooolFo`3oO@KoKol06_ooool001Cooooo00?o0000ooooooooool0
C_ooool01olV0?ooP@3oonP0oooo0;coo`2`ool0Uooo0<P00_l80?l05Oooooooo`38ool0UonC0?oo
o`2lool0e?l07?oobP3oonP0ool20?oo^03ooed0oon10?ooE`3oo`10oomY0?oo9P3oo`0dool04?oo
05Woo`0^o`02ooooo`03o`3o`?l0oggo06_o00Co06_o00?o0?mmo`3o`?ooool01?ooool01ol0FOoo
02koo`3oa_l0ob;o013oo`0doolV0?l00oooool01OmY0?oo02Soocko0?n10?ooM@3o00;ooooo00Ko
>?l0o`3Noonh0?oooooook80oomM0?l3ooooo`07oaX0oooooooo0<cooil0ool0olcoGOl0onP0o`02
ooooo`04o`3Nooooooooooooo`3oG`;ooooo0_oX0?l3ooooo`05of?o0?mGo`3o/P3oo`3o]?me0?l0
0oooool01?lno`3oooooo`3oC?ooool2ocSo00?ooooo00Co08ooo`23ool02_oo00[o0_ooool2o`3o
2P03og/0oooooooooooo00Oooooo00CoHol0ob00ooo:0?ooHol01_ooool01?l0m_ooooooo`2^ool0
[_l2o`3odPOooooo0_l0ogL4ooooo`04o`0doomY0?ooJ@3oofT0o`Cooooo0_l0oc@7ooooo`;o0?mI
0oooool3o`10o`_ooooo0ol0i?l6ooooo`coHol0=oooool5o`3oI@[ooooo4_o:0?m1ooooo`_o0?lR
;OoooolGo`3oO@Go8?l05oooool5ofoo01Gooooo000Dooooo`03o`000?oooooooooo04kooooo00Ko
013ooh40oooX0?ooo`2lool0/?oo09L2ool0b00EoonY0?oo0<Soo`2`ool0Uooj0?ooo`2lool0e?o:
0?ooK`3oonP0ooln0?oo^03ooh40oomG0?oo00[oofT0oolV0?oo0<coo`0dool04?oo02ko00;ooooo
00Co0?o0o`3oOOl0Jooo06_o1Ol0C?l00ol0oggo0?o0ooooo`04ooooo`06o`0^ool0olKo0?lRo`0@
ool0=?oo9P3o0oooool03_mY0?oo02Soo`3o>_n10?ooooooogD0oooooooo>?l0oooooonh0?oooooo
ok80ooooooooG@3o0_ooool01OlJ0?oooooooooooonO0?oooooo00;o0?o<2?oX0?l3ooooo`;oHol0
00CoEol0oooooonb0?ooM@3o0oooool01Olno`3oooooocSo0?l0odco>?l000Cooooo00Ko08oooooo
ool0oo3oooooo`23ool02_l4ooooo`;oN`3o2Oooool00olP0?oobP3oolX0o`04of?o0003o`3foooo
oooo0:ko00Cooooo00?o0?oBo`3o:?ooool00_ooool2o`3oM`Cooooo0omY0?l4ooooo`?o0?ld2ooo
ool3o`3oF@?ooooo0ol0@?l;of?o00?o0>Co0omSo`10oooooa;obP3oAoooool<o`3o8RKooooo4_l0
ogdLooooo`co8?l09Oooool001Cooooo00?o0000ooooooooool0C_ooool02Ol04?ooJ@3oolX0oooo
0?;oo`2lool0/?oo09Oo04Koool0b002ool0U`0FooX0ooo40?ooo`2lool0e?o:0?oo01KoonP0oonb
0?oo^03ooh40oomG0?oo043oofT0oolV0?oo03Coo`0@ool0FOoo02koooooool0oggo0?o0o`1[o`;o
04co1?ooool01?l0ogOo04coo`3oOOl0ol04ooooo`06o`0^ool0olKo0?n?o`0@ool0=?oo9P3o0ooo
ool01_mY0?oo02Soo`3o>_n10?oo0?mBogD0o`;ooooo00Ko>?l0o`3Noonh0?oo05;ook80oomM0?l3
ooooo`04oaX0oooooooo0<cooil0o`;ooooo00Go0?o<o`3NoomMo`3oHol0o`3oG`06of?o00;ooooo
00?oEol0ok80oome0?l00oooool01?lno`3oooooocSo0?l0od`5oego0004o`2?ooooooooooooo`3o
l0?ooooo00?o00[oooooooooool00oooool00omk0?oo0?l:ooooo`07ooooo`;o803o0_o:0?l2o`3f
o`03of?o0?l0[_ooHol000;oHol00oooool2o`3odP;o0?mg0oooool3ofT0o`Gooooo0_l0oc@6oooo
o`_oHol00_l0oeT4of?o00?o043o2oooool4o`3TocCooooo2oo:0?l>ooooo`Ko0?mU>_ooool;o`3o
8RKooooo3?l0ogdjooooo`_o8?l06_ooool001Cooooo00?o0000ooooooooool0C_ooool01ol0FOoo
G@3ookP0oooo0?;oo`2lol@0oooo0;000ooo09L04_nC0?oonP3oool0_?oo0=Co01coolX0oooX0?oo
N`3ookP0oomM0?ooP@3ooeL0ool0@?ooJ@3oo`23ool04?oo0?o`o`0^o`;ooooo00Co0?o0o`1[ool0
C?oooooo1?l0Vol2ooooo`04o`3oMol0C?oo0?mmo`3o`0?ooooo00Ko05Woo`0^ool0olKo0?lRo`0@
oolV0?l3ooooo`06ofT0ool0:?oo0?ljoh40ool0oe;oM@3o0_ooool01olho`3o0=kookP0oooooooo
/P3ooed0ool0oh<00_ooool02olJ0?ooooooooooool0c?ooW`3oooooool0g_oo0?o<ooooool0oeoo
GOl000Oooooo00CoEol0ok80ooooooooM@3o0omMo`02ocSo0003o`3oC?mMo`3ooooo00Cooooo00?o
08oooego0?l0oo000_mMo`03ooooo`03o`0:oooooooooooo00?ooooo00?oN`3oo`3o2_ooool02?oo
ool00olP0?oo0?KoolX0o`02o`2^o`Cooooo0omSo`02o`3oM`;o0?oB0omY0?l00ol0=?ooHol0of?o
0003of?o00;o0?ld2?mSo`0=ooooo`?o0?mI1?ooool3o`10o`cooooo0ol0i?lUooooo`cobP3o7ooo
ool6o`3oIBSooooo3?l0ob8Poooooa7o0?mmDOooool5ob3o01Gooooo000Dooooo`03o`000?oooooo
oooo04kooooo00Ko09_ooeL0oonh0?ooo`3bool0_?o40?l3ool0/00GoiWo0?nC0?oonP3oool0_?oo
0=Co01coolX0oooX0?oo?P3ookP0oon10?ooE`3oo`0:oomY0?oo9P3oo`3<ool04?oo05Woo`0^oooo
oooo0?o0o`3oMol0C?l00_l0Vol00ol0[_ooooooooooo`03o`2Ko`04ooooool0C?oo06_oo`3o`0Co
oooo00Ko02koo`3oa_l0ob;o013oo`0doolV0?l2ooooo`0?ofT0ool0ooKo02Sooh40oomG0?ooM@3o
o`3oGooooooo>?l0oooooonh0?oooooook80ooooooooG@3o00?ooooo00[o6P3oooooooooooooW`3o
ooooool0g_ooooooo`3oc?l0oeoooooo1_mMo`001?mGo`3oGOl0ok80oome0?l3ooooo`04ocSo0?oo
ooooooooo`3oC0Gooooo00?o08ooooooool0oo000oooool4oego0003o`0:oooooooooooo00?ooooo
00?oN`3oo`3o2_l0o`X01oooool00ol0m_oo803oo`2^o`03olX0o`Cooooo0_l0ogL01?ooooooJ@3o
ofT0oomY0?l2o`0do`04o`3o:?ooooooooooooooo`?o0?ld6_ooool3o`3oF@Cooooo0ol0@?l<oooo
o`?o0>Co5_ooool<olX0oc7ooooo1_l0ofDGooooo`_o0?lR6ooooolAo`3oOGcooooo000Dooooo`?o
0000Coooool01_mG0?ooP@3oonP0oooo0=Coo`2lol@0o`;oVOl001SoT`3oooX0oooo0;coo`3Vool0
e?o:0?ooK`3oonP0ooln0?oo^03ooh40oomG0?oo043oofT0oolV0?oo013oo`3ol?l0;_ooooooo`3o
`?l0ogOo06_oo`1<ool0[_l6ooooo`06o`2Kool0[_oo0?mgo`1<ool0Jooo0?o00oooool01_l0;_oo
0?o6o`3oSol04?oo03CoobH0o`?ooooo00KoJ@3oo`0Xoon10?ooE`3oo`3oD_me0?l2ooooo`06ocSo
0?nh0?oo0=koo`1Boonb0?ooG@3o0oooool01OlJ0?ooooooooooooooooooW`3o00;ooooo00?o0?mO
o`3oc?l0ol`01_ooool01?mGo`3o/P3ooooooome0?l2ooooo`04ocSo0?ooooooooooo`3oC0Gooooo
00Co08oooooooooooooo0?o`1oooool01?mMo`3o00[ooego0?mMo`03ooooo`04og/0oooooooo0?l:
o`3o2PCooooo00?o0?Koooooool0[_l00_lP0?l2ooooo`?obP3o00Go0?mgofT0oomY0?ooJ@3ooooo
o`02o`0do`04ooooool0om;o0?oBo`3o:0;o0?ld8?ooool3o`3oF@Cooooo0ol0@?l<ooooo`Co0>Co
1_ooool<olX0oa3oooooE_l0C?l>ooooo`co0?mmSOooool001Cooooo00?o0000ooooooooool0Cooo
ool01_lV0?ooP@3oonP0oooo0?;oo`2loi<0o`?oa03o01KonP3oool0_?oo0=Co01coolX0oonO0?oo
j03ookP0oome0?ooP@3ooeL0ool0@?ooJ@3oo`23ool04?ooooooo`0^ool0oggo0?o0o`1[ool0C?oo
oooo1_l0okX2ooooo`05o`2Koooooooo04coo`1[ool0ol000oooool01_l0;_ooooooo`3oa_l04?oo
03CoobH0o`?ooooo00KoJ@3oo`0Xool0oc[oP@3oo`3oD_me0?l2ooooo`07ocSo0?oooooo^03oo`3N
oonb0?ooG@3oo`3oP`02ooooo`08oaX0ooooooooooooo`3NoonO0?oo0<coooooool0oel2ooooo`;o
0?o<0oooool01?mGo`3o/P3ooooooome0?l2ooooo`05ocSo0?ooooooooooooooool0od`01Oooool0
0ol0Soooooooo`3ol009ooooo`03o`0:ool0Pooooooo00;oGOl00_ooool01?mk0?ooooooooooool0
o`X2ooooo`03o`3fool0[_oo0:ko00?ooooo00Go803oooooool0ogOo0?mgofT0o`03olX0o`;o03Co
0oooool2o`3o=003o`3od_oooooo0?lX00;o0?lX8Oooool2o`3oF@Gooooo0ol0@?l8ooooo`_obP3o
2OoooolCo`1<ocWooooo1Ol0ofD3o`3o8QGooooo;_l0C?miooooo`005?ooool00ol0003ooooooooo
o`1?ooooo`0Oo`0@oomY0?oobP3oool0l_oo0;conP3oo`3oj_oolP3onP3oool0_?oo0>Koo`3Do`0L
ooo:0?ooj03ooch0oonh0?ooP@3ooeL0ool02_ooJ@3oobH0ool04?oo0?o`o`0^oooooooo0?o0o`1[
ool0C?oo0:koo`3o^P05ooooo`;o0?nj0_ooool01?l0Vooo0?mgo`1<ool0ol03ooooo`07o`0^ool0
FOoo0?o6ooooool04?ooooooobH0o`02ooooo`07ofT0ool0:?oo?_l0oh40ool0oe;oM@3oo`3oG`02
ooooo`06ocSo0?nh0?oo0=kook80oomM0?oo0?n30oooool01_lJ0?oo0=koooooooooooooW`3oo`3<
o`Gooooo0ol0ol`01omGo`3o/P3ooooooome0?ooooooocSo0?lno`000_ooool00ol0odcooooooooo
o`03ooooo`04o`2?ooooooooooooo`3ol0[ooooo00Co00[oo`23oooooooooooo0_mMo`001ooooooo
N`3ooooooooooooo0?l:o`3fool0[_l01_ooool3ofT0o`;ooooo0_l0=?l3olX0o`;o0?ld0oooool2
o`3odP;ooooo0ol0obPPooooo`?o0?mI00?oooooolX0ooo:0?l02_o:0?l8ooooo`?o0>Co2Ol0C?lM
ooooogSoP@3o0_ooool_o`1<od[ooooo000Dooooo`03o`000?oooooooooo04oooooo00Ko013oofT0
oonh0?ooo`3bool0n?oo0;`2ooX0o`0Fool0_?oo0?Soo`3Do`0Rool07?oobP3oonP0ooln0?oo^03o
oh40oomG0?oo043oofT0oolV0?oo013oo`3ol?l0;_oo0?o0o`2Kool0Jooo04coo`3o^PSooooo00Oo
0?njooooool0Vooo0:koo`1[ool0C?oo0?o000;ooooo00Oo02koo`1Iool0olKo0?n?o`0@ool0Sooo
9P3o00;ooooo00OoJ@3oo`0XoomGo`3oP@3oo`3oD_me0?oo0?mO00;ooooo00[o>?l0okP0oooooooo
05;ook80oomM0?oo0?n3ooooool0g_oo6P3o1?ooool00onO0?oo0<coo`3<o`05ooooo`04oeOo0?nb
0?oo0?o<ogD0o`;o0?o<00Go?_l0ooooooooooooooooo`3oC004ooooo`04o`2?ooooooooooooo`3o
l0cooooo00?o00[oo`23ooooool00_ooool2oego0004og/0oooooooo0?Koo`2^o`;o0?l:0_ooool3
ofT0o`03oooooolP0?oooooo00;o03Co0oooool2o`3o=0KobP3o00?oooooo`3od_l0om800oooool3
o`3o:0cooooo5Oo:0?l2o`3oF@Gooooo1?l0@?l3ooooo`Wo04co0ol0i?lBoooooa7oP@3o9Oooool6
o`3o8Poooooo1Ol0ofD00ooooooo0?mmo`3oO@06o`3oOC3ooooo;On10?l4ooooobco04co7_ooool0
01Cooooo00?o0000ooooooooool0Coooool01_l04?ooE`3ookP0oooX0?ooo`3bool0e0;oo`2l01Go
g03oool0i_oo0=Co01coolX0oom_0?ooj03ookP0oome0?ooP@3ooeL0ool0@?ooJ@3oo`23ool04?oo
02koooooool0ol3o06_oo`1<ool0okX00oooool4o`3fo`?ooooo00Ko0?njo`2Kool0[_oo0?mgo`1<
ool0ol03ooooo`06o`0^ool0olKo0?n?o`0@ool0=?oo9P3o0_ooool01omY0?oo0?ndo`0Xoon10?oo
E`3oo`3oD_me0?l00oooool01Onh0?ooooooo`1Boonb0?ooG@3o00?o0=ko00WooooooaX0oooooooo
ooooo`3oGoooooooW`3oooooool0c?l01?ooool01_mGo`3o/P3ooooooome0?ooooooocko00?o0?o<
00?o0?m<ooooooooool00oooool00ol0Soooooooo`3ol00>ooooo`03o`0:ool0Pooooooo00?ooooo
00?oGOl0og/0ool0[_l00_ooool3ofT0o`05ooooool0ogOoooooooooool0=?l00_lP0?l01?oooooo
0?ldo`3o=?l0oc@8oooooaGobP3o5oooool3o`3oF@?ooooo0ol0C?l4o`10o`_ooooo1?l0i?l6oooo
o`SoP@3o;oooool7o`3o8Q?ooooo2?l0ogd4o`3oIF7ooooo>On10?lEooooo`005?ooool00ol0003o
ooooooooo`1?ooooo`07o`0@oomG0?ooP@3oonP0oooo0?;oS@3oool0e002ool0iP0Fool0e?l07?oo
0;[oolX0oonO0?ooj03ookP0oomM0?ooP@3oo`0:oomY0?oo9P3oo`0@ool0oo3o02koo`3o`?l0Jooo
0:koo`1<ool0ok[oooooo`3fo`Go08Wo00Wo0?Kooooooooooooo0?njooooool0Voooooooo`1<ool0
ol000oooool01_l0;_oo05Woo`3oSol04?oo03CoobH0o`;ooooo00SoJ@3oo`3o]?l0:?ooP@3ooeL0
ool0oe;oM@3oo`3oG`;ooooo00Oo>?l0okP0oooooooo05;ook80oooooooo0?n300;ooooo00Ko6P3o
oooooooooooo0?mOoooooonO0?l2ooooo`;o0<co00SooooooeOo0?nb0?ooooooogD0ool0okCooooo
ocko00?ooooo1Ol0ol`01?l0Soooooooooooool0oo0?ooooo`03o`0:ool0Pooooooo00;ooooo00?o
0?Kooooooomk0?l00_mY0?l2ooooo`03o`3o2_l0ogOooooo00;o03Co0_ooool00ol0ocCo803ooooo
o`0?ooooo`;o0?oB1Oooool3o`3o:1kooooo1Ol0C?l7ooooo`?o043o1_ooool<oh40oc3ooooo1ol0
ob8Booooo`So0?mm3?ooool5o`3oIGSooooo4Omk0?lQooooo`005?ooool00ol0003oooooooooo`1?
ooooo`07o`1IoomG0?ooP@3oonP0oooo0?;o0;[oo`0Lo`02ool0e00Dool0l_l07?oo0?oNolX0oooX
0?oo?P3ookP0oon10?ooE`3oo`10oomY0?oo9P3oo`0@ool0FOoo02koo`3oOOl0Jooo04coo`3o^_oo
ool3o`29o`Co0>[o00[o08Woo`3fool0m_ooooooo`3o^_oooooo09_oo`3oMol0C?oo0?o00_ooool0
1_l0;_oo05Woo`3oa_l04?oo03CoobH0o`?ooooo01GoJ@3oo`0Xoon10?ooE`3oo`3oD_me0?oooooo
o`3oGooooooo>?l0okP0oooooooo05;ook80oomM0?ooooooo`3oPooooooo6P3oooooool0oel00ooo
ool02onO0?oooooooooooooooooo0<cook80oooooooo>?l0ogD0ool0okCo?_l000?ooooo00?o0?m<
ooooooooool00_ooool01Ol0Soooooooo`3oc?l0oo3o0?o<013ooooo00Co00[oo`23oooooooo0?Ko
0omY0?l00omk0?ooGOl0oego0002o`3oM`;o03Co00Coooooo`3o=?l0ocCo0?ld0_ooool00olP0?oo
ooooooooo`0?ooooo`;o0?oB1_ooool3o`3o:1Kooooo1Ol0C?l4ooooo`?o0?mI0_ooool<oh40o`[o
oooo1?l0i?lWooooo`Oo0?lR4_ooool7o`3oOAWooooo1Ol0ofDJooooodgoGOl03?mk0?lMoego01Go
oooo000Dooooo`03o`000?oooooooooo04oooooo01oo09_ooeL0oomY0?ooj03oo`0Foooo0?;ooh/0
o`0Loooo0?;o01coo`2jooo:0?ooK`3oonP0oonh0?ooM@3ooh40oomG0?oo043oofT0ool0Pooo013o
o`0^ool0ol3o06_oo`1<ool0ok[oooooo`3fool0ROoo0>[o00Gooooo00[o0>[oo`29ool0ROoooooo
o`3o^_oooooo09_oo`3oMol0C?oo0?o00_ooool01_l0;_oo05Woo`3oa_l04?oo03CoobH0o`?ooooo
00SoJ@3oo`0XoomGo`3oP@3ooooooome0?ooooooo`3oG`;ooooo00Oo^03oooooool0D_oo/P3ooed0
oooooooo0?n300;ooooo00?o6P3oooooooooool00oooool2oil0o`08oooooomGo`3o/P3oo`3<oome
0?oo0?ndoooooolno`03ooooo`03o`3oC?oooooooooo00;ooooo00Go08oooooooooooooo0?o`oooo
o`02o`3oc0oooooo0omY0?l01?l0[_ooooooooooooooool2og/0o`;o03Co00?oGOl0o`3o=?l0oc@0
0_l0o`X4ooooo`;o803o4Oooool2o`3odPOooooo0ol0obP=ooooo`Ko04co1Oooool9oh40o`03o`3o
FOoooooooooo00Oooooo1?l0@?l<ooooo`?o0>Co7_ooool6o`3o8Q;ooooo1ol0ogdKooooo`[oGOl0
1Ol0ofDEoego04;ooooo2omk0?lnooooo`005?ooool00ol0003oooooooooo`1@ooooo`05oeL0oomY
0?oobP3oonP0ool0od000_oo0?804olDo`3o0;[oo`3og_o:0?ooQol0onP0oonh0?ooG@3ooh40oomG
0?ooJ@3oobH0ool04?oo0?o`o`0^ool0Jooo09_oo`1<ooooool00_l0ROl6o`2Qo`;ooooo00Wo0>[o
o`29ool0m_oo0?njooooool0Vooo0:koo`1<ool0ol000_ooool01ol0;_oo05Woo`3oa_l0ohoo013o
o`3oC?lV0?l00_ooool03omY0?oo02SooeOo0?n10?ooooooo`3oD_me0?ooooooo`3oGooooooo^03o
ocSo0?oooooo05;ook80o`02ooooo`03o`3oPol0oeoo6P3o00Oooooo00GoW`3ook80ooooooooM@3o
ooooo`03o`3<o`;ooooo00?o0?m<ooooooooool00_ooool01?l0Soooooooooooool0oo04ooooo`;o
0?o<2_ooool3ofT0o`03o`3fool02_oo08?o00?ooooo00?o0?mgo`0dool0=?l00_mk0?l00ol0ocCo
oooooego0002oego00?o0?l:0oooool2ob00oa7ooooo0_l0om88ooooo`Co0?lX1?ooool5o`1<o`Ko
oooo1On10?l:ooooo`;o0?mI2oooool4o`10o`_ooooo1?l0i?lEooooo`Go0?lR4_ooool6o`3oOA7o
oooo4OmMo`0?ooooo`Ko0?mUA_ooool;og/0odWooooo000Dooooo`03o`000?oooooooooo053ooooo
00KoE`3oofT0oonh0?ooj03oo`3o4?l0od02o`2jo`0Co`3og_o:0?ooK`3oonP0oomk0?oo^03ooh40
oomG0?oo043oofT0oolV0?oo013oo`0^ool0ol3o06_oo`1<ool0[_oo08Woo`3Zo`02o`2Qo`Gooooo
0_l0XOl02_oooooo0>[oo`29oooooooo0?njooooool0Vooo04coo`1[ool0ol02ooooo`06o`0^oooo
oooo0?o6o`0@ool0=?oo9P3o0_ooool02OmY0?oo0?ndo`0Xoon10?ooooooo`3oD_me0?ooooooo`3o
G`02ooooo`0:okP0oolho`3o05;ook80oomM0?ooooooo`3oGol0oh?ooooooaX0o`Kooooo00Ko/P3o
oil0ooooooooM@3oo`3o]?lno`02ooooo`?o0<co1?ooool01?l0Soooooooooooool0oo06ooooo`;o
0?o<1oooool02OmY0?oooooooooooooooooo0?Koo`2^ool02_oo08?oooooo`02o`0do`?o0?ld00?o
ooooog/0ooooool00oooool3oego00;o0?l:0oooool2ob00oa7ooooo0_l0om8:ooooo`04o`3o:?l0
C?oo04coo`1<o`Gooooo1_n10?lAooooo`?o0?mI3?ooool5o`10o`[ooooo1?l0i?l<ooooo`Go0?lR
4Oooool6o`3oOAOoGOl09_ooool8o`3oIC;ooooo3?mk0?liooooo`Ko803o5Oooool001Cooooo00?o
0000ooooooooool0D?ooool01_lV0?ooE`3ookP0oooX0?oo01Koo`3o40;o0?oN01?o0?m0olX0ooo^
o`3oj03ookP0oonb0?ooP@3ooeL0ool0@?ooJ@3oo`0@ool0=?oo02koo`1[ool0C?oo0:koooooool0
ROoo0:7o00Sooooo00_o0:7oooooool0j_oo08Woo`3fool0ok[oooooo`2Kool0C?oo06_oo`3o`002
ooooo`06o`0^oooooooo0?o6o`0@ool0=?oo9P3o0_ooool01omY0?oo0?ndo`0Xoon10?oo?_l0o`3o
D_me0?l00_ooool02_l0oeoooooookP0oolho`3o05;ooooooonb0?ooooooo`3oGol0oh<2ooooo`03
oaX0oooooooooooo00;ooooo00?o/P3ooeOo0?ooool00_nO0?l00ol0okCo?_l0ooooo`02ooooo`03
o`3oC?oooooo0<co00?o0<co00?o08ooo`3<ool0oo002Oooool2o`3oc0?ooooo0_mY0?l3ooooo`06
o`3fool0[_ooooooooooool02_oo03Co0_l0oc@5ooooo`;oN`3o1Oooool2oego00;o0?l:0oooool0
0olP0?ooooooooooo`0@ooooo`;o0?oB1oooool2o`1<o`;ooooo00?o0?lXoh40oon10?l00on10?lJ
ooooo`?o0?mI3_ooool5o`10o`Wooooo1?l0i?l3ooooo`Go0?lR1?ooool<oego00?o0?mmMOl0j_l;
og/0ob?o0>[o5oooool;ob00o`Ko0?nj5Oooool001Cooooo0ol0001@ooooo`04o`0@oomG0?oo^03o
onP0o`;o01Ko0_l0oa004_o:0?ooK`3oohOo0?oX0?oo^03oogD0oon10?ooE`3oofT0oolV0?oo013o
o`0^ool0ol3o06_oo`1<ool0[_oo08Woo`2Qo`[ooooo00[o0:7oooooool0j_oo08Woo`3o^_oooooo
09_oo`2^ool0C?oo0?o00_ooool01_l0;_ooooooo`3oa_oooooo013oobH0o`;ooooo00SoJ@3oo`3o
]?l0:?ooP@3ooeL0oooooooo0?mBogD0o`;ooooo00Oo0?mOokP0oooooooo>?l0o`1BoomM0?oo/P3o
00;ooooo00?o0?n3oooooolJ0?l00_ooool2ok80o`05oooooomGo`3oooooogD0ooooool01OnO0?l0
0ol0odcoooooooooo`02ooooo`03o`2?oooooooooooo00;o0<co2_ooool00ol0olcoJ@3oofT0o`04
ooooo`08o`3foooooooo0:koooooool0=?oo0?mgo`0:ool0Pol8ooooo`;oN`3o1Oooool2oego00;o
0?l:0_mMo`02ob00oa;ooooo0_l0om82ooooo`;o04co1_n10?l2ooooo`?o0?lX7Oooool2o`3oFA7o
oooo1?l0@?l7oego00;o0?lR1Ol0i?lFo`3ZoeGooooo1ol0ofD=ooooo`coN`3o7_ooool@o`3o^Pgo
0>[o2_lP0?lAo`3ZoaGooooo000Dooooo`03o`000?oooooooooo053ooooo00Ko013ooeL0oonh0?oo
/P3oonP0oonCo`02o`0Fo`0AolX0ooo^o`3oj03oog/0oonh0?ooG@3ooh40ool0UOooJ@3oobH0ool0
4?oo02koo`1[ool0C?oo0:koooooool0ROl02oooool02_l0XOooooooo`3Zool0ROooooooo`3o^_oo
oooo09_oo`1<ool0ol02ooooo`06o`0^ool0FOoo0?o6o`3oSol04?oo9P3o0oooool01omY0?oo02So
oeOo0?n10?ooooooo`3oD_me0?l00oooool01_l0oeoo^03oo`3oGol0D_oo>?l0ok80o`;ooooo00co
0?n3oooooooooooo6P3ook80oolho`3ooooooeOo0?ooooooM@3oooooool0ok@4ooooo`04o`3oC?nO
0?ooW`3ooil0o`;ooooo00?o08ooooooool0oo000_ooool2o`3<o`Sooooo00?oJ@3oo`3oc?ooool0
1?ooool01Ol0m_oo0:koo`0dool0=?oo0?mg00;ooooo00?o00[oo`23ooooool02?ooool00omk0?oo
ooooooooo`06ooooo`Co0?l:0_lP0?l8oego00Wooooo00?o04cooh40oon10?l00_n10?l;ooooo`?o
0?lX7?ooool3o`3oF@03oooooomMo`3oGOl000goGOl000?oooooo`3Zool0@?l01?l0@?l9o`3Zo`Go
0>Co0_ooool6o`3oOFGooooo00?o0?mUog/0oomk0?l02_mk0?lCoooooaOo0?nj5Oooool8ob00oa3o
oooo2onO0?lEooooo`005?ooool00ol0003oooooooooo`1@ooooo`0Io`0@oomG0?ooP@3ookP0oooX
0?oobP3oo`0Fooo:0?ooK`3oonP0oonO0?oo^03ook80oon10?ooE`3oo`10oomY0?oo013oo`0dool0
;_oo06_oo`1<ool0[_oo08Woo`3Zo`0<ooooo`09o`2Qoooooooo08Woo`3fool0ok[oooooo`2Kool0
C?oo06_o00;ooooo00Ko02koo`1Iool0olKo0?n?o`0@oolV0?l3ooooo`07ofT0ool0:?ooEol0oh40
oolno`3o0?mBogD0o`04ooooo`05okP0oooooooo05;oocSo0?mM0?l00onb0?l01?l0oh?o/P3ook80
oolho`02ooooo`05oeOo0?ooooooM@3oooooool0ok@01?ooool01?l0odcoooooooooooooool4oil0
o`03o`3ol?oooooooooo00;ooooo00?o0<coooooooooool00oooool2ofT0o`;ooooo00Wo0?o<oooo
ooooooooooooo`3fool0[_oo03Coo`3o=?l0ogL01?ooool00ol02_ooooooooooo`08ooooo`03og/0
oooooooooooo00Wooooo0_l0o`X2ob00o`03o`3o2_oooooooooo00?ooooo1omMo`03oh40o`;oGOl0
0_l0om8>oego00?o0?lX7?mMo`03o`3oF@;ooooo3?l0j_l4o`3o8P;ooooo2?l0@?l3ooooo`?o0?mm
1Ol0i?mNooooo`_oN`3o1Oooool3o`3oIAOo0?nj5oooool]oil0o`_o043o5Oooool001Cooooo00?o
0000ooooooooool0D?ooool06?l04?ooE`3oofT0oonh0?ooj03oofl0ooo:0?ooK`3oofWo0?oX0?oo
N`3ookP0oome0?ooP@3ooeL0ool0:?ooJ@3oo`0@ool0;_oo0?o0o`1<ool0[_oo0:7oo`29o`kooooo
00Wo0:7oo`3Zool0ROoo0?njooooool0Vooo04coo`1[ool0ol000_ooool01Ol0;_oo0?o6o`3oSol0
4?oo9P3o00?ooooo00SoJ@3oo`0Xool0ooKoP@3oocko0?oooooo0?mBogD0o`?ooooo00Go^03ooooo
oooooooo05;ooed0o`02ocSo00;o/P3o00[o>?l0oooooolJ0?oooooooeOo0?ooooooM@3oooooooln
o`3o0?nd1?ooool00ol0odcoooooooooo`02ooooo`03o`2?oooooooooooo00?oW`3o0oooool2o`3<
o`;ooooo00?oJ@3oooooooooool00oooool00ol0olcoooooo`3fo`02o`0do`03o`3o=?l0ogOooooo
00Gooooo00?o00[oooooooooool02?ooool00omk0?ooooooooooo`0<ooooo`;o803o0ol0o`X5oooo
o`?oP@3o1oooool2o`3odPoooooo0ol0obPEooooo`Wo0>[o00?o0?mIooooooooool00oooool5o`3o
8Pcooooo0ol0ogd8o`10o`?ooooo1Ol0i?m>ooooo`_oN`3o4ol0okX2ooooo`Ko0?mU3ooooolGoil0
o`Cooooo2OlP0?l7oooooaOo043o8_ooool001Cooooo00?o0000ooooooooool0D?ooool01_l0FOoo
E`3oofT0oonh0?oo/P3oonP0o`?o0=ko00ooj03ooch0oonh0?ooG@3ooh40oomG0?ooJ@3oobH0ool0
4?oo02koo`1[ool0C?oo0:koo`29ool0j_l03_ooool02Ol0XOoo0>[oo`29ool0m_oo0?njo`2^ool0
C?oo06_oo`3o`002ooooo`06o`0^oooooooo0?o6o`0@ool0=?oo9P3o0_ooool02?mY0?ooooooo`0X
oon10?oo?_l0ooooool0oe;oM@3o1?ooool01Onh0?ooooooo`1BooooooooG@3o00?ooooo00Wo0?n3
oooooooooooo6P3ooeOo0?ooooooM@3oocko0?l0ok@01?ooool00ol0odcoooooooooo`02ooooo`04
o`2?ooooooooooooo`3ol0?ooooo0onO0?l2ooooo`03o`3<oomY0?oooooo00Kooooo00Go0?o<o`0d
ool0[_ooooooo`3oM`08ooooo`03o`0:oooooooooooo00Sooooo0omk0?l=ooooo`;o803o00?ooooo
o`3o2_l0o`X00on10?l00ol0C?ooooooooooo`09ooooo`;o0?oB4?ooool3o`3o:0cooooo1_l0j_l:
ooooo`?o0?mI0_l0ob8<ooooo`Go0?mm2oooool6o`10o`;ooooo1Ol0i?lhooooo`Go0?nj3?mk0?l7
o`3o^QOooooo5onO0?l@ooooo`_o803o4?l0@?liooooo`005?ooool00ol0003oooooooooo`1@oooo
o`0Go`1IoomG0?ooJ@3ooh40oonh0?oo0P3oonP0ool20?ooj03oog/0oonh0?oo/P3ooed0oon10?oo
043oofT0ool04?oo02koo`3o`?l0Jooo04coo`2Qool0ROl03oooool02Ol0XOooooooo`29ool0m_oo
0?njooooool0Vooo04coo`3o`002ooooo`06o`0^oooooooo0?o6o`0@ool0=?oo9P3o0_ooool02?mY
0?oo0?ndo`0Xoon10?oo0?ljooooool0oe;oM@3o1?ooool01Onh0?ooooooo`1BooooooooG@3o00Co
oooo00So0?n3oooooolJ0?ooooooogD0oooooooo?_l0o`3o]0Cooooo00?o0?m<ooooooooool00_oo
ool01?l0Soooooooooooool0oo06ooooo`;oW`3o00?oJ@3oo`3<ooooool01Oooool01Ol0ocCo03Co
o`2^ool0olco0?mg00[ooooo00?o00[oooooooooool02_ooool3og/0o`cooooo00?o803ooh40oon1
0?l00_l0C?l4o`3o2P_ooooo0_l0om8Aooooo`?o0?lX0oooool6o`3Zo`_ooooo1Ol0ob83ooooo`?o
0?mI1_ooool5o`3oOAKooooo2_l0@?l3o`3Tob7ooooo2_l0okX<og/0oa?ooooo5onO0?l?ooooo`Go
0?mU2Ol0@?l:ob00o`Co043oD?ooool001Cooooo00?o0000ooooooooool0D?ooool01_l0FOoo9P3o
oed0oon10?oo^03ooil0o`;oj03o00koW`3ookP0oonb0?ooM@3ooh40oomG0?oo02SoofT0ool04?oo
02koo`1[ool0C?oo0:koo`29oa7ooooo00So0:7oo`3Zool0ROoo0?njooooool0Vooo04coo`3o`0;o
oooo00Ko02koo`3o=?l0olKoooooo`0@oolV0?l2ooooo`09ofT0ool0okCo02SooeL0oon10?oo?_l0
o`3oD_ooooooM@3o00?ooooo00Go^03ooooooooooooo05;ooed0o`05ooooo`07o`3oPomGo`3o6P3o
ogD0oolno`3oooooo`3o]003ooooo`03o`3oC?oooooooooo00?ooooo00?o08ooooooool0oo002?oo
ool01?mY0?ooW`3oooooool0c?l4ooooo`06o`3o=?l0=?oo0:koooooool0ogOo0?o<2oooool00ol0
2_ooooooooooo`0<ooooo`;oN`3o2Oooool2oh40o`03ooooool0C?oo803o00;o803o0oooool5o`3o
2PSooooo0_l0om8?ooooo`Ko0>[o00?o0?lXooooooooool02_ooool4o`3o8P_ooooo00?o0?mIo`3o
OOl0ogd00ol0ogdUooooo`ko043o2oooool9o`3o^PcoN`3o2OoooolFoil0oaGooooo5_l0@?l00ooo
oooo803oob00o`06ob00o`;o0?mU9?oooolSokP0oaGooooo000Dooooo`03o`000?oooooooooo053o
oooo00Ko09_oo`0@oomM0?ooP@3ookP0oonb0?l2oil0o`0>og/0oonh0?oo/P3ooed0oon10?ooE`3o
ofT0oolV0?oo013oo`0^ool0Jooo04coooooool0ROlAooooo`0@o`2Qoooooooo08Woooooool0ok[o
09_oo`1<ool0oggo0?o0ooooool0;_oo05Woo`3oa_oooooo013oobH0o`?ooooo00SoJ@3oo`0Xoooo
ooooP@3oocko0?oooooo0?mBogD0o`Cooooo00Go^03oooooool0D_oooooooed0o`05ooooo`05o`3o
Pome0?oo6P3oocko0?l0ok@01?ooool00ol0odcoooooooooo`02ooooo`04o`2?ooooooooooooo`3o
l0Oooooo00OoJ@3oooooooooooooW`3oooooool0c?oooooo00;o0?ld00Coooooo`0doooooooo0?mg
0_ooool00ol0olcoooooooooo`09ooooo`03o`0:oooooooooooo00gooooo0omk0?l3ooooo`?oP@3o
00?oooooo`1<ool0C?l01?ooool2ob00o`Kooooo1_l0o`X4ooooo`;o0?oB2?ooool5o`3Zo`Oooooo
1?l0obP4ooooo`Co0?lR3?ooool4o`3oO@?ooooo0ol0oeT/ooooo`Ko0>Co2?l0@?l<og/0ohGo^03o
>?ooool000Oooooo1Ol00008ooooo`03o`000?oooooooooo057ooooo01Co013ooeL0oomY0?ooP@3o
okP0oonb0?ooN`3ooch0oonh0?oo803ooed0oon10?ooE`3oofT0ool04?oo02koo`1[ool0C?oo0:ko
o`29oa;ooooo013o0:7oooooool0ROoo0?Koo`3o^_l0Vooo0:koo`1<ool0ol3oooooo`0^ool0FOoo
0?o6o`3oSol04?oo9P3o0oooool02?mY0?oo02Sooooooon10?oo?_l0ooooool0oe;oM@3o1?ooool0
1Onh0?ooooooooooool0D_ooG@3o00Cooooo00KoEol0oooooome0?oo0?n3oaX0ool0ok@4ooooo`03
o`3oC?oooooooooo00;ooooo00?o08ooooooool0oo002?ooool01omY0?ooooooooooooooooooW`3o
ooooool0c?l00_ooool00ol0=?oo0:koo`3oM`04ooooo`03o`3oc?oooooooooo00Wooooo00?o00[o
ooooooooool03oooool00omk0?ooP@3ooh40o`02ooooo`;o04co2?ooool3ob00o`Wooooo1_l0o`X3
o`3odP03ooooool0j_oo0>[o00;o0>[o4?ooool3o`3o:003o`3o8_oooooooooo00Wooooo1Ol0ogd:
ooooo`?o0?mI8_ooool8o`3o^QWo^03o0onO0?l[o`10oaSooooo2_lP0?lHooooo`Ko0?mUCoooool0
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`1Aooooo`05o`0@oomG0?oo
J@3ooh40ool0omP00onh0?l03?nb0?ooG@3ooh40oomG0?oo043oofT0ool04?oo02koo`1[ool0C?oo
ooooo`29oa?ooooo00So0:7oo`29ool0m_oo0?njo`2Kool0[_oo04coo`3o`0;ooooo00Go02koo`3o
a_l0ohoo013oobH0o`03ooooo`09ofT0ool0:?oo0?ofoh40oolno`3oooooo`3oD_ooooooM@3o00?o
oooo00Ko^03ooooooooooooo05;ooooooomM0?l3ooooo`06oeOo0?me0?oo?_l0ooooool0oh?o6P3o
0oooool00ol0odcoooooooooo`02ooooo`04o`2?ooooooooooooo`3ol0Oooooo00?oJ@3ooooooooo
ool00oooool2oil0o`04o`3<ool0=?oo0:koo`3oM`Kooooo00?o0?o<ooooooooool02Oooool00ol0
2_ooooooooooo`0<ooooo`?oP@3o0_ooool3og/0o`cooooo0olP0?l<ooooo`05o`3o2_l0j_oo0>[o
o`3Zool0om804?ooool3o`3o8P?ooooo1?l0obP4ooooo`Co0?mm4_ooool3o`3oF@oooooo6?nh0?l@
oil0o`Co0>Co?_ooool=ob00obSooooo1Ol0ofE:ooooo`002Oooool00ol0003oooooooooo`08oooo
o`Go0000Coooool04ol04?oo9P3oofT0oon10?oo0?oHokP0oonb0?oo07Ooob00oomM0?ooP@3ooeL0
oomY0?oo9P3oo`0@ool0;_oo04coo`2^ool0ROl05?ooool02?l0XOooooooo`29oooooooo0?njo`2K
ool0C?oo0?o00_ooool01Ol0;_oo0?o6o`3oSol04?oo9P3o00?ooooo00WoJ@3oo`0Xool0ooKoP@3o
o`3o>_lno`3o0?mBoooooome0?l01?ooool01Onh0?ooooooo`1BooooooooG@3o00;ooooo00_oEol0
ogD0oooooooo?_l0ooooool0okCo0?n3oaX0ool0oh?oooooo`3oC004ooooo`03o`2?oooooooo0?o`
00Oooooo00?oJ@3oooooooooool00oooool01_l0ocCooooooooooonO0?oo0:koo`3oM`Sooooo00?o
0?o<ooooooooool02Oooool00ol02_ooooooooooo`08ooooo`?oP@3o1?ooool2o`1<o`;ooooo1?mk
0?l;ooooo`?o803o1Oooool5o`3Zo`Cooooo0_l0om84o`3o2PKooooo1?l0ob8:ooooo`04o`3o:?l0
oggo0?mmo`3oOAWooooo1?l0oeT;okP0o`;o0?nj1Omk0?l@oil0oaGooooo1ol0i?l/ooooo`_o803o
>_ooool6o`3oIDCooooo000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0DOoo
ool04ol0FOoo9P3oofT0oon10?ooKol0o`3of?m:o`3o803ooed0ool2o`3oP@3ooeL0oomY0?oo013o
o`0^ool0Jooo04coooooool0ROl05?ooool02?l0XOooooooo`29oooooooo0?njo`2Kool0C?oo0?o0
0_ooool01_l0;_oo0?o6o`3oSol04?oo0?m<obH0o`;ooooo00WoJ@3oo`0Xool0ooKoE`3ooh40ooln
o`3oooooo`3oD_me0?l01?ooool01Onh0?ooooooooooool0D_ooG@3o00;ooooo00?oEol0ogD0ooln
o`000_ooool01?l0okCooooooooooolJ0?l4o`3oP`;ooooo00?o08ooooooool0oo001_ooool00omY
0?ooooooooooo`03ooooo`05o`3o=?ooooooooooo`0dooooool00_nO0?l9ooooo`03o`3oc?oooooo
oooo00Wooooo00?o00[oooooooooool01?ooool3oh40o`Gooooo0_l0C?l8ooooo`KoN`3o2?ooool4
ob00o`03o`3Zoooooooooooo00Wooooo0_l0om82ooooo`;o0?l:1?l0ob8;ooooo`Co0?mm0oooool4
o`3o:0gooooo3?nh0?l00ol0oeWo0?njog/0o`07og/0o`SoW`3o;?ooool:o`3ToaOooooo2olP0?m;
ooooo`Oo0?mU?Oooool000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo057ooooo00Go05Woo`0@oomY0?ooG@3ooh40o`02o`3of00;ob00oomM0?ooP@3ooeL0ool0@?oo
J@3oo`0@ool0;_oo06_oo`1<ool0ROl05_ooool01ol0XOoo08Woooooool0ok[o09_oo`1<ool0ol00
0_ooool01_l0;_oo05Woo`3oa_l04?oo03CoobH0o`;ooooo00[oJ@3oo`3o]?l0:?ooE`3ooh40oooo
oooo?_l0o`3oD_ooooooM@3o0oooool02Onh0?ooooooooooool0D_oooooooed0oomGo`3oM@3oocko
0003ooooo`04o`3o]?ooooooooooooooo`;o6P3o0_ooool01Ol0oh?o08ooo`3oPol0oh?o0?o`00;o
0?n31?ooool00omY0?ooooooooooo`02ooooo`09o`3o=?ooooooooooo`0doooooooo0:koo`3oMooo
ooooW`3o00Wooooo00?o0?o<ooooooooool02Oooool2o`0:o`04oooooon10?ooP@3ooh40o`Oooooo
00?o04coooooooooool03_ooool<og/0o`Go803o2Oooool2o`3odP;o0?lR1?ooool7o`3o2P04oooo
ool0oggo0?mmo`3oO@_ooooo0_l0obP;okP0o`;ooooo3?mk0?l00oooooooW`3ooil0o`05oil0ocko
oooo3?l0i?l00ooooooo803oob00o`08ob00oegooooo2?l0ofDeooooo`001oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0DOooool01Ol0FOoo013oobH0oomY0?ooP@3o
00;o803o00_o8?l0oh40oolJ0?ooE`3oofT0oolV0?oo013oo`0^ool0C?oo08Woo`2Qo`0Fooooo`07
o`2Qool0ROoo0?Koo`3o^_l0Vooo04coo`1[o`02ooooo`06o`0^ool0FOoo0?o6o`0@ool0=?oo9P3o
0oooool02OmY0?oo02SooeL0oon10?ooEol0ocko0?l0oe;oooooogD0o`04ooooo`08okP0oooooooo
05;ooooooomM0?ooEol0ogD0oolno`02ooooo`03o`3o]?oooooooooo00;ooooo00?o0?m<oooooolJ
0?l00_ooool00ol0Soooooooo`3ol003ooooo`?o0?n300?oJ@3oo`3oPoooool00_ooool01ol0ocCo
oooooooooooooooo03Coo`2^ool0m_l00oooool2oil0o`Sooooo00?o0?o<ooooooooool02?ooool3
oh40o`Wooooo00?o04coooooooooool05?ooool2o`3Zo`Gooooo3?mk0?l2o`3o8P;ooooo0_l0om89
ooooo`?o0?mm1ol0o`X9okP0o`;ooooo2omk0?l4o`3o^P03oooooonO0?ooW`3o00KoW`3o0oooool3
o`3oFDCooooo2?lP0?l;o`3TofCooooo1ol0ofD^ooooo`002?ooool3o`0000Wooooo00?o0000oooo
ooooool0DOooool01_l0Vooo013oobH0oomY0?oo00Cooh40o`;oG@3o00WoP@3ooaX0oomG0?ooJ@3o
o`0@ool0;_oo06_oo`1<ool0ROl05oooool03ol0XOoo08Woo`3fool0ok[o09_oo`1<ool0Jooo0?o0
ooooool0;_oo05Woo`3oa_oooooo013oobH0o`03ooooo`07ofT0ool0:?oo0?ofoh40oomGo`3ooooo
o`3oDP02ooooo`05ogD0oooooooooooooooooonh0?l00_ooool01?l0D_ooooooogD0oolno`03oooo
o`05o`3o]?ooooooooooooooool0od`00oooool2oaX0o`03o`2?oooooooo0?o`00Gooooo00KoJ@3o
oooooooooooo0?n3ooooool0oc@3ooooo`03o`0doooooooo0:ko00GoP@3o00?o0<cooil0ooooool0
1oooool00ol0olcoooooooooo`04ooooo`?oP@3o0_ooool00ol0Pooo00[oooooo`05ooooo`;o04co
5Oooool2o`3Zo`kooooo0ol0ob82ob00oa?oN`3o1_nh0?l;og/0o`Co0?l:1?l0okX8oil0o`kooooo
0ol0oeTiooooo`So803o4oooool;o`3Tof3ooooo2Ol0ofDUooooo`005?ooool00ol0003ooooooooo
o`1Aooooo`05o`2Qool04?oo9P3oofT0ool01?l00on10?l02OlJ0?ooE`3oo`10oomY0?oo013oo`0^
ool0C?oo08Woo`2Qo`0Gooooo`0?o`2Qool0j_oo08Woo`3o^_l0Vooo0:koo`1<ool0ol3oooooo`0^
ool0FOoo0?o6o`3oSol04?oo9P3o00?ooooo00SoJ@3oo`0Xool0ooKoP@3oo`3o>_mGo`3o?_l0o`3o
DP;ooooo00[oM@3ooooooooooooooooookP0oooooooo05;oogD0oomM0?oo?_l00oooool01Ol0okCo
oooooooooooooooo0?m<00Cooooo00Co08oooaX0oooooooo0?o`1Oooool01?mY0?oooooooooooooo
ool2o`3oP`OoP@3o0oooool3oh40o`03oil0oon10?ooP@3o00coP@3o1_ooool00ol0Pooo00[ooooo
o`03ooooo`03o`1<oooooooooooo01?ooooo0_l0j_l=ooooo`?o0?lR1_ooool5ob00o`;ooooo0_l0
om801?l0oggoooooooooooooool5okP0o`oooooo0_l0okX8oil0o`03o`3o2_l0obSo0?lX00?o0?lX
2_l0o`X9ooooo`?o0?mI;Oooool9ob00obKooooo4_l0i?mGooooo`_o0?mU6_ooool001Cooooo00?o
0000ooooooooool0D_ooool01?l0FOoo013ooeL0oomY0?l3o`04o`08oeL0ool02_ooJ@3oobH0ool0
4?oo02koo`1<ool0ROlHooooo`0?o`2Qoooooooo08Woooooool0ok[o09_oo`1<ool0ol3oooooo`0^
ool0FOoo0?o6o`3oSol04?oo9P3o00?ooooo00SoJ@3oo`0Xool0ooKoE`3ooh40oomGo`3oooooo`3o
DP;ooooo0_me0?l2ooooo`06okP0oome0?ooM@3ooooooolno`3oG@3o0_ooool00ol0okCooooooooo
o`02ooooo`03o`3oC?oooooooooo00;ooooo00?o08oooooooolJ0?l01Oooool00omY0?oooooooooo
o`02ooooo`08o`3o=?n10?ooooooo`0doooooooo0:koo`3oMol0m_l6ooooo`03o`3<ooooooooW`3o
00Wooooo00?o0?o<ooooooooool02?ooool01Ol0Pooo00[ooooooooooooo04co01Cooooo0_l0j_l<
ooooo`?o0?lR3Oooool00ol0oggo803oob00o`06okP0o`kooooo2?nO0?l>ooooo`Co0?lX1_ooool<
o`3o2P?o0?mI7oooool;ob00od7ooooo6?l0i?m:ooooo`Go0?mU5Oooool001Cooooo00?o0000oooo
ooooool0D_ooool03ol0FOoo013ooeL0oomY0?oo08ooo`3o]?lJ0?ooE`3oo`10oomY0?oo08?oo`0@
ool0Jooo04coo`2Qo`0Iooooo`0>o`2Qool0ROoo0?Koo`3o^_l0Vooo04coo`3o`?oooooo02koo`1I
ool0olKo0?n?o`0@oolV0?l3ooooo`08ofT0ool0:?oo0?ofoeL0oon10?ooEol0ooooool0oe84oooo
o`?oM@3o00Go^03oooooool0D_oooooooed0o`02ooooo`05o`3o]?ooooooooooooooool0od`01Ooo
ool00ol0Soooooooo`3ol002oaX0o`?ooooo00?oJ@3ooooooon10?l00on10?l2ooooo`04o`0dool0
oh?o0:koo`3fo`Sooooo00?o0<cooooooonO0?l02Oooool00ol0olcoooooooooo`08ooooo`03o`23
ool02_oo04co01?ooooo0_l0j_l:ooooo`Co0?lR3Oooool6okP0o`Cooooo2?lP0?l8oil0o`03o`3o
^_oooooooooo01Oooooo1Ol0obP=ooooo`?o0?l:0ol0oeT4o`3o2QSo803oI?oooolGo`3ToaOooooo
8Ol0ocXEooooo`005?ooool00ol0003oooooooooo`1Booooo`0?o`29ool04?oo9P3oofT0ool0Sooo
09GooaX0oomG0?ooJ@3oobH0ool04?oo02koo`1<ool0ROoo0:7o01Wooooo00ko0:7oo`29ool0m_oo
0?njo`2Kool0C?oo0?o0ooooool0;_oo05Woo`3oa_l0ohoo013oobH0o`?ooooo00WoJ@3oo`0Xool0
ooKoE`3ooh40ooooooooEol0o`3oD_lno`001_ooool01Olno`3o^03oooooool0D_ooG@3o00;ooooo
00Go0?ndooooooooooooooooo`3oC004ooooo`04o`2?ooooooooooooo`3ol0;ooooo00?o6P3ooooo
oonh0?l01Onh0?l2ooooo`05o`0doooooooo0:koo`3oPol0m_l02Oooool00ol0c?oooooooil0o`09
ooooo`;o0?o<2?ooool00ol0C?oo08?oo`0:o`0Aooooo`;o0>[o2Oooool3o`3o8Pcooooo1Onh0?l;
ooooo`OoW`3o1?l0okXAob00oa;ooooo1?l0obPCob00o`Sooooo5ol0o`YdoooooaOo0>Co=_ooool0
01Cooooo00?o0000ooooooooool0D_ooool01Ol0Vooo013oobH0ool02_ooJ@3o00;oE`3o00Oo043o
ofT0oolV0?oo013oo`0^ool0C?oo08Wo01[ooooo00Oo0:7oo`29ool0m_oo0?njo`2Kool0C?oo0?o0
00;ooooo00Go02koo`3oa_l0ohoo013oobH0o`04ooooo`09ofT0ool0:?ooE`3ooh40ool0oc[ooooo
oeOo0?l0oe;o?_l000Cooooo00So?_l0oooooonh0?ooooooo`1BooooooooG@3oo`3o]0Cooooo00?o
0?m<ooooooooool00_ooool00ol0Soooooooo`3ol005okP0o`04ofT0oon10?ooooooo`3o=0;ooooo
1?nh0?l01?l0[_oo0?Koooooool0oh<9ooooo`03o`3<ooooooooW`3o00[ooooo00?o0?o<oooooooo
ool00oooool2o`1<o`;ooooo00?o08?oo`0:ooooool03Oooool2o`3Zo`Sooooo0ol0ob89ooooo`Ko
^03o0_l0ogd7ooooo`OoW`3o00?oooooo`3o^_l0okX00_l0om800ol0ok[oooooooooo`0DoooooaKo
803o00?oooooo`3o:?l0obP00ol0obP<ooooo`?o0?mI7OoooolAo`3o2Ucooooo3?l0ocXBoooooaOo
0>Co7oooool001Cooooo00?o0000ooooooooool0D_ooool01?l0XOoo04coobH0ool0@?l2ofT0o`08
o`0:oomY0?oo9P3oo`23ool04?oo06_oo`1<ool0XOlJooooo`07o`2Qool0j_oo08Woo`3o^_l0Vooo
04coo`3o`002ooooo`06o`0^ool0ocCo0?o6o`0@ool0odco9P3o0oooool02?mY0?oo02SooeL0oon1
0?oo0?ljoooooomGo`3o0?mB1_lno`02ooooo`05okP0oooooooo05;ooed0ool0ok@00oooool00ol0
odcoooooooooo`03ooooo`?o^03o1?ooool01OmY0?ooP@3ooaX0oooooooo0?ld00?ooooo00?o03Co
ooooool0[_l00_nh0?l2ooooo`;o0?n32?ooool00ol0c?oooooooil0o`0:ooooo`05o`3oc?oooooo
ooooooooool0C?l01Oooool00ol0Pooo00[oooooo`0:ooooo`;o0>[o2?ooool2o`3o8PKooooo1_nh
0?l2ooooo`?o0?mm1?ooool6oil0o`?ooooo1Ol0okX4ooooo`;o0?oB<Oooool5o`3o:0[ooooo1?l0
oeTZooooo`_o0?l:@?oooolAo`3o>SGooooo2_l0i?lEooooo`005?ooool3o`0005?ooooo00Co04co
obH0ool0=?oo043o0_mY0?l01ol0:?oo9P3oo`0@ool0;_oo04coo`29ool0XOl06_ooool03ol0XOoo
0>[oo`29ool0ok[oooooo`1<ool0Jooo0?mmooooool0;_oo05Woo`3oa_l04?oo03CoobH0o`03oooo
o`05ofT0ool0:?oo0?ofoeL0oon10?l00_ooool00ol0oe;oEol0oeOo0002oeOo00Gooooo00Co^03o
o`1Bool0okCoG@3o0oooool00ol0odcoooooooooo`03okP0o`;ooooo00?o0?o`ooooooooool00_oo
ool01?n10?oooooooooooolJ0?l3ooooo`06o`0doooooooo0?mgo`2^ool0m_oooooo0_nh0?l2oooo
o`03o`3oPooooooooooo00Kooooo00Co0<cooooooonO0?ooW`3o2Oooool2o`3oc003o`1<oooooooo
oooo00Gooooo00?o08?oo`0:ooooool02?ooool00ol0j_ooooooooooo`05ooooo`?o0?lR0oooool5
okP0o`Gooooo0ol0ogd00oooooooW`3ooil0o`04oil0o`Gooooo1?l0okX;ooooo`;o0?oB=?ooool4
o`3o:0[ooooo0ol0oeTboooooa;o0?l:7OoooolAo`3o>VGooooo000Dooooo`03o`000?oooooooooo
05?ooooo00Co05Woo`0@oolV0?oo0?nK0_l0of/01_lV0?oo08?oo`0@ool0;_oo04coo`29oa_ooooo
00oo0:7oooooool0ROoo0?njooooool0C?oo06_oo`3oOOoooooo02koo`1Iool0olKo0?n?o`0@oolV
0?l00oooool01OmY0?oo02Soo`3om_mG0?ooP@3o00?ooooo00?o0?mBooooooooool01oooool2okP0
o`07oooooomM0?ooooooooooool0odcooooookP0o`02ooooo`03o`2?oooooooo0?o`00Cooooo00Go
P@3ooooooooooooo0?ldoaX0o`03ooooo`05o`0doooooooo0?mgo`2^ool0m_l00oooool2okP0o`03
ooooool0oh?ooooo00Kooooo00Go0<cooooooooooooooooooil0o`08ooooo`;o04co00?o0?o<oooo
ooooool01_ooool00ol0Pooo00[oooooo`05ooooo`;o0>[o1_ooool2o`3o8P?ooooo0onh0?l7oooo
o`03o`3oOOnO0?ooW`3o00CoW`3o1oooool4o`3o^Q7ooooo0_l0om8fooooo`Go0?lX2?ooool3o`3o
FD7ooooo4Ol0o`X00ooooooo0?ljo`3o>P09o`3o>WKooooo000Dooooo`03o`000?oooooooooo05?o
oooo00Go08Woo`0@ool0:?oo9P3oo`3o>P02obH0o`05o`0dool04?oo06_oo`1<ool0XOl07?ooool0
3_l0XOoo08Woo`3o^_oooooo04coo`1[ool0oggoooooo`0^ool0FOoo0?o6o`3oSol04?oo9P3o0ooo
ool01_mY0?oo02Soo`3om_mG0?ooP@3oo`3o>P;ooooo00?o0?mBooooooooool02?ooool7okP0o`?o
oooo00?o08ooooooool0oo001?ooool03?n10?ooooooooooool0ocCooooooaX0oooooooo03Cooooo
ool0ogOo0:koo`3fo`Kooooo0_nh0?l8ooooo`04o`3<ooooooooooooooooo`?oW`3o1?ooool01Ol0
C?oooooooooooooooooo0?o<00Sooooo00?o08?oo`0:ool02_l00_ooool2o`3Zo`Kooooo0_l0ob82
ooooo`?o^03o1Oooool6oil0o`Wooooo1?l0okXGooooo`;o0?oB>Oooool5o`3o:0Kooooo1?l0oeU3
ooooo`co0?lj2ol0o`Yfooooo`005?ooool00ol0003oooooooooo`1Cooooo`03o`2Kool04?oo02ko
00?o9P3o00Go03Coo`0@ool0;_oo04coo`29o`0Mooooo`0>o`2Qool0ROoo0?Koo`3o^_l0Vooo04co
o`3o`?oooooo02koo`1Iool0olKo0?n?o`0@oolV0?l3ooooo`06ofT0ool0:?oo0?ofoeL0oon10?oo
0?lj0_ooool00ol0oe;oooooooooo`07ooooo`03o`3o]?oooooo05;o00;ooooo00?oG@3ooooooooo
ool00_ooool01?l0Soooooooooooool0oo03ooooo`04oh40oomY0?ooooooo`3o=0?ooooo00Ko6P3o
o`0doooooooo0?mgo`2^ool0m_l8ooooo`;o^03o1oooool00ol0c?ooooooooooo`03ooooo`;oW`3o
00?oooooo`1<ooooool01?ooool2o`3oc0Oooooo0_l0Pol00ol02_oo0>[oooooo`05ooooo`;o0?lR
00CooooookP0oonh0?oo^03o0_ooool6oil0o`;o0?mm2_ooool3o`3o^Qgooooo0_l0om8looooo`Co
0?lX1_ooool3o`3oFCCooooo3?l0ocXGoooooa;o0?l:I?ooool001Cooooo00?o0000ooooooooool0
Doooool00ol0XOoo013oo`0^o`02o`0Xo`06o`0dool04?oo02koo`1[ool0C?oo08Wo7Oooool03_l0
XOoo08Woo`3fool0ok[o09_oo`1<ool0ol3oooooo`0^ool0FOoo0?o6o`3oSol04?oo9P3o1?ooool0
1OmY0?oo0?ofoeL0ooooooooP@3o00?ooooo00?o0?mBooooooooool01_ooool01ol0okCooooooooo
ool0D_ooooooo`3oC?mM0?l00oooool01?l0Soooooooooooool0oo02ooooo`05oh40oomY0?oooooo
ooooool0oc@00oooool01_l0=?oo6P3oo`3oMol0[_ooooooo`3fo`Wooooo00?o0?n3okP0ooooool0
1_ooool00ol0c?ooooooooooo`03ooooo`03o`1<oonO0?oooooo00Oooooo00?o0?o<ooooooooool0
1Oooool01?l0j_oo08?oo`0:ool02_l3ooooo`;o0?lR0onh0?l5oil0o`?ooooo0_l0ogd:ooooo`?o
0?nj8_ooool2o`3odSkooooo1Ol0obP4ooooo`Co0?mI9?ooool<o`3o>SGooooo5ol0o`Y=ooooo`00
5?ooool00ol0003oooooooooo`1Dooooo`0:o`1<ool04?oo02koo`1Bool0Pooo013oo`1Iool0Jooo
04coo`2Qoagooooo00ko0:7oo`29ool0j_oo0?njo`2Kool0C?oo0?o0ooooool0;_oo05Woo`3oa_l0
ohoo013oobH0o`Cooooo00GoJ@3oo`3o]?mG0?oooooooh40o`03ooooo`03o`3oD_oooooooooo00Ko
oooo00So0?ndooooooooooooooooo`1Bool0odcooooooed0o`;ooooo00?o08ooooooool0oo000_oo
ool01On10?ooooooofT0oooooooo0?ld00?ooooo00Ko03Coooooool0ogOo6P3oo`2^ool0m_l;oooo
o`03o`3oPonh0?oo^03o00Kooooo00Go0<coooooooooooooooooo`1<o`02ooooo`?oW`3o1_ooool0
0ol0olcoooooooooo`02ooooo`;o0>[o0_ooool01?l0Poooooooo`0:oonO0?l3okP0o`;oW`3o2?oo
ool00ol0oggoooooooooo`08ooooo`;o0?nj9oooool2o`3odT7ooooo1Ol0obP3ooooo`Co0?mI5Ooo
ool;o`3o>USooooo4Ol0o`Xlooooo`005?ooool00ol0003oooooooooo`1Dooooo`04o`1Iool0C?oo
013oo`3Ho`;o013o00?o0?o0o`1<ool0ROl07_ooool03_l0XOooooooo`29ool0ok[o09_oo`1<ool0
ol3oooooo`0^ool0FOooooooo`3oa_l04?oo9P3o1?ooool01_mY0?oo02SooeL0ooooooooP@3oo`3o
>P;ooooo00?o0?mBooooooooool01Oooool00ol0okCoooooooooo`02ooooo`06o`3oC?l0D_oooooo
oooooomM0?oo08oo0_ooool01Ol0oo3ooooooooooon10?ooJ@3o00;ooooo00[o0?ldoooooooooooo
ooooo`0doooooooo0?mgo`2^oolJ0?oo0?Ko3?ooool01?l0oh?ooooookP0oonh0?l5ooooo`03o`3<
oooooooo04co00Kooooo4?nO0?l3okP0o`03o`0:oooooooooooo00Sooooo0_l0ogd9ooooo`;o0?nj
:oooool2o`3odTCooooo1_l0obP00ooooooo0?mIo`3oF@02o`3oF@Oooooo2_l0ocYdooooo`co0?l:
<?ooool001Cooooo00?o0000ooooooooool0E?ooool00ol0Jooo04coo`0@o`02o`0@o`04o`1Iool0
Jooo04coo`29oaoooooo00ko0:7oo`29ool0ok[o09_oo`1<ool0ol3oooooo`0^ool0FOooooooo`3o
a_l04?oo9P3oo`3oC0?ooooo00KoJ@3oo`0Xool0ooKoE`3ooooooon10?l3ooooo`03o`3oD_oooooo
oooo00Cooooo00?o0?ndooooooooool00_ooool01_l0odcoooooo`1Bool0D_oooooooed0o`;ooooo
00Oo0?o`oooooon10?ooooooofT0oooooooo0?ld00?ooooo00Ko03Coooooool0ogOoooooo`2^oolJ
0?l>ooooo`03o`3oPooooooooooo00;o^03o0oooool2o`1<o`03o`3<oooooooooooo00gooooo00Co
0>[ooooooooooooooooo0onh0?l2ooooo`04o`23oooooooo00[oo`0:o`Kooooo0_l0ogd8ooooo`?o
0?nj;oooool3o`3odTOooooo1?l0obP01?l0oc[o0?mIo`3oFOl0oeT4o`3o>X[ooooo4Ol0o`XOoooo
o`005?ooool00ol0003oooooooooo`1Dooooo`09o`29ool0FOoo04coo`3oa_l0FOoo06_oo`1<ool0
ROoo0:7o01oooooo00Ko0:7oo`29ool0ok[oooooo`1<ool0ol02ooooo`06o`0^ool0ocCo0?o6o`0@
oolV0?oo0?m<0oooool01_mY0?oo02Soo`3om_mG0?oooooooh40o`?ooooo00?o0?mBooooooooool0
0oooool00ol0okCoooooooooo`03ooooo`06o`3oC?ooooooooooooooool0D_oo08oo0_mM0?l01?oo
ooooP@3ooooooomY0?l2ooooo`0;o`3o=?ooooooooooooooool0=?ooooooo`3oMooooooo0:koo`3f
oolJ0?l03_ooool01?l0oh?oooooooooooooool3okP0o`?ooooo00?o0<coooooooooool02oooool0
0ol0j_oo^03ookP0o`02okP0o`Kooooo00?o08?oooooooooool00_l02_l3ooooo`03o`3oOOoooooo
oooo00Kooooo0_l0okXeooooo`;o0?oB@_ooool7o`3o>P;ooooo0_l0obP4o`3oFI_ooooo2_l0ohlE
ooooo`005?ooool00ol0003oooooooooo`1Dooooo`03o`2Qool0ROoo04co00?o04co00?o0?njo`29
ooooool07oooool03_l0XOoo08Woooooool0ok[o04coo`3o`?l0oggoooooo`0^ool0ocCo0?o6o`0@
ool0=?oo9P3o1?ooool01_mY0?oo0?ofoeL0ooooooooP@3oo`3o>P?ooooo00?o0?mBooooooooool0
0_ooool00ol0okCoooooooooo`02ooooo`03o`3oC?oooooooooo00;ooooo00Go08ooo`1Bool0D_oo
0?o`oh40o`02ooooo`03ofT0oooooooo0?ld00?ooooo00Ko03Coooooool0ogOoooooo`2^ool0m_l2
ooooo`03oaX0oooooooooooo00cooooo00Ko0?n3ooooooooooooooooo`1<ooooool3okP0o`03oooo
ool0c?oooooo00Sooooo1?nh0?l2o`3o8P;o0?o<1oooool2o`23o`;ooooo00?o00[oo`3oOOl0ogd0
1_ooool3o`3o^SWooooo0_l0om8iooooo`Oo0?lj3oooool4o`3oF@;o0?lXQOooool@o`3oSaoooooo
000Dooooo`03o`000?oooooooooo05Cooooo00?o0:7oo`29ool0Jol00_l0C?l00ol0Jooo08Wooooo
o`0Pooooo`0>o`2Qool0ROooooooo`3o^_l0Vooo04coo`3oOOoooooo02koo`3o=?l0olKo013oo`0d
oolV0?l4ooooo`06ofT0ool0ooKoE`3ooooooon10?oo0?lj0oooool00ol0oe;oooooooooo`02oooo
o`03o`3o]?oooooooooo00;ooooo00?o0?m<ooooooooool00_ooool02Ol0Soooooooooooool0D_oo
P@3ooed0oomY0?ooooooo`3o=004ooooo`06o`0doooooooo0?mgooooool0[_oo0?Ko0oooool00olJ
0?ooooooooooo`0<ooooo`03o`3oPooooooo04co00Gooooo2onh0?l00ol0j_oo0?lRo`3o8P05oooo
o`03o`3oc?oooooooooo00Kooooo00?o08?oo`3oOOl0ogd00_l02_l4ooooo`;o0?nj?_ooool3o`3o
dS3ooooo1_l0ocXJooooo`Co0?mI1?l0obQdooooo`_o0?n?;oooool001Cooooo0ol0001Eooooo`05
o`2Qool0ROoo09_oo`2Kool0ROl08_ooool03_l0XOoo08Woo`3fool0ok[o09_oo`1<ool0oggooooo
o`0^ool0ocCo0?o6o`3oSol04?oo9P3o1?ooool01_mY0?oooooooeL0ooooooooP@3oo`3o>P?ooooo
00Go0?mBooooooooooooooooo`3o]005ooooo`03o`3oC?oooooooooo00;ooooo00Oo08oooooooooo
ooooP@3oooooool0D_ooJ@3o00;oG@3o0oooool01ol0=?ooooooooooool0ogOo0:koooooool0m_l0
1?ooool00olJ0?ooooooooooo`0<ooooo`03o`1<oooooooooooo00Oooooo00?o0<coooooooooool0
0_ooool2o`3o8P03o`3Zoooooooooooo00Oooooo00?o0?o<ooooooooool01Oooool00ol0oggo08?o
ooooo`02ooooo`;o00[o0_l0okY3ooooo`;o0?oB9oooool7o`3o>RCooooo0ol0oeT00ooooooo0?lX
o`3o:004o`3o:6Cooooo2_l0ohljooooo`005?ooool00ol0003oooooooooo`1Fooooo`04o`29ool0
m_oo0?Koo`29ob;ooooo00ko0:7oo`29ool0m_oo0?njo`2Kool0C?oo0?mmooooool0;_oo05Woo`3o
a_l0ohoo013oobH0o`Cooooo00?oJ@3ooooooomG0?l00_ooool00on10?oo0?ljooooo`02ooooo`04
o`3oD_ooooooooooo`3o]0Cooooo00?o0?m<ooooooooool00_ooool01?l0Sooooooooooooon10?l3
ooooo`04ofT0ool0D_oooooooed0o`;ooooo00Ko03Coooooool0ogOoooooo`2^ool0m_l5ooooo`03
oaX0oooooooooooo00_ooooo00?o04coooooool0oh<02Oooool01_l0c?ooooooo`3o8_l0ob;ooooo
o`3Zo`_ooooo0_l0ol`3ooooo`;o0?mm0_ooool2o`23o`?o0?nj0_l02_m5ooooo`;o0?oB0ooooom@
o`0^o`Co0?mI0oooool6o`3o:5Kooooo2?l0ohm4ooooo`005?ooool00ol0003oooooooooo`1Foooo
o`04o`2Qool0ROoo08Woo`2Qob;ooooo00ko0:7oo`29ool0j_oo0?njo`2Kool0C?oo0?mmooooool0
;_oo05Woo`3oa_l0ohoo013oobH0o`Cooooo00?oJ@3ooooooomG0?l00_ooool00on10?oo0?ljoooo
o`02ooooo`04o`3oD_ooooooooooo`3o]0Cooooo00?o0?m<ooooooooool00_ooool01?l0Sooooooo
oh40ool0oo02ooooo`03ofT0oooooooo0?ld00;o05;o0_mM0?l01_l0=?ooooooo`3oMooooooo0:ko
o`3fo`Kooooo00?o6P3oooooooooool02Oooool01Ol0C?oooooooooooooooooo0?n300Oooooo0_l0
ob801?l0c?ooooooooooool0j_l>ooooo`;o0?o<00?o0?mmooooooooool00_ooool2o`3o^P03o`23
oooooooooooo00;ooooo00?o00[oooooooooool0>oooool<o`0^oaKooooo1_l0ocXdoooooaOo02ko
AOooool7o`3oSdcooooo000Dooooo`03o`000?oooooooooo05Oooooo00?o0:7oooooooooool08_oo
ool03ol0XOooooooo`29ool0ok[o09_oo`1<ool0ol3oooooo`0^ool0FOooooooo`3oa_l04?oo9P3o
o`3oC003ooooo`07ofT0ool0:?oo0?ofoeL0ooooooooP@3oo`3o>P04ooooo`03o`3oD_l0okCooooo
00Cooooo00?o0?m<ooooooooool00_ooool01?l0Sooooooooh40ool0oo02ooooo`03ofT0ool0ocCo
oooo00;ooooo00Oo05;oo`0doomM0?oo0?mgooooool0[_oo0?Ko00Sooooo00?o6P3oooooooooool0
1oooool00ol0C?ooooooooooo`03ooooo`03o`3oPooooooo0?lR00Co0?lR0oooool00ol0c?oo0>[o
ooooo`0>ooooo`03o`3oOOoooooo0?o<00?ooooo00Go0?njooooooooooooooooo`23o`04ooooo`;o
00[o<oooool8o`0^o`cooooo0_l0om8>ooooo`Ko0?lj@Oooool3o`3oF@Wooooo1?l0obPGo`0^obCo
oooo2_l0ohmCooooo`005?ooool00ol0003oooooooooo`1looooo`0?o`2Qoooooooo08Woo`3o^_l0
Vooo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo0?m<00Cooooo00OoJ@3oo`3om_mG
0?oooooooh40oooooooo0?lj00Cooooo00?o0?ndooooooooool00_ooool00ol0odcoooooooooo`02
ooooo`09o`2?ooooooooP@3oooooool0oo3oooooofT0oooooooo0?ld00Cooooo00Ko03CooooooomM
0?ooG@3oo`2^ool0m_l9ooooo`03oaX0oooooooooooo00Gooooo00?o04coooooooooool01Ol0ob80
0ol0oh?oooooooooo`05ooooo`03o`3Zoooooooo0<co00gooooo0_l0ogd3ooooo`;o0?o<00?o0?nj
ooooooooool00oooool2o`23o`Cooooo0_l02_lXooooo`Wo02ko5_ooool2o`3odPOooooo1Ol0ocY:
ooooo`Co0?mI2_ooool6o`3o:13ooooo;ol0;_mBooooo`005?ooool00ol0003oooooooooo`1loooo
o`0?o`2Qoooooooo08Woo`3o^_l0Vooo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo
0?m<00Cooooo00OoJ@3ooooooomG0?oo0?ndoooooon10?oo0?lj00Cooooo00?o0?ndooooooooool0
0_ooool00ol0odcoooooooooo`02ooooo`04o`2?oon10?ooooooo`3ol0;ooooo00?oJ@3oo`3o=?oo
ool00oooool01ol0=?ooooooo`1Bool0ogOo0:kooed0ool0m_l02_ooool01?lJ0?oooooooooooooo
ool2o`3o8P04o`1<ool0ob;o0?lRo`3o8PKooooo00?o0?n3ooooooooool00oooool01Ol0j_oooooo
oooooooooooo0<co00[ooooo0_l0ogd4ooooo`;o0?nj00?oooooo`3oc?l0ol`01_ooool00ol0Pooo
ooooooooo`03ooooo`;o00[o8Oooool5o`0^ob7ooooo0ol0om84o`3o>U?ooooo0ol0oeT=ooooo`Go
0?lX6_ooool9o`3oSaOooooo6?l0;_ljooooo`005?ooool00ol0003oooooooooo`1mooooo`0>o`2Q
ool0ROoo0?Koo`2Kool0C?oo06_oooooool0;_oo05Woooooool0olKo013oobH0ool0od`4ooooo`07
ofT0ooooooooE`3oo`3o]?ooooooP@3oo`3o>P03ooooo`03o`3o]?oooooo0?mB00?ooooo00?o0?m<
ooooooooool00_ooool02?l0SoooP@3oooooool0oo3oooooofT0oooooooo0?ld1?ooool01ol0=?oo
ooooo`3oMol0D_oo0:koo`3foomM0?l02?ooool2o`3o8P06oaX0ool0ob;o0?lRo`3o8_oooooo04co
2oooool01Ol0oh?ooooooooooooooooo0>[o00Gooooo00?o0<coooooooooool01_ooool00ol0oggo
ooooooooo`03ooooo`03o`3o^_oooooooooo00?ooooo00?o0?o<ooooooooool01?ooool00ol0Pooo
ooooooooo`04ooooo`;o00[o6Oooool6o`0^ob;ooooo1Ol0ocX2ooooo`;o0?oBF?ooool4o`3oF@ko
oooo1_l0obP>ooooo`Ko0?n?>?oooolUo`0^oaGooooo000Dooooo`03o`000?oooooooooo07gooooo
00ko0:7oo`29ool0m_oo09_oo`1<ool0Jooo0?mmo`0^ool0FOoo0?ldo`3oa_l04?oo9P3oo`3oC0Co
oooo00[oJ@3ooooooomG0?ooooooo`3o]?ooooooP@3oo`3o>_oooooo0?nd0_ooool01?l0oe;ooooo
ooooool0od`4ooooo`09o`2?oon10?ooooooooooool0oo3oooooofT0oooooooo0?ld00Cooooo00Oo
03Coo`3o>_l0ogOo0:koo`1Bool0m_ooG@3o00Go0?lj0ol0ob83ooooo`04oaX0ooooooooooooo`1<
o`gooooo00?o0?n3ooooool0j_l01oooool00ol0c?ooooooooooo`03ooooo`;o0?mm1?ooool2o`3o
^POooooo0_l0ol`5ooooo`;o08?o1_ooool2o`0:oa7ooooo1_l0;_lSooooo`Go0?lj2Oooool3o`3o
dUWooooo1?l0oeT@ooooo`Ko0?lX0oooool5o`3oSeSooooo2ol0ol0Eooooo`005?ooool00ol0003o
ooooooooo`1mooooo`0>o`2Qool0ROoo0?Koo`2Kool0C?oo06_oo`3oOOoooooo02koo`3o=?l0olKo
013oobH0ool0od`4ooooo`03ofT0ooooooooE`3o00;ooooo00Co0?ndoh40oooooooo0?nd1?ooool2
o`3oDP03o`3oC?oooooooooo00;ooooo00CoP@3ooooooooooooo0?o`0_ooool00omY0?oo0?ldoooo
o`02ooooo`0:o`3o>_l0=?oo0?ljooooool0ogOo0:koooooool0D_oooooooed0o`;ooooo0_l0ob84
o`3o>P?ooooo00?o6P3oooooool0C?l03Oooool2o`3Zo`Wooooo00?o0<coooooooooool00_l0ogd5
ooooo`03o`3o^_oooooooooo00Wooooo0_l0ol`5ooooo`03o`23oooooooooooo00Gooooo0_l02_l:
ooooo`Go02ko9?ooool5o`3o>Q7ooooo0ol0om9Jooooo`Co0?mI3oooool6o`3oS`?o0?lXB_ooool@
o`3o`23ooooo000Dooooo`03o`000?oooooooooo07gooooo00ko0:7oo`29ool0m_oo09_oo`2^ool0
C?oo0?mmooooool0;_oo0?ldo`3oa_l04?oo03CoobH0o`Cooooo00?oJ@3ooooooomG0?l00_ooool2
o`3o]003oh40ool0oc[ooooo00Gooooo00Ko0?mBoooooooooooooooooh40ool0Sol2ooooo`06o`3o
l?ooooooJ@3oooooool0ocCooooo0_l0ocX03?oooooo03Coooooool0ogOoooooo`2^ool0m_oooooo
o`1BooooooooG@3oo`3o8PKooooo0_l0ocX2ooooo`03oaX0oooooooooooo00_ooooo00?o0>[ooooo
ooooool00_l0oh<8ooooo`03o`3<ool0oggooooo00Cooooo0_l0okX>ooooo`03o`3oc?oooooooooo
00?ooooo00?o08?oooooooooool01_ooool2o`0:o`Cooooo1?l0;_lUooooo`Co0?lj6Oooool2o`3o
dUcooooo0ol0oeT5ooooo`Oo0?n?2Oooool6o`3o:3Oooooo3Ol0ol0`ooooo`005?ooool00ol0003o
ooooooooo`1mooooo`0?o`2Qool0j_oo08Woo`2Kool0[_oo04coo`3oOOoooooo02koo`3o=?l0olKo
013oo`0doolV0?oo0?m<00Cooooo00?oJ@3ooooooomG0?l00oooool00on10?ooooooo`3o>P04oooo
o`06o`3oC?l0oe;o0?mBo`3oD_ooooooP@3o0oooool01?l0oo3oooooofT0ool0oc@2o`3o>P;o0?mB
00Oo03Coo`3oD_l0oe;o0?mgo`2^oooooooo0?Ko00;ooooo00?o05;oo`3o8_mM0?l02?ooool01?l0
oc[o04cooooooolJ0?l;ooooo`03o`3Zoooooooooooo00?ooooo00?o0?n3ooooooooool01?ooool2
o`3oO@03o`3<oooooooooooo00;ooooo00?o0?njooooooooool03oooool2o`3oc0Cooooo0_l0Pol8
ooooo`;o00[o0_l0;_lTooooo`Go0?lj7oooool3o`3odUWooooo2?l0ohlFooooo`Ko0?lX9Oooool<
o`3o`1oooooo2Ol02_lEooooo`005?ooool3o`0007gooooo00oo0:7oo`3Zool0ROoo0?njo`2Kool0
C?oo0?mmooooool0;_oo0?ldo`3oa_oooooo013oobH0ool0od`01?ooool00omY0?oooooooeL0o`04
ooooo`03oh40ool0oc[ooooo00?ooooo00Ko0?m<oooooooooooo0?mBoh40ool0Sol3o`3oDP03o`3o
l?mY0?oo0?mB00?o0?mB0_ooool01ol0=?ooooooo`3oMooooooo0:koo`3oD_l0m_l00_l0oe801?oo
oooo05;ooooooomM0?l7ooooo`04o`1<ool0oc[o0?ljoaX0o`[ooooo00?o0>[oooooooooool01Ooo
ool01?l0oh?oooooooooooooool2o`3oO@?ooooo00Co0<cooooooooooooo0?nj5?ooool2o`3oc0Co
oooo00Co08?ooooooooooooooooo1?l0;_l2ooooo`;o00[o7oooool5o`3o>ROooooo0_l0om9@oooo
o`Oo0?n?1oooool4o`3oFAWooooo1_l0obPDooooo`_o0?o08?ooool;o`0:oakooooo000Dooooo`03
o`000?oooooooooo07gooooo00oo0:7oo`3Zool0ROoo0?njo`2Kool0C?oo0?mmooooool0;_oo05Wo
ooooool0olKo013oobH0ool0od`01?ooool00omY0?oooooooeL0o`05ooooo`03oh40ool0oc[ooooo
00;ooooo00Ko0?m<ooooooooooooP@3oooooool0Sol2ooooo`05o`3ol?ooooooJ@3oooooool0oc@0
1?ooool02Ol0=?ooooooo`3oMol0[_ooooooo`3foooooooo0?lRooooo`02o`3oDP03o`1Boooooooo
G@3o00Gooooo00Ko04coooooooooooooooooo`3o>_lJ0?l8ooooo`03o`3Zoooooooooooo00Oooooo
00?o0?n3ooooool0ogd01_ooool00ol0c?oo0?njooooo`0Fooooo`04o`3oc?ooooooooooooooo`Co
02ko2?ooool3o`0:oaKooooo1_l0ocX^ooooo`?o0?oBAoooool6o`3oSa;ooooo1?l0oeTKooooo`Go
0?lX0oooool<o`3o`27ooooo2_l02_lYooooo`005?ooool00ol0003oooooooooo`1mooooo`0?o`2Q
ool0j_oo08Woo`3o^_l0Vooo04coo`3oOOoooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo0?m<00Co
oooo00?oJ@3ooooooomG0?l01Oooool01On10?ooooooo`3o>_oooooo0?m<00;ooooo00CoP@3ooooo
oooooooo08oo0_ooool01?l0oo3o0?ljofT0ool0oc@4ooooo`08o`0dooooooooooooo`3oMol0[_oo
ooooo`3fool0ob84ooooo`03o`1Bool0oe;oG@3o00Cooooo00?o04coooooooooool01?ooool00olJ
0?ooooooooooo`04ooooo`03o`3Zoooooooooooo00Sooooo00?o0?mmo`3oPoooool01Oooool00ol0
ok[oooooo`3<o`0Hooooo`03o`3oc?l0;_oo02ko00?ooooo00?o08?oooooooooool02Oooool3o`0:
o`kooooo1Ol0ocXgooooo`;o0?oB@?ooool5o`3oSacooooo1Ol0oeTBooooo`co0?o00ol0obPRoooo
o`So00[o<oooool001Cooooo00?o0000ooooooooool0OOooool03ol0XOoo0>[oo`29ool0ok[o09_o
o`1<ool0ol3oooooo`0^ool0FOooooooo`3oa_l04?oo9P3oo`3oC004ooooo`03ofT0ooooooooE`3o
00Kooooo0_n10?l01?l0oc[oP@3ooh40oon10?l2ooooo`08o`2?ooooooooooooo`3o>_l0oo3oJ@3o
ooooool0oc@4ooooo`07o`0doooooooo0?mgooooool0[_ooooooo`3fo`06ooooo`03o`1Boooooooo
G@3o00;ooooo00?o04coooooooooool01Oooool00olJ0?oo0?ljo`3o>P03ooooo`03o`3Zoooooooo
oooo00Oooooo0_l0ogd2ooooo`;o0?n30oooool01Ol0ok[ooooooooooooooooo0<co01Kooooo0_l0
;_l00ooooooo0?o<o`3oc003ooooo`;o08?o3?ooool3o`0:o`Gooooo1_l0ocXnooooo`?o0?oB>?oo
ool5o`3oSbKooooo1?l0oeT3ooooo`_o0?o03oooool7o`3o:1?ooooo2?l02_lkooooo`005?ooool0
0ol0003oooooooooo`1mooooo`0?o`2Qool0j_oo08Woo`3o^_l0Vooo04coo`3o`?oooooo02koo`1I
oooooooo0?o6o`0@oolV0?oo0?m<00Cooooo00CoJ@3ooooooomG0?oo0?of1_ooool3oh40o`;o0?lj
0_ooool01ol0Sooo0?ljo`3o>_oooooo0?o`ofT0ool0oc@01Oooool01_l0=?ooooooo`3oMol0[_oo
ooooo`3fo`Sooooo00Go05;ooooooomM0?ooooooo`1<o`08ooooo`05oaX0oooooooo0?ljo`3o>_l0
j_l02Oooool00ol0oggoooooooooo`04ooooo`03o`3oPol0ok[o0?nj00Gooooo00?o0<cooooooooo
ool04Oooool2o`0^o`Gooooo0_l0ol`3ooooo`03o`23oooooooooooo00[ooooo0_l0ocX2o`0:o`?o
0?ljAoooool3o`3odS3ooooo1Ol0ohlWooooo`_o0?o000?o0?mIooooooooool07_ooool7o`3o:0Co
oooo2?l02_m3ooooo`005?ooool00ol0003oooooooooo`1mooooo`0?o`2Qoooooooo08Woo`3fool0
Vooo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo0?m<00Cooooo00CoJ@3oo`0XoomG
0?oo0?of1oooool00ol0odcoooooooooo`03o`3o>P07o`2?ooooooooooooo`3ol?mY0?ooooooo`3o
=004ooooo`07o`0doooooooo0?mgooooool0[_ooooooo`3fo`09ooooo`03o`1BooooooooG@3o00[o
oooo00?o6P3oooooool0j_l00_l0ocX6ooooo`;o0?mm1oooool00ol0ok[o0?n3o`3oP`06ooooo`03
o`3<oooooooooooo00kooooo0_l0;_l9ooooo`;o0?o<0_ooool2o`23o`;ooooo2?l0ocX4ooooo`?o
00[oB_ooool3o`3odRSooooo1Ol0ohlRooooo`[o0?o03?ooool5o`3oFAoooooo1ol02_l3o`3o:4So
oooo000Dooooo`03o`000?oooooooooo07gooooo013o0:7oooooool0ROoo0?Koo`2Kool0C?oo0?o0
ooooool0;_oo05Woo`3o=?l0olKo013oobH0oooooooo0?m<1?ooool00omY0?oooooooeL0o`07oooo
o`03o`3oC?oooooooooo00;ooooo00So08ooooooooooooooooooo`3ol?mY0?ooooooo`3o=0Cooooo
00Oo03Coooooool0ogOoooooo`2^ool0ob;o0?Ko00Wooooo00Co05;oo`1<ooooooooG@3o2Oooool0
0olJ0?oo0>[oooooo`02ooooo`;o0?lj0_ooool2o`3oO@Oooooo0_l0okX3ooooo`;o0?n31Oooool0
0ol0c?ooooooooooo`0:ooooo`?o02ko3?ooool00ol0oc[o0?o<o`3oc002o`3o>P;o08?o3oooool3
o`0:od[ooooo0ol0om8Pooooo`Go0?n?7oooool8o`3o`1_ooooo1?l0oeTDooooo`Oo00[o2_ooool7
o`3o:2;ooooo2_mM0?lEooooo`005?ooool00ol0003oooooooooo`1mooooo`0@o`2Qoooooooo08Wo
o`3fool0Vooo04coo`3o`?l0oggo02koo`1Iool0ocCo0?o6o`0@oolV0?ooooooo`3oC0Cooooo00?o
J@3ooooooomG0?l01oooool00ol0odcoooooooooo`02ooooo`07o`2?ooooooooooooooooool0oo3o
J@3oo`3o=005ooooo`06o`0doooooooo0?mgo`2^ool0ob;o0?Ko2_ooool01Ol0C?oo05;ooooooooo
ooooG@3o00Sooooo00?o0>[ooaX0ooooool01?ooool00ol0oc[o0?mmooooo`07ooooo`03o`3o^_oo
oooooooo00Gooooo00?o0?n3ooooooooool00oooool2o`3<o`Sooooo0_l0;_l5ooooo`[o0?lj0ooo
ool2o`3oc0;ooooo00?o08?oooooooooool03oooool3o`0:od[ooooo0ol0om8Iooooo`Co0?n?7Ooo
ool7o`3o`2Oooooo1?l0oeT8ooooo`So00[o6?ooool6o`3o:13ooooo3?mM0?lOooooo`005?ooool0
0ol0003oooooooooo`1nooooo`0?o`2Qool0ROoo0?Koo`2Kool0C?oo06_oo`3oOOl0;_oo05Woo`3o
=?l0olKo013oo`0doolV0?oo0?m<00Cooooo00CoJ@3ooooooomG0?oo0?of1_ooool00ol0odcooooo
ooooo`02ooooo`07o`2?oooooooooooooooooomY0?ooooooo`3o=004ooooo`07o`0doooooooo0?mg
ooooool0[_ooooooo`3fo`09ooooo`04o`1<ooooooooooooo`1Bo`;ooooo00?oG@3oooooooooool0
1?ooool01?l0j_oooooooooooolJ0?l3ooooo`;o0?mm00Coooooo`3o>_l0oc[o0?lj1?ooool00ol0
ok[oooooooooo`07ooooo`;o0?n31Oooool00ol0c?ooooooooooo`03ooooo`;o02ko1ol0ocX?oooo
o`;o0?o<00?oooooo`23ool0Pol04_ooool3o`0:od[ooooo0ol0om8Booooo`Co0?n?6_ooool7o`3o
`3;ooooo2?l02_lVooooo`Co0?lX3?mM0?l[ooooo`005?ooool00ol0003oooooooooo`1nooooo`0?
o`2Qool0ROoo0?Koo`2Kool0C?oo06_oo`3oOOoooooo02koo`3o=?l0olKo013oo`0doolV0?oo0?m<
00Cooooo00CoJ@3ooooooomG0?oo0?of1Oooool00ol0odcoooooooooo`02ooooo`07o`2?oooooooo
ooooooooool0oo3oJ@3oo`3o=005ooooo`07o`0doooooooo0?mgo`3o8_l0[_ooooooo`3fo`08oooo
o`03o`1<oooooooooooo00;ooooo00Co05;ooooooomM0?oo0?mB1?ooool01Ol0j_oooooooooooooo
oooo6P3o00?o0?mm1_ooool2o`3o>P;o0?nj3?ooool00ol0oh?oooooooooo`02ooooo`04o`3o>_l0
c?oo0?ljo`3o>P;o02ko6_ooool2o`3oc003ooooool0Pooooooo01?ooooo1?l02_m9ooooo`?o0?oB
3?ooool3o`3oSaSooooo1_l0ol0booooo`Oo00[o1?ooool4o`3oFAoooooo2omM0?l2ooooo`Ko0?lX
;oooool001Cooooo0ol0001nooooo`0@o`2Qool0j_oo08Woo`2Kool0ogOo04coo`3oOOoooooo02ko
o`3o=?oooooo013oo`0doolV0?ooooooo`3oC0?ooooo00CoJ@3oo`0XoomG0?oo0?of1Oooool00ol0
odcoooooooooo`02ooooo`07o`2?oooooooooooooooooomY0?ooooooo`3o=005ooooo`06o`0doooo
oooo0?mgo`2^oooooooo0?Ko2?ooool00ol0C?ooooooooooo`03ooooo`04o`1Boooooooooooooed0
o`;o0?mB00?oooooo`3Zooooool00_ooool2o`3oO@03oaX0oooooooooooo00Oooooo00?o0?njoooo
ool0ocX03Ol0ocX2o`3oP`;o0?lj0_ooool00ol0c?oo02koooooo`0Mooooo`;o0?o<0_l0PolFoooo
o`?o00[oBOooool2o`3odPKooooo1?l0ohlDooooo`Oo0?o0;_ooool:o`0:o`oooooo1?l0oeT:oooo
oa7oG@3o4oooool7o`3o:2Sooooo000Dooooo`03o`000?oooooooooo07kooooo013o0:7oo`3Zool0
ROoo09_oo`2^ool0C?oo0?mmooooool0;_oo0?ldooooool04?oo03CoobH0oooooooo0?m<1?ooool0
0omY0?ooE`3oo`3omP05ooooo`03o`3oC?oooooooooo00;ooooo00Oo08ooooooooooooooooooofT0
oooooooo0?ld00Cooooo00Oo03Coooooool0ogOoooooo`2^oooooooo0?Ko00Sooooo00?o04cooooo
ooooool01?ooool01_l0D_oooooooooooomM0?ooooooo`3Zo`;ooooo0_l0ogd3ooooo`03oaX0oooo
oooooooo00Gooooo00?o0?njooooooooool04?ooool3o`3oP`;o02ko00?oooooo`3<ooooool07_oo
ool2o`3oc003o`23oooooooooooo01Kooooo1Ol02_m6ooooo`?o0?oB0ol0ohlBooooo`Ko0?o0:Ooo
ool<o`0:oaOooooo4?mM0?l[ooooo`So0?lX8?ooool001Cooooo00?o0000ooooooooool0O_ooool0
4?l0XOoo0>[oo`29ool0Vooo0:koo`1<ool0oggoooooo`0^ool0FOooooooo`3oa_l04?oo9P3ooooo
ool0od`4ooooo`04ofT0oomG0?ooooooo`3omPCooooo00?o0?m<ooooooooool00_ooool01_l0Sooo
oooooooooomY0?oo0?o`o`3o=0Gooooo00Oo03Coooooool0ogOoooooo`2^oooooooo0?Ko00Oooooo
00?o04coooooooooool01_ooool01?l0D_oooooooooooomM0?l3o`3oO@Gooooo00?o6P3ooooooooo
ool00oooool2o`3o^QGooooo00?o02koo`3oPol0oh<00_ooool2o`3<oaoooooo00?o0?o<o`23ool0
Pol06oooool6o`0:ockooooo1?l0ohl01?oooooo0?oBo`3od_l0om8<ooooo`Ko0?o09Oooool:o`0:
oa_ooooo2?mM0?l:ooooo`Co0?mI=Oooool7o`3o:1Wooooo000Dooooo`03o`000?oooooooooo07ko
oooo00ko0:7oo`3Zool0ROoo09_oo`2^ool0C?oo0?mmooooool0;_oo05Woooooool0olKo013oobH0
o`;ooooo00So0?m<ooooooooooooooooofT0ooooooooE`3oo`3omP?ooooo00?o0?m<ooooooooool0
0_ooool01ol0SoooooooooooooooooooJ@3oooooool0oc@01Oooool01_l0=?oo0?lRo`3oMol0[_oo
ooooo`3fo`Sooooo00?o04coooooooooool01_ooool01?l0D_ooooooo`3ZoomM0?l2ooooo`03o`3o
D_oooooooooo00Cooooo00Go6P3oooooooooooooooooo`3o^P0Eooooo`;o02ko0oooool2o`3oP`;o
oooo00?o0<coooooooooool07_ooool00ol0olco08?oooooo`0Oooooo`Ko00[o=?ooool4o`3oS`So
oooo0ol0om84ooooo`Go0?o08oooool8o`0:oagooooo2?mM0?lFooooo`Co0?mI>?ooool4o`3o:1Go
oooo000Dooooo`03o`000?oooooooooo07kooooo00ko0:7oo`3Zool0ROoo09_oo`2^ool0C?oo0?o0
ooooool0;_oo05Woooooool0olKo013oobH0o`;ooooo00So0?m<ooooooooooooooooo`0XoomY0?oo
E`3oo`3omP?ooooo00?o0?m<ooooooooool00_ooool01ol0SoooooooooooooooooooJ@3oooooool0
oc@01Oooool01_l0=?oo0?mgooooool0[_ooooooo`3fo`Oooooo00?o04coooooooooool01_ooool2
o`3oO@04o`1Boooooooooooooed0o`;ooooo00?o0?mBooooooooool01?ooool00olJ0?ooooooo`3o
^P0Eooooo`03o`0^oooooooooooo00Gooooo0ol0oh<00ol0c?ooooooooooo`0Oooooo`;o08?o9?oo
ool5o`0:ob_ooooo1?l0ohl=ooooo`;o0?o00ol0om800ol0ol3oooooooooo`0Oooooo`Oo00[o6ooo
ool:oed0ob;ooooo1?l0oeU=ooooo`005?ooool00ol0003oooooooooo`1nooooo`0>o`2Qool0j_oo
08Woo`2Kool0[_oo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?l2ooooo`09o`3oC?oo
ooooooooooooool0:?ooJ@3ooeL0oooooooo0?of00;ooooo00?o0?m<ooooooooool00_ooool01_l0
SooooooooooooomY0?oo0?o`o`3o=0Gooooo00Oo03Coo`3o8_l0ogOoooooo`2^oooooooo0?Ko00Oo
oooo00?o04coooooooooool01Oooool01?l0oggoooooooooool0D_l3ooooo`04oed0oooooooooooo
o`3oDPGooooo00?o6P3oo`3o^_ooool04oooool2o`0^o`_ooooo00?o0?n3o`3<ool0c?l08Oooool2
o`23obOooooo2ol02_lMooooo`?o0?n?3?ooool5o`3o`0Gooooo0ol0om8@ooooo`oo00[o5oooool;
oed0oc3ooooo0ol0oeU:ooooo`005?ooool00ol0003oooooooooo`1nooooo`0Ao`2Qool0j_oo08Wo
o`3o^_l0Vooo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo08ooooooool0od`01?oo
ool01_mY0?ooE`3oooooool0ooKoooooo`3oC0Cooooo00Oo08ooooooooooooooooooofT0oooooooo
0?ld00Gooooo00Ko03Coo`3o8_l0ogOoooooo`2^ool0m_l7ooooo`03o`1<oooooooooooo00Cooooo
0_l0ogd2ooooo`03o`3Zoooooooo05;o00?ooooo00CoG@3ooooooooooooo0?mB0_ooool2o`3o^P03
oooooolJ0?oooooo01;ooooo00?o02koooooooooool03Oooool00ol0oh?o0<coo`3oP`0Qooooo`;o
08?o;?ooool4o`29o`co00[o8?l0ROl=ooooo`03o`3od_l02_oo00[o00go00[o6_ooool<oed0ocko
oooo1?l0oeU6ooooo`005?ooool00ol0003oooooooooo`1nooooo`0Ao`2Qool0j_oo08Woo`3o^_l0
Vooo04coo`3o`?oooooo02koo`1Iool0ocCo0?o6o`0@oolV0?oo08ooooooool0od`01?ooool01_mY
0?ooE`3oooooool0ooKoooooo`3oC0Cooooo00Oo08ooooooooooooooooooofT0oooooooo0?ld00Go
oooo00Ko03Coo`3oMooooooo0:koooooool0m_l7ooooo`03o`1<oooooooooooo00?ooooo00Go0?mm
ooooooooooooooooo`3Zo`03ooooo`04o`1Boooooooooooooed0o`?ooooo0_l0okX4ooooo`03oaX0
oooooooooooo00kooooo0_l0;_lBooooo`04o`3<ool0oh?o0?n3o`3oPb3ooooo00?o08?oo`3oc?oo
ool07?ooool=o`29oa3ooooo;_l02_l?o`29o`oooooo2omM0?m>ooooo`Co0?mI@_ooool001Cooooo
00?o0000ooooooooool0O_ooool04Ol0XOooooooo`29ool0ok[o09_oo`1<ool0ol3oooooo`0^ool0
FOoo0?ldo`3oa_l04?oo9P3oo`2?oooooooo0?m<00Cooooo00Go02SoofT0ooooooooooooo`3omP05
ooooo`06o`2?ooooooooooooofT0ool0oo3o0?ld1Oooool01ol0=?ooooooo`3oMooooooo0:kooooo
ool0m_l01_ooool00ol0C?ooooooooooo`02ooooo`;o0?mm0oooool00ol0j_ooooooooooo`02oooo
o`05o`1BoooooooooooooooooomM0?l00_l0okX00ooooooo0?mBooooo`03ooooo`03oaX0oooooooo
oooo00gooooo00?o02koooooooooool04oooool2o`3<o`04ooooool0oh?o0?n3o`3oPakooooo0_l0
Pol2o`3oc17ooooo2Ol0ROlSooooo`?o0?n?2?ooool5o`3o`1gooooo0ol0om87ooooo`Co08Wo2omM
0?l7o`29oeKooooo1?l0oeTnooooo`002?ooool3o`0000Wooooo00?o0000ooooooooool0Ooooool0
3_l0XOoo08Woo`3fool0Vooo04coo`3o`?l0oggo02koo`1Iool0ocCo0?o6o`0@ool0=?oo9P3o0_oo
ool01_l0odcooooooooooooooooo02SoofT0o`;ooooo00?o0?ofooooooooool00_ooool01ol0Sooo
ooooooooooooooooJ@3oo`3ol?l0oc@01Oooool01_l0=?ooooooo`3oMooooooo0:koo`3fo`Oooooo
00Go04coooooooooooooooooo`3oO@05ooooo`03o`3Zoooooooooooo00?ooooo00Go05;ooooooooo
oooo0?njoed0o`03ooooo`03o`3oD_oooooooooo00;ooooo00?o6P3oooooooooool02oooool00ol0
;_ooooooooooo`0Fooooo`04o`3<ooooooooooooooooo`;o0?n37_ooool2o`23o`;o0?o<1_ooool9
o`29obWooooo0ol0ohl6ooooo`Go0?o09Oooool;oed0oa;ooooo5ol0ROm3ooooo`Go0?mI>Oooool0
00Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo07oooooo00ko0:7o
o`29ool0m_oo09_oo`1<ool0ol3o0?mmo`0^ool0FOoo0?ldooooool04?oo03CoobH0o`;ooooo00Wo
0?m<ooooooooooooooooo`0XoomY0?ooE`3oo`3oC?l0ooH01?ooool01ol0Sooooooooooooooooooo
J@3oooooool0oc@01?ooool01ol0ob;o03Coo`3oMooooooo0:koooooool0m_l01_ooool01Ol0C?oo
oooooooooooooooo0?mm00Gooooo00?o0>[oooooooooool01?ooool01Ol0D_oo0?njo`3o^_oooooo
G@3o00Cooooo00?o0?mBooooooooool00_ooool00olJ0?ooooooooooo`09ooooo`03o`0^oooooooo
oooo01Sooooo0_l0c?l3ooooo`?o0?n37Oooool2o`23o`Ko08Wo;oooool3o`3oS`Cooooo1Ol0ol0P
ooooo`[oG@3o0oooool4o`3odRgooooo5ol0ROlaooooo`Go0?mI=?ooool000_ooooo00?o0000oooo
ooooool01_ooool5o`0007gooooo00oo0:7oo`29ool0m_oo09_oo`1<ool0ol3o0?mmo`0^ool0FOoo
0?ldooooool04?oo03CoobH0ool0Sol00_ooool01_l0odcoooooooooool0:?ooJ@3ooeL0o`;ooooo
00Go0?ofooooooooooooooooo`2?o`02ooooo`03ofT0ool0oo3o0?ld00Gooooo00Oo03Coooooool0
ogOoooooo`2^oooooooo0?Ko00Kooooo00Co04cooooooooooooo0?mm1Oooool00ol0j_oooooooooo
o`04ooooo`;o0?nj00Go05;ooooooooooooooooooed0o`04ooooo`;o0?mB0oooool00olJ0?oooooo
ooooo`06ooooo`;o02ko7Oooool00ol0c?ooooooooooo`03ooooo`?o0?n35_ooool6o`29o`;o08?o
0_l0ol`^ooooo`?o0?n?0oooool4o`3o`1gooooo2?mM0?lAooooo`Co0?oB@?ooool_o`29o`Oooooo
1Ol0oeT_ooooo`002Oooool2o`0000Wooooo00?o0000ooooooooool0Ooooool03ol0XOoo08Woo`3f
ool0Vooo06_oo`1<ool0oggoooooo`0^ool0ocCoooooo`0@ool0=?oo9P3oo`2?o`03ooooo`05o`3o
C?oooooo02SoofT0oomG0?l00_ooool01?l0ooKoooooooooool0Sol3ooooo`03ofT0ool0oo3o0?ld
00Cooooo00Oo0?lRo`0doooooooo0?mgooooool0[_oo0?Ko00Kooooo00Co04cooooooooooooo0?mm
1_ooool00ol0j_ooooooooooo`02ooooo`;o0?nj0oooool01Ol0D_ooooooooooooooooooG@3o00Go
oooo00Go0?mBoooooooooooooooooaX0o`06ooooo`03o`0^oooooooooooo01kooooo00?o0<cooooo
ooooool01Oooool3o`3oP`kooooo1Ol0ROl8ooooo`;o08?o0_l0ol`Yooooo`?o0?n?00?oooooo`3o
`?l0ol000ol0ol0Jooooo`OoG@3o7Oooool3o`3odVcooooo5ol0ROl8ooooo`Oo6P3o5Oooool000_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1oooooo`0?o`2Qool0ROoo0?Koo`2K
ool0Jooo04coo`3oOOoooooo02koo`1Ioooooooo013ooooooolV0?oo08oo00?ooooo0ol0od`00ol0
:?ooJ@3oooooo`02ooooo`03o`3om_oooooo08oo00;ooooo00CoJ@3oooooool0oo3o0?ld1?ooool0
1ol0ob;o03Coooooool0ogOo0:koooooool0m_l01_ooool00ol0C?ooooooo`3oO@06ooooo`03o`3Z
oooooooooooo00;ooooo00?o0?njooooooooool00oooool01Ol0D_ooooooooooooooooooG@3o00Ko
oooo0_l0oe82ooooo`03oaX0oooooooooooo00;ooooo00?o02koooooooooool08?ooool2o`3<o`So
oooo0ol0oh<6ooooo`Go08Wo3oooool00ol0Poooooooo`3oc002o`3oc2?ooooo0ol0ohl4o`3o`1Oo
oooo2?mM0?lWooooo`Co0?oBNOooool3o`3oF@_o6P3o1ol0ROlEooooo`001oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool0Ooooool03ol0XOoo08Woo`3fool0Vooo06_o
o`1<ool0oggoooooo`0^ool0FOooooooo`0@oooooooo9P3oo`2?o`06ooooo`03o`0XoomY0?oooooo
00;ooooo00So0?ofooooool0SoooooooofT0oooooooo0?o`o`3o=0Cooooo00So0?lRooooool0=?oo
0?mgooooool0[_ooooooo`3fo`Gooooo00?o04coooooool0ogd01_ooool01?l0j_oooooooooooooo
ool2o`3o^POooooo00Go05;ooooooooooooooooooed0o`07ooooo`04o`3oD_oooooooooooaX0o`;o
oooo00?o02koooooooooool08oooool2o`3<o`Wooooo0_l0oh<4o`29oaGooooo0_l0Pol2ooooo`;o
0?o<7_ooool2o`3oS`Co0?o04oooool8oed0oc?ooooo0ol0om9_ooooo`[o6P3o00?oooooo`3oFOl0
oeT00_l0oeTRooooo`002?ooool3o`0000Wooooo00?o0000ooooooooool0Ooooool03ol0XOoo08Wo
o`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOooooooo`3oa_l04?oo9P3oo`2?o`06ooooo`03
o`0XooooooooJ@3o00;ooooo00Co0?ofo`2?ooooooooJ@3o0_ooool00ol0oo3o0?ldooooo`03oooo
o`07o`3o8_l0=?ooooooo`3oMooooooo0:koo`3fo`06ooooo`03o`1<ool0oggooooo00Gooooo00Go
0>[oooooooooooooooooo`3o^P09ooooo`03o`1Boooooooooooo00;ooooo00?oG@3oooooooooool0
1Oooool2o`3oDP03oooooolJ0?oo02ko02Sooooo00?o0<coooooooooool01?ooool4o`29o`04oooo
ool0oh?o0?n3o`3oPaOooooo0_l0Pol2ooooo`;o0?o<6Oooool5o`3o`0oooooo2?mM0?lnooooo`Co
0?oBHoooool8oaX0o`oooooo1?l0oeTNooooo`005?ooool00ol0003oooooooooo`1oooooo`0?o`2Q
ool0j_oo08Woo`2Kool0Jooo04coo`3o`?oooooo02koo`1Ioooooooo0?o6o`0@oolV0?oo08oo00Ko
oooo00?o02SooooooomY0?l00oooool00ol0SoooooooofT0o`02ooooo`03o`3ol?l0ocCooooo00;o
oooo00So0?lRooooool0=?ooooooo`3oMooooooo0:koo`3fo`Gooooo00?o04coo`3oOOooool01_oo
ool01?l0j_ooooooo`3o^_l0okX;ooooo`03o`1Boooooooooooo00;ooooo00?oG@3oooooooooool0
1Oooool2o`0^o`03o`3oD_lJ0?oooooo02Sooooo0_l0c?l01?oooooo08Woo`29ool0ROl8ooooo`?o
0?n35_ooool2o`23o`;ooooo0_l0ol`Cooooo`Co0?o03?ooool8oed0od[ooooo1?l0om9Hooooo`Oo
6P3o6oooool3o`3oFA_ooooo000Dooooo`03o`000?oooooooooo07oooooo013o0:7oo`3Zool0ROoo
09_oo`2^ool0C?oo0?o0ooooool0;_oo05Woo`3o=?l0olKo013oobH0ool0ob;o08oo1Oooool00ol0
:?oooooooeL0o`02ofT0o`03oooooomY0?ooJ@3o00?ooooo00?o0?o`o`3o=?ooool00_ooool02?l0
ob;oooooo`0dool0ogOoooooo`2^oooooooo0?Ko1Oooool00ol0C?ooooooooooo`05ooooo`03o`3Z
oooooooo0?nj00kooooo00?o05;oooooooooool00_ooool00omM0?ooooooooooo`02ooooo`;o02ko
0oooool00ol0oe;o6P3oooooo`0Xooooo`;o08Wo00?o0<coooooooooool02oooool3o`3oPaGooooo
0ol0Pol01?oooooo0?o<o`3oc?l0ol`<ooooo`Co0?o00_l0ohl6ooooo`SoG@3oE_ooool4o`3odTco
oooo2?lJ0?lUooooo`Co0?mI5oooool001Cooooo00?o0000ooooooooool0Ooooool04?l0XOoo0>[o
o`29ool0Vooo0:koo`1<ool0ol3oooooo`0^ool0FOoo0?ldo`3oa_l04?oo9P3oo`3o8_l0Sol5oooo
o`04o`0XooooooooE`3oooooo`?oJ@3o00Go0?ofoooooooooooo0?o`o`3o=003ooooo`08o`3o8_oo
oooo03Coooooool0ogOoooooo`2^ool0m_l5ooooo`03o`1<ool0oggooooo00Gooooo00?o0>[ooooo
ool0okX03oooool00ol0D_ooooooooooo`03ooooo`04oed0oooooooo02koo`0^o`Kooooo00?o0?mB
oaX0ool0oe809Oooool2o`29o`?ooooo00?o0<coooooooooool03Oooool4o`3oPaCooooo0_l0Pol2
ooooo`?o0?o<1Oooool4o`3o`0?o0?n?0_ooool7oed0of;ooooo0ol0om91ooooo`So6P3o<Oooool2
o`3oFAGooooo000Dooooo`03o`000?oooooooooo07oooooo013o0:7oooooool0ROoo09_oo`2^ool0
C?oo0?o0ooooool0;_oo05Woo`3o=?l0olKo013oobH0ool0ob;o08oo1Oooool01_l0:?oooooooooo
oomG0?ooooooo`2?o`;ooooo00Co0?ofooooool0oo3o0?ld0oooool02?l0ob;oooooo`0doooooooo
0?mgooooool0[_oo0?Ko1Oooool00ol0C?ooooooooooo`04ooooo`03o`3Zoooooooo0?nj017ooooo
00Co05;ooooooooooooooooo0_l0;_l00omM0?ooooooooooo`08ooooo`;o6P3o0_l0oe8Pooooo`;o
08Wo1_ooool2o`3<oa7ooooo0ol0oh<Cooooo`;o08?o0oooool3o`3oc0;o0?o000?ooooooed0oomM
0?l01_mM0?m/ooooo`Co0?oB=_ooool7oaX0oe3ooooo000Dooooo`03o`000?oooooooooo07oooooo
017o0:7oooooool0ROoo09_oo`2^ool0C?oo0?o0ooooool0;_oo05Woo`3o=?oooooo013oo`0doolV
0?ooooooo`2?o`04ooooo`06o`0XoooooooooooooeL0oooooooo08oo0oooool00ol0ooKo0?o`o`3o
=003ooooo`04o`3o8_oooooo03Coo`3oM`;ooooo00?o0:koo`3fooooool01?ooool00ol0C?oooooo
ooooo`04ooooo`03o`3Zool0ok[ooooo017ooooo00Co05;oo`0^ool0;_oo02ko0oooool00omM0?oo
ooooooooo`09ooooo`;o6P3o0ol0oe8Kooooo`;o08Wo2_ooool2o`3<oa;ooooo1?l0oh<Aooooo`03
o`23oomM0?ooG@3o00KoG@3oN?ooool4o`3odRSooooo0_l0oe88oaX0od;o0?mB5Oooool001Cooooo
00?o0000ooooooooool0Ooooool04Ol0XOooooooo`29ool0Vooo0:koo`1<ool0ol3o0?mmo`0^ool0
FOoo0?ldooooool04?oo03CoobH0oooooooo08oo00Cooooo00Go02SoooooooooooooE`3oo`2?o`05
ooooo`05o`3om_ooooooooooooooool0ob800_ooool01Ol0=?oo0?mgooooool0[_oo0?Ko00Gooooo
00?o04coooooooooool01?ooool00ol0j_oo0?njooooo`0@ooooo`?o02ko00?o05;oooooooooool0
1?ooool2oed0o`_ooooo00?o6P3oooooooooool00ol0oe8Fooooo`;o08Wo3_ooool2o`3<oaCooooo
1?l0oh<7ooooo`OoG@3o0_ooool3o`23o`;ooooo0ol0olaYoooooa7o0?mB1?l0om8No`3oDPSo6P3o
Goooool001Cooooo0ol0001oooooo`0Ao`2Qoooooooo08Woooooool0Vooo04coo`3o`?l0oggo02ko
o`1Iool0ocCoooooo`0@oooooooo9P3oooooool0Sol01Oooool01?l0:?oooooooooooomG0?l5oooo
o`0<o`3ol?l0ooKo0?ofooooool0ob;oooooo`0doooooooo0?mgooooool0[_oo0?Ko1Oooool00ol0
C?ooooooooooo`04ooooo`03o`3Zoooooooooooo00_ooooo1Ol0;_l4ooooo`03o`1Boooooooooooo
00Gooooo00?oG@3oooooooooool02Oooool2oaX0o`?ooooo2_l0oe8:ooooo`;o08Wo4_ooool00ol0
c?ooooooooooo`0Eooooo`OoG@3o0ol0ol03ooooo`?o0?n?0oooool4o`23o`04ooooool0olco0?o<
o`3oc5Cooooo4_l0oe8Eooooo`Go0?oB4_ooool7oaX0ofOooooo000Dooooo`03o`000?oooooooooo
07oooooo017o0:7oooooool0ROoo0?Koo`2Kool0C?oo0?o0o`3oOOl0;_oo05Woooooool0ocCo013o
oooooolV0?oo0?lRo`2?o`05ooooo`04o`0Xoooooooo08oooeL0o`Cooooo00Co0?o`o`3o=?oooooo
oooo0ol0ooH01_l0=?oo0?ofo`3om_l0ooKo0:koo`3fo`Co0?of00?o04coooooooooool01?ooool0
0ol0j_ooooooooooo`08ooooo`Co02ko2Oooool00ol0D_ooooooooooo`06ooooo`03oed0oooooooo
oooo00[ooooo0_lJ0?l;ooooo`So0?mB0_l0ROlEooooo`;o0<co3oooool6oed0o`?ooooo0ol0ol00
1?l0oh?oooooooooooooool3o`3oS`[ooooo0ol0Pol01?oooooo0?o<o`3oc?l0ol`XooooobWo0?mB
;?ooool5o`3odPGooooo2?lJ0?m^ooooo`005?ooool00ol0003oooooooooo`1oooooo`0Ao`2Qoooo
oooo08Woo`3fool0Vooo04coo`3o`?l0oggo02koo`1Ioooooooo0?ldo`0@oooooooo9P3oo`3o8_l0
Sol01Oooool01?l0:?ooooooo`2?oomG0?l4ooooo`05o`3ol?ooooooooooooooool0ob800_ooool0
1_l0=?oo0?mgoooooooooooo0:koo`3fo`Cooooo00Co04coo`3om_l0ooKo0?of0_ooool00ol0ok[o
0>[oooooo`06ooooo`?o02ko3_ooool00ol0D_ooooooooooo`06ooooo`03oed0oooooooooooo00_o
oooo0_lJ0?l@ooooo`03o`29oooooooo0?mB00So0?mB3oooool2o`3<o`Cooooo2OmM0?l5ooooo`Co
0?o01?ooool00ol0oh?o0?n?o`3oS`02o`3oP`kooooo1?l0Pol3o`3oc1[ooooo2ol0oe9Gooooo`So
6P3oM_ooool001Cooooo00?o0000ooooooooool0P?ooool04Ol0XOoo08Woo`3fool0Vooo04coo`3o
`?l0oggoooooo`0^ool0FOoo0?ldo`0@oooooooo9P3oo`3o8_oooooo08oo00Cooooo00Co02Soo`2?
ooooooooE`3o1?ooool01?l0oo3oooooooooool0ob82ooooo`06o`0doooooooo0?mgooooool0[_oo
0?Ko1?ooool00ol0C?ooooooooooo`02ooooo`03o`3om_l0ok[o0>[o00Oooooo00?o02kooooooooo
ool03oooool00ol0D_ooooooooooo`07ooooo`?oG@3o3?ooool00olJ0?ooooooooooo`0;ooooo`;o
08Wo2oooool7o`3oDP?ooooo2omM0?l;ooooo`?o0?o01_ooool3o`3oS`Cooooo1Ol0oh<=ooooo`Co
08?o0_l0ol`5oooooa;o0?mBFoooool7oaX0o`Oooooo1Ol0om9booooo`005?ooool00ol0003ooooo
ooooo`20ooooo`0?o`2Qool0ROoo0?Koo`2Kool0C?ooooooo`3o`?oooooo02koo`1Iool0ocCo013o
oooooolV0?oo0?lR00;ooooo00Ko08ooooooooooooooooooo`0Xool0Sol2ooooo`05oeL0oooooooo
ooooooooool0oo000_ooool02Ol0ob;oooooooooool0=?ooooooo`3oMooooooo0:koo`3fo`04oooo
o`03o`1<oooooooooooo00;ooooo00?o0?njo`3Zool0ooH01Oooool2o`0^oa?ooooo00?o05;ooooo
ooooool02Oooool2oed0o`_ooooo0olJ0?l8ooooo`;o08Wo3?ooool;oed0o`So0?mB0_l0c?l3o`3o
DPKooooo0ol0ol06ooooo`?o0?n?1Oooool7o`3oDPGo0?n33?l0oe84o`23o`03o`3oc?l0oe;o0?mB
06Kooooo1olJ0?lCooooo`Co0?oBK_ooool001Cooooo00?o0000ooooooooool0P?ooool03ol0XOoo
08Woo`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOoo0?ldo`0@oooooooo9P3oo`3o8P03oooo
o`04o`2?oooooooo08ooo`0Xo`?ooooo00OoE`3ooooooooooooo0?o`o`3o=?oooooo0?lR00?ooooo
00Ko03Coooooool0ogOoooooo`2^ool0m_l3ooooo`03o`3oOOl0C?oooooo00?ooooo00Co0?njo`3Z
oooooooo0?of0oooool00ol0;_ooooooooooo`0Dooooo`03o`1Boooooooooooo00[ooooo0omM0?l;
ooooo`?o6P3o1?ooool00ol0ROooooooooooo`0<oed0oaGooooo0_l0c?l00ooooooo0?mBo`3oDP04
o`3o`0Ko0?mB0ol0ohl8o`3oDPcooooo1Ol0oh<;ooooo`?o08?o00?o0?o<ooooooooool0GOooool6
oaX0oakooooo1?l0om9>ooooo`Oo08?o5Oooool001Cooooo00?o0000ooooooooool0P?ooool03ol0
XOoo08Woo`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOoo0?ldo`0@oooooooo9P3oo`3oS`04
ooooo`;o08oo00Go02SooooooooooooooooooeL0o`02ooooo`04o`3ol?ooooooooooo`3o8P?ooooo
00Ko03Coo`3oMoooooooooooo`2^ool0m_l3ooooo`03o`1<oooooooooooo00;ooooo00?o0?njo`3Z
ooooool00_ooool00ol0ooKo02koo`0^o`0Gooooo`03o`1Boooooooooooo00gooooo5OmM0?lSoooo
o`;o0<co00?o0?o0ooooooooool01Oooool3o`3oSacooooo1Ol0oh<9ooooo`Co08?oE_ooool6oaX0
obSooooo1?l0om8mooooo`go08?o7?ooool001Cooooo00?o0000ooooooooool0P?ooool04?l0XOoo
08Woo`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOoo0?ldooooool04?oo9P3oo`3oSol0ob86
ooooo`04o`0XoooooooooooooeL0o`;ooooo00?o0?o`ooooool0ob800oooool00ol0=?ooooooo`3o
M`02ooooo`06o`2^ooooooooooooooooool0oggo04co0oooool00ol0ok[oooooo`3Zo`03ooooo`03
o`0^ool0ooKooooo01Sooooo00?o05;oooooooooool06_ooool2o`29o`04oooooolJ0?oo6P3ooaX0
ob3ooooo1?l0ol02ooooo`;o0<co0oooool3o`3oSbCooooo1_l0oh<7ooooo`Co08?oC?ooool6oaX0
oc;ooooo1?l0om8]ooooo`co08?o:Oooool001Cooooo00?o0000ooooooooool0P?ooool04?l0XOoo
08Woo`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOoo0?ldooooool04?oo9P3oo`3oSol0ob86
ooooo`04o`0XoooooooooooooeL0o`;ooooo00?o0?o`ooooool0ob800oooool01_l0=?ooooooo`3o
Mooooooo0:koo`3fo`?ooooo00?o0?mmo`1<ooooool00_ooool00ol0ok[o0>[oooooo`02ooooo`04
o`0^ooooooooooooo`3omQWooooo00?o05;oooooooooool06?ooool00ol0ROooooooooooo`04oooo
o`?o6P3o6_ooool3o`3o`0Sooooo00?o0<coo`3oSol0ohl0;Oooool6o`3oP`Cooooo00?o0?o<o`23
ool0Pol00ol0Polnooooo`Wo6P3o??ooool4o`3odQkooooo2ol0Poleooooo`005?ooool00ol0003o
ooooooooo`20ooooo`0@o`2Qool0ROoo0?Koo`2Kool0Jooo04coo`3o`?oooooo02koo`1Ioooooooo
0?ldo`0@ool0=?oo9P3oo`3o8PKooooo00So02SooooooooooooooooooeL0ool0oo3oooooo`3o8PCo
oooo00Ko03Coooooool0ogOoooooo`2^ool0m_l2ooooo`03o`3oOOl0C?oooooo00;ooooo00?o0?nj
ooooool0j_l00_ooool00ol0;_ooooooooooo`02ooooo`03o`3om_oooooooooo01Oooooo00?o05;o
ooooooooool05_ooool00ol0ROooooooooooo`08ooooo`?o6P3o4oooool4o`3o`0Sooooo0ol0ohl0
0ooooooo0<coo`3<o`0cooooo`Ko0?n300Coooooo`3oc?l0olco0?o<1Ol0Pol^ooooo`_o6P3oBOoo
ool4o`3odPkooooo3?l0Pom0ooooo`005?ooool00ol0003oooooooooo`20ooooo`0@o`2Qool0ROoo
0?Koo`2Kool0Jooo04coo`3o`?oooooo02koo`1Ioooooooo0?ldo`0@oooooooo9P3oo`3o8PKooooo
00So02SooooooooooooooooooeL0ool0oo3oooooo`3o8P?ooooo00?o03Coooooool0ogL00_ooool0
1_l0[_oo0?Kooooooooooooo0?mmo`1<o`?ooooo00Go0?njo`3Zooooooooooooo`0^o`05ooooo`03
o`3om_oooooooooo01Sooooo00?o05;oooooooooool05?ooool00ol0ROooooooooooo`0<ooooo`?o
6P3o3Oooool3o`3o`0Wooooo0ol0ohl6ooooo`;o0<co=oooool4o`3oP`?o0?o<0_ooool6o`23oako
oooo2_lJ0?mHooooo`?o0?oB2ol0Pom<ooooo`005?ooool3o`00083ooooo017o0:7oo`3Zool0ROoo
09_oo`1[ool0C?oo0?o0o`3oOOl0;_oo05Woooooool0ocCo013ooooooolV0?ooooooo`3o8P06oooo
o`07o`0XoooooooooooooeL0ool0oo3oooooo`3o8P03ooooo`03o`0doooooooo0?mg00;ooooo00Ko
0:koo`3foooooooo0?mmooooool0C?l2ooooo`05o`3o^_oooooo0>[oooooool0;_l01oooool00ol0
ooKoooooooooo`0Gooooo`03o`1Boooooooooooo01;ooooo0_l0ROlBooooo`Co6P3o1_ooool3o`3o
`0Wooooo0ol0ohl;ooooo`;o0<co??ooool3o`3oc0Co0?n300?oooooo`23ool0Pol01?l0Pol@oooo
o`So6P3oFOooool<o`23o`03ooooool0om;o0?oB00?o0?oBDOooool001Cooooo00?o0000oooooooo
ool0P?ooool04Ol0XOoo0>[oo`29ool0Vooo06_oo`1<ool0ol3o0?mmo`0^ool0FOooooooo`3o=?l0
4?ooooooobH0oooooooo0?lR00Kooooo00Ko02SoooooooooooooE`3oo`3ol?l0ob84ooooo`06o`0d
oooooooo0?mgooooool0[_oo0?Ko0_ooool01ol0oggo04cooooooooooooo0?njooooool0j_l00_oo
ool00ol0;_ooooooooooo`06ooooo`03o`3om_oooooooooo01Oooooo00?o05;oooooooooool04?oo
ool00ol0ROooooooooooo`0Fooooo`?o6P3o0ol0ol09ooooo`?o0?n?4?ooool2o`3<ocgooooo0ol0
ol`00ooooooo0?n3o`3oP`05o`3oP`Wo08?o1olJ0?mFooooo`_o08?o4_ooool5o`3odTcooooo000D
ooooo`03o`000?oooooooooo083ooooo017o0:7oo`3Zool0ROoo09_oo`1[ool0C?oo0?o0o`3oOOl0
;_oo05Woooooool0ocCo013ooooooolV0?ooooooo`3o8P06ooooo`06o`0XoooooooooooooeL0ool0
oo3o0?lR1?ooool02_l0=?oo0?mgoooooooooooo0:koo`3foooooooo0?mmooooool0C?l2ooooo`05
o`3o^_l0j_ooooooooooool0;_l02_ooool00ol0ooKoooooooooo`0Gooooo`03o`1Boooooooooooo
00kooooo00?o08Woooooooooool05_ooool3o`3o`003oooooolJ0?oo6P3o00;o6P3o1Oooool3o`3o
SaGooooo0_l0c?lnooooo`Co0?o<0oooool:oaX0o`oo08?o=_oooolHo`23ob;ooooo1?l0om98oooo
o`005?ooool00ol0003oooooooooo`20ooooo`0Bo`2Qool0j_oo08Woo`2Kool0[_oo04coo`3o`?l0
oggo02koo`1Iool0oo3o0?ldo`0@oooooooo9P3oo`3oSooooooo0?lR1_ooool01?l0:?ooooooo`3o
l?mG0?l4ooooo`03o`0doooooooo0?mg00;ooooo00co0:koo`3foooooooo0?mmooooool0C?oooooo
o`3o^_oooooo0>[oooooool0;_l;ooooo`03o`3om_oooooooooo01Sooooo00?o05;oooooooooool0
3?ooool00ol0ROooooooooooo`0Dooooo`?o0?o02?ooool6oaX0oaWooooo00?o0<coooooooooool0
=oooool;oaX0o`Wooooo2?l0oh<8ooooocKo08?o?_ooool5o`3odT?ooooo000Dooooo`03o`000?oo
oooooooo083ooooo01;o0:7oo`3Zool0ROoo0?Koo`2Kool0C?ooooooo`3o`?l0;_oo05Woo`3ol?oo
oooo013ooooooolV0?oo0?n?ooooool0ob86ooooo`04o`0Xool0ocCo0?o`oeL0o`Cooooo00?o03Co
ooooool0ogL00_ooool02ol0[_oo0?Koo`3oOOoooooo04coooooool0ok[oooooo`3Zoooooooo02ko
00gooooo00?o0?ofooooooooool05oooool00ol0D_ooooooooooo`0;ooooo`03o`29oooooooooooo
01?ooooo0_l0ol0:ooooo`?o0?n?1?ooool6oaX0oaCooooo0_l0c?l[ooooo`co6P3o2oooool3o`3o
c0kooooo1ol0oh=jooooo`Go0?oB?_ooool001Cooooo00?o0000ooooooooool0P?ooool04?l0XOoo
ooooo`29ool0m_oo09_oo`1<oooooooo0?o0ooooool0;_oo05Woooooool04?ooooooobH0ool0ohl2
ooooo`03o`3o8_oooooooooo00?ooooo00Go02Soo`3o=?l0oo3ooooooeL0o`03ooooo`0@o`0doooo
oooo0?mgooooool0[_oo0?Koooooool0oggoooooo`1<oooooooo0?njooooool0j_ooooooo`0^o`ko
oooo00?o0?ofooooooooool05oooool00ol0D_ooooooooooo`08ooooo`;o08Wo5?ooool2o`3o`0Wo
oooo0ol0ohl=ooooo`[o6P3o3?ooool2o`3<oakooooo2olJ0?l3ooooomCo0:7o5Oooool001Cooooo
00?o0000ooooooooool0P?ooool04?l0XOooooooo`29ool0m_oo09_oo`1<oooooooo0?o0ooooool0
;_oo05Woooooool04?oo0?o6obH0ool0ohl2ooooo`03o`3o8_oooooooooo00?ooooo00Go02Soo`3o
=?l0oo3ooooooeL0o`02ooooo`03o`0doooooooo0?mg00;ooooo00?o0:koo`3fool0ogd00_ooool0
1_l0C?oo0?njooooool0j_ooooooo`0^oa3ooooo00?o0?ofooooooooool05oooool00ol0D_oooooo
ooooo`06ooooo`03o`29oooooooooooo01;ooooo0_l0ol08ooooo`?o0?n?6_ooool/oaX0o`ko0:7o
6_ooool4o`3oc1Sooooo2ol0oh=_ooooo`Ko0?oB<oooool001Cooooo00?o0000ooooooooool0P?oo
ool04?l0XOooooooo`29ool0m_oo09_oo`1<oooooooo0?o0ooooool0;_oo05Woooooool04?oo0?o6
obH0ool0=?l3ooooo`03o`3o8_oooooooooo00;ooooo00?o0?ldo`0Xooooool00_ooool01OmG0?oo
ooooo`0doooooooo0?mg00;ooooo00?o0:koo`3fool0ogd00_ooool01Ol0C?oo0?njooooool0j_oo
02ko017ooooo00?o0?ofooooooooool06?ooool00ol0D_ooooooooooo`04ooooo`03o`29oooooooo
oooo017ooooo0_l0ol08ooooo`;o0?n?;Oooool3o`3<o`Wooooo3ol0XOl]ooooo`Co0?o<7oooool:
o`3oPf_ooooo1Ol0om8^ooooo`005?ooool00ol0003oooooooooo`20ooooo`0@o`2Qoooooooo08Wo
o`3fool0Vooo04coooooool0ol3oooooo`0^ool0FOoo0?o`o`0@ool0olKo9P3oo`0do`Cooooo1?l0
ob800ol0ocCo02Soooooo`02ooooo`05oeL0oooooooo03Coooooool0ogL00_ooool02_l0[_oo0?Ko
oooooooooooo04coooooool0ok[o0>[oooooool0;_lBooooo`03o`3om_oooooooooo01Sooooo0_l0
D_l3ooooo`03o`29oooooooooooo013ooooo0_l0ol07ooooo`?o0?n?<_ooool00ol0c?oo0:7oo`2Q
o`06o`2Qod3ooooo1?l0ol`Uooooo`So0?n3J?ooool6o`3odRSooooo000Dooooo`03o`000?oooooo
oooo083ooooo017o0:7oooooool0ROoo0?Koo`2Kool0C?ooooooo`3o`?oooooo02koo`1Iool0oo3o
013oo`3oa_oooooo9P3oo`3oS`04ooooo`05o`3o8_oooooo0?ldooooool0:?l01?ooool02?mG0?oo
ooooooooool0ogOoooooo`2^ool0m_oo0?mm0_ooool01Ol0C?oo0?njooooool0j_oo02ko01Cooooo
00?o0?ofooooooooool06Oooool00ol0D_ooooooo`29o`0Aooooo`;o0?o01oooool2o`3oSbgooooo
2Ol0XOl2ooooo`;o0<coB?ooool4o`3oc2Wooooo2?l0oh=Vooooo`Go0?oB8oooool001Cooooo0ol0
0020ooooo`0Ao`2Qoooooooo08Woo`3fool0Vooo04coooooool0ol3oooooo`0^ool0FOoo0?o`oooo
ool04?ooooooobH0ool0ohl01_ooool00ol0ocCo0?o`o`0Xo`04ooooo`03oeL0oooooooo0?mg00;o
oooo00?o0:koo`3fool0ogd00_ooool01Ol0C?oo0?njooooool0j_oo02ko01Cooooo00?o0?ofoooo
ooooool06Oooool00ol0ROoo05;oooooo`0?ooooo`;o0?o01oooool2o`3oSb[ooooo1Ol0XOl=oooo
o`?o0<coBOooool4o`3oc2gooooo2_l0oh=Qooooo`Ko0?oB7Oooool001Cooooo00?o0000oooooooo
ool0POooool04?l0XOoo08Woo`3fool0Vooo06_oo`1<ool0ol3oooooo`0^ool0FOoo0?o`ooooool0
4?oo0?ldobH0ool0ohl5ooooo`04o`3o=?oooooo0?o`o`0Xo`Cooooo00?o03CooeL0ool0ogL00_oo
ool02Ol0[_oo0?Kooooooooooooo04coo`3o^_oooooo0>[oo`0^o`0Fooooo`03o`3om_oooooooooo
01Oooooo00Co08Wooooooooooooo05;o3Oooool2o`3o`0Kooooo0ol0ohlVooooo`Ko0:7o5Oooool3
o`3<od[ooooo1?l0ol`cooooo`_o0?n3G?ooool5o`3odQSooooo000Dooooo`03o`000?oooooooooo
087ooooo013o0:7oo`29ool0m_oo09_oo`1[ool0C?oo0?o0o`3oOOl0;_oo05Woo`3ol?oooooo013o
o`3o=?lV0?oo03Co1Oooool01Ol0ocCoooooo`3ol?oooooo02So00?ooooo00?o03CooooooomG0?l0
0_ooool02Ol0[_oo0?Kooooooooooooo04coo`3o^_oooooo0>[oo`0^o`07ooooo`Oo0?n?2Oooool0
0ol0ooKoooooooooo`0Eooooo`03o`29oooooooooooo00;ooooo00?o05;oooooooooool02?ooool2
o`3o`0Kooooo0_l0ohlSooooo`Ko0:7o7_ooool2o`3<obgoooooAOlV0?lHooooo`[o0?n3Eoooool3
o`3odQGooooo000Dooooo`03o`000?oooooooooo087ooooo013o0:7oo`29ool0m_oo09_oo`1[ool0
C?oo0?o0o`3oOOl0;_oo05Woooooool0oo3o013oo`3o=?lV0?oo03Co1Oooool01Ol0ocCoooooo`3o
l?oooooo02So00;ooooo00So03Cooooooooooooo0?mgoeL0ool0[_oo0?Koo`3oO@;ooooo00Co04co
ooooool0j_oo02ko1_ooool3o`3oS`Kooooo1Ol0ohl5ooooo`03o`3om_oooooooooo01?ooooo00?o
08Woooooooooool01?ooool2o`1Bo`Kooooo0_l0ol05ooooo`?o0?n?7oooool6o`2QobKooooo0ol0
c?lBoooooaSo9P3o8oooool5o`3oc1gooooo;olV0?mRooooo`005?ooool00ol0003oooooooooo`21
ooooo`0Ao`2Qool0ROoo0?Koo`2Kool0Jooo04coo`3o`?l0oggo02koo`1Ioooooooo0?o`o`0@ool0
ocCo9P3oo`0dool0ohl00oooool00ol0ocCoooooo`3ol002ooooo`06o`0Xooooooooooooo`0doooo
oooo0?mg0_ooool3oeL0o`06ooooool0C?oo0?njooooool0j_oo02ko1?ooool2o`3oS`kooooo0_l0
ohl3ooooo`03o`3om_oooooooooo01;ooooo00?o08Woooooooooool01oooool01?l0D_oooooooooo
ooooool2o`3o`0Gooooo0_l0ohlLooooo`Ko0:7o;oooool3o`3<o`?ooooo3?lV0?m0ooooo`Go0?o<
@_ooool5o`3oPbgo9P3o5oooool9oeL0oaGooooo000Dooooo`03o`000?oooooooooo087ooooo017o
0:7oo`29ool0m_oo09_oo`1[ool0C?ooooooo`3o`?l0;_oo05Woooooool0oo3o013ooooooolV0?oo
03Coo`3oS`03ooooo`03o`3o=?oooooo0?o`00;ooooo00Ko02Sooooooooooooo03Coooooool0ogL2
ooooo`03o`2^ool0m_oooooo00WoE`3o00?o0?n?ooooooooool04?ooool2o`3oS`;ooooo00?o0?of
ooooooooool03oooool2o`29o`_ooooo00?o05;oo`3o`?l0ol001Oooool2o`3oSa[ooooo1?l0XOlb
ooooo`Wo9P3oDOooool4o`3oc4Gooooo2_l0oh<<ooooobcoE`3o2OlV0?lEooooo`005?ooool00ol0
003oooooooooo`21ooooo`0Ao`2Qool0ROoo0?Koo`2Kool0Jooo04coooooool0ol3oooooo`0^oooo
oooo0?o`o`0@oooooooo9P3oo`0dool0ohl00_ooool01?l0ocCoooooooooool0oo03ooooo`05o`0X
ool0=?ooooooooooool0ogL00_ooool02?l0[_oo0?Kooooooooooooo04coooooool0j_oo02ko0_oo
ool2o`3oS`?oE`3o4_ooool01?l0ohooooooooooool0ooH?ooooo`03o`29oooooooooooo00[ooooo
0_l0ol001?l0D_ooooooooooooooool3o`3oSaWooooo0ol0XOl/ooooo`[o9P3o2Oooool3o`3<oe;o
oooo1Ol0ol`noooooaSoE`3o:_ooool;o`3oaQGooooo000Dooooo`03o`000?oooooooooo087ooooo
01?o0:7oo`3Zool0ROoo09_oo`1[ool0C?ooooooo`3o`?oooooo02koooooool0oo3o013oo`3oa_oo
oooo9P3oo`0doooooooo0?ld00;ooooo00?o0?o`ooooooooool00_ooool01Ol0:?oo03Cooooooooo
oooo0?mg00;ooooo00[o0:koooooooooooooooooo`1<oooooooo0>[oo`0^oooooooo0?n?1Oooool2
oeL0oa7ooooo0_l0ohl00ooooooo0?ofooooo`0<ooooo`03o`29oooooooooooo00Wooooo0_l0ol03
ooooo`03o`1Bool0ohoo0?n?01Wooooo0ol0XOlZooooo`Go9P3o5_ooool4o`3<oe?ooooo1?l0ol`S
oooooaOoE`3o6?ooool<o`3oP`kooooo4?l0olHPooooo`005?ooool00ol0003oooooooooo`21oooo
o`0Bo`2Qool0j_oo08Woo`2Kool0Jooo04coooooool0ol3oooooo`0^ool0FOooooooo`0@ool0olKo
ooooobH0ool0=?oo0?ld0oooool00ol0oo3oooooooooo`02ooooo`08o`0Xool0=?ooooooooooool0
ogOoooooo`2^ool0m_l2ooooo`06o`1<oooooooo0>[oo`0^oooooooo0?n?2?ooool00omG0?oooooo
ooooo`0@ooooo`03o`3oSol0ooKooooo00_ooooo00?o08Woooooooooool02?ooool2o`3o`0?ooooo
0ol0ohl2o`1BoaKooooo0ol0XOlWooooo`Ko9P3o7oooool3o`3<oeCooooo1Ol0ol`7oooooaOoE`3o
>oooool3o`3oP`_o0?o6<?ooool001Cooooo00?o0000ooooooooool0POooool04_l0XOoo0>[oo`29
ool0Vooo06_oo`1<oooooooo0?o0ooooool0;_oo05Woooooool04?oo0?o6oooooolV0?oo03Coo`3o
S`;ooooo00?o0?o`ooooooooool00oooool01?l0=?oo02Soooooool0ogL2ooooo`0:o`2^ool0m_oo
ooooooooool0C?ooooooo`3Zool0;_ooooooo`3oS`Wooooo0_mG0?lBooooo`03o`3om_l0ohoo0?n?
00Oooooo0_l0ROl9ooooo`;o0?o00_ooool3o`3oS`Gooooo0_l0D_lBooooo`;o0:7o9Oooool5obH0
obSooooo0ol0c?m5oooooaSoE`3oBOooool<o`3oaPSooooo3?l0oh<Wooooo`005?ooool00ol0003o
ooooooooo`21ooooo`0Bo`2Qool0j_oo08Woooooool0Vooo04coooooool0ol3oooooo`0^ool0FOoo
ooooo`0@ool0olKoooooobH0ool0=?oo0?n?0_ooool00ol0oo3oooooooooo`03ooooo`04o`0dool0
:?ooooooo`3oM`;ooooo00Wo0:koo`3fooooooooooooo`1<oooooooo0>[oo`0^ool0ohl02Oooool3
o`3o`003oeL0ool0ol3o0?o000?o0?o03Oooool00ol0ooKoooooo`3oS`02o`3oS`?ooooo00?o08Wo
ooooooooool01oooool2o`3o`004ooooool0ohoo0?n?o`3oS`[ooooo00?o05;oooooooooool03?oo
ool3o`2Qob7ooooo1_lV0?l`ooooo`Co0<co:_oooolGoeL0oaKooooo1?l0ol`kooooo`co0?o68?oo
ool<o`3oPa_ooooo000Dooooo`?o0000POooool04_l0XOoo0>[oo`29oooooooo09_oo`1<oooooooo
0?o0o`3oOOl0;_oo05Woooooool04?oo0?o6oooooolV0?oo03Coo`3oS`;ooooo00?o0?o`oooooooo
ool00oooool01?l0=?ooooooo`0Xool0ogL2ooooo`08o`2^ool0m_ooooooo`1<oooooooo0>[oo`0^
ool0ohl8ooooo`;o0?o01?ooool00omG0?ooooooooooo`02ooooo`Go0?o02Oooool01Ol0ooKooooo
oooooooooooo0?n?00;o08Wo2?ooool2o`3o`0?o0?n?3_ooool2o`1Bo`Wooooo0ol0XOlOooooo`Go
9P3o>_ooool3o`3<oaGooooo4_mG0?laooooo`Go0?o<9OoooolAo`3oaSSooooo1_l0oh<Eooooo`00
5?ooool00ol0003oooooooooo`21ooooo`0Do`2Qool0j_oo08Woooooool0Vooo04coooooool0ol3o
0?mmo`0^ool0FOooooooo`0@ool0olKoooooobH0oooooooo03Coooooool0oo05ooooo`08o`0doooo
ooooooooooooool0:?ooooooo`2^ool0m_l2ooooo`04o`1<oooooooo0>[oo`0^o`Oooooo0_l0ol06
ooooo`03oeL0oooooooooooo00Oooooo0ol0ol07ooooo`05o`3om_ooooooooooo`29ooooool01_l0
ohl3o`3o`003o`3oSooooooooooo01;ooooo0_l0D_l4ooooo`?o0:7o7?ooool6obH0od;ooooo1?l0
c?l6ooooo`_oE`3oB?ooool4o`3oc17ooooo4?l0olITooooo`005?ooool00ol0003oooooooooo`21
ooooo`0>o`2Qool0j_oo08Woo`3fool0Vooo04coooooool0ol3o0?mmo`0^ool0FOooooooo`0@ool0
olH2ooooo`04obH0ool0=?ooooooo`3ol0Gooooo00So03Cooooooooooooo0?mgo`0Xoooooooo0:ko
o`3fo`;ooooo00Co04coooooool0j_oo02ko1_ooool00ol0ol3oooooooooo`07ooooo`03oeL0oooo
oooooooo00Wooooo1?l0ol04ooooo`;o08Wo1?ooool4o`3o`1[ooooo0_l0D_l2o`2QoaWooooo1_lV
0?m8ooooo`[oE`3oEoooool5o`3oc0Cooooo2?l0olIdooooo`005?ooool00ol0003oooooooooo`21
ooooo`06o`2Qool0j_oo08Woo`3fool0Vooo04co0_ooool00ol0ol3o02koo`1Io`02ooooo`07o`0@
ooooooooooooobH0ool0=?ooooooo`3ol004ooooo`0>o`0dooooooooooooooooool0ogOoooooo`0X
ool0[_oo0?Koooooool0C?ooooooo`3Zool0;_l6ooooo`03o`3o`?oooooooooo00Wooooo00?oE`3o
ooooooooool03?ooool01_l0ol3o08Woo`29ool0ROoo0?o0o`3omPCo0?o07_ooool2o`2Qo`;o05;o
5Oooool4obH0odKooooo2?mG0?l9ooooo`Co0<coEOooool4o`3oaPGo0?o<Noooool001Cooooo00?o
0000ooooooooool0POooool01_l0XOoo0>[oo`29ool0m_oo09_oo`1<o`;ooooo00?o0?o0o`0^ool0
FOl00_ooool01_l04?oo0?o6oooooolV0?oo03Coo`3ol0Gooooo00ko03Coooooooooooooooooo`3o
Mooooooo0?mmo`0Xool0m_ooooooo`1<oooooooo0>[oo`0^o`Kooooo00?o0?o0ooooooooool02_oo
ool00omG0?ooooooooooo`0:ooooo`;o08Wo1Oooool00ol0ooKoooooooooo`0Nooooo`03o`2Qoooo
oooooooo00;ooooo00?o05;oooooooooool03oooool3obH0od?ooooo1omG0?lEooooo`Co0<coB?oo
ool9o`3oaPWooooo1Ol0olafooooo`005?ooool00ol0003oooooooooo`21ooooo`06o`2Qool0j_oo
08Woo`3fool0Vooo04co0_ooool00ol0ol3o02koo`1Io`02ooooo`06o`0@ool0oo3oooooobH0ool0
oo3o03Co1?ooool00ol0=?ooooooooooo`02ooooo`0:o`3oMooooooo0:koo`3fool0:?ooooooo`1<
ool0ohoo0>[oo`0^o`Gooooo00?o0?o0ooooooooool02oooool00omG0?ooooooooooo`04ooooo`Ko
08Wo2?ooool00ol0ooKoooooooooo`0Looooo`03o`2Qoooooooooooo00Cooooo0_l0D_l<ooooo`?o
9P3o?oooool7oeL0ob3ooooo1Ol0c?lhooooo`_o0?o65oooool5o`3oc77ooooo000Dooooo`03o`00
0?oooooooooo087ooooo00Ko0:7oo`3Zool0ROoo0?Koo`2Kool0C?l2ooooo`03o`3o`?oooooo02ko
00;ooooo00Oo013oo`3oa_l0oo3o9P3oo`3ol?l0ohoo03Co00;ooooo00?o03Coooooooooool00ooo
ool01Ol0ogOo0?mmo`2^ool0m_oooooo00;o02So00?o0>[oo`0^ooooool01?ooool00ol0ol3ooooo
ooooo`0<ooooo`03o`29oomG0?oo08Wo00Co08Wo3oooool00ol0ooKoooooooooo`0Iooooo`;o0:7o
2Oooool2o`1Bo`Oooooo0olV0?llooooo`KoE`3o;?ooool4o`3<ob[ooooo2_l0olHWooooo`Go0?o<
K?ooool001Cooooo00?o0000ooooooooool0POooool02ol0XOooooooo`29ool0m_oo09_oo`1[ool0
C?ooooooo`3o`?l0oggo02ko00;ooooo00Ko013oo`3oa_ooooooooooobH0ool0ohl3o`0do`Gooooo
00So0?mgooooool0oggo0:koo`3foooooooo04coo`3oS`?o02So0oooool00ol0ol3oooooooooo`0:
ooooo`?o08Wo0_ooool00omG0?ooooooooooo`0Booooo`03o`3om_oooooooooo01Oooooo00?o0:7o
ooooooooool02oooool2o`1Bo`;ooooo0olV0?ljooooo`GoE`3o=_ooool5o`3<oagooooo2?l0olHf
ooooo`Ko0?o<I_ooool000Wooooo0ol00008ooooo`03o`000?oooooooooo087ooooo00_o0:7ooooo
ool0ROoo0?Koo`2Kool0Jooo04coooooool0ol3o0?mmo`0^o`02ooooo`07o`0@ool0olKooooooooo
oolV0?ooooooo`3oS`07ooooo`0;o`3oMooooooo0?mmo`2^ool0m_ooooooo`1<oooooooo0>[oo`0^
ooooool01Ol0:?l8ooooo`?o08Wo1Oooool00omG0?ooooooooooo`0Cooooo`03o`3om_oooooooooo
01Cooooo0_l0XOl?ooooo`?o9P3o=oooool6oeL0od3ooooo1Ol0c?lAooooo`Oo0?o6A?ooool5o`3o
c67ooooo000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0POooool02ol0XOoo
ooooo`29ool0m_oo09_oo`1[ool0C?ooooooo`3o`?l0oggo02ko00;ooooo00Oo013oooooool0olKo
ooooobH0oooooooo0?n?00Oooooo00Wo0?mgo`3oOOl0[_oo0?Koooooool0ok[o04coooooool0;_l0
1?ooool01?l0ol3oooooooooool0:?l5ooooo`;o08Wo2Oooool00omG0?ooooooooooo`0Cooooo`;o
0?of4oooool00ol0XOooooooooooo`0<ooooo`?o9P3o0_ooool2o`1Boc7ooooo1OmG0?m;ooooo`Go
0<co1?ooool8o`3oaU3ooooo1_l0olaKooooo`001oooool5o`0000Sooooo00?o0000ooooooooool0
P_ooool04Ol0XOoo08Woo`3fool0Vooo06_oo`1<oooooooo0?o0o`3oOOl0;_oo05Woooooool04?oo
ooooo`3oa_oooooo9P3o00;ooooo00?o0?n?ooooooooool01?ooool02Ol0ogOo0?mmo`2^ool0m_oo
ooooo`1<oooooooo0>[oo`0^o`03ooooo`03o`3o`?oooooooooo00;ooooo0_l0:?l2ooooo`03o`29
oooooooooooo00[ooooo00?oE`3oooooooooool05?ooool2o`3omQ3ooooo00?o0:7oooooooooool0
2oooool2obH0o`Oooooo0_l0D_lZooooo`GoE`3oDOooool4o`3oaPGo0<coGOooool6o`3oc5Gooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo1Ol00020ooooo`0Ao`2Qool0ROoo0?Koo`2Kool0
Jooo04coooooool0ol3o0?mmo`0^ool0FOooooooo`0@oooooooo0?o6oooooolV0?l00_ooool00ol0
ohooooooooooo`04ooooo`08o`3oMol0oggo0:koo`3fool0ohoo04coooooool0;_l4ooooo`03o`3o
`?oooooooooo00Cooooo00?o02SoobH0oolV0?l00olV0?l9ooooo`03oeL0oooooooooooo01Kooooo
0_l0ooH<ooooo`;o0:7o3?ooool2obH0o`_ooooo0_l0D_lSooooo`GoE`3oC_ooool8o`3oaPWooooo
1_l0c?mMooooo`Go0?o<D?ooool000Sooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`22ooooo`06o`2Qool0ROoo0?Koo`2Kool0Jooo04co0_ooool01ol0ol3o02koo`1Ioooooooo013o
ooooool0olH00_ooool01?lV0?ooooooooooool0ohl4ooooo`09o`3oMol0oggoooooo`2^ool0m_oo
0?njo`1<oooooooo02ko00?ooooo00?o0?o0ooooooooool01?ooool3obH0o`04o`0Xoooooooooooo
ooooo`?o9P3o1oooool00omG0?ooooooooooo`0Gooooo`03o`3om_oooooooooo00Sooooo00?o0:7o
ooooooooool02_ooool2obH0o`oooooo0ol0D_lKooooo`GoE`3oBoooool8o`3oaQOooooo2?l0c?mJ
ooooo`Ko0?o<B_ooool000Wooooo0_l00009ooooo`03o`000?oooooooooo08;ooooo00Ko0:7oo`29
ool0m_oo09_oo`1[ool0C?l2ooooo`07o`3o`?l0;_oo05Woooooool04?ooooooo`3oaP02ooooo`04
obH0ooooooooooooo`3oS`Cooooo00Wo0?mgo`3oOOoooooo0:koooooool0ok[o04coo`3Zool0;_l0
0oooool00ol0ol3oooooooooo`02ooooo`;o9P3o0_l0ROl2o`3oaP03o`0Xool0olKooooo00?ooooo
0_lV0?l6ooooo`03oeL0oooooooooooo01Oooooo0_l0ooH6ooooo`;o0:7o2oooool2obH0oaCooooo
0_l0D_lDooooo`GoE`3oB?ooool8o`3oaROooooo1ol0c?mIooooo`Go0?o<AOooool000[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`22ooooo`06o`2Qool0ROoo0?Koo`2Kool0Jooo
04co0_ooool01ol0ol3o02koo`1Ioooooooo013oooooool0olH00_ooool01OlV0?oooooooooooooo
oooo0?n?00?ooooo00So0?mgo`3oOOl0[_oo0?Koooooool0ok[o04coo`0^o`?ooooo00Co0?o0oooo
oooooooooooo0_l0olH00olV0?oo08Woooooo`04ooooo`04o`0Xool0olKo0?o6o`3oaP?ooooo0_lV
0?l5ooooo`03oeL0oooooooooooo01Sooooo00?o0?ofooooooooool00_ooool00ol0XOoooooooooo
o`09ooooo`;o9P3o6?ooool2o`1Bo`kooooo1?mG0?m6ooooo`Oo0?o6=_ooool:o`3<oeCooooo1ol0
ol`nooooo`005?ooool00ol0003oooooooooo`22ooooo`06o`2Qool0ROoo0?Koooooool0Jooo04co
0_ooool01Ol0ol3o02koo`1Ioooooooo013o00;ooooo00?o0?o6oooooolV0?l01?ooool5o`3oS`06
o`2^ool0m_ooooooo`1<oooooooo02ko0oooool01?l0ol3oooooooooooooool2obH0o`03ooooool0
ROoooooo00Gooooo00Co02Sooooooooooooo0?o61?ooool00olV0?ooooooooooo`02ooooo`03oeL0
oooooooooooo01Wooooo0_l0ooH2o`2Qo`[ooooo0_lV0?lLooooo`;o05;o1oooool5oeL0od?ooooo
1ol0olI7ooooo`co0<coCoooool8o`3oc3Kooooo000Dooooo`03o`000?oooooooooo08;ooooo00Ko
0:7oo`29ool0m_oo0?njo`1[ool0C?l2ooooo`05o`3o`?l0;_oo05Woooooool04?l00_ooool00ol0
olKoooooobH0o`06ooooo`09o`3oMol0oggoooooo`2^ool0m_oo0?njo`1<ool0;_oo0>[o00;ooooo
00Go0?o0oooooooooooo0?o6obH0o`02ooooo`03o`29oooooooooooo00Gooooo00Go02Sooooooooo
ooooooooo`3oaP04ooooo`03obH0oooooooooooo00;ooooo00?oE`3oooooooooool06Oooool00ol0
XOooooooo`3omP02o`3omPKooooo0_lV0?lPooooo`;o05;o1OmG0?m2ooooo`Ko0?o6F_ooool<o`3<
od_ooooo2?l0ol`^ooooo`005?ooool00ol0003oooooooooo`22ooooo`06o`2Qool0ROoo0?Koo`3o
^_l0Vooo04co0_ooool00ol0ol3o02koo`1Io`02ooooo`03o`0@oooooooo0?o600;ooooo00?o9P3o
ooooooooool00oooool02?l0ogOo0?mmooooool0[_oo0?Koo`3o^_l0C?oo02ko0oooool01ol0ol3o
ooooo`3oa_oooooo9P3oooooool0ROl02Oooool01Ol0:?oooooooooooooooooo0?o600Cooooo00?o
9P3oooooooooool00_ooool00omG0?ooooooooooo`0Gooooo`03o`2Qoooooooooooo00?ooooo1?l0
ooH2obH0ob3ooooo1?mG0?l01?oooooo05;oo`1Bool0D_lmooooo`Ko0?o6K?ooool;o`3<odSooooo
2?l0ol`Vooooo`005?ooool00ol0003oooooooooo`22ooooo`06o`2Qool0ROoo0?Koo`3o^_l0Vooo
04co0_ooool00ol0ol3o0?mmo`0^o`02ooooo`03o`0@oooooooo0?o600;ooooo00?o9P3ooooooooo
ool00oooool02?l0oggoooooooooool0[_ooooooo`3o^_l0C?oo02ko0_ooool01Ol0ol3oooooo`3o
a_oooooo9P3o00;ooooo00?o08Woooooooooool02?ooool01Ol0:?oooooooooooooooooo0?o600Co
oooo00Go9P3ooooooooooooooooooeL0o`0Gooooo`;o0:7o2?ooool2obH0o`Co0?of6Oooool5oeL0
o`Sooooo0_l0D_leooooo`Ko0?o6OOoooolBo`3<ockooooo1ol0ol`4ooooo`Ko05;o5Oooool001Co
oooo00?o0000ooooooooool0P_ooool01_l0XOoo08Woo`3fool0ok[o09_oo`1<o`;ooooo00?o0?o0
o`3oOOl0;_l00_ooool00ol04?ooooooo`3oaP02ooooo`03obH0oooooooooooo00?ooooo00ko0?mm
ooooool0[_oo0?Koooooool0C?oo02koo`3Zoooooooo0?o0ooooool0olKoooooobH0o`;ooooo00?o
08Woooooooooool02_ooool01Ol0:?oooooooooooooooooo0?o600Cooooo00Go9P3ooooooooooooo
oooooeL0o`0Eooooo`03o`2Qoooooooooooo00Kooooo0_lV0?l6ooooo`Co0?of4Oooool4oeL0o`oo
oooo0ol0D_l/ooooo`Ko0?o6UOoooolGo`3<obWooooo2Ol0D_l3o`3oc1Sooooo000Dooooo`03o`00
0?oooooooooo08;ooooo00Ko0:7oo`3Zool0ROoo0?njo`2Kool0C?l2ooooo`03o`3o`?l0oggo02ko
00;ooooo00?o013oooooool0olH00_ooool00olV0?ooooooooooo`03ooooo`07o`3oOOoooooo0:ko
o`3fool0ok[o04coo`0^o`02ooooo`04o`3o`?l0olKoooooobH0o`?ooooo00?o08Woooooooooool0
2_ooool00ol0:?ooooooooooo`02ooooo`03o`3oa_oooooooooo00;ooooo00Go9P3ooooooooooooo
oooooeL0o`0Booooo`;o0:7o2?ooool00olV0?ooooooooooo`0:ooooo`Co0?of2?ooool5oeL0oaKo
oooo0ol0D_lSooooo`Ko0?o6/_oooolHo`3<o`Kooooo2ol0D_l<ooooo`?o0?o<5Oooool001Cooooo
00?o0000ooooooooool0P_ooool01_l0XOoo0>[oo`29ool0ok[o09_oo`1<o`;ooooo00?o0?o0o`3o
OOl0;_l00_ooool01_l04?ooooooooooool0olKoooooobH0o`Cooooo00ko0?mmoooooooooooo0:ko
o`3fool0ok[o02koo`3Zoooooooo0?o0ooooool0olKoooooobH0o`;ooooo00?o08Woooooooooool0
3?ooool00ol0:?ooooooooooo`02ooooo`03o`3oa_oooooooooo00;ooooo00Go9P3ooooooooooooo
oooooeL0o`0?ooooo`;o0:7o2?ooool2obH0oa7ooooo1?l0ooH4oeL0oakooooo0ol0D_lJooooo`Ko
0?o6boooool;o`1Boa[o0<co5Oooool001Cooooo0ol00022ooooo`06o`2Qool0j_oo08Woo`3o^_l0
Vooo04co0oooool01Ol0ol3o02kooooooooooooo013o00;ooooo00Co0?o6oooooooooooo9P3o0ooo
ool03Ol0oggoooooooooool0[_oo0?Koo`3o^_l0;_oo0>[oooooool0ol3o0?o6oooooolV0?l00_oo
ool00ol0ROooooooooooo`04ooooo`[o0:7o00?o02Soooooooooool00_ooool00ol0olKooooooooo
o`02ooooo`05obH0oooooooooooooooooomG0?l03Oooool00ol0XOooooooooooo`06ooooo`;o9P3o
5?ooool3oeL0o`03ooooool0ooKo0?of00;o0?of8?ooool3o`1Boa7ooooo1_l0olK7ooooo`[o05;o
>_ooool001Cooooo00?o0000ooooooooool0P_ooool01_l0XOoo0>[oo`29ool0ok[o09_oo`1<o`?o
oooo00Go0?o0o`0^ool0FOooooooo`0@o`02ooooo`04o`3oa_ooooooooooobH0o`?ooooo00co0?mm
oooooooooooo0:koooooool0ok[o02koo`3Zool0ol3oooooo`3oa_lV0?l2ooooo`03o`29oooooooo
oooo00Cooooo00?o0:7oooooooooool02?ooool00ol0XOoo02Soo`2Qo`03ooooo`03o`3oa_oooooo
oooo00;ooooo00Go9P3ooooooooooooooooooeL0o`0:ooooo`;o0:7o2?ooool00olV0?oooooooooo
o`0Aooooo`?oE`3o2?ooool4o`3omQoooooo0ol0D_l8ooooo`Ko0?o6aOooool8o`1BodCooooo000D
ooooo`03o`000?oooooooooo08;ooooo00Ko0:7oo`3Zool0ROoo0?njo`2Kool0C?l3ooooo`05o`3o
`?l0;_oo05Woooooool04?l00_ooool01?l0olKooooooooooolV0?l2ooooo`0<o`3oOOl0ogOooooo
o`2^ool0m_oo0?njo`0^ool0j_ooooooo`3o`?l0olKo9P3o0oooool00ol0ROooooooooooo`02oooo
o`;o0:7o3?ooool01?l0:?ooooooo`2Qool0XOl2ooooo`03o`3oa_oooooooooo00;ooooo0_lV0?l2
ooooo`03oeL0oooooooooooo00Kooooo00?o0:7oooooooooool01_ooool2obH0oa7ooooo0omG0?l?
ooooo`Co0?of7_ooool4o`1Bo`Co0?o6`oooool8o`1Bodcooooo000Dooooo`03o`000?oooooooooo
08;ooooo00Oo0:7oo`3Zool0ROoo0?njo`2Kool0C?oo0?mg00;ooooo00Go0?o0o`0^ool0FOoooooo
o`0@o`03ooooo`03o`3oa_oooooo9P3o00;ooooo00_o0?mmoooooooooooo0:koo`3fool0ok[o02ko
o`3Zool0ol3o0?o6obH0o`04ooooo`05o`29ooooooooooooooooool0XOl03oooool00ol0:?oooooo
ooooo`03o`2Qo`03o`3oa_oooooooooo00?ooooo0_lV0?l00oooooooE`3oooooo`04ooooo`;o0:7o
1oooool2obH0oa3ooooo0omG0?lFooooo`Co0?of5_ooool6o`3oaP;ooooo1Ol0D_nhooooo`[o05;o
E?ooool001Cooooo00?o0000ooooooooool0P_ooool01ol0XOooooooo`29ool0ok[o09_oo`1<ool0
ogL00_ooool01Ol0ol3o02koo`1Ioooooooo013o00?ooooo00?o0?o6oooooolV0?l00_ooool02_l0
oggoooooooooool0[_oo0?Koo`3o^_l0;_oo0>[oo`3oa_lV0?l4ooooo`03o`29oooooooooooo00;o
oooo00?o0:7oooooooooool03Oooool00ol0:?ooooooooooo`03ooooo`;o0:7o1_ooool2obH0o`03
oeL0ool0XOoo0:7o00;o0:7o2?ooool00olV0?ooooooooooo`0=ooooo`?oE`3o7Oooool4o`3omPco
oooo1_l0olH=ooooo`Go05;oZ?ooool;o`1Boekooooo000Dooooo`03o`000?oooooooooo08;ooooo
00Oo0:7oooooool0ROoo0?Koo`2Kool0Jooo04co00;ooooo00Go0?o0o`3oOOl0;_ooooooo`0@o`03
ooooo`06o`3oa_ooooooooooobH0ool0oggo0?mg0_ooool01_l0[_oo0?Koo`0^ool0C?oo0>[oobH0
o`Gooooo00Go08Woooooooooooooooooo`2Qo`0Aooooo`03o`0Xoooooooooooo00Cooooo2Ol0XOl2
oeL0o`Kooooo1?lV0?l>ooooo`;oE`3o9?ooool4o`3omP03ooooool0olKo0?o600Go0?o66?ooool4
o`1BoiSooooo3?l0D_mYooooo`005?ooool00ol0003oooooooooo`22ooooo`07o`2Qoooooooo08Wo
o`3fool0Vooo06_oo`1<o`02ooooo`03o`3o`?oooooo02ko00;ooooo00Go013ooooooooooooooooo
o`3oaP02ooooo`0:obH0ool0ogOoooooooooool0[_oo0?njo`0^ool0olKo0>[oobH0o`Gooooo00Go
08Woooooooooooooooooo`2Qo`0Booooo`03o`0Xoooooooooooo00Cooooo00?o0?o6ooooooooool0
1oooool00omG0?oo9P3oobH0o`03obH0oa3ooooo0_mG0?lTooooo`Ko0?o61?l0ooHPooooo`Co05;o
ROooool;o`1BogGooooo000Dooooo`03o`000?oooooooooo08;ooooo00Oo0:7oooooool0ROoo0?Ko
o`2Kool0Jooo04co00;ooooo00?o0?o0ooooool0;_l00_ooool00ol04?ooooooooooo`02ooooo`0;
o`3oa_oooooo9P3oo`3oMooooooo0:koo`3fool0ok[o02koo`3ZoolV0?l01Oooool01Ol0ROoooooo
oooooooooooo0:7o01?ooooo00?o02Soooooooooool01Oooool00ol0olKoooooooooo`07ooooo`03
oeL0oooooooooooo013ooooo0_mG0?lOooooo`Oo0?o62_ooool3o`3omR7ooooo2?l0D_meooooo`co
05;oP?ooool001Cooooo00?o0000ooooooooool0P_ooool01ol0XOooooooo`29ool0m_oo09_oo`1[
ool0C?l00oooool01Ol0ol3o02kooooooooooooo013o00Cooooo00?o0?o6o`3oOOlV0?l00_ooool0
1_l0[_oo0?Koo`0^ool0C?oo9P3oo`3o`0Gooooo00Co08Wooooooooooooo0:7o5Oooool00ol0:?oo
ooooooooo`05ooooo`;o0?o62?ooool2oeL0o`gooooo0omG0?lDooooo`go0?o65?ooool8o`3omR7o
oooo2ol0D_mMooooo`go05;oS?ooool001Cooooo00?o0000ooooooooool0Poooool01_l0XOoo08Wo
o`3fool0Vooo06_oo`1<o`?ooooo00Go0?o0o`0^ooooooooooooo`0@o`04ooooo`03o`3oa_l0oggo
0?mg00;o9P3o00Go0:koo`3foolV0?oo9P3oo`3Zo`06ooooo`03o`29oooooooo0:7o01Kooooo00?o
02Soooooooooool01oooool00ol0olKoooooooooo`07ooooo`;oE`3o1oooool4oeL0oa7ooooo1_l0
olHYooooo`So0?of9?ooool8o`1Bockooooo5ol0D_nIooooo`005?ooool3o`0008?ooooo00Ko0:7o
o`29ool0m_oo0?njo`1[ool0C?l3ooooo`05o`3o`?l0FOoo02koooooool04?l01?ooool00ol0oggo
0?o6o`3oaP02ooooo`?o9P3o00?o04coo`3Zooooool01?ooool01?l0ROooooooooooool0XOlGoooo
o`03o`0Xoooooooooooo00Oooooo00?o0?o6ooooooooool02?ooool7oeL0oa7ooooo1?l0olHgoooo
o`Ko0?of9_oooolno`1Bok3ooooo000Dooooo`03o`000?oooooooooo08?ooooo00Ko0:7oo`29ool0
m_oo0?njo`2Kool0C?l3ooooo`05o`3o`?l0FOoo02koooooool04?l01?ooool00ol0oggoooooo`3o
M`02o`3oaP04o`2^ool0;_oo04coo`3Zo`Kooooo00?o08Woooooool0XOl06Oooool00ol0:?oooooo
ooooo`07ooooo`03o`3oa_oooooooooo01cooooo0ol0olI1ooooo`Wo0?ofooooool<ooooo`005?oo
ool00ol0003oooooooooo`23ooooo`07o`2Qool0ROoo0?Koo`3o^_l0Vooo04coo`3oM`02ooooo`05
o`3o`?l0FOoo02koooooool04?l00oooool02_l0oggoooooooooool0ogOoooooo`2^ool0m_oo02ko
o`1<ool0j_l5ooooo`03o`29oooooooo0:7o01[ooooo00?o02Soooooooooool02?ooool2o`3oaQOo
oooo1Ol0olI=ooooo`_o0?ofooooool1ooooo`005?ooool00ol0003oooooooooo`23ooooo`07o`2Q
ool0ROoo0?Koo`3o^_l0Vooo04coo`3oM`03ooooo`04o`1Iool0;_oo0?mmo`0@o`?ooooo00?o0?mm
ooooool0ogL00_ooool01Ol0[_oo0?Koo`0^ool0C?oo0>[o00Gooooo00?o08Woooooool0XOl06ooo
ool00ol0:?ooooooooooo`09ooooo`?o0?o64?ooool4o`3oaUgooooo1_l0ooI@o`1[oj[ooooo000D
ooooo`03o`000?oooooooooo08?ooooo00Oo0:7oo`29ool0m_oo0?njo`2Kool0C?oo0?mg00?ooooo
00Oo0?o0o`0^ool0oggoooooo`0@oooooooo0?mm00;ooooo00So0?mgoooooooooooo0:koo`0^oooo
oooo04coo`3Zo`Gooooo00?o08Woo`2Qooooool06oooool00ol0:?ooooooooooo`0<ooooo`Co0?o6
1_ooool6o`3oaUGooooo4_l0Jol@ooooo`co0?of=?oooomLo`1[odkooooo000Dooooo`03o`000?oo
oooooooo08?ooooo00Oo0:7oo`29ool0m_oo0?njo`2Kool0C?oo0?mg00?ooooo00Ko0?o0o`0^oooo
oooo0?mmo`0@ool0ogd3ooooo`08o`3oMoooooooooooo`2^ool0;_oo04coo`3o`?l0j_l4ooooo`03
o`29oooooooo0:7o01gooooo00?o02Soooooooooool03oooool6o`3oaUGooooo1_l0Jol^ooooobco
0?ofI?oooolio`1[oaGooooo000Dooooo`03o`000?oooooooooo08?ooooo00Oo0:7oo`29ool0m_oo
0?njo`2Kool0C?oo0?mg00?ooooo00Go0?o0o`0^ooooooooooooo`0@o`04ooooo`07o`3oMooooooo
ooooo`2^ool0;_oo04coo`3Zo`05ooooo`03o`29ool0XOoooooo01gooooo00?o02Soooooooooool0
HOooool9o`1[of3oooooNol0ooHGooooo`_o02So5Oooool001Cooooo00?o0000ooooooooool0Pooo
ool01ol0XOoo08Woo`3fool0ok[o09_oo`1<ool0ogL00oooool01Ol0ol3o02kooooooooooooo013o
00?ooooo00So0?mgoooooooooooo0:koo`0^ool0ok[o04coo`3Zo`Gooooo00?o08Woo`2Qooooool0
7_ooool00ol0:?ooooooooooo`1Gooooo`Wo06_oi?ooool8o`2Ko`oo02So8?ooool001Cooooo00?o
0000ooooooooool0Poooool01ol0XOoo08Woo`3fool0ok[o09_oo`1<ool0ogL00oooool01Ol0ol3o
05Woo`0^oooooooo013o00?ooooo00So0?mgoooooooooooo0:koo`0^oooooooo04coo`3Zo`Cooooo
00?o08Woo`2Qooooool08?ooool00ol0:?ooooooooooo`1Aooooo`Go06_oe_oooolDo`2Ko`_o02So
;oooool001Cooooo00?o0000ooooooooool0Poooool02?l0XOoo08Woo`3fool0ok[o09_oo`1<oooo
oooo0?mg0_ooool01Ol0ol3o05Woo`0^oooooooo013o00?ooooo00So0?mgoooooooooooo0:koo`0^
ool0ol3o04coo`3Zo`Cooooo00?o08Woo`2Qooooool08?ooool00ol0:?ooooooooooo`19ooooo`So
06_obOoooolBo`2Ko`Sooooo3?l0:?ljooooo`005?ooool00ol0003oooooooooo`23ooooo`08o`2Q
ool0ROoo0?Koo`3o^_l0Vooo06_oo`1<ool0ogL2ooooo`05o`3o`?l0FOoo02koooooool04?l00ooo
ool01ol0ogOoooooooooool0;_oo0?Koo`1<ool0j_l01Oooool00ol0ROoo0:7oooooo`0Qooooo`03
o`0Xoooooooooooo043ooooo2?l0Joo6ooooo`_o09_o3oooool;o`0XodKooooo000Dooooo`?o0000
Poooool02?l0XOoo08Woo`3foooooooo09_oo`1[ool0C?oo0?mg0oooool01Ol0FOooooooo`0^oooo
oooo013o00;ooooo00Oo0?mgoooooooooooo02koo`3o`?l0C?oo0>[o00Cooooo00?o08Woo`2Qoooo
ool08_ooool00ol0:?ooooooooooo`0looooo`Co06_o_?oooolBo`2Ko`Sooooo4_l0:?mAooooo`00
5?ooool00ol0003oooooooooo`23ooooo`08o`2Qool0ROoo0?Koooooool0Vooo06_oo`1<ool0ogL3
ooooo`07o`1Ioooooooo02koooooool04?ooooooo`3oM`02ooooo`05o`0^ool0m_oo0?o0o`1<ool0
j_l01?ooool00ol0ROoo0:7oooooo`0Sooooo`03o`0Xoooooooooooo03Oooooo1?l0JonYoooooaOo
09_o2?oooolBo`0Xof?ooooo000Dooooo`03o`000?oooooooooo08?ooooo00So0:7oo`29ool0j_oo
0?Koo`2Kool0Jooo04coo`3oM`?ooooo00Oo05Woooooool0;_ooooooo`0@oooooooo0?mg00;ooooo
00Go02koo`3fool0ol3o04coo`3Zo`04ooooo`03o`29ool0XOoooooo02Cooooo00?o02Sooooooooo
ool0<_ooool4o`1[oi_ooooo4_l0VolDooooo`_o02SoMOooool001Cooooo00?o0000ooooooooool0
Poooool02?l0XOoo08Woo`3Zool0m_oo09_oo`2^ool0C?oo0?mg0oooool03_l0FOoo0?o0ooooool0
;_oo013oooooool0ogOoooooo`0^ool0[_oo0?Koo`1<oooooooo0>[o1?ooool00ol0ROoooooooooo
o`0Uooooo`03o`0Xoooooooooooo02cooooo1Ol0JonCooooo`co09_o5OoooolAo`0Xoh3ooooo000D
ooooo`03o`000?oooooooooo08?ooooo00So0:7oo`29ool0j_oo0?Koo`2Kool0[_oo04coo`3oM`?o
oooo00Ko05Woo`3o`?oooooo02koo`0@ool0ogL2ooooo`05o`0^ool0[_oo0?Koo`1<ool0j_l01?oo
ool00ol0ROoo0:7oooooo`0Vooooo`03o`0Xoooooooooooo02Wooooo0ol0Jon7oooooa7o09_o3ooo
oolBo`0Xoi7ooooo000Dooooo`03o`000?oooooooooo08?ooooo00So0:7oo`29ool0j_oo0?Koo`2K
ool0[_oo04coo`3oM`?ooooo00Ko05Woo`3o`?oooooo02koo`0@ool0ogL2o`0^o`05o`3o`?l0[_oo
ooooo`1<ool0j_l01?ooool00ol0ROoo0:7oooooo`0Wooooo`03o`0Xoooooooooooo02Gooooo0ol0
Jomioooooa7o09_o4oooool=o`0Xoj?ooooo000Dooooo`03o`000?oooooooooo08?ooooo00So0:7o
o`29ool0j_oo0?Koo`3o^_l0Vooo04coo`3oM`Cooooo00Co05Woo`3o`?oooooo013o0_l0;_l01_oo
oooo0:koo`3foooooooo04coo`3Zo`Cooooo00?o08Woo`2Qooooool02oooool6o`1[oaOooooo00?o
02Soooooooooool08_ooool2o`1[og7ooooo2ol0VolHooooo`co02So/?ooool001Cooooo00?o0000
ooooooooool0Poooool02?l0XOoo08Woo`3Zool0m_oo0?njo`2Kool0Jooo04co1?ooool03?l0FOoo
0?o0ooooool0ogOo013oooooool0ol3o0:koo`3foooooooo04coo`3Zo`Cooooo00?o08Wooooooooo
ool02Oooool2o`1[o`?o09_o0oooool2o`1[oaKooooo00?o02Soooooooooool07oooool2o`1[ofOo
oooo3?l0VolHooooo`_o02So_?ooool001Cooooo00?o0000ooooooooool0Poooool02Ol0XOoooooo
o`29ool0m_oo0?njo`2Kool0Jooo04coo`3oM`03ooooo`0<o`1Ioooooooo0?o0o`3oMol04?oo0?o0
ooooool0[_oo0?Koo`1<oooooooo0>[o0oooool00ol0ROoo0:7oooooo`09ooooo`03o`1[ool0Vooo
09_o00?ooooo0ol0Vol2ooooo`;o06_o5?ooool00ol0:?ooooooooooo`0Mooooo`;o06_oGOooool<
o`2Koa?ooooo4Ol0:?o7ooooo`005?ooool00ol0003oooooooooo`24ooooo`08o`2Qool0ROoo0?Ko
o`3o^_l0Vooo06_oo`1<ool0ogL3ooooo`0;o`1Ioooooooo0?o0o`3o`?l04?oo0?o0ooooool0[_oo
0?Koo`1<ool0j_l01?ooool00ol0ROoo0:7oooooo`08ooooo`03o`1[oooooooooooo00Oooooo00Go
09_oooooooooooooooooo`1[o`0Dooooo`03o`0Xoooooooooooo01[ooooo0_l0JomCooooo`co09_o
3OoooolBo`0XomSooooo000Dooooo`03o`000?oooooooooo08Cooooo00So0:7oo`29ool0m_oo0?nj
o`2Kool0Jooo04coo`3oM`?ooooo00Go05Woooooool0ogOoooooo`0@o`02ooooo`04o`2^oooooooo
04coo`3Zo`Cooooo00?o08Woooooooooool01oooool00ol0Vooo06_oooooo`09ooooo`05o`2Koooo
ooooooooooooool0Jol05?ooool00ol0:?ooooooooooo`0Hooooo`03o`1[oooooooooooo04Sooooo
2ol0Vol>ooooo`_o02Soj_ooool001Cooooo0ol00024ooooo`09o`2Qool0ROooooooo`3fool0Vooo
06_oo`1<oooooooo0?mg00;ooooo00_o05Woooooool0ogOoooooo`0@oooooooo0:koo`3foooooooo
04coo`3Zo`04ooooo`03o`29oooooooooooo00Oooooo00?o06_oooooooooool02_ooool01Ol0Vooo
oooooooooooooooo06_o01Cooooo0_l0:?lFooooo`;o06_o@Oooool:o`2Ko`gooooo3?l0:?oeoooo
o`005?ooool00ol0003oooooooooo`24ooooo`09o`2Qool0ROooooooo`3fool0Vooo06_oo`1<oooo
oooo0?mg00;ooooo00_o05Woo`3oMoooooooooooo`0@oooooooo0:koo`3fool0C?ooooooo`3Zo`03
ooooo`03o`29ool0XOoooooo00Oooooo00?o06_oooooooooool03?ooool01Ol0Vooooooooooooooo
oooo06_o01Gooooo00?o02Soooooooooool04Oooool2o`1[oc_ooooo2?l0Vol<ooooo`_o02Sooooo
ool2ooooo`005?ooool00ol0003oooooooooo`24ooooo`08o`2Qool0ROooooooo`3fool0Vooo06_o
o`1<ooooool2o`3oM`03ooooool0FOoooooo00;ooooo00Oo013oooooool0[_oo0?Koo`1<oooooooo
0>[o00?ooooo00?o08Woo`2Qooooool01_ooool00ol0Joooooooooooo`0>ooooo`05o`2Koooooooo
ooooooooool0Jol05Oooool3o`0Xo`oooooo00?o06_oooooooooool0<oooool8o`2Ko`Sooooo3?l0
:?ooooooo`gooooo000Dooooo`03o`000?oooooooooo08Cooooo00Oo0:7oo`29oooooooo0?Koo`2K
ool0Jooo04co00;ooooo00?o0?mgooooool0FOl00oooool01ol04?ooooooo`2^ool0m_oo04cooooo
ool0j_l00oooool00ol0ROooooooooooo`05ooooo`03o`2Kool0Jooooooo013ooooo00Go09_ooooo
ooooooooooooo`1[o`0Gooooo`;o02So2oooool2o`1[o`_ooooo5?l0:?l?ooooo`Go09_o4ol0:?oo
oooooaWooooo000Dooooo`03o`000?oooooooooo08Cooooo00Oo0:7oo`29oooooooo0?Koo`2Kool0
Jooo04co00?ooooo00?o0?mgo`1Iooooool00oooool01Ol04?oo0:koooooool0C?oo0>[o00Cooooo
00?o08Woooooooooool01Oooool00ol0Joooooooooooo`0Aooooo`04o`2Kooooooooooooooooo`;o
06_o5oooool4o`0Xo`Gooooo0_l0Jol5ooooo`So02So5?oooolDo`0Xoooooooo;?ooool001Cooooo
00?o0000ooooooooool0Q?ooool01ol0XOoo08Woooooool0m_oo09_oo`1[ool0C?l01Oooool02Ol0
FOoooooooooooooooooo013oo`3foooooooo04coo`3Zo`03ooooo`03o`29ool0XOoooooo00Gooooo
00?o06_oooooooooool04oooool00ol0Voooooooooooo`02ooooo`03o`1[oooooooooooo01Sooooo
3?l0:?lKooooo`So09_oooooooliooooo`005?ooool00ol0003oooooooooo`24ooooo`07o`2Qool0
ROooooooo`3fool0Voooooooo`1<o`05ooooo`09o`1Iooooooooooooooooool04?oo0?Koo`1<oooo
oooo0>[o00?ooooo00?o08Woo`2Qooooool01Oooool00ol0Joooooooooooo`0Dooooo`03o`2Koooo
oooooooo00;ooooo00?o06_oooooooooool06Oooool2o`1[oacooooo1ol0Vooooooood7ooooo000D
ooooo`03o`000?oooooooooo08Cooooo00Oo0:7oo`29oooooooo0?Koo`2Koooooooo04co00Gooooo
00Wo05Woooooooooooooooooo`0@ool0m_oo04coooooool0j_l00oooool00ol0ROooooooooooo`04
ooooo`03o`1[ool0Vooooooo01Kooooo00?o09_oooooooooool00_ooool00ol0Joooooooooooo`0F
ooooo`;o06_o6?ooool6o`2KooooooooB?ooool000Sooooo0ol00009ooooo`03o`000?oooooooooo
08Cooooo00Oo0:7oo`29oooooooo0?Koo`3o^_l0Vooo04co00Gooooo00Wo05Wooooooooooooooooo
o`0@ool0m_oo04coooooool0j_l00oooool00ol0ROooooooooooo`04ooooo`03o`1[oooooooooooo
01Oooooo00?o09_oooooooooool00_ooool00ol0Joooooooooooo`0Cooooo`;o06_o5_ooool4o`2K
ooooooooC_ooool000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
08Cooooo00So0:7oo`29oooooooo0?Koooooool0Vooo06_oo`1<o`Cooooo00Wo05Wooooooooooooo
0:koo`0@oooooooo04coooooool0j_l00_ooool00ol0ROoo0:7oooooo`04ooooo`03o`1[ool0Vooo
oooo01Wooooo00?o09_oooooooooool00_ooool3o`1[oa3ooooo0_l0JolEooooo`?o09_ooooooomB
ooooo`002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Cooooo00So0:7oo`29
oooooooo0?Koooooool0Vooo06_oo`1<o`Cooooo00So05Wooooooooooooo0:koo`0@ool0C?oooooo
o`3Zo`?ooooo00?o08Woo`2Qooooool01?ooool00ol0Joooooooooooo`06ooooo`Co05Wo3oooool0
0ol0Voooooooooooo`05ooooo`03o`1[oooooooooooo00cooooo00?o06_oooooooooool04_ooool3
o`2KooooooooEOooool000_ooooo00?o0000ooooooooool01_ooool5o`0008;ooooo00So0:7oo`29
ooooooooooooo`3fool0Vooo06_oo`1<o`Gooooo00Oo05Woooooool0[_oo013oo`1<oooooooo0>[o
00?ooooo00?o08Woo`2Qooooool00oooool00ol0Joooooooooooo`05ooooo`?o05Wo0_ooool4o`1I
o`gooooo00?o09_oooooooooool01Oooool2o`1[o`Sooooo1?l0JolBooooo`?o09_ooooooomHoooo
o`001oooool4o`0000Wooooo00?o0000ooooooooool0Q?ooool02?l0XOoo08Wooooooooooooo0?Ko
o`2Kool0Jooo04co1Oooool01ol0FOoo0:koo`3o^_l04?oo04coooooool0j_l00oooool00ol0ROoo
ooooooooo`03ooooo`03o`1[oooooooooooo00Cooooo00?o05Woooooooooool01oooool00ol0FOoo
ooooooooo`0;ooooo`03o`2Koooooooooooo00Kooooo2?l0JolDooooo`;o09_ooooooomKooooo`00
1oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Cooooo00Wo0:7oo`29ool0j_oo
ooooo`3fool0Vooo06_oo`2^ool0C?l01?ooool01ol0FOoo0:koo`3o^_l0C?oo013oooooool0j_l0
0_ooool00ol0ROoo0:7oooooo`03ooooo`03o`2Kool0Jooooooo00Cooooo00?o05Woooooooooool0
2?ooool00ol0FOooooooooooo`0<ooooo`03o`2Koooooooooooo01kooooo0ol0Vooooooooegooooo
0007ooooo`Go00002?ooool00ol0003oooooooooo`24ooooo`09o`2Qool0ROoo0>[oooooool0m_oo
09_oo`1[ool0[_oo04co00Cooooo00Oo05Woo`2^ool0m_oo04coo`0@oooooooo0>[o00;ooooo00?o
08Woo`2Qooooool00oooool00ol0Joooooooooooo`02ooooo`;o05Wo3?ooool00ol0FOoooooooooo
o`0<ooooo`03o`2Koooooooooooo01_ooooo0_l0Voooooooof3ooooo000Dooooo`03o`000?oooooo
oooo08Cooooo00Wo0:7oo`29ool0j_ooooooo`3fool0Vooo06_oo`2^ool0C?l01?ooool01ol0FOoo
0?njo`3fool0C?oo013oooooool0j_l00_ooool00ol0ROoo0:7oooooo`02ooooo`03o`2Kool0Jooo
oooo00;ooooo00?o05Woooooooooool03Oooool00ol0FOooooooooooo`0<ooooo`03o`2Koooooooo
oooo01Sooooo0_l0Voooooooof;ooooo000Dooooo`03o`000?oooooooooo08Cooooo00Wo0:7oo`29
ool0j_ooooooo`3fool0Vooo06_oooooool0C?l01?ooool01_l0FOoo0?njo`1<oooooooo013oo`3Z
o`?ooooo00?o08Woo`2Qooooool00_ooool00ol0Joooooooooooo`02ooooo`03o`1Ioooooooooooo
00kooooo00?o05Woooooooooool03?ooool2o`2KoaGooooo0ol0VoooooooofCooooo000Dooooo`03
o`000?oooooooooo08Cooooo00[o0:7oo`29ool0j_ooooooo`3fool0Vooo06_oooooool0[_oo04co
0oooool01_l0[_oo05Woo`1<oooooooo013oo`3Zo`;ooooo00?o08Woo`2Qooooool00oooool01Ol0
Jooooooooooooooooooo05Wo01;ooooo00?o05Woooooooooool03Oooool2o`2Koa7ooooo0_l0Vooo
ooooodKooooo3?l0FOlEooooo`005?ooool00ol0003oooooooooo`24ooooo`0:o`2Qool0ROoo0>[o
ooooool0m_oo09_oo`1[oooooooo0:koo`1<o`;ooooo00Co0:koo`3o^_l0FOoo04co0_ooool01Ol0
4?ooooooooooool0ROoo0:7o00?ooooo00?o09_oo`1[ooooool00_ooool00ol0FOooooooooooo`0A
ooooo`03o`1Ioooooooooooo00kooooo00?o09_oooooooooool02oooool3o`2Koooooooo<_oooolF
o`1Iob7ooooo000Dooooo`03o`000?oooooooooo08Cooooo00Oo0:7oooooool0ROooooooo`3foooo
oooo06_o00;ooooo00Ko04cooooooooooooo0:koo`3o^_l0C?l3ooooo`05o`0@ooooooooooooo`29
ool0XOl00oooool01Ol0Jooooooooooooooooooo05Wo00Kooooo1_l04?l9ooooo`03o`1Ioooooooo
oooo00kooooo0_l0Vol9ooooo`;o09_ooooooolNoooooaOo05Wo=oooool001Cooooo00?o0000oooo
ooooool0QOooool02Ol0XOoo08Woooooool0m_ooooooo`2Kool0Joooooooo`1<o`02ooooo`03o`2^
ool0ok[o04co00?ooooo00Go013ooooooooooooo08Woo`2Qo`03ooooo`04o`1[ooooooooooooo`1I
o`Gooooo0_l04?l6ooooo`?o013o1_ooool00ol0FOooooooooooo`0@ooooo`Wo09_oooooool8oooo
oaSo05WoC_ooool001Cooooo0ol00025ooooo`07o`2Qool0ROooooooooooool0m_oo09_oo`1[o`02
ooooo`05o`1<ool0[_ooooooo`1<ool0FOl00oooool01Ol0j_oo013oooooool0ROoo0:7o00;ooooo
00Go09_oo`1[ooooooooooooo`1Io`04ooooo`03o`0@oooooooooooo00Wooooo00?o013ooooooooo
ool01?ooool00ol0FOooooooooooo`3aooooobko05Wo6?oooolio`0@oaGooooo000Dooooo`03o`00
0?oooooooooo08Gooooo00Oo0:7oo`29ooooooooooooo`3fool0Vooo06_o00;ooooo00co04cooooo
ool0C?oo04coo`3fool0FOooooooo`3Zoooooooo013oo`29ool0XOl3ooooo`04o`1[oooooooooooo
o`1Io`Cooooo00?o013oooooooooool02_ooool00ol04?ooooooooooo`05ooooo`03o`1Ioooooooo
oooo0;_oooooNol04?m>ooooo`005?ooool00ol0003oooooooooo`25ooooo`07o`2Qool0ROoooooo
ooooool0m_oo09_oo`1[o`03ooooo`;o04co00Wo0?Koooooool0FOooooooo`3Zoooooooo013oo`29
ool0XOl00oooool01?l0Joooooooooooool0FOl3ooooo`03o`0@oooooooooooo00cooooo00?o013o
ooooooooool01?ooool00ol0FOooooooooooo`2Hooooob?o013o1ooooolGo`1Ioj_ooooo000Doooo
o`03o`000?oooooooooo08Gooooo00Oo0:7oo`29ooooooooooooo`3fool0Vooo06_o00?ooooo00_o
0?njooooool0m_ooooooo`1Ioooooooo0>[oooooool04?oo08Woo`2Qo`02ooooo`04o`2Kool0Jooo
ooooo`1Io`?ooooo00?o013oooooooooool03_ooool00ol04?ooooooooooo`04ooooo`03o`1Ioooo
oooooooo08cooooo2ol04?lBoooooaSo05Wo`_ooool001Cooooo00?o0000ooooooooool0QOooool0
1ol0XOoo08Wooooooooooooo0?Koo`2Kool0Jol00oooool00ol0ok[oooooo`3fo`02ooooo`06o`1I
ool0j_ooooooooooool04?oo0:7o0_ooool00ol0Joooooooo`1Io`03ooooo`03o`0@oooooooooooo
013ooooo00?o013oooooooooool01?ooool00ol0FOooooooooooo`1oooooo`co013o1_oooolGo`1I
om[ooooo000Dooooo`03o`000?oooooooooo08Gooooo00Oo0:7oo`29ooooooooooooo`3fool0Vooo
06_o00?ooooo00?o0?njooooool0m_l00_ooool01_l0FOoo0>[ooooooooooooo08Woo`0@o`;ooooo
00?o06_oooooool0FOl00_ooool00ol04?ooooooooooo`0Aooooo`03o`0@oooooooooooo00Cooooo
00?o05Woooooooooool0Loooool<o`0@o`03ooooool0FOoo05Wo00oo05WolOooool001Cooooo00?o
0000ooooooooool0QOooool01ol0XOoo08Wooooooooooooo0?Koo`2Kool0Jol00ol0okX00ooooooo
0?Koooooo`02ooooo`0:o`1Iooooooooooooo`29oooooooo013oooooool0Joooooooo`1Io`;ooooo
00?o013oooooooooool04oooool00ol04?ooooooooooo`04ooooo`03o`1Ioooooooooooo06Oooooo
2ol04?l00ooooooo05Woo`1Io`0:o`1Ioooooooo0oooool001Cooooo00?o0000ooooooooool0QOoo
ool01ol0XOoo08Wooooooooooooo0?Koo`2Kool0Jol01?ooool01Ol0m_oooooooooooooooooo05Wo
00;ooooo00Oo08Woo`2Qoooooooo013oo`1[ool0FOoooooo00;o013o5oooool00ol04?oooooooooo
o`04ooooo`03o`1Ioooooooooooo05oooooo1ol04?l<o`1Ioooooooo3oooool001Cooooo00?o0000
ooooooooool0QOooool00ol0XOoo08Woooooo`02ooooo`03o`2Kool0Jooooooo00?ooooo00Go0?Ko
ooooooooooooooooo`1Io`02ooooo`04o`29ool0XOooooooooooo`?o013o6_ooool00ol04?oooooo
ooooo`03ooooo`03o`1Ioooooooooooo05Sooooo1ol04?l7o`1Ioooooooo6oooool001Cooooo00?o
0000ooooooooool0QOooool00ol0XOooooooo`29o`02ooooo`03o`2Koooooooo06_o00?ooooo00co
0?Koooooooooooooooooo`3Zool0FOooooooo`29ool0XOooooooo`1[ool0FOlLooooo`03o`0@oooo
oooooooo00Cooooo00?o05Woooooooooool0B_ooool5o`1Io`So013o0ol0FOooooooobKooooo000D
ooooo`03o`000?oooooooooo08Gooooo00?o0:7oooooool0ROl00_ooool00ol0Voooooooo`1[o`02
ooooo`03o`3foooooooooooo00;ooooo00Oo0>[oooooool0FOoo08Woo`2Qoooooooo05Wo01kooooo
00?o013oooooooooool01?ooool00ol0FOooooooooooo`0aoooooaGo05Wo2?l04?oooooooc7ooooo
000Dooooo`?o0000QOooool00ol0XOooooooo`29o`02ooooo`03o`2Koooooooo06_o00;ooooo00Go
0?Koooooooooooooooooo`3Zo`02ooooo`Co05Wo00?o06_oooooooooool07Oooool00ol04?oooooo
ooooo`04ooooo`03o`1Ioooooooooooo02[ooooo1_l0FOl=ooooo`So013oooooooliooooo`005?oo
ool00ol0003oooooooooo`25ooooo`03o`2Qoooooooo08Wo00;ooooo00Go09_oo`3fool0Jooooooo
o`3fo`04ooooo`08o`3Zooooooooooooo`29ool0XOooooooo`1[ool0VolPooooo`03o`0@oooooooo
oooo00Cooooo00?o05Woooooooooool09_ooool3o`1Io`cooooo1ol04?oooooood7ooooo000Doooo
o`03o`000?oooooooooo08Gooooo00?o0:7oooooool0ROl00_ooool00ol0Vooo0?Koo`1[o`02o`3f
o`Cooooo00Oo0>[ooooooooooooo08Woo`2Qoooooooo06_o02;ooooo00?o013oooooooooool01?oo
ool00ol0FOooooooooooo`0Rooooo`?o05Wo2_ooool5o`0@ooooooooB?ooool001Cooooo00?o0000
ooooooooool0QOooool00ol0XOooooooo`29o`02ooooo`04o`2Koooooooo06_oo`3fo`Gooooo00Oo
0>[ooooooooooooo08Woo`2Qool0Jooo09_o02?ooooo00?o013oooooooooool01?ooool00ol0FOoo
ooooooooo`0Nooooo`?o05Wo2Oooool4o`0@ooooooooCOooool001Cooooo00?o0000ooooooooool0
QOooool00ol0XOooooooo`29o`02ooooo`04o`2Kooooooooooooo`1[o`Cooooo00So0>[ooooooooo
ooooooooo`29ool0XOoo06_oo`2KobCooooo00?o013oooooooooool01?ooool00ol0FOoooooooooo
o`0Jooooo`?o05Wo2Oooool3o`0@ooooooooDOooool001Cooooo00?o0000ooooooooool0QOooool0
0ol0XOooooooo`29o`03ooooo`03o`2Koooooooo06_o00Cooooo00So0>[oooooooooooooooooo`29
ool0XOoo06_oo`2KobCooooo00?o013oooooooooool01Oooool00ol0FOooooooooooo`0Fooooo`?o
05Wo2Oooool3o`0@ooooooooE?ooool001Cooooo00?o0000ooooooooool0QOooool00ol0XOoooooo
o`29o`03ooooo`03o`2Koooooooo06_o00Cooooo00Oo0>[oooooooooooooooooo`29ool0Jooo09_o
02Kooooo00?o013oooooooooool01Oooool00ol0FOooooooooooo`0Booooo`?o05Wo2Oooool3o`0@
ooooooooEoooool001Cooooo00?o0000ooooooooool0QOooool01?l0XOooooooo`29ool0j_l2oooo
o`03o`2Koooooooo06_o00Cooooo00Oo0>[ooooooooooooo08Woo`2Qool0Jooo09_o02Oooooo00?o
013oooooooooool01Oooool00ol0FOooooooooooo`0?ooooo`;o05Wo2Oooool3o`0@ooooooooF_oo
ool001Cooooo00?o0000ooooooooool0QOooool01?l0XOooooooo`29ool0j_l2ooooo`03o`2Koooo
oooo06_o00Cooooo00Oo0>[ooooooooooooo08Woo`2Qool0Jooo09_o02Sooooo00?o013ooooooooo
ool01Oooool3o`1Io`_ooooo0ol0FOl9ooooo`;o013ooooooomMooooo`005?ooool00ol0003ooooo
ooooo`25ooooo`04o`2Qoooooooo08Woo`3Zo`;ooooo00?o09_oooooool0Jol00oooool01ol0j_oo
oooooooooooooooo08Woo`1[ool0Vol0:_ooool00ol04?ooooooooooo`07ooooo`_o05Wo2oooool0
0ol04?ooooooooooo`3ooooooegooooo000Dooooo`03o`000?oooooooooo08Gooooo00Co0:7ooooo
ool0ROoo0>[o0_ooool00ol0Voooooooo`1[o`03ooooo`07o`3Zooooooooooooooooool0ROoo06_o
o`2Ko`0[ooooo`03o`0@oooooooooooo01[ooooo0_l04?ooooooof3ooooo000Dooooo`?o0000QOoo
ool01?l0XOooooooo`29ool0j_l2ooooo`03o`2Koooooooo06_o00?ooooo00Oo0>[ooooooooooooo
ooooo`29ool0Jooo09_o02cooooo00?o013oooooooooool05oooool2o`0@ooooooooH_ooool001Co
oooo00?o0000ooooooooool0QOooool01?l0XOooooooo`29ool0j_l3ooooo`03o`2Koooooooo06_o
00;ooooo00Oo0>[ooooooooooooo08Woo`1[oooooooo09_o02gooooo00?o013oooooooooool05Ooo
ool00ol04?ooooooooooo`3oooooof;ooooo000Dooooo`03o`000?oooooooooo08Kooooo00?o0:7o
ooooool0ROl00oooool00ol0Voooooooo`1[o`02ooooo`06o`3Zooooooooooooo`29ool0Jooo09_o
;oooool00ol04?ooooooooooo`0Booooo`;o013ooooooomUooooo`005?ooool00ol0003ooooooooo
o`26ooooo`04o`2Qoooooooo08Woo`3Zo`;ooooo00Go09_oooooool0Joooooooo`3Zo`03ooooo`03
o`1[ool0XOoo09_o033ooooo00?o013oooooooooool03_ooool3o`0@ooooooooIoooool001Cooooo
00?o0000ooooooooool0Q_ooool01?l0XOooooooo`29ool0j_l2ooooo`05o`2Kooooooooooooo`1[
ool0j_l00oooool00ol0Jooo0:7oo`2Ko`0aooooo`;o013o3?ooool2o`0@ooooooooJ_ooool001Co
oooo00?o0000ooooooooool0Q_ooool01?l0XOooooooo`29ool0j_l2ooooo`05o`2Koooooooooooo
o`1[ool0j_l00_ooool01?l0Jooo08Woo`2Qool0Volcooooo`;o013o1oooool3o`0@ooooooooK?oo
ool001Cooooo00?o0000ooooooooool0Q_ooool01?l0XOooooooo`29ool0j_l3ooooo`05o`2Koooo
ooooooooo`1[ooooool00_l0Jol00ooooooo09_oooooo`0eooooo`Oo013ooooooom_ooooo`005?oo
ool00ol0003oooooooooo`26ooooo`04o`2Qoooooooo08Woo`3Zo`?ooooo00Co09_ooooooooooooo
0>[o0_l0Jol00ol0ROoo0:7oo`2Ko`3oooooojcooooo000Dooooo`03o`000?oooooooooo08Kooooo
00Co0:7oooooool0ROoo0>[o0oooool00ol0Voooooooo`3Zo`03ooooo`03o`29ool0XOoo09_o0?oo
oooo[?ooool001Cooooo00?o0000ooooooooool0Q_ooool01Ol0XOooooooo`29oooooooo0>[o00;o
oooo00?o09_oooooool0j_l00oooool00ol0ROoo09_oooooo`3oooooojcooooo000Dooooo`03o`00
0?oooooooooo08Kooooo00Go0:7oooooool0ROooooooo`3Zo`02ooooo`03o`2Koooooooo0>[o00?o
oooo00?o08Woo`2Kooooool0oooooon/ooooo`005?ooool3o`0008Kooooo00Go0:7oooooool0ROoo
ooooo`3Zo`02ooooo`03o`2Kool0j_oooooo00;ooooo00?o08Woooooool0Vol0oooooon]ooooo`00
5?ooool00ol0003oooooooooo`26ooooo`05o`2Qoooooooo08Woooooool0j_l00oooool01_l0Vooo
oooooooooooooooo08Woo`2Koooooooo[_ooool001Cooooo00?o0000ooooooooool0Q_ooool01Ol0
XOooooooo`29oooooooo0>[o00;ooooo00?o0>[oo`2Kooooool00_ooool00ol0ROoo0:7oooooo`3o
ooooojgooooo000Dooooo`03o`000?oooooooooo08Kooooo00?o0:7oooooool0ROl00_ooool3o`3Z
o`;o09_o00Coooooo`2Kool0ROoo0:7ooooooon^ooooo`005?ooool00ol0003oooooooooo`26oooo
o`04o`2Qooooooooooooo`29o`Gooooo0ol0Vol00ol0ROoo0:7oooooo`3oooooojgooooo000Doooo
o`03o`000?oooooooooo08Kooooo00Co0:7ooooooooooooo08Wo1oooool00ol0ROooooooo`2Qo`3o
ooooojkooooo000Dooooo`03o`000?oooooooooo08Kooooo00Co0:7ooooooooooooo08Wo1oooool0
0ol0ROooooooo`2Qo`3oooooojkooooo000Dooooo`03o`000?oooooooooo08Kooooo00Co0:7ooooo
oooooooo08Wo1oooool00ol0ROoo0:7oooooo`3oooooojkooooo0008ooooo`?o00002Oooool00ol0
003oooooooooo`26ooooo`04o`2Qooooooooooooo`29o`Oooooo00?o08Woo`2Qooooool0oooooon^
ooooo`001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0Q_ooool0
1?l0XOooooooooooool0ROl7ooooo`03o`29ool0XOoooooo0?oooooo[_ooool000Oooooo00Go0000
ooooooooooooooooo`000008ooooo`Go0000QOooool00ol0XOooooooo`29o`07ooooo`03o`29ool0
XOoooooo0?oooooo[_ooool000Oooooo1?l00009ooooo`03o`000?oooooooooo08Oooooo00?o0:7o
ooooool0ROl01_ooool00ol0ROooooooo`2Qo`3oooooojoooooo0007ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Qoooool00ol0XOooooooo`29o`06ooooo`03o`29ool0XOoooooo
0?oooooo[oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`27ooooo`03
o`2Qoooooooo08Wo00Kooooo00?o08Woo`2Qooooool0oooooon_ooooo`002Oooool2o`0000Wooooo
00?o0000ooooooooool0Qoooool00ol0XOooooooo`29o`06ooooo`03o`29ool0XOoooooo0?oooooo
[oooool001Cooooo00?o0000ooooooooool0Qoooool01?l0XOooooooooooool0ROl4ooooo`03o`29
oooooooo0:7o0?oooooo/?ooool001Cooooo00?o0000ooooooooool0Qoooool01?l0XOoooooooooo
ool0ROl4ooooo`03o`29oooooooo0:7o0?oooooo/?ooool001Cooooo00?o0000ooooooooool0Qooo
ool01?l0XOooooooooooool0ROl4ooooo`03o`29ool0XOoooooo0?oooooo/?ooool001Cooooo00?o
0000ooooooooool0Qoooool01Ol0XOoooooooooooooooooo08Wo00;ooooo00?o08Woooooool0XOl0
oooooonaooooo`005?ooool00ol0003oooooooooo`27ooooo`05o`2Qooooooooooooooooool0ROl0
0_ooool00ol0ROooooooo`2Qo`3ooooook7ooooo000Dooooo`03o`000?oooooooooo08Sooooo00?o
0:7oooooooooool00ol0ROl2ooooo`03o`2Qoooooooooooo0?oooooo[oooool001Cooooo0ol00028
ooooo`04o`2Qooooooooooooooooo`;o08Wo00?oooooo`2Qooooool0oooooonaooooo`005?ooool0
0ol0003oooooooooo`28ooooo`03o`2Qoooooooooooo00Cooooo00?o0:7oooooooooool0oooooon`
ooooo`005?ooool00ol0003oooooooooo`28ooooo`03o`2Qoooooooooooo00Cooooo00?o0:7ooooo
ooooool0oooooon`ooooo`005?ooool00ol0003oooooooooo`28ooooo`03o`2Qoooooooooooo00Co
oooo00?o0:7oooooooooool0oooooon`ooooo`005?ooool00ol0003oooooooooo`28ooooo`03o`2Q
oooooooooooo00?ooooo00?o0:7oooooooooool0oooooonaooooo`005?ooool00ol0003ooooooooo
o`29ooooo`03o`2Qoooooooooooo00;ooooo00?o0:7oooooooooool0oooooonaooooo`005?ooool0
0ol0003oooooooooo`29ooooo`03o`2Qoooooooooooo00;ooooo00?o0:7oooooooooool0oooooona
ooooo`005?ooool00ol0003oooooooooo`29ooooo`05o`2Qooooooooooooooooool0XOl0oooooond
ooooo`005?ooool00ol0003oooooooooo`29ooooo`05o`2Qooooooooooooooooool0XOl0oooooond
ooooo`005?ooool00ol0003oooooooooo`29ooooo`05o`2Qooooooooooooooooool0XOl0oooooond
ooooo`005?ooool00ol0003oooooooooo`29ooooo`04o`2Qooooooooooooo`2Qoooooooo]Oooool0
01Cooooo0ol0002:ooooo`03o`2Qoooooooo0:7o0?oooooo]Oooool001Cooooo00?o0000oooooooo
ool0Roooool00ol0XOooooooooooo`3ooooookCooooo000Dooooo`03o`000?oooooooooo0?oooooo
oooooom3ooooo`005?ooool00ol0003oooooooooo`3ooooooooooooo@oooool001Cooooo00?o0000
ooooooooool0oooooooooooood?ooooo000Dooooo`03o`000?oooooooooo0?oooooooooooom3oooo
o`005?ooool00ol0003oooooooooo`3ooooooooooooo@oooool001Cooooo00?o0000ooooooooool0
oooooooooooood?ooooo000Dooooo`03o`000?oooooooooo0?oooooooooooom3ooooo`005?ooool0
0ol0003oooooooooo`3ooooooooooooo@oooool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {369.812, 0}} -> {-18.3692, -0.303851, \
0.896058, 0.0186087}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 600 370.82 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190476 0.0147151 0.210581 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .12001 -18 -4.5 ]
[.01131 .12001 0 4.5 ]
[.01131 .2253 -6 -4.5 ]
[.01131 .2253 0 4.5 ]
[.01131 .33059 -18 -4.5 ]
[.01131 .33059 0 4.5 ]
[.01131 .43588 -6 -4.5 ]
[.01131 .43588 0 4.5 ]
[.01131 .54117 -18 -4.5 ]
[.01131 .54117 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(100)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(200)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(300)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(400)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(500)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12001 m
.03006 .12001 L
s
[(0.5)] .01131 .12001 1 0 Mshowa
.02381 .2253 m
.03006 .2253 L
s
[(1)] .01131 .2253 1 0 Mshowa
.02381 .33059 m
.03006 .33059 L
s
[(1.5)] .01131 .33059 1 0 Mshowa
.02381 .43588 m
.03006 .43588 L
s
[(2)] .01131 .43588 1 0 Mshowa
.02381 .54117 m
.03006 .54117 L
s
[(2.5)] .01131 .54117 1 0 Mshowa
.125 Mabswid
.02381 .03577 m
.02756 .03577 L
s
.02381 .05683 m
.02756 .05683 L
s
.02381 .07789 m
.02756 .07789 L
s
.02381 .09895 m
.02756 .09895 L
s
.02381 .14106 m
.02756 .14106 L
s
.02381 .16212 m
.02756 .16212 L
s
.02381 .18318 m
.02756 .18318 L
s
.02381 .20424 m
.02756 .20424 L
s
.02381 .24635 m
.02756 .24635 L
s
.02381 .26741 m
.02756 .26741 L
s
.02381 .28847 m
.02756 .28847 L
s
.02381 .30953 m
.02756 .30953 L
s
.02381 .35165 m
.02756 .35165 L
s
.02381 .3727 m
.02756 .3727 L
s
.02381 .39376 m
.02756 .39376 L
s
.02381 .41482 m
.02756 .41482 L
s
.02381 .45694 m
.02756 .45694 L
s
.02381 .47799 m
.02756 .47799 L
s
.02381 .49905 m
.02756 .49905 L
s
.02381 .52011 m
.02756 .52011 L
s
.02381 .56223 m
.02756 .56223 L
s
.02381 .58328 m
.02756 .58328 L
s
.02381 .60434 m
.02756 .60434 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.06244 .23827 L
.08255 .36403 L
.10458 .48505 L
.11448 .53079 L
.11992 .55265 L
.12507 .57057 L
.12986 .58429 L
.13238 .59014 L
.13506 .59512 L
.13731 .59821 L
.13859 .59946 L
.13979 .60027 L
.14089 .60068 L
.14189 .60077 L
.14305 .6005 L
.14415 .59986 L
.1454 .59864 L
.1461 .5977 L
.14674 .59668 L
.1479 .59443 L
.14918 .59129 L
.1514 .58404 L
.15374 .57362 L
.15629 .55859 L
.15902 .53777 L
.16396 .48741 L
.16859 .42941 L
.17113 .39766 L
.17351 .37093 L
.1757 .35053 L
.17771 .33592 L
.17994 .32428 L
.18111 .31996 L
.18234 .31659 L
.18356 .31434 L
.18486 .31298 L
.18609 .31256 L
.1872 .3128 L
.18852 .31376 L
.18925 .31458 L
.18994 .31549 L
.19252 .3201 L
.19508 .32611 L
.19789 .33387 L
.20358 .35185 L
.22371 .42124 L
.23368 .45144 L
.2386 .46346 L
.24099 .46828 L
Mistroke
.24315 .4719 L
.24437 .47357 L
.24568 .47504 L
.24641 .47569 L
.24707 .47618 L
.24838 .4768 L
.2497 .47695 L
.25045 .4768 L
.25115 .4765 L
.25189 .476 L
.25256 .47539 L
.25334 .47447 L
.25407 .47341 L
.25656 .46837 L
.25885 .46189 L
.26405 .44271 L
.27305 .40626 L
.27778 .38962 L
.28275 .37514 L
.2854 .36875 L
.2883 .36282 L
.29339 .35491 L
.29589 .35209 L
.29856 .34978 L
.29986 .3489 L
.30108 .3482 L
.30227 .34763 L
.30336 .34721 L
.30452 .34687 L
.30577 .3466 L
.30692 .34644 L
.30801 .34636 L
.30928 .34636 L
.31045 .34644 L
.31174 .3466 L
.31239 .34671 L
.31311 .34686 L
.31567 .34754 L
.31842 .34852 L
.32342 .35079 L
.34188 .36081 L
.35144 .36499 L
.35686 .36672 L
.3619 .36789 L
.36464 .36836 L
.36724 .36869 L
.36957 .36892 L
.37088 .36901 L
.37209 .36908 L
.37339 .36913 L
Mistroke
.37461 .36917 L
.37531 .36918 L
.37595 .36919 L
.37668 .36919 L
.37738 .36919 L
.37806 .36919 L
.37877 .36918 L
.38006 .36915 L
.38086 .36913 L
.3816 .3691 L
.38299 .36905 L
.40138 .36782 L
.40642 .36751 L
.40919 .36738 L
.41182 .36727 L
.41426 .3672 L
.41564 .36716 L
.41692 .36714 L
.41799 .36713 L
.41917 .36711 L
.4204 .36711 L
.42156 .3671 L
.42273 .36711 L
.424 .36712 L
.42465 .36712 L
.42533 .36713 L
.42657 .36715 L
.42898 .3672 L
.43117 .36726 L
.43649 .36746 L
.44151 .36769 L
.46258 .36887 L
.47232 .36935 L
.48261 .36977 L
.4914 .37003 L
.50107 .37026 L
.54143 .37097 L
.58027 .37168 L
.60004 .372 L
.62157 .37227 L
.64245 .37248 L
.66135 .37264 L
.68108 .37276 L
.6919 .37281 L
.70207 .37285 L
.71187 .37288 L
.7168 .37289 L
.7222 .3729 L
.72683 .3729 L
.72942 .3729 L
Mistroke
.73177 .37291 L
.73397 .37291 L
.73513 .37291 L
.73636 .37291 L
.73743 .37291 L
.73861 .37291 L
.73968 .37291 L
.74069 .37291 L
.74194 .37291 L
.74263 .37291 L
.74326 .37291 L
.74449 .37291 L
.74565 .37291 L
.747 .37291 L
.74825 .37291 L
.75107 .37291 L
.75586 .3729 L
.76093 .37289 L
.76976 .37288 L
.77945 .37286 L
.79895 .3728 L
.81986 .37271 L
.86121 .3725 L
.90104 .37225 L
.93936 .37198 L
.97619 .37173 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.06244 .23833 L
.08255 .36409 L
.10458 .48507 L
.11448 .53075 L
.11992 .55257 L
.12507 .57044 L
.12986 .58409 L
.13238 .5899 L
.13506 .59481 L
.13614 .5964 L
.13731 .59783 L
.13859 .59903 L
.13979 .5998 L
.14096 .60018 L
.14207 .60018 L
.14306 .59987 L
.14415 .59917 L
.1448 .59856 L
.14548 .59775 L
.1467 .59588 L
.14802 .59319 L
.14946 .58936 L
.15205 .57999 L
.15447 .56791 L
.15683 .55259 L
.15898 .5353 L
.16382 .48469 L
.16911 .4169 L
.172 .38106 L
.17472 .3528 L
.17702 .33441 L
.17832 .32645 L
.17951 .32058 L
.18074 .31587 L
.18209 .31215 L
.18276 .31078 L
.18349 .30967 L
.1848 .30851 L
.18608 .30827 L
.18727 .30875 L
.18856 .30994 L
.18922 .31076 L
.18994 .31183 L
.19245 .31663 L
.1948 .32235 L
.20388 .35066 L
.22464 .42334 L
.22962 .43911 L
.23505 .45443 L
Mistroke
.23753 .46056 L
.24018 .46629 L
.24265 .47078 L
.24493 .47397 L
.2461 .47521 L
.24734 .47617 L
.24858 .47675 L
.24929 .47689 L
.24994 .47688 L
.25113 .47654 L
.25222 .47583 L
.25347 .47449 L
.25466 .47273 L
.25685 .46816 L
.25888 .46256 L
.26347 .44643 L
.27247 .41106 L
.28217 .37997 L
.28772 .36734 L
.29015 .363 L
.29281 .35903 L
.29516 .35615 L
.29767 .35368 L
.30032 .35171 L
.30279 .35041 L
.30402 .34992 L
.30538 .34951 L
.30607 .34936 L
.3068 .34922 L
.3075 .34912 L
.30813 .34905 L
.30934 .34899 L
.31066 .34901 L
.3119 .3491 L
.31305 .34925 L
.31437 .34949 L
.31561 .34977 L
.31844 .35061 L
.32417 .35291 L
.33399 .35774 L
.34434 .36258 L
.34899 .36436 L
.35396 .36591 L
.35682 .36662 L
.35941 .36715 L
.36203 .36757 L
.36449 .36787 L
.36673 .36807 L
.36786 .36814 L
.36911 .3682 L
Mistroke
.37017 .36824 L
.37131 .36826 L
.37238 .36827 L
.37336 .36827 L
.37459 .36825 L
.37573 .36823 L
.37697 .36818 L
.3783 .36812 L
.38076 .36797 L
.38299 .3678 L
.39315 .36681 L
.40387 .36574 L
.40829 .36538 L
.41303 .36507 L
.41575 .36493 L
.41823 .36483 L
.41942 .36479 L
.42072 .36476 L
.42195 .36473 L
.42308 .36471 L
.42422 .36469 L
.42546 .36467 L
.42655 .36467 L
.4277 .36466 L
.42896 .36466 L
.43013 .36467 L
.43142 .36468 L
.43214 .36469 L
.4328 .3647 L
.43534 .36474 L
.43811 .3648 L
.44312 .36495 L
.46165 .36564 L
.47193 .36598 L
.48154 .36622 L
.48637 .36631 L
.49156 .36639 L
.49732 .36646 L
.50259 .3665 L
.52323 .36663 L
.54237 .36678 L
.58063 .36718 L
.59948 .36736 L
.61983 .36751 L
.63102 .36757 L
.6413 .36762 L
.65175 .36767 L
.66149 .3677 L
.67061 .36772 L
.68036 .36774 L
Mistroke
.68593 .36775 L
.68867 .36775 L
.69119 .36775 L
.69349 .36776 L
.69592 .36776 L
.69718 .36776 L
.69836 .36776 L
.69965 .36776 L
.70038 .36776 L
.70105 .36776 L
.70233 .36776 L
.70354 .36776 L
.70463 .36776 L
.70581 .36776 L
.70709 .36776 L
.70845 .36776 L
.71089 .36776 L
.71524 .36775 L
.72002 .36775 L
.72519 .36774 L
.73074 .36773 L
.74074 .3677 L
.76197 .36763 L
.78209 .36753 L
.82041 .3673 L
.86118 .367 L
.90043 .36667 L
.93817 .36634 L
.97619 .366 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.06244 .23826 L
.08255 .36401 L
.10458 .48504 L
.11448 .53078 L
.11992 .55265 L
.12507 .57059 L
.12986 .58433 L
.13238 .5902 L
.13506 .5952 L
.13731 .5983 L
.13859 .59956 L
.13979 .60038 L
.14089 .60081 L
.14189 .60091 L
.14305 .60066 L
.14415 .60004 L
.1454 .59884 L
.1461 .59792 L
.14674 .59692 L
.1479 .59468 L
.14918 .59158 L
.1514 .58441 L
.15374 .57408 L
.15629 .55919 L
.15902 .53855 L
.16396 .48862 L
.16859 .43107 L
.17351 .3729 L
.17553 .35395 L
.17771 .33791 L
.17896 .3308 L
.1801 .32554 L
.18119 .32158 L
.18234 .31843 L
.18356 .31614 L
.18486 .31472 L
.18609 .31425 L
.1872 .31446 L
.18852 .31536 L
.18925 .31615 L
.18994 .31704 L
.19252 .32157 L
.19508 .32748 L
.19789 .33515 L
.20358 .35293 L
.22371 .42159 L
.23368 .45143 L
.2386 .46324 L
.24099 .46794 L
Mistroke
.24315 .47143 L
.24437 .47302 L
.24568 .47439 L
.24641 .47498 L
.24707 .47541 L
.24838 .47591 L
.2497 .47591 L
.25045 .47568 L
.25115 .47528 L
.25189 .47469 L
.25256 .47397 L
.25407 .47176 L
.25535 .46924 L
.25653 .46638 L
.2592 .45823 L
.26405 .43931 L
.27305 .40178 L
.27778 .38487 L
.28275 .3703 L
.2854 .36393 L
.2883 .35806 L
.29339 .35036 L
.29589 .34767 L
.29726 .34648 L
.29856 .34552 L
.29977 .34476 L
.30108 .34409 L
.30225 .34361 L
.30336 .34326 L
.3046 .34297 L
.30573 .34281 L
.30695 .34272 L
.30763 .34271 L
.30827 .34273 L
.30933 .34281 L
.31049 .34296 L
.31171 .3432 L
.31285 .34348 L
.31547 .34432 L
.31787 .34531 L
.32328 .34806 L
.33418 .35463 L
.34434 .36047 L
.35347 .36457 L
.35858 .36627 L
.36324 .36742 L
.36589 .36793 L
.36834 .3683 L
.37103 .36861 L
.37238 .36874 L
Mistroke
.37387 .36885 L
.37516 .36892 L
.37638 .36898 L
.37705 .369 L
.37778 .36902 L
.37907 .36905 L
.38029 .36906 L
.38159 .36907 L
.38281 .36906 L
.38393 .36904 L
.38513 .36902 L
.38625 .36899 L
.38881 .36891 L
.39396 .36869 L
.3987 .36847 L
.40319 .36829 L
.40571 .3682 L
.40704 .36817 L
.40845 .36813 L
.40963 .36811 L
.41094 .36808 L
.41213 .36807 L
.41324 .36806 L
.41456 .36805 L
.41522 .36805 L
.41595 .36805 L
.41723 .36806 L
.41843 .36807 L
.41916 .36808 L
.41984 .36809 L
.42113 .36811 L
.42401 .36818 L
.42641 .36826 L
.42865 .36835 L
.43374 .36861 L
.44404 .36927 L
.4625 .37062 L
.47292 .37128 L
.4828 .37181 L
.50134 .37252 L
.5212 .37306 L
.53961 .37353 L
.57881 .37451 L
.59884 .37493 L
.62046 .37531 L
.6606 .37583 L
.6806 .37602 L
.69078 .3761 L
.70168 .37617 L
.71199 .37622 L
Mistroke
.72137 .37626 L
.73028 .3763 L
.73972 .37632 L
.74446 .37633 L
.74967 .37634 L
.75442 .37635 L
.75886 .37635 L
.76154 .37635 L
.76286 .37635 L
.76409 .37635 L
.76529 .37635 L
.76637 .37635 L
.76758 .37635 L
.76887 .37636 L
.76954 .37636 L
.77026 .37636 L
.77153 .37636 L
.77224 .37635 L
.77291 .37635 L
.77363 .37635 L
.77441 .37635 L
.77582 .37635 L
.77715 .37635 L
.77964 .37635 L
.78423 .37635 L
.78929 .37634 L
.79954 .37633 L
.80904 .37631 L
.81796 .37629 L
.85663 .37616 L
.89776 .37597 L
.93737 .37577 L
.97547 .37556 L
.97619 .37556 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.06244 .2384 L
.08255 .36415 L
.10458 .48508 L
.11448 .53071 L
.11992 .55248 L
.12507 .57028 L
.12986 .58384 L
.13238 .58958 L
.13506 .59441 L
.13614 .59596 L
.13731 .59734 L
.13859 .59849 L
.13979 .59919 L
.14096 .5995 L
.14207 .59944 L
.14306 .59906 L
.14415 .59827 L
.1448 .59761 L
.14548 .59674 L
.1467 .59474 L
.14802 .5919 L
.14946 .58789 L
.15205 .5781 L
.15447 .56551 L
.15683 .54956 L
.15898 .53157 L
.16382 .47895 L
.16911 .40899 L
.172 .37256 L
.17472 .34433 L
.17702 .32632 L
.17832 .31866 L
.17951 .31311 L
.18074 .30874 L
.18144 .30683 L
.18209 .30539 L
.1834 .3034 L
.18413 .30277 L
.1848 .30247 L
.18599 .30252 L
.18725 .30329 L
.18832 .30445 L
.18951 .3062 L
.19215 .31149 L
.19461 .3178 L
.20388 .34782 L
.22464 .42231 L
.22962 .43839 L
.23505 .45403 L
Mistroke
.23984 .46551 L
.24246 .47057 L
.24375 .47265 L
.24493 .47429 L
.24609 .47563 L
.24736 .47676 L
.24863 .4775 L
.24933 .47773 L
.24998 .47781 L
.25113 .47766 L
.25219 .47715 L
.2534 .47611 L
.25455 .47467 L
.25563 .47291 L
.25677 .47062 L
.25882 .46551 L
.26347 .45042 L
.27309 .41487 L
.27833 .39771 L
.2832 .38438 L
.28773 .37442 L
.29184 .36736 L
.2964 .36157 L
.29891 .35922 L
.30127 .35749 L
.30362 .3562 L
.30481 .35569 L
.30612 .35525 L
.30723 .35495 L
.30842 .35471 L
.30955 .35456 L
.31058 .35447 L
.31186 .35444 L
.31305 .35448 L
.31436 .35459 L
.31502 .35467 L
.31575 .35477 L
.31828 .35527 L
.32065 .3559 L
.33069 .35962 L
.34152 .36397 L
.34614 .36554 L
.35108 .36691 L
.35392 .36753 L
.3565 .36798 L
.35909 .36833 L
.36154 .36857 L
.36276 .36866 L
.3641 .36872 L
.36477 .36875 L
Mistroke
.36549 .36877 L
.3668 .36879 L
.3681 .36878 L
.36934 .36876 L
.37045 .36872 L
.37166 .36867 L
.3731 .36858 L
.37441 .36848 L
.37735 .36821 L
.38263 .36758 L
.39279 .36606 L
.40352 .36448 L
.41267 .36342 L
.41787 .36297 L
.42272 .36266 L
.42512 .36253 L
.42772 .36243 L
.43018 .36235 L
.43246 .36229 L
.43451 .36225 L
.43677 .36222 L
.4379 .36221 L
.43913 .3622 L
.44028 .3622 L
.44134 .36219 L
.4425 .36219 L
.44375 .3622 L
.44492 .3622 L
.44598 .3622 L
.44724 .36221 L
.44859 .36222 L
.45106 .36224 L
.46129 .36233 L
.46586 .36237 L
.46842 .36239 L
.47076 .3624 L
.47209 .36241 L
.47278 .36241 L
.47353 .36241 L
.47424 .36241 L
.47489 .36241 L
.47615 .36241 L
.47739 .36241 L
.4781 .36241 L
.47874 .36241 L
.47993 .36241 L
.48118 .36241 L
.48249 .3624 L
.48369 .3624 L
.48638 .36238 L
Mistroke
.49122 .36235 L
.49688 .36229 L
.50223 .36223 L
.5205 .362 L
.53089 .3619 L
.53598 .36186 L
.54063 .36183 L
.5452 .36181 L
.55018 .36179 L
.55545 .36177 L
.56046 .36176 L
.56573 .36175 L
.57136 .36174 L
.58148 .36173 L
.59176 .36172 L
.60289 .3617 L
.61339 .36167 L
.62305 .36165 L
.66253 .36151 L
.70049 .36132 L
.7409 .36105 L
.7798 .36072 L
.82115 .36031 L
.86098 .35986 L
.8993 .35941 L
.94007 .35891 L
.97619 .35848 L
Mfstroke
1 .119 0 r
.02381 .01472 m
.06244 .2384 L
.08255 .36415 L
.10458 .48507 L
.11448 .53071 L
.11992 .55248 L
.12507 .57028 L
.12986 .58385 L
.13238 .58959 L
.13506 .59443 L
.13614 .59599 L
.13731 .59737 L
.13859 .59852 L
.13979 .59923 L
.14096 .59955 L
.14207 .59949 L
.14306 .59912 L
.14415 .59834 L
.1448 .59768 L
.14548 .59682 L
.1467 .59483 L
.14802 .592 L
.14946 .58801 L
.15205 .57825 L
.15447 .5657 L
.15683 .5498 L
.15898 .53186 L
.16382 .47936 L
.16911 .40952 L
.172 .37314 L
.17472 .34493 L
.17702 .32692 L
.17832 .31926 L
.17951 .3137 L
.18074 .30932 L
.18144 .3074 L
.18209 .30595 L
.1834 .30395 L
.18413 .30331 L
.1848 .30301 L
.18599 .30304 L
.18725 .3038 L
.18832 .30495 L
.18951 .30668 L
.19215 .31194 L
.19461 .31821 L
.20388 .34805 L
.21453 .3865 L
.22464 .42183 L
.23435 .45118 L
Mistroke
.23701 .45788 L
.23984 .46412 L
.24229 .46861 L
.24357 .47057 L
.24493 .4723 L
.24618 .47353 L
.24688 .47407 L
.24754 .47446 L
.2487 .47487 L
.24994 .47488 L
.25121 .47438 L
.25241 .47342 L
.25349 .47214 L
.25466 .47027 L
.25688 .46544 L
.25924 .45865 L
.26347 .44355 L
.27286 .40719 L
.27779 .39055 L
.28298 .37609 L
.28754 .36609 L
.28995 .36181 L
.29253 .35796 L
.2949 .35503 L
.29706 .35286 L
.29924 .3511 L
.30127 .34981 L
.30359 .34874 L
.30482 .34832 L
.30613 .34799 L
.30679 .34786 L
.30751 .34775 L
.30882 .34763 L
.3101 .3476 L
.31128 .34764 L
.31237 .34773 L
.3134 .34787 L
.31453 .34807 L
.31574 .34833 L
.32049 .34978 L
.32578 .35194 L
.33135 .35453 L
.3413 .35906 L
.3462 .36096 L
.35083 .36244 L
.35339 .36312 L
.35617 .36374 L
.35848 .36416 L
.36102 .36452 L
.36217 .36465 L
Mistroke
.36341 .36477 L
.36449 .36485 L
.36566 .36493 L
.36697 .36499 L
.36822 .36502 L
.36944 .36504 L
.37057 .36504 L
.37172 .36502 L
.37281 .365 L
.37378 .36496 L
.37483 .36491 L
.3772 .36477 L
.37938 .3646 L
.39982 .36223 L
.40494 .36168 L
.40979 .36124 L
.41415 .36092 L
.4164 .36079 L
.41889 .36067 L
.42111 .36058 L
.42351 .3605 L
.42483 .36047 L
.42604 .36045 L
.4272 .36043 L
.42842 .36041 L
.42947 .36041 L
.4306 .3604 L
.43166 .3604 L
.43263 .3604 L
.43376 .3604 L
.43499 .36041 L
.43616 .36042 L
.43723 .36044 L
.43958 .36047 L
.44178 .36051 L
.44678 .36063 L
.45688 .36092 L
.4673 .3612 L
.47243 .36131 L
.47718 .36139 L
.48148 .36145 L
.48605 .3615 L
.48867 .36152 L
.49113 .36154 L
.49334 .36155 L
.49572 .36156 L
.49811 .36156 L
.49944 .36157 L
.50066 .36157 L
.5018 .36157 L
Mistroke
.50303 .36157 L
.50419 .36157 L
.50526 .36157 L
.50651 .36157 L
.50768 .36157 L
.50896 .36157 L
.50968 .36157 L
.51034 .36157 L
.51169 .36157 L
.51313 .36157 L
.51382 .36157 L
.51448 .36157 L
.51572 .36157 L
.51701 .36157 L
.5182 .36157 L
.5195 .36157 L
.52016 .36157 L
.52088 .36157 L
.52229 .36157 L
.5238 .36158 L
.52652 .36158 L
.52928 .36158 L
.5319 .36159 L
.5368 .3616 L
.54138 .36162 L
.54645 .36165 L
.5567 .36171 L
.57512 .36184 L
.59608 .36198 L
.60526 .36203 L
.61531 .36207 L
.62441 .3621 L
.63414 .36213 L
.64442 .36215 L
.65398 .36217 L
.65931 .36218 L
.66422 .36218 L
.66678 .36218 L
.66961 .36218 L
.67103 .36218 L
.67181 .36218 L
.67256 .36219 L
.67325 .36219 L
.674 .36219 L
.67532 .36219 L
.67598 .36219 L
.67669 .36219 L
.67797 .36219 L
.67923 .36219 L
.68038 .36219 L
Mistroke
.68163 .36218 L
.683 .36218 L
.68577 .36218 L
.68819 .36218 L
.69079 .36218 L
.69547 .36217 L
.70076 .36217 L
.70566 .36216 L
.71674 .36213 L
.7265 .3621 L
.73687 .36206 L
.77466 .36187 L
.8149 .36159 L
.85363 .36126 L
.89481 .36087 L
.93447 .36048 L
.97262 .3601 L
.97619 .36007 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.06244 .23823 L
.08255 .36397 L
.10458 .48502 L
.11448 .53079 L
.11992 .55269 L
.12507 .57066 L
.12986 .58445 L
.13238 .59035 L
.13506 .59539 L
.13731 .59854 L
.13859 .59983 L
.13979 .60069 L
.14089 .60115 L
.14189 .60128 L
.14305 .60107 L
.14415 .60049 L
.1454 .59934 L
.1461 .59846 L
.14674 .59749 L
.1479 .59532 L
.14918 .5923 L
.1514 .58529 L
.15374 .57518 L
.15629 .56059 L
.15902 .54035 L
.16396 .49137 L
.16859 .43472 L
.17351 .377 L
.17553 .35801 L
.17771 .34181 L
.17896 .33458 L
.1801 .3292 L
.18119 .32511 L
.18234 .32182 L
.18356 .31939 L
.18486 .31783 L
.18609 .31723 L
.1872 .31732 L
.18852 .31811 L
.18925 .31883 L
.18994 .31966 L
.19252 .32399 L
.19508 .32972 L
.19789 .33721 L
.20358 .35466 L
.22371 .42232 L
.22848 .43714 L
.23368 .45173 L
.23827 .46262 L
Mistroke
.24079 .46752 L
.24315 .47123 L
.24458 .47297 L
.24533 .47371 L
.24613 .47435 L
.2468 .47476 L
.24753 .47509 L
.24882 .47529 L
.25013 .47497 L
.25087 .47453 L
.25154 .47397 L
.25284 .47242 L
.25407 .47035 L
.25656 .46443 L
.25885 .45706 L
.26405 .43592 L
.27305 .39705 L
.27778 .37977 L
.28275 .36505 L
.2854 .35869 L
.2883 .35289 L
.29097 .34857 L
.29339 .34542 L
.29589 .34289 L
.29717 .34185 L
.29856 .34092 L
.29985 .34022 L
.30103 .3397 L
.30217 .33932 L
.30336 .33903 L
.30458 .33885 L
.30527 .33879 L
.3059 .33877 L
.30707 .33879 L
.30831 .33891 L
.30942 .33909 L
.31046 .33931 L
.31283 .34002 L
.31537 .34105 L
.31771 .34218 L
.32298 .34525 L
.3413 .35752 L
.35044 .36264 L
.35546 .36487 L
.3602 .36658 L
.3629 .36737 L
.36582 .3681 L
.37092 .36905 L
.37344 .36939 L
.37611 .36967 L
Mistroke
.37839 .36985 L
.37969 .36993 L
.3809 .36999 L
.3822 .37004 L
.38338 .37008 L
.3847 .37012 L
.38542 .37013 L
.3861 .37014 L
.38734 .37015 L
.38847 .37016 L
.38972 .37016 L
.39104 .37016 L
.39215 .37016 L
.39333 .37015 L
.39547 .37013 L
.39799 .37011 L
.40032 .37009 L
.40162 .37008 L
.40229 .37007 L
.40301 .37007 L
.40373 .37007 L
.4044 .37006 L
.4052 .37006 L
.40593 .37006 L
.40717 .37007 L
.40787 .37007 L
.40852 .37008 L
.40984 .37009 L
.41125 .37011 L
.41253 .37013 L
.41393 .37016 L
.41646 .37024 L
.4212 .37043 L
.4261 .3707 L
.43068 .37101 L
.44109 .37188 L
.46214 .37385 L
.47256 .37471 L
.48244 .37541 L
.50099 .3764 L
.52085 .37719 L
.53925 .37784 L
.57845 .37913 L
.59848 .37969 L
.62011 .38018 L
.66025 .38087 L
.68024 .38113 L
.70132 .38135 L
.72101 .3815 L
.73936 .38161 L
Mistroke
.74985 .38165 L
.75977 .38169 L
.76868 .38171 L
.77367 .38172 L
.77835 .38173 L
.78327 .38174 L
.78778 .38175 L
.79279 .38175 L
.79555 .38175 L
.79817 .38175 L
.8007 .38176 L
.80211 .38176 L
.80339 .38176 L
.80458 .38176 L
.80588 .38176 L
.8071 .38176 L
.80822 .38176 L
.80954 .38176 L
.81077 .38176 L
.81147 .38176 L
.81212 .38176 L
.81356 .38176 L
.81495 .38176 L
.81646 .38176 L
.8192 .38175 L
.82404 .38175 L
.82859 .38175 L
.83897 .38174 L
.84907 .38172 L
.85997 .3817 L
.9011 .38159 L
.94071 .38147 L
.97619 .38134 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.06244 .2383 L
.08255 .36404 L
.10458 .48503 L
.11448 .53075 L
.11992 .5526 L
.12507 .5705 L
.12986 .58421 L
.13238 .59005 L
.13506 .59502 L
.13731 .59808 L
.13859 .59932 L
.13979 .60012 L
.14089 .60053 L
.14189 .60061 L
.14305 .60033 L
.14415 .59967 L
.1454 .59843 L
.1461 .59748 L
.14674 .59645 L
.1479 .59417 L
.14918 .59101 L
.1514 .58371 L
.15374 .5732 L
.15629 .55807 L
.15902 .53709 L
.16396 .48636 L
.16859 .42804 L
.17113 .39625 L
.17351 .3696 L
.1757 .34936 L
.17771 .33495 L
.17877 .32892 L
.17994 .32355 L
.18111 .31934 L
.18234 .3161 L
.18303 .31477 L
.18368 .31381 L
.18489 .3127 L
.1862 .31241 L
.18694 .3126 L
.18761 .31299 L
.18875 .31403 L
.19 .31568 L
.19252 .32033 L
.19824 .33524 L
.20358 .3522 L
.22371 .42086 L
.22868 .43639 L
.23411 .45153 L
Mistroke
.2366 .45759 L
.23924 .46327 L
.24172 .4677 L
.24399 .47084 L
.24517 .47204 L
.2464 .47296 L
.24764 .47349 L
.24835 .4736 L
.24901 .47356 L
.2502 .47314 L
.25128 .47233 L
.25254 .47087 L
.25372 .46894 L
.25592 .46398 L
.25794 .45788 L
.26253 .44023 L
.27154 .40156 L
.27626 .38374 L
.28123 .36827 L
.28389 .36146 L
.28679 .35517 L
.29187 .34685 L
.29437 .34392 L
.29704 .34154 L
.29834 .34065 L
.29956 .33995 L
.30076 .3394 L
.30185 .33899 L
.30301 .33867 L
.30425 .33843 L
.3054 .33831 L
.30649 .33828 L
.30776 .33833 L
.30894 .33846 L
.31023 .33869 L
.3116 .33902 L
.31412 .33984 L
.31649 .34083 L
.3219 .34366 L
.34037 .3553 L
.35018 .36047 L
.35512 .36249 L
.36052 .36421 L
.36515 .3653 L
.36775 .36577 L
.3701 .3661 L
.3723 .36635 L
.37469 .36656 L
.37578 .36663 L
.37694 .3667 L
Mistroke
.37802 .36675 L
.37902 .36678 L
.38023 .36682 L
.38155 .36684 L
.38271 .36685 L
.38394 .36686 L
.38516 .36685 L
.3863 .36684 L
.38733 .36683 L
.38844 .36681 L
.39101 .36675 L
.39372 .36667 L
.39857 .36652 L
.40279 .36641 L
.40515 .36637 L
.40627 .36635 L
.4073 .36634 L
.40852 .36633 L
.40916 .36632 L
.40985 .36632 L
.41099 .36632 L
.41225 .36632 L
.4134 .36632 L
.41464 .36634 L
.41581 .36635 L
.41688 .36637 L
.41936 .36643 L
.42162 .3665 L
.42669 .36672 L
.43139 .36699 L
.43582 .36729 L
.45652 .36896 L
.47485 .37031 L
.48527 .37091 L
.49501 .37136 L
.5149 .37207 L
.53595 .37271 L
.57479 .37384 L
.59455 .37434 L
.61609 .37479 L
.65587 .37542 L
.67559 .37565 L
.69658 .37584 L
.70691 .37592 L
.71805 .37599 L
.72769 .37604 L
.73824 .37608 L
.74859 .37612 L
.75823 .37614 L
.76356 .37615 L
Mistroke
.76842 .37616 L
.7711 .37616 L
.77402 .37616 L
.77657 .37617 L
.77931 .37617 L
.78062 .37617 L
.78186 .37617 L
.78306 .37617 L
.78418 .37617 L
.78524 .37617 L
.78637 .37617 L
.78762 .37617 L
.78875 .37617 L
.7894 .37617 L
.79009 .37617 L
.79132 .37617 L
.792 .37617 L
.79264 .37617 L
.7941 .37617 L
.79653 .37617 L
.79914 .37617 L
.80479 .37616 L
.81014 .37616 L
.82017 .37614 L
.82982 .37612 L
.84007 .3761 L
.85849 .37605 L
.89622 .37592 L
.93642 .37575 L
.97509 .37557 L
.97619 .37556 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.06244 .23836 L
.08255 .3641 L
.10458 .48505 L
.11448 .53072 L
.11992 .55252 L
.12507 .57036 L
.12986 .58399 L
.13238 .58977 L
.13506 .59466 L
.13614 .59623 L
.13731 .59764 L
.13859 .59883 L
.13979 .59957 L
.14096 .59993 L
.14207 .59991 L
.14306 .59957 L
.14415 .59884 L
.1448 .59821 L
.14548 .59738 L
.1467 .59546 L
.14802 .59271 L
.14946 .58882 L
.15205 .57928 L
.15447 .567 L
.15683 .55141 L
.15898 .53381 L
.16382 .48224 L
.16911 .41332 L
.172 .37718 L
.17472 .34895 L
.17702 .33077 L
.17832 .32297 L
.17951 .31728 L
.18074 .31274 L
.18209 .30921 L
.18276 .30794 L
.18349 .30693 L
.1848 .30594 L
.18608 .30587 L
.18727 .30649 L
.18856 .30782 L
.18922 .30871 L
.18994 .30985 L
.1948 .32077 L
.20388 .34948 L
.21473 .38793 L
.22464 .42188 L
.23395 .44944 L
.2365 .45574 L
Mistroke
.23921 .46162 L
.24156 .46585 L
.24279 .46771 L
.24409 .46934 L
.24481 .47009 L
.2456 .47078 L
.24632 .47127 L
.24699 .47161 L
.2483 .47191 L
.24904 .47185 L
.24971 .47164 L
.25097 .47085 L
.25168 .47016 L
.25233 .46936 L
.25353 .46747 L
.25481 .46488 L
.25731 .45817 L
.25965 .4502 L
.26498 .42864 L
.27484 .38926 L
.28021 .37216 L
.2852 .35977 L
.28949 .35176 L
.29405 .34566 L
.29666 .34319 L
.29912 .34145 L
.30133 .34035 L
.30258 .3399 L
.30372 .33958 L
.30498 .33934 L
.30617 .33921 L
.30724 .33916 L
.30841 .33919 L
.30968 .3393 L
.31032 .33939 L
.31102 .33951 L
.31344 .34007 L
.31569 .3408 L
.31812 .34177 L
.32252 .34387 L
.33238 .34939 L
.34318 .35521 L
.34819 .35744 L
.35354 .3594 L
.3586 .3608 L
.36319 .36171 L
.3659 .36209 L
.3684 .36234 L
.3697 .36245 L
.37114 .36253 L
Mistroke
.37186 .36257 L
.37263 .3626 L
.37336 .36262 L
.37404 .36264 L
.37535 .36266 L
.37604 .36266 L
.37678 .36266 L
.37749 .36266 L
.37815 .36265 L
.37939 .36262 L
.38062 .36259 L
.38174 .36255 L
.38428 .36243 L
.39415 .36178 L
.39958 .36141 L
.40472 .36111 L
.4095 .36089 L
.41081 .36085 L
.4122 .36081 L
.4134 .36078 L
.4147 .36075 L
.41586 .36073 L
.41693 .36072 L
.41795 .36071 L
.41902 .36071 L
.4202 .36071 L
.4213 .36071 L
.42251 .36072 L
.42379 .36074 L
.42504 .36076 L
.42635 .36079 L
.42871 .36085 L
.43404 .36105 L
.4437 .36154 L
.46178 .36262 L
.47123 .36311 L
.48137 .36355 L
.49095 .36386 L
.49969 .36408 L
.53947 .36486 L
.57774 .36562 L
.59911 .366 L
.61845 .36627 L
.65766 .36668 L
.67696 .36683 L
.6869 .36689 L
.6978 .36694 L
.70814 .36698 L
.71779 .36701 L
.72312 .36702 L
Mistroke
.72797 .36703 L
.73066 .36703 L
.73357 .36704 L
.73613 .36704 L
.73887 .36704 L
.74017 .36704 L
.74141 .36704 L
.74262 .36705 L
.74374 .36705 L
.7448 .36705 L
.74592 .36705 L
.74717 .36705 L
.7483 .36705 L
.74895 .36705 L
.74964 .36705 L
.75087 .36705 L
.75156 .36705 L
.7522 .36705 L
.75366 .36705 L
.75609 .36704 L
.7587 .36704 L
.7614 .36704 L
.76434 .36704 L
.7697 .36703 L
.77972 .36701 L
.78912 .36699 L
.79949 .36696 L
.82049 .36688 L
.86069 .36669 L
.89936 .36646 L
.94049 .36619 L
.97619 .36595 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.06244 .23848 L
.08255 .36421 L
.10458 .48508 L
.11448 .53066 L
.11992 .55238 L
.12507 .57011 L
.12986 .58358 L
.13238 .58926 L
.13506 .59401 L
.13614 .59552 L
.13731 .59686 L
.13859 .59795 L
.13979 .59859 L
.14096 .59884 L
.14207 .59871 L
.14306 .59826 L
.14415 .59739 L
.1448 .59668 L
.14548 .59575 L
.1467 .59363 L
.14802 .59065 L
.14946 .58645 L
.15205 .57624 L
.15447 .56315 L
.15683 .54656 L
.15898 .52784 L
.16382 .47309 L
.16911 .40081 L
.172 .3638 L
.17472 .33563 L
.17702 .31806 L
.17832 .31074 L
.17951 .30553 L
.18074 .30152 L
.18144 .29981 L
.18209 .29856 L
.1834 .29695 L
.18413 .29652 L
.1848 .2964 L
.18599 .29676 L
.18725 .29784 L
.18832 .29924 L
.18951 .30124 L
.19215 .30704 L
.19461 .31376 L
.20388 .34492 L
.21453 .38444 L
.22464 .42049 L
.23435 .45032 L
Mistroke
.23701 .45715 L
.23984 .46352 L
.24229 .46813 L
.24357 .47015 L
.24493 .47195 L
.24618 .47327 L
.24684 .47382 L
.24754 .47429 L
.24878 .47481 L
.24994 .47489 L
.25121 .47452 L
.25241 .47369 L
.25349 .47253 L
.25466 .47081 L
.25688 .4663 L
.25924 .45991 L
.26347 .4456 L
.27309 .41011 L
.27833 .39321 L
.2832 .38014 L
.28773 .37041 L
.29184 .36353 L
.2964 .3579 L
.29891 .35562 L
.30127 .35395 L
.30362 .3527 L
.30481 .35222 L
.30612 .35179 L
.30723 .3515 L
.30842 .35128 L
.30955 .35113 L
.31058 .35105 L
.31186 .35103 L
.31305 .35107 L
.31436 .35118 L
.31502 .35125 L
.31575 .35136 L
.31828 .35185 L
.32065 .35246 L
.33082 .35609 L
.34152 .36013 L
.34618 .36158 L
.35115 .3628 L
.354 .36333 L
.3566 .3637 L
.35786 .36385 L
.35921 .36397 L
.3605 .36407 L
.36168 .36413 L
.36275 .36417 L
Mistroke
.36389 .3642 L
.36497 .36421 L
.36596 .3642 L
.36711 .36418 L
.36837 .36414 L
.36956 .36408 L
.37066 .36401 L
.37308 .36381 L
.37527 .36359 L
.38018 .36296 L
.39034 .36132 L
.40106 .35955 L
.41022 .35831 L
.41542 .35777 L
.42027 .35737 L
.42527 .35706 L
.42773 .35695 L
.43001 .35686 L
.43203 .35679 L
.43426 .35673 L
.4365 .35669 L
.43889 .35665 L
.44015 .35664 L
.44147 .35663 L
.4426 .35662 L
.44384 .35661 L
.44454 .35661 L
.44518 .35661 L
.44591 .35661 L
.44661 .3566 L
.44784 .3566 L
.44854 .3566 L
.44918 .3566 L
.45033 .3566 L
.45141 .35661 L
.4526 .35661 L
.45387 .35661 L
.45884 .35663 L
.46139 .35663 L
.46281 .35664 L
.4641 .35664 L
.46531 .35664 L
.46661 .35664 L
.46785 .35664 L
.46898 .35664 L
.46962 .35664 L
.47031 .35664 L
.47154 .35663 L
.47302 .35663 L
.47436 .35662 L
Mistroke
.47727 .35661 L
.48003 .35659 L
.48504 .35654 L
.48967 .35648 L
.50013 .35632 L
.52044 .35599 L
.53038 .35586 L
.53947 .35576 L
.54881 .35569 L
.55769 .35564 L
.56706 .3556 L
.57729 .35557 L
.61793 .35541 L
.65705 .35523 L
.69862 .35498 L
.73867 .35468 L
.77721 .35432 L
.8182 .35387 L
.85767 .3534 L
.89563 .35293 L
.93605 .3524 L
.97494 .3519 L
.97619 .35189 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.06244 .2385 L
.08255 .36424 L
.10458 .48509 L
.11448 .53064 L
.11992 .55234 L
.12507 .57004 L
.12986 .58348 L
.13238 .58913 L
.13506 .59384 L
.13614 .59533 L
.13731 .59665 L
.13859 .59771 L
.13979 .59833 L
.14096 .59855 L
.14207 .59838 L
.14306 .5979 L
.14415 .59699 L
.1448 .59625 L
.14548 .59529 L
.1467 .59312 L
.14802 .59006 L
.14946 .58577 L
.15205 .57535 L
.15447 .56199 L
.15683 .54508 L
.15898 .52598 L
.16382 .47012 L
.16911 .39657 L
.172 .35916 L
.17472 .33094 L
.17702 .31351 L
.17832 .30632 L
.17951 .30124 L
.18074 .29739 L
.18144 .29577 L
.18209 .29461 L
.1834 .29317 L
.18413 .29284 L
.1848 .2928 L
.18599 .29331 L
.18725 .29453 L
.18832 .29607 L
.18951 .29819 L
.19461 .31125 L
.20388 .34329 L
.22464 .42058 L
.23462 .45199 L
.23953 .46436 L
.24192 .46932 L
Mistroke
.24409 .47305 L
.24531 .47479 L
.24662 .47633 L
.24734 .47702 L
.24801 .47755 L
.24931 .47827 L
.25063 .47853 L
.25138 .47846 L
.25208 .47824 L
.25282 .47784 L
.2535 .47733 L
.25427 .47656 L
.25501 .47565 L
.25749 .47134 L
.25979 .46582 L
.26498 .44981 L
.27475 .41699 L
.27988 .40194 L
.28527 .38878 L
.29002 .37959 L
.29253 .37562 L
.29521 .37203 L
.29768 .36927 L
.29992 .36721 L
.30201 .36563 L
.3043 .36425 L
.30667 .36317 L
.30796 .36273 L
.30916 .36239 L
.31029 .36214 L
.31133 .36197 L
.31252 .36183 L
.31364 .36176 L
.31486 .36173 L
.31616 .36176 L
.31726 .36183 L
.31849 .36195 L
.31979 .36212 L
.3212 .36235 L
.32376 .36287 L
.33326 .36548 L
.3421 .36796 L
.34672 .36899 L
.34909 .36942 L
.35166 .3698 L
.35312 .36997 L
.35448 .3701 L
.35577 .3702 L
.35643 .37025 L
.35714 .37028 L
Mistroke
.35836 .37033 L
.35951 .37036 L
.36021 .37036 L
.36087 .37036 L
.36212 .37034 L
.3628 .37033 L
.36345 .3703 L
.36465 .37024 L
.36595 .37016 L
.36735 .37004 L
.36988 .36978 L
.37221 .36948 L
.38321 .36747 L
.39308 .3653 L
.40365 .36308 L
.41279 .3615 L
.42272 .36022 L
.42802 .35972 L
.43293 .35935 L
.43753 .35907 L
.4426 .35881 L
.45138 .35848 L
.46071 .35818 L
.50093 .35671 L
.51942 .35599 L
.53964 .35533 L
.5597 .35484 L
.5808 .35442 L
.62138 .35372 L
.66045 .3531 L
.70196 .3525 L
.74197 .3519 L
.78045 .3513 L
.82139 .35064 L
.86081 .34998 L
.89872 .34934 L
.93908 .34865 L
.97619 .34803 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.06244 .23832 L
.08255 .36404 L
.10458 .48502 L
.11448 .53073 L
.11992 .55257 L
.12507 .57046 L
.12986 .58416 L
.13238 .58999 L
.13506 .59495 L
.13731 .598 L
.13859 .59923 L
.13979 .60003 L
.14089 .60042 L
.14189 .60049 L
.14305 .6002 L
.14415 .59953 L
.1454 .59828 L
.1461 .59733 L
.14674 .59628 L
.1479 .59399 L
.14918 .5908 L
.1514 .58345 L
.15374 .57289 L
.15629 .55766 L
.15902 .53655 L
.16396 .48549 L
.16859 .42684 L
.17113 .39494 L
.17351 .36829 L
.1757 .34812 L
.17771 .33382 L
.17877 .32786 L
.17994 .32258 L
.18111 .31846 L
.18234 .31531 L
.18303 .31404 L
.18368 .31313 L
.18489 .31211 L
.1862 .3119 L
.18694 .31215 L
.18761 .31257 L
.18875 .31368 L
.19 .3154 L
.19252 .32017 L
.19824 .33525 L
.20358 .35225 L
.22371 .42055 L
.22868 .43591 L
.23411 .4508 L
Mistroke
.2366 .45672 L
.23924 .46221 L
.24172 .46644 L
.24399 .46934 L
.24517 .4704 L
.2464 .47115 L
.24764 .47148 L
.24835 .47147 L
.24901 .47131 L
.2502 .47066 L
.25128 .46961 L
.25254 .46785 L
.25372 .46562 L
.25592 .46006 L
.25794 .45341 L
.26253 .43464 L
.27154 .39478 L
.27626 .37679 L
.28123 .36138 L
.28389 .35468 L
.28679 .34856 L
.28945 .34397 L
.29187 .34061 L
.29437 .33789 L
.29566 .33676 L
.29704 .33574 L
.29833 .33497 L
.29952 .33439 L
.30065 .33396 L
.30185 .33362 L
.30306 .33339 L
.30375 .3333 L
.30439 .33326 L
.30555 .33325 L
.3068 .33333 L
.3079 .33348 L
.30894 .33369 L
.31008 .33398 L
.31131 .33436 L
.3166 .3367 L
.32146 .33957 L
.33979 .35215 L
.34892 .3575 L
.35394 .35987 L
.35869 .3617 L
.3643 .36335 L
.36695 .36395 L
.3694 .36441 L
.37168 .36476 L
.37419 .36508 L
Mistroke
.37671 .36532 L
.37938 .36552 L
.38187 .36564 L
.38328 .36569 L
.38458 .36573 L
.38584 .36576 L
.38698 .36578 L
.38829 .36579 L
.38953 .3658 L
.39066 .36581 L
.39185 .36581 L
.39287 .36581 L
.39398 .36581 L
.39519 .3658 L
.39648 .3658 L
.39761 .36579 L
.3988 .36579 L
.39947 .36579 L
.4002 .36579 L
.40149 .36579 L
.40222 .36579 L
.403 .36579 L
.40374 .36579 L
.40442 .36579 L
.40565 .3658 L
.40635 .36581 L
.40701 .36582 L
.40841 .36584 L
.40973 .36586 L
.41225 .36592 L
.41455 .36599 L
.41969 .3662 L
.42432 .36647 L
.42942 .36683 L
.43972 .36773 L
.45817 .36955 L
.469 .37052 L
.47927 .37132 L
.49853 .37245 L
.51712 .37326 L
.53738 .37403 L
.57809 .37545 L
.6173 .3765 L
.63876 .37694 L
.65895 .37728 L
.69757 .37777 L
.71757 .37795 L
.72775 .37803 L
.73865 .37809 L
.74896 .37815 L
Mistroke
.75834 .37819 L
.76725 .37822 L
.77669 .37824 L
.78664 .37826 L
.79583 .37828 L
.80093 .37828 L
.80572 .37829 L
.80846 .37829 L
.81096 .37829 L
.81235 .37829 L
.81386 .37829 L
.81455 .37829 L
.81529 .37829 L
.81597 .37829 L
.81661 .37829 L
.81785 .37829 L
.81851 .37829 L
.81921 .37829 L
.81995 .37829 L
.82065 .37829 L
.82196 .37829 L
.82319 .37829 L
.82432 .37829 L
.82689 .37829 L
.82945 .37829 L
.83228 .37829 L
.83801 .37828 L
.84302 .37828 L
.84841 .37827 L
.85818 .37826 L
.87821 .37822 L
.89931 .37817 L
.9374 .37807 L
.97619 .37794 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.06244 .2381 L
.08255 .36386 L
.10458 .485 L
.11448 .53087 L
.11992 .55284 L
.12507 .57092 L
.12986 .58485 L
.13238 .59085 L
.13506 .59602 L
.13731 .59929 L
.13859 .60067 L
.13979 .60161 L
.14089 .60216 L
.14189 .60239 L
.14305 .60229 L
.14415 .60183 L
.1454 .60083 L
.1461 .60004 L
.14674 .59916 L
.14793 .59713 L
.14918 .59437 L
.15135 .58797 L
.15374 .57831 L
.15629 .56453 L
.15902 .54538 L
.16396 .49886 L
.16859 .44447 L
.17351 .38757 L
.17553 .36826 L
.17771 .35139 L
.17896 .34368 L
.1801 .33783 L
.18119 .33331 L
.18234 .32951 L
.18357 .32656 L
.18471 .3247 L
.18541 .32395 L
.18607 .32348 L
.1873 .32319 L
.1886 .32361 L
.1898 .32457 L
.19112 .32617 L
.19252 .3284 L
.19524 .33401 L
.19779 .34038 L
.20358 .35744 L
.22371 .42395 L
.22868 .43925 L
.23411 .45426 L
Mistroke
.2389 .46535 L
.24152 .47023 L
.24281 .47224 L
.24399 .47381 L
.24515 .47508 L
.24642 .47613 L
.24769 .47678 L
.24839 .47695 L
.24904 .47698 L
.2502 .4767 L
.25125 .47606 L
.25246 .47482 L
.25361 .47315 L
.25469 .47111 L
.25583 .46845 L
.25789 .46247 L
.26253 .4445 L
.27215 .40171 L
.27739 .38154 L
.28226 .36639 L
.28644 .3563 L
.2909 .34833 L
.29344 .34498 L
.29584 .34253 L
.298 .34088 L
.29913 .34021 L
.30033 .33962 L
.30154 .33917 L
.30267 .33886 L
.30336 .33872 L
.30401 .33862 L
.30524 .33853 L
.30653 .33854 L
.30772 .33865 L
.30903 .33887 L
.30969 .33901 L
.31042 .3392 L
.31273 .33998 L
.31522 .34106 L
.31972 .34357 L
.34059 .35841 L
.35095 .36477 L
.3606 .36908 L
.36547 .37062 L
.37067 .37185 L
.37364 .37237 L
.37645 .37277 L
.37896 .37305 L
.3817 .37329 L
.38405 .37344 L
Mistroke
.38658 .37357 L
.38896 .37366 L
.39114 .37373 L
.3937 .37378 L
.39648 .37383 L
.40155 .37392 L
.40683 .37403 L
.40978 .37411 L
.41246 .37421 L
.41767 .37446 L
.42258 .37476 L
.43236 .37557 L
.44268 .37663 L
.46115 .37864 L
.48103 .38047 L
.49914 .38167 L
.51867 .38263 L
.53959 .38352 L
.57945 .38503 L
.6178 .38615 L
.63759 .38659 L
.65861 .38698 L
.69638 .38751 L
.71574 .3877 L
.7366 .38786 L
.75665 .38798 L
.76674 .38802 L
.77776 .38806 L
.78786 .38809 L
.79738 .38811 L
.80266 .38812 L
.80837 .38813 L
.81352 .38814 L
.81834 .38814 L
.82291 .38815 L
.82526 .38815 L
.82781 .38815 L
.82926 .38815 L
.83061 .38815 L
.832 .38815 L
.83326 .38815 L
.8345 .38815 L
.83567 .38815 L
.8369 .38815 L
.83759 .38815 L
.83823 .38815 L
.83945 .38815 L
.84076 .38815 L
.842 .38815 L
.84312 .38815 L
Mistroke
.84444 .38815 L
.84587 .38815 L
.84848 .38815 L
.8512 .38815 L
.85409 .38815 L
.85928 .38814 L
.86868 .38813 L
.8788 .38812 L
.8971 .3881 L
.93831 .38802 L
.97619 .38794 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.06244 .23838 L
.08255 .3641 L
.10458 .48504 L
.11448 .53069 L
.11992 .55248 L
.12507 .57031 L
.12986 .58392 L
.13238 .58969 L
.13506 .59456 L
.13614 .59613 L
.13731 .59753 L
.13859 .5987 L
.13979 .59944 L
.14096 .59978 L
.14207 .59975 L
.14306 .5994 L
.14415 .59865 L
.1448 .59802 L
.14548 .59718 L
.1467 .59523 L
.14802 .59246 L
.14946 .58853 L
.15205 .57891 L
.15447 .56652 L
.15683 .55079 L
.15898 .53303 L
.16382 .48092 L
.16911 .41134 L
.172 .375 L
.17472 .34678 L
.17702 .32875 L
.17832 .32106 L
.17951 .31548 L
.18074 .31108 L
.18144 .30915 L
.18209 .30769 L
.1834 .30567 L
.18413 .30502 L
.1848 .30471 L
.18599 .30473 L
.18725 .30548 L
.18832 .30662 L
.18951 .30834 L
.19215 .31358 L
.19461 .3198 L
.20388 .3492 L
.21453 .38672 L
.22464 .42087 L
.23435 .44868 L
Mistroke
.23701 .45481 L
.23984 .46031 L
.24122 .46252 L
.24251 .46428 L
.24366 .46555 L
.24493 .46659 L
.2461 .46719 L
.24719 .46739 L
.24834 .46721 L
.24957 .46651 L
.25072 .46536 L
.25181 .4638 L
.25278 .46201 L
.25384 .45964 L
.25627 .4526 L
.25884 .44309 L
.26347 .42301 L
.27286 .38252 L
.27779 .3653 L
.28298 .3511 L
.28754 .34186 L
.29012 .33789 L
.29253 .33494 L
.29474 .3328 L
.29676 .33131 L
.29787 .33065 L
.29908 .33007 L
.30022 .32964 L
.30127 .32934 L
.30253 .32908 L
.30372 .32895 L
.30479 .32892 L
.30596 .32896 L
.30722 .3291 L
.30786 .32921 L
.30857 .32935 L
.31099 .33002 L
.31324 .33087 L
.31567 .33199 L
.32007 .33442 L
.32993 .34087 L
.34072 .34787 L
.34573 .35068 L
.35109 .35325 L
.35572 .35506 L
.36074 .3566 L
.3637 .35731 L
.36642 .35784 L
.36898 .35824 L
.37179 .35858 L
Mistroke
.37431 .3588 L
.37666 .35895 L
.37797 .35901 L
.37915 .35905 L
.37981 .35907 L
.38053 .35909 L
.38183 .35911 L
.38248 .35912 L
.38316 .35913 L
.38439 .35913 L
.38571 .35913 L
.38645 .35912 L
.38715 .35912 L
.38842 .3591 L
.38957 .35908 L
.39216 .35903 L
.39702 .35893 L
.39916 .35888 L
.40152 .35884 L
.40273 .35883 L
.40402 .35881 L
.40474 .35881 L
.4054 .3588 L
.40668 .3588 L
.40799 .3588 L
.40873 .3588 L
.40942 .35881 L
.41015 .35881 L
.41081 .35882 L
.4123 .35884 L
.41361 .35886 L
.41481 .35889 L
.41754 .35897 L
.41995 .35906 L
.4225 .35917 L
.43194 .35976 L
.44209 .36059 L
.4604 .36221 L
.47055 .36301 L
.48159 .36374 L
.5017 .36472 L
.54242 .36613 L
.58162 .36736 L
.60165 .36788 L
.62328 .36835 L
.66341 .369 L
.68341 .36925 L
.70449 .36945 L
.72418 .36959 L
.74253 .36969 L
Mistroke
.75302 .36973 L
.76294 .36976 L
.77185 .36978 L
.77684 .36979 L
.78151 .3698 L
.78606 .3698 L
.79095 .36981 L
.79373 .36981 L
.7951 .36981 L
.79637 .36981 L
.79762 .36981 L
.79875 .36981 L
.8 .36981 L
.80069 .36981 L
.80134 .36981 L
.80256 .36981 L
.80325 .36981 L
.8039 .36981 L
.8052 .36981 L
.80593 .36981 L
.8066 .36981 L
.80779 .36981 L
.80909 .36981 L
.81144 .36981 L
.81419 .36981 L
.81712 .3698 L
.82237 .3698 L
.83173 .36979 L
.84183 .36977 L
.86011 .36973 L
.90123 .36961 L
.94085 .36947 L
.97619 .36933 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.06244 .2385 L
.08255 .36422 L
.10458 .48507 L
.11448 .53063 L
.11992 .55234 L
.12507 .57005 L
.12986 .5835 L
.13238 .58916 L
.13506 .59389 L
.13614 .59539 L
.13731 .59671 L
.13859 .59778 L
.13979 .59841 L
.14096 .59864 L
.14207 .59849 L
.14306 .59802 L
.14415 .59712 L
.1448 .59639 L
.14548 .59544 L
.1467 .59328 L
.14802 .59025 L
.14946 .58598 L
.15205 .57561 L
.15447 .56231 L
.15683 .54544 L
.15898 .52639 L
.16382 .47054 L
.16911 .39685 L
.172 .3594 L
.17472 .33118 L
.17702 .31377 L
.17832 .30658 L
.17951 .30151 L
.18074 .29766 L
.18144 .29604 L
.18209 .29488 L
.1834 .29343 L
.18413 .2931 L
.1848 .29306 L
.18599 .29356 L
.18725 .29478 L
.18832 .2963 L
.18951 .29842 L
.19461 .31138 L
.20388 .34299 L
.21473 .38323 L
.22464 .4181 L
.22942 .43321 L
.23462 .44768 L
Mistroke
.237 .45339 L
.23953 .45865 L
.24191 .46267 L
.24295 .46411 L
.24409 .46542 L
.24541 .46657 L
.24613 .46701 L
.24681 .46729 L
.24755 .46746 L
.24822 .46746 L
.249 .46728 L
.24974 .46693 L
.25038 .46647 L
.25106 .46582 L
.25229 .46422 L
.2536 .46188 L
.25505 .45856 L
.25752 .45131 L
.26018 .44177 L
.26498 .42228 L
.27539 .38239 L
.28046 .3672 L
.28506 .35628 L
.28994 .34758 L
.29262 .34397 L
.29515 .34125 L
.29791 .33898 L
.30044 .33747 L
.30177 .33688 L
.30323 .33638 L
.30396 .33618 L
.30475 .33601 L
.3055 .33588 L
.30617 .3358 L
.30735 .33571 L
.30845 .33569 L
.30966 .33575 L
.31097 .33588 L
.31227 .33609 L
.31363 .33637 L
.31607 .33704 L
.32045 .33864 L
.32524 .34078 L
.3361 .34603 L
.34599 .35009 L
.35082 .35157 L
.35336 .35219 L
.35606 .35274 L
.35841 .35312 L
.35966 .35328 L
Mistroke
.36101 .35343 L
.36224 .35354 L
.36337 .35363 L
.3645 .35369 L
.36557 .35374 L
.36689 .35377 L
.36809 .35379 L
.36875 .35379 L
.36947 .35378 L
.37077 .35375 L
.37199 .35371 L
.37328 .35366 L
.37559 .35351 L
.37828 .3533 L
.3808 .35306 L
.38652 .35241 L
.39556 .35129 L
.40517 .35026 L
.41018 .34986 L
.41284 .34969 L
.4157 .34953 L
.41832 .34942 L
.42073 .34935 L
.42303 .3493 L
.42418 .34928 L
.42544 .34926 L
.42613 .34926 L
.42688 .34925 L
.42759 .34925 L
.42824 .34925 L
.42947 .34925 L
.43077 .34926 L
.43145 .34926 L
.43217 .34927 L
.43348 .34928 L
.43646 .34933 L
.43921 .34939 L
.44181 .34946 L
.4467 .34961 L
.45645 .34994 L
.46683 .35026 L
.4722 .35039 L
.47725 .35049 L
.48217 .35057 L
.48669 .35063 L
.49099 .35067 L
.49554 .35071 L
.50009 .35073 L
.50509 .35075 L
.51599 .35079 L
Mistroke
.52629 .35084 L
.53554 .3509 L
.54559 .35098 L
.58457 .35138 L
.60401 .35155 L
.62542 .35169 L
.64573 .35179 L
.66476 .35185 L
.66972 .35187 L
.67513 .35188 L
.67991 .35189 L
.685 .3519 L
.68759 .3519 L
.69003 .3519 L
.69241 .35191 L
.6946 .35191 L
.69668 .35191 L
.69773 .35191 L
.69889 .35191 L
.70004 .35191 L
.70128 .35191 L
.70245 .35191 L
.70352 .35191 L
.7047 .35191 L
.7058 .35191 L
.70702 .35191 L
.70832 .35191 L
.71099 .35191 L
.71343 .35191 L
.71789 .3519 L
.7226 .35189 L
.73251 .35188 L
.74335 .35185 L
.76295 .35177 L
.7839 .35167 L
.82539 .35141 L
.86536 .35109 L
.90381 .35075 L
.94472 .35037 L
.97619 .35007 L
Mfstroke
1 .356 0 r
.02381 .01472 m
.06244 .23841 L
.08255 .36414 L
.10458 .48504 L
.11448 .53066 L
.11992 .55242 L
.12507 .5702 L
.12986 .58375 L
.13238 .58947 L
.13506 .59428 L
.13614 .59581 L
.13731 .59718 L
.13859 .5983 L
.13979 .59899 L
.14096 .59928 L
.14207 .59919 L
.14306 .59878 L
.14415 .59796 L
.1448 .59727 L
.14548 .59638 L
.1467 .59432 L
.14802 .59141 L
.14946 .58731 L
.15205 .57729 L
.15447 .5644 L
.15683 .54802 L
.15898 .52951 L
.16382 .47508 L
.16911 .40249 L
.172 .3649 L
.17472 .33604 L
.17702 .31787 L
.17832 .31025 L
.17951 .3048 L
.18074 .30057 L
.18144 .29876 L
.18209 .29743 L
.1834 .29569 L
.18413 .29522 L
.1848 .29506 L
.18599 .2954 L
.18725 .29649 L
.18832 .29794 L
.18951 .30002 L
.19215 .30611 L
.19461 .31322 L
.20388 .34654 L
.22464 .42861 L
.23505 .46478 L
.24018 .48002 L
Mistroke
.24493 .49206 L
.24923 .5007 L
.25163 .50438 L
.2538 .50687 L
.25505 .50792 L
.25619 .50861 L
.25745 .50908 L
.25809 .5092 L
.25878 .50923 L
.25995 .50909 L
.26121 .50866 L
.26239 .50799 L
.26347 .50719 L
.26576 .50491 L
.26829 .50165 L
.27341 .49338 L
.28259 .47629 L
.29343 .45797 L
.29818 .45154 L
.30336 .44577 L
.30826 .44149 L
.31281 .43844 L
.31762 .43607 L
.32031 .43507 L
.32275 .43433 L
.32526 .43372 L
.32791 .43322 L
.33081 .43281 L
.33349 .43253 L
.33599 .43233 L
.33832 .43219 L
.34362 .43192 L
.34862 .43166 L
.35144 .43146 L
.35405 .43123 L
.35885 .43067 L
.36395 .42985 L
.37276 .42784 L
.3825 .42488 L
.40344 .4174 L
.42267 .41132 L
.44149 .40695 L
.46132 .40359 L
.4994 .39842 L
.53993 .39383 L
.57894 .39054 L
.6204 .38784 L
.66035 .38576 L
.69879 .38415 L
.73968 .38272 L
Mistroke
.77905 .38154 L
.8169 .38052 L
.85721 .37952 L
.896 .37861 L
.93724 .3777 L
.97619 .37687 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.06244 .23799 L
.08255 .36376 L
.10458 .48498 L
.11448 .53093 L
.11992 .55298 L
.12507 .57115 L
.12986 .5852 L
.13238 .59128 L
.13506 .59655 L
.13731 .59993 L
.13859 .60138 L
.13979 .6024 L
.14089 .60302 L
.14189 .60332 L
.14305 .60332 L
.14415 .60295 L
.1454 .60209 L
.1461 .60137 L
.14674 .60057 L
.14793 .59869 L
.14918 .59611 L
.15135 .59008 L
.15374 .58091 L
.15629 .5678 L
.15902 .54954 L
.16396 .50503 L
.16859 .45247 L
.17351 .39623 L
.17553 .37665 L
.17771 .35921 L
.17896 .35109 L
.1801 .34484 L
.18119 .33993 L
.18234 .33572 L
.18357 .33234 L
.18471 .3301 L
.18541 .32912 L
.18607 .32845 L
.1873 .3278 L
.1886 .32788 L
.1898 .32855 L
.19112 .32987 L
.19252 .33183 L
.19524 .33698 L
.19779 .34302 L
.20358 .35954 L
.22371 .42529 L
.22868 .44057 L
.23411 .45562 L
Mistroke
.2389 .46682 L
.24152 .47181 L
.24281 .47388 L
.24399 .47553 L
.24515 .47688 L
.24642 .47802 L
.24769 .47879 L
.24839 .47903 L
.24904 .47912 L
.2502 .47898 L
.25125 .47847 L
.25246 .4774 L
.25361 .47588 L
.25469 .474 L
.25583 .47151 L
.25789 .4658 L
.26253 .44821 L
.27215 .40522 L
.27739 .38468 L
.28226 .36918 L
.28644 .35881 L
.2909 .35059 L
.29344 .34712 L
.29584 .34458 L
.298 .34285 L
.30033 .34153 L
.30154 .34104 L
.30267 .34071 L
.30391 .34046 L
.3046 .34038 L
.30524 .34033 L
.30651 .34033 L
.30723 .34037 L
.3079 .34045 L
.30912 .34065 L
.31042 .34096 L
.3127 .34171 L
.31484 .34263 L
.31972 .34534 L
.34059 .36049 L
.3504 .36678 L
.35576 .36955 L
.36075 .37167 L
.36537 .37323 L
.36958 .37435 L
.37425 .37528 L
.37682 .37567 L
.37924 .37598 L
.38386 .3764 L
.38649 .37658 L
Mistroke
.38895 .3767 L
.3939 .37688 L
.39923 .37702 L
.40417 .37715 L
.40887 .3773 L
.41308 .37748 L
.41768 .37773 L
.42801 .37851 L
.43736 .37945 L
.45834 .38184 L
.47923 .38392 L
.49843 .3853 L
.51719 .3863 L
.537 .3872 L
.57499 .38874 L
.59615 .38946 L
.61544 .39001 L
.65436 .39085 L
.67346 .39117 L
.69423 .39146 L
.71363 .39167 L
.73503 .39185 L
.7553 .39198 L
.77432 .39207 L
.78416 .3921 L
.79452 .39213 L
.80422 .39216 L
.81302 .39217 L
.82258 .39218 L
.82783 .39219 L
.83278 .39219 L
.83737 .3922 L
.8416 .3922 L
.84381 .3922 L
.84624 .3922 L
.84747 .3922 L
.84878 .3922 L
.85002 .3922 L
.85115 .3922 L
.85245 .3922 L
.85367 .3922 L
.85476 .3922 L
.85594 .3922 L
.85723 .3922 L
.8586 .3922 L
.86103 .3922 L
.8654 .3922 L
.87019 .39219 L
.88093 .39219 L
.89093 .39218 L
Mistroke
.91134 .39215 L
.92991 .39213 L
.96983 .39206 L
.97619 .39205 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.06244 .2385 L
.08255 .36421 L
.10458 .48505 L
.11448 .53061 L
.11992 .55231 L
.12507 .57002 L
.12986 .58347 L
.13238 .58913 L
.13506 .59385 L
.13614 .59535 L
.13731 .59666 L
.13859 .59774 L
.13979 .59836 L
.14096 .59858 L
.14207 .59842 L
.14306 .59794 L
.14415 .59703 L
.1448 .59629 L
.14548 .59534 L
.1467 .59316 L
.14802 .5901 L
.14946 .5858 L
.15205 .57535 L
.15447 .56192 L
.15683 .54487 L
.15898 .52557 L
.16382 .46879 L
.16911 .39371 L
.172 .35568 L
.17472 .32721 L
.17702 .30978 L
.17832 .30264 L
.17951 .29763 L
.18074 .29385 L
.18144 .29229 L
.18209 .29117 L
.1834 .28983 L
.18413 .28955 L
.1848 .28957 L
.18599 .29016 L
.18725 .29148 L
.18832 .2931 L
.18951 .29531 L
.19461 .30864 L
.20388 .34063 L
.21473 .38074 L
.22464 .41492 L
.22942 .42945 L
.23462 .443 L
Mistroke
.237 .44813 L
.23953 .45263 L
.24077 .45439 L
.24192 .45576 L
.24297 .45672 L
.24409 .45745 L
.2454 .45784 L
.24662 .45772 L
.24732 .45742 L
.24796 .45699 L
.24869 .4563 L
.24939 .45545 L
.25078 .45314 L
.25207 .45028 L
.25498 .44127 L
.25983 .4206 L
.26498 .39627 L
.27438 .35764 L
.27966 .34159 L
.28449 .33063 L
.28875 .32371 L
.29117 .32081 L
.29341 .31871 L
.29463 .31779 L
.29579 .31706 L
.29684 .31651 L
.29795 .31602 L
.29916 .31562 L
.30027 .31535 L
.30147 .31516 L
.30279 .31507 L
.30409 .31509 L
.30529 .3152 L
.30661 .31542 L
.30728 .31556 L
.30802 .31575 L
.31057 .31657 L
.31297 .31758 L
.32227 .32283 L
.33245 .32944 L
.34318 .33562 L
.34783 .33776 L
.3528 .33962 L
.35566 .34049 L
.35826 .34115 L
.3609 .34171 L
.36333 .34212 L
.36555 .34242 L
.3679 .34267 L
.37025 .34284 L
Mistroke
.37159 .34291 L
.37285 .34296 L
.37401 .343 L
.37511 .34302 L
.3761 .34303 L
.37718 .34303 L
.37835 .34302 L
.37959 .343 L
.38077 .34298 L
.38183 .34295 L
.38671 .34277 L
.39187 .34253 L
.39632 .34233 L
.40109 .34215 L
.40247 .34211 L
.40378 .34208 L
.40505 .34205 L
.40623 .34203 L
.40734 .34202 L
.40853 .34201 L
.40971 .342 L
.41102 .342 L
.41171 .34201 L
.41244 .34201 L
.41373 .34203 L
.41445 .34204 L
.41512 .34205 L
.41664 .34208 L
.4192 .34215 L
.42192 .34225 L
.42725 .34252 L
.43217 .34282 L
.44328 .34366 L
.46344 .34524 L
.48221 .34637 L
.49288 .34684 L
.50286 .34721 L
.5417 .34841 L
.583 .34964 L
.62278 .35054 L
.66105 .35117 L
.68077 .35141 L
.70176 .35162 L
.71209 .3517 L
.72323 .35178 L
.73286 .35183 L
.74342 .35188 L
.75377 .35192 L
.76341 .35195 L
.77359 .35197 L
Mistroke
.7793 .35198 L
.78177 .35198 L
.78449 .35198 L
.78682 .35198 L
.78932 .35199 L
.7907 .35199 L
.79197 .35199 L
.79325 .35199 L
.79444 .35199 L
.79553 .35199 L
.79669 .35199 L
.79798 .35199 L
.79915 .35199 L
.80026 .35199 L
.80146 .35199 L
.80259 .35199 L
.80363 .35199 L
.80612 .35199 L
.80845 .35198 L
.81373 .35198 L
.81889 .35197 L
.82441 .35197 L
.83458 .35195 L
.84564 .35193 L
.86576 .35187 L
.90653 .35172 L
.94578 .35155 L
.97619 .35141 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.06244 .23854 L
.08255 .36427 L
.10458 .48509 L
.11448 .53061 L
.11992 .55228 L
.12507 .56995 L
.12986 .58334 L
.13238 .58896 L
.13376 .59155 L
.13506 .59363 L
.13623 .59522 L
.13731 .59639 L
.1385 .59737 L
.13979 .59802 L
.14086 .5982 L
.14202 .59802 L
.14313 .59744 L
.14415 .59654 L
.14544 .59485 L
.1468 .59235 L
.14796 .58958 L
.14923 .58582 L
.15207 .57432 L
.15472 .55915 L
.15723 .54019 L
.15952 .51861 L
.16467 .45553 L
.16933 .38938 L
.1737 .33628 L
.17589 .31719 L
.17712 .30892 L
.17825 .30284 L
.17942 .29794 L
.1807 .29405 L
.18135 .29262 L
.18204 .29145 L
.18328 .2902 L
.18456 .28991 L
.18529 .29014 L
.18595 .29058 L
.18718 .29189 L
.18848 .2939 L
.19072 .29859 L
.19319 .30511 L
.20237 .33612 L
.22313 .41386 L
.2331 .44594 L
.23802 .4588 L
.24257 .46807 L
Mistroke
.2451 .47175 L
.24583 .47257 L
.24652 .47324 L
.2478 .47419 L
.24849 .47453 L
.24922 .47475 L
.25053 .47475 L
.25126 .47453 L
.25195 .47417 L
.25269 .4736 L
.25349 .47278 L
.25478 .47102 L
.25617 .4685 L
.25871 .46243 L
.26347 .4474 L
.27282 .41431 L
.28289 .38493 L
.28866 .37277 L
.29118 .36854 L
.29394 .36463 L
.29638 .36175 L
.29899 .35925 L
.30174 .35719 L
.3043 .35577 L
.30559 .35522 L
.30695 .35474 L
.30812 .35442 L
.3094 .35414 L
.31011 .35403 L
.31077 .35394 L
.31153 .35386 L
.31225 .35382 L
.31352 .35378 L
.31424 .35379 L
.31491 .35382 L
.3161 .3539 L
.31721 .35402 L
.31844 .3542 L
.31976 .35442 L
.32491 .35566 L
.3346 .35866 L
.34362 .36124 L
.34824 .36223 L
.35082 .36265 L
.35317 .36295 L
.35443 .36308 L
.35575 .36318 L
.35645 .36323 L
.35721 .36327 L
.35791 .3633 L
Mistroke
.35855 .36332 L
.35982 .36334 L
.36052 .36335 L
.36118 .36334 L
.36235 .36332 L
.36364 .36327 L
.36432 .36324 L
.36507 .3632 L
.36641 .3631 L
.36893 .36286 L
.37187 .3625 L
.37458 .3621 L
.38473 .36016 L
.39459 .35804 L
.40516 .35598 L
.41514 .35447 L
.42423 .3535 L
.42909 .35313 L
.43358 .35285 L
.43851 .35262 L
.44375 .35243 L
.45253 .35219 L
.46223 .35198 L
.50245 .35078 L
.52094 .35017 L
.54116 .34966 L
.56121 .34929 L
.58232 .34898 L
.6229 .34846 L
.66196 .34799 L
.70348 .34749 L
.74348 .34698 L
.78197 .34645 L
.82291 .34585 L
.86233 .34523 L
.90024 .34463 L
.9406 .34398 L
.97619 .34342 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.06244 .23856 L
.08255 .36429 L
.10458 .48509 L
.11448 .53059 L
.11992 .55224 L
.12507 .56987 L
.12986 .58322 L
.13238 .58881 L
.13376 .59137 L
.13506 .59343 L
.13623 .595 L
.13731 .59615 L
.1385 .5971 L
.13979 .59771 L
.14086 .59786 L
.14202 .59763 L
.14313 .59701 L
.14415 .59605 L
.14544 .5943 L
.1468 .59172 L
.14796 .58886 L
.14923 .58499 L
.15207 .57318 L
.15472 .5576 L
.15723 .53811 L
.15952 .5159 L
.16467 .45082 L
.16933 .38268 L
.1737 .3286 L
.17589 .30946 L
.17712 .30127 L
.17825 .2953 L
.17942 .29056 L
.1807 .28688 L
.18135 .28556 L
.18204 .28451 L
.18328 .28348 L
.18456 .28344 L
.18529 .28381 L
.18595 .28438 L
.18718 .28592 L
.18848 .28818 L
.19072 .2933 L
.19319 .3003 L
.20237 .33311 L
.22313 .41452 L
.2331 .44831 L
.23802 .46221 L
.24257 .47277 L
Mistroke
.2451 .47738 L
.2464 .47931 L
.2478 .48105 L
.2486 .48186 L
.24934 .48248 L
.25004 .48295 L
.25079 .48332 L
.25208 .48362 L
.25281 .48359 L
.25349 .48343 L
.25479 .48277 L
.25601 .48172 L
.25711 .48042 L
.25831 .47865 L
.26099 .47353 L
.26347 .46769 L
.27324 .44059 L
.28376 .4139 L
.2886 .40415 L
.29369 .39588 L
.29804 .39039 L
.30279 .3859 L
.30534 .38408 L
.30776 .3827 L
.30992 .38173 L
.31227 .38091 L
.31483 .38028 L
.31612 .38006 L
.31686 .37995 L
.31753 .37987 L
.31874 .37976 L
.32004 .37969 L
.32124 .37966 L
.32238 .37966 L
.32342 .37969 L
.32457 .37974 L
.32578 .37981 L
.32691 .3799 L
.3311 .38035 L
.34059 .38157 L
.34285 .38181 L
.34527 .38203 L
.34666 .38213 L
.34793 .3822 L
.3492 .38226 L
.3504 .38229 L
.35166 .38231 L
.35229 .38231 L
.35298 .38231 L
.35421 .38229 L
Mistroke
.35536 .38225 L
.35606 .38222 L
.35672 .38218 L
.35796 .3821 L
.36075 .38184 L
.36297 .38156 L
.36533 .3812 L
.36959 .38039 L
.37924 .37796 L
.39923 .37193 L
.40974 .36909 L
.42085 .36667 L
.4308 .365 L
.44173 .36359 L
.46093 .36172 L
.50138 .35824 L
.5403 .35538 L
.58169 .35322 L
.62155 .35157 L
.6599 .35023 L
.7007 .34899 L
.73999 .34792 L
.77776 .34694 L
.81798 .34593 L
.85669 .34498 L
.89785 .34398 L
.93749 .34305 L
.97562 .34218 L
.97619 .34216 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.06244 .23851 L
.08255 .36423 L
.10458 .48507 L
.11448 .53061 L
.11992 .5523 L
.12507 .56999 L
.12986 .58341 L
.13238 .58904 L
.13506 .59373 L
.13614 .59521 L
.13731 .59651 L
.13859 .59756 L
.13979 .59815 L
.14096 .59835 L
.14207 .59816 L
.14306 .59765 L
.14415 .59671 L
.1448 .59595 L
.14548 .59497 L
.1467 .59274 L
.14802 .58962 L
.14946 .58525 L
.15205 .57462 L
.15447 .561 L
.15683 .54371 L
.15898 .52416 L
.16382 .46674 L
.16911 .39094 L
.172 .35254 L
.17472 .32379 L
.17702 .30624 L
.17832 .29908 L
.17951 .29409 L
.18074 .29036 L
.18144 .28883 L
.18209 .28776 L
.1834 .28651 L
.18413 .28631 L
.1848 .28639 L
.18599 .28711 L
.18725 .28859 L
.18832 .29035 L
.18951 .29273 L
.19461 .30698 L
.20388 .34141 L
.22464 .42384 L
.23462 .45794 L
.23953 .47209 L
.24409 .48304 L
Mistroke
.24683 .48834 L
.24931 .49212 L
.25073 .49379 L
.25207 .49498 L
.25281 .49548 L
.25348 .49583 L
.25422 .4961 L
.25501 .49624 L
.2562 .49619 L
.25747 .49578 L
.25867 .49505 L
.25977 .49412 L
.26245 .49089 L
.26498 .48681 L
.28324 .44793 L
.28824 .43837 L
.29363 .42961 L
.29828 .42343 L
.30336 .41812 L
.30841 .41422 L
.31115 .41261 L
.31371 .4114 L
.31607 .4105 L
.31829 .40983 L
.32085 .40923 L
.32318 .40884 L
.32439 .40868 L
.32573 .40854 L
.32713 .40843 L
.32843 .40835 L
.32965 .4083 L
.33077 .40827 L
.33205 .40824 L
.33327 .40824 L
.33459 .40824 L
.33525 .40824 L
.33599 .40825 L
.3385 .40829 L
.34122 .40833 L
.34197 .40834 L
.34276 .40835 L
.34351 .40835 L
.3442 .40836 L
.34541 .40836 L
.34672 .40835 L
.34796 .40832 L
.34911 .4083 L
.3503 .40825 L
.35162 .40819 L
.35428 .40802 L
Mistroke
.35658 .40781 L
.35905 .40753 L
.36352 .40684 L
.36911 .40567 L
.37441 .40429 L
.38437 .40117 L
.40442 .39431 L
.42258 .38916 L
.43272 .38696 L
.44227 .38527 L
.46325 .38232 L
.50182 .37776 L
.54284 .37371 L
.58235 .37086 L
.62034 .36867 L
.66078 .36677 L
.69971 .36524 L
.74109 .36385 L
.78096 .36265 L
.81931 .36158 L
.86011 .3605 L
.8994 .3595 L
.93717 .35858 L
.97619 .35766 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.06244 .23827 L
.08255 .364 L
.10458 .48502 L
.11448 .53075 L
.11992 .55261 L
.12507 .57053 L
.12986 .58425 L
.13238 .5901 L
.13506 .59508 L
.13731 .59816 L
.13859 .5994 L
.13979 .60021 L
.14089 .60062 L
.14189 .6007 L
.14305 .60042 L
.14415 .59976 L
.1454 .59853 L
.1461 .59759 L
.14674 .59655 L
.1479 .59427 L
.14918 .59111 L
.1514 .58379 L
.15374 .57325 L
.15629 .55805 L
.15902 .53693 L
.16396 .4857 L
.16859 .42656 L
.17113 .39422 L
.17351 .36706 L
.1757 .3464 L
.17771 .33166 L
.17877 .3255 L
.17994 .32 L
.18111 .31571 L
.18234 .3124 L
.18303 .31106 L
.18368 .31009 L
.18489 .30899 L
.1862 .30874 L
.18694 .30897 L
.18761 .30941 L
.18875 .31056 L
.19 .31236 L
.19252 .31741 L
.19824 .33372 L
.20358 .35246 L
.22371 .42997 L
.23411 .46676 L
.23924 .48274 L
Mistroke
.24399 .4958 L
.24865 .50651 L
.25286 .51396 L
.25402 .51556 L
.25527 .51705 L
.25636 .51813 L
.25754 .51909 L
.25881 .51983 L
.2595 .52012 L
.26014 .52031 L
.2613 .52048 L
.26253 .5204 L
.26375 .52008 L
.26445 .51979 L
.2651 .51945 L
.26642 .51858 L
.26783 .51739 L
.27273 .51159 L
.28381 .49352 L
.29343 .47805 L
.29852 .47118 L
.30394 .46508 L
.3094 .46022 L
.31435 .45684 L
.31933 .4543 L
.32402 .45256 L
.32659 .45184 L
.3293 .45123 L
.33416 .45042 L
.33686 .4501 L
.33939 .44986 L
.34514 .44942 L
.35013 .44905 L
.35557 .44855 L
.36071 .44791 L
.36546 .44712 L
.37445 .44508 L
.38401 .4422 L
.42173 .42924 L
.44105 .42439 L
.4619 .42063 L
.50301 .41488 L
.5426 .41034 L
.58068 .40708 L
.62121 .40441 L
.66022 .40237 L
.70168 .40067 L
.74163 .39934 L
.78007 .39826 L
.82095 .39726 L
Mistroke
.86032 .3964 L
.89818 .39562 L
.93849 .39484 L
.97619 .39415 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.06244 .23825 L
.08255 .36398 L
.10458 .48501 L
.11448 .53077 L
.11992 .55265 L
.12507 .5706 L
.12986 .58437 L
.13238 .59025 L
.13506 .59528 L
.13731 .5984 L
.13859 .59968 L
.13979 .60052 L
.14089 .60097 L
.14189 .60108 L
.14305 .60085 L
.14415 .60025 L
.1454 .59908 L
.1461 .59818 L
.14674 .59719 L
.1479 .59499 L
.14918 .59192 L
.1514 .58483 L
.15374 .5746 L
.15629 .55983 L
.15902 .53934 L
.16396 .48972 L
.16859 .43239 L
.17351 .37431 L
.17553 .35534 L
.17771 .33926 L
.17896 .33213 L
.1801 .32685 L
.18119 .32286 L
.18234 .31969 L
.18356 .31738 L
.18486 .31595 L
.18609 .31546 L
.1872 .31565 L
.18852 .31655 L
.18925 .31734 L
.18994 .31822 L
.19252 .32273 L
.19508 .32862 L
.19789 .33625 L
.20358 .35389 L
.22371 .42149 L
.22848 .43615 L
.23368 .45049 L
.23827 .46106 L
Mistroke
.24079 .46572 L
.24315 .46915 L
.24458 .47068 L
.24539 .47133 L
.24613 .47179 L
.24744 .47225 L
.2481 .47229 L
.24882 .47217 L
.25013 .47152 L
.25087 .47089 L
.25154 .47014 L
.25284 .46818 L
.25407 .46571 L
.25656 .45893 L
.25885 .4508 L
.26405 .42834 L
.27305 .38856 L
.27778 .37129 L
.28275 .35682 L
.2854 .35066 L
.2883 .34512 L
.29097 .34105 L
.29339 .33815 L
.29589 .33587 L
.29726 .33491 L
.29856 .33418 L
.29976 .33364 L
.30087 .33326 L
.30208 .33296 L
.30336 .33277 L
.30458 .33271 L
.30527 .33271 L
.3059 .33275 L
.30707 .33288 L
.30831 .33311 L
.30942 .33339 L
.31046 .33371 L
.31283 .33462 L
.31771 .33716 L
.32298 .3406 L
.3413 .35383 L
.35086 .35952 L
.35634 .36208 L
.36132 .36395 L
.3666 .36545 L
.3695 .36609 L
.37224 .36658 L
.37461 .36693 L
.37712 .36723 L
.37987 .36748 L
Mistroke
.38241 .36766 L
.38493 .3678 L
.38733 .36789 L
.38948 .36795 L
.39183 .36801 L
.39709 .36809 L
.40196 .36816 L
.40436 .36821 L
.40661 .36826 L
.41082 .36839 L
.41536 .36859 L
.42027 .36887 L
.42978 .36961 L
.44022 .37065 L
.46129 .37293 L
.48245 .37481 L
.50173 .37602 L
.54066 .37775 L
.58053 .37926 L
.61888 .38036 L
.63867 .3808 L
.65968 .38118 L
.69745 .38171 L
.71681 .3819 L
.73767 .38206 L
.75773 .38217 L
.76781 .38222 L
.77883 .38226 L
.78893 .38228 L
.79846 .3823 L
.80373 .38231 L
.80944 .38232 L
.81459 .38233 L
.81941 .38233 L
.82398 .38233 L
.82655 .38234 L
.82889 .38234 L
.83145 .38234 L
.83289 .38234 L
.83358 .38234 L
.83423 .38234 L
.83552 .38234 L
.83669 .38234 L
.83795 .38234 L
.83865 .38234 L
.8393 .38234 L
.84053 .38234 L
.84183 .38234 L
.84307 .38234 L
.84419 .38234 L
Mistroke
.84695 .38234 L
.84955 .38234 L
.85473 .38233 L
.86035 .38233 L
.86979 .38232 L
.88018 .38231 L
.90121 .38228 L
.94148 .3822 L
.97619 .38212 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.06244 .23858 L
.08255 .36429 L
.10458 .48507 L
.11448 .53056 L
.11992 .5522 L
.12507 .56982 L
.12986 .58316 L
.13238 .58873 L
.13376 .59129 L
.13506 .59335 L
.13623 .5949 L
.13731 .59605 L
.1385 .59699 L
.13979 .59759 L
.14086 .59773 L
.14202 .59749 L
.14313 .59685 L
.14415 .59588 L
.14544 .59411 L
.1468 .5915 L
.14796 .58862 L
.14923 .58471 L
.15207 .57278 L
.15472 .55704 L
.15723 .5373 L
.15952 .51478 L
.16467 .44856 L
.16925 .38037 L
.17166 .34773 L
.17423 .31966 L
.17646 .30186 L
.17774 .29444 L
.17893 .28912 L
.18002 .28552 L
.18102 .28318 L
.18212 .28153 L
.18328 .28074 L
.18452 .2808 L
.18521 .28119 L
.18585 .28177 L
.18703 .28328 L
.18828 .28546 L
.19045 .29035 L
.19283 .29699 L
.20302 .33296 L
.22139 .40173 L
.22616 .41759 L
.23137 .43301 L
.23595 .44434 L
Mistroke
.23847 .44935 L
.24084 .45306 L
.24227 .45475 L
.24307 .45549 L
.24381 .45602 L
.24512 .45659 L
.24578 .45668 L
.2465 .45662 L
.24781 .45606 L
.24855 .45546 L
.24922 .45474 L
.25052 .4528 L
.25175 .45032 L
.25424 .44338 L
.25654 .43497 L
.26173 .41191 L
.27074 .37241 L
.27546 .35547 L
.28043 .34118 L
.28309 .33501 L
.28599 .32939 L
.28865 .32518 L
.29107 .3221 L
.29357 .31959 L
.29486 .31855 L
.29624 .3176 L
.29753 .31687 L
.29872 .31633 L
.29985 .31591 L
.30105 .31558 L
.30226 .31534 L
.30295 .31525 L
.30359 .3152 L
.30475 .31516 L
.306 .3152 L
.3071 .31531 L
.30814 .31546 L
.30928 .31569 L
.31051 .316 L
.31309 .31682 L
.3158 .31791 L
.32066 .32025 L
.33899 .32995 L
.34389 .33202 L
.34852 .33362 L
.35108 .33434 L
.35385 .33499 L
.35616 .33543 L
.3587 .3358 L
.35986 .33594 L
Mistroke
.3611 .33606 L
.36217 .33615 L
.36334 .33623 L
.36466 .33629 L
.36591 .33633 L
.36712 .33635 L
.36825 .33635 L
.36941 .33634 L
.37049 .33632 L
.37147 .33628 L
.37252 .33624 L
.37489 .33611 L
.37706 .33595 L
.38693 .33499 L
.3975 .3339 L
.40263 .33348 L
.40515 .33331 L
.40748 .33318 L
.40955 .33308 L
.41183 .33299 L
.41413 .33292 L
.41539 .3329 L
.41657 .33288 L
.41772 .33287 L
.41879 .33286 L
.41997 .33286 L
.42122 .33286 L
.42254 .33287 L
.42379 .33288 L
.4249 .3329 L
.42611 .33292 L
.42833 .33298 L
.43066 .33305 L
.43486 .33321 L
.45456 .3342 L
.46473 .33469 L
.47438 .33507 L
.48304 .33534 L
.49247 .33556 L
.51193 .3359 L
.53283 .33626 L
.57355 .33711 L
.61275 .3378 L
.63278 .33808 L
.6544 .33832 L
.67356 .3385 L
.68442 .33859 L
.69454 .33866 L
.70501 .33871 L
.71453 .33876 L
Mistroke
.72472 .33879 L
.73001 .33881 L
.73562 .33882 L
.74035 .33883 L
.74286 .33883 L
.74557 .33884 L
.74804 .33884 L
.75031 .33884 L
.75259 .33884 L
.75476 .33884 L
.75606 .33884 L
.75725 .33884 L
.75791 .33884 L
.75862 .33884 L
.75991 .33885 L
.76112 .33884 L
.7624 .33884 L
.76349 .33884 L
.76469 .33884 L
.7661 .33884 L
.7674 .33884 L
.7703 .33884 L
.77299 .33884 L
.77554 .33884 L
.78518 .33882 L
.79006 .33881 L
.79544 .3388 L
.81385 .33874 L
.83319 .33867 L
.85404 .33857 L
.89517 .33832 L
.93478 .33806 L
.97288 .33779 L
.97619 .33777 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.06244 .23832 L
.08255 .36404 L
.10458 .48501 L
.11448 .53072 L
.11992 .55256 L
.12507 .57046 L
.12986 .58415 L
.13238 .58999 L
.13506 .59494 L
.13731 .598 L
.13859 .59923 L
.13979 .60003 L
.14089 .60043 L
.14189 .6005 L
.14305 .60021 L
.14415 .59954 L
.1454 .59829 L
.1461 .59734 L
.14674 .5963 L
.1479 .594 L
.14918 .59082 L
.1514 .58348 L
.15374 .57293 L
.15629 .55772 L
.15902 .53663 L
.16396 .48564 L
.16859 .42706 L
.17113 .3952 L
.17351 .36857 L
.1757 .34842 L
.17771 .33414 L
.17877 .32819 L
.17994 .32292 L
.18111 .31882 L
.18234 .31568 L
.18303 .31442 L
.18368 .31352 L
.18489 .31251 L
.1862 .31232 L
.18694 .31257 L
.18761 .313 L
.18875 .31412 L
.19 .31585 L
.19252 .32063 L
.19824 .33571 L
.20358 .35267 L
.22371 .42067 L
.22868 .43593 L
.23411 .45071 L
Mistroke
.2366 .45657 L
.23924 .46199 L
.24172 .46613 L
.2428 .4676 L
.24399 .46893 L
.24517 .46994 L
.2464 .47063 L
.24705 .47082 L
.24775 .47089 L
.24901 .47062 L
.25027 .46981 L
.25147 .4685 L
.25255 .46684 L
.25372 .46452 L
.25594 .45862 L
.2583 .45048 L
.26253 .43254 L
.27193 .39044 L
.27686 .37188 L
.28204 .35634 L
.2866 .3461 L
.28919 .34165 L
.29159 .33831 L
.29377 .33591 L
.29582 .33414 L
.29696 .33335 L
.29819 .33265 L
.29929 .33214 L
.30033 .33176 L
.30157 .33143 L
.3027 .33123 L
.30392 .33113 L
.3046 .33112 L
.30524 .33114 L
.30629 .33123 L
.30746 .3314 L
.30868 .33167 L
.30982 .332 L
.31244 .33297 L
.31484 .3341 L
.32025 .3373 L
.3413 .3523 L
.35044 .3577 L
.35546 .36006 L
.3602 .36187 L
.36582 .36351 L
.36847 .36411 L
.37092 .36457 L
.3757 .36525 L
.37822 .3655 L
Mistroke
.3809 .36571 L
.38342 .36586 L
.38582 .36596 L
.38797 .36603 L
.39032 .36608 L
.39286 .36612 L
.39557 .36616 L
.40045 .36622 L
.40282 .36625 L
.40539 .3663 L
.40782 .36636 L
.41005 .36643 L
.41428 .3666 L
.41875 .36683 L
.42824 .36752 L
.4384 .36849 L
.45674 .37046 L
.47657 .37233 L
.49812 .37378 L
.51884 .37478 L
.53799 .37558 L
.57727 .37707 L
.61505 .37819 L
.63603 .37866 L
.65527 .37903 L
.69398 .37959 L
.71291 .37979 L
.73362 .37996 L
.75325 .38008 L
.7742 .38017 L
.78445 .3802 L
.79556 .38023 L
.80066 .38024 L
.80605 .38024 L
.8111 .38025 L
.81572 .38026 L
.82057 .38026 L
.82516 .38026 L
.82768 .38026 L
.83002 .38026 L
.83136 .38026 L
.83258 .38026 L
.83326 .38026 L
.83399 .38026 L
.83531 .38026 L
.83646 .38026 L
.83753 .38026 L
.8387 .38026 L
.83996 .38026 L
.84127 .38026 L
Mistroke
.84252 .38026 L
.84486 .38026 L
.84704 .38026 L
.84906 .38026 L
.85363 .38026 L
.85828 .38026 L
.86329 .38025 L
.87234 .38024 L
.89296 .38021 L
.93418 .38013 L
.97387 .38004 L
.97619 .38004 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.06244 .23836 L
.08255 .36407 L
.10458 .48502 L
.11448 .53069 L
.11992 .5525 L
.12507 .57035 L
.12986 .584 L
.13238 .58979 L
.13506 .59469 L
.13614 .59628 L
.13731 .5977 L
.13859 .59889 L
.13979 .59965 L
.14096 .60002 L
.14207 .60002 L
.14306 .59969 L
.14415 .59898 L
.1448 .59836 L
.14548 .59755 L
.1467 .59565 L
.14802 .59294 L
.14946 .58908 L
.15205 .57963 L
.15447 .56745 L
.15683 .55199 L
.15898 .53452 L
.16382 .48331 L
.16911 .41476 L
.172 .37875 L
.17472 .35061 L
.17702 .3325 L
.17832 .32473 L
.17951 .31907 L
.18074 .31457 L
.18209 .31108 L
.18276 .30984 L
.18349 .30886 L
.1848 .30791 L
.18608 .30788 L
.18727 .30854 L
.18856 .3099 L
.18922 .31081 L
.18994 .31196 L
.1948 .3229 L
.20388 .35128 L
.21473 .38891 L
.22464 .42193 L
.22942 .43631 L
.23462 .45006 L
Mistroke
.237 .45545 L
.23953 .46036 L
.24192 .46404 L
.24296 .46529 L
.24409 .4664 L
.2454 .46729 L
.24612 .46758 L
.24679 .46772 L
.24798 .46762 L
.24926 .46699 L
.24999 .46637 L
.25077 .46548 L
.25219 .46323 L
.25358 .46025 L
.25485 .45682 L
.25977 .43857 L
.26498 .41466 L
.27438 .37438 L
.27966 .35697 L
.28449 .34487 L
.28875 .33711 L
.29117 .33382 L
.29341 .3314 L
.29579 .32946 L
.29795 .32821 L
.29914 .32771 L
.30044 .32731 L
.30166 .32706 L
.30279 .32693 L
.30404 .3269 L
.30524 .32696 L
.30631 .3271 L
.30747 .32733 L
.30874 .32765 L
.31009 .32809 L
.3125 .32908 L
.31682 .33138 L
.32159 .33447 L
.33236 .34234 L
.34224 .34921 L
.35165 .35451 L
.35638 .35659 L
.36156 .3584 L
.36678 .35976 L
.3697 .36034 L
.37236 .36076 L
.37484 .36108 L
.37753 .36136 L
.38007 .36155 L
.38241 .36169 L
Mistroke
.38485 .36179 L
.38707 .36186 L
.3883 .36189 L
.38965 .36192 L
.39209 .36196 L
.39684 .36201 L
.40115 .36206 L
.40382 .36211 L
.40633 .36216 L
.40898 .36223 L
.41185 .36233 L
.41703 .36258 L
.42178 .36288 L
.43153 .36368 L
.44062 .36459 L
.46129 .36679 L
.47994 .36844 L
.50022 .36972 L
.52147 .37071 L
.5416 .37154 L
.5824 .37307 L
.62169 .37418 L
.65946 .37494 L
.67882 .37524 L
.69968 .3755 L
.71974 .3757 L
.74084 .37586 L
.7606 .37597 L
.77897 .37604 L
.7895 .37607 L
.79944 .37609 L
.80837 .3761 L
.8134 .37611 L
.81803 .37611 L
.82271 .37612 L
.82534 .37612 L
.82774 .37612 L
.82997 .37612 L
.83114 .37612 L
.83239 .37612 L
.8336 .37612 L
.83469 .37612 L
.83578 .37612 L
.83681 .37612 L
.83801 .37612 L
.83933 .37612 L
.83999 .37612 L
.84071 .37612 L
.84199 .37612 L
.84327 .37612 L
Mistroke
.84447 .37612 L
.84674 .37612 L
.84941 .37612 L
.85188 .37612 L
.85746 .37612 L
.86712 .37611 L
.87617 .3761 L
.8968 .37607 L
.93556 .37599 L
.97619 .37589 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.06244 .23838 L
.08255 .36409 L
.10458 .48503 L
.11448 .53068 L
.11992 .55248 L
.12507 .57031 L
.12986 .58393 L
.13238 .58971 L
.13506 .59459 L
.13614 .59616 L
.13731 .59757 L
.13859 .59875 L
.13979 .5995 L
.14096 .59985 L
.14207 .59983 L
.14306 .59949 L
.14415 .59875 L
.1448 .59812 L
.14548 .59729 L
.1467 .59536 L
.14802 .59261 L
.14946 .58871 L
.15205 .57915 L
.15447 .56684 L
.15683 .55121 L
.15898 .53357 L
.16382 .48183 L
.16911 .4127 L
.172 .37653 L
.17472 .34838 L
.17702 .33037 L
.17832 .32268 L
.17951 .3171 L
.18074 .31269 L
.18144 .31076 L
.18209 .3093 L
.1834 .30727 L
.18413 .30662 L
.1848 .30631 L
.18599 .30633 L
.18725 .30708 L
.18832 .30821 L
.18951 .30992 L
.19215 .31513 L
.19461 .32131 L
.20388 .35047 L
.21453 .38762 L
.22464 .42148 L
.23435 .44905 L
Mistroke
.23701 .45511 L
.23984 .46054 L
.24122 .46272 L
.24251 .46444 L
.24367 .46569 L
.24493 .46669 L
.24609 .46724 L
.24717 .46741 L
.24836 .46716 L
.24963 .46637 L
.25027 .46574 L
.25096 .46488 L
.25223 .46283 L
.25345 .46022 L
.25459 .45727 L
.2589 .44203 L
.26347 .42167 L
.27286 .38042 L
.27779 .36301 L
.28298 .34875 L
.28754 .33956 L
.29012 .33565 L
.29253 .33277 L
.29474 .33071 L
.29676 .3293 L
.29787 .32869 L
.29908 .32816 L
.30022 .32778 L
.30127 .32753 L
.30253 .32733 L
.30372 .32726 L
.30479 .32727 L
.30596 .32737 L
.30722 .32757 L
.30786 .32771 L
.30857 .32789 L
.31099 .32867 L
.31324 .32963 L
.31567 .33086 L
.32007 .3335 L
.32993 .34041 L
.34072 .34788 L
.34573 .3509 L
.35109 .35368 L
.35572 .35568 L
.36074 .35741 L
.3637 .35822 L
.36642 .35885 L
.36898 .35933 L
.37179 .35976 L
Mistroke
.37431 .36007 L
.37666 .36029 L
.37915 .36047 L
.38056 .36054 L
.38183 .3606 L
.38305 .36065 L
.38437 .36069 L
.38577 .36072 L
.38708 .36074 L
.38831 .36076 L
.38961 .36077 L
.39073 .36078 L
.39195 .36078 L
.39269 .36078 L
.39339 .36079 L
.3947 .36079 L
.39544 .36079 L
.39612 .36079 L
.39686 .36079 L
.39766 .36079 L
.39896 .36079 L
.40019 .36079 L
.40089 .3608 L
.40153 .3608 L
.40298 .36081 L
.40415 .36082 L
.40541 .36084 L
.40766 .36087 L
.41034 .36094 L
.41277 .36101 L
.41807 .36124 L
.42308 .36153 L
.43281 .3623 L
.44311 .3633 L
.46156 .36516 L
.48138 .36679 L
.49947 .36785 L
.51893 .36871 L
.53983 .36953 L
.57961 .37097 L
.61788 .37203 L
.6376 .37245 L
.65859 .37283 L
.67862 .37312 L
.70025 .37338 L
.72117 .37357 L
.74039 .37371 L
.75926 .3738 L
.76997 .37384 L
.77995 .37387 L
Mistroke
.79043 .3739 L
.79559 .37391 L
.80035 .37392 L
.80459 .37392 L
.80926 .37392 L
.81395 .37393 L
.81652 .37393 L
.81893 .37393 L
.82017 .37393 L
.8215 .37393 L
.82275 .37393 L
.82389 .37393 L
.82458 .37393 L
.82522 .37393 L
.82593 .37393 L
.82667 .37393 L
.82793 .37393 L
.82864 .37393 L
.8293 .37393 L
.83058 .37393 L
.83179 .37393 L
.83406 .37393 L
.8365 .37393 L
.83916 .37393 L
.84383 .37393 L
.84878 .37392 L
.85769 .37391 L
.86705 .3739 L
.87715 .37389 L
.89542 .37385 L
.93655 .37375 L
.97616 .37364 L
.97619 .37364 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.06244 .23855 L
.08255 .36427 L
.10458 .48509 L
.11448 .5306 L
.11992 .55227 L
.12507 .56993 L
.12986 .58332 L
.13238 .58893 L
.13376 .59152 L
.13506 .5936 L
.13623 .59518 L
.13731 .59636 L
.1385 .59734 L
.13979 .59798 L
.14086 .59816 L
.14202 .59797 L
.14313 .59739 L
.14415 .59648 L
.14544 .59478 L
.1468 .59227 L
.14796 .5895 L
.14923 .58572 L
.15207 .57418 L
.15472 .55896 L
.15723 .53993 L
.15952 .51827 L
.16467 .45488 L
.16933 .38843 L
.1737 .33526 L
.17589 .31621 L
.17712 .30798 L
.17825 .30193 L
.17942 .29707 L
.1807 .29324 L
.18135 .29183 L
.18204 .29069 L
.18328 .28948 L
.18456 .28924 L
.18529 .28949 L
.18595 .28995 L
.18718 .29129 L
.18848 .29333 L
.19072 .29807 L
.19319 .30463 L
.20237 .33567 L
.22313 .41282 L
.2331 .44431 L
.23802 .45671 L
.24041 .46166 L
Mistroke
.24257 .46537 L
.24379 .46707 L
.2451 .46858 L
.24583 .46924 L
.24649 .46973 L
.2478 .47037 L
.24912 .47053 L
.24987 .47038 L
.25057 .47008 L
.25131 .46958 L
.25198 .46897 L
.25349 .467 L
.25477 .46472 L
.25595 .46211 L
.25862 .45468 L
.26347 .43753 L
.27247 .40358 L
.28217 .37428 L
.28772 .3623 L
.29015 .35815 L
.29281 .35433 L
.29516 .35153 L
.29767 .3491 L
.30032 .34712 L
.30279 .34576 L
.30402 .34524 L
.30538 .34478 L
.30607 .34459 L
.3068 .34442 L
.30744 .34429 L
.30813 .34418 L
.30945 .34404 L
.31071 .34398 L
.31192 .344 L
.31305 .34406 L
.31437 .3442 L
.31561 .34438 L
.31844 .34498 L
.3212 .34574 L
.32417 .34671 L
.3338 .35033 L
.33889 .35219 L
.34434 .35389 L
.34713 .35462 L
.34976 .3552 L
.35233 .35566 L
.3547 .356 L
.35695 .35623 L
.35808 .35632 L
.35933 .35639 L
Mistroke
.36058 .35644 L
.36128 .35646 L
.36192 .35647 L
.36317 .35648 L
.36435 .35646 L
.36504 .35644 L
.36568 .35642 L
.36688 .35636 L
.36818 .35628 L
.36958 .35618 L
.37444 .35565 L
.38017 .3548 L
.38544 .35388 L
.39531 .35209 L
.40588 .3504 L
.411 .34975 L
.41586 .34924 L
.42021 .34888 L
.42495 .34858 L
.4295 .34837 L
.43209 .34828 L
.43452 .34821 L
.43708 .34816 L
.43942 .34812 L
.44199 .3481 L
.44328 .34809 L
.44469 .34808 L
.44592 .34807 L
.44709 .34807 L
.44813 .34806 L
.44926 .34806 L
.4505 .34806 L
.4518 .34806 L
.45292 .34806 L
.45415 .34806 L
.45529 .34806 L
.45634 .34806 L
.45755 .34806 L
.45869 .34806 L
.45975 .34806 L
.46073 .34805 L
.4618 .34805 L
.46294 .34805 L
.46419 .34805 L
.46556 .34805 L
.46699 .34804 L
.46832 .34804 L
.47071 .34802 L
.47326 .34801 L
.4791 .34796 L
Mistroke
.48441 .34789 L
.5046 .34754 L
.51467 .34736 L
.52535 .34719 L
.53447 .34708 L
.54451 .34699 L
.55406 .34693 L
.56434 .34688 L
.58292 .34681 L
.62413 .34665 L
.66382 .34646 L
.702 .34624 L
.74264 .34592 L
.78175 .34555 L
.82332 .34508 L
.86338 .34459 L
.90192 .34409 L
.94291 .34354 L
.97619 .3431 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.06244 .23858 L
.08255 .36431 L
.10458 .48509 L
.11448 .53058 L
.11992 .55222 L
.12507 .56984 L
.12986 .58318 L
.13238 .58875 L
.13376 .59131 L
.13506 .59336 L
.13623 .59492 L
.13731 .59607 L
.1385 .59701 L
.13979 .59761 L
.14086 .59775 L
.14202 .59751 L
.14313 .59688 L
.14415 .59591 L
.14544 .59414 L
.1468 .59154 L
.14796 .58867 L
.14923 .58478 L
.15207 .57291 L
.15472 .55727 L
.15723 .5377 L
.15952 .51542 L
.16467 .45018 L
.16933 .38208 L
.17161 .35168 L
.1737 .32826 L
.17589 .3093 L
.17704 .30168 L
.17825 .29531 L
.1795 .29039 L
.18065 .28713 L
.18192 .28486 L
.18264 .28411 L
.18328 .28372 L
.18455 .2837 L
.18573 .28444 L
.18702 .28596 L
.18767 .28698 L
.18838 .28826 L
.19319 .30046 L
.20237 .33282 L
.22313 .41274 L
.2331 .44555 L
.23802 .45876 L
.24257 .46843 L
Mistroke
.2451 .47237 L
.24652 .47403 L
.2478 .47515 L
.24853 .47561 L
.24921 .47592 L
.24995 .47611 L
.25073 .47615 L
.25205 .4758 L
.25279 .47536 L
.25349 .4748 L
.25479 .47335 L
.25601 .47149 L
.25831 .46685 L
.26347 .45237 L
.27226 .42355 L
.28172 .39642 L
.28715 .3844 L
.29211 .37582 L
.29686 .36967 L
.29924 .36728 L
.30185 .36515 L
.30445 .36349 L
.30682 .36235 L
.30813 .36185 L
.30955 .36141 L
.31089 .36108 L
.31212 .36086 L
.31326 .3607 L
.31433 .3606 L
.3155 .36054 L
.31676 .36053 L
.31807 .36056 L
.31932 .36064 L
.32044 .36074 L
.32166 .36088 L
.32417 .36126 L
.32695 .36178 L
.33258 .36302 L
.3375 .36413 L
.34268 .36514 L
.34501 .36551 L
.34749 .36583 L
.34892 .36598 L
.35022 .36609 L
.35153 .36618 L
.35276 .36624 L
.35388 .36628 L
.35507 .3663 L
.35608 .3663 L
.35719 .36628 L
Mistroke
.35839 .36624 L
.35968 .36618 L
.36089 .3661 L
.36201 .36601 L
.36466 .36572 L
.36712 .36538 L
.3727 .36437 L
.38285 .36194 L
.40166 .35703 L
.41156 .35491 L
.422 .3532 L
.42733 .35252 L
.43317 .35192 L
.44343 .35109 L
.46361 .3499 L
.50405 .34756 L
.54298 .34564 L
.56423 .34489 L
.58436 .34428 L
.62271 .34327 L
.66351 .34234 L
.7028 .34152 L
.74057 .34076 L
.78079 .33995 L
.8195 .33916 L
.86066 .33831 L
.9003 .33749 L
.93843 .3367 L
.97619 .33595 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.06244 .23836 L
.08255 .36407 L
.10458 .48502 L
.11448 .53069 L
.11992 .5525 L
.12507 .57034 L
.12986 .58397 L
.13238 .58975 L
.13506 .59464 L
.13614 .59622 L
.13731 .59763 L
.13859 .59881 L
.13979 .59955 L
.14096 .59991 L
.14207 .59989 L
.14306 .59955 L
.14415 .59881 L
.1448 .59817 L
.14548 .59734 L
.1467 .59541 L
.14802 .59265 L
.14946 .58874 L
.15205 .57914 L
.15447 .56676 L
.15683 .55104 L
.15898 .53326 L
.16382 .48099 L
.16911 .41081 L
.172 .3739 L
.17472 .34506 L
.17702 .32653 L
.17832 .3186 L
.17951 .31283 L
.18074 .30827 L
.18144 .30626 L
.18209 .30475 L
.1834 .30265 L
.18413 .30199 L
.1848 .30167 L
.18599 .30171 L
.18725 .30251 L
.18832 .30374 L
.18951 .30558 L
.19215 .31122 L
.19461 .31796 L
.20388 .35031 L
.22464 .4317 L
.23505 .46816 L
.24018 .48376 L
Mistroke
.24493 .49631 L
.24958 .50633 L
.25161 .50984 L
.2538 .51295 L
.25506 .51438 L
.25621 .51547 L
.25732 .51628 L
.25848 .51691 L
.25971 .5173 L
.26086 .51742 L
.26212 .51729 L
.26282 .5171 L
.26347 .51686 L
.26465 .51624 L
.26576 .51548 L
.26829 .51313 L
.27075 .51016 L
.27341 .50637 L
.28259 .49092 L
.29252 .47457 L
.29777 .4673 L
.30336 .46088 L
.30882 .45594 L
.31377 .45251 L
.31875 .44993 L
.32344 .44818 L
.32601 .44746 L
.32872 .44684 L
.33358 .44603 L
.33628 .44571 L
.33881 .44546 L
.34456 .44502 L
.34955 .44465 L
.35499 .44414 L
.36013 .44348 L
.36488 .44267 L
.37387 .44058 L
.38343 .43765 L
.42115 .42453 L
.44047 .41965 L
.46132 .41585 L
.50243 .41004 L
.54202 .40544 L
.5801 .40214 L
.62063 .39942 L
.65964 .39735 L
.7011 .39562 L
.74105 .39426 L
.77949 .39316 L
.82037 .39213 L
Mistroke
.85975 .39124 L
.8976 .39044 L
.93791 .38964 L
.97619 .38892 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.06244 .23809 L
.08255 .36384 L
.10458 .48499 L
.11448 .53087 L
.11992 .55285 L
.12507 .57094 L
.12986 .58489 L
.13238 .5909 L
.13506 .59608 L
.13731 .59936 L
.13859 .60075 L
.13979 .6017 L
.14089 .60226 L
.14189 .60249 L
.14305 .6024 L
.14415 .60195 L
.1454 .60097 L
.1461 .60019 L
.14674 .59931 L
.14793 .5973 L
.14918 .59456 L
.15135 .58819 L
.15374 .57856 L
.15629 .56483 L
.15902 .54573 L
.16396 .49927 L
.16859 .44481 L
.17351 .3877 L
.17553 .36828 L
.17771 .35129 L
.17896 .34351 L
.1801 .33761 L
.18119 .33304 L
.18234 .3292 L
.18357 .32621 L
.18471 .32432 L
.18541 .32355 L
.18607 .32307 L
.1873 .32275 L
.1886 .32316 L
.1898 .32412 L
.19112 .32572 L
.19252 .32795 L
.19524 .33357 L
.19779 .33997 L
.20358 .35709 L
.22371 .42351 L
.22868 .4387 L
.23411 .45354 L
Mistroke
.2366 .45949 L
.23924 .46506 L
.24172 .46941 L
.24399 .47247 L
.24517 .47364 L
.2464 .47452 L
.24764 .475 L
.24835 .47508 L
.24901 .47501 L
.2502 .47454 L
.25128 .47367 L
.25254 .47212 L
.25372 .47008 L
.25592 .46485 L
.25794 .45841 L
.26253 .43966 L
.27154 .39849 L
.27626 .37964 L
.28123 .36344 L
.28389 .3564 L
.28679 .34996 L
.28945 .34515 L
.29187 .34165 L
.29437 .33882 L
.29566 .33766 L
.29704 .33661 L
.29833 .33582 L
.29952 .33523 L
.30065 .3348 L
.30185 .33447 L
.30306 .33426 L
.30375 .33419 L
.30439 .33415 L
.30555 .33417 L
.3068 .33429 L
.3079 .33448 L
.30894 .33473 L
.31131 .3355 L
.31386 .33663 L
.31619 .33788 L
.32146 .34129 L
.33979 .35525 L
.34892 .36135 L
.35869 .36632 L
.3643 .36839 L
.3694 .3698 L
.37186 .37035 L
.37453 .37084 L
.37938 .37152 L
.38173 .37177 L
Mistroke
.38426 .37199 L
.38883 .37228 L
.39162 .37241 L
.39426 .37252 L
.39923 .37269 L
.40929 .37309 L
.41498 .37341 L
.42027 .37378 L
.43084 .37476 L
.4408 .37589 L
.45942 .37814 L
.47781 .38006 L
.49799 .3816 L
.51794 .38272 L
.53901 .38372 L
.57945 .38541 L
.61838 .38664 L
.63964 .38714 L
.65976 .38754 L
.69811 .38812 L
.7179 .38834 L
.73891 .38851 L
.7584 .38864 L
.77669 .38873 L
.78653 .38876 L
.79688 .3888 L
.80658 .38882 L
.81539 .38884 L
.82495 .38886 L
.82984 .38886 L
.83515 .38887 L
.84007 .38887 L
.8446 .38888 L
.84894 .38888 L
.85352 .38888 L
.85605 .38888 L
.85846 .38888 L
.86062 .38888 L
.86184 .38888 L
.86297 .38888 L
.86361 .38888 L
.8643 .38888 L
.86555 .38888 L
.86676 .38888 L
.86788 .38888 L
.8691 .38888 L
.86978 .38888 L
.87043 .38888 L
.87172 .38888 L
.87311 .38888 L
Mistroke
.87547 .38888 L
.87804 .38888 L
.8827 .38888 L
.89143 .38888 L
.90086 .38887 L
.91126 .38886 L
.93228 .38884 L
.97256 .38879 L
.97619 .38878 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.06244 .23861 L
.08255 .36433 L
.10458 .48509 L
.11448 .53055 L
.11992 .55218 L
.12507 .56977 L
.12986 .58307 L
.13256 .58897 L
.13506 .5932 L
.13607 .59455 L
.13716 .59573 L
.13835 .5967 L
.13947 .59727 L
.14073 .59749 L
.14192 .59726 L
.14299 .59667 L
.14415 .59556 L
.1448 .59473 L
.14548 .59367 L
.1467 .59129 L
.14802 .58798 L
.14946 .58336 L
.15205 .57221 L
.15447 .55793 L
.15683 .53983 L
.15898 .51936 L
.16382 .45934 L
.16898 .3829 L
.1717 .34609 L
.1732 .32901 L
.17459 .31542 L
.17591 .30492 L
.17711 .29715 L
.17845 .29049 L
.1792 .28761 L
.17989 .28541 L
.18103 .28275 L
.18228 .28103 L
.1835 .2804 L
.1848 .28069 L
.18603 .28176 L
.18673 .28267 L
.18739 .28368 L
.19013 .28945 L
.19504 .30401 L
.20614 .3455 L
.22629 .42113 L
.23127 .43691 L
.2367 .45163 L
Mistroke
.23919 .45723 L
.24183 .46219 L
.24311 .46416 L
.24432 .46572 L
.24541 .46684 L
.24658 .46774 L
.24774 .46828 L
.24882 .46843 L
.25001 .46819 L
.25128 .46742 L
.25192 .46683 L
.25262 .46602 L
.25388 .46412 L
.25624 .45912 L
.25848 .45288 L
.26086 .44508 L
.26512 .42951 L
.27451 .39593 L
.27945 .38116 L
.28463 .36842 L
.28919 .35963 L
.2916 .35586 L
.29418 .35246 L
.29655 .34986 L
.29871 .34792 L
.30089 .34633 L
.30292 .34516 L
.30524 .34416 L
.30647 .34376 L
.30779 .34342 L
.30845 .34329 L
.30917 .34317 L
.31048 .34301 L
.31175 .34293 L
.31293 .34291 L
.31402 .34294 L
.31505 .34301 L
.31618 .34312 L
.3174 .34328 L
.31987 .34373 L
.32214 .34424 L
.33292 .34738 L
.33818 .3489 L
.34296 .35007 L
.34521 .35052 L
.34765 .35093 L
.34996 .35123 L
.35209 .35144 L
.35326 .35152 L
.35435 .35158 L
Mistroke
.35554 .35162 L
.35683 .35164 L
.35748 .35164 L
.35818 .35164 L
.35946 .35161 L
.3607 .35156 L
.36186 .35149 L
.36316 .35139 L
.36456 .35126 L
.36711 .35097 L
.37187 .35022 L
.38255 .34796 L
.40211 .34353 L
.40747 .34254 L
.41321 .34164 L
.42357 .34044 L
.42866 .34002 L
.43419 .33967 L
.43941 .33942 L
.44424 .33923 L
.46308 .33868 L
.50236 .33731 L
.52207 .33663 L
.54014 .33614 L
.5595 .33577 L
.58036 .33545 L
.62 .33492 L
.65813 .33444 L
.69871 .33395 L
.73778 .33345 L
.77929 .33286 L
.8193 .33224 L
.85778 .33161 L
.89872 .33092 L
.93814 .33025 L
.97605 .32962 L
.97619 .32962 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.06244 .23861 L
.08255 .36433 L
.10458 .4851 L
.11448 .53055 L
.11992 .55217 L
.12507 .56976 L
.12986 .58305 L
.13256 .58894 L
.13506 .59316 L
.13607 .5945 L
.13716 .59568 L
.13835 .59664 L
.13947 .5972 L
.14073 .59741 L
.14192 .59718 L
.14299 .59657 L
.14415 .59545 L
.1448 .59461 L
.14548 .59354 L
.1467 .59114 L
.14802 .58781 L
.14946 .58317 L
.15205 .57195 L
.15447 .55761 L
.15683 .53942 L
.15898 .51886 L
.16382 .45858 L
.16898 .38181 L
.1717 .34483 L
.1732 .32768 L
.17459 .31403 L
.17591 .30349 L
.17711 .2957 L
.17845 .28904 L
.1792 .28615 L
.17989 .28396 L
.18103 .28132 L
.18228 .27963 L
.1835 .27904 L
.1848 .27938 L
.18603 .2805 L
.18673 .28143 L
.18739 .28248 L
.19013 .28838 L
.19504 .30323 L
.20614 .34563 L
.22629 .42353 L
.23127 .44007 L
.2367 .45586 L
Mistroke
.23919 .46209 L
.24183 .46788 L
.24431 .47235 L
.24658 .47549 L
.24775 .47669 L
.24899 .47762 L
.25023 .47816 L
.25094 .47829 L
.25159 .47828 L
.25279 .47796 L
.25387 .47729 L
.25512 .47609 L
.25631 .47453 L
.2585 .47063 L
.26053 .46605 L
.26512 .45337 L
.27489 .42383 L
.28002 .40985 L
.28541 .39728 L
.29016 .38824 L
.29534 .38054 L
.30006 .37536 L
.30444 .37195 L
.30681 .3706 L
.30937 .36948 L
.31055 .36907 L
.3118 .36871 L
.31287 .36845 L
.31403 .36823 L
.31515 .36806 L
.31617 .36794 L
.3172 .36785 L
.31817 .3678 L
.3193 .36777 L
.32035 .36777 L
.3215 .3678 L
.32273 .36787 L
.32393 .36795 L
.32503 .36806 L
.32751 .36834 L
.332 .36899 L
.33695 .36974 L
.33967 .37013 L
.34224 .37044 L
.3447 .37069 L
.34599 .37079 L
.34737 .37088 L
.34852 .37094 L
.34979 .37098 L
.35095 .371 L
Mistroke
.35203 .37101 L
.3532 .37099 L
.35432 .37096 L
.35532 .37092 L
.35642 .37085 L
.3576 .37077 L
.35887 .37065 L
.36114 .37039 L
.36383 .37 L
.36673 .36948 L
.372 .36831 L
.38183 .36556 L
.40139 .35964 L
.41175 .35702 L
.42286 .35482 L
.43355 .35326 L
.44329 .35217 L
.46236 .35049 L
.50223 .34725 L
.54058 .34461 L
.56037 .34358 L
.58138 .34265 L
.61915 .34118 L
.65937 .33986 L
.69808 .33874 L
.73924 .33763 L
.77888 .33661 L
.81701 .33564 L
.85759 .33462 L
.89666 .33365 L
.93818 .33264 L
.97619 .33174 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.06244 .2386 L
.08255 .36432 L
.10458 .48508 L
.11448 .53055 L
.11992 .55218 L
.12507 .56978 L
.12986 .58309 L
.13256 .589 L
.13506 .59324 L
.13607 .59459 L
.13716 .59578 L
.13835 .59675 L
.13947 .59732 L
.14073 .59755 L
.14192 .59733 L
.14299 .59674 L
.14415 .59564 L
.1448 .59482 L
.14548 .59376 L
.1467 .59139 L
.14802 .58809 L
.14946 .5835 L
.15205 .57236 L
.15447 .55812 L
.15683 .54004 L
.15898 .51958 L
.16382 .45952 L
.16898 .38289 L
.1717 .34597 L
.1732 .32885 L
.17459 .31523 L
.17591 .3047 L
.17711 .29692 L
.17845 .29026 L
.1792 .28736 L
.17989 .28516 L
.18103 .2825 L
.18228 .28078 L
.1835 .28015 L
.1848 .28045 L
.18603 .28152 L
.18673 .28243 L
.18739 .28345 L
.19013 .28922 L
.19504 .30378 L
.20614 .34501 L
.22629 .41933 L
.23127 .43458 L
.2367 .4485 L
Mistroke
.23919 .45361 L
.24055 .45599 L
.24183 .45791 L
.24303 .45942 L
.24432 .46067 L
.2455 .46144 L
.24658 .46181 L
.24766 .46183 L
.24881 .46143 L
.2499 .46063 L
.25089 .45952 L
.25205 .45773 L
.25331 .4552 L
.2556 .44909 L
.26055 .43099 L
.26512 .41185 L
.27413 .37704 L
.27885 .36235 L
.28382 .34997 L
.28648 .34464 L
.28938 .33976 L
.29204 .33611 L
.29446 .33342 L
.29696 .33123 L
.29825 .33032 L
.29963 .32949 L
.30092 .32885 L
.30211 .32837 L
.30322 .328 L
.30444 .32769 L
.3057 .32746 L
.30689 .32733 L
.30805 .32728 L
.30913 .32729 L
.31028 .32735 L
.31156 .32749 L
.31221 .32759 L
.3129 .32771 L
.31416 .32796 L
.31889 .32932 L
.32324 .33095 L
.33393 .33545 L
.33915 .33745 L
.34389 .33898 L
.34615 .3396 L
.34859 .34017 L
.3507 .34058 L
.35303 .34095 L
.35549 .34124 L
.35684 .34135 L
Mistroke
.35811 .34144 L
.35929 .34149 L
.36036 .34152 L
.36161 .34154 L
.36279 .34153 L
.3641 .3415 L
.36528 .34146 L
.36664 .34138 L
.36793 .34129 L
.37021 .34109 L
.37269 .34081 L
.38348 .33916 L
.39293 .33752 L
.40305 .33598 L
.40886 .33529 L
.41415 .33481 L
.4167 .33462 L
.41947 .33445 L
.42207 .33433 L
.42451 .33423 L
.42679 .33416 L
.42924 .33411 L
.43057 .33409 L
.43197 .33407 L
.43316 .33406 L
.43446 .33405 L
.43518 .33405 L
.43585 .33405 L
.43711 .33405 L
.43782 .33405 L
.43847 .33405 L
.43918 .33405 L
.43994 .33406 L
.44119 .33406 L
.44237 .33407 L
.44503 .3341 L
.45412 .33422 L
.45891 .33428 L
.46402 .33434 L
.46685 .33436 L
.46942 .33438 L
.47066 .33439 L
.472 .3344 L
.47326 .3344 L
.47443 .3344 L
.47563 .33441 L
.47694 .33441 L
.47822 .33441 L
.47893 .33441 L
.47959 .33441 L
Mistroke
.48075 .33441 L
.48202 .3344 L
.48321 .3344 L
.48432 .3344 L
.4886 .33438 L
.49332 .33435 L
.50286 .33427 L
.5128 .33419 L
.51771 .33416 L
.52226 .33413 L
.52499 .33412 L
.52747 .33411 L
.53022 .3341 L
.53173 .3341 L
.53316 .3341 L
.53437 .3341 L
.53565 .3341 L
.53675 .3341 L
.53795 .3341 L
.53924 .3341 L
.53997 .3341 L
.54063 .3341 L
.54192 .3341 L
.54313 .3341 L
.5455 .3341 L
.54772 .33411 L
.55278 .33413 L
.56303 .33417 L
.58145 .33425 L
.59992 .33433 L
.61039 .33436 L
.62013 .33439 L
.63062 .33441 L
.64016 .33443 L
.64505 .33443 L
.65036 .33444 L
.65327 .33444 L
.65596 .33444 L
.65853 .33444 L
.65983 .33444 L
.66125 .33444 L
.66257 .33444 L
.66378 .33445 L
.66494 .33445 L
.66618 .33445 L
.6674 .33445 L
.66854 .33445 L
.66957 .33445 L
.67069 .33445 L
.67191 .33444 L
Mistroke
.67325 .33444 L
.67597 .33444 L
.67848 .33444 L
.68082 .33444 L
.68545 .33444 L
.68966 .33443 L
.69913 .33441 L
.70906 .33439 L
.71824 .33436 L
.73901 .33427 L
.75771 .33417 L
.77832 .33403 L
.81856 .3337 L
.85729 .33332 L
.89847 .33288 L
.93814 .33243 L
.97619 .33199 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.06244 .23853 L
.08255 .36424 L
.10458 .48506 L
.11448 .53059 L
.11992 .55226 L
.12507 .56993 L
.12986 .58332 L
.13238 .58894 L
.13376 .59153 L
.13506 .59361 L
.13623 .59519 L
.13731 .59637 L
.1385 .59734 L
.13979 .59798 L
.14086 .59816 L
.14202 .59796 L
.14313 .59738 L
.14415 .59646 L
.14544 .59475 L
.1468 .59222 L
.14796 .58943 L
.14923 .58562 L
.15207 .57399 L
.15472 .55861 L
.15723 .53933 L
.15952 .51733 L
.16467 .45259 L
.16933 .38426 L
.1737 .32944 L
.17589 .30985 L
.17712 .30141 L
.17825 .29524 L
.17942 .2903 L
.1807 .28645 L
.18135 .28505 L
.18204 .28393 L
.18328 .2828 L
.18456 .28268 L
.18529 .28302 L
.18595 .28358 L
.18718 .28511 L
.18848 .28739 L
.19072 .29261 L
.19319 .2998 L
.20237 .33375 L
.22313 .41837 L
.2331 .45401 L
.24257 .48127 L
.2478 .4922 L
Mistroke
.24923 .49451 L
.25075 .49659 L
.25207 .49804 L
.25276 .49868 L
.25349 .49924 L
.25416 .49965 L
.2549 .5 L
.25619 .50033 L
.2575 .5003 L
.25873 .49995 L
.25992 .49931 L
.26102 .49849 L
.26347 .4959 L
.26576 .4927 L
.26829 .48851 L
.27341 .4787 L
.28259 .45999 L
.28788 .4501 L
.29343 .44106 L
.29858 .43415 L
.30336 .429 L
.30785 .42522 L
.31263 .4222 L
.31536 .42088 L
.31793 .41987 L
.32023 .41915 L
.32275 .41852 L
.32529 .41803 L
.32797 .41765 L
.33045 .41739 L
.33277 .41722 L
.33551 .41708 L
.338 .41698 L
.34067 .4169 L
.34362 .4168 L
.34593 .4167 L
.34842 .41657 L
.35105 .41638 L
.35352 .41616 L
.3583 .41556 L
.36268 .41481 L
.3675 .41375 L
.37279 .41234 L
.38343 .40885 L
.40466 .40109 L
.42396 .39518 L
.44402 .39084 L
.46297 .38781 L
.50141 .38264 L
.54229 .37806 L
Mistroke
.58167 .37479 L
.61952 .3723 L
.65983 .37013 L
.69862 .36843 L
.73986 .36689 L
.77959 .36559 L
.81781 .36446 L
.85847 .36333 L
.89762 .3623 L
.93922 .36126 L
.97619 .36037 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.06244 .23847 L
.08255 .36418 L
.10458 .48504 L
.11448 .53062 L
.11992 .55235 L
.12507 .57008 L
.12986 .58356 L
.13238 .58924 L
.13506 .594 L
.13614 .59551 L
.13731 .59684 L
.13859 .59793 L
.13979 .59857 L
.14096 .59882 L
.14207 .59868 L
.14306 .59823 L
.14415 .59735 L
.1448 .59662 L
.14548 .59569 L
.1467 .59356 L
.14802 .59054 L
.14946 .58631 L
.15205 .57599 L
.15447 .56274 L
.15683 .5459 L
.15898 .52684 L
.16382 .47074 L
.16911 .39608 L
.172 .35776 L
.17472 .3287 L
.17702 .31068 L
.17832 .30324 L
.17951 .29798 L
.18074 .29399 L
.18144 .29232 L
.18209 .29112 L
.1834 .28965 L
.18413 .28933 L
.1848 .28932 L
.18599 .2899 L
.18725 .29124 L
.18832 .29291 L
.18951 .29522 L
.19461 .30934 L
.20388 .34402 L
.22464 .42772 L
.23462 .46285 L
.24409 .48978 L
.24931 .50067 L
Mistroke
.25074 .50301 L
.25227 .50513 L
.25358 .50666 L
.25501 .50795 L
.25569 .50844 L
.25641 .50885 L
.2577 .50935 L
.25891 .50952 L
.2596 .50949 L
.26024 .50938 L
.26144 .50899 L
.26253 .50841 L
.26379 .5075 L
.26498 .50643 L
.26959 .50066 L
.27466 .49228 L
.28493 .47345 L
.29392 .45878 L
.30336 .44723 L
.3082 .44293 L
.31348 .43937 L
.31829 .43702 L
.32275 .43547 L
.32547 .43477 L
.32804 .43425 L
.33038 .43387 L
.33285 .43355 L
.33554 .43328 L
.33802 .43308 L
.34362 .43272 L
.34848 .43239 L
.35308 .43198 L
.35839 .43132 L
.36323 .4305 L
.37201 .42844 L
.38156 .42547 L
.40092 .41837 L
.42231 .41127 L
.44254 .40643 L
.46154 .40311 L
.5002 .39763 L
.54131 .3928 L
.5809 .38935 L
.61897 .38676 L
.6595 .38455 L
.69852 .38285 L
.73998 .38135 L
.77993 .38013 L
.81836 .37908 L
.85925 .37806 L
Mistroke
.89862 .37714 L
.93648 .37629 L
.97619 .37545 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.06244 .23817 L
.08255 .3639 L
.10458 .485 L
.11448 .53082 L
.11992 .55275 L
.12507 .57077 L
.12986 .58463 L
.13238 .59058 L
.13506 .59568 L
.13731 .59888 L
.13859 .60021 L
.13979 .60111 L
.14089 .60161 L
.14189 .60178 L
.14305 .60162 L
.14415 .60109 L
.1454 .60001 L
.1461 .59917 L
.14674 .59824 L
.1479 .59615 L
.14918 .59322 L
.1514 .58641 L
.15374 .57655 L
.15629 .56228 L
.15902 .54247 L
.16396 .4944 L
.16859 .43843 L
.17351 .38055 L
.17553 .36118 L
.17771 .34444 L
.17896 .33687 L
.1801 .33118 L
.18119 .32683 L
.18234 .32323 L
.18357 .32051 L
.18471 .31887 L
.18541 .31826 L
.18607 .31793 L
.1873 .31789 L
.1886 .3186 L
.1898 .31984 L
.19112 .32176 L
.19252 .32434 L
.19779 .33785 L
.20358 .35698 L
.22371 .43289 L
.23368 .46825 L
.24315 .49696 L
.24838 .50976 L
Mistroke
.25113 .51538 L
.25407 .52032 L
.25547 .52224 L
.25679 .52378 L
.25807 .52502 L
.25925 .52592 L
.26037 .52655 L
.26155 .527 L
.26274 .52721 L
.26405 .52717 L
.26536 .52686 L
.26657 .52635 L
.2672 .526 L
.26789 .52555 L
.2693 .52445 L
.27187 .52186 L
.27428 .51887 L
.28359 .50447 L
.2938 .48842 L
.29936 .48102 L
.30452 .47527 L
.30959 .47069 L
.31419 .4674 L
.31929 .46458 L
.32213 .46336 L
.32474 .46242 L
.32932 .46114 L
.33173 .46063 L
.33428 .46018 L
.33856 .45961 L
.34326 .45914 L
.34805 .45875 L
.35326 .4583 L
.35819 .45777 L
.36275 .45714 L
.36805 .45619 L
.37368 .45492 L
.38365 .45205 L
.42137 .43902 L
.4407 .43399 L
.46154 .43009 L
.50265 .42425 L
.54224 .41964 L
.58032 .41633 L
.62085 .41365 L
.65986 .41162 L
.70133 .40994 L
.74128 .40866 L
.77971 .40764 L
.8206 .4067 L
Mistroke
.85997 .4059 L
.89782 .4052 L
.93813 .4045 L
.97619 .40387 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.06244 .23834 L
.08255 .36405 L
.10458 .48501 L
.11448 .5307 L
.11992 .55253 L
.12507 .5704 L
.12986 .58407 L
.13238 .58988 L
.13506 .59481 L
.13731 .59783 L
.13859 .59905 L
.13979 .59982 L
.14089 .60019 L
.14189 .60024 L
.14305 .59992 L
.14415 .59922 L
.1454 .59792 L
.1461 .59695 L
.14674 .59588 L
.1479 .59353 L
.14918 .59028 L
.1514 .58279 L
.15374 .57202 L
.15629 .5565 L
.15902 .53495 L
.16396 .4827 L
.16859 .42268 L
.17113 .39017 L
.17351 .36319 L
.1757 .34295 L
.17771 .32873 L
.1788 .32275 L
.17994 .31768 L
.18109 .31377 L
.18234 .3107 L
.18303 .30951 L
.18368 .30868 L
.18489 .30782 L
.1862 .30778 L
.18694 .30811 L
.18761 .30863 L
.18875 .30988 L
.19 .31174 L
.19252 .3168 L
.19824 .33244 L
.20358 .34985 L
.22371 .41846 L
.22868 .43359 L
.23411 .44806 L
Mistroke
.2366 .4537 L
.23924 .4588 L
.24052 .46089 L
.24173 .46258 L
.2429 .46392 L
.24399 .4649 L
.24507 .46558 L
.24625 .46595 L
.2474 .4659 L
.24864 .46536 L
.24978 .46435 L
.25087 .46293 L
.25184 .46124 L
.2529 .45896 L
.25533 .452 L
.25791 .44233 L
.26253 .42137 L
.27193 .37847 L
.27686 .36022 L
.28204 .34527 L
.2866 .33565 L
.28919 .33156 L
.29159 .32857 L
.29381 .32643 L
.29582 .32498 L
.29693 .32435 L
.29814 .32381 L
.29928 .32343 L
.30033 .32318 L
.30159 .32299 L
.30278 .32293 L
.30386 .32296 L
.30502 .32309 L
.30629 .32332 L
.30763 .32367 L
.31005 .32453 L
.31437 .32669 L
.31913 .32975 L
.33979 .34533 L
.3492 .35127 L
.35433 .35387 L
.35911 .35584 L
.3643 .35752 L
.36728 .35828 L
.36998 .35885 L
.3748 .35964 L
.37745 .35996 L
.37996 .3602 L
.38218 .36037 L
.38458 .36052 L
Mistroke
.3872 .36064 L
.38966 .36074 L
.39995 .36103 L
.40489 .36118 L
.40958 .36137 L
.4138 .3616 L
.41839 .3619 L
.42872 .3628 L
.43808 .36381 L
.45906 .36625 L
.47994 .36828 L
.49914 .36962 L
.53772 .37151 L
.57722 .37314 L
.61521 .37435 L
.63637 .37486 L
.65566 .37525 L
.69459 .37586 L
.71369 .37608 L
.73445 .37626 L
.75424 .3764 L
.76436 .37645 L
.77525 .3765 L
.78542 .37654 L
.79474 .37657 L
.80358 .37659 L
.81302 .37661 L
.82284 .37663 L
.83196 .37664 L
.83755 .37664 L
.84029 .37664 L
.84281 .37664 L
.84507 .37665 L
.84754 .37665 L
.85003 .37665 L
.8514 .37665 L
.85267 .37665 L
.85392 .37665 L
.85462 .37665 L
.85526 .37665 L
.85649 .37665 L
.85765 .37665 L
.85832 .37665 L
.85902 .37665 L
.86027 .37665 L
.86096 .37665 L
.86161 .37665 L
.86309 .37665 L
.86559 .37665 L
.86786 .37665 L
Mistroke
.87297 .37664 L
.87754 .37664 L
.8825 .37664 L
.89151 .37663 L
.91134 .37661 L
.93237 .37658 L
.97019 .37652 L
.97619 .37651 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.06244 .23863 L
.08255 .36435 L
.10458 .48509 L
.11448 .53053 L
.11992 .55213 L
.12507 .56969 L
.12986 .58295 L
.13256 .58881 L
.13506 .593 L
.13607 .59433 L
.13716 .59549 L
.13835 .59642 L
.13947 .59696 L
.14073 .59714 L
.14192 .59687 L
.14299 .59623 L
.14415 .59507 L
.1448 .59421 L
.14548 .59311 L
.1467 .59066 L
.14802 .58725 L
.14946 .58252 L
.15205 .57108 L
.15447 .55646 L
.15683 .5379 L
.15898 .51689 L
.16382 .45519 L
.16898 .37669 L
.1717 .33914 L
.1732 .32184 L
.17459 .30816 L
.17591 .29765 L
.17711 .28995 L
.17845 .28342 L
.17915 .28077 L
.17989 .27852 L
.18111 .2759 L
.18224 .27453 L
.18347 .27406 L
.18417 .27421 L
.1848 .27458 L
.18599 .27581 L
.18711 .27751 L
.18965 .28301 L
.19478 .2988 L
.20398 .3345 L
.21465 .3784 L
.22478 .41755 L
.23449 .44972 L
Mistroke
.23998 .46429 L
.2426 .46995 L
.24507 .47433 L
.24733 .47737 L
.24861 .47862 L
.24978 .47943 L
.25077 .47985 L
.25185 .48002 L
.25299 .47986 L
.25404 .47937 L
.25529 .47841 L
.25646 .4771 L
.25866 .47369 L
.26103 .46885 L
.2636 .46259 L
.27296 .43646 L
.28303 .41063 L
.28879 .3989 L
.29408 .39041 L
.29913 .38424 L
.30191 .3816 L
.30444 .37963 L
.3067 .37818 L
.30915 .37692 L
.31174 .3759 L
.3129 .37553 L
.31418 .37519 L
.31647 .37473 L
.31772 .37455 L
.31889 .37442 L
.31998 .37433 L
.32098 .37428 L
.32214 .37424 L
.32323 .37423 L
.3244 .37424 L
.3257 .37428 L
.32635 .37431 L
.32706 .37435 L
.32833 .37443 L
.33306 .37482 L
.3386 .37532 L
.3413 .37552 L
.34248 .37559 L
.34376 .37565 L
.34499 .3757 L
.34613 .37573 L
.34722 .37575 L
.34837 .37575 L
.34959 .37573 L
.35072 .3757 L
Mistroke
.35197 .37565 L
.35331 .37557 L
.35465 .37546 L
.35611 .37532 L
.35878 .375 L
.36377 .37414 L
.36907 .37291 L
.37471 .37131 L
.38486 .36796 L
.40485 .36133 L
.41537 .35851 L
.42647 .35616 L
.43642 .35452 L
.44735 .35308 L
.46655 .35095 L
.507 .34681 L
.54592 .34357 L
.58731 .34106 L
.62717 .33909 L
.66552 .33749 L
.70632 .336 L
.74561 .3347 L
.78338 .33351 L
.8236 .33229 L
.86231 .33115 L
.90347 .32995 L
.94311 .32884 L
.97619 .32793 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.06244 .23844 L
.08255 .36414 L
.10458 .48503 L
.11448 .53064 L
.11992 .55239 L
.12507 .57016 L
.12986 .5837 L
.13238 .58941 L
.13506 .59422 L
.13614 .59575 L
.13731 .59711 L
.13859 .59824 L
.13979 .59892 L
.14096 .59921 L
.14207 .59911 L
.14306 .5987 L
.14415 .59787 L
.1448 .59719 L
.14548 .59629 L
.1467 .59423 L
.14802 .59132 L
.14946 .58721 L
.15205 .57716 L
.15447 .56424 L
.15683 .54782 L
.15898 .52924 L
.16382 .47453 L
.16911 .40164 L
.172 .36414 L
.17472 .33558 L
.17702 .31775 L
.17832 .31031 L
.17951 .30501 L
.18074 .30092 L
.18144 .29918 L
.18209 .2979 L
.1834 .29624 L
.18413 .2958 L
.1848 .29567 L
.18599 .29602 L
.18725 .29709 L
.18832 .29851 L
.18951 .30051 L
.19215 .30635 L
.19461 .31308 L
.20388 .34397 L
.21453 .3823 L
.22464 .41638 L
.22934 .43035 L
Mistroke
.23435 .44311 L
.23723 .4491 L
.23984 .45338 L
.2411 .45498 L
.24176 .45567 L
.24246 .4563 L
.24375 .45711 L
.24493 .45745 L
.24609 .45734 L
.24714 .45684 L
.24836 .45574 L
.24951 .45414 L
.25057 .45216 L
.25155 .44987 L
.25377 .44315 L
.25848 .42317 L
.26347 .3984 L
.27286 .35654 L
.27814 .339 L
.28298 .32706 L
.28724 .31958 L
.28965 .31647 L
.29189 .31425 L
.29312 .31329 L
.29427 .31253 L
.29532 .31196 L
.29643 .31148 L
.29764 .31108 L
.29875 .31083 L
.29995 .31067 L
.30127 .31063 L
.30257 .31071 L
.30377 .31089 L
.30509 .31119 L
.3065 .31161 L
.30886 .31254 L
.31146 .31385 L
.32076 .3201 L
.33166 .32859 L
.34166 .33574 L
.35107 .34103 L
.3558 .34307 L
.36098 .34483 L
.3662 .34614 L
.36912 .34669 L
.37178 .34709 L
.37426 .3474 L
.37695 .34765 L
.37949 .34784 L
.38183 .34797 L
Mistroke
.38427 .34808 L
.3865 .34815 L
.38907 .34821 L
.39151 .34826 L
.3959 .34834 L
.40057 .34843 L
.40326 .3485 L
.40569 .34858 L
.41044 .34878 L
.41598 .34909 L
.4212 .34948 L
.4413 .35153 L
.45977 .35362 L
.47861 .35537 L
.49928 .35674 L
.53973 .35865 L
.57865 .36023 L
.62003 .36151 L
.6599 .36238 L
.69825 .36297 L
.71804 .36319 L
.73905 .36337 L
.75854 .3635 L
.77682 .36359 L
.78666 .36363 L
.79702 .36366 L
.80672 .36369 L
.81553 .3637 L
.82508 .36372 L
.83033 .36372 L
.83529 .36373 L
.83988 .36373 L
.8441 .36373 L
.84631 .36373 L
.84875 .36373 L
.84997 .36373 L
.85128 .36373 L
.85252 .36373 L
.85366 .36373 L
.85495 .36373 L
.85617 .36373 L
.85726 .36373 L
.85845 .36373 L
.85974 .36373 L
.8611 .36373 L
.86354 .36373 L
.86791 .36373 L
.8727 .36373 L
.87788 .36373 L
.88343 .36372 L
Mistroke
.89344 .36371 L
.91473 .36368 L
.93487 .36365 L
.97327 .36358 L
.97619 .36357 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.06244 .23859 L
.08255 .3643 L
.10458 .48508 L
.11448 .53056 L
.11992 .55219 L
.12507 .5698 L
.12986 .58312 L
.13256 .58903 L
.13506 .59327 L
.13607 .59462 L
.13716 .59581 L
.13835 .59679 L
.13947 .59736 L
.14073 .59759 L
.14192 .59737 L
.14299 .59678 L
.14415 .59568 L
.1448 .59486 L
.14548 .5938 L
.1467 .59144 L
.14802 .58814 L
.14946 .58353 L
.15205 .5724 L
.15447 .55814 L
.15683 .54004 L
.15898 .51956 L
.16382 .45936 L
.16898 .3823 L
.1717 .34497 L
.1732 .32759 L
.17459 .31373 L
.17591 .30299 L
.17711 .29505 L
.17845 .28823 L
.1792 .28527 L
.17989 .28301 L
.18103 .28028 L
.18228 .27852 L
.1835 .27787 L
.1848 .27818 L
.18603 .27929 L
.18673 .28022 L
.18739 .28128 L
.19013 .28726 L
.19504 .30244 L
.20614 .34601 L
.22629 .42638 L
.23127 .44364 L
.2367 .46041 L
Mistroke
.24149 .47292 L
.24411 .47862 L
.24658 .48307 L
.24901 .48642 L
.25037 .4878 L
.25163 .48871 L
.25269 .4892 L
.25385 .48942 L
.25507 .48929 L
.2562 .48884 L
.25736 .48806 L
.25846 .48703 L
.26051 .48441 L
.26272 .48073 L
.26512 .47596 L
.28454 .43108 L
.28986 .42107 L
.29559 .41231 L
.301 .40598 L
.30595 .40171 L
.30825 .40017 L
.3107 .39882 L
.31282 .39786 L
.31511 .39702 L
.31781 .39626 L
.31905 .39599 L
.32036 .39575 L
.32154 .39558 L
.32284 .39542 L
.32402 .39531 L
.32512 .39522 L
.32637 .39516 L
.32708 .39513 L
.32773 .39511 L
.32893 .39509 L
.3302 .39508 L
.33134 .39509 L
.33241 .3951 L
.33358 .39513 L
.33484 .39516 L
.33745 .39524 L
.33889 .39528 L
.34024 .39532 L
.34151 .39535 L
.34217 .39536 L
.34288 .39537 L
.34412 .39538 L
.34527 .39538 L
.3464 .39537 L
.34762 .39535 L
Mistroke
.34877 .39532 L
.34982 .39528 L
.35105 .39522 L
.35239 .39513 L
.35483 .39493 L
.35745 .39463 L
.36025 .39422 L
.36529 .39325 L
.37099 .39183 L
.37635 .39024 L
.38638 .38682 L
.40477 .3804 L
.41521 .37729 L
.42495 .37489 L
.4449 .37125 L
.46597 .36842 L
.5049 .36382 L
.54628 .35981 L
.58615 .35697 L
.6245 .35475 L
.6653 .3528 L
.70459 .35121 L
.74236 .34986 L
.78258 .34855 L
.82129 .34736 L
.86245 .34616 L
.90209 .34504 L
.94022 .34399 L
.97619 .34305 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.06244 .23853 L
.08255 .36424 L
.10458 .48505 L
.11448 .53058 L
.11992 .55225 L
.12507 .56992 L
.12986 .58332 L
.13238 .58893 L
.13376 .59152 L
.13506 .5936 L
.13623 .59519 L
.13731 .59636 L
.1385 .59734 L
.13979 .59798 L
.14086 .59816 L
.14202 .59796 L
.14313 .59738 L
.14415 .59646 L
.14544 .59475 L
.1468 .59223 L
.14796 .58943 L
.14923 .58563 L
.15207 .574 L
.15472 .55862 L
.15723 .53934 L
.15952 .51733 L
.16467 .45248 L
.16933 .38388 L
.1737 .32872 L
.17589 .30899 L
.17712 .3005 L
.17825 .29429 L
.17942 .28933 L
.1807 .28546 L
.18135 .28407 L
.18204 .28295 L
.18328 .28184 L
.18456 .28175 L
.18529 .28212 L
.18595 .28269 L
.18718 .28428 L
.18848 .28661 L
.19072 .29195 L
.19319 .29928 L
.20237 .3338 L
.22313 .41941 L
.2331 .45548 L
.24257 .48336 L
.2478 .49488 L
Mistroke
.25075 .49974 L
.25216 .50155 L
.25349 .50293 L
.25471 .50391 L
.25603 .50463 L
.25722 .50498 L
.25832 .50505 L
.25952 .50485 L
.26083 .50432 L
.26149 .50394 L
.26219 .50344 L
.26347 .50234 L
.26604 .49942 L
.26877 .49547 L
.27367 .48698 L
.28475 .4659 L
.29444 .44995 L
.29953 .44332 L
.30488 .43774 L
.30975 .43383 L
.31232 .43217 L
.31506 .43068 L
.3176 .42954 L
.3199 .42868 L
.32439 .42741 L
.32674 .42692 L
.32891 .42657 L
.33129 .42626 L
.33381 .426 L
.33804 .42568 L
.34268 .42541 L
.34791 .42507 L
.35287 .42463 L
.35732 .42407 L
.36217 .42324 L
.36743 .42209 L
.37302 .42057 L
.38307 .41724 L
.40274 .40986 L
.42079 .40388 L
.44012 .39915 L
.46096 .39545 L
.50056 .3898 L
.53863 .38525 L
.57916 .38162 L
.61817 .37891 L
.65964 .37659 L
.69959 .37479 L
.73802 .37334 L
.77891 .37201 L
Mistroke
.81828 .37087 L
.85614 .36985 L
.89644 .36884 L
.93523 .36791 L
.97619 .36697 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.06244 .23809 L
.08255 .36383 L
.10458 .48498 L
.11448 .53086 L
.11992 .55285 L
.12507 .57094 L
.12986 .58489 L
.13238 .59089 L
.13506 .59608 L
.13731 .59937 L
.13859 .60075 L
.13979 .60171 L
.14089 .60227 L
.14189 .6025 L
.14305 .60242 L
.14415 .60197 L
.1454 .601 L
.1461 .60022 L
.14674 .59935 L
.14793 .59734 L
.14918 .59461 L
.15135 .58826 L
.15374 .57868 L
.15629 .565 L
.15902 .546 L
.16396 .49984 L
.16859 .44578 L
.17351 .38888 L
.17553 .36941 L
.17771 .35228 L
.17896 .34441 L
.1801 .33841 L
.18119 .33374 L
.18234 .3298 L
.18357 .32672 L
.18471 .32475 L
.18541 .32394 L
.18607 .32343 L
.1873 .32307 L
.1886 .32346 L
.1898 .32442 L
.19112 .32606 L
.19252 .32837 L
.19524 .33425 L
.19779 .34103 L
.20358 .3595 L
.22371 .43446 L
.23411 .47123 L
.24399 .50097 L
Mistroke
.24829 .51156 L
.25286 .52074 L
.25549 .52485 L
.25788 .5277 L
.25903 .52876 L
.26028 .52966 L
.26145 .53028 L
.26253 .53065 L
.2638 .53084 L
.265 .53078 L
.26607 .53054 L
.26724 .53008 L
.26852 .52937 L
.26987 .52838 L
.27229 .52607 L
.27662 .52062 L
.28139 .5134 L
.29219 .49631 L
.30207 .48334 L
.31152 .47455 L
.31627 .47139 L
.32145 .46877 L
.32669 .46687 L
.32962 .46607 L
.33227 .46548 L
.33476 .46502 L
.33745 .46462 L
.34232 .46406 L
.35262 .46314 L
.35765 .46262 L
.36224 .46201 L
.36708 .46119 L
.37227 .46009 L
.3833 .45703 L
.40397 .44976 L
.42311 .44334 L
.44167 .43854 L
.46141 .43482 L
.49912 .42938 L
.5393 .4246 L
.57795 .42116 L
.61906 .4184 L
.65865 .41634 L
.69673 .41479 L
.73725 .41349 L
.77627 .41247 L
.81773 .41155 L
.85768 .41078 L
.89612 .41011 L
.937 .40944 L
Mistroke
.97619 .40884 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.06244 .23825 L
.08255 .36397 L
.10458 .485 L
.11448 .53076 L
.11992 .55264 L
.12507 .57059 L
.12986 .58436 L
.13238 .59024 L
.13506 .59525 L
.13731 .59837 L
.13859 .59965 L
.13979 .60048 L
.14089 .60092 L
.14189 .60104 L
.14305 .6008 L
.14415 .60018 L
.1454 .599 L
.1461 .59809 L
.14674 .5971 L
.1479 .59488 L
.14918 .59179 L
.1514 .58465 L
.15374 .57433 L
.15629 .55944 L
.15902 .53874 L
.16396 .48847 L
.16859 .43026 L
.17113 .39829 L
.17351 .37136 L
.1757 .35078 L
.17771 .33603 L
.17994 .32427 L
.18111 .31989 L
.18234 .31649 L
.18356 .31421 L
.18486 .31283 L
.18609 .3124 L
.1872 .31265 L
.18852 .31362 L
.18925 .31445 L
.18994 .31538 L
.19252 .32005 L
.19508 .32612 L
.19789 .33394 L
.20358 .35193 L
.2141 .38788 L
.22371 .41977 L
.23301 .44654 L
.23556 .45264 L
Mistroke
.23827 .45829 L
.24062 .4623 L
.24185 .46402 L
.24315 .46551 L
.24387 .46617 L
.24466 .46675 L
.24538 .46713 L
.24605 .46736 L
.24737 .46742 L
.24811 .4672 L
.24878 .46685 L
.25003 .46573 L
.25074 .46482 L
.25139 .46381 L
.25267 .46131 L
.25387 .45835 L
.25622 .45087 L
.25881 .44049 L
.26405 .41581 L
.2739 .37151 L
.27886 .35435 L
.28169 .34637 L
.28427 .34028 L
.28891 .33189 L
.29146 .32859 L
.29387 .32624 L
.29495 .3254 L
.2961 .32465 L
.29709 .32412 L
.29815 .32366 L
.29929 .32328 L
.30036 .32304 L
.30163 .32287 L
.30279 .32283 L
.30396 .32289 L
.30506 .32303 L
.30628 .32328 L
.30758 .32364 L
.31024 .32467 L
.31268 .32589 L
.32185 .33214 L
.33259 .34084 L
.3426 .3485 L
.35173 .35423 L
.35642 .35658 L
.3615 .35865 L
.36707 .36041 L
.37234 .36161 L
.37482 .36205 L
.37746 .36244 L
Mistroke
.38219 .36298 L
.38471 .36319 L
.38711 .36336 L
.39161 .36362 L
.40174 .36409 L
.41049 .36457 L
.42005 .36531 L
.43037 .36639 L
.43973 .36753 L
.46071 .37021 L
.48159 .37239 L
.5008 .37384 L
.53937 .37591 L
.57887 .37765 L
.61687 .37892 L
.63639 .37941 L
.65731 .37986 L
.67714 .38021 L
.69869 .38052 L
.71765 .38074 L
.73856 .38093 L
.75835 .38107 L
.77936 .38118 L
.79872 .38125 L
.80961 .38128 L
.81958 .38131 L
.82874 .38133 L
.83852 .38134 L
.84925 .38135 L
.85923 .38136 L
.86456 .38137 L
.86948 .38137 L
.87488 .38137 L
.8776 .38137 L
.87913 .38137 L
.88059 .38137 L
.88184 .38137 L
.88321 .38137 L
.88446 .38137 L
.88561 .38137 L
.88632 .38137 L
.88698 .38137 L
.88822 .38137 L
.88892 .38137 L
.88956 .38137 L
.89026 .38137 L
.891 .38137 L
.89217 .38137 L
.89341 .38137 L
.89565 .38137 L
Mistroke
.89832 .38137 L
.90074 .38137 L
.90557 .38137 L
.91069 .38137 L
.91988 .38136 L
.94066 .38135 L
.97619 .38132 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.06244 .23867 L
.08255 .36438 L
.10458 .4851 L
.11448 .53051 L
.11992 .55208 L
.12507 .56961 L
.12986 .58282 L
.13256 .58865 L
.13385 .59095 L
.13506 .5928 L
.13616 .59421 L
.13716 .59525 L
.13827 .59611 L
.13947 .59667 L
.14062 .59682 L
.14187 .59652 L
.14305 .59577 L
.14415 .59462 L
.14544 .59267 L
.1468 .58986 L
.14796 .58678 L
.14923 .58261 L
.15207 .56998 L
.15472 .55333 L
.15723 .53246 L
.15952 .50861 L
.16467 .4386 L
.16925 .36736 L
.17166 .33397 L
.17423 .3059 L
.17646 .28859 L
.17774 .28158 L
.17893 .27668 L
.18002 .27349 L
.18102 .27151 L
.18212 .27027 L
.18328 .26988 L
.18452 .27035 L
.18521 .27097 L
.18585 .27174 L
.18703 .27362 L
.18828 .27615 L
.19283 .28888 L
.20302 .32745 L
.22139 .40122 L
.23083 .43379 L
.23603 .44867 L
.23859 .4549 L
.24096 .45987 L
Mistroke
.24337 .46394 L
.24441 .46538 L
.24554 .46667 L
.24679 .46774 L
.24796 .46839 L
.24861 .46859 L
.2493 .46868 L
.25053 .46846 L
.25158 .46791 L
.25269 .46693 L
.25375 .46562 L
.2547 .46412 L
.25705 .45927 L
.25928 .45339 L
.27753 .39442 L
.28254 .38138 L
.28792 .36999 L
.293 .36174 L
.29542 .35863 L
.29766 .35617 L
.30227 .3523 L
.30471 .35083 L
.30732 .34966 L
.30863 .3492 L
.31006 .3488 L
.3114 .3485 L
.31264 .3483 L
.31376 .34816 L
.31499 .34806 L
.31627 .34801 L
.31747 .34801 L
.31878 .34805 L
.31951 .34809 L
.32019 .34813 L
.32144 .34824 L
.32277 .34839 L
.32761 .3491 L
.33329 .35008 L
.33849 .35091 L
.34085 .35121 L
.34305 .35144 L
.34425 .35154 L
.34534 .35161 L
.34655 .35167 L
.34785 .35172 L
.34914 .35174 L
.35034 .35173 L
.35165 .35171 L
.35231 .35168 L
.35304 .35165 L
Mistroke
.35426 .35157 L
.35557 .35147 L
.35794 .35121 L
.36028 .35088 L
.36283 .35043 L
.36748 .34942 L
.37621 .34698 L
.39754 .34015 L
.40762 .33742 L
.41688 .33542 L
.42657 .33382 L
.43704 .33253 L
.45603 .33082 L
.49553 .32766 L
.53353 .32502 L
.55305 .324 L
.57397 .32309 L
.61535 .32155 L
.65522 .32028 L
.69357 .3192 L
.73437 .31811 L
.77365 .31708 L
.81142 .31609 L
.85165 .31502 L
.89036 .314 L
.93151 .31293 L
.97116 .31192 L
.97619 .3118 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.06244 .23865 L
.08255 .36436 L
.10458 .48508 L
.11448 .5305 L
.11992 .55209 L
.12507 .56964 L
.12986 .58287 L
.13256 .58872 L
.13385 .59103 L
.13506 .59289 L
.13616 .5943 L
.13716 .59535 L
.13827 .59622 L
.13947 .59679 L
.14062 .59696 L
.14187 .59668 L
.14305 .59594 L
.14415 .59481 L
.14544 .59289 L
.1468 .5901 L
.14796 .58705 L
.14923 .58291 L
.15207 .57036 L
.15472 .55379 L
.15723 .533 L
.15952 .50921 L
.16467 .43915 L
.16925 .36757 L
.17166 .33396 L
.17423 .30571 L
.17646 .28829 L
.17774 .28123 L
.17893 .2763 L
.18002 .27308 L
.18102 .27108 L
.18212 .26981 L
.18328 .2694 L
.18452 .26986 L
.18521 .27047 L
.18585 .27124 L
.18703 .27309 L
.18828 .27561 L
.19283 .28825 L
.20302 .32619 L
.22139 .3969 L
.23083 .42672 L
.23354 .43375 L
.23612 .43952 L
.23847 .44386 L
Mistroke
.23975 .4458 L
.24096 .44731 L
.24211 .44842 L
.24335 .44923 L
.24448 .44957 L
.24551 .44954 L
.24649 .44915 L
.24756 .44832 L
.24868 .44695 L
.24973 .44519 L
.25097 .44246 L
.25214 .43924 L
.25434 .43162 L
.25928 .40919 L
.26896 .36356 L
.27426 .34344 L
.27923 .32854 L
.28345 .31881 L
.28799 .31108 L
.29045 .30796 L
.29304 .30542 L
.29525 .30378 L
.29766 .30249 L
.29898 .30199 L
.3002 .30165 L
.30084 .30151 L
.30154 .3014 L
.30228 .30131 L
.30296 .30126 L
.30422 .30124 L
.30537 .30129 L
.30601 .30135 L
.3067 .30144 L
.30796 .30167 L
.30908 .30192 L
.31031 .30226 L
.31281 .3031 L
.31731 .30503 L
.32824 .31072 L
.33303 .31316 L
.33827 .31554 L
.34282 .31726 L
.34768 .3187 L
.35037 .31931 L
.35282 .31974 L
.35399 .31991 L
.35527 .32007 L
.35639 .32018 L
.3576 .32028 L
.35889 .32036 L
Mistroke
.3601 .32041 L
.36084 .32043 L
.36154 .32045 L
.36286 .32045 L
.36353 .32044 L
.36424 .32043 L
.36553 .32039 L
.36631 .32036 L
.36705 .32032 L
.36844 .32023 L
.37094 .32003 L
.37325 .31979 L
.37844 .31915 L
.38831 .31776 L
.39374 .31703 L
.39888 .31644 L
.40366 .31599 L
.40618 .3158 L
.40886 .31563 L
.4111 .31552 L
.41358 .31542 L
.41467 .31539 L
.41584 .31536 L
.41694 .31534 L
.41795 .31532 L
.41911 .31531 L
.42034 .31531 L
.42149 .3153 L
.42256 .31531 L
.42383 .31532 L
.42499 .31533 L
.42626 .31535 L
.42761 .31538 L
.43245 .31551 L
.43777 .31571 L
.45594 .31654 L
.46593 .31694 L
.4754 .31724 L
.48633 .31749 L
.4963 .31766 L
.53457 .31827 L
.57528 .31915 L
.61449 .31989 L
.63451 .3202 L
.65614 .32048 L
.67529 .32068 L
.69628 .32086 L
.71627 .32099 L
.72718 .32104 L
.73735 .32107 L
Mistroke
.74238 .32109 L
.74784 .3211 L
.753 .32111 L
.75546 .32111 L
.75776 .32111 L
.76 .32111 L
.76205 .32112 L
.76433 .32112 L
.76558 .32112 L
.76678 .32112 L
.76792 .32112 L
.76915 .32112 L
.7703 .32112 L
.77135 .32112 L
.77258 .32112 L
.77327 .32112 L
.77391 .32112 L
.77509 .32112 L
.77634 .32112 L
.77888 .32112 L
.78129 .32111 L
.78581 .32111 L
.79067 .3211 L
.79596 .32109 L
.80548 .32107 L
.81429 .32105 L
.83295 .32098 L
.85355 .32089 L
.89374 .32066 L
.93241 .3204 L
.97354 .3201 L
.97619 .32008 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.06244 .23869 L
.08255 .3644 L
.10458 .48509 L
.11448 .53048 L
.11992 .55204 L
.12507 .56955 L
.12986 .58272 L
.13256 .58853 L
.13385 .59081 L
.13506 .59265 L
.13616 .59404 L
.13716 .59506 L
.13827 .5959 L
.13947 .59644 L
.14062 .59656 L
.14187 .59624 L
.14305 .59544 L
.14415 .59425 L
.14544 .59226 L
.1468 .58938 L
.14796 .58624 L
.14923 .582 L
.15207 .56913 L
.15472 .55216 L
.15723 .53086 L
.15952 .5065 L
.16467 .4348 L
.16925 .36201 L
.17166 .32818 L
.17299 .31255 L
.17423 .30005 L
.17646 .28292 L
.17765 .27647 L
.17893 .27134 L
.18004 .26827 L
.1812 .26623 L
.18219 .26533 L
.18328 .26513 L
.1846 .26582 L
.18582 .26724 L
.18645 .26823 L
.18715 .26951 L
.18857 .2726 L
.19356 .28745 L
.20289 .32335 L
.21384 .36792 L
.22384 .40544 L
.22862 .42121 L
.23382 .43606 L
Mistroke
.2362 .44181 L
.23873 .44703 L
.23997 .44917 L
.24112 .45092 L
.24225 .45233 L
.24329 .45339 L
.2445 .45428 L
.24515 .45458 L
.24584 .45477 L
.24656 .45481 L
.24724 .45469 L
.24852 .45402 L
.24972 .45284 L
.25083 .45125 L
.25204 .44894 L
.25333 .44584 L
.256 .43751 L
.25849 .42789 L
.26418 .40343 L
.27404 .36458 L
.27899 .3492 L
.2844 .33596 L
.28905 .32744 L
.2916 .32379 L
.294 .32096 L
.29625 .31882 L
.29868 .31699 L
.30089 .31572 L
.30292 .31487 L
.30418 .31448 L
.30537 .31419 L
.30644 .314 L
.30761 .31386 L
.30888 .31378 L
.30952 .31377 L
.31022 .31378 L
.31147 .31384 L
.31264 .31395 L
.31375 .3141 L
.31492 .31429 L
.31701 .31472 L
.32172 .316 L
.3317 .31922 L
.33719 .3208 L
.33989 .32144 L
.34238 .32193 L
.34478 .32231 L
.34733 .32261 L
.34865 .32272 L
.34989 .32279 L
Mistroke
.3506 .32282 L
.35124 .32284 L
.35199 .32285 L
.3527 .32286 L
.35383 .32285 L
.35503 .32281 L
.35617 .32275 L
.35719 .32269 L
.35972 .32245 L
.36209 .32214 L
.36669 .32135 L
.37092 .32043 L
.38045 .31797 L
.39032 .31532 L
.40089 .31287 L
.40602 .31191 L
.41087 .31115 L
.41519 .31058 L
.41996 .31008 L
.42455 .30971 L
.42942 .3094 L
.43393 .30919 L
.43816 .30903 L
.44769 .30878 L
.45795 .30857 L
.49911 .30742 L
.50905 .30713 L
.51965 .30687 L
.52966 .30667 L
.53876 .30654 L
.54817 .30644 L
.55837 .30636 L
.56801 .30631 L
.57688 .30626 L
.61631 .30609 L
.65421 .30593 L
.69457 .30572 L
.73342 .30543 L
.77472 .30502 L
.8145 .30455 L
.85276 .30403 L
.89348 .30343 L
.93268 .30283 L
.97433 .3022 L
.97619 .30217 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.06244 .23825 L
.08255 .36397 L
.10458 .485 L
.11448 .53076 L
.11992 .55264 L
.12507 .57059 L
.12986 .58435 L
.13238 .59023 L
.13506 .59524 L
.13731 .59836 L
.13859 .59963 L
.13979 .60046 L
.14089 .6009 L
.14189 .60101 L
.14305 .60077 L
.14415 .60015 L
.1454 .59897 L
.1461 .59805 L
.14674 .59705 L
.1479 .59483 L
.14918 .59174 L
.1514 .58459 L
.15374 .57427 L
.15629 .55938 L
.15902 .5387 L
.16396 .48853 L
.16859 .43047 L
.17351 .37153 L
.17553 .35227 L
.17771 .33593 L
.17896 .32868 L
.1801 .32333 L
.18119 .31929 L
.18234 .31608 L
.18356 .31376 L
.18486 .31235 L
.18609 .31192 L
.1872 .31219 L
.18852 .3132 L
.18925 .31407 L
.18994 .31504 L
.19252 .31996 L
.19508 .3264 L
.19789 .33477 L
.20358 .35432 L
.22371 .4314 L
.23368 .46684 L
.24315 .49541 L
.24838 .50802 L
Mistroke
.25113 .5135 L
.25407 .51823 L
.25547 .52005 L
.25679 .52147 L
.25807 .52259 L
.25925 .52337 L
.26037 .52389 L
.26155 .5242 L
.26274 .52428 L
.26405 .52411 L
.26536 .52366 L
.26657 .52302 L
.26789 .52209 L
.2693 .52086 L
.27428 .51489 L
.28359 .50009 L
.29367 .48412 L
.29896 .47704 L
.30452 .47085 L
.30939 .46649 L
.31471 .46278 L
.31954 .46024 L
.32403 .45848 L
.32867 .45718 L
.33288 .45634 L
.33522 .45598 L
.33774 .45566 L
.34232 .45521 L
.34729 .4548 L
.35262 .45434 L
.35765 .4538 L
.36224 .45316 L
.36739 .45223 L
.37227 .45114 L
.3833 .44796 L
.42159 .43469 L
.44134 .42961 L
.46234 .42575 L
.50006 .42036 L
.54023 .41561 L
.57889 .4122 L
.61999 .40944 L
.65959 .40736 L
.69766 .40579 L
.73819 .40444 L
.7772 .40337 L
.81867 .40239 L
.85862 .40156 L
.89705 .40082 L
.93794 .40008 L
Mistroke
.97619 .39943 L
Mfstroke
.862 1 0 r
.02381 .01472 m
.06244 .23817 L
.08255 .36389 L
.10458 .48499 L
.11448 .53081 L
.11992 .55275 L
.12507 .57077 L
.12986 .58464 L
.13238 .59059 L
.13506 .5957 L
.13731 .59892 L
.13859 .60025 L
.13979 .60116 L
.14089 .60166 L
.14189 .60184 L
.14305 .60169 L
.14415 .60117 L
.1454 .60011 L
.1461 .59927 L
.14674 .59835 L
.1479 .59627 L
.14918 .59336 L
.1514 .58659 L
.15374 .57678 L
.15629 .56259 L
.15902 .54288 L
.16396 .49504 L
.16859 .43929 L
.17351 .38153 L
.17553 .36215 L
.17771 .34536 L
.17896 .33776 L
.1801 .33204 L
.18119 .32765 L
.18234 .32402 L
.18357 .32126 L
.18471 .3196 L
.18541 .31897 L
.18607 .31862 L
.1873 .31856 L
.1886 .31924 L
.1898 .32046 L
.19112 .32236 L
.19252 .32492 L
.19779 .33839 L
.20358 .35749 L
.22371 .43339 L
.23368 .46881 L
.24315 .49763 L
.24838 .51056 L
Mistroke
.25113 .51626 L
.25407 .52132 L
.25547 .52332 L
.25679 .52493 L
.25807 .52624 L
.25925 .52721 L
.26037 .52792 L
.26155 .52845 L
.26274 .52874 L
.26405 .52879 L
.26536 .52857 L
.26657 .52814 L
.2672 .52783 L
.26789 .52742 L
.2693 .52641 L
.27187 .52396 L
.27428 .52108 L
.28359 .50693 L
.2938 .49094 L
.29936 .48352 L
.30452 .47773 L
.30959 .47311 L
.31419 .46976 L
.31929 .46688 L
.32474 .46465 L
.32932 .46332 L
.3319 .46274 L
.33428 .46231 L
.33864 .46168 L
.34326 .46119 L
.35272 .46033 L
.35793 .45976 L
.36288 .45906 L
.37246 .45713 L
.3812 .45471 L
.4195 .44137 L
.43925 .43601 L
.46025 .43195 L
.49797 .42645 L
.53814 .42161 L
.57679 .41813 L
.6179 .41534 L
.65749 .41326 L
.69557 .4117 L
.7361 .41039 L
.77511 .40936 L
.81658 .40844 L
.85653 .40766 L
.89496 .40698 L
.93585 .40631 L
Mistroke
.97522 .40571 L
.97619 .40569 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.06244 .23833 L
.08255 .36404 L
.10458 .48501 L
.11448 .5307 L
.11992 .55253 L
.12507 .57041 L
.12986 .58408 L
.13238 .5899 L
.13506 .59483 L
.13731 .59785 L
.13859 .59907 L
.13979 .59984 L
.14089 .60022 L
.14189 .60027 L
.14305 .59995 L
.14415 .59925 L
.1454 .59795 L
.1461 .59698 L
.14674 .59591 L
.1479 .59356 L
.14918 .59031 L
.1514 .58282 L
.15374 .57204 L
.15629 .5565 L
.15902 .53491 L
.16396 .48253 L
.16859 .42218 L
.17113 .38935 L
.17351 .36198 L
.1757 .34135 L
.17771 .3268 L
.1788 .32067 L
.17994 .31547 L
.18109 .31144 L
.18234 .30828 L
.18303 .30706 L
.18368 .30621 L
.18489 .30534 L
.1862 .30532 L
.18694 .30569 L
.18761 .30625 L
.18875 .30759 L
.19 .30959 L
.19252 .31504 L
.19824 .33209 L
.20358 .35136 L
.22371 .42989 L
.23411 .46692 L
.24399 .49617 L
Mistroke
.24829 .50628 L
.25286 .51468 L
.25422 .51661 L
.25549 .51817 L
.25674 .51944 L
.25788 .52037 L
.25897 .52105 L
.26011 .52155 L
.26127 .52182 L
.26253 .52185 L
.26384 .52161 L
.26505 .52115 L
.26568 .52082 L
.26638 .52039 L
.26779 .51932 L
.27035 .51677 L
.27276 .51378 L
.28208 .49912 L
.29228 .48256 L
.29784 .47486 L
.30301 .46885 L
.30807 .46405 L
.31267 .46059 L
.31778 .45763 L
.32062 .45634 L
.32323 .45535 L
.32781 .454 L
.33021 .45346 L
.33276 .45299 L
.33704 .45239 L
.34175 .45191 L
.34653 .4515 L
.35175 .45105 L
.35634 .45055 L
.36123 .44987 L
.36691 .44884 L
.37216 .44762 L
.38214 .4447 L
.41986 .43142 L
.43918 .42629 L
.46003 .42231 L
.50113 .41635 L
.54073 .41164 L
.5788 .40825 L
.61933 .4055 L
.65834 .40341 L
.69981 .40168 L
.73976 .40035 L
.77819 .39929 L
.81908 .39832 L
Mistroke
.85845 .39748 L
.89631 .39675 L
.93661 .39601 L
.97541 .39534 L
.97619 .39532 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.06244 .23816 L
.08255 .3639 L
.10458 .48499 L
.11448 .53081 L
.11992 .55275 L
.12507 .57078 L
.12986 .58464 L
.13238 .59059 L
.13506 .5957 L
.13731 .59891 L
.13859 .60024 L
.13979 .60114 L
.14089 .60165 L
.14189 .60182 L
.14305 .60167 L
.14415 .60114 L
.1454 .60007 L
.1461 .59923 L
.14674 .5983 L
.1479 .59622 L
.14918 .5933 L
.1514 .5865 L
.15374 .57666 L
.15629 .56241 L
.15902 .54261 L
.16396 .4945 L
.16859 .4384 L
.17351 .38043 L
.17553 .36108 L
.17771 .34442 L
.17896 .3369 L
.1801 .33127 L
.18119 .32697 L
.18234 .32343 L
.18357 .32075 L
.18471 .31915 L
.18541 .31855 L
.18607 .31822 L
.1873 .31819 L
.1886 .31887 L
.1898 .32007 L
.19112 .32191 L
.19252 .32439 L
.19779 .33715 L
.20358 .35485 L
.22371 .42183 L
.22848 .4363 L
.23368 .4504 L
.23606 .45605 L
Mistroke
.2386 .46135 L
.24079 .4652 L
.24194 .4669 L
.24315 .46842 L
.24389 .46919 L
.24469 .46989 L
.24542 .4704 L
.24611 .47074 L
.24681 .47096 L
.24745 .47103 L
.24818 .47095 L
.24888 .47071 L
.25017 .46982 L
.25137 .46843 L
.25268 .46624 L
.25407 .46314 L
.25652 .45577 L
.25882 .44694 L
.26405 .42276 L
.2739 .37784 L
.27886 .36011 L
.28169 .35179 L
.28427 .3454 L
.28891 .33653 L
.29146 .33299 L
.29387 .33043 L
.29495 .32951 L
.2961 .32868 L
.29815 .32755 L
.29929 .32711 L
.30036 .3268 L
.30153 .32658 L
.30279 .32646 L
.304 .32647 L
.30469 .32653 L
.30534 .32661 L
.30665 .32685 L
.30738 .32703 L
.30806 .32723 L
.31044 .32812 L
.31294 .32935 L
.31822 .33267 L
.324 .33706 L
.33453 .34571 L
.34411 .35302 L
.34894 .35621 L
.35419 .3592 L
.35871 .36136 L
.3637 .3633 L
.36899 .36488 L
Mistroke
.37169 .36552 L
.37459 .3661 L
.3773 .36655 L
.37978 .36689 L
.38464 .36741 L
.38941 .36778 L
.3945 .36808 L
.40364 .36856 L
.41452 .36928 L
.42437 .37019 L
.46446 .37529 L
.48285 .37723 L
.50303 .37877 L
.52298 .37994 L
.54405 .38101 L
.5845 .38279 L
.62342 .38405 L
.64468 .38456 L
.66481 .38497 L
.70315 .38555 L
.72294 .38577 L
.74396 .38596 L
.76344 .38609 L
.78173 .38618 L
.80193 .38626 L
.82043 .38631 L
.83937 .38635 L
.8501 .38637 L
.86008 .38638 L
.87061 .38639 L
.87578 .38639 L
.88055 .38639 L
.8848 .38639 L
.88948 .3864 L
.89417 .3864 L
.89674 .3864 L
.89914 .3864 L
.9004 .3864 L
.90173 .3864 L
.90288 .3864 L
.90413 .3864 L
.9049 .3864 L
.9056 .3864 L
.90626 .3864 L
.90698 .3864 L
.90824 .3864 L
.90892 .3864 L
.90956 .3864 L
.91085 .3864 L
.91206 .3864 L
Mistroke
.91315 .3864 L
.91434 .3864 L
.91699 .3864 L
.91945 .3864 L
.92373 .3864 L
.92845 .3864 L
.93799 .38639 L
.95639 .38639 L
.97619 .38638 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.06244 .23863 L
.08255 .36433 L
.10458 .48507 L
.11448 .53052 L
.11992 .55212 L
.12507 .56969 L
.12986 .58294 L
.13256 .58881 L
.13506 .593 L
.13607 .59433 L
.13716 .59549 L
.13835 .59643 L
.13947 .59697 L
.14073 .59715 L
.14192 .59688 L
.14299 .59624 L
.14415 .59507 L
.1448 .59421 L
.14548 .59311 L
.1467 .59065 L
.14802 .58723 L
.14946 .58248 L
.15205 .571 L
.15447 .55629 L
.15683 .5376 L
.15898 .5164 L
.16382 .45388 L
.16898 .37387 L
.1717 .3355 L
.1732 .31782 L
.17459 .30385 L
.17591 .29313 L
.17711 .28529 L
.17845 .27865 L
.17915 .27596 L
.17989 .27367 L
.18111 .27103 L
.18224 .26966 L
.18347 .26922 L
.18417 .26939 L
.1848 .26979 L
.18599 .27108 L
.18711 .27287 L
.18965 .27861 L
.19478 .29509 L
.20398 .33242 L
.22478 .41916 L
.23519 .45519 L
.24031 .46968 L
Mistroke
.24281 .47571 L
.24507 .48046 L
.24713 .48414 L
.24936 .4873 L
.25059 .48863 L
.25172 .48958 L
.2528 .49022 L
.25394 .49061 L
.25509 .4907 L
.25632 .49045 L
.25749 .48988 L
.25855 .48911 L
.25979 .4879 L
.26115 .48626 L
.2636 .48252 L
.28303 .4409 L
.28835 .43061 L
.29408 .42127 L
.29903 .41478 L
.30444 .40931 L
.30695 .4073 L
.30962 .4055 L
.31444 .40303 L
.31728 .40199 L
.31996 .40123 L
.32236 .40071 L
.32496 .40029 L
.32723 .40003 L
.32972 .39982 L
.33097 .39974 L
.33232 .39967 L
.33475 .39957 L
.33911 .39943 L
.34151 .39935 L
.34376 .39925 L
.34626 .39911 L
.34903 .39889 L
.35138 .39865 L
.35391 .39833 L
.35968 .39734 L
.36497 .3961 L
.37477 .39307 L
.38508 .38918 L
.40503 .38144 L
.42316 .37577 L
.44275 .37141 L
.46369 .36793 L
.50364 .3622 L
.54207 .35764 L
.58296 .35397 L
Mistroke
.62233 .35115 L
.66019 .34889 L
.70049 .34688 L
.73929 .34521 L
.78053 .34363 L
.82026 .34222 L
.85847 .34095 L
.89914 .33965 L
.93829 .33845 L
.97619 .33733 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.06244 .23858 L
.08255 .36428 L
.10458 .48506 L
.11448 .53055 L
.11992 .55219 L
.12507 .56981 L
.12986 .58315 L
.13256 .58907 L
.13506 .59333 L
.13607 .59469 L
.13716 .59589 L
.13835 .59687 L
.13947 .59746 L
.14073 .5977 L
.14192 .5975 L
.14299 .59692 L
.14415 .59584 L
.1448 .59502 L
.14548 .59398 L
.1467 .59163 L
.14802 .58835 L
.14946 .58378 L
.15205 .57269 L
.15447 .55848 L
.15683 .54042 L
.15898 .51995 L
.16382 .45959 L
.16911 .37997 L
.172 .34018 L
.17342 .32378 L
.17472 .31095 L
.17702 .29353 L
.17823 .287 L
.17951 .28188 L
.18082 .2783 L
.18203 .2763 L
.18273 .27567 L
.18337 .2754 L
.1841 .2754 L
.1848 .27569 L
.1859 .27667 L
.18711 .2784 L
.18838 .28083 L
.18956 .2836 L
.19395 .29693 L
.20388 .33626 L
.22464 .42264 L
.23505 .45925 L
.24018 .47434 L
Mistroke
.24493 .48599 L
.24923 .494 L
.25046 .49577 L
.25163 .49719 L
.25266 .49824 L
.2538 .49914 L
.25498 .49981 L
.25622 .50019 L
.25737 .50025 L
.25845 .50006 L
.25972 .49953 L
.26087 .49879 L
.2622 .49763 L
.26347 .49628 L
.26807 .48961 L
.27315 .48025 L
.28342 .45979 L
.2924 .44413 L
.30185 .4319 L
.30668 .42742 L
.31197 .42374 L
.31429 .42249 L
.31677 .42137 L
.32123 .41983 L
.32394 .41916 L
.32687 .4186 L
.32963 .41821 L
.33218 .41794 L
.33447 .41775 L
.337 .41758 L
.3421 .41729 L
.34461 .41714 L
.34733 .41695 L
.34974 .41674 L
.35229 .41648 L
.35712 .41582 L
.36159 .41501 L
.37152 .41248 L
.3825 .40874 L
.40344 .4007 L
.42267 .39442 L
.44149 .38996 L
.46132 .38647 L
.4994 .38091 L
.53993 .37598 L
.57894 .37242 L
.6204 .36946 L
.66035 .36716 L
.69879 .36535 L
.73968 .36373 L
Mistroke
.77905 .36237 L
.8169 .36119 L
.85721 .36003 L
.896 .35897 L
.93724 .3579 L
.97619 .35694 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.06244 .23857 L
.08255 .36427 L
.10458 .48505 L
.11448 .53054 L
.11992 .55218 L
.12507 .56981 L
.12986 .58314 L
.13256 .58907 L
.13506 .59333 L
.13607 .59468 L
.13716 .59588 L
.13835 .59686 L
.13947 .59745 L
.14073 .59769 L
.14192 .59748 L
.14299 .5969 L
.14415 .59581 L
.1448 .59499 L
.14548 .59395 L
.1467 .59159 L
.14802 .5883 L
.14946 .5837 L
.15205 .57256 L
.15447 .55825 L
.15683 .54003 L
.15898 .51934 L
.16382 .45812 L
.16898 .37921 L
.1717 .34109 L
.1732 .32345 L
.17459 .30944 L
.17591 .29863 L
.17711 .29066 L
.17845 .28384 L
.1792 .28088 L
.17989 .27863 L
.18103 .2759 L
.18228 .27414 L
.1835 .27349 L
.1848 .27379 L
.18603 .27487 L
.18673 .2758 L
.18739 .27683 L
.19013 .28271 L
.19504 .29753 L
.20614 .33909 L
.21578 .37564 L
.22124 .39475 L
.22629 .41076 L
Mistroke
.23134 .4244 L
.2341 .43056 L
.2367 .43523 L
.23791 .43696 L
.23919 .43843 L
.23986 .43904 L
.2406 .43956 L
.24189 .44011 L
.24306 .44015 L
.24432 .43963 L
.2455 .43856 L
.24658 .43705 L
.24773 .43481 L
.24896 .43169 L
.25115 .42406 L
.25351 .41307 L
.25611 .39844 L
.26512 .34589 L
.27005 .32293 L
.27524 .30441 L
.27967 .29291 L
.28217 .28801 L
.2845 .2844 L
.28581 .28274 L
.28723 .28122 L
.28848 .2801 L
.2898 .27914 L
.29099 .27845 L
.2923 .27788 L
.29349 .27752 L
.2946 .27731 L
.29527 .27724 L
.296 .27721 L
.29732 .27726 L
.29861 .27745 L
.2998 .27773 L
.30108 .27813 L
.3025 .2787 L
.30537 .28017 L
.31028 .28346 L
.31545 .28763 L
.3247 .29572 L
.33477 .30402 L
.34031 .30792 L
.34555 .31105 L
.3505 .31348 L
.35587 .31554 L
.36076 .31693 L
.36526 .31787 L
.36951 .31849 L
Mistroke
.37192 .31875 L
.37418 .31895 L
.37655 .31911 L
.37873 .31922 L
.38124 .31933 L
.38362 .3194 L
.39322 .31963 L
.39598 .3197 L
.39858 .31979 L
.40344 .31999 L
.40805 .32026 L
.41228 .32057 L
.42183 .32148 L
.44227 .32402 L
.46134 .32637 L
.47968 .32814 L
.49933 .32954 L
.54071 .33182 L
.58058 .33373 L
.61893 .33516 L
.65973 .33628 L
.68 .33672 L
.69902 .33707 L
.73679 .3376 L
.75699 .33781 L
.7755 .33796 L
.79443 .33809 L
.81514 .33819 L
.83476 .33826 L
.84575 .33829 L
.85572 .33831 L
.86505 .33833 L
.87492 .33835 L
.88575 .33836 L
.89096 .33836 L
.89572 .33837 L
.90024 .33837 L
.90517 .33837 L
.90787 .33837 L
.91037 .33837 L
.91292 .33837 L
.91531 .33838 L
.91755 .33838 L
.91873 .33838 L
.91997 .33838 L
.92102 .33838 L
.92217 .33838 L
.92321 .33838 L
.92419 .33838 L
.92541 .33838 L
Mistroke
.92657 .33838 L
.92762 .33838 L
.92875 .33838 L
.92998 .33838 L
.93129 .33838 L
.93363 .33838 L
.93615 .33838 L
.93854 .33838 L
.94303 .33837 L
.94787 .33837 L
.95315 .33837 L
.97145 .33836 L
.97619 .33836 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.06244 .23862 L
.08255 .36432 L
.10458 .48507 L
.11448 .53051 L
.11992 .55212 L
.12507 .56969 L
.12986 .58296 L
.13256 .58883 L
.13506 .59303 L
.13607 .59436 L
.13716 .59553 L
.13835 .59647 L
.13947 .59701 L
.14073 .5972 L
.14192 .59694 L
.14299 .5963 L
.14415 .59514 L
.1448 .59428 L
.14548 .59319 L
.1467 .59073 L
.14802 .58733 L
.14946 .58259 L
.15205 .57112 L
.15447 .55641 L
.15683 .5377 L
.15898 .51646 L
.16382 .45369 L
.16898 .37339 L
.1717 .33509 L
.1732 .31754 L
.17459 .30373 L
.17591 .29317 L
.17711 .28546 L
.17845 .27894 L
.17915 .2763 L
.17989 .27407 L
.18111 .27148 L
.18224 .27014 L
.18347 .2697 L
.18417 .26986 L
.1848 .27024 L
.18599 .27148 L
.18711 .2732 L
.18965 .2787 L
.19478 .29438 L
.20398 .3292 L
.21465 .37077 L
.22478 .40624 L
.22948 .42021 L
Mistroke
.23449 .43241 L
.23737 .43773 L
.23873 .4397 L
.23998 .44113 L
.24124 .44219 L
.2419 .44257 L
.2426 .44283 L
.24378 .44291 L
.24507 .44244 L
.24631 .44136 L
.24749 .43972 L
.24855 .4377 L
.2497 .43488 L
.25228 .42613 L
.25466 .41531 L
.2636 .36631 L
.26825 .3437 L
.27326 .32378 L
.27798 .30927 L
.28231 .29941 L
.2848 .29508 L
.28711 .29185 L
.28965 .28912 L
.29236 .28705 L
.29372 .2863 L
.29444 .28598 L
.29521 .2857 L
.29587 .28549 L
.29661 .28531 L
.29789 .28509 L
.29915 .28501 L
.29985 .28502 L
.30049 .28505 L
.30174 .28519 L
.30292 .28541 L
.30406 .2857 L
.30528 .28609 L
.3075 .28697 L
.31256 .28963 L
.32281 .29656 L
.33234 .30311 L
.34122 .30819 L
.34584 .31025 L
.35077 .31199 L
.35359 .31276 L
.35625 .31336 L
.35864 .31378 L
.36124 .31414 L
.36377 .31439 L
.36521 .31449 L
Mistroke
.36656 .31456 L
.36729 .31459 L
.36798 .31462 L
.36928 .31465 L
.37001 .31466 L
.37068 .31466 L
.37142 .31466 L
.3722 .31466 L
.37352 .31464 L
.37426 .31462 L
.37494 .31461 L
.37751 .31452 L
.38233 .31428 L
.39142 .31377 L
.39404 .31365 L
.39652 .31354 L
.39875 .31347 L
.39999 .31344 L
.40117 .31341 L
.40245 .31339 L
.40313 .31338 L
.40386 .31338 L
.40459 .31337 L
.40535 .31337 L
.40601 .31337 L
.40672 .31337 L
.40801 .31338 L
.40873 .31339 L
.40938 .3134 L
.41066 .31342 L
.41186 .31345 L
.41435 .31353 L
.41665 .31363 L
.42183 .31391 L
.43154 .31465 L
.44061 .31547 L
.46126 .31734 L
.48156 .31872 L
.5001 .31961 L
.53988 .32123 L
.57815 .32275 L
.61886 .32404 L
.65807 .32499 L
.67809 .32538 L
.69972 .32573 L
.71887 .32598 L
.73986 .3262 L
.75985 .32636 L
.77089 .32643 L
.78093 .32648 L
Mistroke
.8005 .32656 L
.81126 .32659 L
.82143 .32662 L
.83112 .32663 L
.83601 .32664 L
.83882 .32664 L
.8414 .32664 L
.84359 .32664 L
.84598 .32664 L
.84729 .32664 L
.84851 .32664 L
.84975 .32665 L
.85091 .32665 L
.852 .32665 L
.85318 .32665 L
.85425 .32665 L
.85523 .32665 L
.8563 .32665 L
.85747 .32665 L
.85869 .32665 L
.85983 .32665 L
.86109 .32664 L
.86243 .32664 L
.86483 .32664 L
.86742 .32664 L
.87028 .32664 L
.88018 .32663 L
.88974 .32662 L
.89873 .32661 L
.9374 .32653 L
.97619 .32643 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.06244 .23874 L
.08255 .36444 L
.10458 .4851 L
.11448 .53044 L
.11992 .55196 L
.12507 .56941 L
.12986 .58251 L
.13256 .58826 L
.13385 .59052 L
.13506 .59232 L
.13616 .59367 L
.13716 .59466 L
.13827 .59546 L
.13947 .59594 L
.14062 .59601 L
.14187 .59561 L
.14305 .59474 L
.14415 .59348 L
.14544 .59137 L
.1468 .58837 L
.14796 .58509 L
.14923 .58069 L
.15207 .56734 L
.15472 .54975 L
.15723 .52766 L
.15952 .50233 L
.16467 .42772 L
.16925 .35242 L
.17166 .31793 L
.17299 .30217 L
.17423 .2897 L
.1754 .28005 L
.17646 .27288 L
.17765 .26667 L
.17893 .26184 L
.17994 .25923 L
.18105 .25744 L
.18221 .25661 L
.18328 .25666 L
.18456 .2576 L
.1852 .25839 L
.18591 .25947 L
.18833 .2646 L
.19116 .27274 L
.1938 .28181 L
.20374 .32187 L
.22233 .39765 L
.22731 .41514 L
.23273 .43181 L
Mistroke
.23522 .43838 L
.23786 .44448 L
.24034 .44918 L
.24261 .45246 L
.24379 .4537 L
.24502 .45464 L
.24627 .45515 L
.24697 .45523 L
.24763 .45517 L
.24882 .45467 L
.2499 .45378 L
.25116 .4522 L
.25234 .45015 L
.25454 .44495 L
.25656 .43872 L
.26115 .42139 L
.27016 .38532 L
.27985 .3536 L
.28541 .34017 L
.29049 .33089 L
.29536 .32448 L
.2978 .32206 L
.30047 .31997 L
.30302 .31846 L
.30436 .31784 L
.30577 .31729 L
.30701 .31691 L
.30837 .31657 L
.30961 .31635 L
.31077 .31619 L
.31198 .31609 L
.31313 .31604 L
.31416 .31604 L
.31528 .31607 L
.3165 .31614 L
.31779 .31625 L
.32012 .31654 L
.3302 .31837 L
.3355 .31926 L
.33817 .31961 L
.33968 .31976 L
.34108 .31987 L
.3424 .31995 L
.34365 .31999 L
.34477 .32001 L
.34598 .32001 L
.34661 .31999 L
.34731 .31997 L
.34803 .31994 L
.34871 .3199 L
Mistroke
.34992 .31982 L
.35122 .31969 L
.35372 .31938 L
.35608 .31898 L
.36053 .318 L
.36927 .31534 L
.3788 .31181 L
.38979 .30765 L
.40013 .30422 L
.40942 .30174 L
.41947 .29973 L
.42939 .2983 L
.43986 .29718 L
.45862 .29561 L
.49661 .29256 L
.51777 .29106 L
.53705 .28999 L
.57598 .28845 L
.61585 .28723 L
.65419 .28623 L
.695 .28525 L
.73428 .28432 L
.77205 .2834 L
.81228 .28239 L
.85098 .28138 L
.89214 .28029 L
.93179 .27924 L
.96992 .27825 L
.97619 .27809 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.06244 .23866 L
.08255 .36437 L
.10458 .48509 L
.11448 .5305 L
.11992 .55207 L
.12507 .56961 L
.12986 .58281 L
.13256 .58864 L
.13385 .59095 L
.13506 .59279 L
.13616 .5942 L
.13716 .59523 L
.13827 .5961 L
.13947 .59665 L
.14062 .5968 L
.14187 .59651 L
.14305 .59575 L
.14415 .59459 L
.14544 .59264 L
.1468 .58982 L
.14796 .58673 L
.14923 .58256 L
.15207 .5699 L
.15472 .5532 L
.15723 .53226 L
.15952 .50833 L
.16467 .43795 L
.16925 .36613 L
.17166 .33237 L
.17423 .30396 L
.17646 .28644 L
.17774 .27934 L
.17893 .2744 L
.18002 .27118 L
.18102 .26919 L
.18212 .26796 L
.18328 .26759 L
.18452 .26811 L
.18521 .26876 L
.18585 .26957 L
.18703 .27151 L
.18828 .27413 L
.19283 .28727 L
.20302 .32717 L
.22139 .40381 L
.23083 .43814 L
.23603 .45433 L
.24096 .46724 L
.24318 .47205 L
Mistroke
.24554 .47637 L
.2469 .47842 L
.24813 .47998 L
.24937 .48122 L
.25053 .48208 L
.2516 .48258 L
.25272 .48281 L
.25368 .48274 L
.25474 .48238 L
.25587 .48167 L
.25709 .48055 L
.25823 .47916 L
.25928 .47764 L
.2641 .46816 L
.26922 .45557 L
.2784 .4321 L
.2884 .41054 L
.29403 .4013 L
.29917 .39473 L
.30372 .39035 L
.30869 .38691 L
.31119 .38564 L
.31387 .38458 L
.31639 .38382 L
.31869 .38331 L
.31983 .38312 L
.32104 .38294 L
.32208 .38282 L
.32321 .38271 L
.32441 .38263 L
.32554 .38256 L
.32623 .38254 L
.32688 .38252 L
.3281 .38249 L
.32917 .38248 L
.33031 .38249 L
.33128 .38249 L
.33235 .38251 L
.33474 .38256 L
.33698 .3826 L
.33815 .38263 L
.3394 .38265 L
.34059 .38266 L
.34166 .38266 L
.34293 .38265 L
.34364 .38265 L
.3443 .38263 L
.34551 .3826 L
.34679 .38255 L
.34802 .38249 L
Mistroke
.34934 .38241 L
.35172 .3822 L
.35455 .38187 L
.35714 .38148 L
.36167 .38059 L
.36662 .37934 L
.37563 .37646 L
.39697 .36835 L
.4163 .36202 L
.42599 .3596 L
.43646 .35748 L
.45545 .35446 L
.49647 .349 L
.53598 .34454 L
.57397 .3413 L
.61441 .33853 L
.65334 .33629 L
.69472 .33428 L
.73459 .33256 L
.77294 .33105 L
.81374 .32953 L
.85303 .32814 L
.8908 .32683 L
.93102 .32549 L
.96973 .32424 L
.97619 .32404 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.06244 .23843 L
.08255 .36413 L
.10458 .48502 L
.11448 .53064 L
.11992 .55239 L
.12507 .57017 L
.12986 .58372 L
.13238 .58944 L
.13506 .59424 L
.13614 .59578 L
.13731 .59715 L
.13859 .59827 L
.13979 .59896 L
.14096 .59925 L
.14207 .59916 L
.14306 .59875 L
.14415 .59793 L
.1448 .59724 L
.14548 .59635 L
.1467 .5943 L
.14802 .59139 L
.14946 .58728 L
.15205 .57725 L
.15447 .56433 L
.15683 .54792 L
.15898 .52934 L
.16382 .47458 L
.16911 .40126 L
.172 .36322 L
.17472 .33402 L
.17702 .31568 L
.17832 .308 L
.17951 .30253 L
.18074 .29831 L
.18144 .29651 L
.18209 .2952 L
.1834 .2935 L
.18413 .29307 L
.1848 .29296 L
.18599 .29337 L
.18725 .29456 L
.18832 .29611 L
.18951 .2983 L
.19215 .30467 L
.19461 .31205 L
.20388 .34638 L
.22464 .42997 L
.23505 .46675 L
.24018 .48239 L
Mistroke
.24493 .49494 L
.24958 .5049 L
.25161 .50836 L
.2538 .51141 L
.25506 .51281 L
.25621 .51386 L
.25732 .51463 L
.25848 .51521 L
.25971 .51556 L
.26086 .51564 L
.26212 .51546 L
.26282 .51525 L
.26347 .51498 L
.26465 .51432 L
.26576 .51352 L
.26829 .5111 L
.27341 .50422 L
.28259 .48866 L
.29272 .47198 L
.29824 .46441 L
.30336 .45857 L
.30843 .45393 L
.31303 .45063 L
.31814 .44786 L
.32097 .44667 L
.32359 .44576 L
.32816 .44456 L
.33057 .44408 L
.33312 .44366 L
.3374 .44313 L
.3421 .44269 L
.34689 .44229 L
.35211 .44179 L
.35703 .44119 L
.36159 .44047 L
.36689 .4394 L
.37252 .43798 L
.3825 .43485 L
.42021 .42133 L
.43954 .41627 L
.46038 .41232 L
.50149 .40629 L
.54108 .40153 L
.57916 .3981 L
.61969 .39529 L
.6587 .39316 L
.70017 .39137 L
.74012 .38999 L
.77855 .38888 L
.81944 .38785 L
Mistroke
.85881 .38697 L
.89666 .38618 L
.93697 .38539 L
.97576 .38467 L
.97619 .38466 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.06244 .23808 L
.08255 .36382 L
.10458 .48498 L
.11448 .53086 L
.11992 .55286 L
.12507 .57095 L
.12986 .58492 L
.13238 .59093 L
.13506 .59613 L
.13731 .59943 L
.13859 .60083 L
.13979 .60179 L
.14089 .60236 L
.14189 .6026 L
.14305 .60253 L
.14415 .60209 L
.1454 .60114 L
.1461 .60037 L
.14674 .5995 L
.14793 .59751 L
.14918 .59481 L
.15135 .58851 L
.15374 .57898 L
.15629 .56539 L
.15902 .5465 L
.16396 .50059 L
.16859 .44676 L
.17351 .38996 L
.17553 .37046 L
.17771 .35327 L
.17896 .34535 L
.1801 .3393 L
.18119 .33459 L
.18234 .3306 L
.18357 .32746 L
.18471 .32545 L
.18541 .32462 L
.18607 .32408 L
.1873 .32368 L
.1886 .32403 L
.1898 .32496 L
.19112 .32657 L
.19252 .32884 L
.19524 .33468 L
.19779 .34143 L
.20358 .35985 L
.22371 .43477 L
.23411 .47156 L
.24399 .50137 L
Mistroke
.24829 .51202 L
.25286 .52128 L
.25549 .52545 L
.25788 .52838 L
.25903 .52948 L
.26028 .53042 L
.26145 .53109 L
.26253 .5315 L
.2638 .53173 L
.265 .53172 L
.26607 .53152 L
.26724 .5311 L
.26852 .53043 L
.26987 .52948 L
.27229 .52724 L
.27662 .52188 L
.28139 .51472 L
.29219 .49764 L
.30207 .48461 L
.31152 .47574 L
.31627 .47254 L
.32145 .46988 L
.32669 .46792 L
.32962 .4671 L
.33227 .46649 L
.33745 .4656 L
.34232 .465 L
.35118 .46417 L
.35606 .46367 L
.36068 .46308 L
.36613 .46219 L
.3711 .46117 L
.38084 .45857 L
.40076 .45165 L
.42181 .44439 L
.4417 .43916 L
.46011 .43562 L
.49935 .4299 L
.53706 .42536 L
.57723 .42173 L
.61589 .41912 L
.657 .41696 L
.69659 .41536 L
.73467 .41416 L
.77519 .41312 L
.81421 .41229 L
.85567 .41153 L
.89562 .41087 L
.93406 .41028 L
.97494 .40969 L
Mistroke
.97619 .40967 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.06244 .2384 L
.08255 .3641 L
.10458 .48501 L
.11448 .53065 L
.11992 .55243 L
.12507 .57024 L
.12986 .58383 L
.13238 .58958 L
.13506 .59442 L
.13614 .59598 L
.13731 .59736 L
.13859 .59852 L
.13979 .59923 L
.14096 .59955 L
.14207 .59949 L
.14306 .59912 L
.14415 .59833 L
.1448 .59767 L
.14548 .59681 L
.1467 .59481 L
.14802 .59196 L
.14946 .58794 L
.15205 .57809 L
.15447 .5654 L
.15683 .54925 L
.15898 .53096 L
.16382 .47702 L
.16911 .40468 L
.172 .36711 L
.17472 .33823 L
.17702 .32002 L
.17832 .31236 L
.17951 .30686 L
.18074 .30257 L
.18144 .30072 L
.18209 .29934 L
.1834 .29751 L
.18413 .29697 L
.1848 .29676 L
.18599 .29698 L
.18725 .29794 L
.18832 .29927 L
.18951 .3012 L
.19215 .3069 L
.19461 .31355 L
.20388 .34429 L
.21453 .38242 L
.22464 .41612 L
.22934 .42986 L
Mistroke
.23435 .44229 L
.23723 .44802 L
.23984 .45202 L
.2411 .45346 L
.24176 .45406 L
.24246 .45458 L
.24375 .45519 L
.24493 .4553 L
.24609 .45496 L
.24714 .45421 L
.24836 .45278 L
.24951 .45084 L
.25057 .4485 L
.25155 .44587 L
.25377 .43827 L
.25848 .41633 L
.26347 .38992 L
.27286 .34675 L
.27814 .32921 L
.28065 .32268 L
.28298 .31759 L
.28724 .31056 L
.28949 .30791 L
.29189 .30583 L
.29311 .30504 L
.29442 .30437 L
.29567 .30391 L
.29681 .30361 L
.29784 .30345 L
.29898 .30338 L
.30016 .30342 L
.30127 .30356 L
.30253 .30382 L
.30386 .3042 L
.30627 .30517 L
.30885 .30653 L
.3117 .30835 L
.3216 .3163 L
.34015 .33211 L
.35022 .33881 L
.35947 .34322 L
.36431 .34488 L
.36962 .34626 L
.3723 .3468 L
.37516 .34728 L
.38032 .34795 L
.38564 .34844 L
.39054 .34878 L
.40164 .34945 L
.41142 .35017 L
Mistroke
.42178 .35121 L
.45964 .35627 L
.48069 .35859 L
.49994 .36012 L
.53874 .36236 L
.57846 .36424 L
.61668 .3656 L
.63801 .36618 L
.65734 .36662 L
.69649 .36731 L
.71575 .36756 L
.73658 .36778 L
.75653 .36794 L
.7776 .36807 L
.79726 .36817 L
.81559 .36823 L
.82606 .36826 L
.83596 .36829 L
.85452 .36832 L
.86419 .36833 L
.87445 .36834 L
.88321 .36835 L
.89287 .36836 L
.89779 .36836 L
.90298 .36836 L
.9074 .36836 L
.91223 .36837 L
.91497 .36837 L
.91746 .36837 L
.91884 .36837 L
.92033 .36837 L
.92162 .36837 L
.92304 .36837 L
.92436 .36837 L
.92558 .36837 L
.92688 .36837 L
.92761 .36837 L
.92827 .36837 L
.92946 .36837 L
.93075 .36837 L
.93197 .36837 L
.9331 .36837 L
.93575 .36837 L
.93819 .36837 L
.9437 .36837 L
.94855 .36836 L
.95367 .36836 L
.9723 .36836 L
.97619 .36836 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.06244 .23853 L
.08255 .36423 L
.10458 .48504 L
.11448 .53057 L
.11992 .55224 L
.12507 .56991 L
.12986 .5833 L
.13238 .58891 L
.13376 .5915 L
.13506 .59358 L
.13623 .59516 L
.13731 .59633 L
.1385 .59731 L
.13979 .59794 L
.14086 .59812 L
.14202 .59792 L
.14313 .59733 L
.14415 .5964 L
.14544 .59469 L
.1468 .59215 L
.14796 .58934 L
.14923 .58552 L
.15207 .57383 L
.15472 .55837 L
.15723 .53895 L
.15952 .51675 L
.16467 .45119 L
.16933 .38167 L
.1737 .32585 L
.17589 .30594 L
.17712 .2974 L
.17825 .29116 L
.17942 .28619 L
.1807 .28232 L
.18135 .28093 L
.18204 .27983 L
.18328 .27874 L
.18456 .27869 L
.18529 .27908 L
.18595 .27968 L
.18718 .28132 L
.18848 .28371 L
.19072 .28918 L
.19319 .29667 L
.20237 .33193 L
.22313 .41896 L
.2331 .4554 L
.24257 .48358 L
.2478 .49528 L
Mistroke
.25075 .50027 L
.25216 .50216 L
.25349 .50362 L
.25471 .50467 L
.25603 .50548 L
.25722 .50592 L
.25832 .50608 L
.25952 .50599 L
.26083 .50559 L
.26149 .50526 L
.26219 .50484 L
.26347 .50387 L
.26604 .5012 L
.26877 .49751 L
.27367 .4894 L
.28475 .46879 L
.29444 .45293 L
.29953 .44628 L
.30488 .44064 L
.30975 .43664 L
.31506 .43339 L
.3174 .43228 L
.3199 .43128 L
.32439 .42991 L
.32676 .42936 L
.32933 .42889 L
.33159 .42855 L
.33398 .42826 L
.33851 .42784 L
.34268 .42751 L
.34754 .42711 L
.35214 .42663 L
.35745 .42589 L
.3623 .42499 L
.37107 .42278 L
.38062 .41964 L
.39998 .41219 L
.42137 .4048 L
.4416 .39973 L
.46061 .39623 L
.49926 .39043 L
.54037 .38533 L
.57996 .38167 L
.61804 .37891 L
.65857 .37657 L
.69758 .37476 L
.73904 .37318 L
.77899 .37189 L
.81743 .3708 L
.85831 .36974 L
Mistroke
.89769 .36878 L
.93554 .36792 L
.97585 .36704 L
.97619 .36703 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.06244 .23824 L
.08255 .36395 L
.10458 .48499 L
.11448 .53076 L
.11992 .55265 L
.12507 .57062 L
.12986 .5844 L
.13238 .59029 L
.13506 .59533 L
.13731 .59846 L
.13859 .59975 L
.13979 .6006 L
.14089 .60105 L
.14189 .60117 L
.14305 .60095 L
.14415 .60035 L
.1454 .59919 L
.1461 .59829 L
.14674 .59731 L
.1479 .59512 L
.14918 .59206 L
.1514 .58497 L
.15374 .57474 L
.15629 .55996 L
.15902 .53942 L
.16396 .4895 L
.16859 .43157 L
.17351 .37261 L
.17553 .35334 L
.17771 .33699 L
.17896 .32974 L
.1801 .32438 L
.18119 .32033 L
.18234 .31711 L
.18356 .31476 L
.18486 .31331 L
.18609 .31282 L
.1872 .31303 L
.18852 .31396 L
.18925 .31476 L
.18994 .31567 L
.19252 .3203 L
.19508 .32634 L
.19789 .33415 L
.20358 .35215 L
.2141 .38808 L
.22371 .41985 L
.22848 .43422 L
.23368 .44809 L
Mistroke
.23606 .45357 L
.2386 .45862 L
.24097 .46247 L
.24201 .46383 L
.24315 .46506 L
.24447 .4661 L
.2452 .46649 L
.24587 .46671 L
.24661 .4668 L
.24729 .46673 L
.24807 .46647 L
.2488 .46601 L
.24944 .46545 L
.25013 .46468 L
.25135 .46281 L
.25267 .46009 L
.25412 .45622 L
.25658 .44767 L
.25924 .43623 L
.26405 .41263 L
.26908 .38807 L
.27445 .36521 L
.27943 .34828 L
.28413 .33625 L
.28667 .33125 L
.28941 .32695 L
.29191 .32396 L
.29422 .32191 L
.29553 .32102 L
.29677 .32036 L
.29812 .31981 L
.29888 .31959 L
.29957 .31942 L
.3003 .3193 L
.30096 .31923 L
.3017 .31919 L
.30248 .31919 L
.30379 .31931 L
.30454 .31943 L
.30524 .31957 L
.30641 .31988 L
.30766 .32031 L
.30992 .32129 L
.31505 .32432 L
.3254 .33248 L
.34389 .34764 L
.35412 .35404 L
.35989 .35677 L
.36521 .35873 L
.36987 .36006 L
Mistroke
.37499 .36116 L
.38035 .36198 L
.38536 .36252 L
.40391 .36381 L
.42415 .36565 L
.43512 .36706 L
.4453 .3685 L
.46539 .37123 L
.48593 .37342 L
.50454 .37486 L
.54463 .37715 L
.5832 .37893 L
.60276 .37965 L
.62422 .38031 L
.66373 .38122 L
.68326 .38156 L
.70418 .38186 L
.724 .38209 L
.74556 .38228 L
.76627 .38242 L
.78542 .38253 L
.8041 .3826 L
.82471 .38267 L
.84407 .38271 L
.85404 .38273 L
.86493 .38275 L
.88499 .38277 L
.89592 .38278 L
.90609 .38278 L
.91662 .38279 L
.92656 .38279 L
.93549 .38279 L
.94052 .38279 L
.94516 .38279 L
.94884 .38279 L
.9528 .3828 L
.95653 .3828 L
.95994 .3828 L
.96201 .3828 L
.96393 .3828 L
.96504 .3828 L
.96604 .3828 L
.96719 .3828 L
.96828 .3828 L
.96924 .3828 L
.97026 .3828 L
.97113 .3828 L
.97208 .3828 L
.97311 .3828 L
.97421 .3828 L
Mistroke
.97619 .3828 L
Mfstroke
.53 1 0 r
.02381 .01472 m
.06244 .23871 L
.08255 .36441 L
.10458 .48509 L
.11448 .53046 L
.11992 .552 L
.12507 .56948 L
.12986 .58262 L
.13256 .5884 L
.13385 .59068 L
.13506 .59249 L
.13616 .59387 L
.13716 .59487 L
.13827 .59569 L
.13947 .59621 L
.14062 .59631 L
.14187 .59595 L
.14305 .59512 L
.14415 .5939 L
.14544 .59185 L
.1468 .58891 L
.14796 .58571 L
.14923 .5814 L
.15207 .56832 L
.15472 .55108 L
.15723 .52945 L
.15952 .50468 L
.16467 .43177 L
.16925 .35778 L
.17166 .32346 L
.17299 .30763 L
.17423 .29501 L
.17646 .27779 L
.17765 .27135 L
.17893 .26628 L
.18004 .26328 L
.1812 .26133 L
.18219 .26053 L
.18328 .26044 L
.1846 .26129 L
.18582 .26286 L
.18645 .26395 L
.18715 .26532 L
.18857 .26861 L
.19356 .28429 L
.20289 .32218 L
.22384 .41012 L
.23382 .44467 L
.23873 .45852 L
.24329 .46875 L
Mistroke
.24582 .47306 L
.24711 .4748 L
.24851 .47629 L
.24932 .47695 L
.25005 .47742 L
.25076 .47774 L
.2515 .47795 L
.25279 .47795 L
.25352 .47776 L
.25421 .47744 L
.2555 .47649 L
.25673 .47517 L
.25902 .47174 L
.2615 .46685 L
.26418 .46056 L
.28361 .41064 L
.28893 .39991 L
.29466 .39064 L
.30006 .38403 L
.30246 .38171 L
.30502 .37963 L
.30751 .37795 L
.30976 .37669 L
.31206 .37566 L
.31418 .3749 L
.31665 .37422 L
.31793 .37394 L
.31933 .37369 L
.32169 .37337 L
.32298 .37325 L
.32418 .37316 L
.32543 .37309 L
.32614 .37307 L
.32679 .37305 L
.32799 .37302 L
.32927 .37301 L
.3304 .37301 L
.33147 .37301 L
.33264 .37302 L
.3339 .37303 L
.33528 .37305 L
.33655 .37306 L
.3372 .37306 L
.33789 .37306 L
.33865 .37306 L
.33934 .37306 L
.34057 .37305 L
.34127 .37304 L
.34191 .37302 L
.34309 .37299 L
Mistroke
.34434 .37294 L
.34554 .37287 L
.34686 .37278 L
.34926 .37257 L
.35159 .3723 L
.35376 .37198 L
.35866 .37103 L
.36388 .36968 L
.38219 .36295 L
.40218 .35486 L
.41269 .35129 L
.42379 .34821 L
.44468 .34396 L
.46388 .34093 L
.50187 .33547 L
.54231 .33065 L
.58124 .32711 L
.62262 .32401 L
.66249 .32149 L
.70084 .31938 L
.74164 .31737 L
.78093 .31557 L
.8187 .31392 L
.85892 .31224 L
.89763 .31066 L
.93879 .30903 L
.97619 .30761 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.06244 .23826 L
.08255 .36398 L
.10458 .485 L
.11448 .53075 L
.11992 .55262 L
.12507 .57056 L
.12986 .58432 L
.13238 .59019 L
.13506 .5952 L
.13731 .59831 L
.13859 .59958 L
.13979 .60041 L
.14089 .60084 L
.14189 .60095 L
.14305 .60071 L
.14415 .60008 L
.1454 .59889 L
.1461 .59798 L
.14674 .59698 L
.1479 .59475 L
.14918 .59166 L
.1514 .58449 L
.15374 .57415 L
.15629 .55923 L
.15902 .53851 L
.16396 .48825 L
.16859 .43007 L
.17351 .37105 L
.17553 .35179 L
.17771 .33547 L
.17896 .32824 L
.1801 .32291 L
.18119 .31889 L
.18234 .31572 L
.18356 .31343 L
.18486 .31206 L
.18609 .31166 L
.1872 .31196 L
.18852 .31301 L
.18925 .3139 L
.18994 .31489 L
.19252 .31989 L
.19508 .32639 L
.19789 .33483 L
.20358 .3545 L
.22371 .43177 L
.23368 .4673 L
.24315 .49599 L
.24838 .50873 L
Mistroke
.25113 .5143 L
.25407 .51916 L
.25547 .52104 L
.25679 .52254 L
.25807 .52373 L
.25925 .52459 L
.26037 .52518 L
.26155 .52558 L
.26274 .52574 L
.26405 .52566 L
.26536 .5253 L
.26657 .52474 L
.26789 .52389 L
.2693 .52274 L
.27428 .51703 L
.28359 .50249 L
.29367 .4866 L
.29896 .47952 L
.30452 .47331 L
.30939 .46891 L
.31471 .46514 L
.31954 .46255 L
.32403 .46074 L
.32867 .45938 L
.33288 .45849 L
.33774 .45777 L
.34232 .45728 L
.35207 .4564 L
.3574 .45582 L
.36238 .4551 L
.37118 .45334 L
.38084 .45066 L
.41972 .43705 L
.44093 .43142 L
.46105 .42761 L
.49935 .42204 L
.5401 .41716 L
.57933 .41367 L
.61705 .41111 L
.65722 .40896 L
.69587 .40736 L
.73698 .406 L
.77657 .40493 L
.81465 .40406 L
.85518 .40324 L
.89419 .40253 L
.93566 .40182 L
.97561 .40117 L
.97619 .40116 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.06244 .23832 L
.08255 .36402 L
.10458 .485 L
.11448 .5307 L
.11992 .55254 L
.12507 .57043 L
.12986 .58411 L
.13238 .58993 L
.13506 .59488 L
.13731 .59792 L
.13859 .59914 L
.13979 .59992 L
.14089 .6003 L
.14189 .60036 L
.14305 .60005 L
.14415 .59935 L
.1454 .59807 L
.1461 .5971 L
.14674 .59604 L
.1479 .5937 L
.14918 .59046 L
.1514 .58299 L
.15374 .57224 L
.15629 .55672 L
.15902 .53513 L
.16396 .48264 L
.16859 .42204 L
.17113 .3891 L
.17351 .3617 L
.1757 .34111 L
.17771 .32663 L
.1788 .32054 L
.17994 .31537 L
.18109 .31137 L
.18234 .30823 L
.18303 .30701 L
.18368 .30616 L
.18489 .30526 L
.1862 .3052 L
.18694 .30553 L
.18761 .30605 L
.18875 .30731 L
.19 .3092 L
.19252 .31434 L
.19824 .33028 L
.20358 .34799 L
.22371 .41675 L
.22868 .43163 L
.23411 .44564 L
Mistroke
.2366 .45098 L
.23924 .45568 L
.24052 .45753 L
.24173 .45896 L
.24282 .45997 L
.24399 .46072 L
.24515 .46108 L
.24624 .46105 L
.24742 .46054 L
.24869 .45942 L
.24933 .4586 L
.25003 .45752 L
.25129 .45501 L
.25365 .44838 L
.25589 .43992 L
.25827 .42914 L
.26253 .4075 L
.27193 .3626 L
.27721 .34324 L
.28204 .32991 L
.2863 .32146 L
.28871 .31793 L
.29096 .31538 L
.29218 .31427 L
.29334 .31338 L
.29438 .31271 L
.29549 .31214 L
.2967 .31166 L
.29782 .31134 L
.29902 .31114 L
.30033 .31105 L
.30163 .3111 L
.30284 .31126 L
.30416 .31156 L
.30556 .31199 L
.30792 .31297 L
.31052 .31437 L
.31982 .32121 L
.33072 .33075 L
.34072 .33907 L
.34995 .34541 L
.36005 .35049 L
.3653 .35236 L
.3702 .3537 L
.37537 .35475 L
.3809 .35554 L
.38621 .35609 L
.39112 .35648 L
.40222 .35722 L
.41262 .35806 L
Mistroke
.42236 .35908 L
.4411 .36161 L
.46173 .3645 L
.48199 .36679 L
.50052 .36831 L
.54025 .37067 L
.57846 .37251 L
.5998 .37333 L
.61913 .37396 L
.65828 .37492 L
.67754 .37528 L
.69837 .37561 L
.71793 .37585 L
.73939 .37606 L
.75983 .37622 L
.7789 .37634 L
.79926 .37643 L
.81783 .3765 L
.83692 .37655 L
.8468 .37657 L
.85769 .37659 L
.87748 .37662 L
.88832 .37663 L
.89849 .37663 L
.90833 .37664 L
.91869 .37665 L
.92753 .37665 L
.9372 .37665 L
.94228 .37665 L
.94708 .37665 L
.95144 .37665 L
.95606 .37666 L
.95845 .37666 L
.96109 .37666 L
.96351 .37666 L
.96572 .37666 L
.96833 .37666 L
.96977 .37666 L
.97113 .37666 L
.97239 .37666 L
.97355 .37666 L
.97483 .37666 L
.97554 .37666 L
.97619 .37666 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.06244 .23853 L
.08255 .36422 L
.10458 .48503 L
.11448 .53055 L
.11992 .55223 L
.12507 .5699 L
.12986 .5833 L
.13238 .58892 L
.13376 .5915 L
.13506 .59358 L
.13623 .59517 L
.13731 .59634 L
.1385 .59731 L
.13979 .59795 L
.14086 .59813 L
.14202 .59793 L
.14313 .59733 L
.14415 .59641 L
.14544 .59469 L
.1468 .59214 L
.14796 .58932 L
.14923 .58548 L
.15207 .57374 L
.15472 .55817 L
.15723 .53858 L
.15952 .51613 L
.16467 .44957 L
.16933 .37897 L
.17161 .34728 L
.1737 .32287 L
.17589 .30313 L
.17704 .2952 L
.17825 .28856 L
.1795 .28342 L
.18065 .28 L
.18192 .27758 L
.18264 .27677 L
.18328 .27634 L
.18455 .27624 L
.18573 .27694 L
.18702 .27845 L
.18767 .27946 L
.18838 .28075 L
.19319 .29306 L
.20237 .32546 L
.21321 .36658 L
.22313 .40078 L
.2279 .41486 L
.23042 .42137 L
Mistroke
.2331 .42742 L
.23568 .43217 L
.2369 .43398 L
.23802 .43536 L
.23915 .43644 L
.24037 .43722 L
.24144 .43754 L
.24257 .43745 L
.24388 .43676 L
.24507 .4355 L
.24572 .43452 L
.24644 .43322 L
.24773 .43017 L
.24894 .42646 L
.25023 .42159 L
.25254 .4105 L
.26347 .34233 L
.26805 .31871 L
.27286 .29936 L
.27539 .29139 L
.27814 .28427 L
.28068 .27909 L
.28298 .27541 L
.28534 .27257 L
.28756 .27066 L
.28879 .26991 L
.28991 .26938 L
.29115 .26898 L
.29246 .26874 L
.29351 .26868 L
.29463 .26873 L
.29569 .26889 L
.29666 .26911 L
.29779 .26947 L
.29902 .26997 L
.30127 .27114 L
.30611 .27457 L
.31065 .27861 L
.32102 .28917 L
.33125 .29951 L
.34202 .30872 L
.35164 .31486 L
.3571 .31744 L
.36218 .31931 L
.36686 .32064 L
.37112 .32156 L
.37603 .32238 L
.38067 .32296 L
.39897 .32459 L
.41911 .32687 L
Mistroke
.43896 .32993 L
.45999 .33313 L
.47942 .33545 L
.5003 .33726 L
.54155 .33993 L
.58128 .34204 L
.61949 .34355 L
.66015 .3447 L
.6993 .3455 L
.72073 .34583 L
.74091 .34608 L
.77948 .34643 L
.79943 .34656 L
.8205 .34667 L
.84038 .34675 L
.85849 .34681 L
.87802 .34686 L
.89894 .3469 L
.91803 .34693 L
.9388 .34696 L
.97619 .34699 L
Mfstroke
.435 1 0 r
.02381 .01472 m
.06244 .23874 L
.08255 .36444 L
.10458 .4851 L
.11448 .53044 L
.11992 .55195 L
.12507 .5694 L
.12986 .5825 L
.13256 .58824 L
.13385 .59049 L
.13506 .59229 L
.13616 .59364 L
.13716 .59462 L
.13827 .59542 L
.13947 .59589 L
.14062 .59596 L
.14187 .59555 L
.14305 .59468 L
.14415 .5934 L
.14544 .59129 L
.1468 .58827 L
.14796 .58499 L
.14923 .58056 L
.15207 .56717 L
.15472 .54952 L
.15723 .52734 L
.15952 .50191 L
.16467 .42695 L
.16925 .35126 L
.17166 .3166 L
.17299 .30077 L
.17423 .28825 L
.1754 .27856 L
.17646 .27137 L
.17765 .26514 L
.17893 .26031 L
.17994 .25769 L
.18105 .25591 L
.18221 .25509 L
.18328 .25515 L
.18456 .25611 L
.1852 .2569 L
.18591 .258 L
.18833 .26318 L
.19116 .27141 L
.1938 .28057 L
.20374 .3212 L
.22233 .39864 L
.22731 .41668 L
.23273 .4341 L
Mistroke
.23752 .4469 L
.24014 .45262 L
.24261 .45694 L
.24379 .45859 L
.24504 .45999 L
.24569 .46058 L
.24641 .4611 L
.24766 .46168 L
.2488 .46181 L
.25003 .46151 L
.25118 .46077 L
.25223 .4597 L
.25337 .45811 L
.25443 .45625 L
.25682 .4508 L
.26115 .43765 L
.27092 .40364 L
.27605 .38719 L
.28144 .37221 L
.28619 .36128 L
.29138 .35181 L
.29609 .34531 L
.30047 .3409 L
.30284 .33908 L
.3054 .33753 L
.30783 .3364 L
.31006 .33562 L
.31207 .3351 L
.31322 .33488 L
.31429 .33471 L
.31542 .33457 L
.31644 .33448 L
.31763 .33441 L
.31876 .33438 L
.31988 .33437 L
.32111 .33438 L
.3224 .33443 L
.32361 .33449 L
.32577 .33463 L
.3281 .33482 L
.33065 .33504 L
.33337 .33525 L
.33469 .33535 L
.33594 .33542 L
.33705 .33548 L
.33827 .33552 L
.33943 .33555 L
.34066 .33557 L
.34179 .33556 L
.34286 .33554 L
Mistroke
.34411 .33549 L
.34525 .33543 L
.34657 .33534 L
.34783 .33522 L
.35042 .33489 L
.35283 .3345 L
.35829 .33326 L
.36365 .33162 L
.3685 .32986 L
.37938 .32529 L
.40026 .31663 L
.40942 .31358 L
.41947 .3109 L
.43823 .30731 L
.45804 .30451 L
.49848 .29928 L
.53741 .29513 L
.57879 .29192 L
.61866 .28939 L
.65701 .28728 L
.69781 .28529 L
.73709 .28351 L
.77486 .28187 L
.81509 .28016 L
.85379 .27853 L
.89495 .27683 L
.9346 .27523 L
.97273 .27375 L
.97619 .27362 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.06244 .2387 L
.08255 .36441 L
.10458 .48509 L
.11448 .53048 L
.11992 .55202 L
.12507 .56952 L
.12986 .58268 L
.13256 .58847 L
.13385 .59075 L
.13506 .59258 L
.13616 .59396 L
.13716 .59497 L
.13827 .5958 L
.13947 .59633 L
.14062 .59644 L
.14187 .5961 L
.14305 .59529 L
.14415 .59409 L
.14544 .59207 L
.1468 .58917 L
.14796 .586 L
.14923 .58172 L
.15207 .56876 L
.15472 .55168 L
.15723 .53026 L
.15952 .50574 L
.16467 .43364 L
.16925 .36044 L
.17166 .32641 L
.17299 .31068 L
.17423 .2981 L
.17646 .28089 L
.17765 .27442 L
.17893 .26929 L
.18004 .26623 L
.1812 .26422 L
.18219 .26335 L
.18328 .2632 L
.1846 .26396 L
.18582 .26545 L
.18645 .26648 L
.18715 .26781 L
.18857 .271 L
.19356 .28631 L
.20289 .32344 L
.22384 .40983 L
.23382 .44364 L
.23873 .45702 L
.24329 .46665 L
Mistroke
.24582 .47051 L
.24723 .4721 L
.24851 .47315 L
.24925 .47357 L
.24992 .47383 L
.25066 .47398 L
.25145 .47397 L
.25276 .47356 L
.25351 .4731 L
.25421 .47252 L
.2555 .47107 L
.25673 .46928 L
.25902 .46491 L
.26418 .4518 L
.27297 .42602 L
.28244 .40105 L
.28786 .38958 L
.29283 .38112 L
.29757 .37483 L
.29999 .37227 L
.30256 .36996 L
.30514 .36807 L
.30747 .36668 L
.30985 .36555 L
.31203 .36474 L
.31459 .36404 L
.31593 .36376 L
.31736 .36353 L
.31859 .36338 L
.31975 .36327 L
.32102 .36318 L
.32173 .36315 L
.32238 .36313 L
.32368 .36311 L
.32433 .36311 L
.32506 .36311 L
.32634 .36314 L
.32754 .36318 L
.32895 .36324 L
.33025 .36331 L
.33317 .36348 L
.33575 .36362 L
.33815 .36374 L
.33936 .36378 L
.34066 .36382 L
.34139 .36383 L
.34209 .36384 L
.3434 .36384 L
.34455 .36383 L
.34578 .3638 L
Mistroke
.34695 .36375 L
.34802 .3637 L
.34927 .36361 L
.35063 .36349 L
.3531 .36321 L
.35569 .36283 L
.35844 .36232 L
.36339 .36116 L
.37306 .3581 L
.38183 .35477 L
.40272 .34684 L
.41187 .34397 L
.42192 .34138 L
.44068 .33785 L
.46049 .33507 L
.50093 .32997 L
.53986 .32589 L
.58124 .32266 L
.62111 .32011 L
.65946 .31802 L
.70026 .31608 L
.73955 .31437 L
.77732 .31283 L
.81754 .31125 L
.85625 .30977 L
.89741 .30823 L
.93705 .30679 L
.97518 .30546 L
.97619 .30542 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.06244 .23875 L
.08255 .36445 L
.10458 .48509 L
.11448 .53042 L
.11992 .55193 L
.12507 .56937 L
.12986 .58245 L
.13256 .58818 L
.13385 .59042 L
.13506 .59221 L
.13616 .59355 L
.13716 .59453 L
.13827 .59531 L
.13947 .59578 L
.14062 .59583 L
.14187 .5954 L
.14305 .59451 L
.14415 .59321 L
.14544 .59107 L
.1468 .58801 L
.14796 .58469 L
.14923 .58021 L
.15207 .56667 L
.15472 .5488 L
.15723 .52632 L
.15952 .5005 L
.16467 .42418 L
.16925 .34716 L
.17166 .31209 L
.17299 .29618 L
.17423 .28364 L
.1754 .27398 L
.17646 .26685 L
.17765 .26072 L
.17893 .25598 L
.17994 .25345 L
.18105 .25175 L
.18221 .25101 L
.18328 .25114 L
.18456 .25216 L
.1852 .25299 L
.18591 .25411 L
.18833 .25937 L
.19116 .26764 L
.1938 .27679 L
.20374 .31697 L
.22233 .39128 L
.22731 .40778 L
.23273 .42287 L
Mistroke
.23522 .42845 L
.23658 .43107 L
.23786 .43322 L
.23906 .43491 L
.24036 .43636 L
.24153 .4373 L
.24261 .43781 L
.24369 .43795 L
.24484 .43765 L
.24593 .4369 L
.24692 .43579 L
.24808 .43392 L
.24934 .43116 L
.25163 .4241 L
.25403 .414 L
.25658 .40095 L
.26115 .37527 L
.27055 .3286 L
.27583 .30876 L
.28066 .29474 L
.28492 .28542 L
.28958 .27813 L
.29193 .27546 L
.29444 .27327 L
.29566 .27244 L
.29681 .27177 L
.29793 .27123 L
.29895 .27083 L
.30011 .27048 L
.30135 .2702 L
.30251 .27004 L
.3036 .26996 L
.30487 .26995 L
.30604 .27003 L
.30733 .27018 L
.30798 .27029 L
.3087 .27042 L
.31126 .27106 L
.31401 .27197 L
.31901 .27399 L
.32857 .27817 L
.33323 .27995 L
.33747 .28126 L
.33969 .2818 L
.34209 .28228 L
.34341 .28249 L
.34463 .28265 L
.34579 .28277 L
.34703 .28287 L
.34827 .28294 L
Mistroke
.34896 .28296 L
.3496 .28297 L
.35083 .28297 L
.35201 .28295 L
.35267 .28292 L
.35337 .28288 L
.35463 .28279 L
.35613 .28264 L
.35749 .28248 L
.36271 .28159 L
.36835 .28028 L
.37858 .27747 L
.3889 .27471 L
.39853 .27268 L
.40338 .27192 L
.40858 .27131 L
.41154 .27104 L
.41435 .27084 L
.41687 .2707 L
.41829 .27064 L
.4196 .27059 L
.42194 .27053 L
.42317 .27051 L
.42446 .27049 L
.42558 .27048 L
.42663 .27047 L
.42778 .27047 L
.42901 .27047 L
.42971 .27047 L
.43036 .27048 L
.43181 .27049 L
.43309 .27051 L
.43445 .27053 L
.43939 .27063 L
.44952 .27089 L
.45511 .27103 L
.4604 .27114 L
.4653 .27123 L
.47064 .27131 L
.4755 .27136 L
.47999 .27139 L
.4888 .27145 L
.49831 .2715 L
.50384 .27154 L
.50892 .27159 L
.51889 .27172 L
.52795 .27189 L
.53751 .27211 L
.57556 .27317 L
.61605 .27422 L
Mistroke
.65503 .27507 L
.6749 .27544 L
.69647 .27577 L
.71546 .27601 L
.73639 .27621 L
.75621 .27635 L
.76707 .27641 L
.77724 .27645 L
.7822 .27647 L
.78761 .27648 L
.79239 .27649 L
.79748 .2765 L
.80007 .2765 L
.80251 .27651 L
.80489 .27651 L
.80708 .27651 L
.80916 .27651 L
.81021 .27651 L
.81136 .27651 L
.81252 .27651 L
.81376 .27651 L
.81493 .27651 L
.816 .27651 L
.81718 .27651 L
.81828 .27651 L
.81949 .27651 L
.8208 .27651 L
.82346 .27651 L
.82591 .27651 L
.83037 .2765 L
.83508 .27649 L
.84499 .27647 L
.85583 .27645 L
.87543 .27638 L
.89638 .27628 L
.93787 .27606 L
.97619 .27583 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.06244 .23876 L
.08255 .36446 L
.10458 .48509 L
.11448 .53042 L
.11992 .55191 L
.12507 .56934 L
.12986 .58239 L
.13256 .58811 L
.13385 .59035 L
.13506 .59213 L
.13616 .59346 L
.13716 .59443 L
.13827 .5952 L
.13947 .59565 L
.14062 .59569 L
.14187 .59525 L
.14305 .59433 L
.14415 .59302 L
.14544 .59085 L
.1468 .58776 L
.14923 .57989 L
.15058 .57404 L
.15185 .5675 L
.15472 .54822 L
.15723 .52555 L
.15952 .49952 L
.16467 .4226 L
.16925 .34515 L
.17166 .31001 L
.17299 .29411 L
.17423 .2816 L
.1754 .272 L
.17646 .26493 L
.17765 .25886 L
.17893 .2542 L
.17994 .25173 L
.18105 .25009 L
.18221 .2494 L
.18328 .24958 L
.18456 .25066 L
.1852 .25151 L
.18591 .25266 L
.18833 .258 L
.19116 .26635 L
.1938 .27558 L
.20374 .31613 L
.22233 .39167 L
.22731 .40863 L
.23273 .42434 L
Mistroke
.23522 .43027 L
.23786 .43549 L
.23915 .43754 L
.24036 .43915 L
.24144 .44029 L
.24261 .44118 L
.24377 .44166 L
.24486 .44172 L
.24604 .44131 L
.24731 .44026 L
.24795 .43949 L
.24865 .43844 L
.24991 .43598 L
.25114 .43287 L
.25227 .42937 L
.25658 .41144 L
.26115 .38824 L
.27055 .34372 L
.27548 .32498 L
.28066 .30917 L
.28522 .29846 L
.28764 .29394 L
.29021 .2899 L
.29259 .28684 L
.29474 .28458 L
.29692 .28275 L
.29895 .28141 L
.30127 .28028 L
.3025 .27984 L
.30382 .27947 L
.30448 .27933 L
.3052 .2792 L
.30651 .27903 L
.30778 .27895 L
.30896 .27895 L
.31006 .27899 L
.31108 .27907 L
.31221 .2792 L
.31343 .27938 L
.3159 .27986 L
.31818 .28041 L
.32338 .28185 L
.32895 .28341 L
.33166 .28408 L
.33421 .28462 L
.33653 .28503 L
.3378 .28521 L
.33899 .28535 L
.34016 .28546 L
.34123 .28554 L
Mistroke
.34242 .2856 L
.3437 .28563 L
.34477 .28563 L
.34593 .28561 L
.34703 .28556 L
.34805 .28549 L
.34934 .28537 L
.35055 .28523 L
.35281 .28489 L
.35525 .28442 L
.35789 .28379 L
.36867 .28032 L
.37858 .27649 L
.38767 .27309 L
.39742 .27003 L
.40301 .26862 L
.40811 .26756 L
.41295 .26675 L
.41809 .26606 L
.42281 .26556 L
.42801 .26514 L
.43719 .26462 L
.44234 .2644 L
.4479 .26419 L
.45795 .26382 L
.47761 .26301 L
.49911 .26209 L
.50905 .26174 L
.51965 .26145 L
.5248 .26134 L
.52966 .26126 L
.53876 .26114 L
.54339 .2611 L
.54849 .26107 L
.55381 .26104 L
.55879 .26102 L
.56344 .26101 L
.56769 .261 L
.57003 .261 L
.57259 .261 L
.57724 .26099 L
.57981 .26099 L
.58258 .26099 L
.5852 .26099 L
.58644 .26099 L
.5876 .26099 L
.58977 .26099 L
.59093 .26099 L
.59216 .26099 L
.59345 .26099 L
Mistroke
.59468 .26099 L
.59578 .26099 L
.59697 .26099 L
.59827 .26099 L
.59949 .26099 L
.60083 .26099 L
.60227 .26099 L
.6052 .26099 L
.60788 .26099 L
.61305 .26099 L
.61796 .26099 L
.63798 .26101 L
.6467 .26101 L
.65129 .26101 L
.65614 .26102 L
.65865 .26102 L
.65998 .26102 L
.66141 .26102 L
.66272 .26102 L
.66392 .26102 L
.66512 .26102 L
.66626 .26102 L
.66741 .26102 L
.66864 .26102 L
.66968 .26102 L
.67083 .26102 L
.67207 .26102 L
.6734 .26102 L
.6758 .26102 L
.67835 .26101 L
.68113 .26101 L
.68674 .26101 L
.69194 .261 L
.69677 .26099 L
.70729 .26096 L
.71722 .26093 L
.73581 .26084 L
.75581 .26072 L
.77426 .26057 L
.81365 .26019 L
.85153 .25974 L
.89185 .25919 L
.93067 .25863 L
.97193 .25804 L
.97619 .25798 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.06244 .23863 L
.08255 .36432 L
.10458 .48505 L
.11448 .53048 L
.11992 .55207 L
.12507 .56963 L
.12986 .58287 L
.13256 .58873 L
.13385 .59104 L
.13506 .5929 L
.13616 .59432 L
.13716 .59537 L
.13827 .59624 L
.13947 .59681 L
.14062 .59698 L
.14187 .5967 L
.14305 .59595 L
.14415 .59481 L
.14544 .59288 L
.1468 .59007 L
.14796 .587 L
.14923 .58283 L
.15207 .57015 L
.15472 .55336 L
.15723 .5322 L
.15952 .50788 L
.16467 .43555 L
.16925 .3609 L
.17166 .32581 L
.17423 .29641 L
.17646 .27837 L
.17774 .27107 L
.17893 .26597 L
.18002 .26263 L
.18102 .26055 L
.18212 .25921 L
.18328 .25873 L
.18452 .25914 L
.18521 .25973 L
.18585 .26048 L
.18703 .26232 L
.18828 .26483 L
.19283 .27754 L
.20302 .31589 L
.22139 .3852 L
.22623 .39998 L
.23083 .41154 L
.23336 .41653 L
.2347 .41868 L
Mistroke
.23612 .42053 L
.23744 .42179 L
.23864 .4225 L
.23984 .42277 L
.24096 .42255 L
.24203 .42187 L
.2432 .42055 L
.24442 .41845 L
.24555 .41576 L
.24759 .40895 L
.24873 .40391 L
.24977 .39855 L
.25465 .36462 L
.25928 .32795 L
.26427 .29445 L
.26896 .27086 L
.27384 .25346 L
.27643 .24681 L
.27923 .2414 L
.28147 .23822 L
.28274 .23684 L
.28392 .23581 L
.28517 .23496 L
.2863 .23439 L
.28761 .23396 L
.28885 .23375 L
.28992 .23373 L
.29105 .23384 L
.29202 .23404 L
.29308 .23437 L
.29422 .23484 L
.29545 .23546 L
.29766 .23686 L
.30293 .24136 L
.30782 .2465 L
.31887 .25946 L
.32924 .27099 L
.33899 .27992 L
.34795 .28608 L
.353 .28867 L
.35763 .29056 L
.36242 .29207 L
.36766 .2933 L
.37313 .29424 L
.37822 .29489 L
.39693 .29674 L
.41723 .2995 L
.43856 .30332 L
.4587 .30673 L
.47855 .30932 L
Mistroke
.49959 .31135 L
.53744 .31422 L
.57775 .31679 L
.61654 .31868 L
.65779 .32018 L
.69751 .32125 L
.73573 .322 L
.75706 .32232 L
.77639 .32256 L
.81554 .32294 L
.85563 .32321 L
.8942 .3234 L
.93522 .32355 L
.97473 .32367 L
.97619 .32367 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.06244 .2387 L
.08255 .3644 L
.10458 .48509 L
.11448 .53047 L
.11992 .55202 L
.12507 .56952 L
.12986 .58268 L
.13256 .58847 L
.13385 .59075 L
.13506 .59258 L
.13616 .59396 L
.13716 .59498 L
.13827 .59581 L
.13947 .59633 L
.14062 .59645 L
.14187 .5961 L
.14305 .5953 L
.14415 .59409 L
.14544 .59207 L
.1468 .58916 L
.14796 .58599 L
.14923 .58171 L
.15207 .56873 L
.15472 .5516 L
.15723 .5301 L
.15952 .50549 L
.16467 .4329 L
.16925 .35897 L
.17166 .32453 L
.17299 .3086 L
.17423 .29586 L
.17646 .27842 L
.17765 .27187 L
.17893 .26667 L
.18004 .26358 L
.1812 .26154 L
.18219 .26067 L
.18328 .26052 L
.1846 .26129 L
.18582 .26281 L
.18645 .26387 L
.18715 .26522 L
.18857 .26847 L
.19356 .2841 L
.20289 .32216 L
.22384 .41094 L
.23382 .44598 L
.23873 .46015 L
.24329 .47078 L
Mistroke
.24582 .47537 L
.24711 .47728 L
.24851 .47898 L
.24932 .47977 L
.25005 .48037 L
.25076 .48082 L
.2515 .48117 L
.25279 .48145 L
.25352 .48142 L
.25421 .48127 L
.2555 .48064 L
.25673 .47966 L
.25783 .47846 L
.25902 .47686 L
.26418 .46709 L
.28361 .42003 L
.28893 .40948 L
.29466 .40021 L
.30006 .39346 L
.30502 .38888 L
.30731 .38722 L
.30976 .38574 L
.31418 .38373 L
.31688 .38287 L
.31942 .38226 L
.32171 .38185 L
.32299 .38168 L
.32418 .38154 L
.32661 .38134 L
.3279 .38126 L
.32928 .38119 L
.33073 .38114 L
.3321 .3811 L
.33467 .38105 L
.33692 .38101 L
.3393 .38095 L
.34054 .38091 L
.34191 .38086 L
.34434 .38073 L
.34668 .38055 L
.34924 .3803 L
.35192 .37995 L
.35441 .37954 L
.35888 .37862 L
.36366 .37737 L
.37458 .37361 L
.38451 .36953 L
.40528 .3611 L
.41441 .358 L
.42446 .35514 L
Mistroke
.44312 .35107 L
.46289 .3477 L
.5032 .34161 L
.54199 .33674 L
.58323 .33279 L
.62296 .32967 L
.66117 .32715 L
.70184 .32485 L
.74099 .32289 L
.78259 .32098 L
.82268 .31926 L
.86125 .31768 L
.90227 .31606 L
.94178 .31455 L
.97619 .31328 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.06244 .23862 L
.08255 .36432 L
.10458 .48506 L
.11448 .53051 L
.11992 .55212 L
.12507 .56969 L
.12986 .58296 L
.13256 .58884 L
.13506 .59304 L
.13607 .59436 L
.13716 .59553 L
.13835 .59647 L
.13947 .59702 L
.14073 .59721 L
.14192 .59694 L
.14299 .59631 L
.14415 .59515 L
.1448 .59429 L
.14548 .59319 L
.1467 .59074 L
.14802 .58733 L
.14946 .58259 L
.15205 .57111 L
.15447 .5564 L
.15683 .53768 L
.15898 .51641 L
.16382 .4535 L
.16898 .37252 L
.1717 .33351 L
.1732 .31551 L
.17459 .30127 L
.17591 .29034 L
.17711 .28234 L
.17845 .27555 L
.17915 .2728 L
.17989 .27046 L
.18111 .26774 L
.18224 .26634 L
.18347 .26586 L
.18417 .26603 L
.1848 .26643 L
.18599 .26774 L
.18711 .26955 L
.18965 .27541 L
.19212 .28288 L
.19478 .29229 L
.20398 .33068 L
.22478 .41975 L
.23491 .45581 L
Mistroke
.24026 .47156 L
.24319 .47895 L
.24595 .48491 L
.24859 .48957 L
.24997 .49156 L
.25143 .49327 L
.25266 .49439 L
.25331 .49486 L
.25401 .49526 L
.25524 .49571 L
.25638 .49584 L
.25763 .49566 L
.25834 .49541 L
.25899 .49509 L
.26018 .4943 L
.26145 .49317 L
.26364 .49061 L
.26606 .48705 L
.2763 .46732 L
.28707 .44592 L
.29627 .43133 L
.30147 .42505 L
.30631 .42047 L
.31137 .41687 L
.31614 .41442 L
.32042 .41287 L
.32283 .41221 L
.32505 .41172 L
.32969 .41098 L
.33232 .41068 L
.33477 .41045 L
.34505 .40962 L
.35005 .40909 L
.35549 .40827 L
.36062 .40722 L
.36538 .40599 L
.38393 .39939 L
.40416 .39114 L
.42316 .38472 L
.4413 .38024 L
.46088 .37656 L
.50199 .37009 L
.54158 .36497 L
.57966 .36123 L
.62018 .35807 L
.6592 .35561 L
.70066 .35348 L
.74061 .35177 L
.77905 .35033 L
.81993 .34897 L
Mistroke
.8593 .34775 L
.89716 .34665 L
.93747 .34553 L
.97619 .34451 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.06244 .23824 L
.08255 .36395 L
.10458 .48499 L
.11448 .53076 L
.11992 .55265 L
.12507 .57062 L
.12986 .58441 L
.13238 .59031 L
.13506 .59535 L
.13731 .59849 L
.13859 .59978 L
.13979 .60063 L
.14089 .60109 L
.14189 .60121 L
.14305 .601 L
.14415 .60041 L
.1454 .59925 L
.1461 .59836 L
.14674 .59738 L
.1479 .59521 L
.14918 .59216 L
.1514 .58511 L
.15374 .57493 L
.15629 .56022 L
.15902 .53979 L
.16396 .49019 L
.16859 .43262 L
.17351 .37384 L
.17553 .3545 L
.17771 .33802 L
.17896 .33068 L
.1801 .32522 L
.18119 .32109 L
.18234 .3178 L
.18356 .31538 L
.18486 .31388 L
.18609 .31337 L
.1872 .31358 L
.18852 .31453 L
.18925 .31536 L
.18994 .3163 L
.19252 .32114 L
.19508 .32751 L
.19789 .33583 L
.20358 .35533 L
.22371 .43238 L
.23368 .46793 L
.24315 .49673 L
.24838 .50958 L
Mistroke
.25113 .51523 L
.25407 .5202 L
.25547 .52215 L
.25679 .52372 L
.25807 .52498 L
.25925 .5259 L
.26037 .52656 L
.26155 .52703 L
.26274 .52727 L
.26405 .52727 L
.26536 .52699 L
.26657 .52651 L
.2672 .52617 L
.26789 .52574 L
.2693 .52467 L
.27187 .52213 L
.27428 .51918 L
.28359 .50485 L
.2938 .48881 L
.29936 .48139 L
.30452 .47561 L
.30959 .471 L
.31419 .46766 L
.31929 .46479 L
.32474 .46257 L
.32932 .46124 L
.33173 .4607 L
.33428 .46022 L
.33895 .45955 L
.34326 .45908 L
.35272 .45818 L
.35793 .45757 L
.36288 .45683 L
.37246 .45481 L
.3812 .45231 L
.4195 .43879 L
.43925 .43341 L
.46025 .42931 L
.49797 .42375 L
.53814 .41888 L
.57679 .41537 L
.6179 .41257 L
.65749 .41047 L
.69557 .40891 L
.7361 .40761 L
.77511 .40659 L
.81658 .40568 L
.85653 .40492 L
.89496 .40426 L
.93585 .40361 L
Mistroke
.97522 .40302 L
.97619 .40301 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.06244 .23868 L
.08255 .36437 L
.10458 .48506 L
.11448 .53046 L
.11992 .55202 L
.12507 .56953 L
.12986 .58271 L
.13256 .58852 L
.13385 .59081 L
.13506 .59264 L
.13616 .59403 L
.13716 .59505 L
.13827 .5959 L
.13947 .59643 L
.14062 .59655 L
.14187 .59622 L
.14305 .59542 L
.14415 .59422 L
.14544 .5922 L
.1468 .5893 L
.14796 .58613 L
.14923 .58185 L
.15207 .56884 L
.15472 .55163 L
.15723 .52995 L
.15952 .50503 L
.16467 .43102 L
.16925 .35523 L
.17166 .32003 L
.17299 .30383 L
.17423 .29091 L
.17646 .27331 L
.17765 .2667 L
.17893 .26146 L
.18004 .25832 L
.1812 .25623 L
.18219 .25531 L
.18328 .25508 L
.1846 .25576 L
.18582 .25716 L
.18645 .25816 L
.18715 .25943 L
.18857 .26253 L
.19356 .27744 L
.20289 .31338 L
.21384 .35705 L
.22384 .39209 L
.22862 .40573 L
.23114 .41177 L
Mistroke
.23382 .41707 L
.23515 .41918 L
.2364 .4208 L
.23752 .42193 L
.23873 .42276 L
.23989 .42312 L
.24111 .423 L
.24215 .42244 L
.24329 .42129 L
.24396 .42033 L
.24469 .41901 L
.24602 .41588 L
.24732 .41181 L
.24851 .4071 L
.25122 .3929 L
.2541 .37321 L
.25936 .33308 L
.26418 .30128 L
.26876 .27793 L
.27358 .25995 L
.27608 .25294 L
.27841 .2477 L
.28097 .24322 L
.28239 .24125 L
.28369 .23974 L
.28482 .23865 L
.28606 .23768 L
.28731 .23692 L
.28863 .23633 L
.28979 .23599 L
.29103 .23579 L
.29221 .23575 L
.29328 .23584 L
.29439 .23603 L
.29542 .23631 L
.29655 .2367 L
.29775 .23722 L
.30199 .23975 L
.30686 .24368 L
.31134 .24786 L
.32143 .25793 L
.33026 .26609 L
.3397 .27311 L
.34483 .27602 L
.34949 .27813 L
.35418 .27975 L
.3586 .28087 L
.36111 .28135 L
.36377 .28177 L
.36603 .28204 L
Mistroke
.36853 .28228 L
.37121 .28248 L
.37409 .28263 L
.37681 .28274 L
.3793 .28281 L
.38403 .28293 L
.38849 .28305 L
.39096 .28314 L
.39364 .28325 L
.3983 .28351 L
.4039 .28393 L
.40905 .28445 L
.41902 .28572 L
.43946 .28896 L
.45853 .29184 L
.47687 .29402 L
.49652 .29578 L
.5379 .29882 L
.57777 .30141 L
.61612 .30339 L
.65692 .30503 L
.69621 .30624 L
.73398 .3071 L
.7742 .30777 L
.81291 .30823 L
.83296 .30841 L
.85407 .30857 L
.8922 .3088 L
.93278 .30897 L
.97184 .30909 L
.97619 .3091 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.06244 .23871 L
.08255 .36441 L
.10458 .48508 L
.11448 .53044 L
.11992 .55198 L
.12507 .56945 L
.12986 .58258 L
.13256 .58835 L
.13385 .59062 L
.13506 .59243 L
.13616 .59379 L
.13716 .59479 L
.13827 .5956 L
.13947 .5961 L
.14062 .59619 L
.14187 .59581 L
.14305 .59496 L
.14415 .59372 L
.14544 .59164 L
.1468 .58866 L
.14796 .58541 L
.14923 .58104 L
.15207 .56776 L
.15472 .55023 L
.15723 .52816 L
.15952 .50281 L
.16467 .42773 L
.16925 .35143 L
.17166 .31635 L
.17299 .30032 L
.17423 .28762 L
.1754 .27777 L
.17646 .27046 L
.17765 .2641 L
.17893 .25912 L
.17994 .25641 L
.18105 .25451 L
.18221 .25357 L
.18328 .25353 L
.18456 .25436 L
.1852 .2551 L
.18591 .25612 L
.18833 .26109 L
.19116 .26904 L
.1938 .27793 L
.20374 .31716 L
.22233 .38934 L
.22731 .40504 L
.22993 .41228 L
Mistroke
.23273 .41897 L
.23542 .42421 L
.23669 .42619 L
.23786 .4277 L
.23904 .42887 L
.24031 .42972 L
.24143 .43004 L
.24261 .42992 L
.24377 .42929 L
.24482 .42822 L
.24604 .42634 L
.24719 .42388 L
.24924 .41769 L
.25146 .40822 L
.2565 .3782 L
.26115 .34762 L
.2658 .32075 L
.2708 .29745 L
.27553 .28063 L
.27985 .26923 L
.28234 .26421 L
.28466 .26046 L
.28719 .25725 L
.2899 .25478 L
.29127 .25386 L
.29275 .2531 L
.29343 .25282 L
.29415 .25258 L
.29544 .25227 L
.29668 .2521 L
.29784 .25206 L
.29911 .25213 L
.29982 .25221 L
.30047 .25232 L
.30164 .25258 L
.30275 .2529 L
.30527 .25385 L
.31037 .25654 L
.31953 .26272 L
.32964 .26956 L
.33515 .27269 L
.34028 .27505 L
.34493 .27666 L
.34754 .27736 L
.34991 .27785 L
.3525 .27826 L
.35397 .27844 L
.35532 .27856 L
.3565 .27864 L
.35781 .2787 L
Mistroke
.35846 .27872 L
.35917 .27874 L
.36044 .27874 L
.36167 .27873 L
.36281 .2787 L
.36406 .27865 L
.36539 .27857 L
.36786 .27839 L
.3701 .27819 L
.37894 .27716 L
.38831 .27608 L
.39302 .27566 L
.3957 .27547 L
.3982 .27534 L
.39961 .27528 L
.40094 .27523 L
.40214 .2752 L
.40344 .27518 L
.40411 .27517 L
.40485 .27516 L
.40562 .27516 L
.40635 .27516 L
.40765 .27517 L
.40838 .27517 L
.40905 .27518 L
.41025 .27521 L
.41137 .27524 L
.41391 .27533 L
.41638 .27545 L
.41902 .27561 L
.42928 .27643 L
.44039 .27753 L
.46054 .27945 L
.48043 .28086 L
.50148 .28198 L
.53939 .28394 L
.57975 .28605 L
.61859 .28775 L
.65989 .2892 L
.69967 .29029 L
.73793 .29105 L
.75766 .29136 L
.77865 .29162 L
.79868 .29182 L
.82031 .292 L
.84123 .29212 L
.86044 .29221 L
.87932 .29228 L
.89015 .2923 L
.9 .29233 L
Mistroke
.90938 .29234 L
.91957 .29236 L
.93033 .29237 L
.9405 .29238 L
.94874 .29238 L
.95343 .29238 L
.95782 .29238 L
.96019 .29238 L
.96244 .29238 L
.96449 .29238 L
.96667 .29238 L
.96791 .29239 L
.96903 .29239 L
.97017 .29239 L
.97122 .29239 L
.97245 .29239 L
.9731 .29239 L
.97378 .29239 L
.97493 .29239 L
.97619 .29239 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.06244 .23834 L
.08255 .36404 L
.10458 .485 L
.11448 .53069 L
.11992 .55251 L
.12507 .57037 L
.12986 .58403 L
.13238 .58983 L
.13506 .59474 L
.13614 .59633 L
.13731 .59775 L
.13859 .59896 L
.13979 .59972 L
.14096 .60009 L
.14207 .60009 L
.14306 .59978 L
.14415 .59906 L
.1448 .59845 L
.14548 .59764 L
.1467 .59574 L
.14802 .59303 L
.14946 .58917 L
.15205 .57969 L
.15447 .56747 L
.15683 .55192 L
.15898 .53433 L
.16382 .48251 L
.16911 .41263 L
.172 .37568 L
.17472 .34665 L
.17702 .32791 L
.17832 .31986 L
.17951 .31399 L
.18074 .30932 L
.18209 .30571 L
.18276 .30443 L
.18349 .30342 L
.1848 .30248 L
.18608 .30251 L
.18727 .30327 L
.18856 .30479 L
.18994 .30709 L
.19225 .31221 L
.1948 .31927 L
.20388 .3513 L
.22464 .43311 L
.23462 .46844 L
.24409 .49639 L
.24931 .50842 L
Mistroke
.25207 .5135 L
.25358 .51584 L
.25501 .51773 L
.25631 .51919 L
.25772 .52044 L
.25901 .52129 L
.26018 .52182 L
.2613 .5221 L
.26252 .52217 L
.26379 .52198 L
.26498 .52157 L
.26625 .5209 L
.26759 .51995 L
.27 .51769 L
.27546 .51054 L
.28537 .49429 L
.29507 .47926 L
.30394 .46853 L
.30852 .46429 L
.31334 .46071 L
.31817 .45795 L
.32345 .45573 L
.32804 .45435 L
.33061 .45376 L
.33294 .45332 L
.33747 .45265 L
.34175 .45217 L
.35149 .45123 L
.35682 .4506 L
.3618 .44984 L
.3706 .44799 L
.38026 .4452 L
.41914 .43129 L
.44036 .42559 L
.46047 .42173 L
.49877 .41605 L
.53952 .41108 L
.57875 .40753 L
.61647 .40492 L
.65664 .40275 L
.6953 .40112 L
.7364 .39975 L
.77599 .39867 L
.81407 .3978 L
.8546 .39698 L
.89361 .39627 L
.93508 .39556 L
.97503 .39492 L
.97619 .3949 L
Mfstroke
.174 1 0 r
.02381 .01472 m
.06244 .23815 L
.08255 .36387 L
.10458 .48498 L
.11448 .53082 L
.11992 .55277 L
.12507 .57081 L
.12986 .58471 L
.13238 .59068 L
.13506 .59581 L
.13731 .59905 L
.13859 .6004 L
.13979 .60132 L
.14089 .60184 L
.14189 .60204 L
.14305 .60191 L
.14415 .60141 L
.1454 .60037 L
.1461 .59955 L
.14674 .59864 L
.14793 .59655 L
.14918 .59373 L
.15135 .58719 L
.15374 .57733 L
.15629 .56328 L
.15902 .54375 L
.16396 .49628 L
.16859 .44082 L
.17351 .38308 L
.17553 .36361 L
.17771 .34668 L
.17896 .33899 L
.1801 .33317 L
.18119 .32871 L
.18234 .32499 L
.18357 .32214 L
.18471 .3204 L
.18541 .31973 L
.18607 .31934 L
.1873 .31922 L
.1886 .31984 L
.1898 .32101 L
.19112 .32287 L
.19252 .32539 L
.19779 .33877 L
.20358 .35784 L
.22371 .43376 L
.23368 .46923 L
.24315 .49815 L
.24838 .51116 L
Mistroke
.25113 .51694 L
.25407 .52208 L
.25679 .52579 L
.25807 .52716 L
.25925 .52818 L
.26044 .52899 L
.26172 .52959 L
.26285 .5299 L
.26405 .53 L
.26527 .52986 L
.26596 .52968 L
.2666 .52946 L
.26777 .52888 L
.26902 .52807 L
.27117 .52622 L
.27355 .5236 L
.28372 .50846 L
.29267 .49428 L
.30207 .48192 L
.30691 .47694 L
.31219 .47255 L
.31699 .46943 L
.32145 .46719 L
.32675 .46523 L
.33155 .46396 L
.33421 .46343 L
.3371 .46296 L
.34232 .4623 L
.35262 .46126 L
.36224 .46 L
.36708 .45911 L
.37227 .45794 L
.3833 .45473 L
.40308 .44759 L
.42462 .44028 L
.4453 .4351 L
.46444 .43162 L
.50367 .42599 L
.54139 .42154 L
.58156 .41803 L
.62022 .41548 L
.66132 .41339 L
.70092 .41186 L
.73899 .4107 L
.77952 .40972 L
.81853 .40893 L
.86 .40821 L
.89995 .40758 L
.93838 .40703 L
.97619 .40651 L
Mistroke
Mfstroke
.15 1 0 r
.02381 .01472 m
.06244 .23806 L
.08255 .3638 L
.10458 .48497 L
.11448 .53088 L
.11992 .55289 L
.12507 .57101 L
.12986 .585 L
.13238 .59104 L
.13506 .59626 L
.13731 .59959 L
.13859 .601 L
.13979 .60198 L
.14089 .60257 L
.14189 .60283 L
.14305 .60279 L
.14415 .60237 L
.1454 .60145 L
.1461 .6007 L
.14674 .59985 L
.14793 .5979 L
.14918 .59524 L
.15135 .58903 L
.15374 .57964 L
.15629 .56622 L
.15902 .54755 L
.16396 .50215 L
.16859 .44879 L
.17351 .39217 L
.17553 .3726 L
.17771 .35528 L
.17896 .34726 L
.1801 .34111 L
.18119 .3363 L
.18234 .3322 L
.18357 .32895 L
.18471 .32684 L
.18541 .32595 L
.18607 .32536 L
.1873 .32486 L
.1886 .32512 L
.1898 .32597 L
.19112 .3275 L
.19252 .32971 L
.19524 .33542 L
.19779 .34209 L
.20358 .36037 L
.22371 .43512 L
.23411 .47192 L
.24399 .50179 L
Mistroke
.24829 .51249 L
.25286 .52184 L
.25549 .52606 L
.25788 .52905 L
.25903 .53018 L
.26028 .53117 L
.26145 .53187 L
.26253 .53232 L
.2638 .5326 L
.265 .53262 L
.26607 .53245 L
.26724 .53207 L
.26852 .53144 L
.26987 .53052 L
.27229 .52834 L
.27662 .52306 L
.28139 .51593 L
.29219 .49883 L
.30207 .4857 L
.31152 .47673 L
.31627 .47348 L
.32145 .47076 L
.32669 .46876 L
.32962 .46791 L
.33227 .46728 L
.33745 .46635 L
.34232 .46572 L
.35118 .46483 L
.36068 .4637 L
.36613 .46279 L
.3711 .46174 L
.38084 .4591 L
.40076 .45211 L
.42181 .4448 L
.44088 .43971 L
.46163 .43571 L
.50238 .42981 L
.54161 .42519 L
.57933 .42188 L
.6195 .41922 L
.65816 .41724 L
.69926 .41564 L
.73886 .41445 L
.77693 .41353 L
.81746 .41272 L
.85647 .41205 L
.89794 .41142 L
.93789 .41086 L
.97619 .41035 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.06244 .23874 L
.08255 .36443 L
.10458 .48509 L
.11448 .53044 L
.11992 .55195 L
.12507 .56941 L
.12986 .5825 L
.13256 .58825 L
.13385 .5905 L
.13506 .5923 L
.13616 .59365 L
.13716 .59464 L
.13827 .59544 L
.13947 .59592 L
.14062 .59598 L
.14187 .59558 L
.14305 .59471 L
.14415 .59344 L
.14544 .59133 L
.1468 .58831 L
.14796 .58502 L
.14923 .5806 L
.15207 .56721 L
.15472 .54954 L
.15723 .52733 L
.15952 .50185 L
.16467 .42659 L
.16925 .35034 L
.17166 .31532 L
.17299 .2993 L
.17423 .28662 L
.1754 .2768 L
.17646 .2695 L
.17765 .26318 L
.17893 .25825 L
.17994 .25559 L
.18105 .25376 L
.18221 .2529 L
.18328 .25294 L
.18456 .25388 L
.1852 .25467 L
.18591 .25577 L
.18833 .26099 L
.19116 .2693 L
.1938 .27859 L
.20374 .32004 L
.22233 .39976 L
.23273 .43681 L
.23786 .45148 L
Mistroke
.24036 .45745 L
.24261 .46207 L
.24468 .46553 L
.24576 .46701 L
.24691 .46831 L
.24814 .46936 L
.24927 .46999 L
.25032 .47027 L
.25148 .47022 L
.25275 .46972 L
.2539 .46886 L
.25454 .46821 L
.25523 .46738 L
.25649 .46554 L
.25891 .4609 L
.26115 .45563 L
.27092 .42785 L
.28144 .39922 L
.28628 .38838 L
.29138 .37893 L
.29614 .3719 L
.30047 .36697 L
.305 .36312 L
.30749 .36152 L
.30983 .36029 L
.31187 .35942 L
.31401 .35869 L
.31637 .35807 L
.31854 .35765 L
.32088 .35732 L
.3222 .35718 L
.3234 .35708 L
.32451 .35701 L
.32573 .35695 L
.32688 .35691 L
.32794 .35687 L
.33291 .35679 L
.33427 .35677 L
.33571 .35674 L
.33693 .35671 L
.33827 .35666 L
.33953 .3566 L
.34068 .35654 L
.34325 .35635 L
.34563 .3561 L
.34788 .3558 L
.35221 .35502 L
.35691 .35388 L
.36762 .35018 L
.37751 .34582 L
Mistroke
.39784 .33638 L
.41688 .3293 L
.43512 .32453 L
.45473 .32065 L
.49598 .31349 L
.5357 .30763 L
.57392 .30325 L
.61458 .29937 L
.65373 .29617 L
.69533 .29322 L
.73542 .29067 L
.77399 .2884 L
.81502 .28611 L
.85452 .284 L
.89251 .28203 L
.93296 .28 L
.97189 .27812 L
.97619 .27792 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.06244 .23859 L
.08255 .36427 L
.10458 .48504 L
.11448 .53052 L
.11992 .55215 L
.12507 .56977 L
.12986 .58308 L
.13256 .58899 L
.13506 .59324 L
.13607 .59458 L
.13716 .59577 L
.13835 .59674 L
.13947 .59731 L
.14073 .59754 L
.14192 .59731 L
.14299 .59672 L
.14415 .59561 L
.1448 .59477 L
.14548 .59371 L
.1467 .59132 L
.14802 .58799 L
.14946 .58334 L
.15205 .57208 L
.15447 .55763 L
.15683 .53922 L
.15898 .51829 L
.16382 .45623 L
.16911 .37385 L
.172 .33271 L
.17342 .31583 L
.17472 .30267 L
.17702 .2849 L
.17823 .27828 L
.17951 .27312 L
.18082 .26955 L
.18203 .26759 L
.18273 .267 L
.18337 .26676 L
.1841 .26681 L
.1848 .26716 L
.1859 .26824 L
.18711 .2701 L
.18838 .27269 L
.18956 .27561 L
.19395 .28966 L
.20388 .3311 L
.22464 .42123 L
.23505 .45883 L
.24018 .47431 L
Mistroke
.24493 .48632 L
.24923 .49473 L
.25163 .49818 L
.25268 .49938 L
.2538 .50041 L
.25505 .50129 L
.25619 .50181 L
.25743 .50209 L
.25813 .50211 L
.25878 .50204 L
.25996 .50171 L
.26104 .50118 L
.26229 .50033 L
.26347 .4993 L
.26584 .49663 L
.26807 .49353 L
.27315 .48498 L
.28342 .46544 L
.29222 .45023 L
.30185 .43757 L
.30696 .43267 L
.31171 .42917 L
.31672 .42641 L
.31953 .42523 L
.32207 .42435 L
.32665 .42315 L
.32923 .42265 L
.3316 .42226 L
.34059 .42122 L
.34966 .42022 L
.35475 .41945 L
.35939 .41854 L
.37007 .41566 L
.38004 .41208 L
.40072 .40359 L
.41986 .39663 L
.43842 .39159 L
.45815 .3876 L
.49587 .38145 L
.53604 .37599 L
.5747 .37204 L
.61581 .36879 L
.6554 .36632 L
.69347 .36443 L
.734 .3628 L
.77302 .36149 L
.81448 .36028 L
.85443 .35925 L
.89286 .35832 L
.93375 .3574 L
Mistroke
.97312 .35657 L
.97619 .3565 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.06244 .23843 L
.08255 .36412 L
.10458 .48501 L
.11448 .53062 L
.11992 .55238 L
.12507 .57016 L
.12986 .58369 L
.13238 .58941 L
.13506 .59422 L
.13614 .59575 L
.13731 .59711 L
.13859 .59824 L
.13979 .59892 L
.14096 .59921 L
.14207 .59912 L
.14306 .5987 L
.14415 .59788 L
.1448 .59719 L
.14548 .59629 L
.1467 .59423 L
.14802 .59131 L
.14946 .58719 L
.15205 .57713 L
.15447 .56417 L
.15683 .5477 L
.15898 .52903 L
.16382 .47393 L
.16911 .39999 L
.172 .36157 L
.17472 .33212 L
.17702 .31366 L
.17832 .30595 L
.17951 .30048 L
.18074 .29628 L
.18144 .2945 L
.18209 .29322 L
.1834 .29159 L
.18413 .29119 L
.1848 .29112 L
.18599 .29161 L
.18725 .2929 L
.18832 .29453 L
.18951 .29682 L
.19215 .30342 L
.19461 .31102 L
.20388 .34606 L
.22464 .4304 L
.23505 .46739 L
.24018 .48315 L
Mistroke
.24493 .49585 L
.24958 .50602 L
.25161 .5096 L
.2538 .51281 L
.25506 .51431 L
.25621 .51545 L
.25732 .51633 L
.25848 .51703 L
.25971 .5175 L
.26086 .5177 L
.26212 .51766 L
.26282 .51752 L
.26347 .51733 L
.26465 .5168 L
.26576 .51611 L
.26829 .51393 L
.27075 .51111 L
.27341 .50747 L
.28259 .49233 L
.29252 .4761 L
.29777 .46883 L
.30336 .46235 L
.30882 .45733 L
.31377 .45379 L
.31875 .4511 L
.32344 .44924 L
.32601 .44845 L
.32872 .44776 L
.33358 .44684 L
.33628 .44645 L
.33881 .44615 L
.34456 .44557 L
.34955 .44508 L
.35499 .44445 L
.36013 .44367 L
.36488 .44276 L
.37387 .44048 L
.38343 .43736 L
.42115 .42366 L
.44047 .41857 L
.46132 .41458 L
.50243 .40846 L
.54202 .40365 L
.5801 .40021 L
.62063 .3974 L
.65964 .39528 L
.7011 .39354 L
.74105 .39221 L
.77949 .39115 L
.82037 .39019 L
Mistroke
.85975 .38937 L
.8976 .38865 L
.93791 .38794 L
.97619 .38729 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.06244 .23819 L
.08255 .36392 L
.10458 .48499 L
.11448 .53079 L
.11992 .5527 L
.12507 .5707 L
.12986 .58453 L
.13238 .59046 L
.13506 .59553 L
.13731 .59871 L
.13859 .60002 L
.13979 .6009 L
.14089 .60138 L
.14189 .60154 L
.14305 .60135 L
.14415 .60079 L
.1454 .59968 L
.1461 .59882 L
.14674 .59786 L
.1479 .59573 L
.14918 .59275 L
.1514 .58583 L
.15374 .57581 L
.15629 .56133 L
.15902 .5412 L
.16396 .49231 L
.16859 .43538 L
.17351 .37688 L
.17553 .35752 L
.17771 .34096 L
.17896 .33354 L
.1801 .32802 L
.18119 .32381 L
.18234 .32042 L
.18356 .3179 L
.18486 .31627 L
.18609 .31563 L
.1872 .3157 L
.18852 .31648 L
.18925 .31721 L
.18994 .31805 L
.19252 .32244 L
.19508 .32829 L
.19789 .33592 L
.20358 .35364 L
.2141 .38928 L
.22371 .42095 L
.23301 .4476 L
.23556 .45369 L
Mistroke
.23827 .45935 L
.24062 .46339 L
.24185 .46514 L
.24315 .46665 L
.24387 .46733 L
.24466 .46793 L
.24538 .46834 L
.24605 .46859 L
.24737 .4687 L
.24811 .46852 L
.24878 .46819 L
.25003 .46713 L
.25074 .46626 L
.25139 .46527 L
.2526 .46298 L
.25387 .45987 L
.25637 .45181 L
.25871 .44223 L
.26405 .41645 L
.2739 .37081 L
.27886 .35314 L
.28169 .34494 L
.28427 .33869 L
.28891 .33011 L
.29146 .32675 L
.29387 .32438 L
.29495 .32354 L
.2961 .32279 L
.29709 .32226 L
.29815 .32181 L
.29929 .32145 L
.30036 .32122 L
.30163 .32107 L
.30279 .32106 L
.30396 .32114 L
.30506 .32131 L
.30628 .3216 L
.30758 .322 L
.31024 .32311 L
.31268 .32443 L
.32185 .33104 L
.33259 .34022 L
.3426 .34831 L
.3525 .35485 L
.3615 .35918 L
.36664 .36098 L
.3715 .36229 L
.37663 .36331 L
.38219 .3641 L
.38707 .3646 L
Mistroke
.39164 .36497 L
.40204 .36566 L
.41283 .36648 L
.42308 .36754 L
.44334 .37027 L
.46187 .37288 L
.48191 .37519 L
.50008 .37673 L
.51977 .37801 L
.54075 .37917 L
.58083 .38107 L
.6194 .38242 L
.63936 .38295 L
.66043 .38341 L
.69842 .38405 L
.71794 .38429 L
.73886 .38449 L
.76012 .38465 L
.78024 .38477 L
.80017 .38486 L
.81859 .38492 L
.83727 .38497 L
.85788 .38501 L
.87724 .38504 L
.88721 .38505 L
.8981 .38506 L
.91816 .38507 L
.92909 .38508 L
.93926 .38508 L
.94922 .38509 L
.95862 .38509 L
.97619 .38509 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.06244 .2384 L
.08255 .3641 L
.10458 .485 L
.11448 .53063 L
.11992 .55241 L
.12507 .57021 L
.12986 .58378 L
.13238 .58952 L
.13506 .59435 L
.13614 .5959 L
.13731 .59727 L
.13859 .59842 L
.13979 .59912 L
.14096 .59943 L
.14207 .59935 L
.14306 .59896 L
.14415 .59816 L
.1448 .59749 L
.14548 .59661 L
.1467 .59458 L
.14802 .59171 L
.14946 .58764 L
.15205 .57768 L
.15447 .56485 L
.15683 .54851 L
.15898 .52998 L
.16382 .47524 L
.16911 .40169 L
.172 .36353 L
.17472 .3343 L
.17702 .31597 L
.17832 .30829 L
.17951 .3028 L
.18074 .29855 L
.18144 .29672 L
.18209 .29538 L
.1834 .29361 L
.18413 .29312 L
.1848 .29295 L
.18599 .29325 L
.18725 .2943 L
.18832 .2957 L
.18951 .29772 L
.19215 .30362 L
.19461 .31046 L
.20388 .34186 L
.21453 .3804 L
.22464 .41401 L
.22934 .42752 L
Mistroke
.23435 .43954 L
.23723 .44491 L
.23859 .44695 L
.23984 .44848 L
.2411 .44966 L
.24176 .45012 L
.24246 .45047 L
.24364 .45072 L
.24493 .45047 L
.24618 .44963 L
.24735 .44825 L
.24841 .44647 L
.24956 .44393 L
.25081 .44041 L
.25214 .4358 L
.25452 .42546 L
.26347 .37591 L
.26805 .35239 L
.27286 .33185 L
.27539 .32295 L
.27814 .3147 L
.28068 .30842 L
.28298 .30374 L
.28518 .3001 L
.28756 .29703 L
.28888 .2957 L
.29008 .29468 L
.29131 .29383 L
.29246 .29321 L
.29344 .2928 L
.2945 .29247 L
.29567 .29225 L
.29674 .29216 L
.29785 .29217 L
.29907 .29231 L
.30021 .29255 L
.30127 .29286 L
.30368 .29383 L
.30589 .29503 L
.31088 .29854 L
.31991 .30666 L
.33057 .31705 L
.3405 .32585 L
.34964 .3324 L
.3594 .3375 L
.36498 .33957 L
.37024 .34105 L
.37497 .34205 L
.3801 .34287 L
.38498 .34346 L
Mistroke
.38954 .34392 L
.39995 .34483 L
.42098 .34717 L
.45977 .35311 L
.48092 .3557 L
.50102 .35747 L
.53923 .35993 L
.5799 .36202 L
.61905 .36348 L
.64047 .36409 L
.66065 .36456 L
.69922 .36525 L
.71917 .36551 L
.74024 .36573 L
.77823 .36602 L
.79776 .36613 L
.81868 .36621 L
.83993 .36628 L
.86006 .36633 L
.89841 .3664 L
.9182 .36643 L
.93921 .36645 L
.97619 .36648 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.06244 .23869 L
.08255 .36439 L
.10458 .48507 L
.11448 .53046 L
.11992 .55201 L
.12507 .56951 L
.12986 .58267 L
.13256 .58847 L
.13385 .59075 L
.13506 .59258 L
.13616 .59396 L
.13716 .59497 L
.13827 .59581 L
.13947 .59633 L
.14062 .59644 L
.14187 .5961 L
.14305 .59529 L
.14415 .59408 L
.14544 .59205 L
.1468 .58914 L
.14796 .58595 L
.14923 .58166 L
.15207 .56862 L
.15472 .55141 L
.15723 .52976 L
.15952 .50492 L
.16467 .43141 L
.16925 .35619 L
.17166 .3211 L
.17299 .30488 L
.17423 .29191 L
.17646 .27417 L
.17765 .26751 L
.17893 .26222 L
.18004 .25906 L
.1812 .25698 L
.18219 .25608 L
.18328 .2559 L
.1846 .25666 L
.18582 .25818 L
.18645 .25924 L
.18715 .26059 L
.18857 .26387 L
.19356 .27972 L
.20289 .31861 L
.22384 .40977 L
.23382 .44564 L
.23873 .46017 L
.24329 .47115 L
Mistroke
.24582 .47595 L
.24851 .47983 L
.24925 .48065 L
.25005 .4814 L
.25076 .48194 L
.2515 .48238 L
.25217 .48267 L
.25291 .48286 L
.25421 .48287 L
.25551 .48246 L
.2567 .48172 L
.25736 .48117 L
.25807 .48047 L
.25937 .47892 L
.26187 .47507 L
.26418 .47071 L
.27395 .44825 L
.28447 .42427 L
.28932 .41495 L
.29441 .4067 L
.29917 .40045 L
.3035 .39597 L
.30803 .39238 L
.31035 .39093 L
.31287 .38962 L
.3152 .38862 L
.31734 .38787 L
.32157 .38676 L
.32393 .38632 L
.32614 .386 L
.32856 .38573 L
.33116 .38549 L
.33608 .38514 L
.3413 .38475 L
.34381 .38451 L
.34658 .38419 L
.35146 .38343 L
.35716 .3822 L
.36252 .38068 L
.38263 .37263 L
.40109 .36439 L
.42129 .35708 L
.4413 .35196 L
.4624 .34781 L
.50292 .34081 L
.54194 .33524 L
.5834 .33069 L
.62335 .32714 L
.66179 .32429 L
.70267 .32175 L
Mistroke
.74204 .31963 L
.7799 .31781 L
.82021 .31602 L
.859 .31441 L
.90024 .31278 L
.93997 .31127 L
.97619 .30996 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.06244 .2385 L
.08255 .36419 L
.10458 .48502 L
.11448 .53058 L
.11992 .55228 L
.12507 .56999 L
.12986 .58343 L
.13238 .58909 L
.13506 .5938 L
.13614 .5953 L
.13731 .59661 L
.13859 .59767 L
.13979 .59829 L
.14096 .5985 L
.14207 .59833 L
.14306 .59784 L
.14415 .59692 L
.1448 .59617 L
.14548 .59521 L
.1467 .59301 L
.14802 .58992 L
.14946 .58558 L
.15205 .57502 L
.15447 .56144 L
.15683 .54415 L
.15898 .52455 L
.16382 .46656 L
.16911 .38906 L
.172 .34944 L
.17472 .31968 L
.17702 .30147 L
.17832 .29404 L
.17951 .28886 L
.18074 .28499 L
.18144 .28342 L
.18209 .28231 L
.1834 .28105 L
.18413 .28086 L
.1848 .28097 L
.18599 .28178 L
.18725 .28338 L
.18832 .28528 L
.18951 .28785 L
.19461 .30318 L
.20388 .34005 L
.22464 .42686 L
.23462 .4627 L
.24409 .49018 L
.24931 .50146 L
Mistroke
.25227 .50621 L
.25368 .50799 L
.25501 .50935 L
.25623 .51032 L
.25754 .51106 L
.25874 .51146 L
.25984 .51159 L
.26103 .51149 L
.26234 .51109 L
.263 .51079 L
.26371 .51038 L
.26498 .50947 L
.26755 .50695 L
.27028 .50349 L
.27518 .49583 L
.28626 .47626 L
.29596 .46118 L
.30105 .45485 L
.3064 .44944 L
.31126 .44559 L
.31658 .44242 L
.32141 .44032 L
.32591 .43893 L
.33055 .43791 L
.33476 .43725 L
.33962 .43668 L
.3442 .43623 L
.35395 .43512 L
.35886 .43434 L
.36425 .43324 L
.3738 .43064 L
.38272 .42758 L
.40133 .42032 L
.42159 .41319 L
.44281 .40774 L
.46292 .40397 L
.50367 .39781 L
.54291 .39297 L
.58062 .38949 L
.6208 .38662 L
.65945 .38445 L
.70056 .38264 L
.74015 .38125 L
.77823 .38014 L
.81875 .37912 L
.85777 .37824 L
.89923 .37739 L
.93918 .37663 L
.97619 .37595 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.06244 .23878 L
.08255 .36447 L
.10458 .4851 L
.11448 .53041 L
.11992 .55189 L
.12507 .5693 L
.12986 .58233 L
.13256 .58803 L
.13385 .59026 L
.13506 .59203 L
.13616 .59335 L
.13716 .59431 L
.13827 .59507 L
.13947 .5955 L
.14062 .59552 L
.14187 .59506 L
.14305 .59412 L
.14415 .59278 L
.14544 .59058 L
.1468 .58745 L
.14923 .57949 L
.15058 .57358 L
.15185 .56697 L
.15472 .54749 L
.15723 .52458 L
.15952 .49825 L
.16467 .42045 L
.16925 .34223 L
.17166 .30689 L
.17299 .29094 L
.17423 .27844 L
.1754 .26887 L
.17646 .26183 L
.17765 .25583 L
.17893 .25124 L
.17994 .24883 L
.18105 .24725 L
.18221 .24664 L
.18328 .24688 L
.18456 .24803 L
.1852 .24892 L
.18591 .25011 L
.18833 .25558 L
.19116 .26408 L
.1938 .27346 L
.20374 .31471 L
.22233 .39218 L
.22731 .4098 L
.23273 .42638 L
Mistroke
.23522 .4328 L
.23786 .43864 L
.24036 .44302 L
.24143 .44452 L
.24261 .44585 L
.24378 .44681 L
.24501 .44741 L
.24614 .44756 L
.24721 .4473 L
.24846 .44646 L
.2496 .44517 L
.25092 .44301 L
.25216 .44031 L
.2544 .43389 L
.25647 .42645 L
.26115 .40656 L
.27016 .36776 L
.27985 .3344 L
.28541 .32041 L
.29049 .3108 L
.29536 .30418 L
.2978 .3017 L
.30047 .29955 L
.30302 .29799 L
.30436 .29734 L
.30577 .29677 L
.30701 .29636 L
.30837 .296 L
.30961 .29575 L
.31077 .29558 L
.31198 .29545 L
.31313 .29537 L
.31416 .29534 L
.31528 .29534 L
.3165 .29537 L
.31779 .29544 L
.3189 .29552 L
.32012 .29563 L
.32544 .29626 L
.32835 .29663 L
.33105 .29693 L
.33337 .29713 L
.33466 .29722 L
.33584 .29728 L
.33713 .29732 L
.33786 .29733 L
.33854 .29733 L
.33977 .29731 L
.34108 .29726 L
.34228 .29719 L
Mistroke
.34337 .2971 L
.34583 .29681 L
.34811 .29644 L
.35028 .29598 L
.35512 .29466 L
.36041 .29276 L
.38125 .28283 L
.39224 .27767 L
.40259 .27363 L
.41188 .27079 L
.42192 .26846 L
.43184 .26671 L
.44231 .26522 L
.46107 .26289 L
.49906 .25835 L
.52022 .25625 L
.5395 .25473 L
.57843 .25239 L
.6183 .25047 L
.65665 .2489 L
.69745 .24742 L
.73674 .24605 L
.77451 .24474 L
.81473 .24335 L
.85344 .242 L
.8946 .24057 L
.93424 .23922 L
.97237 .23798 L
.97619 .23786 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.06244 .23847 L
.08255 .36416 L
.10458 .48501 L
.11448 .53059 L
.11992 .55231 L
.12507 .57004 L
.12986 .58352 L
.13238 .58919 L
.13506 .59394 L
.13614 .59545 L
.13731 .59678 L
.13859 .59786 L
.13979 .5985 L
.14096 .59874 L
.14207 .59859 L
.14306 .59812 L
.14415 .59723 L
.1448 .5965 L
.14548 .59556 L
.1467 .5934 L
.14802 .59036 L
.14946 .58608 L
.15205 .57565 L
.15447 .56223 L
.15683 .54514 L
.15898 .52574 L
.16382 .46832 L
.16911 .39155 L
.172 .35236 L
.17472 .32296 L
.17702 .30496 L
.17832 .29759 L
.17951 .29243 L
.18074 .28854 L
.18144 .28693 L
.18209 .28579 L
.1834 .28442 L
.18413 .28414 L
.1848 .28417 L
.18599 .28481 L
.18725 .28619 L
.18832 .28788 L
.18951 .29018 L
.19461 .30402 L
.20388 .33685 L
.21473 .37702 L
.22464 .41017 L
.22942 .42374 L
.23194 .42999 L
Mistroke
.23462 .43573 L
.2372 .44017 L
.23842 .44182 L
.23953 .44305 L
.24066 .44397 L
.24188 .44457 L
.24296 .44471 L
.24409 .44443 L
.24539 .4435 L
.24658 .44201 L
.24724 .44091 L
.24795 .43947 L
.24925 .43618 L
.25175 .42726 L
.25406 .41619 L
.26498 .35227 L
.26963 .32973 L
.27463 .31075 L
.27694 .30383 L
.27936 .29773 L
.28163 .29305 L
.28368 .2896 L
.28616 .28639 L
.28742 .28511 L
.28879 .28398 L
.29006 .28315 L
.29123 .28257 L
.29235 .28217 L
.29354 .28189 L
.29482 .28176 L
.29553 .28175 L
.29619 .28179 L
.29746 .28197 L
.29867 .28226 L
.30007 .28273 L
.30136 .28329 L
.3043 .28494 L
.30892 .28837 L
.31391 .29285 L
.32294 .30191 L
.33277 .31166 L
.34353 .32078 L
.34854 .32424 L
.3539 .32734 L
.35853 .32953 L
.36355 .33143 L
.36923 .33306 L
.3746 .33419 L
.37982 .335 L
.38464 .33558 L
Mistroke
.42401 .33986 L
.46187 .34571 L
.48129 .34802 L
.50218 .34983 L
.54342 .35246 L
.58315 .35449 L
.62136 .35591 L
.64269 .35652 L
.66203 .35698 L
.70118 .3577 L
.72044 .35797 L
.74126 .3582 L
.76082 .35837 L
.78229 .35852 L
.80272 .35863 L
.82179 .35872 L
.84044 .35878 L
.86072 .35884 L
.88198 .35888 L
.9021 .35891 L
.9215 .35894 L
.94291 .35896 L
.97619 .35899 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.06244 .23854 L
.08255 .36422 L
.10458 .48503 L
.11448 .53054 L
.11992 .55221 L
.12507 .56988 L
.12986 .58326 L
.13238 .58886 L
.13376 .59145 L
.13506 .59352 L
.13623 .5951 L
.13731 .59626 L
.1385 .59723 L
.13979 .59785 L
.14086 .59802 L
.14202 .59781 L
.14313 .59721 L
.14415 .59627 L
.14544 .59453 L
.1468 .59197 L
.14796 .58913 L
.14923 .58526 L
.15207 .57345 L
.15472 .55778 L
.15723 .53808 L
.15952 .51549 L
.16467 .44838 L
.16933 .37675 L
.1737 .31923 L
.17589 .29882 L
.17712 .29009 L
.17825 .28374 L
.17942 .2787 L
.1807 .27479 L
.18135 .2734 L
.18204 .27231 L
.18328 .27126 L
.18456 .27127 L
.18529 .27171 L
.18595 .27237 L
.18718 .27412 L
.18848 .27666 L
.19072 .28243 L
.19319 .29031 L
.20237 .32737 L
.22313 .41776 L
.2331 .45499 L
.24257 .48369 L
.2478 .49569 L
Mistroke
.25075 .50088 L
.25216 .50288 L
.25349 .50445 L
.25471 .50561 L
.25603 .50656 L
.25722 .50713 L
.25832 .50742 L
.25952 .50748 L
.26083 .50724 L
.26149 .50701 L
.26219 .50668 L
.26347 .50588 L
.26469 .50489 L
.26604 .50356 L
.26877 .50021 L
.27367 .49258 L
.28475 .47244 L
.29526 .45537 L
.29986 .44937 L
.30488 .44394 L
.30945 .43998 L
.31433 .4367 L
.31948 .43414 L
.32427 .43244 L
.32697 .4317 L
.3299 .43106 L
.33521 .43018 L
.34514 .42897 L
.35462 .42762 L
.36001 .42656 L
.36505 .42532 L
.37521 .42212 L
.38611 .41791 L
.40589 .4098 L
.42743 .40251 L
.44811 .39754 L
.46725 .39401 L
.50648 .38789 L
.5442 .38311 L
.58437 .37934 L
.62303 .37654 L
.66413 .37423 L
.70373 .37251 L
.7418 .3712 L
.78233 .37007 L
.82134 .36914 L
.86281 .36828 L
.90276 .36753 L
.94119 .36686 L
.97619 .36629 L
Mistroke
Mfstroke
0 1 .111 r
.02381 .01472 m
.06244 .23823 L
.08255 .36395 L
.10458 .48499 L
.11448 .53076 L
.11992 .55265 L
.12507 .57062 L
.12986 .58441 L
.13238 .59031 L
.13506 .59535 L
.13731 .59849 L
.13859 .59977 L
.13979 .60062 L
.14089 .60108 L
.14189 .60121 L
.14305 .60099 L
.14415 .60039 L
.1454 .59923 L
.1461 .59834 L
.14674 .59736 L
.1479 .59517 L
.14918 .59212 L
.1514 .58505 L
.15374 .57484 L
.15629 .56009 L
.15902 .53958 L
.16396 .48977 L
.16859 .4319 L
.17351 .37289 L
.17553 .35356 L
.17771 .33716 L
.17896 .32987 L
.1801 .32448 L
.18119 .32041 L
.18234 .31717 L
.18356 .3148 L
.18486 .31334 L
.18609 .31284 L
.1872 .31304 L
.18852 .31396 L
.18925 .31477 L
.18994 .31567 L
.19252 .32031 L
.19508 .32636 L
.19789 .33419 L
.20358 .35222 L
.2141 .38817 L
.22371 .4199 L
.22848 .43424 L
.23368 .44805 L
Mistroke
.23606 .4535 L
.2386 .45852 L
.24099 .46235 L
.24202 .46368 L
.24315 .46488 L
.24447 .46589 L
.24518 .46625 L
.24585 .46646 L
.24705 .4665 L
.24833 .466 L
.24905 .46547 L
.24983 .46465 L
.25057 .46366 L
.25125 .46253 L
.25255 .45985 L
.25392 .45619 L
.2564 .44756 L
.25874 .43753 L
.26405 .41116 L
.2739 .36538 L
.27886 .34793 L
.28169 .3399 L
.28427 .33381 L
.2865 .32942 L
.28891 .32554 L
.29146 .32235 L
.29261 .3212 L
.29387 .32013 L
.29612 .31867 L
.29736 .3181 L
.29851 .31771 L
.29959 .31746 L
.30057 .31733 L
.30171 .31727 L
.30279 .31732 L
.30392 .31746 L
.30515 .31771 L
.3063 .31803 L
.30736 .3184 L
.30983 .3195 L
.31242 .32095 L
.32267 .3287 L
.34108 .34442 L
.35061 .35105 L
.35585 .35397 L
.3608 .35624 L
.36541 .35794 L
.37041 .35939 L
.37496 .36038 L
.37916 .36108 L
Mistroke
.38382 .36168 L
.38884 .36216 L
.3979 .36284 L
.4086 .36365 L
.41853 .36461 L
.42864 .36586 L
.43968 .36743 L
.45977 .37037 L
.47858 .37266 L
.49892 .37449 L
.52035 .37592 L
.54053 .37706 L
.58155 .37905 L
.60199 .37983 L
.62106 .38044 L
.65905 .38137 L
.67942 .38175 L
.69798 .38203 L
.71869 .38229 L
.73784 .38248 L
.75763 .38264 L
.77619 .38275 L
.79487 .38285 L
.81548 .38293 L
.83568 .38298 L
.85418 .38303 L
.87312 .38306 L
.89383 .38309 L
.91345 .38311 L
.93441 .38312 L
.95577 .38314 L
.97593 .38314 L
.97619 .38314 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.06244 .23875 L
.08255 .36443 L
.10458 .48507 L
.11448 .5304 L
.11992 .55191 L
.12507 .56934 L
.12986 .58241 L
.13256 .58813 L
.13385 .59037 L
.13506 .59215 L
.13616 .59349 L
.13716 .59446 L
.13827 .59523 L
.13947 .59569 L
.14062 .59572 L
.14187 .59528 L
.14305 .59437 L
.14415 .59305 L
.14544 .59087 L
.1468 .58777 L
.14796 .5844 L
.14923 .57986 L
.15207 .56612 L
.15472 .54794 L
.15723 .52498 L
.15952 .49852 L
.16467 .41971 L
.16925 .33971 L
.17166 .3034 L
.17299 .287 L
.17423 .27412 L
.1754 .26425 L
.17646 .25698 L
.17765 .25072 L
.17893 .2459 L
.17994 .2433 L
.18105 .24154 L
.18221 .24073 L
.18328 .24079 L
.18456 .24172 L
.1852 .24249 L
.18591 .24356 L
.18833 .24862 L
.19116 .25662 L
.1938 .26553 L
.20374 .30477 L
.21263 .34085 L
.22233 .37554 L
.22773 .3909 L
Mistroke
.23035 .39687 L
.23273 .40116 L
.23392 .40283 L
.2352 .40424 L
.23641 .40515 L
.23752 .40558 L
.2387 .40556 L
.24 .4049 L
.24065 .40428 L
.24135 .4034 L
.24261 .40116 L
.24386 .39806 L
.245 .39431 L
.24624 .38923 L
.2476 .38228 L
.24989 .36718 L
.25232 .34679 L
.26115 .26459 L
.26608 .23195 L
.26856 .21971 L
.27127 .20903 L
.27359 .20181 L
.27607 .19583 L
.27841 .19159 L
.28054 .18877 L
.28184 .18745 L
.28322 .18637 L
.2844 .18569 L
.28569 .18516 L
.28642 .18496 L
.28709 .18484 L
.28785 .18476 L
.28858 .18475 L
.28987 .18486 L
.2906 .185 L
.29128 .18516 L
.29248 .18556 L
.29361 .18604 L
.29619 .18746 L
.30141 .19145 L
.31986 .2101 L
.33032 .21944 L
.33542 .22302 L
.34006 .22564 L
.34504 .22779 L
.34973 .22924 L
.35231 .22983 L
.3547 .23025 L
.35731 .23059 L
.35863 .23073 L
Mistroke
.36008 .23085 L
.36148 .23094 L
.36282 .23101 L
.36402 .23106 L
.36533 .2311 L
.36607 .23112 L
.36674 .23113 L
.36752 .23114 L
.36825 .23114 L
.36956 .23115 L
.37029 .23115 L
.37097 .23115 L
.37219 .23115 L
.37334 .23115 L
.37469 .23114 L
.37593 .23114 L
.37723 .23114 L
.37846 .23114 L
.37976 .23115 L
.38049 .23115 L
.38117 .23116 L
.38235 .23118 L
.38359 .23121 L
.38581 .23127 L
.38704 .23132 L
.38819 .23137 L
.39081 .23152 L
.39518 .23187 L
.39985 .23238 L
.41065 .23404 L
.42046 .23599 L
.44127 .24052 L
.46046 .24415 L
.47916 .2469 L
.49894 .24926 L
.53685 .25332 L
.57721 .2572 L
.61605 .26026 L
.65735 .26288 L
.69713 .2649 L
.7354 .26642 L
.77611 .26768 L
.81532 .26863 L
.85697 .26942 L
.89711 .27003 L
.93573 .27051 L
.97619 .27095 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.06244 .23878 L
.08255 .36447 L
.10458 .48509 L
.11448 .5304 L
.11992 .55188 L
.12507 .56929 L
.12986 .58232 L
.13256 .58802 L
.13385 .59024 L
.13506 .59201 L
.13616 .59333 L
.13716 .59428 L
.13827 .59504 L
.13947 .59547 L
.14062 .59549 L
.14187 .59502 L
.14305 .59408 L
.14415 .59273 L
.14544 .59053 L
.1468 .58739 L
.14923 .5794 L
.15058 .57347 L
.15185 .56685 L
.15472 .54731 L
.15723 .52432 L
.15952 .49789 L
.16467 .4197 L
.16925 .34102 L
.17166 .30545 L
.17299 .2894 L
.17423 .27682 L
.1754 .26719 L
.17646 .26012 L
.17765 .25408 L
.17893 .24946 L
.17994 .24704 L
.18105 .24545 L
.18221 .24484 L
.18328 .24508 L
.18456 .24623 L
.1852 .24713 L
.18591 .24832 L
.18833 .25382 L
.19116 .26238 L
.1938 .27185 L
.20374 .31367 L
.22233 .39308 L
.22731 .41138 L
.23273 .42887 L
Mistroke
.23522 .43581 L
.23786 .44229 L
.24034 .44738 L
.24261 .45105 L
.24379 .45251 L
.24502 .45369 L
.24627 .45447 L
.24697 .45471 L
.24763 .45481 L
.24882 .45463 L
.2499 .45404 L
.25116 .45285 L
.25234 .4512 L
.25341 .44929 L
.25454 .44683 L
.25656 .44143 L
.26115 .42602 L
.27077 .39031 L
.28088 .35829 L
.28952 .33874 L
.29441 .33092 L
.29895 .32555 L
.30148 .32327 L
.30387 .32151 L
.30604 .32023 L
.30833 .31915 L
.31083 .31826 L
.31314 .31767 L
.31442 .31742 L
.31562 .31724 L
.31693 .31708 L
.31761 .31701 L
.31834 .31695 L
.319 .3169 L
.31973 .31686 L
.32102 .31681 L
.32174 .3168 L
.32253 .31678 L
.32326 .31678 L
.32394 .31677 L
.32517 .31678 L
.32587 .31679 L
.32653 .31679 L
.32793 .31681 L
.32862 .31682 L
.32925 .31682 L
.33046 .31683 L
.33177 .31684 L
.33288 .31683 L
.33406 .31681 L
Mistroke
.33533 .31677 L
.33651 .31672 L
.33781 .31665 L
.33921 .31654 L
.34175 .31627 L
.34446 .31587 L
.34701 .31537 L
.34932 .31481 L
.35501 .31305 L
.36036 .3109 L
.38045 .3003 L
.39885 .29069 L
.40928 .28633 L
.41902 .28303 L
.43898 .27796 L
.46005 .2737 L
.49898 .26632 L
.54036 .25992 L
.58022 .25517 L
.61857 .25129 L
.65937 .24772 L
.69866 .24467 L
.73643 .24198 L
.77665 .23927 L
.81536 .23677 L
.85652 .23421 L
.89616 .23182 L
.93429 .22961 L
.97487 .22738 L
.97619 .2273 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.06244 .23828 L
.08255 .36398 L
.10458 .48499 L
.11448 .53073 L
.11992 .55259 L
.12507 .57052 L
.12986 .58426 L
.13238 .59012 L
.13506 .59512 L
.13731 .59821 L
.13859 .59947 L
.13979 .60028 L
.14089 .6007 L
.14189 .6008 L
.14305 .60054 L
.14415 .5999 L
.1454 .59868 L
.1461 .59775 L
.14674 .59673 L
.1479 .59447 L
.14918 .59133 L
.1514 .58407 L
.15374 .5736 L
.15629 .55848 L
.15902 .53745 L
.16396 .48631 L
.16859 .42699 L
.17113 .39444 L
.17351 .36704 L
.1757 .34616 L
.17771 .33126 L
.17877 .32502 L
.17994 .31946 L
.18111 .31511 L
.18234 .31177 L
.18303 .31041 L
.18368 .30943 L
.18489 .30833 L
.1862 .3081 L
.18694 .30835 L
.18761 .30881 L
.18875 .31 L
.19 .31186 L
.19252 .31706 L
.19824 .33374 L
.20358 .35284 L
.22371 .4312 L
.23411 .46834 L
.24399 .49791 L
Mistroke
.24829 .50825 L
.25286 .51702 L
.25549 .5208 L
.25788 .52331 L
.25903 .52419 L
.26028 .52489 L
.26145 .52531 L
.26253 .52549 L
.2638 .52546 L
.265 .52519 L
.26607 .52477 L
.26724 .52412 L
.26852 .52321 L
.26987 .52202 L
.27229 .51938 L
.28139 .50589 L
.29135 .48969 L
.29658 .48215 L
.30207 .47538 L
.30694 .47042 L
.31225 .46609 L
.31709 .46304 L
.32158 .46086 L
.32622 .45918 L
.33043 .45806 L
.33529 .45712 L
.33987 .45648 L
.34873 .45553 L
.35823 .45439 L
.36368 .45347 L
.36865 .45242 L
.37839 .44976 L
.39831 .44263 L
.41936 .43509 L
.43842 .42982 L
.45917 .42568 L
.49992 .4196 L
.53916 .41482 L
.57688 .4114 L
.61705 .40864 L
.6557 .40659 L
.69681 .40492 L
.7364 .40368 L
.77448 .40272 L
.81501 .40187 L
.85402 .40117 L
.89549 .4005 L
.93544 .39991 L
.97387 .39937 L
.97619 .39934 L
Mistroke
Mfstroke
0 1 .206 r
.02381 .01472 m
.06244 .23871 L
.08255 .36439 L
.10458 .48505 L
.11448 .53042 L
.11992 .55196 L
.12507 .56944 L
.12986 .58257 L
.13256 .58833 L
.13385 .5906 L
.13506 .59241 L
.13616 .59377 L
.13716 .59477 L
.13827 .59557 L
.13947 .59607 L
.14062 .59615 L
.14187 .59576 L
.14305 .5949 L
.14415 .59364 L
.14544 .59154 L
.1468 .58854 L
.14796 .58526 L
.14923 .58084 L
.15207 .56742 L
.15472 .54966 L
.15723 .52724 L
.15952 .50138 L
.16467 .42422 L
.16925 .34523 L
.17166 .3089 L
.17299 .29233 L
.17423 .27923 L
.1754 .2691 L
.17646 .26157 L
.17765 .25503 L
.17893 .24989 L
.17994 .24706 L
.18105 .24505 L
.18221 .24401 L
.18328 .24387 L
.18456 .24458 L
.1852 .24526 L
.18591 .24622 L
.18716 .24842 L
.18833 .25096 L
.1938 .26734 L
.20374 .30586 L
.21263 .34129 L
.22233 .37509 L
.22494 .3827 L
Mistroke
.22773 .3898 L
.23013 .39494 L
.23273 .3992 L
.23341 .40006 L
.23413 .40083 L
.23541 .40185 L
.2366 .40233 L
.23792 .40228 L
.23909 .40165 L
.24035 .40027 L
.24153 .39822 L
.24261 .39565 L
.24377 .39206 L
.24499 .38721 L
.24718 .37545 L
.24954 .35804 L
.25214 .33356 L
.25645 .28775 L
.26115 .24512 L
.26371 .22771 L
.26608 .21485 L
.26859 .2042 L
.27127 .19562 L
.27377 .18975 L
.275 .18751 L
.27613 .18579 L
.27824 .18333 L
.27936 .1824 L
.28054 .18167 L
.28183 .18112 L
.28302 .18085 L
.28367 .18078 L
.28438 .18077 L
.28568 .18092 L
.28689 .18123 L
.28817 .18173 L
.28927 .18228 L
.29048 .18301 L
.29611 .18779 L
.30141 .19376 L
.31986 .21806 L
.33032 .23027 L
.33542 .23523 L
.34006 .23909 L
.3447 .24234 L
.34973 .2452 L
.35505 .24756 L
.36008 .24926 L
.3654 .25063 L
.37105 .25173 L
Mistroke
.38117 .25328 L
.41902 .26055 L
.44008 .26576 L
.45933 .26987 L
.47922 .2731 L
.49812 .27545 L
.53634 .27932 L
.577 .28276 L
.61615 .2853 L
.65775 .28734 L
.69784 .28884 L
.73641 .28993 L
.77743 .2908 L
.81694 .29143 L
.85493 .29191 L
.89538 .29232 L
.93431 .29264 L
.97569 .29294 L
.97619 .29294 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.06244 .23877 L
.08255 .36447 L
.10458 .48509 L
.11448 .5304 L
.11992 .55188 L
.12507 .56929 L
.12986 .58232 L
.13256 .58802 L
.13385 .59024 L
.13506 .59201 L
.13616 .59333 L
.13716 .59428 L
.13827 .59504 L
.13947 .59547 L
.14062 .59549 L
.14187 .59502 L
.14305 .59408 L
.14415 .59273 L
.14544 .59051 L
.1468 .58736 L
.14923 .57936 L
.15058 .57341 L
.15185 .56677 L
.15472 .54715 L
.15723 .52404 L
.15952 .49745 L
.16467 .41858 L
.16925 .33914 L
.17166 .30333 L
.17299 .28722 L
.17423 .27461 L
.1754 .26499 L
.17646 .25793 L
.17765 .2519 L
.17893 .24731 L
.17994 .24489 L
.18105 .24331 L
.18221 .24269 L
.18328 .24291 L
.18456 .24403 L
.1852 .2449 L
.18591 .24607 L
.18833 .25145 L
.19116 .25982 L
.1938 .26906 L
.20374 .30954 L
.22233 .3839 L
.22731 .39995 L
.22993 .40731 L
Mistroke
.23273 .41407 L
.23542 .41932 L
.23669 .42128 L
.23786 .42275 L
.23904 .42388 L
.24031 .42466 L
.24143 .42491 L
.24261 .42469 L
.24377 .42393 L
.24482 .42274 L
.24604 .42069 L
.24719 .41804 L
.24924 .41145 L
.25146 .40146 L
.2565 .36996 L
.26115 .3378 L
.2658 .30917 L
.2708 .28383 L
.27553 .26512 L
.27985 .25212 L
.28466 .24177 L
.28738 .23757 L
.2899 .2346 L
.29128 .23332 L
.29258 .23231 L
.29376 .23155 L
.29501 .2309 L
.29638 .23036 L
.29763 .23 L
.29833 .22985 L
.29899 .22975 L
.2997 .22967 L
.30047 .22962 L
.30168 .22963 L
.30238 .22967 L
.30303 .22974 L
.30433 .22993 L
.30507 .23008 L
.30574 .23023 L
.30812 .23091 L
.31063 .23183 L
.32168 .23691 L
.32632 .23897 L
.33129 .24081 L
.33414 .24164 L
.33673 .24223 L
.33798 .24246 L
.33934 .24266 L
.34062 .24281 L
.3418 .24291 L
Mistroke
.34305 .24298 L
.34423 .24301 L
.3453 .24301 L
.34646 .24298 L
.34772 .24291 L
.34842 .24285 L
.34906 .24279 L
.35148 .24249 L
.35372 .24211 L
.35614 .2416 L
.36054 .24046 L
.37038 .23732 L
.38117 .23381 L
.38615 .23242 L
.39149 .23116 L
.39653 .23022 L
.40112 .22957 L
.40382 .22928 L
.40631 .22907 L
.40904 .2289 L
.41042 .22883 L
.41194 .22877 L
.41327 .22874 L
.41449 .22871 L
.41513 .2287 L
.41583 .22869 L
.41655 .22869 L
.41723 .22868 L
.41849 .22869 L
.41963 .2287 L
.42095 .22871 L
.42219 .22873 L
.42459 .22879 L
.42683 .22887 L
.43192 .22908 L
.44222 .22959 L
.46068 .23044 L
.4711 .23078 L
.48098 .23104 L
.49952 .2315 L
.51938 .23216 L
.53779 .23297 L
.57699 .23491 L
.61864 .23679 L
.65878 .23837 L
.6974 .23961 L
.73848 .24063 L
.75896 .24103 L
.77804 .24134 L
.81608 .24182 L
Mistroke
.83649 .24201 L
.85506 .24215 L
.87582 .24227 L
.89498 .24236 L
.91362 .24243 L
.93338 .24249 L
.97121 .24257 L
.97619 .24257 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.06244 .23841 L
.08255 .36411 L
.10458 .48501 L
.11448 .53063 L
.11992 .55239 L
.12507 .57019 L
.12986 .58374 L
.13238 .58947 L
.13506 .5943 L
.13614 .59584 L
.13731 .59721 L
.13859 .59835 L
.13979 .59904 L
.14096 .59934 L
.14207 .59926 L
.14306 .59886 L
.14415 .59805 L
.1448 .59737 L
.14548 .59648 L
.1467 .59444 L
.14802 .59155 L
.14946 .58746 L
.15205 .57746 L
.15447 .56457 L
.15683 .54816 L
.15898 .52956 L
.16382 .47457 L
.16911 .40055 L
.172 .36198 L
.17472 .33234 L
.17702 .3137 L
.17832 .30589 L
.17951 .30032 L
.18074 .29602 L
.18144 .29419 L
.18209 .29286 L
.1834 .29114 L
.18413 .29069 L
.1848 .29058 L
.18599 .29101 L
.18725 .29223 L
.18832 .29382 L
.18951 .29607 L
.19215 .3026 L
.19461 .31018 L
.20388 .34535 L
.22464 .43017 L
.23505 .46728 L
.24018 .48308 L
Mistroke
.24493 .4958 L
.24958 .50599 L
.25161 .50958 L
.2538 .51279 L
.25506 .51429 L
.25621 .51544 L
.25732 .51633 L
.25848 .51703 L
.25971 .51751 L
.26086 .51772 L
.26212 .51769 L
.26282 .51756 L
.26347 .51737 L
.26465 .51685 L
.26576 .51617 L
.26829 .51402 L
.27075 .51121 L
.27341 .50758 L
.28259 .49239 L
.29252 .47602 L
.29777 .46865 L
.30336 .46208 L
.30882 .45697 L
.31377 .45336 L
.31875 .45061 L
.32344 .44868 L
.32601 .44786 L
.32872 .44714 L
.33358 .44616 L
.33881 .4454 L
.34456 .44475 L
.34935 .44422 L
.35456 .44354 L
.36404 .44184 L
.36972 .44045 L
.37497 .43891 L
.38495 .43545 L
.40518 .4276 L
.42418 .42109 L
.44233 .41643 L
.4619 .41269 L
.50301 .40647 L
.5426 .40163 L
.58068 .39818 L
.62121 .39538 L
.66022 .3933 L
.70168 .39161 L
.74163 .39034 L
.78007 .38936 L
.82095 .38849 L
Mistroke
.86032 .38776 L
.89818 .38712 L
.93849 .38649 L
.97619 .38594 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.06244 .2383 L
.08255 .36401 L
.10458 .48499 L
.11448 .5307 L
.11992 .55255 L
.12507 .57045 L
.12986 .58415 L
.13238 .58998 L
.13506 .59494 L
.13731 .59799 L
.13859 .59922 L
.13979 .60001 L
.14089 .6004 L
.14189 .60047 L
.14305 .60017 L
.14415 .59949 L
.1454 .59822 L
.1461 .59726 L
.14674 .5962 L
.1479 .59388 L
.14918 .59066 L
.1514 .58323 L
.15374 .57253 L
.15629 .55707 L
.15902 .53557 L
.16396 .48324 L
.16859 .42269 L
.17113 .38969 L
.17351 .36218 L
.1757 .34145 L
.17771 .32684 L
.1788 .32068 L
.17994 .31545 L
.18109 .31138 L
.18234 .30818 L
.18303 .30694 L
.18368 .30605 L
.18489 .30511 L
.1862 .30502 L
.18694 .30533 L
.18761 .30583 L
.18875 .30707 L
.19 .30895 L
.19252 .31407 L
.19824 .33004 L
.20358 .34781 L
.22371 .41658 L
.22868 .43138 L
.23411 .44527 L
Mistroke
.2366 .45053 L
.23924 .45513 L
.24052 .45692 L
.24173 .45829 L
.24282 .45923 L
.24399 .4599 L
.24515 .46018 L
.24624 .46005 L
.24742 .45944 L
.24869 .45817 L
.24933 .45728 L
.25003 .45611 L
.25129 .45342 L
.25365 .44641 L
.25589 .43757 L
.25827 .42639 L
.26253 .40412 L
.27193 .35846 L
.27721 .33896 L
.28204 .3256 L
.2863 .31721 L
.28871 .31373 L
.29096 .31125 L
.29218 .31017 L
.29334 .30933 L
.29438 .3087 L
.29549 .30816 L
.2967 .30773 L
.29782 .30746 L
.29902 .30729 L
.30033 .30726 L
.30163 .30737 L
.30284 .30758 L
.30416 .30792 L
.30556 .30842 L
.30792 .3095 L
.31052 .311 L
.31982 .31821 L
.33072 .32812 L
.34072 .33671 L
.34995 .34326 L
.36005 .34851 L
.3653 .35046 L
.3702 .35186 L
.37537 .35298 L
.3809 .35384 L
.38621 .35446 L
.39112 .3549 L
.40222 .35579 L
.42236 .35791 L
Mistroke
.46173 .36373 L
.4815 .36611 L
.49959 .36771 L
.51901 .36904 L
.53989 .37027 L
.57962 .37226 L
.61784 .37367 L
.63752 .37422 L
.6585 .3747 L
.67849 .37508 L
.7001 .37542 L
.74019 .37587 L
.76014 .37603 L
.78121 .37616 L
.80087 .37625 L
.8192 .37632 L
.83786 .37638 L
.85813 .37643 L
.87939 .37647 L
.89951 .3765 L
.94032 .37654 L
.97619 .37657 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.06244 .23863 L
.08255 .36431 L
.10458 .48504 L
.11448 .53047 L
.11992 .55207 L
.12507 .56964 L
.12986 .58288 L
.13256 .58874 L
.13385 .59106 L
.13506 .59292 L
.13616 .59434 L
.13716 .59539 L
.13827 .59627 L
.13947 .59684 L
.14062 .59701 L
.14187 .59673 L
.14305 .59599 L
.14415 .59485 L
.14544 .59292 L
.1468 .59011 L
.14796 .58703 L
.14923 .58286 L
.15207 .57016 L
.15472 .55333 L
.15723 .5321 L
.15952 .50766 L
.16467 .43478 L
.16925 .35927 L
.17166 .32372 L
.17423 .29393 L
.17646 .27562 L
.17774 .26821 L
.17893 .26301 L
.18002 .25959 L
.18102 .25743 L
.18212 .25602 L
.18328 .25547 L
.18452 .2558 L
.18521 .25635 L
.18585 .25707 L
.18703 .25884 L
.18828 .26128 L
.19283 .27378 L
.20302 .31181 L
.22139 .38034 L
.22623 .39455 L
.23083 .40525 L
.23336 .40957 L
.23479 .41139 L
Mistroke
.23548 .41207 L
.23612 .41259 L
.23735 .41324 L
.23847 .4134 L
.23967 .41305 L
.24096 .41198 L
.24211 .41036 L
.24318 .40821 L
.24435 .40507 L
.24561 .40068 L
.24817 .38804 L
.25051 .37195 L
.25928 .29289 L
.2641 .2587 L
.26653 .24561 L
.26922 .23399 L
.2715 .22617 L
.27396 .21959 L
.27628 .21494 L
.2784 .21184 L
.27961 .2105 L
.28091 .20941 L
.28213 .20865 L
.28324 .20819 L
.28455 .20789 L
.28528 .20783 L
.28596 .20784 L
.28721 .20802 L
.28853 .20841 L
.28979 .20896 L
.29115 .20973 L
.2936 .21153 L
.29917 .21717 L
.31896 .24441 L
.3294 .25812 L
.3405 .26989 L
.35033 .27747 L
.35592 .28065 L
.36118 .283 L
.37038 .28595 L
.37556 .28714 L
.38032 .28805 L
.41991 .29523 L
.45798 .30319 L
.47757 .30618 L
.49851 .30852 L
.53998 .31201 L
.57993 .31468 L
.61836 .31657 L
.65925 .31802 L
Mistroke
.69862 .31903 L
.73647 .31973 L
.77678 .32025 L
.81557 .32061 L
.85682 .32089 L
.89655 .3211 L
.93476 .32126 L
.97543 .3214 L
.97619 .3214 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.06244 .23879 L
.08255 .36448 L
.10458 .48509 L
.11448 .53039 L
.11992 .55186 L
.12507 .56925 L
.12986 .58226 L
.13256 .58794 L
.13385 .59016 L
.13506 .59192 L
.13616 .59323 L
.13716 .59417 L
.13827 .59492 L
.13947 .59533 L
.14062 .59533 L
.14187 .59484 L
.14305 .59388 L
.14415 .59251 L
.14544 .59027 L
.1468 .58708 L
.14923 .579 L
.15058 .573 L
.15185 .56629 L
.15472 .54649 L
.15723 .52317 L
.15952 .49633 L
.16467 .41674 L
.16925 .33674 L
.17166 .30081 L
.17299 .28469 L
.17423 .27211 L
.1754 .26253 L
.17646 .25552 L
.17765 .24956 L
.17893 .24505 L
.17994 .24269 L
.18105 .24118 L
.18221 .24062 L
.18328 .24091 L
.18456 .2421 L
.1852 .24301 L
.18591 .24421 L
.18833 .24972 L
.19116 .25823 L
.1938 .26761 L
.20374 .30878 L
.22233 .38526 L
.22731 .40211 L
.23273 .41736 L
Mistroke
.23522 .4229 L
.23658 .42548 L
.23786 .42755 L
.23906 .42915 L
.24036 .43047 L
.24153 .43125 L
.24261 .4316 L
.24369 .43154 L
.24484 .43099 L
.24593 .42997 L
.24692 .42857 L
.24808 .42633 L
.24934 .4231 L
.25163 .41507 L
.25403 .40388 L
.25658 .38973 L
.26115 .36241 L
.27055 .31267 L
.27583 .2911 L
.28066 .27561 L
.28492 .26514 L
.28958 .25676 L
.29193 .25359 L
.29444 .25091 L
.29681 .24897 L
.29895 .24764 L
.30127 .24661 L
.30259 .2462 L
.30382 .24591 L
.30512 .24569 L
.3063 .24557 L
.30695 .24554 L
.30767 .24552 L
.30896 .24553 L
.31006 .24559 L
.31128 .2457 L
.31255 .24586 L
.31375 .24604 L
.31818 .24691 L
.32305 .24799 L
.32819 .24899 L
.33088 .24936 L
.3324 .24952 L
.33313 .24958 L
.33382 .24962 L
.33513 .24968 L
.33632 .2497 L
.3376 .24968 L
.33832 .24965 L
.33899 .24962 L
Mistroke
.34024 .24952 L
.34142 .2494 L
.34365 .24907 L
.34605 .24859 L
.34867 .24791 L
.35337 .24633 L
.35773 .24451 L
.37836 .23397 L
.38894 .22911 L
.3989 .22559 L
.40784 .22334 L
.41288 .22239 L
.41751 .22169 L
.42725 .22061 L
.43635 .2199 L
.45702 .21855 L
.49594 .21586 L
.50613 .21529 L
.5172 .2148 L
.52766 .21445 L
.53733 .21421 L
.54696 .21403 L
.556 .21389 L
.57661 .21367 L
.59681 .21351 L
.61532 .21341 L
.62513 .21336 L
.63426 .21333 L
.65496 .21328 L
.67371 .21324 L
.69403 .21319 L
.71539 .21313 L
.73555 .21304 L
.77648 .2128 L
.81591 .21249 L
.85381 .21213 L
.89417 .2117 L
.93302 .21128 L
.97431 .21084 L
.97619 .21082 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.06244 .23878 L
.08255 .36447 L
.10458 .48509 L
.11448 .5304 L
.11992 .55188 L
.12507 .56929 L
.12986 .58232 L
.13256 .58802 L
.13385 .59025 L
.13506 .59201 L
.13616 .59334 L
.13716 .59429 L
.13827 .59505 L
.13947 .59548 L
.14062 .5955 L
.14187 .59503 L
.14305 .59409 L
.14415 .59274 L
.14544 .59054 L
.1468 .5874 L
.14923 .57941 L
.15058 .57347 L
.15185 .56684 L
.15472 .54728 L
.15723 .52424 L
.15952 .49774 L
.16467 .41921 L
.16925 .33997 L
.17166 .30409 L
.17299 .2879 L
.17423 .27519 L
.1754 .26546 L
.17646 .25831 L
.17765 .25219 L
.17893 .24751 L
.17994 .24504 L
.18105 .24342 L
.18221 .24277 L
.18328 .24299 L
.18456 .24412 L
.1852 .245 L
.18591 .24619 L
.18833 .25169 L
.19116 .26027 L
.1938 .26979 L
.20374 .31211 L
.22233 .39329 L
.22731 .41218 L
.23273 .4304 L
Mistroke
.23752 .44384 L
.24014 .4499 L
.24261 .45456 L
.24379 .45638 L
.24504 .45797 L
.24569 .45866 L
.24641 .4593 L
.24766 .46009 L
.2488 .46044 L
.25003 .46038 L
.25118 .45989 L
.25223 .45906 L
.25337 .45776 L
.25443 .45619 L
.25682 .45144 L
.26115 .43964 L
.27092 .40791 L
.28144 .37689 L
.28628 .36543 L
.29138 .3556 L
.29572 .34897 L
.30047 .34344 L
.30303 .34112 L
.30544 .33932 L
.30995 .33679 L
.31248 .33579 L
.31481 .33508 L
.31736 .33449 L
.32006 .33404 L
.32223 .33379 L
.32455 .33358 L
.32874 .33331 L
.33336 .33302 L
.33569 .33284 L
.33827 .33258 L
.34099 .33222 L
.34355 .33179 L
.34843 .33068 L
.35375 .32903 L
.35949 .32674 L
.3796 .31589 L
.39922 .30494 L
.40961 .30014 L
.42071 .2959 L
.44121 .28983 L
.4603 .28512 L
.50177 .2755 L
.54172 .26769 L
.58015 .26156 L
.62104 .25593 L
Mistroke
.66041 .25119 L
.69826 .24714 L
.73857 .24321 L
.77736 .23969 L
.81861 .23616 L
.85833 .23291 L
.89655 .2299 L
.93721 .22683 L
.97619 .22402 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.06244 .23852 L
.08255 .3642 L
.10458 .48501 L
.11448 .53055 L
.11992 .55224 L
.12507 .56992 L
.12986 .58333 L
.13238 .58896 L
.13376 .59155 L
.13506 .59364 L
.13623 .59523 L
.13731 .59641 L
.1385 .59739 L
.13979 .59803 L
.14086 .59821 L
.14202 .59802 L
.14313 .59744 L
.14415 .59652 L
.14544 .59481 L
.1468 .59228 L
.14796 .58947 L
.14923 .58564 L
.1506 .58057 L
.15207 .57392 L
.15472 .55837 L
.15739 .53735 L
.15993 .51187 L
.16467 .44944 L
.16893 .38415 L
.17117 .35193 L
.17352 .3232 L
.17477 .31065 L
.17615 .29926 L
.17741 .29089 L
.17855 .28491 L
.17974 .28023 L
.181 .27673 L
.18218 .27469 L
.18328 .2737 L
.18445 .27352 L
.18569 .27416 L
.18675 .27528 L
.18791 .27706 L
.19051 .28264 L
.19294 .28939 L
.20319 .32589 L
.22161 .39314 L
.22659 .40811 L
.22922 .41501 L
Mistroke
.23202 .42139 L
.23471 .42635 L
.23598 .42821 L
.23714 .4296 L
.23832 .43065 L
.23959 .43135 L
.24072 .43154 L
.2419 .43126 L
.24306 .43044 L
.24411 .42917 L
.24532 .42702 L
.24647 .42425 L
.24852 .41733 L
.25074 .40676 L
.25578 .37315 L
.26044 .33936 L
.26508 .3106 L
.27009 .2867 L
.27239 .27806 L
.27481 .27045 L
.27708 .26463 L
.27914 .26034 L
.28161 .25635 L
.28287 .25476 L
.28424 .25335 L
.28552 .25232 L
.28669 .25159 L
.28781 .25108 L
.28899 .25073 L
.29027 .25055 L
.29099 .25053 L
.29164 .25057 L
.29291 .25077 L
.29412 .25111 L
.2948 .25137 L
.29552 .25168 L
.29682 .25235 L
.29975 .25432 L
.30463 .2587 L
.30911 .26355 L
.3192 .27578 L
.33747 .29643 L
.34726 .30471 L
.35637 .31033 L
.36161 .31271 L
.36637 .31442 L
.37187 .31595 L
.37706 .31706 L
.38677 .3186 L
.39705 .31996 L
Mistroke
.4155 .32271 L
.45335 .3297 L
.47441 .33285 L
.49366 .33496 L
.53245 .33796 L
.57218 .34037 L
.61039 .34207 L
.63008 .34274 L
.65106 .34333 L
.67105 .3438 L
.69266 .34422 L
.73275 .3448 L
.7527 .345 L
.77377 .34518 L
.81176 .34542 L
.83129 .34551 L
.85221 .34559 L
.89359 .34571 L
.93345 .3458 L
.9718 .34588 L
.97619 .34588 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.06244 .23874 L
.08255 .36443 L
.10458 .48508 L
.11448 .53042 L
.11992 .55193 L
.12507 .56937 L
.12986 .58245 L
.13256 .58819 L
.13385 .59043 L
.13506 .59222 L
.13616 .59357 L
.13716 .59454 L
.13827 .59533 L
.13947 .5958 L
.14062 .59585 L
.14187 .59543 L
.14305 .59453 L
.14415 .59324 L
.14544 .5911 L
.1468 .58804 L
.14796 .58471 L
.14923 .58023 L
.15207 .56667 L
.15472 .54876 L
.15723 .5262 L
.15952 .50026 L
.16467 .42331 L
.16925 .34511 L
.17166 .30927 L
.17299 .29294 L
.17423 .28003 L
.1754 .27007 L
.17646 .2627 L
.17765 .25632 L
.17893 .25137 L
.17994 .24871 L
.18105 .24688 L
.18221 .24604 L
.18328 .2461 L
.18456 .24707 L
.1852 .24788 L
.18591 .249 L
.18833 .2543 L
.19116 .26274 L
.1938 .2722 L
.20374 .31465 L
.22233 .39694 L
.23273 .43515 L
.23786 .4503 L
Mistroke
.24036 .45651 L
.24261 .46135 L
.24468 .46502 L
.24691 .46805 L
.24814 .46925 L
.24927 .47003 L
.25034 .47047 L
.25148 .47059 L
.25264 .47035 L
.25387 .46966 L
.25503 .46862 L
.25609 .46736 L
.25869 .46313 L
.26115 .45793 L
.27941 .4089 L
.28441 .39698 L
.28979 .38606 L
.29445 .37834 L
.29953 .37171 L
.30457 .36682 L
.30732 .36478 L
.30988 .36323 L
.31446 .36115 L
.31702 .36032 L
.31935 .35972 L
.32205 .35918 L
.32454 .3588 L
.33017 .35819 L
.33509 .35773 L
.3378 .35745 L
.34037 .35713 L
.34545 .35631 L
.35009 .35528 L
.35443 .35403 L
.35917 .35236 L
.37982 .34233 L
.39918 .33208 L
.42057 .3232 L
.4408 .31724 L
.45981 .31269 L
.49846 .30424 L
.53957 .29664 L
.57916 .29086 L
.61724 .28619 L
.65777 .28199 L
.69678 .27854 L
.73824 .27534 L
.77819 .27257 L
.81663 .27012 L
.85751 .26767 L
Mistroke
.89688 .26543 L
.93474 .26337 L
.97505 .26128 L
.97619 .26122 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.06244 .23866 L
.08255 .36434 L
.10458 .48506 L
.11448 .53047 L
.11992 .55205 L
.12507 .56959 L
.12986 .5828 L
.13256 .58863 L
.13385 .59094 L
.13506 .59279 L
.13616 .59419 L
.13716 .59523 L
.13827 .59609 L
.13947 .59664 L
.14062 .59679 L
.14187 .59649 L
.14305 .59572 L
.14415 .59456 L
.14544 .59259 L
.1468 .58975 L
.14796 .58664 L
.14923 .58243 L
.15207 .56964 L
.15472 .55273 L
.15723 .53144 L
.15952 .50699 L
.16467 .43437 L
.16925 .35934 L
.17166 .32392 L
.17423 .29411 L
.17646 .27576 L
.17774 .26834 L
.17893 .26317 L
.18002 .25979 L
.18102 .25771 L
.18212 .25641 L
.18328 .25601 L
.18452 .25653 L
.18521 .2572 L
.18585 .25803 L
.18703 .26005 L
.18828 .26279 L
.19283 .27664 L
.20302 .3194 L
.22139 .40204 L
.23083 .43871 L
.23603 .45609 L
.24096 .47022 L
.24554 .48075 L
Mistroke
.24813 .48534 L
.24937 .48714 L
.25053 .48856 L
.2516 .48963 L
.25276 .49051 L
.2538 .49107 L
.25477 .49136 L
.25582 .49145 L
.25696 .49127 L
.25816 .49078 L
.25928 .49006 L
.26054 .48895 L
.26189 .48748 L
.2643 .48417 L
.26976 .47442 L
.27967 .45355 L
.28936 .43467 L
.29824 .42134 L
.30282 .41615 L
.30763 .41186 L
.31247 .40863 L
.31524 .40721 L
.31775 .40614 L
.32234 .40465 L
.32486 .40405 L
.32723 .40358 L
.33146 .40294 L
.33604 .4024 L
.34101 .40187 L
.34634 .40122 L
.35137 .40042 L
.35596 .39947 L
.36599 .39661 L
.37701 .39236 L
.39768 .38314 L
.41682 .37562 L
.43539 .37019 L
.45512 .36587 L
.49284 .3591 L
.53301 .35304 L
.57167 .34861 L
.61277 .34492 L
.65237 .34208 L
.69044 .33989 L
.73097 .33797 L
.76998 .33641 L
.81145 .33496 L
.8514 .33371 L
.88983 .3326 L
.93072 .33148 L
Mistroke
.97009 .33046 L
.97619 .33031 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.06244 .23819 L
.08255 .36391 L
.10458 .48498 L
.11448 .53078 L
.11992 .5527 L
.12507 .57071 L
.12986 .58455 L
.13238 .59048 L
.13506 .59556 L
.13731 .59874 L
.13859 .60006 L
.13979 .60094 L
.14089 .60143 L
.14189 .60159 L
.14305 .60141 L
.14415 .60086 L
.1454 .59976 L
.1461 .5989 L
.14674 .59795 L
.1479 .59583 L
.14918 .59286 L
.1514 .58596 L
.15374 .57597 L
.15629 .56151 L
.15902 .54141 L
.16396 .49251 L
.16859 .43548 L
.17351 .3767 L
.17553 .35716 L
.17771 .34039 L
.17896 .33286 L
.1801 .32723 L
.18119 .32293 L
.18234 .31946 L
.18356 .31688 L
.18486 .31521 L
.18609 .31456 L
.1872 .31464 L
.18852 .31547 L
.18925 .31624 L
.18994 .31713 L
.19252 .3218 L
.19508 .32805 L
.19789 .33629 L
.20358 .35569 L
.22371 .4327 L
.23368 .46827 L
.24315 .49714 L
.24838 .51006 L
Mistroke
.25113 .51575 L
.25407 .52078 L
.25547 .52276 L
.25679 .52436 L
.25807 .52565 L
.25925 .52661 L
.26037 .5273 L
.26155 .52781 L
.26274 .52808 L
.26405 .52811 L
.26536 .52787 L
.26657 .52742 L
.2672 .5271 L
.26789 .52668 L
.2693 .52564 L
.27187 .52314 L
.27428 .5202 L
.28359 .5058 L
.2938 .48952 L
.29936 .48195 L
.30452 .47602 L
.30959 .47128 L
.31419 .46783 L
.31929 .46485 L
.32474 .46252 L
.32932 .4611 L
.33428 .46 L
.33895 .45925 L
.34326 .45871 L
.35233 .45771 L
.36206 .4563 L
.36765 .45518 L
.37274 .45392 L
.38272 .45087 L
.40339 .44319 L
.42253 .43654 L
.44109 .43161 L
.46083 .42779 L
.49855 .42218 L
.53872 .4173 L
.57737 .41383 L
.61848 .41109 L
.65807 .40907 L
.69615 .4076 L
.73668 .4064 L
.77569 .4055 L
.81715 .40472 L
.8571 .40409 L
.89554 .40356 L
.93642 .40304 L
Mistroke
.9758 .40257 L
.97619 .40257 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.06244 .23869 L
.08255 .36437 L
.10458 .48504 L
.11448 .53042 L
.11992 .55197 L
.12507 .56946 L
.12986 .5826 L
.13256 .58838 L
.13385 .59065 L
.13506 .59247 L
.13616 .59383 L
.13716 .59484 L
.13827 .59565 L
.13947 .59615 L
.14062 .59624 L
.14187 .59587 L
.14305 .59502 L
.14415 .59377 L
.14544 .59169 L
.1468 .58869 L
.14796 .58543 L
.14923 .58103 L
.15207 .56765 L
.15472 .54992 L
.15723 .52751 L
.15952 .50163 L
.16467 .42419 L
.16925 .34446 L
.17166 .30762 L
.17299 .29078 L
.17423 .27744 L
.1754 .2671 L
.17646 .25939 L
.17765 .25267 L
.17893 .24736 L
.17994 .2444 L
.18105 .24227 L
.18221 .24109 L
.18328 .24084 L
.18456 .24142 L
.1852 .24204 L
.18591 .24293 L
.18716 .24501 L
.18833 .24745 L
.1938 .26337 L
.20374 .30119 L
.21263 .33596 L
.22233 .3686 L
.22494 .37571 L
Mistroke
.22773 .38215 L
.22908 .38477 L
.23035 .38688 L
.23149 .38845 L
.23273 .38977 L
.23394 .39062 L
.23521 .391 L
.23639 .39081 L
.23748 .3901 L
.23878 .38852 L
.23996 .38627 L
.24061 .38466 L
.24132 .38259 L
.24261 .37787 L
.24484 .36643 L
.2461 .35777 L
.24729 .34811 L
.25225 .29244 L
.25686 .23441 L
.25911 .21163 L
.26115 .19519 L
.26343 .18107 L
.26586 .17005 L
.26713 .16562 L
.26851 .16169 L
.27101 .15644 L
.27226 .15458 L
.27363 .15303 L
.27432 .15242 L
.27506 .15189 L
.27577 .15149 L
.2764 .15122 L
.27763 .15089 L
.27832 .15082 L
.27896 .15082 L
.28013 .15098 L
.28137 .15134 L
.28251 .15184 L
.28356 .15243 L
.28591 .15413 L
.29017 .15836 L
.29989 .17161 L
.32039 .20442 L
.33039 .21856 L
.33948 .22903 L
.34894 .23728 L
.35788 .24281 L
.36279 .2451 L
.36732 .24685 L
.37756 .24997 L
Mistroke
.41693 .26051 L
.45478 .27084 L
.47421 .27457 L
.49509 .27749 L
.53634 .28178 L
.57606 .28495 L
.61428 .28715 L
.65494 .28882 L
.69409 .28997 L
.73569 .29084 L
.77578 .29144 L
.81435 .29186 L
.85537 .29221 L
.89488 .29249 L
.93287 .29271 L
.97332 .29293 L
.97619 .29295 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.06244 .23876 L
.08255 .36444 L
.10458 .48507 L
.11448 .53039 L
.11992 .55188 L
.12507 .5693 L
.12986 .58234 L
.13256 .58805 L
.13385 .59028 L
.13506 .59205 L
.13616 .59337 L
.13716 .59433 L
.13827 .59509 L
.13947 .59553 L
.14062 .59554 L
.14187 .59508 L
.14305 .59414 L
.14415 .59279 L
.14544 .59057 L
.1468 .58742 L
.14923 .5794 L
.15058 .57343 L
.15185 .56675 L
.15472 .54701 L
.15723 .52368 L
.15952 .49675 L
.16467 .41631 L
.16925 .33463 L
.17166 .29772 L
.17299 .28113 L
.17423 .26816 L
.1754 .25824 L
.17646 .25096 L
.17765 .24472 L
.17893 .23992 L
.17994 .23735 L
.18105 .23561 L
.18221 .23482 L
.18328 .23489 L
.18456 .23582 L
.1852 .23659 L
.18591 .23765 L
.18833 .24265 L
.19116 .25056 L
.1938 .25936 L
.20374 .29811 L
.21263 .33363 L
.22233 .36714 L
.22494 .37452 L
Mistroke
.22773 .38128 L
.23035 .38637 L
.23151 .38815 L
.23273 .38966 L
.23401 .3908 L
.23518 .3914 L
.23644 .39152 L
.23716 .39131 L
.23782 .39092 L
.23904 .38969 L
.24014 .38793 L
.24141 .38501 L
.24261 .38128 L
.24485 .37142 L
.24599 .36481 L
.24723 .3561 L
.2515 .31504 L
.25611 .25992 L
.25872 .23175 L
.26115 .21021 L
.26354 .19344 L
.26608 .17974 L
.2688 .16899 L
.27127 .16199 L
.27356 .15735 L
.27485 .1554 L
.27604 .15396 L
.27708 .15295 L
.27823 .1521 L
.27942 .15146 L
.28054 .15107 L
.28183 .15085 L
.28256 .15082 L
.28324 .15086 L
.28448 .15106 L
.2858 .15146 L
.28698 .15195 L
.28808 .15252 L
.2906 .15417 L
.2958 .15876 L
.30141 .16489 L
.32103 .18849 L
.32641 .19411 L
.33215 .19929 L
.33754 .20329 L
.34251 .20623 L
.34763 .20857 L
.35318 .21041 L
.35807 .21155 L
.36325 .21241 L
Mistroke
.36788 .213 L
.37222 .21346 L
.38211 .21455 L
.3925 .21614 L
.40237 .21824 L
.4209 .22334 L
.44094 .22916 L
.45911 .23363 L
.4788 .23735 L
.49978 .24047 L
.53986 .24554 L
.57843 .24967 L
.61946 .25313 L
.65896 .25576 L
.69696 .25777 L
.7374 .25946 L
.77633 .26073 L
.81771 .26179 L
.85757 .26262 L
.89592 .26329 L
.93673 .26389 L
.97601 .2644 L
.97619 .2644 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.06244 .23879 L
.08255 .36449 L
.10458 .48509 L
.11448 .53038 L
.11992 .55185 L
.12507 .56924 L
.12986 .58224 L
.13256 .58792 L
.13385 .59013 L
.13506 .59188 L
.13616 .59319 L
.13716 .59413 L
.13827 .59487 L
.13947 .59529 L
.14062 .59528 L
.14187 .59478 L
.14305 .59381 L
.14415 .59243 L
.14544 .59018 L
.1468 .58699 L
.14923 .57888 L
.15058 .57286 L
.15185 .56613 L
.15472 .54629 L
.15723 .52292 L
.15952 .49601 L
.16467 .41628 L
.16925 .33618 L
.17166 .30023 L
.17299 .28411 L
.17423 .27153 L
.1754 .26195 L
.17646 .25496 L
.17765 .24902 L
.17893 .24452 L
.17994 .24218 L
.18105 .24069 L
.18221 .24016 L
.18328 .24047 L
.18456 .2417 L
.1852 .24262 L
.18591 .24385 L
.18833 .24943 L
.19116 .25805 L
.1938 .26754 L
.20374 .30934 L
.22233 .38797 L
.22731 .40572 L
.23273 .42227 L
Mistroke
.23522 .42861 L
.23786 .43428 L
.23915 .43658 L
.24036 .43842 L
.24152 .43989 L
.24261 .44094 L
.24369 .44167 L
.24487 .44205 L
.24602 .44199 L
.24726 .44138 L
.24841 .44028 L
.24949 .43873 L
.25047 .43691 L
.25152 .43445 L
.25395 .427 L
.25653 .41681 L
.26115 .39541 L
.27055 .3524 L
.27548 .33311 L
.28066 .3161 L
.28522 .30404 L
.29021 .29385 L
.29474 .28704 L
.29895 .28254 L
.30159 .28049 L
.30402 .27904 L
.30669 .27787 L
.30803 .27743 L
.3095 .27704 L
.3108 .27677 L
.31198 .27659 L
.31264 .2765 L
.31335 .27643 L
.31465 .27633 L
.31586 .27627 L
.31714 .27625 L
.31824 .27625 L
.31945 .27627 L
.32062 .2763 L
.32186 .27635 L
.32406 .27645 L
.32531 .2765 L
.32664 .27656 L
.3279 .2766 L
.32904 .27662 L
.3301 .27664 L
.33125 .27664 L
.33234 .27662 L
.33334 .27659 L
.33443 .27654 L
Mistroke
.33563 .27645 L
.33688 .27634 L
.33805 .27621 L
.34063 .27581 L
.34302 .27532 L
.34844 .27374 L
.35322 .27183 L
.35831 .26932 L
.37684 .25794 L
.39683 .2465 L
.40809 .24177 L
.41844 .23847 L
.43794 .23403 L
.45853 .23026 L
.49652 .22369 L
.53697 .21834 L
.5759 .21469 L
.61728 .21156 L
.65714 .20908 L
.69549 .20702 L
.73629 .20504 L
.77558 .20327 L
.81335 .20164 L
.85357 .19998 L
.89228 .19844 L
.93344 .1969 L
.97308 .19551 L
.97619 .19541 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.06244 .23808 L
.08255 .36381 L
.10458 .48497 L
.11448 .53086 L
.11992 .55285 L
.12507 .57095 L
.12986 .58492 L
.13238 .59093 L
.13506 .59613 L
.13731 .59943 L
.13859 .60083 L
.13979 .60179 L
.14089 .60236 L
.14189 .60261 L
.14305 .60254 L
.14415 .6021 L
.1454 .60114 L
.1461 .60037 L
.14674 .59951 L
.14793 .59752 L
.14918 .59481 L
.15135 .5885 L
.15374 .57896 L
.15629 .56534 L
.15902 .5464 L
.16396 .5003 L
.16859 .44617 L
.17351 .38902 L
.17553 .36942 L
.17771 .35216 L
.17896 .34421 L
.1801 .33815 L
.18119 .33343 L
.18234 .32943 L
.18357 .3263 L
.18471 .3243 L
.18541 .32347 L
.18607 .32295 L
.1873 .32257 L
.1886 .32294 L
.1898 .3239 L
.19112 .32554 L
.19252 .32786 L
.19524 .33378 L
.19779 .34061 L
.20358 .35922 L
.22371 .4345 L
.23411 .47135 L
.24399 .50117 L
Mistroke
.24829 .51181 L
.25286 .52106 L
.25549 .52521 L
.25788 .52811 L
.25903 .5292 L
.26028 .53013 L
.26145 .53078 L
.26253 .53118 L
.2638 .5314 L
.265 .53136 L
.26607 .53115 L
.26724 .53071 L
.26852 .53002 L
.26987 .52905 L
.27229 .52677 L
.27662 .52133 L
.28139 .51405 L
.29219 .49671 L
.30207 .48344 L
.31152 .47437 L
.31627 .47109 L
.32145 .46835 L
.32669 .46633 L
.32962 .46546 L
.33227 .46482 L
.33745 .46386 L
.34232 .4632 L
.35118 .46225 L
.36068 .46101 L
.36613 .46003 L
.3711 .45893 L
.38084 .45617 L
.40076 .44901 L
.42181 .44161 L
.44088 .4365 L
.46163 .4325 L
.50238 .42656 L
.54161 .42193 L
.57933 .41863 L
.6195 .416 L
.65816 .41406 L
.69926 .4125 L
.73886 .41136 L
.77693 .41049 L
.81746 .40974 L
.85647 .40913 L
.89794 .40856 L
.93789 .40806 L
.97619 .40761 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.06244 .23879 L
.08255 .36447 L
.10458 .48508 L
.11448 .53038 L
.11992 .55185 L
.12507 .56924 L
.12986 .58225 L
.13256 .58792 L
.13385 .59013 L
.13506 .59189 L
.13616 .5932 L
.13716 .59414 L
.13827 .59488 L
.13947 .59529 L
.14062 .59528 L
.14187 .59478 L
.14305 .59381 L
.14415 .59242 L
.14544 .59016 L
.1468 .58696 L
.14923 .57882 L
.15058 .57277 L
.15185 .566 L
.15472 .54603 L
.15723 .52245 L
.15952 .49525 L
.16467 .41428 L
.16925 .33268 L
.17166 .29613 L
.17299 .27979 L
.17423 .26706 L
.1754 .25739 L
.17646 .25033 L
.17765 .24433 L
.17893 .23978 L
.17994 .2374 L
.18105 .23585 L
.18221 .23525 L
.18328 .23548 L
.18456 .2366 L
.1852 .23747 L
.18591 .23862 L
.18833 .24395 L
.19116 .2522 L
.1938 .26131 L
.20374 .30124 L
.21263 .33802 L
.22233 .37353 L
.22773 .38938 L
Mistroke
.23035 .3956 L
.23273 .40014 L
.23392 .40195 L
.2352 .40352 L
.23641 .4046 L
.23752 .40519 L
.2387 .40536 L
.24 .40494 L
.24065 .40446 L
.24135 .40373 L
.24261 .40179 L
.24386 .39903 L
.245 .39564 L
.24626 .39089 L
.2476 .38458 L
.24984 .37082 L
.25232 .35126 L
.26115 .26978 L
.26608 .23456 L
.26877 .21953 L
.27127 .20792 L
.2757 .19232 L
.27804 .1863 L
.28054 .18134 L
.28324 .17742 L
.28476 .17579 L
.28617 .17462 L
.2874 .17383 L
.28875 .17319 L
.28943 .17295 L
.29016 .17275 L
.29148 .17254 L
.29275 .17249 L
.29347 .17253 L
.29414 .17261 L
.29537 .17284 L
.29667 .17319 L
.29892 .17406 L
.30141 .17531 L
.31161 .1823 L
.32235 .19003 L
.32679 .19268 L
.33153 .19497 L
.33426 .196 L
.33673 .19675 L
.33793 .19705 L
.33922 .19732 L
.34158 .19771 L
.34273 .19784 L
.34398 .19794 L
Mistroke
.34515 .198 L
.34622 .19803 L
.34748 .19802 L
.34819 .198 L
.34885 .19798 L
.35005 .19791 L
.35134 .1978 L
.35268 .19765 L
.35413 .19747 L
.35676 .19705 L
.36168 .19607 L
.37128 .1939 L
.37596 .19293 L
.38023 .19218 L
.38483 .19156 L
.38735 .19131 L
.38975 .19114 L
.39101 .19107 L
.3917 .19104 L
.39235 .19102 L
.39349 .19099 L
.39475 .19097 L
.39541 .19097 L
.39611 .19097 L
.39737 .19098 L
.39806 .191 L
.39871 .19101 L
.40019 .19107 L
.4015 .19113 L
.40293 .19122 L
.40553 .19142 L
.41038 .19191 L
.42126 .19347 L
.44075 .19681 L
.46219 .20001 L
.50162 .2044 L
.54198 .20888 L
.58082 .21309 L
.62212 .21695 L
.6619 .22012 L
.70016 .22266 L
.74088 .22485 L
.78008 .22653 L
.82174 .22796 L
.86188 .22907 L
.9005 .22995 L
.94157 .23074 L
.97619 .23132 L
Mfstroke
0 1 .585 r
.02381 .01472 m
.06244 .2387 L
.08255 .36439 L
.10458 .48507 L
.11448 .53044 L
.11992 .55198 L
.12507 .56946 L
.12986 .5826 L
.13256 .58838 L
.13385 .59065 L
.13506 .59246 L
.13616 .59383 L
.13716 .59483 L
.13827 .59565 L
.13947 .59615 L
.14062 .59624 L
.14187 .59587 L
.14305 .59503 L
.14415 .59379 L
.14544 .59172 L
.1468 .58875 L
.14796 .58551 L
.14923 .58115 L
.15207 .5679 L
.15472 .55039 L
.15723 .52833 L
.15952 .50297 L
.16467 .4276 L
.16925 .35033 L
.17166 .31443 L
.17299 .2979 L
.17423 .28475 L
.1754 .27451 L
.17646 .26685 L
.17765 .26017 L
.17893 .2549 L
.17994 .252 L
.18105 .24994 L
.18221 .24888 L
.18328 .24875 L
.18456 .24954 L
.1852 .25026 L
.18591 .2513 L
.18716 .25365 L
.18833 .25638 L
.1938 .27408 L
.20374 .31683 L
.22233 .40048 L
.23273 .43971 L
.23786 .45559 L
Mistroke
.24261 .46763 L
.24483 .47214 L
.24691 .47564 L
.24806 .47722 L
.24931 .47862 L
.25044 .4796 L
.25148 .48024 L
.25264 .48064 L
.25373 .48071 L
.25492 .48045 L
.25619 .47979 L
.25683 .47932 L
.25752 .47869 L
.25879 .4773 L
.26115 .47387 L
.28057 .42998 L
.29088 .40912 L
.29668 .4002 L
.30199 .39387 L
.30671 .3896 L
.31188 .3862 L
.31449 .38492 L
.31727 .3838 L
.32228 .38235 L
.32474 .38183 L
.32741 .38138 L
.33225 .38073 L
.3413 .37963 L
.34621 .37886 L
.35079 .37791 L
.35582 .37658 L
.36122 .37481 L
.38227 .36526 L
.40206 .35553 L
.4236 .34721 L
.44428 .34154 L
.46342 .3373 L
.50265 .32955 L
.54037 .32339 L
.58054 .31832 L
.61919 .31439 L
.6603 .31101 L
.69989 .30837 L
.73797 .30625 L
.7785 .30431 L
.81751 .30266 L
.85898 .30107 L
.89893 .29964 L
.93736 .29834 L
.97619 .2971 L
Mistroke
Mfstroke
0 1 .609 r
.02381 .01472 m
.06244 .23861 L
.08255 .3643 L
.10458 .48504 L
.11448 .53049 L
.11992 .5521 L
.12507 .56968 L
.12986 .58295 L
.13256 .58883 L
.13506 .59303 L
.13607 .59436 L
.13716 .59553 L
.13835 .59647 L
.13947 .59701 L
.14073 .5972 L
.14192 .59693 L
.14299 .5963 L
.14415 .59513 L
.1448 .59427 L
.14548 .59317 L
.1467 .59071 L
.14802 .58729 L
.14946 .58252 L
.15205 .57098 L
.15447 .55617 L
.15683 .53728 L
.15898 .51578 L
.16382 .45182 L
.16898 .36883 L
.1717 .32868 L
.1732 .31014 L
.17459 .29549 L
.17591 .28424 L
.17711 .276 L
.17845 .26901 L
.17915 .26617 L
.17989 .26376 L
.18111 .26095 L
.18224 .25948 L
.18347 .25897 L
.18417 .25913 L
.1848 .25952 L
.18599 .26084 L
.18711 .26269 L
.18833 .2653 L
.18965 .26868 L
.19478 .28611 L
.20398 .32613 L
.22478 .4188 L
.23491 .45586 L
Mistroke
.24026 .47205 L
.24319 .47969 L
.24595 .48592 L
.24859 .49086 L
.24997 .49301 L
.25143 .49492 L
.25266 .49623 L
.25331 .4968 L
.25401 .49731 L
.25524 .49798 L
.25638 .49832 L
.25763 .49838 L
.25834 .49828 L
.25899 .4981 L
.26018 .49756 L
.26145 .49671 L
.26364 .49463 L
.26606 .49157 L
.28707 .45253 L
.29627 .43784 L
.30147 .43137 L
.30631 .42657 L
.3111 .42288 L
.31545 .42033 L
.31786 .4192 L
.32046 .41818 L
.3252 .41675 L
.32759 .4162 L
.33022 .4157 L
.33553 .41491 L
.34505 .41373 L
.35028 .41295 L
.35524 .41201 L
.36454 .40961 L
.37455 .40609 L
.38544 .40152 L
.4048 .39313 L
.42619 .38561 L
.44642 .38055 L
.46543 .37684 L
.50408 .37036 L
.54519 .3648 L
.58478 .36083 L
.62286 .35784 L
.66339 .35534 L
.7024 .35347 L
.74386 .35188 L
.78381 .35062 L
.82225 .34959 L
.86313 .34862 L
Mistroke
.90251 .34777 L
.94036 .34701 L
.97619 .34632 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.06244 .23831 L
.08255 .36401 L
.10458 .48499 L
.11448 .5307 L
.11992 .55254 L
.12507 .57043 L
.12986 .58413 L
.13238 .58995 L
.13506 .5949 L
.13731 .59795 L
.13859 .59918 L
.13979 .59996 L
.14089 .60035 L
.14189 .60041 L
.14305 .6001 L
.14415 .59942 L
.1454 .59814 L
.1461 .59718 L
.14674 .59612 L
.1479 .59379 L
.14918 .59056 L
.1514 .58311 L
.15374 .57237 L
.15629 .55687 L
.15902 .53529 L
.16396 .48274 L
.16859 .42183 L
.17113 .38856 L
.17351 .36076 L
.1757 .33978 L
.17771 .32498 L
.1788 .31875 L
.17994 .31345 L
.18109 .30935 L
.18234 .30615 L
.18303 .30492 L
.18368 .30406 L
.18489 .30319 L
.1862 .3032 L
.18694 .30359 L
.18761 .30418 L
.18875 .30558 L
.19 .30766 L
.19252 .31329 L
.19824 .33085 L
.20358 .35059 L
.22371 .43013 L
.23411 .46741 L
.24399 .49692 L
Mistroke
.24829 .50719 L
.25286 .51582 L
.25549 .51949 L
.25788 .52188 L
.25903 .5227 L
.26028 .52332 L
.26145 .52367 L
.26253 .52379 L
.2638 .52368 L
.265 .52334 L
.26607 .52286 L
.26724 .52214 L
.26987 .51989 L
.27229 .51714 L
.28139 .50328 L
.29206 .48575 L
.30207 .47239 L
.31108 .4639 L
.31614 .4605 L
.32077 .45811 L
.32557 .45627 L
.33082 .45483 L
.33347 .45428 L
.3363 .45379 L
.34139 .4531 L
.35166 .45192 L
.35706 .45118 L
.36277 .45018 L
.37327 .44763 L
.38294 .44452 L
.42088 .43056 L
.44036 .42529 L
.46127 .42121 L
.5026 .41505 L
.54241 .41026 L
.58071 .40688 L
.62146 .40417 L
.66069 .40218 L
.69841 .40072 L
.73858 .39952 L
.77724 .39861 L
.81834 .39782 L
.85794 .39718 L
.89601 .39664 L
.93654 .3961 L
.97555 .39563 L
.97619 .39562 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.06244 .23857 L
.08255 .36426 L
.10458 .48503 L
.11448 .53052 L
.11992 .55216 L
.12507 .56978 L
.12986 .58311 L
.13256 .58903 L
.13506 .59328 L
.13607 .59464 L
.13716 .59583 L
.13835 .59681 L
.13947 .59739 L
.14073 .59762 L
.14192 .5974 L
.14299 .59681 L
.14415 .59571 L
.1448 .59488 L
.14548 .59383 L
.1467 .59145 L
.14802 .58813 L
.14946 .5835 L
.15205 .57226 L
.15447 .55782 L
.15683 .53941 L
.15898 .51846 L
.16382 .45616 L
.16911 .37309 L
.172 .33145 L
.17342 .31435 L
.17472 .30099 L
.17702 .28294 L
.17823 .27619 L
.17951 .27092 L
.18082 .26726 L
.18203 .26523 L
.18273 .2646 L
.18337 .26433 L
.1841 .26435 L
.1848 .26468 L
.1859 .26573 L
.18711 .26757 L
.18838 .27015 L
.18956 .27307 L
.19395 .28721 L
.20388 .32918 L
.22464 .42039 L
.23505 .45824 L
.24018 .47377 L
Mistroke
.24493 .48578 L
.24923 .49414 L
.25163 .49755 L
.25268 .49872 L
.2538 .49973 L
.25505 .50057 L
.25619 .50107 L
.25743 .50131 L
.25813 .50131 L
.25878 .50122 L
.25996 .50086 L
.26104 .50032 L
.26229 .49944 L
.26347 .49839 L
.26807 .49254 L
.27315 .48386 L
.28342 .46388 L
.2924 .44795 L
.30185 .43514 L
.30668 .4303 L
.31197 .42621 L
.31677 .42345 L
.32123 .42156 L
.32396 .42066 L
.32653 .41996 L
.33133 .41894 L
.3365 .41811 L
.3421 .41734 L
.35159 .41585 L
.35698 .41472 L
.36202 .4134 L
.37218 .41001 L
.38307 .40551 L
.40286 .3968 L
.4244 .38895 L
.44508 .38359 L
.46422 .3798 L
.50345 .37324 L
.54117 .36814 L
.58134 .36412 L
.61999 .36117 L
.6611 .35877 L
.70069 .35703 L
.73877 .35573 L
.7793 .35464 L
.81831 .35379 L
.85978 .35302 L
.89973 .35237 L
.93816 .3518 L
.97619 .35127 L
Mistroke
Mfstroke
0 1 .68 r
.02381 .01472 m
.06244 .23825 L
.08255 .36396 L
.10458 .48498 L
.11448 .53074 L
.11992 .55263 L
.12507 .57058 L
.12986 .58435 L
.13238 .59023 L
.13506 .59524 L
.13731 .59836 L
.13859 .59963 L
.13979 .60046 L
.14089 .6009 L
.14189 .60101 L
.14305 .60077 L
.14415 .60015 L
.1454 .59896 L
.1461 .59805 L
.14674 .59705 L
.1479 .59482 L
.14918 .59172 L
.1514 .58455 L
.15374 .57419 L
.15629 .55922 L
.15902 .53841 L
.16396 .48778 L
.16859 .42899 L
.17113 .39664 L
.17351 .36936 L
.1757 .34853 L
.17771 .33364 L
.17994 .32181 L
.18111 .31743 L
.18234 .31404 L
.18356 .31179 L
.18486 .31046 L
.18609 .31009 L
.1872 .3104 L
.18852 .31145 L
.18925 .31233 L
.18994 .3133 L
.19252 .31816 L
.19789 .33245 L
.20358 .35082 L
.21328 .38433 L
.22371 .41893 L
.22895 .43455 L
.23393 .44748 L
.23841 .45678 L
Mistroke
.23963 .45882 L
.24093 .4607 L
.24208 .46207 L
.24328 .4632 L
.24452 .46399 L
.24566 .46433 L
.24689 .46425 L
.24758 .46398 L
.24823 .46357 L
.24941 .46241 L
.25048 .46085 L
.25172 .45842 L
.25289 .4555 L
.25506 .44848 L
.25706 .44035 L
.26159 .41826 L
.2706 .37344 L
.27533 .35409 L
.2803 .338 L
.28295 .33122 L
.28585 .32519 L
.28849 .32087 L
.29094 .31777 L
.29224 .31645 L
.29347 .31541 L
.29458 .31462 L
.29576 .31393 L
.29705 .31336 L
.29823 .31299 L
.29951 .31273 L
.30023 .31265 L
.30091 .31262 L
.30217 .31265 L
.3028 .31272 L
.30351 .31282 L
.30474 .3131 L
.30591 .31344 L
.30852 .31451 L
.31135 .31605 L
.32124 .32353 L
.33979 .33974 L
.35015 .34718 L
.3598 .35224 L
.36467 .35411 L
.36987 .35566 L
.37565 .35693 L
.3809 .35775 L
.38573 .35832 L
.39086 .35879 L
.40006 .35951 L
Mistroke
.41007 .36037 L
.42085 .36157 L
.44039 .36439 L
.4587 .36718 L
.47842 .36968 L
.49994 .37166 L
.52055 .37308 L
.53967 .37421 L
.57882 .37618 L
.59881 .37698 L
.62042 .37769 L
.66051 .37868 L
.68046 .37905 L
.70153 .37937 L
.73953 .37979 L
.75905 .37994 L
.77997 .38007 L
.80123 .38018 L
.82135 .38025 L
.8597 .38036 L
.87949 .3804 L
.9005 .38043 L
.93827 .38048 L
.97619 .38052 L
Mfstroke
0 1 .704 r
.02381 .01472 m
.06244 .23855 L
.08255 .36423 L
.10458 .48501 L
.11448 .53051 L
.11992 .55217 L
.12507 .56981 L
.12986 .58316 L
.13238 .58874 L
.13376 .59131 L
.13506 .59336 L
.13623 .59492 L
.13731 .59607 L
.1385 .59701 L
.13979 .59761 L
.14086 .59775 L
.14202 .5975 L
.14313 .59686 L
.14415 .59588 L
.14544 .59408 L
.1468 .59144 L
.14796 .58853 L
.14923 .58456 L
.1506 .57931 L
.15207 .57244 L
.15472 .55636 L
.15739 .53459 L
.15993 .50814 L
.16467 .44312 L
.16893 .37514 L
.17117 .34183 L
.17352 .31241 L
.17477 .2997 L
.17615 .28826 L
.17741 .27994 L
.17855 .27406 L
.17974 .26951 L
.181 .26617 L
.18218 .26431 L
.18328 .26348 L
.18445 .26346 L
.18569 .26428 L
.18675 .26555 L
.18791 .26748 L
.19051 .27341 L
.19294 .28047 L
.20319 .31828 L
.22161 .38675 L
.22659 .40147 L
.22922 .4081 L
Mistroke
.23202 .41404 L
.2334 .41647 L
.23471 .4184 L
.23588 .41979 L
.23714 .42089 L
.23835 .42151 L
.23962 .42164 L
.24071 .42127 L
.2419 .4203 L
.24314 .41856 L
.24432 .41615 L
.24538 .41329 L
.24653 .40935 L
.24911 .39706 L
.25149 .38133 L
.26044 .30665 L
.26508 .27534 L
.26752 .26218 L
.27009 .25059 L
.27235 .24215 L
.27481 .23468 L
.27705 .22937 L
.27914 .22557 L
.28043 .22372 L
.28183 .22213 L
.28315 .22099 L
.28437 .22023 L
.28547 .21978 L
.28667 .2195 L
.28793 .21945 L
.28911 .21961 L
.28977 .21978 L
.29049 .22003 L
.2918 .22064 L
.29307 .22141 L
.29425 .22227 L
.29975 .22778 L
.31998 .25702 L
.32989 .2708 L
.33899 .28139 L
.34782 .28943 L
.35713 .29556 L
.36197 .2979 L
.36648 .29967 L
.37671 .30255 L
.38175 .3036 L
.38721 .3046 L
.39714 .30628 L
.41572 .3098 L
.43518 .31407 L
Mistroke
.45661 .31846 L
.47694 .32166 L
.49598 .32383 L
.53477 .32704 L
.55449 .32838 L
.57601 .32964 L
.61574 .33137 L
.63543 .33201 L
.65641 .33257 L
.6764 .333 L
.69801 .33338 L
.73809 .33389 L
.75805 .33407 L
.77912 .33422 L
.81711 .33443 L
.85755 .33459 L
.89648 .3347 L
.93786 .33481 L
.97619 .3349 L
Mfstroke
0 1 .727 r
.02381 .01472 m
.06244 .23874 L
.08255 .36442 L
.10458 .48506 L
.11448 .53039 L
.11992 .5519 L
.12507 .56933 L
.12986 .5824 L
.13256 .58813 L
.13385 .59036 L
.13506 .59215 L
.13616 .59348 L
.13716 .59445 L
.13827 .59522 L
.13947 .59567 L
.14062 .59571 L
.14187 .59526 L
.14305 .59434 L
.14415 .59301 L
.14544 .59083 L
.1468 .58771 L
.14796 .58433 L
.14923 .57976 L
.15207 .56594 L
.15472 .54763 L
.15723 .52447 L
.15952 .49771 L
.16467 .41767 L
.16925 .33599 L
.17166 .29886 L
.17299 .2821 L
.17423 .26895 L
.1754 .25887 L
.17646 .25144 L
.17765 .24504 L
.17893 .24007 L
.17994 .23738 L
.18105 .23551 L
.18221 .23459 L
.18328 .23455 L
.18456 .23536 L
.1852 .23608 L
.18591 .23707 L
.18833 .24188 L
.19116 .24959 L
.1938 .25821 L
.20374 .29636 L
.21263 .33128 L
.22233 .36385 L
.22494 .37086 L
Mistroke
.22773 .37711 L
.22908 .37962 L
.23035 .38161 L
.2315 .38305 L
.23273 .38419 L
.23393 .38484 L
.23524 .38498 L
.2359 .38479 L
.23661 .38438 L
.23788 .38304 L
.23916 .38084 L
.24036 .37785 L
.24144 .3743 L
.24261 .3694 L
.24484 .35668 L
.2461 .34715 L
.24729 .33656 L
.25225 .27645 L
.25448 .2457 L
.25686 .21591 L
.25907 .1934 L
.26115 .17693 L
.26362 .16253 L
.26586 .15323 L
.26715 .14915 L
.26833 .14606 L
.26972 .14314 L
.27101 .14099 L
.27217 .13947 L
.27341 .13822 L
.27412 .13766 L
.27479 .13722 L
.27605 .13663 L
.27669 .13644 L
.27737 .1363 L
.2786 .13622 L
.27992 .13636 L
.28067 .13653 L
.28137 .13675 L
.28245 .13718 L
.28363 .13777 L
.28602 .13932 L
.29028 .14302 L
.29989 .15414 L
.32112 .18154 L
.33116 .19199 L
.34042 .19914 L
.34509 .20183 L
.35004 .20411 L
.35501 .20588 L
Mistroke
.36048 .20737 L
.37027 .20935 L
.37943 .21097 L
.39969 .21553 L
.41822 .22113 L
.43883 .22754 L
.45795 .23247 L
.47645 .23605 L
.49617 .23898 L
.53777 .24392 L
.57785 .24771 L
.61642 .2504 L
.65745 .25256 L
.69696 .25413 L
.73495 .25528 L
.77539 .25621 L
.81432 .25693 L
.8557 .25754 L
.89557 .25804 L
.93392 .25846 L
.97472 .25886 L
.97619 .25888 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.06244 .23878 L
.08255 .36446 L
.10458 .48507 L
.11448 .53038 L
.11992 .55186 L
.12507 .56926 L
.12986 .58228 L
.13256 .58796 L
.13385 .59018 L
.13506 .59194 L
.13616 .59325 L
.13716 .5942 L
.13827 .59495 L
.13947 .59536 L
.14062 .59536 L
.14187 .59488 L
.14305 .59391 L
.14415 .59254 L
.14544 .59029 L
.1468 .5871 L
.14923 .57898 L
.15058 .57295 L
.15185 .56621 L
.15472 .54627 L
.15723 .52272 L
.15952 .49552 L
.16467 .41438 L
.16925 .33229 L
.17166 .2954 L
.17299 .27889 L
.17423 .26601 L
.1754 .2562 L
.17646 .24903 L
.17765 .24292 L
.17893 .23825 L
.17994 .23578 L
.18105 .23414 L
.18221 .23345 L
.18328 .2336 L
.18456 .23462 L
.1852 .23544 L
.18591 .23654 L
.18833 .24168 L
.19116 .24973 L
.1938 .25865 L
.20374 .29784 L
.21263 .33384 L
.22233 .36806 L
.22494 .37568 L
Mistroke
.22773 .38274 L
.23013 .38776 L
.2314 .38993 L
.23273 .39181 L
.2334 .39258 L
.23413 .39328 L
.23541 .39411 L
.23671 .39439 L
.23792 .39407 L
.23911 .39314 L
.24019 .3917 L
.24143 .38923 L
.24261 .38601 L
.24368 .38227 L
.24485 .37714 L
.24723 .36307 L
.24943 .34527 L
.2515 .32458 L
.2565 .26694 L
.26115 .22099 L
.26343 .20385 L
.26586 .18919 L
.26856 .17666 L
.27101 .16807 L
.27357 .1614 L
.27501 .15851 L
.27634 .15632 L
.27879 .15332 L
.28002 .15224 L
.28067 .15178 L
.28137 .15136 L
.28261 .15079 L
.28379 .15044 L
.28493 .15027 L
.28599 .15024 L
.28713 .15033 L
.28839 .15058 L
.28971 .15098 L
.29095 .15147 L
.29319 .15262 L
.29525 .15391 L
.29989 .15748 L
.3098 .16658 L
.32039 .17606 L
.32553 .17991 L
.33039 .18289 L
.33475 .18499 L
.33719 .18592 L
.33948 .18664 L
.34169 .18719 L
Mistroke
.34406 .18765 L
.34541 .18784 L
.34669 .18799 L
.34784 .1881 L
.3491 .18818 L
.34979 .18821 L
.35044 .18824 L
.35166 .18826 L
.35297 .18826 L
.3537 .18825 L
.35438 .18823 L
.35552 .18819 L
.35677 .18813 L
.35929 .18796 L
.36867 .18712 L
.37091 .18692 L
.37329 .18673 L
.37549 .18659 L
.37756 .18649 L
.37868 .18644 L
.37989 .18641 L
.38054 .18639 L
.38122 .18638 L
.38245 .18637 L
.38377 .18638 L
.38499 .1864 L
.3857 .18641 L
.38634 .18643 L
.38777 .18649 L
.38897 .18655 L
.39007 .18662 L
.39256 .18681 L
.39708 .18729 L
.40192 .18798 L
.40725 .18892 L
.418 .19119 L
.4391 .196 L
.45836 .19969 L
.47829 .20259 L
.49721 .20487 L
.53547 .20918 L
.57619 .21336 L
.61539 .21668 L
.65705 .21959 L
.69718 .22189 L
.73581 .22368 L
.77688 .22522 L
.81644 .22643 L
.85449 .22739 L
.89498 .22827 L
Mistroke
.93396 .229 L
.9754 .22968 L
.97619 .22969 L
Mfstroke
0 1 .775 r
.02381 .01472 m
.06244 .23879 L
.08255 .36447 L
.10458 .48508 L
.11448 .53038 L
.11992 .55185 L
.12507 .56924 L
.12986 .58225 L
.13256 .58793 L
.13385 .59014 L
.13506 .5919 L
.13616 .59321 L
.13716 .59415 L
.13827 .59489 L
.13947 .5953 L
.14062 .5953 L
.14187 .5948 L
.14305 .59383 L
.14415 .59245 L
.14544 .59019 L
.1468 .58699 L
.14923 .57886 L
.15058 .57282 L
.15185 .56606 L
.15472 .54612 L
.15723 .52257 L
.15952 .49541 L
.16467 .41458 L
.16925 .33308 L
.17166 .29651 L
.17299 .28015 L
.17423 .2674 L
.1754 .2577 L
.17646 .25062 L
.17765 .2446 L
.17893 .24002 L
.17994 .23762 L
.18105 .23606 L
.18221 .23545 L
.18328 .23568 L
.18456 .2368 L
.1852 .23767 L
.18591 .23883 L
.18833 .24417 L
.19116 .25246 L
.1938 .26162 L
.20374 .30188 L
.21263 .33914 L
.22233 .37541 L
.22773 .39184 L
Mistroke
.23035 .3984 L
.23273 .4033 L
.23392 .40532 L
.2352 .40712 L
.23641 .40844 L
.23752 .40927 L
.2387 .40972 L
.24 .40963 L
.24065 .40933 L
.24135 .4088 L
.24261 .40726 L
.24386 .40492 L
.245 .40194 L
.24626 .39768 L
.2476 .39193 L
.24984 .37919 L
.25232 .36084 L
.26115 .28279 L
.26608 .24772 L
.27127 .2204 L
.2757 .20397 L
.27821 .19708 L
.28054 .19201 L
.28326 .18749 L
.2846 .18576 L
.28583 .18441 L
.28814 .18246 L
.28935 .1817 L
.29063 .18108 L
.29191 .18063 L
.29263 .18045 L
.29329 .18032 L
.29456 .18016 L
.29577 .18013 L
.29645 .18016 L
.29717 .18021 L
.29847 .1804 L
.29919 .18053 L
.29986 .18069 L
.30141 .18112 L
.31986 .18951 L
.32491 .19147 L
.32775 .19231 L
.32908 .19264 L
.33032 .1929 L
.33146 .1931 L
.33272 .19328 L
.33399 .19342 L
.33468 .19347 L
.33533 .19351 L
Mistroke
.33652 .19356 L
.33761 .19356 L
.33887 .19352 L
.34006 .19345 L
.34132 .19333 L
.34247 .19318 L
.34503 .19275 L
.3474 .19222 L
.34963 .19162 L
.36008 .18797 L
.37034 .18405 L
.37594 .18216 L
.38117 .18069 L
.38579 .17965 L
.39075 .17882 L
.39358 .17847 L
.39625 .17822 L
.39865 .17806 L
.40001 .17799 L
.40126 .17794 L
.40232 .17791 L
.40346 .17789 L
.40454 .17787 L
.40552 .17787 L
.40662 .17787 L
.40781 .17789 L
.40906 .17791 L
.41022 .17794 L
.41264 .17802 L
.41483 .17812 L
.41974 .17841 L
.44056 .17996 L
.44969 .18054 L
.45974 .18103 L
.4694 .18138 L
.47844 .18164 L
.49823 .18221 L
.51853 .18299 L
.53707 .18387 L
.57685 .18585 L
.61512 .18755 L
.65584 .18919 L
.69504 .19055 L
.73669 .19176 L
.77683 .19271 L
.81545 .19347 L
.85653 .19413 L
.89609 .19467 L
.93413 .19513 L
.97463 .19556 L
Mistroke
.97619 .19558 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.06244 .23879 L
.08255 .36448 L
.10458 .48509 L
.11448 .53039 L
.11992 .55186 L
.12507 .56925 L
.12986 .58227 L
.13256 .58795 L
.13385 .59016 L
.13506 .59192 L
.13616 .59323 L
.13716 .59418 L
.13827 .59492 L
.13947 .59534 L
.14062 .59534 L
.14187 .59485 L
.14305 .59389 L
.14415 .59252 L
.14544 .59028 L
.1468 .58709 L
.14923 .57901 L
.15058 .57301 L
.15185 .5663 L
.15472 .5465 L
.15723 .52318 L
.15952 .49632 L
.16467 .41662 L
.16925 .33634 L
.17166 .30019 L
.17299 .28396 L
.17423 .27127 L
.1754 .26159 L
.17646 .25451 L
.17765 .24847 L
.17893 .24389 L
.17994 .24149 L
.18105 .23995 L
.18221 .23937 L
.18328 .23964 L
.18456 .24082 L
.1852 .24173 L
.18591 .24293 L
.18833 .24848 L
.19116 .25709 L
.1938 .26661 L
.20374 .3088 L
.22233 .38912 L
.22731 .40752 L
.23273 .42495 L
Mistroke
.23522 .43178 L
.23786 .43808 L
.24034 .4429 L
.24261 .44624 L
.24379 .44749 L
.24502 .44841 L
.24627 .44888 L
.24697 .44893 L
.24763 .44883 L
.24882 .44826 L
.2499 .44729 L
.25116 .4456 L
.25234 .44344 L
.25454 .43806 L
.25656 .43173 L
.26115 .41443 L
.27092 .37528 L
.27605 .35688 L
.28144 .34029 L
.28619 .32831 L
.29138 .31801 L
.29609 .31101 L
.30047 .30626 L
.30284 .3043 L
.3054 .30259 L
.30783 .30133 L
.31006 .30043 L
.31207 .29979 L
.31429 .29926 L
.3166 .29885 L
.31876 .29858 L
.3281 .29795 L
.33066 .29778 L
.33338 .29753 L
.33571 .29725 L
.33827 .29684 L
.34086 .29632 L
.34365 .29561 L
.34871 .29393 L
.35387 .2917 L
.3586 .28924 L
.37715 .27734 L
.39765 .26456 L
.40765 .25963 L
.41674 .25593 L
.43514 .25009 L
.45482 .24497 L
.49477 .23525 L
.5332 .22748 L
.57409 .22108 L
Mistroke
.61346 .21598 L
.65131 .21184 L
.69162 .2081 L
.73041 .20496 L
.77166 .20197 L
.81138 .19935 L
.8496 .19701 L
.89026 .19469 L
.92941 .1926 L
.97101 .19054 L
.97619 .1903 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.06244 .23877 L
.08255 .36446 L
.10458 .48508 L
.11448 .5304 L
.11992 .55188 L
.12507 .56929 L
.12986 .58233 L
.13256 .58803 L
.13385 .59026 L
.13506 .59203 L
.13616 .59335 L
.13716 .59431 L
.13827 .59507 L
.13947 .5955 L
.14062 .59552 L
.14187 .59505 L
.14305 .59412 L
.14415 .59277 L
.14544 .59056 L
.1468 .58742 L
.14923 .57943 L
.15058 .57349 L
.15185 .56685 L
.15472 .54726 L
.15723 .52417 L
.15952 .49758 L
.16467 .41862 L
.16925 .33874 L
.17166 .30252 L
.17299 .28617 L
.17423 .27334 L
.1754 .26351 L
.17646 .25628 L
.17765 .25009 L
.17893 .24535 L
.17994 .24283 L
.18105 .24117 L
.18221 .24048 L
.18328 .24067 L
.18456 .24176 L
.1852 .24263 L
.18591 .2438 L
.18833 .24926 L
.19116 .25782 L
.1938 .26734 L
.20374 .30988 L
.22233 .39194 L
.22731 .41104 L
.23273 .42945 L
Mistroke
.23752 .44302 L
.24014 .44913 L
.24261 .45383 L
.24379 .45566 L
.24504 .45726 L
.24569 .45795 L
.24641 .45859 L
.24766 .45938 L
.2488 .45973 L
.25003 .45965 L
.25118 .45915 L
.25223 .45832 L
.25337 .45701 L
.25443 .45543 L
.25682 .45067 L
.26115 .43891 L
.27092 .40719 L
.28144 .37577 L
.28628 .36404 L
.29138 .35392 L
.29572 .34705 L
.30047 .34127 L
.30303 .33883 L
.30544 .33691 L
.30995 .33417 L
.31248 .33305 L
.31481 .33224 L
.31736 .33153 L
.32006 .33096 L
.32455 .33029 L
.32874 .32981 L
.33369 .32924 L
.33827 .32856 L
.34327 .32753 L
.34871 .32595 L
.3535 .32414 L
.3586 .3218 L
.37715 .31075 L
.39682 .29844 L
.41487 .28945 L
.43419 .28237 L
.45504 .27622 L
.49463 .26549 L
.53271 .25658 L
.57323 .24896 L
.61225 .2428 L
.65371 .23727 L
.69366 .23276 L
.7321 .22898 L
.77298 .22541 L
Mistroke
.81235 .2223 L
.85021 .21954 L
.89052 .2168 L
.92931 .21433 L
.97055 .21187 L
.97619 .21155 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.06244 .23849 L
.08255 .36417 L
.10458 .48501 L
.11448 .53057 L
.11992 .55228 L
.12507 .57 L
.12986 .58345 L
.13238 .58911 L
.13506 .59384 L
.13614 .59534 L
.13731 .59665 L
.13859 .59772 L
.13979 .59834 L
.14096 .59856 L
.14207 .5984 L
.14306 .59792 L
.14415 .597 L
.1448 .59625 L
.14548 .59529 L
.1467 .5931 L
.14802 .59002 L
.14946 .58569 L
.15205 .57513 L
.15447 .56155 L
.15683 .54425 L
.15898 .52459 L
.16382 .46628 L
.16911 .38794 L
.172 .34774 L
.17472 .31748 L
.17702 .29894 L
.17832 .29137 L
.17951 .2861 L
.18074 .28215 L
.18144 .28054 L
.18209 .27941 L
.1834 .27812 L
.18413 .27791 L
.1848 .27802 L
.18599 .27884 L
.18725 .28048 L
.18832 .28242 L
.18951 .28504 L
.19461 .30072 L
.20388 .33845 L
.22464 .42649 L
.23462 .46255 L
.24409 .49016 L
.24931 .50149 L
Mistroke
.25227 .50626 L
.25368 .50806 L
.25501 .50943 L
.25623 .51042 L
.25754 .51118 L
.25874 .51159 L
.25984 .51175 L
.26103 .51166 L
.26234 .51129 L
.263 .511 L
.26371 .51061 L
.26498 .50972 L
.26755 .50725 L
.27028 .50381 L
.27518 .49614 L
.28626 .47631 L
.29596 .46087 L
.30105 .45434 L
.3064 .44875 L
.31126 .44474 L
.31658 .4414 L
.32141 .43917 L
.32591 .43764 L
.33055 .43649 L
.33476 .43572 L
.3442 .43443 L
.35354 .4331 L
.35825 .43222 L
.36342 .43104 L
.37426 .42778 L
.38423 .42402 L
.40535 .41535 L
.42462 .40862 L
.44458 .40353 L
.4635 .39991 L
.5018 .3939 L
.54255 .38874 L
.58178 .38511 L
.6195 .38246 L
.65967 .38029 L
.69833 .37871 L
.73943 .37743 L
.77903 .37646 L
.8171 .37571 L
.85763 .37503 L
.89664 .37446 L
.93811 .3739 L
.97619 .37343 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.06244 .23839 L
.08255 .36408 L
.10458 .485 L
.11448 .53064 L
.11992 .55243 L
.12507 .57024 L
.12986 .58384 L
.13238 .58959 L
.13506 .59444 L
.13614 .596 L
.13731 .59739 L
.13859 .59855 L
.13979 .59927 L
.14096 .59959 L
.14207 .59954 L
.14306 .59917 L
.14415 .59839 L
.1448 .59773 L
.14548 .59687 L
.1467 .59487 L
.14802 .59204 L
.14946 .58802 L
.15205 .57818 L
.15447 .56549 L
.15683 .54933 L
.15898 .531 L
.16382 .47681 L
.16911 .4036 L
.172 .36519 L
.17472 .33543 L
.17702 .31658 L
.17832 .30862 L
.17951 .30292 L
.18074 .29848 L
.18144 .29658 L
.18209 .29518 L
.1834 .29333 L
.18413 .29282 L
.1848 .29265 L
.18599 .29299 L
.18725 .29413 L
.18832 .29566 L
.18951 .29784 L
.19215 .30427 L
.19461 .31176 L
.20388 .34668 L
.22464 .43104 L
.23505 .46808 L
.24018 .48391 L
Mistroke
.24493 .49668 L
.24958 .50696 L
.25161 .51061 L
.2538 .51389 L
.25506 .51544 L
.25621 .51664 L
.25739 .51762 L
.25848 .51832 L
.25964 .51883 L
.26091 .51913 L
.26214 .51915 L
.26284 .51905 L
.26347 .51889 L
.26465 .51842 L
.26576 .51778 L
.26698 .51689 L
.26829 .51572 L
.27341 .50938 L
.28259 .49418 L
.29252 .47759 L
.29777 .47008 L
.30336 .46336 L
.30882 .45811 L
.31377 .45439 L
.31875 .45152 L
.32344 .4495 L
.32872 .44786 L
.33358 .4468 L
.33892 .44594 L
.34456 .44522 L
.35402 .44397 L
.35933 .44306 L
.36417 .44204 L
.37358 .43945 L
.3825 .43637 L
.42079 .42188 L
.44054 .41652 L
.46154 .41241 L
.49926 .40664 L
.53943 .40164 L
.57809 .39811 L
.61919 .39532 L
.65879 .39328 L
.69686 .39181 L
.73739 .39062 L
.7764 .38973 L
.81787 .38898 L
.85782 .38838 L
.89625 .38788 L
.93714 .38739 L
Mistroke
.97619 .38696 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.06244 .23802 L
.08255 .36376 L
.10458 .48496 L
.11448 .5309 L
.11992 .55293 L
.12507 .57108 L
.12986 .58512 L
.13238 .59118 L
.13506 .59644 L
.13731 .59981 L
.13859 .60125 L
.13979 .60225 L
.14089 .60287 L
.14189 .60316 L
.14305 .60314 L
.14415 .60276 L
.1454 .60188 L
.1461 .60116 L
.14674 .60034 L
.14793 .59844 L
.14918 .59584 L
.15135 .58975 L
.15374 .58051 L
.15629 .5673 L
.15902 .54891 L
.16396 .50409 L
.16859 .45118 L
.17351 .39458 L
.17553 .37486 L
.17771 .35728 L
.17896 .34909 L
.1801 .34278 L
.18119 .33782 L
.18234 .33356 L
.18357 .33015 L
.18471 .3279 L
.18541 .32692 L
.18607 .32626 L
.1873 .32563 L
.1886 .32577 L
.1898 .32652 L
.19112 .32795 L
.19252 .33006 L
.19524 .33564 L
.19779 .34221 L
.20358 .36037 L
.22371 .43505 L
.23411 .47186 L
.24399 .50172 L
Mistroke
.24829 .51241 L
.25286 .52173 L
.25549 .52593 L
.25788 .52889 L
.25903 .53001 L
.26028 .53098 L
.26145 .53166 L
.26253 .53208 L
.2638 .53234 L
.265 .53234 L
.26607 .53214 L
.26724 .53174 L
.26852 .53107 L
.26987 .53013 L
.27229 .52788 L
.27662 .52248 L
.28139 .5152 L
.29219 .49772 L
.30207 .48427 L
.31152 .47505 L
.31627 .4717 L
.32145 .46888 L
.32669 .4668 L
.32962 .46591 L
.33227 .46524 L
.33745 .46424 L
.34232 .46355 L
.35118 .46254 L
.36068 .46125 L
.36613 .46024 L
.3711 .45911 L
.38084 .45631 L
.40076 .44907 L
.42181 .44162 L
.44088 .43649 L
.46163 .43247 L
.50238 .42653 L
.54161 .42192 L
.57933 .41865 L
.6195 .41605 L
.65816 .41415 L
.69926 .41264 L
.73886 .41155 L
.77693 .41074 L
.81746 .41005 L
.85647 .4095 L
.89794 .40899 L
.93789 .40855 L
.97619 .40816 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.06244 .2384 L
.08255 .36408 L
.10458 .48499 L
.11448 .53063 L
.11992 .55241 L
.12507 .57022 L
.12986 .5838 L
.13238 .58954 L
.13506 .59438 L
.13614 .59593 L
.13731 .59732 L
.13859 .59847 L
.13979 .59917 L
.14096 .59948 L
.14207 .59941 L
.14306 .59903 L
.14415 .59823 L
.1448 .59756 L
.14548 .59669 L
.1467 .59467 L
.14802 .59179 L
.14946 .58773 L
.15205 .57779 L
.15447 .56496 L
.15683 .54862 L
.15898 .53009 L
.16382 .47523 L
.16911 .40136 L
.172 .36296 L
.17472 .33352 L
.17702 .31503 L
.17832 .30728 L
.17951 .30173 L
.18074 .29743 L
.18144 .29558 L
.18209 .29422 L
.1834 .29241 L
.18413 .2919 L
.1848 .29173 L
.18599 .29201 L
.18725 .29304 L
.18832 .29445 L
.18951 .29646 L
.19215 .30238 L
.19461 .30926 L
.20388 .34088 L
.21453 .3796 L
.22464 .41316 L
.22934 .42656 L
Mistroke
.23435 .43837 L
.23723 .44356 L
.23859 .44549 L
.23984 .44691 L
.2411 .44796 L
.24176 .44833 L
.24246 .4486 L
.24364 .44868 L
.24493 .44822 L
.24618 .44715 L
.24735 .44552 L
.24841 .44349 L
.24956 .44065 L
.25214 .43174 L
.25452 .42061 L
.26347 .36885 L
.26811 .3445 L
.27312 .32306 L
.27784 .30766 L
.28217 .2975 L
.28466 .29321 L
.28697 .29014 L
.28951 .28771 L
.29093 .28673 L
.29222 .28607 L
.29288 .2858 L
.29358 .28558 L
.29483 .28531 L
.29553 .28523 L
.29618 .28519 L
.29689 .28521 L
.29766 .28527 L
.29832 .28537 L
.29903 .28551 L
.30034 .28588 L
.30161 .28636 L
.30279 .2869 L
.30741 .28978 L
.3124 .2939 L
.32143 .30278 L
.33126 .3128 L
.34202 .32252 L
.34703 .3263 L
.35238 .32974 L
.35701 .33222 L
.36204 .3344 L
.36772 .33632 L
.37308 .33767 L
.37831 .33866 L
.38313 .33937 L
Mistroke
.4225 .34411 L
.46035 .3504 L
.47978 .35295 L
.50066 .35494 L
.5419 .35775 L
.58163 .35985 L
.61985 .3613 L
.63953 .36186 L
.66051 .36236 L
.6805 .36275 L
.70211 .36309 L
.7422 .36355 L
.76215 .36372 L
.78322 .36385 L
.82121 .36403 L
.84074 .3641 L
.86166 .36416 L
.90304 .36425 L
.94291 .36432 L
.97619 .36437 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.06244 .23862 L
.08255 .3643 L
.10458 .48502 L
.11448 .53047 L
.11992 .55207 L
.12507 .56963 L
.12986 .58288 L
.13256 .58874 L
.13385 .59106 L
.13506 .59293 L
.13616 .59434 L
.13716 .59539 L
.13827 .59627 L
.13947 .59684 L
.14062 .59701 L
.14187 .59673 L
.14305 .59599 L
.14415 .59485 L
.14544 .59291 L
.1468 .5901 L
.14796 .58701 L
.14923 .58283 L
.1506 .57731 L
.15207 .57009 L
.15472 .5532 L
.15739 .53031 L
.15993 .50242 L
.16467 .43374 L
.169 .36141 L
.17136 .32536 L
.17359 .29766 L
.17598 .27581 L
.17725 .26748 L
.17862 .26077 L
.17981 .25665 L
.18105 .25378 L
.18212 .25235 L
.18328 .25173 L
.1846 .25205 L
.18582 .25315 L
.18645 .25399 L
.18715 .25511 L
.18857 .2579 L
.19114 .2645 L
.19356 .27197 L
.20289 .30688 L
.21364 .34872 L
.21893 .36738 L
.22384 .38256 L
Mistroke
.22854 .39437 L
.23117 .39938 L
.23233 .40114 L
.23355 .40264 L
.2342 .40329 L
.23491 .40385 L
.23617 .40446 L
.23688 .40457 L
.23763 .40448 L
.23835 .40418 L
.239 .40371 L
.24026 .40223 L
.24098 .40103 L
.24164 .39966 L
.24285 .39643 L
.24413 .3919 L
.24632 .38111 L
.24868 .36465 L
.25295 .32298 L
.25799 .26907 L
.26044 .24745 L
.26267 .23131 L
.2649 .21819 L
.26731 .20694 L
.26986 .19786 L
.27226 .1915 L
.27353 .18891 L
.27492 .18657 L
.27637 .18466 L
.27772 .18332 L
.27899 .18242 L
.28014 .18186 L
.28078 .18165 L
.28148 .18151 L
.28275 .18144 L
.28405 .18162 L
.28527 .182 L
.28597 .18229 L
.28661 .18262 L
.28806 .18352 L
.29081 .18579 L
.29371 .18885 L
.30386 .20318 L
.3238 .23572 L
.3325 .24813 L
.34193 .25915 L
.34717 .26408 L
.35201 .2679 L
.36152 .27358 L
.36636 .2757 L
Mistroke
.37169 .2776 L
.38246 .28052 L
.42277 .29002 L
.44132 .29472 L
.46156 .29905 L
.48271 .30236 L
.50281 .30464 L
.54347 .30815 L
.58262 .3107 L
.60405 .31175 L
.62422 .31256 L
.66279 .31374 L
.68275 .3142 L
.70382 .31459 L
.74181 .31512 L
.76133 .31533 L
.78225 .31551 L
.82364 .31578 L
.8635 .31597 L
.90185 .31612 L
.94265 .31625 L
.97619 .31636 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.06244 .23878 L
.08255 .36446 L
.10458 .48508 L
.11448 .53039 L
.11992 .55187 L
.12507 .56927 L
.12986 .5823 L
.13256 .58799 L
.13385 .59021 L
.13506 .59197 L
.13616 .59329 L
.13716 .59424 L
.13827 .59499 L
.13947 .59541 L
.14062 .59542 L
.14187 .59494 L
.14305 .59399 L
.14415 .59263 L
.14544 .5904 L
.1468 .58723 L
.14923 .57918 L
.15058 .57319 L
.15185 .5665 L
.15472 .54674 L
.15723 .52345 L
.15952 .4966 L
.16467 .41682 L
.16925 .33626 L
.17166 .29994 L
.17299 .28361 L
.17423 .27085 L
.1754 .26111 L
.17646 .25397 L
.17765 .24788 L
.17893 .24324 L
.17994 .2408 L
.18105 .2392 L
.18221 .23856 L
.18328 .23878 L
.18456 .23991 L
.1852 .24078 L
.18591 .24195 L
.18833 .24737 L
.19116 .25582 L
.1938 .26518 L
.20374 .30658 L
.22233 .38421 L
.22731 .40139 L
.23273 .41698 L
Mistroke
.23522 .42267 L
.23658 .42532 L
.23786 .42746 L
.23906 .42913 L
.24036 .43051 L
.24153 .43136 L
.24261 .43175 L
.24369 .43173 L
.24484 .43123 L
.24593 .43023 L
.24692 .42886 L
.24808 .42664 L
.24934 .42342 L
.25163 .4154 L
.25403 .40422 L
.25658 .39013 L
.26115 .36284 L
.27055 .31181 L
.27548 .29034 L
.28066 .27233 L
.28522 .26025 L
.28764 .25517 L
.29021 .25066 L
.29259 .24724 L
.29474 .24471 L
.29692 .24263 L
.29895 .24108 L
.30127 .23971 L
.3026 .2391 L
.30382 .23864 L
.30501 .23826 L
.3063 .23794 L
.30767 .23768 L
.30896 .2375 L
.31006 .23739 L
.31128 .23731 L
.31255 .23727 L
.31375 .23727 L
.31486 .23728 L
.31588 .23731 L
.317 .23736 L
.31818 .23741 L
.32066 .23754 L
.32203 .2376 L
.32332 .23765 L
.32452 .23769 L
.32583 .23771 L
.32702 .2377 L
.32811 .23768 L
.32941 .23763 L
Mistroke
.33063 .23755 L
.33196 .23743 L
.33339 .23726 L
.33632 .23676 L
.33899 .23613 L
.34376 .23457 L
.34884 .23232 L
.35799 .2271 L
.37872 .21368 L
.38901 .20817 L
.39443 .2058 L
.40014 .2037 L
.41065 .20074 L
.42032 .1988 L
.43997 .196 L
.45831 .19365 L
.49724 .18877 L
.51849 .18673 L
.53862 .18528 L
.57697 .18324 L
.59637 .18242 L
.61777 .18165 L
.65706 .18057 L
.69728 .17979 L
.73599 .17923 L
.77715 .17877 L
.81679 .17842 L
.85492 .17813 L
.8955 .17788 L
.93457 .17769 L
.97608 .17752 L
.97619 .17752 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.06244 .23845 L
.08255 .36414 L
.10458 .485 L
.11448 .53059 L
.11992 .55233 L
.12507 .57008 L
.12986 .58358 L
.13238 .58927 L
.13506 .59404 L
.13614 .59556 L
.13731 .5969 L
.13859 .598 L
.13979 .59865 L
.14096 .59891 L
.14207 .59878 L
.14306 .59833 L
.14415 .59746 L
.1448 .59674 L
.14548 .59582 L
.1467 .59369 L
.14802 .59069 L
.14946 .58647 L
.15205 .57615 L
.15447 .56287 L
.15683 .54596 L
.15898 .52675 L
.16382 .46982 L
.16911 .39311 L
.172 .35338 L
.17472 .32316 L
.17702 .30444 L
.17832 .29672 L
.17951 .29128 L
.18074 .28718 L
.18144 .28547 L
.18209 .28426 L
.1834 .2828 L
.18413 .28252 L
.1848 .28256 L
.18599 .28325 L
.18725 .28477 L
.18832 .28661 L
.18951 .28914 L
.19461 .30446 L
.20388 .34156 L
.22464 .42837 L
.23462 .46424 L
.24409 .49195 L
.24931 .50349 L
Mistroke
.25227 .50845 L
.25368 .51035 L
.25501 .51183 L
.25623 .51293 L
.25754 .51381 L
.25874 .51435 L
.25984 .51461 L
.26103 .51465 L
.26234 .51441 L
.263 .51419 L
.26371 .51386 L
.26498 .51309 L
.26621 .51213 L
.26755 .51085 L
.27028 .50761 L
.27518 .5002 L
.28626 .48058 L
.29677 .46395 L
.30137 .4581 L
.3064 .4528 L
.31097 .44892 L
.31585 .44567 L
.321 .44311 L
.32578 .44138 L
.33141 .43994 L
.33672 .43899 L
.34665 .43763 L
.3564 .43611 L
.36131 .43508 L
.3667 .43371 L
.38517 .42725 L
.40629 .41863 L
.42556 .41198 L
.44552 .40697 L
.46444 .40341 L
.50273 .39752 L
.54348 .3925 L
.58272 .38899 L
.62044 .38645 L
.66061 .38439 L
.69926 .38292 L
.74037 .38175 L
.77996 .38089 L
.81804 .38024 L
.85857 .37966 L
.89758 .37918 L
.93905 .37873 L
.97619 .37835 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.06244 .23831 L
.08255 .36401 L
.10458 .48498 L
.11448 .53069 L
.11992 .55253 L
.12507 .57043 L
.12986 .58412 L
.13238 .58995 L
.13506 .59489 L
.13731 .59794 L
.13859 .59916 L
.13979 .59994 L
.14089 .60033 L
.14189 .60039 L
.14305 .60008 L
.14415 .59938 L
.1454 .5981 L
.1461 .59713 L
.14674 .59607 L
.1479 .59373 L
.14918 .59048 L
.1514 .583 L
.15374 .57222 L
.15629 .55665 L
.15902 .53498 L
.16396 .48217 L
.16859 .42102 L
.17113 .38771 L
.17351 .36 L
.1757 .33917 L
.17771 .32455 L
.1788 .31841 L
.17994 .3132 L
.18109 .30918 L
.18234 .30603 L
.18303 .30482 L
.18368 .30397 L
.18489 .3031 L
.1862 .30308 L
.18694 .30344 L
.18761 .30398 L
.18875 .30529 L
.19 .30724 L
.19252 .31253 L
.19824 .32883 L
.20358 .34685 L
.22371 .41595 L
.22868 .43069 L
.23411 .44443 L
Mistroke
.2366 .4496 L
.23924 .45406 L
.24052 .45576 L
.24173 .45704 L
.24282 .45789 L
.24399 .45845 L
.24515 .4586 L
.24624 .45834 L
.24742 .45756 L
.24869 .45609 L
.24933 .45509 L
.25003 .45379 L
.25129 .45085 L
.25365 .44331 L
.25589 .43394 L
.25827 .42224 L
.26253 .39927 L
.27193 .35299 L
.27721 .33341 L
.28204 .32009 L
.2863 .31178 L
.28871 .30837 L
.29096 .30595 L
.29218 .30491 L
.29334 .3041 L
.29438 .30351 L
.29549 .30301 L
.2967 .30262 L
.29782 .30239 L
.29902 .30227 L
.30033 .30228 L
.30163 .30243 L
.30284 .30269 L
.30416 .30309 L
.30556 .30363 L
.30792 .30479 L
.31052 .30639 L
.31982 .31389 L
.33072 .32408 L
.34072 .33285 L
.34995 .33949 L
.36005 .34479 L
.3653 .34676 L
.3702 .34818 L
.37537 .3493 L
.3809 .35019 L
.38621 .35084 L
.39112 .35132 L
.40222 .35231 L
.42236 .35465 L
Mistroke
.44269 .35787 L
.46173 .36086 L
.47997 .36318 L
.49959 .36503 L
.54083 .36778 L
.58056 .36984 L
.61877 .37126 L
.63846 .37181 L
.65944 .3723 L
.67943 .37268 L
.70104 .37301 L
.74113 .37346 L
.76108 .37362 L
.78215 .37375 L
.82014 .37393 L
.83967 .37399 L
.86059 .37405 L
.90197 .37414 L
.94183 .3742 L
.97619 .37425 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.06244 .23869 L
.08255 .36436 L
.10458 .48503 L
.11448 .53042 L
.11992 .55197 L
.12507 .56946 L
.12986 .58261 L
.13256 .5884 L
.13385 .59067 L
.13506 .59249 L
.13616 .59386 L
.13716 .59487 L
.13827 .59568 L
.13947 .59619 L
.14062 .59628 L
.14187 .59591 L
.14305 .59506 L
.14415 .59382 L
.14544 .59174 L
.1468 .58875 L
.14796 .58549 L
.14923 .58109 L
.15207 .56772 L
.15472 .55 L
.15723 .52757 L
.15952 .50166 L
.16467 .42398 L
.16925 .34373 L
.17166 .30655 L
.17299 .28954 L
.17423 .27604 L
.1754 .26557 L
.17646 .25776 L
.17765 .25094 L
.17893 .24552 L
.17994 .24249 L
.18105 .24028 L
.18221 .23903 L
.18328 .23871 L
.18456 .23922 L
.1852 .23979 L
.18591 .24065 L
.18716 .24265 L
.18833 .24503 L
.1938 .26065 L
.20374 .29797 L
.21263 .33227 L
.22233 .3641 L
.22494 .37088 L
Mistroke
.22773 .37685 L
.22908 .3792 L
.23035 .38102 L
.2315 .3823 L
.23273 .38325 L
.23393 .3837 L
.23524 .38357 L
.2359 .38324 L
.23661 .38266 L
.23788 .38099 L
.23916 .37839 L
.24036 .37497 L
.24144 .37098 L
.24261 .36553 L
.24484 .35155 L
.24729 .32968 L
.24985 .29931 L
.25225 .26577 L
.25448 .23409 L
.25686 .20428 L
.25911 .18215 L
.26115 .16708 L
.26232 .1603 L
.26358 .15421 L
.26586 .14589 L
.26716 .1424 L
.26854 .13952 L
.26972 .13761 L
.27101 .13601 L
.2717 .13535 L
.27236 .13483 L
.27359 .13413 L
.27428 .13387 L
.27492 .13372 L
.27562 .13364 L
.27637 .13364 L
.27759 .13383 L
.27875 .1342 L
.28001 .1348 L
.28137 .13565 L
.28362 .13745 L
.28608 .13992 L
.29103 .14611 L
.29989 .15991 L
.32112 .19738 L
.34042 .22576 L
.35004 .23571 L
.35511 .2398 L
.36048 .24337 L
.37034 .24831 L
Mistroke
.37943 .25168 L
.41729 .26339 L
.43834 .26989 L
.45759 .27482 L
.47749 .27858 L
.49639 .28118 L
.5346 .28509 L
.55593 .28686 L
.57526 .28821 L
.61441 .29025 L
.63368 .291 L
.6545 .29167 L
.67406 .29218 L
.69552 .29264 L
.73503 .29326 L
.75456 .29349 L
.77548 .29369 L
.81686 .29399 L
.85672 .29421 L
.89507 .29439 L
.93587 .29455 L
.97516 .2947 L
.97619 .2947 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36434 L
.10458 .48505 L
.11448 .53046 L
.11992 .55204 L
.12507 .56958 L
.12986 .58278 L
.13256 .58861 L
.13385 .59091 L
.13506 .59276 L
.13616 .59416 L
.13716 .5952 L
.13827 .59605 L
.13947 .5966 L
.14062 .59674 L
.14187 .59643 L
.14305 .59566 L
.14415 .59449 L
.14544 .59251 L
.1468 .58966 L
.14796 .58653 L
.14923 .5823 L
.15207 .56944 L
.15472 .55243 L
.15723 .531 L
.15952 .50636 L
.16467 .43302 L
.16925 .35714 L
.17166 .32135 L
.17423 .29131 L
.17646 .27286 L
.17774 .26542 L
.17893 .26023 L
.18002 .25685 L
.18102 .25477 L
.18212 .25346 L
.18328 .25306 L
.18452 .25358 L
.18521 .25425 L
.18585 .25509 L
.18703 .25711 L
.18828 .25985 L
.19283 .27373 L
.20302 .31671 L
.22139 .40005 L
.23083 .43691 L
.23603 .45429 L
.24096 .46832 L
.24554 .47864 L
Mistroke
.24813 .48305 L
.24937 .48473 L
.25053 .48604 L
.2516 .48698 L
.25276 .48772 L
.2538 .48814 L
.25477 .4883 L
.25582 .48823 L
.25696 .48787 L
.25816 .4872 L
.25928 .48631 L
.26189 .48335 L
.2643 .47971 L
.26976 .46931 L
.27967 .44746 L
.28861 .42923 L
.29824 .41411 L
.30328 .40831 L
.30789 .40418 L
.3123 .40117 L
.31694 .39882 L
.31941 .39786 L
.32205 .39701 L
.32679 .39585 L
.33244 .39487 L
.33756 .39414 L
.3469 .39266 L
.35161 .39167 L
.35678 .3903 L
.36761 .38648 L
.37759 .38202 L
.39871 .37174 L
.41798 .36379 L
.43794 .35778 L
.45686 .35344 L
.49516 .34602 L
.53591 .33951 L
.57514 .33483 L
.61286 .33132 L
.65303 .32839 L
.69168 .32622 L
.73279 .32441 L
.77238 .32301 L
.81046 .3219 L
.85099 .32088 L
.89 .32 L
.93147 .31916 L
.97142 .3184 L
.97619 .31831 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.06244 .23871 L
.08255 .36438 L
.10458 .48504 L
.11448 .53041 L
.11992 .55194 L
.12507 .56941 L
.12986 .58253 L
.13256 .58829 L
.13385 .59055 L
.13506 .59235 L
.13616 .59371 L
.13716 .5947 L
.13827 .5955 L
.13947 .59599 L
.14062 .59606 L
.14187 .59565 L
.14305 .59478 L
.14415 .5935 L
.14544 .59138 L
.1468 .58834 L
.14796 .58503 L
.14923 .58056 L
.15207 .567 L
.15472 .54903 L
.15723 .5263 L
.15952 .50002 L
.16467 .42124 L
.16925 .3402 L
.17166 .30292 L
.17299 .28596 L
.17423 .27255 L
.1754 .2622 L
.17646 .25452 L
.17765 .24783 L
.17893 .24257 L
.17994 .23966 L
.18105 .23757 L
.18221 .23644 L
.18328 .23621 L
.18456 .23682 L
.1852 .23744 L
.18591 .23834 L
.18716 .24042 L
.18833 .24286 L
.1938 .2587 L
.20374 .29625 L
.21263 .33071 L
.22233 .36265 L
.22494 .36942 L
Mistroke
.22773 .37537 L
.22908 .37769 L
.23035 .37949 L
.2315 .38073 L
.23273 .38164 L
.23393 .38203 L
.23524 .38183 L
.2359 .38145 L
.23661 .38082 L
.23788 .37903 L
.23916 .3763 L
.24036 .3727 L
.24144 .36853 L
.24261 .36284 L
.24484 .34825 L
.24729 .32541 L
.24985 .29367 L
.25225 .2587 L
.25448 .2259 L
.25686 .19539 L
.25911 .17306 L
.26115 .15805 L
.26232 .15138 L
.26358 .14543 L
.26586 .13737 L
.26716 .13404 L
.26854 .1313 L
.26972 .1295 L
.27101 .12801 L
.2717 .12739 L
.27236 .12691 L
.27359 .12627 L
.27428 .12604 L
.27492 .1259 L
.27562 .12583 L
.27637 .12584 L
.27759 .12602 L
.27875 .12636 L
.28001 .12692 L
.28137 .1277 L
.28362 .12933 L
.28608 .13155 L
.29103 .13705 L
.29989 .14907 L
.32112 .18023 L
.33116 .19265 L
.34042 .20171 L
.35004 .20859 L
.35511 .21131 L
.36048 .21367 L
Mistroke
.37943 .21963 L
.41729 .23161 L
.43834 .2387 L
.45759 .24395 L
.47749 .2479 L
.49639 .25064 L
.5346 .25484 L
.55593 .25672 L
.57526 .25814 L
.61441 .26023 L
.63368 .26098 L
.6545 .26164 L
.67406 .26214 L
.69552 .26259 L
.73503 .26317 L
.75456 .26338 L
.77548 .26356 L
.81686 .26385 L
.85672 .26406 L
.89507 .26424 L
.93587 .26441 L
.97516 .26457 L
.97619 .26458 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.06244 .23872 L
.08255 .3644 L
.10458 .48507 L
.11448 .53043 L
.11992 .55196 L
.12507 .56942 L
.12986 .58254 L
.13256 .5883 L
.13385 .59056 L
.13506 .59237 L
.13616 .59373 L
.13716 .59472 L
.13827 .59552 L
.13947 .59601 L
.14062 .59609 L
.14187 .59569 L
.14305 .59483 L
.14415 .59357 L
.14544 .59147 L
.1468 .58846 L
.14796 .58518 L
.14923 .58076 L
.15207 .56736 L
.15472 .54965 L
.15723 .52732 L
.15952 .50163 L
.16467 .42522 L
.16925 .34709 L
.17166 .31101 L
.17299 .29449 L
.17423 .28138 L
.1754 .27122 L
.17646 .26366 L
.17765 .25709 L
.17893 .25194 L
.17994 .24912 L
.18105 .24715 L
.18221 .24617 L
.18328 .24611 L
.18456 .24695 L
.1852 .24771 L
.18591 .24877 L
.18833 .25391 L
.19116 .26223 L
.1938 .27162 L
.20374 .31415 L
.22233 .39705 L
.23273 .43552 L
.23786 .45076 L
Mistroke
.24036 .45701 L
.24261 .46187 L
.24468 .46556 L
.24691 .46859 L
.24814 .46979 L
.24927 .47057 L
.25034 .471 L
.25148 .47112 L
.25264 .47086 L
.25387 .47017 L
.25503 .46913 L
.25609 .46787 L
.25869 .46367 L
.26115 .45852 L
.27941 .40906 L
.28441 .39675 L
.28979 .38538 L
.29445 .37728 L
.29953 .37026 L
.30457 .36501 L
.30714 .36292 L
.30988 .36106 L
.31245 .35963 L
.31478 .35856 L
.31935 .35697 L
.32205 .35626 L
.32454 .35573 L
.33017 .35476 L
.33509 .35399 L
.34037 .35303 L
.34545 .35185 L
.35009 .35047 L
.35917 .34686 L
.37982 .33531 L
.40049 .32327 L
.41964 .31461 L
.4382 .30845 L
.45793 .30315 L
.49565 .2941 L
.53582 .28618 L
.57448 .28045 L
.61558 .2757 L
.65518 .27218 L
.69325 .26958 L
.73378 .26744 L
.77279 .26582 L
.81426 .26443 L
.85421 .2633 L
.89264 .26237 L
.93353 .26147 L
Mistroke
.9729 .26069 L
.97619 .26063 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.06244 .23847 L
.08255 .36415 L
.10458 .485 L
.11448 .53057 L
.11992 .55229 L
.12507 .57003 L
.12986 .5835 L
.13238 .58918 L
.13506 .59392 L
.13614 .59542 L
.13731 .59675 L
.13859 .59783 L
.13979 .59846 L
.14096 .59869 L
.14207 .59854 L
.14306 .59806 L
.14415 .59716 L
.1448 .59642 L
.14548 .59547 L
.1467 .59329 L
.14802 .59022 L
.14946 .58591 L
.15205 .57538 L
.15447 .56182 L
.15683 .54453 L
.15898 .52485 L
.16382 .4664 L
.16911 .3879 L
.172 .34785 L
.17472 .31788 L
.17702 .29959 L
.17832 .29212 L
.17951 .28689 L
.18074 .28294 L
.18144 .28131 L
.18209 .28014 L
.1834 .27874 L
.18413 .27845 L
.1848 .27847 L
.18599 .2791 L
.18725 .28048 L
.18832 .28217 L
.18951 .28449 L
.19461 .2985 L
.20388 .33191 L
.21473 .37264 L
.22464 .40565 L
.22942 .41879 L
.23194 .42467 L
Mistroke
.23462 .42988 L
.23595 .43199 L
.2372 .43363 L
.23832 .43479 L
.23953 .43567 L
.24069 .4361 L
.24191 .43608 L
.24295 .43562 L
.24409 .43459 L
.24476 .43371 L
.24549 .4325 L
.24682 .42957 L
.24812 .42575 L
.24931 .42131 L
.25202 .40794 L
.2549 .38961 L
.26016 .3526 L
.26498 .32242 L
.26947 .29963 L
.27438 .28072 L
.27693 .27323 L
.27931 .2676 L
.28182 .26296 L
.28321 .26091 L
.28449 .25934 L
.28562 .25819 L
.28686 .25717 L
.28811 .25638 L
.28943 .25579 L
.29059 .25547 L
.29183 .25531 L
.29301 .25532 L
.29408 .25546 L
.29519 .25573 L
.29622 .25609 L
.29855 .25722 L
.3006 .25856 L
.30279 .26027 L
.32245 .28232 L
.3405 .30176 L
.34991 .30912 L
.35465 .31201 L
.35983 .31457 L
.36504 .31661 L
.37062 .31828 L
.37589 .31948 L
.38067 .32035 L
.42062 .32642 L
.45906 .33373 L
.47891 .33659 L
Mistroke
.49994 .33877 L
.5378 .34162 L
.55885 .34293 L
.57811 .34396 L
.6169 .34554 L
.6359 .34612 L
.65663 .34663 L
.67796 .34707 L
.69729 .34739 L
.73644 .34786 L
.7557 .34802 L
.77653 .34817 L
.79609 .34828 L
.81755 .34837 L
.85706 .34851 L
.8975 .34862 L
.93643 .34871 L
.97619 .3488 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.06244 .23867 L
.08255 .36436 L
.10458 .48505 L
.11448 .53045 L
.11992 .55202 L
.12507 .56954 L
.12986 .58272 L
.13256 .58853 L
.13385 .59082 L
.13506 .59265 L
.13616 .59404 L
.13716 .59507 L
.13827 .59591 L
.13947 .59644 L
.14062 .59657 L
.14187 .59623 L
.14305 .59544 L
.14415 .59424 L
.14544 .59223 L
.1468 .58933 L
.14796 .58616 L
.14923 .58188 L
.15207 .56886 L
.15472 .55165 L
.15723 .52995 L
.15952 .50498 L
.16467 .43064 L
.16925 .35389 L
.17166 .31788 L
.17299 .3012 L
.17423 .28784 L
.17646 .26953 L
.17765 .26261 L
.17893 .2571 L
.18004 .25377 L
.1812 .25154 L
.18219 .25052 L
.18328 .25024 L
.1846 .25089 L
.18582 .25233 L
.18645 .25335 L
.18715 .25468 L
.18857 .25791 L
.19356 .27379 L
.20289 .31344 L
.22384 .40762 L
.23382 .44456 L
.23873 .45951 L
.24329 .47085 L
Mistroke
.24582 .47586 L
.24851 .47997 L
.24925 .48085 L
.25005 .48167 L
.25076 .48227 L
.2515 .48279 L
.25217 .48315 L
.25291 .48341 L
.25421 .48356 L
.25551 .48331 L
.2567 .48272 L
.25736 .48226 L
.25807 .48165 L
.25937 .48028 L
.26187 .47678 L
.26418 .47274 L
.27395 .45103 L
.28447 .42669 L
.28932 .41694 L
.29441 .40817 L
.29917 .40142 L
.3035 .39648 L
.30803 .39243 L
.31287 .38919 L
.31734 .38702 L
.32157 .38554 L
.3265 .38429 L
.33104 .38344 L
.3413 .38176 L
.34599 .38084 L
.35102 .37961 L
.3601 .37664 L
.3709 .37188 L
.38076 .3668 L
.40143 .35606 L
.42057 .34812 L
.43913 .34249 L
.45887 .3378 L
.49659 .33006 L
.53676 .32333 L
.57541 .31853 L
.61652 .31463 L
.65611 .31179 L
.69419 .30975 L
.73472 .30813 L
.77373 .30695 L
.8152 .30598 L
.85515 .30523 L
.89358 .30462 L
.93447 .30405 L
Mistroke
.97384 .30356 L
.97619 .30353 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.06244 .23826 L
.08255 .36396 L
.10458 .48497 L
.11448 .53072 L
.11992 .55259 L
.12507 .57052 L
.12986 .58426 L
.13238 .59012 L
.13506 .59512 L
.13731 .59821 L
.13859 .59946 L
.13979 .60028 L
.14089 .6007 L
.14189 .60079 L
.14305 .60052 L
.14415 .59987 L
.1454 .59865 L
.1461 .59771 L
.14674 .59669 L
.1479 .59442 L
.14918 .59126 L
.1514 .58396 L
.15374 .57343 L
.15629 .5582 L
.15902 .53701 L
.16396 .48537 L
.16859 .4254 L
.17113 .39252 L
.17351 .36496 L
.1757 .34406 L
.17771 .32925 L
.17877 .32308 L
.17994 .3176 L
.18111 .31335 L
.18234 .3101 L
.18303 .3088 L
.18368 .30786 L
.18489 .30684 L
.1862 .30666 L
.18694 .30694 L
.18761 .30741 L
.18875 .3086 L
.19 .31044 L
.19252 .31552 L
.19824 .33147 L
.20358 .34924 L
.22371 .41794 L
.22868 .43274 L
.23411 .44664 L
Mistroke
.2366 .45194 L
.23924 .45659 L
.24052 .45841 L
.24173 .45982 L
.24282 .4608 L
.24399 .46152 L
.24515 .46185 L
.24624 .46178 L
.24742 .46123 L
.24869 .46005 L
.24933 .4592 L
.25003 .45808 L
.25129 .45549 L
.25365 .44865 L
.25589 .43995 L
.25827 .42888 L
.26253 .40667 L
.27193 .36044 L
.27721 .34028 L
.28204 .32625 L
.2863 .31728 L
.28871 .31349 L
.29096 .31074 L
.29218 .30953 L
.29334 .30856 L
.29549 .30718 L
.2967 .30663 L
.29782 .30626 L
.29904 .306 L
.30033 .30587 L
.30155 .30588 L
.30224 .30594 L
.30287 .30602 L
.30404 .30626 L
.30528 .30661 L
.30743 .30744 L
.30979 .30865 L
.31503 .31216 L
.31995 .31618 L
.33827 .33256 L
.34809 .33993 L
.35344 .34317 L
.35843 .34566 L
.36305 .34754 L
.36726 .34891 L
.37193 .3501 L
.37693 .35107 L
.38177 .35177 L
.38689 .35234 L
.39609 .35315 L
Mistroke
.40611 .35405 L
.41688 .35528 L
.43643 .35822 L
.45473 .36125 L
.47446 .36403 L
.49598 .36626 L
.51658 .36783 L
.5357 .36905 L
.57485 .37116 L
.59484 .37202 L
.61646 .37278 L
.65654 .37382 L
.6765 .3742 L
.69757 .37453 L
.73556 .37497 L
.75508 .37513 L
.776 .37527 L
.79583 .37538 L
.81738 .37548 L
.85725 .37561 L
.89805 .37571 L
.93734 .3758 L
.97511 .37587 L
.97619 .37587 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.06244 .23877 L
.08255 .36445 L
.10458 .48508 L
.11448 .53039 L
.11992 .55188 L
.12507 .5693 L
.12986 .58234 L
.13256 .58805 L
.13385 .59027 L
.13506 .59205 L
.13616 .59337 L
.13716 .59433 L
.13827 .59509 L
.13947 .59553 L
.14062 .59555 L
.14187 .59509 L
.14305 .59415 L
.14415 .59281 L
.14544 .5906 L
.1468 .58747 L
.14923 .57949 L
.15058 .57355 L
.15185 .56691 L
.15472 .54732 L
.15723 .52423 L
.15952 .49762 L
.16467 .41853 L
.16925 .33844 L
.17166 .30211 L
.17299 .28571 L
.17423 .27284 L
.1754 .26298 L
.17646 .25574 L
.17765 .24953 L
.17893 .24477 L
.17994 .24224 L
.18105 .24056 L
.18221 .23986 L
.18328 .24003 L
.18456 .2411 L
.1852 .24196 L
.18591 .24312 L
.18833 .24854 L
.19116 .25704 L
.1938 .26651 L
.20374 .30877 L
.22233 .38984 L
.22731 .40849 L
.23273 .42624 L
Mistroke
.23522 .43323 L
.23786 .43972 L
.24034 .44476 L
.24261 .44832 L
.24379 .4497 L
.24502 .45076 L
.24627 .4514 L
.24697 .45155 L
.24763 .45155 L
.24882 .45117 L
.2499 .45039 L
.25116 .44893 L
.25234 .44702 L
.25454 .44213 L
.25656 .43628 L
.26115 .42002 L
.27092 .38205 L
.27605 .36365 L
.28144 .34674 L
.28619 .33429 L
.29138 .3234 L
.29609 .31583 L
.30047 .31057 L
.30284 .30834 L
.3054 .30636 L
.30767 .30493 L
.31006 .30371 L
.31222 .30282 L
.31459 .30204 L
.31876 .30104 L
.32896 .29949 L
.3338 .29868 L
.33827 .29767 L
.34306 .2962 L
.34827 .29409 L
.35776 .28889 L
.37866 .27373 L
.39889 .25989 L
.4179 .25047 L
.43604 .24399 L
.45562 .23816 L
.49672 .22698 L
.53632 .2185 L
.57439 .21247 L
.61492 .20749 L
.65393 .20385 L
.6954 .20096 L
.73535 .19884 L
.77378 .19726 L
.81467 .19593 L
Mistroke
.85404 .19489 L
.8919 .19405 L
.9322 .19329 L
.97099 .19266 L
.97619 .19258 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.06244 .23827 L
.08255 .36397 L
.10458 .48498 L
.11448 .53073 L
.11992 .5526 L
.12507 .57054 L
.12986 .58429 L
.13238 .59015 L
.13506 .59515 L
.13731 .59826 L
.13859 .59952 L
.13979 .60034 L
.14089 .60077 L
.14189 .60086 L
.14305 .60061 L
.14415 .59997 L
.1454 .59876 L
.1461 .59784 L
.14674 .59682 L
.1479 .59457 L
.14918 .59144 L
.1514 .5842 L
.15374 .57375 L
.15629 .55864 L
.15902 .53762 L
.16396 .48642 L
.16859 .42689 L
.17113 .39415 L
.17351 .36655 L
.1757 .34549 L
.17771 .33046 L
.17877 .32416 L
.17994 .31854 L
.18111 .31415 L
.18234 .31078 L
.18303 .30941 L
.18368 .30842 L
.18489 .30731 L
.1862 .30707 L
.18694 .30733 L
.18761 .30779 L
.18875 .30899 L
.19 .31086 L
.19252 .31612 L
.19824 .33296 L
.20358 .3522 L
.22371 .43083 L
.23411 .46798 L
.24399 .49749 L
Mistroke
.24829 .50778 L
.25286 .51645 L
.25549 .52015 L
.25788 .52257 L
.25903 .5234 L
.26028 .52404 L
.26145 .52441 L
.26253 .52453 L
.2638 .52444 L
.265 .52411 L
.26607 .52363 L
.26724 .52292 L
.26987 .52067 L
.27229 .51791 L
.28139 .50394 L
.29206 .48614 L
.30207 .47253 L
.31108 .46385 L
.31614 .46036 L
.32077 .45791 L
.32557 .45601 L
.33082 .45452 L
.33347 .45395 L
.3363 .45343 L
.34139 .45269 L
.35166 .45143 L
.35706 .45065 L
.36277 .4496 L
.37327 .44697 L
.38294 .44378 L
.42088 .42968 L
.44036 .42439 L
.46127 .42032 L
.5026 .41418 L
.54241 .40944 L
.58071 .40612 L
.62146 .40348 L
.66069 .40156 L
.69841 .40018 L
.73858 .39907 L
.77724 .39825 L
.81834 .39756 L
.85794 .39702 L
.89601 .39656 L
.93654 .39612 L
.97555 .39573 L
.97619 .39573 L
Mfstroke
0 .751 1 r
.02381 .01472 m
.06244 .23811 L
.08255 .36384 L
.10458 .48497 L
.11448 .53084 L
.11992 .55281 L
.12507 .57089 L
.12986 .58482 L
.13238 .59082 L
.13506 .59598 L
.13731 .59926 L
.13859 .60063 L
.13979 .60157 L
.14089 .60212 L
.14189 .60234 L
.14305 .60224 L
.14415 .60177 L
.1454 .60078 L
.1461 .59998 L
.14674 .5991 L
.14793 .59706 L
.14918 .59429 L
.15135 .58786 L
.15374 .57815 L
.15629 .5643 L
.15902 .54502 L
.16396 .49807 L
.16859 .443 L
.17351 .3852 L
.17553 .36555 L
.17771 .34836 L
.17896 .34049 L
.1801 .33452 L
.18119 .32991 L
.18234 .32603 L
.18357 .32303 L
.18471 .32116 L
.18541 .3204 L
.18607 .31995 L
.1873 .3197 L
.1886 .32021 L
.1898 .32129 L
.19112 .32305 L
.19252 .3255 L
.19524 .33165 L
.19779 .33867 L
.20358 .35764 L
.22371 .43355 L
.23411 .47044 L
.24399 .50014 L
Mistroke
.24829 .51067 L
.25286 .51973 L
.25549 .52373 L
.25788 .52647 L
.25903 .52747 L
.26028 .52831 L
.26145 .52886 L
.26253 .52916 L
.2638 .52927 L
.265 .52914 L
.26607 .52882 L
.26724 .52829 L
.26852 .52749 L
.26987 .52641 L
.27229 .52394 L
.27662 .51821 L
.28139 .51068 L
.29219 .49292 L
.30207 .47942 L
.31152 .47024 L
.31627 .46693 L
.32145 .46416 L
.32669 .46212 L
.32962 .46125 L
.33227 .4606 L
.33745 .45962 L
.34232 .45893 L
.35118 .45788 L
.36068 .45651 L
.36613 .45544 L
.3711 .45425 L
.38084 .45133 L
.40076 .44393 L
.42181 .43645 L
.44088 .43134 L
.46163 .42733 L
.50238 .42137 L
.54161 .41675 L
.57933 .41348 L
.6195 .41089 L
.65816 .409 L
.69926 .40751 L
.73886 .40644 L
.77693 .40564 L
.81746 .40497 L
.85647 .40444 L
.89794 .40396 L
.93789 .40354 L
.97619 .40316 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.06244 .23839 L
.08255 .36408 L
.10458 .485 L
.11448 .53064 L
.11992 .55242 L
.12507 .57023 L
.12986 .58381 L
.13238 .58956 L
.13506 .59441 L
.13614 .59596 L
.13731 .59735 L
.13859 .5985 L
.13979 .59921 L
.14096 .59953 L
.14207 .59947 L
.14306 .59909 L
.14415 .5983 L
.1448 .59763 L
.14548 .59677 L
.1467 .59476 L
.14802 .59191 L
.14946 .58787 L
.15205 .57799 L
.15447 .56524 L
.15683 .54902 L
.15898 .53062 L
.16382 .47621 L
.16911 .40275 L
.172 .36425 L
.17472 .33449 L
.17702 .31566 L
.17832 .30773 L
.17951 .30204 L
.18074 .29763 L
.18144 .29574 L
.18209 .29435 L
.1834 .29252 L
.18413 .29202 L
.1848 .29186 L
.18599 .29221 L
.18725 .29335 L
.18832 .29488 L
.18951 .29707 L
.19215 .30349 L
.19461 .31097 L
.20388 .34585 L
.22464 .43019 L
.23505 .46715 L
.24018 .48288 L
Mistroke
.24493 .49551 L
.24958 .50559 L
.25161 .50911 L
.2538 .51223 L
.25506 .51368 L
.25621 .51477 L
.25732 .51559 L
.25848 .51622 L
.25971 .51662 L
.26086 .51675 L
.26212 .51664 L
.26282 .51645 L
.26347 .51621 L
.26465 .51561 L
.26576 .51485 L
.26829 .5125 L
.27075 .5095 L
.27341 .50565 L
.28259 .48974 L
.29252 .47264 L
.29777 .46495 L
.30336 .45809 L
.30882 .45276 L
.31377 .44899 L
.31875 .44611 L
.32344 .44408 L
.32872 .44243 L
.33358 .44135 L
.33892 .44047 L
.34456 .4397 L
.35402 .43832 L
.35933 .43731 L
.36417 .43619 L
.3825 .43015 L
.40317 .42174 L
.42231 .41487 L
.44087 .40992 L
.46061 .40605 L
.49832 .40023 L
.5385 .39522 L
.57715 .39171 L
.61826 .38897 L
.65785 .38699 L
.69593 .38559 L
.73645 .38449 L
.77547 .3837 L
.81693 .38306 L
.85688 .38256 L
.89532 .38216 L
.9362 .38178 L
Mistroke
.97557 .38145 L
.97619 .38145 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.06244 .23835 L
.08255 .36404 L
.10458 .48499 L
.11448 .53067 L
.11992 .55248 L
.12507 .57034 L
.12986 .58399 L
.13238 .58978 L
.13506 .59469 L
.13614 .59627 L
.13731 .59769 L
.13859 .59889 L
.13979 .59964 L
.14096 .60001 L
.14207 .6 L
.14306 .59967 L
.14415 .59895 L
.1448 .59833 L
.14548 .59751 L
.1467 .59559 L
.14802 .59285 L
.14946 .58897 L
.15205 .57941 L
.15447 .56708 L
.15683 .55138 L
.15898 .5336 L
.16382 .48108 L
.16911 .40996 L
.172 .37229 L
.17472 .34276 L
.17702 .32378 L
.17832 .31567 L
.17951 .30979 L
.18074 .30515 L
.18144 .30312 L
.18209 .30161 L
.1834 .29952 L
.18413 .29888 L
.1848 .2986 L
.18599 .29872 L
.18725 .29965 L
.18832 .30099 L
.18951 .30298 L
.19215 .30899 L
.19461 .3161 L
.20388 .34979 L
.22464 .43261 L
.23505 .46947 L
.24018 .4853 L
Mistroke
.24493 .49814 L
.24958 .50857 L
.2538 .5157 L
.25496 .51721 L
.25621 .51859 L
.25729 .51958 L
.25848 .52044 L
.25975 .52108 L
.26044 .52132 L
.26108 .52146 L
.26223 .52154 L
.26347 .52138 L
.26469 .52098 L
.26539 .52065 L
.26604 .52027 L
.26877 .51807 L
.27113 .51546 L
.27367 .51206 L
.28475 .49365 L
.29437 .47798 L
.29945 .47101 L
.30488 .46479 L
.31034 .4598 L
.31529 .45628 L
.32027 .45358 L
.32496 .45168 L
.33024 .45015 L
.3351 .44914 L
.34043 .44832 L
.34607 .4476 L
.35553 .44628 L
.36084 .44532 L
.36569 .44424 L
.37509 .44156 L
.38401 .43841 L
.42231 .42403 L
.44206 .4188 L
.46306 .41479 L
.50078 .40913 L
.54095 .40425 L
.5796 .40083 L
.62071 .39814 L
.6603 .3962 L
.69838 .3948 L
.73891 .3937 L
.77792 .39289 L
.81939 .39222 L
.85934 .39169 L
.89777 .39126 L
.93866 .39084 L
Mistroke
.97619 .39049 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36433 L
.10458 .48503 L
.11448 .53044 L
.11992 .55201 L
.12507 .56953 L
.12986 .58273 L
.13256 .58854 L
.13385 .59083 L
.13506 .59267 L
.13616 .59406 L
.13716 .59509 L
.13827 .59593 L
.13947 .59646 L
.14062 .59658 L
.14187 .59625 L
.14305 .59545 L
.14415 .59424 L
.14544 .59222 L
.1468 .58931 L
.14796 .58612 L
.14923 .58181 L
.1506 .57612 L
.15207 .56869 L
.15472 .55129 L
.15739 .52768 L
.15993 .49886 L
.16467 .42774 L
.169 .35302 L
.17136 .31613 L
.17359 .28809 L
.17598 .26627 L
.17725 .25805 L
.17791 .25464 L
.17862 .2515 L
.17981 .24754 L
.18105 .24482 L
.18221 .24345 L
.18328 .24302 L
.18456 .24343 L
.1852 .24395 L
.18591 .24476 L
.18716 .24669 L
.18833 .24901 L
.19097 .2557 L
.1938 .26452 L
.20374 .30193 L
.21338 .33928 L
.22233 .36897 L
Mistroke
.22723 .38138 L
.22865 .3842 L
.22998 .38649 L
.23116 .38818 L
.23246 .38963 L
.23315 .3902 L
.2338 .3906 L
.23449 .39088 L
.23522 .39098 L
.23591 .39089 L
.23655 .39063 L
.23777 .38963 L
.23846 .38873 L
.23919 .3875 L
.24052 .38445 L
.24194 .37985 L
.2435 .37291 L
.24477 .36562 L
.24611 .35617 L
.2485 .33432 L
.25388 .26648 L
.2565 .23293 L
.25898 .20667 L
.2612 .18832 L
.2636 .17341 L
.26603 .16257 L
.26725 .15838 L
.26859 .15459 L
.26973 .15195 L
.27096 .14964 L
.27211 .14792 L
.27317 .14667 L
.27449 .14552 L
.27518 .14507 L
.27591 .1447 L
.27715 .14433 L
.27785 .14424 L
.27851 .14422 L
.27973 .14438 L
.28086 .1447 L
.28209 .14525 L
.28338 .14601 L
.28558 .14768 L
.28793 .14994 L
.29216 .15499 L
.30176 .16952 L
.32165 .20364 L
.33213 .21962 L
.34323 .23315 L
.35312 .24191 L
Mistroke
.35874 .24565 L
.36401 .24848 L
.37325 .2523 L
.38318 .25547 L
.42442 .26787 L
.44503 .27393 L
.46415 .27836 L
.48265 .2815 L
.50236 .28397 L
.54397 .28789 L
.56485 .28943 L
.58405 .2906 L
.62262 .29231 L
.64146 .29292 L
.66213 .29346 L
.68329 .2939 L
.70258 .29422 L
.7415 .29468 L
.7606 .29483 L
.78137 .29497 L
.82217 .29517 L
.86146 .29531 L
.89923 .29543 L
.93945 .29554 L
.97619 .29564 L
Mfstroke
0 .656 1 r
.02381 .01472 m
.06244 .23835 L
.08255 .36404 L
.10458 .48498 L
.11448 .53065 L
.11992 .55246 L
.12507 .57032 L
.12986 .58395 L
.13238 .58974 L
.13506 .59463 L
.13614 .59621 L
.13731 .59762 L
.13859 .5988 L
.13979 .59954 L
.14096 .5999 L
.14207 .59987 L
.14306 .59953 L
.14415 .59878 L
.1448 .59815 L
.14548 .59731 L
.1467 .59537 L
.14802 .59259 L
.14946 .58865 L
.15205 .57897 L
.15447 .56647 L
.15683 .55054 L
.15898 .53247 L
.16382 .47902 L
.16911 .40677 L
.172 .36883 L
.17472 .33941 L
.17702 .3207 L
.17832 .31276 L
.17951 .30702 L
.18074 .30251 L
.18144 .30055 L
.18209 .29908 L
.1834 .29707 L
.18413 .29645 L
.1848 .29618 L
.18599 .2963 L
.18725 .29717 L
.18832 .29845 L
.18951 .30034 L
.19215 .30602 L
.19461 .3127 L
.20388 .34381 L
.21453 .38219 L
.22464 .41569 L
.22934 .42918 L
Mistroke
.23435 .44122 L
.23723 .44664 L
.23859 .4487 L
.23984 .45026 L
.2411 .45148 L
.24176 .45196 L
.24246 .45233 L
.24364 .45264 L
.24493 .45244 L
.24618 .45167 L
.24735 .45035 L
.24841 .44864 L
.24956 .44617 L
.25081 .44272 L
.25214 .43819 L
.25452 .42797 L
.26347 .37827 L
.27286 .33287 L
.27814 .31474 L
.28065 .30806 L
.28298 .30291 L
.28521 .29887 L
.28724 .29592 L
.28949 .29337 L
.29074 .29226 L
.29189 .29143 L
.293 .29078 L
.29421 .29024 L
.29543 .28986 L
.29672 .28963 L
.29785 .28956 L
.29907 .28961 L
.30022 .28978 L
.30127 .29002 L
.30244 .29039 L
.30355 .29083 L
.30607 .2921 L
.31117 .29563 L
.32033 .30393 L
.33044 .31394 L
.34108 .32353 L
.35071 .33042 L
.35616 .33345 L
.36124 .33571 L
.36584 .33733 L
.37018 .33855 L
.37519 .33963 L
.37974 .34039 L
.39803 .34243 L
.41817 .3449 L
Mistroke
.43802 .34822 L
.45906 .35181 L
.47848 .35447 L
.49937 .35655 L
.52052 .35815 L
.54061 .35944 L
.57882 .3615 L
.60016 .3624 L
.61949 .36306 L
.65864 .36407 L
.6779 .36444 L
.69872 .36477 L
.71829 .36502 L
.73975 .36523 L
.77925 .36552 L
.79878 .36562 L
.8197 .36571 L
.86108 .36585 L
.90095 .36596 L
.93929 .36604 L
.97619 .36611 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.06244 .23874 L
.08255 .36442 L
.10458 .48505 L
.11448 .53038 L
.11992 .55189 L
.12507 .56932 L
.12986 .58239 L
.13256 .58811 L
.13385 .59034 L
.13506 .59212 L
.13616 .59346 L
.13716 .59442 L
.13827 .59519 L
.13947 .59564 L
.14062 .59567 L
.14187 .59522 L
.14305 .59429 L
.14415 .59296 L
.14544 .59076 L
.1468 .58763 L
.14796 .58424 L
.14923 .57966 L
.15207 .56578 L
.15472 .5474 L
.15723 .52414 L
.15952 .49725 L
.16467 .41673 L
.16925 .33449 L
.17166 .29712 L
.17299 .28027 L
.17423 .26706 L
.1754 .25693 L
.17646 .24947 L
.17765 .24305 L
.17893 .23806 L
.17994 .23536 L
.18105 .23348 L
.18221 .23255 L
.18328 .2325 L
.18456 .23329 L
.1852 .23399 L
.18591 .23498 L
.18833 .23974 L
.19116 .24739 L
.1938 .25595 L
.20374 .29388 L
.21263 .32857 L
.22233 .36065 L
.22494 .36742 L
Mistroke
.22773 .37335 L
.22908 .37565 L
.23035 .37741 L
.2315 .37862 L
.23273 .37947 L
.23393 .37979 L
.23524 .3795 L
.2359 .37906 L
.23661 .37836 L
.23788 .37642 L
.23916 .3735 L
.24036 .36968 L
.24144 .36526 L
.24261 .35925 L
.24484 .34382 L
.24729 .31967 L
.24985 .28618 L
.25225 .2496 L
.25448 .21588 L
.25686 .18526 L
.25911 .16339 L
.26115 .14895 L
.26232 .14258 L
.26358 .13694 L
.26586 .12932 L
.26716 .12615 L
.26854 .12354 L
.26972 .1218 L
.27101 .12034 L
.2717 .11972 L
.27236 .11923 L
.27359 .11854 L
.27428 .11827 L
.27492 .11809 L
.27562 .11796 L
.27637 .11789 L
.27759 .11794 L
.27875 .11814 L
.28001 .11851 L
.28137 .11907 L
.28362 .12028 L
.28608 .12197 L
.29103 .12622 L
.29989 .13544 L
.3108 .14736 L
.32112 .15715 L
.32561 .1606 L
.33037 .16362 L
.3356 .16617 L
.33812 .16711 L
Mistroke
.34042 .16783 L
.34263 .1684 L
.34504 .1689 L
.34759 .1693 L
.35001 .16958 L
.35226 .16977 L
.35352 .16985 L
.35467 .16991 L
.35689 .17 L
.35899 .17006 L
.36377 .17016 L
.36638 .17022 L
.36881 .1703 L
.37145 .17042 L
.37434 .1706 L
.3768 .1708 L
.37943 .17108 L
.38472 .17181 L
.38962 .17271 L
.40069 .17539 L
.42081 .18157 L
.44108 .18757 L
.4601 .19189 L
.47828 .19488 L
.49787 .19734 L
.53903 .20149 L
.55957 .20314 L
.57867 .20439 L
.6168 .20619 L
.63727 .2069 L
.65587 .20743 L
.67668 .20791 L
.69587 .20827 L
.73436 .20882 L
.77378 .20922 L
.81169 .20953 L
.85205 .20981 L
.89089 .21007 L
.93219 .21034 L
.97197 .2106 L
.97619 .21062 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.06244 .23877 L
.08255 .36445 L
.10458 .48506 L
.11448 .53037 L
.11992 .55186 L
.12507 .56926 L
.12986 .58229 L
.13256 .58798 L
.13385 .5902 L
.13506 .59196 L
.13616 .59328 L
.13716 .59423 L
.13827 .59498 L
.13947 .5954 L
.14062 .5954 L
.14187 .59492 L
.14305 .59396 L
.14415 .59259 L
.14544 .59035 L
.1468 .58716 L
.14923 .57906 L
.15058 .57304 L
.15185 .5663 L
.15472 .54638 L
.15723 .52284 L
.15952 .49565 L
.16467 .41443 L
.16925 .33211 L
.17166 .29504 L
.17299 .27843 L
.17423 .26547 L
.1754 .25558 L
.17646 .24835 L
.17765 .24217 L
.17893 .23744 L
.17994 .23492 L
.18105 .23324 L
.18221 .23251 L
.18328 .23262 L
.18456 .2336 L
.1852 .2344 L
.18591 .23549 L
.18833 .24057 L
.19116 .24856 L
.1938 .25742 L
.20374 .29652 L
.21263 .3325 L
.22233 .36664 L
.22494 .3742 L
Mistroke
.22773 .38115 L
.23035 .38643 L
.23151 .38828 L
.23273 .38987 L
.23401 .39109 L
.23518 .39176 L
.23644 .39194 L
.23716 .39176 L
.23782 .3914 L
.23904 .3902 L
.24014 .38843 L
.24141 .38548 L
.24261 .38167 L
.24368 .37736 L
.24485 .37148 L
.24723 .35543 L
.24943 .33517 L
.2515 .31175 L
.2565 .24787 L
.26115 .19919 L
.26343 .18179 L
.26586 .1674 L
.26856 .15555 L
.27101 .14776 L
.27357 .14193 L
.27501 .13949 L
.27634 .13768 L
.27761 .13631 L
.27879 .1353 L
.28002 .13449 L
.28072 .13413 L
.28137 .13386 L
.28252 .13351 L
.28377 .13331 L
.28487 .13326 L
.28604 .13333 L
.28709 .13349 L
.28807 .13371 L
.28915 .13404 L
.29031 .13446 L
.2953 .13704 L
.29989 .14011 L
.30902 .14688 L
.31879 .15325 L
.32168 .15472 L
.3244 .1559 L
.32706 .15683 L
.32951 .15749 L
.33183 .15795 L
.333 .15812 L
Mistroke
.33429 .15825 L
.33558 .15834 L
.33631 .15837 L
.33697 .15838 L
.33826 .15838 L
.33948 .15833 L
.34073 .15824 L
.34143 .15818 L
.34207 .15811 L
.34452 .15777 L
.34674 .15738 L
.34908 .15688 L
.3593 .15422 L
.36425 .15294 L
.36893 .15189 L
.37313 .15114 L
.3753 .15083 L
.3777 .15056 L
.38009 .15035 L
.3814 .15027 L
.38262 .15021 L
.38377 .15018 L
.38482 .15016 L
.38597 .15015 L
.38718 .15015 L
.3884 .15018 L
.3897 .15022 L
.39093 .15028 L
.39204 .15034 L
.39477 .15054 L
.39735 .15079 L
.40615 .15198 L
.41569 .15362 L
.43519 .15708 L
.44552 .15861 L
.45663 .15994 L
.477 .16171 L
.49605 .16304 L
.53735 .16591 L
.57713 .16829 L
.61539 .17003 L
.65611 .17154 L
.69531 .17273 L
.73696 .17377 L
.7771 .17462 L
.81573 .17533 L
.8568 .176 L
.89636 .17659 L
.93441 .17713 L
.9749 .17766 L
Mistroke
.97619 .17768 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.06244 .23859 L
.08255 .36428 L
.10458 .48504 L
.11448 .53051 L
.11992 .55213 L
.12507 .56973 L
.12986 .58303 L
.13256 .58893 L
.13506 .59316 L
.13607 .5945 L
.13716 .59568 L
.13835 .59664 L
.13947 .5972 L
.14073 .59741 L
.14192 .59716 L
.14299 .59655 L
.14415 .59542 L
.1448 .59457 L
.14548 .59349 L
.1467 .59107 L
.14802 .58769 L
.14946 .58299 L
.15205 .5716 L
.15447 .55696 L
.15683 .5383 L
.15898 .51707 L
.16382 .45395 L
.16898 .37208 L
.1717 .33241 L
.1732 .31405 L
.17459 .2995 L
.17591 .2883 L
.17711 .28007 L
.17845 .27305 L
.17915 .27019 L
.17989 .26774 L
.18111 .26485 L
.18224 .26331 L
.18347 .2627 L
.18417 .2628 L
.1848 .26313 L
.18599 .26434 L
.18711 .26608 L
.18833 .26856 L
.18965 .2718 L
.19478 .28861 L
.20398 .32736 L
.22478 .41786 L
.23491 .45428 L
Mistroke
.24026 .47007 L
.24319 .47743 L
.24595 .48333 L
.24859 .48787 L
.24997 .48977 L
.25143 .49139 L
.25266 .49241 L
.25336 .49285 L
.25401 .49316 L
.25516 .49348 L
.25638 .49351 L
.25763 .4932 L
.25834 .49288 L
.25899 .4925 L
.26018 .49158 L
.26145 .49034 L
.26364 .48758 L
.26606 .48382 L
.2763 .46303 L
.28707 .44018 L
.29627 .42442 L
.30147 .41759 L
.30631 .41258 L
.31137 .40859 L
.31614 .40581 L
.32042 .40397 L
.32505 .40252 L
.33011 .40138 L
.33546 .40046 L
.34505 .3989 L
.35451 .3968 L
.35982 .39522 L
.36466 .39352 L
.38299 .38533 L
.40366 .3755 L
.4228 .36823 L
.44136 .36311 L
.4611 .35891 L
.49882 .35213 L
.53899 .34635 L
.57764 .3423 L
.61875 .33909 L
.65834 .33681 L
.69642 .33521 L
.73695 .33397 L
.77596 .3331 L
.81743 .33241 L
.85738 .3319 L
.89581 .3315 L
.9367 .33113 L
Mistroke
.97607 .33081 L
.97619 .33081 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.06244 .23856 L
.08255 .36423 L
.10458 .48501 L
.11448 .5305 L
.11992 .55216 L
.12507 .56979 L
.12986 .58313 L
.13256 .58907 L
.13506 .59333 L
.13607 .59468 L
.13716 .59588 L
.13835 .59687 L
.13947 .59745 L
.14073 .59769 L
.14192 .59747 L
.14299 .59688 L
.14415 .59579 L
.1448 .59496 L
.14548 .5939 L
.1467 .59152 L
.14802 .5882 L
.14946 .58355 L
.15205 .57227 L
.15447 .55775 L
.15683 .53919 L
.15898 .51802 L
.16382 .45481 L
.16911 .37038 L
.172 .32839 L
.17342 .31126 L
.17472 .29795 L
.17702 .28003 L
.17823 .27335 L
.17951 .26811 L
.18082 .26442 L
.18203 .26233 L
.18273 .26164 L
.18337 .26131 L
.1841 .26124 L
.1848 .26146 L
.1859 .26233 L
.18711 .26393 L
.18838 .2662 L
.18956 .26881 L
.19395 .28146 L
.20388 .31851 L
.21453 .35963 L
.21978 .37801 L
.22464 .39309 L
Mistroke
.22934 .40514 L
.23197 .41041 L
.23435 .41401 L
.23501 .41478 L
.23571 .41547 L
.23697 .41635 L
.23767 .41662 L
.23832 .41673 L
.23904 .41667 L
.2398 .41638 L
.24046 .41594 L
.24118 .41522 L
.24249 .41327 L
.24376 .41044 L
.24493 .40693 L
.24714 .39762 L
.24921 .38535 L
.25392 .34583 L
.25887 .29981 L
.26347 .2652 L
.26818 .23937 L
.27067 .22914 L
.27332 .22049 L
.27612 .21363 L
.27749 .21101 L
.27876 .20899 L
.27989 .2075 L
.28113 .20616 L
.28237 .20511 L
.28369 .20431 L
.28493 .20381 L
.2861 .20357 L
.28716 .20351 L
.28831 .20362 L
.28955 .20392 L
.29018 .20414 L
.29088 .20444 L
.29326 .20582 L
.29548 .20755 L
.29787 .20983 L
.30221 .2148 L
.32183 .24286 L
.33221 .25667 L
.33792 .26313 L
.34331 .26838 L
.34846 .27259 L
.35405 .27631 L
.36382 .281 L
.36864 .28265 L
.37374 .28407 L
Mistroke
.38291 .28608 L
.42076 .29422 L
.44181 .29945 L
.46107 .30353 L
.48096 .30666 L
.49986 .30882 L
.53807 .31208 L
.55941 .31355 L
.57874 .31466 L
.61789 .31632 L
.63715 .3169 L
.65797 .31741 L
.67754 .31779 L
.699 .31812 L
.71943 .31836 L
.7385 .31854 L
.75716 .31868 L
.77743 .31879 L
.79869 .31889 L
.81881 .31897 L
.85962 .31909 L
.8989 .31918 L
.93667 .31927 L
.97619 .31935 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.06244 .23871 L
.08255 .36438 L
.10458 .48504 L
.11448 .5304 L
.11992 .55194 L
.12507 .56941 L
.12986 .58253 L
.13256 .58829 L
.13385 .59055 L
.13506 .59235 L
.13616 .59371 L
.13716 .5947 L
.13827 .5955 L
.13947 .59599 L
.14062 .59606 L
.14187 .59565 L
.14305 .59478 L
.14415 .5935 L
.14544 .59138 L
.1468 .58834 L
.14796 .58503 L
.14923 .58056 L
.15207 .56701 L
.15472 .54904 L
.15723 .5263 L
.15952 .50003 L
.16467 .42128 L
.16925 .3403 L
.17166 .30306 L
.17299 .2861 L
.17423 .27272 L
.1754 .26238 L
.17646 .2547 L
.17765 .24802 L
.17893 .24277 L
.17994 .23987 L
.18105 .23778 L
.18221 .23666 L
.18328 .23645 L
.18456 .23708 L
.1852 .23771 L
.18591 .23862 L
.18716 .24072 L
.18833 .24318 L
.1938 .25914 L
.20374 .29701 L
.21263 .33186 L
.22233 .36436 L
.22494 .37133 L
Mistroke
.22773 .37753 L
.22908 .37999 L
.23035 .38193 L
.2315 .38331 L
.23273 .38438 L
.23393 .38494 L
.23524 .38496 L
.2359 .38469 L
.23661 .38419 L
.23788 .38265 L
.23916 .3802 L
.24036 .3769 L
.24144 .37301 L
.24261 .36766 L
.24484 .35376 L
.2461 .34332 L
.24729 .3317 L
.25225 .26583 L
.25448 .23271 L
.25686 .2014 L
.25911 .17808 L
.26115 .16212 L
.26232 .15491 L
.26358 .1484 L
.26586 .13939 L
.26716 .13554 L
.26854 .13229 L
.26983 .12987 L
.27101 .12813 L
.27224 .1267 L
.27356 .12556 L
.27479 .12482 L
.27595 .12436 L
.2766 .1242 L
.2773 .1241 L
.27855 .12407 L
.27924 .12413 L
.27989 .12425 L
.2806 .12442 L
.28137 .12466 L
.28362 .12567 L
.28608 .1272 L
.29103 .13133 L
.29989 .14085 L
.3108 .15382 L
.32112 .16512 L
.33037 .17323 L
.3356 .17674 L
.34042 .1793 L
.34508 .18119 L
Mistroke
.34944 .18253 L
.35422 .18362 L
.35936 .18448 L
.36977 .1858 L
.37943 .18721 L
.38433 .18815 L
.38955 .18933 L
.40058 .19246 L
.42068 .19945 L
.44067 .20621 L
.45118 .20918 L
.46228 .21179 L
.48316 .21549 L
.50236 .218 L
.54036 .22187 L
.55988 .22341 L
.5808 .2247 L
.60206 .22567 L
.62218 .22634 L
.64211 .22683 L
.66053 .22717 L
.67921 .22742 L
.68984 .22753 L
.69982 .22761 L
.70966 .22767 L
.72002 .22772 L
.72886 .22775 L
.73852 .22777 L
.74382 .22779 L
.74881 .22779 L
.75329 .2278 L
.75815 .2278 L
.76345 .22781 L
.76612 .22781 L
.76765 .22781 L
.76906 .22781 L
.77025 .22781 L
.77156 .22781 L
.77228 .22781 L
.77294 .22781 L
.77425 .22781 L
.77548 .22781 L
.7766 .22781 L
.77789 .22781 L
.77911 .22781 L
.78028 .22781 L
.78153 .22781 L
.78378 .22781 L
.78646 .22781 L
.78891 .22781 L
Mistroke
.79422 .22781 L
.79924 .2278 L
.81773 .22779 L
.836 .22778 L
.84639 .22777 L
.85613 .22777 L
.86568 .22776 L
.87059 .22776 L
.87596 .22776 L
.87888 .22776 L
.88159 .22776 L
.88439 .22776 L
.88561 .22776 L
.88694 .22776 L
.88824 .22776 L
.88944 .22776 L
.89059 .22776 L
.8918 .22776 L
.89308 .22776 L
.89427 .22776 L
.89558 .22776 L
.89631 .22776 L
.89698 .22776 L
.89816 .22776 L
.89927 .22776 L
.90179 .22776 L
.90424 .22776 L
.90689 .22776 L
.91167 .22776 L
.91606 .22776 L
.92617 .22777 L
.93682 .22777 L
.95655 .22778 L
.97491 .2278 L
.97619 .2278 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.06244 .23874 L
.08255 .36442 L
.10458 .48507 L
.11448 .53041 L
.11992 .55193 L
.12507 .56937 L
.12986 .58246 L
.13256 .5882 L
.13385 .59045 L
.13506 .59224 L
.13616 .59359 L
.13716 .59457 L
.13827 .59535 L
.13947 .59582 L
.14062 .59588 L
.14187 .59546 L
.14305 .59457 L
.14415 .59327 L
.14544 .59113 L
.1468 .58807 L
.14796 .58474 L
.14923 .58026 L
.15207 .56668 L
.15472 .54873 L
.15723 .52609 L
.15952 .50002 L
.16467 .42252 L
.16925 .34357 L
.17166 .30739 L
.17299 .29093 L
.17423 .27793 L
.1754 .2679 L
.17646 .26048 L
.17765 .25407 L
.17893 .24909 L
.17994 .24641 L
.18105 .24456 L
.18221 .2437 L
.18328 .24375 L
.18456 .24469 L
.1852 .24549 L
.18591 .24659 L
.18833 .25184 L
.19116 .26022 L
.1938 .26962 L
.20374 .31185 L
.22233 .3934 L
.22731 .41235 L
.23273 .43058 L
Mistroke
.23752 .44398 L
.24014 .44997 L
.24261 .45454 L
.24379 .45629 L
.24504 .4578 L
.24569 .45844 L
.24641 .45902 L
.24766 .45969 L
.2488 .45991 L
.25003 .45969 L
.25118 .45903 L
.25223 .45804 L
.25337 .45655 L
.25443 .45479 L
.25682 .44959 L
.26115 .43702 L
.27092 .40323 L
.28144 .36921 L
.28628 .35637 L
.29138 .34522 L
.29614 .33695 L
.30047 .33113 L
.305 .32654 L
.30732 .32471 L
.30983 .32305 L
.31217 .32179 L
.31431 .32081 L
.31854 .31933 L
.32311 .31817 L
.32813 .31713 L
.33299 .31613 L
.33827 .31481 L
.3435 .31311 L
.34846 .31104 L
.35776 .30593 L
.37866 .29054 L
.39803 .27647 L
.41941 .26492 L
.43964 .25719 L
.45865 .25113 L
.4973 .24007 L
.51693 .23537 L
.53841 .23109 L
.578 .2251 L
.59759 .22281 L
.61853 .22078 L
.63842 .21923 L
.66 .21792 L
.68077 .21696 L
.69995 .21629 L
Mistroke
.71869 .21581 L
.72934 .21561 L
.73932 .21546 L
.74971 .21533 L
.75483 .21529 L
.75958 .21525 L
.76423 .21522 L
.76844 .2152 L
.77312 .21518 L
.7755 .21517 L
.77811 .21516 L
.78063 .21516 L
.78299 .21515 L
.78429 .21515 L
.78548 .21515 L
.78613 .21515 L
.78685 .21515 L
.78814 .21515 L
.78925 .21515 L
.79047 .21515 L
.79174 .21515 L
.79294 .21515 L
.79507 .21516 L
.79737 .21516 L
.7999 .21516 L
.80267 .21517 L
.80824 .21519 L
.8182 .21524 L
.82848 .2153 L
.83782 .21537 L
.85878 .21556 L
.89878 .21603 L
.93726 .21656 L
.97619 .21713 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36434 L
.10458 .48505 L
.11448 .53047 L
.11992 .55204 L
.12507 .56958 L
.12986 .58279 L
.13256 .58861 L
.13385 .59091 L
.13506 .59276 L
.13616 .59416 L
.13716 .5952 L
.13827 .59605 L
.13947 .5966 L
.14062 .59674 L
.14187 .59643 L
.14305 .59566 L
.14415 .59449 L
.14544 .59251 L
.1468 .58965 L
.14796 .58653 L
.14923 .5823 L
.15207 .56944 L
.15472 .55243 L
.15723 .53101 L
.15952 .50638 L
.16467 .43316 L
.16925 .35759 L
.17166 .32204 L
.17299 .30552 L
.17423 .29227 L
.17646 .27402 L
.17765 .2671 L
.17893 .26156 L
.18004 .2582 L
.1812 .25591 L
.18219 .25485 L
.18328 .25452 L
.1846 .25511 L
.18582 .25648 L
.18645 .25747 L
.18715 .25876 L
.18857 .26192 L
.19356 .27749 L
.20289 .31637 L
.22384 .40848 L
.23382 .44467 L
.23873 .45928 L
.24329 .47026 L
Mistroke
.24582 .47503 L
.24711 .47704 L
.24851 .47884 L
.24932 .47969 L
.25005 .48034 L
.25074 .48084 L
.2515 .48125 L
.25282 .48164 L
.25354 .48166 L
.25421 .48157 L
.2555 .48107 L
.25673 .48021 L
.25783 .47915 L
.25902 .4777 L
.26171 .47349 L
.26418 .46866 L
.27395 .44511 L
.28447 .4193 L
.28932 .40908 L
.29441 .39995 L
.29917 .39298 L
.3035 .38792 L
.30803 .3838 L
.31287 .38053 L
.31734 .37835 L
.32157 .37687 L
.3265 .37561 L
.33104 .37473 L
.3413 .3729 L
.34599 .37187 L
.35102 .3705 L
.3601 .3672 L
.38076 .35661 L
.40055 .34585 L
.41099 .34105 L
.42209 .3368 L
.44276 .33074 L
.4619 .32629 L
.49962 .31861 L
.53979 .31215 L
.57845 .30767 L
.61955 .30415 L
.64005 .30279 L
.65914 .30172 L
.69722 .3001 L
.71765 .29945 L
.73623 .29896 L
.75701 .29852 L
.77618 .29819 L
.81462 .29771 L
Mistroke
.83336 .29754 L
.85399 .29738 L
.87504 .29726 L
.8943 .29717 L
.93309 .29702 L
.97282 .29691 L
.97619 .2969 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.06244 .23849 L
.08255 .36418 L
.10458 .48502 L
.11448 .53057 L
.11992 .55227 L
.12507 .56998 L
.12986 .58343 L
.13238 .58908 L
.13506 .59379 L
.13614 .59528 L
.13731 .59659 L
.13859 .59766 L
.13979 .59827 L
.14096 .59848 L
.14207 .59831 L
.14306 .59781 L
.14415 .59689 L
.1448 .59613 L
.14548 .59516 L
.1467 .59296 L
.14802 .58985 L
.14946 .58549 L
.15205 .57488 L
.15447 .56122 L
.15683 .54382 L
.15898 .52406 L
.16382 .46544 L
.16911 .38682 L
.172 .34661 L
.17472 .31644 L
.17702 .29801 L
.17832 .29051 L
.17951 .28528 L
.18074 .28138 L
.18144 .27978 L
.18209 .27867 L
.1834 .2774 L
.18413 .2772 L
.1848 .27732 L
.18599 .27813 L
.18725 .27976 L
.18832 .28168 L
.18951 .28428 L
.19461 .29981 L
.20388 .33723 L
.22464 .42498 L
.23462 .46087 L
.24409 .48809 L
.24931 .49899 L
Mistroke
.25074 .50131 L
.25227 .50341 L
.25358 .50491 L
.25428 .50557 L
.25501 .50617 L
.25568 .50663 L
.25641 .50704 L
.2577 .5075 L
.25902 .50765 L
.26024 .5075 L
.26144 .50709 L
.26253 .5065 L
.26379 .50559 L
.26498 .50452 L
.26959 .49871 L
.27466 .49018 L
.28493 .47065 L
.29392 .45518 L
.30336 .44279 L
.3082 .4381 L
.31348 .43414 L
.31829 .43145 L
.32275 .42959 L
.32804 .42801 L
.33285 .42698 L
.34362 .42532 L
.35296 .42381 L
.35767 .42281 L
.36284 .42149 L
.37368 .41792 L
.38365 .41388 L
.40477 .40482 L
.42405 .39794 L
.444 .39279 L
.46292 .38911 L
.50122 .38298 L
.54197 .37777 L
.5812 .37415 L
.61892 .37154 L
.65909 .36944 L
.69775 .36796 L
.73886 .3668 L
.77845 .36597 L
.81652 .36535 L
.85705 .36482 L
.89606 .36439 L
.93753 .36399 L
.97619 .36365 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.06244 .23802 L
.08255 .36376 L
.10458 .48496 L
.11448 .5309 L
.11992 .55293 L
.12507 .57108 L
.12986 .58512 L
.13238 .59119 L
.13506 .59644 L
.13731 .59981 L
.13859 .60125 L
.13979 .60225 L
.14089 .60287 L
.14189 .60316 L
.14305 .60314 L
.14415 .60276 L
.1454 .60188 L
.1461 .60115 L
.14674 .60033 L
.14793 .59843 L
.14918 .59583 L
.15135 .58974 L
.15374 .58049 L
.15629 .56728 L
.15902 .54887 L
.16396 .504 L
.16859 .45102 L
.17351 .39432 L
.17553 .37457 L
.17771 .35697 L
.17896 .34876 L
.1801 .34244 L
.18119 .33747 L
.18234 .33321 L
.18357 .32979 L
.18471 .32753 L
.18541 .32655 L
.18607 .32589 L
.1873 .32526 L
.1886 .32539 L
.1898 .32614 L
.19112 .32758 L
.19252 .32969 L
.19524 .33527 L
.19779 .34185 L
.20358 .36003 L
.22371 .43478 L
.23411 .47158 L
.24399 .5014 L
Mistroke
.24829 .51204 L
.25286 .52129 L
.25549 .52544 L
.25788 .52834 L
.25903 .52942 L
.26028 .53035 L
.26145 .531 L
.26253 .53138 L
.2638 .5316 L
.265 .53155 L
.26607 .53132 L
.26724 .53088 L
.26852 .53017 L
.26987 .52918 L
.27229 .52685 L
.27662 .52133 L
.28139 .51393 L
.29219 .49625 L
.30207 .48268 L
.31152 .47338 L
.31627 .47001 L
.32145 .46718 L
.32669 .46509 L
.32962 .46419 L
.33227 .46352 L
.33745 .4625 L
.34232 .4618 L
.35118 .46075 L
.36068 .4594 L
.36613 .45836 L
.3711 .45719 L
.38084 .45432 L
.40076 .44698 L
.42181 .43951 L
.44088 .43438 L
.46163 .43036 L
.50238 .42442 L
.54161 .41982 L
.57933 .41657 L
.6195 .414 L
.65816 .41213 L
.69926 .41065 L
.73886 .4096 L
.77693 .40882 L
.81746 .40817 L
.85647 .40766 L
.89794 .4072 L
.93789 .40679 L
.97619 .40644 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.06244 .23872 L
.08255 .3644 L
.10458 .48505 L
.11448 .5304 L
.11992 .55192 L
.12507 .56938 L
.12986 .58248 L
.13256 .58822 L
.13385 .59048 L
.13506 .59227 L
.13616 .59362 L
.13716 .5946 L
.13827 .59539 L
.13947 .59586 L
.14062 .59592 L
.14187 .5955 L
.14305 .59461 L
.14415 .59331 L
.14544 .59117 L
.1468 .5881 L
.14796 .58476 L
.14923 .58027 L
.15207 .56662 L
.15472 .54856 L
.15723 .52571 L
.15952 .49934 L
.16467 .42048 L
.16925 .33979 L
.17166 .30288 L
.17299 .28613 L
.17423 .27293 L
.1754 .26277 L
.17646 .25525 L
.17765 .24874 L
.17893 .24366 L
.17994 .24088 L
.18105 .23893 L
.18221 .23795 L
.18328 .23786 L
.18456 .23862 L
.1852 .23932 L
.18591 .24031 L
.18716 .24254 L
.18833 .24512 L
.1938 .26164 L
.20374 .30056 L
.21263 .33656 L
.22233 .37089 L
.22494 .37857 L
Mistroke
.22773 .38568 L
.23013 .39076 L
.2314 .39296 L
.23273 .39487 L
.2334 .39564 L
.23413 .39635 L
.23541 .39719 L
.23671 .39746 L
.23792 .39712 L
.23911 .39614 L
.24019 .39462 L
.24143 .39202 L
.24261 .38861 L
.24368 .38465 L
.24485 .37917 L
.24723 .36407 L
.24943 .34482 L
.2515 .32243 L
.2565 .2609 L
.26115 .21305 L
.26343 .19533 L
.26586 .18018 L
.26856 .16717 L
.27101 .15819 L
.27357 .15111 L
.27492 .14817 L
.27634 .14557 L
.27759 .14368 L
.27896 .14198 L
.28012 .14081 L
.28137 .1398 L
.28261 .13903 L
.28379 .1385 L
.28493 .13815 L
.28599 .13795 L
.28713 .13787 L
.28839 .13793 L
.28971 .13812 L
.29095 .13843 L
.29204 .13878 L
.29319 .13924 L
.29525 .14022 L
.29989 .14306 L
.31014 .15071 L
.31518 .1544 L
.31983 .15743 L
.32397 .15969 L
.32853 .16163 L
.3309 .16239 L
.33311 .16294 L
Mistroke
.33545 .16337 L
.33677 .16354 L
.33797 .16365 L
.33917 .16373 L
.34046 .16377 L
.34167 .16377 L
.34277 .16374 L
.34407 .16367 L
.3448 .16362 L
.34547 .16356 L
.34801 .16327 L
.35022 .16294 L
.35265 .16252 L
.35755 .16155 L
.36318 .16041 L
.36851 .15947 L
.37083 .15914 L
.37329 .15885 L
.37458 .15872 L
.376 .15861 L
.37719 .15853 L
.3785 .15846 L
.37973 .15842 L
.38103 .15839 L
.38223 .15839 L
.38334 .1584 L
.38402 .15841 L
.38467 .15843 L
.38587 .15847 L
.38717 .15854 L
.38857 .15864 L
.39096 .15885 L
.39349 .15913 L
.39802 .15978 L
.40798 .16171 L
.41894 .16425 L
.44003 .16898 L
.4593 .17217 L
.46884 .17334 L
.47923 .1744 L
.49814 .17603 L
.53886 .17906 L
.55771 .18022 L
.57806 .18122 L
.59953 .18203 L
.61972 .18262 L
.63932 .18308 L
.66079 .18348 L
.68127 .18378 L
.70035 .184 L
Mistroke
.73933 .18433 L
.76063 .18446 L
.78077 .18457 L
.81917 .18475 L
.86002 .18494 L
.89936 .18512 L
.93718 .18531 L
.97619 .18552 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.06244 .2382 L
.08255 .3639 L
.10458 .48495 L
.11448 .53075 L
.11992 .55266 L
.12507 .57065 L
.12986 .58447 L
.13238 .59038 L
.13506 .59544 L
.13731 .59861 L
.13859 .59991 L
.13979 .60077 L
.14089 .60124 L
.14189 .60138 L
.14305 .60118 L
.14415 .6006 L
.1454 .59946 L
.1461 .59858 L
.14674 .59761 L
.1479 .59545 L
.14918 .59242 L
.1514 .5854 L
.15374 .57524 L
.15629 .56054 L
.15902 .54008 L
.16396 .49025 L
.16859 .43217 L
.17351 .37279 L
.17553 .35332 L
.17771 .3368 L
.17896 .32948 L
.1801 .32407 L
.18119 .31999 L
.18234 .31676 L
.18356 .31442 L
.18486 .313 L
.18609 .31256 L
.1872 .31283 L
.18852 .31383 L
.18925 .31469 L
.18994 .31565 L
.19252 .32048 L
.19789 .33479 L
.20358 .35319 L
.21328 .38667 L
.22371 .42119 L
.22895 .43682 L
.23393 .44982 L
.23841 .45927 L
Mistroke
.24093 .46332 L
.24216 .46485 L
.24328 .46598 L
.24443 .46682 L
.24568 .46733 L
.24678 .46739 L
.24793 .46703 L
.24898 .4663 L
.24995 .46523 L
.25101 .46361 L
.25215 .46134 L
.25469 .45423 L
.25709 .44514 L
.26159 .42402 L
.27127 .37647 L
.27657 .3549 L
.28154 .3389 L
.28576 .3286 L
.29031 .32068 L
.29277 .31764 L
.29411 .31632 L
.29536 .31529 L
.29756 .3139 L
.29873 .31338 L
.29997 .31297 L
.30121 .31271 L
.30192 .31262 L
.30257 .31258 L
.30327 .31257 L
.3039 .3126 L
.30463 .31266 L
.30532 .31277 L
.30654 .31302 L
.30768 .31335 L
.31024 .31436 L
.3128 .3157 L
.31563 .31748 L
.32136 .32181 L
.33188 .33083 L
.34152 .33876 L
.35075 .34503 L
.35563 .34768 L
.36085 .34998 L
.3661 .35179 L
.371 .35306 L
.3766 .35412 L
.3817 .35481 L
.40247 .35656 L
.4116 .35744 L
.42165 .35869 L
Mistroke
.44031 .36163 L
.46008 .36486 L
.4795 .36746 L
.50039 .36949 L
.52154 .37104 L
.54163 .37229 L
.57984 .37429 L
.60118 .37516 L
.62051 .3758 L
.65966 .37677 L
.67892 .37712 L
.69975 .37744 L
.71931 .37768 L
.74077 .37789 L
.78028 .37817 L
.7998 .37827 L
.82072 .37837 L
.8621 .37852 L
.90197 .37864 L
.94032 .37874 L
.97619 .37884 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.06244 .23828 L
.08255 .36397 L
.10458 .48496 L
.11448 .5307 L
.11992 .55256 L
.12507 .57049 L
.12986 .58422 L
.13238 .59007 L
.13506 .59505 L
.13731 .59813 L
.13859 .59938 L
.13979 .60019 L
.14089 .6006 L
.14189 .60068 L
.14305 .6004 L
.14415 .59974 L
.1454 .5985 L
.1461 .59755 L
.14674 .59652 L
.1479 .59423 L
.14918 .59104 L
.1514 .58369 L
.15374 .57307 L
.15629 .55773 L
.15902 .53635 L
.16396 .48422 L
.16859 .42368 L
.17113 .39057 L
.17351 .3629 L
.1757 .342 L
.17771 .32723 L
.1788 .321 L
.17994 .31569 L
.18109 .31157 L
.18234 .30832 L
.18303 .30705 L
.18368 .30616 L
.18489 .3052 L
.1862 .30511 L
.18694 .30543 L
.18761 .30594 L
.18875 .3072 L
.19 .30912 L
.19252 .31434 L
.19824 .33058 L
.20358 .34857 L
.22371 .41759 L
.22868 .43235 L
.23411 .44616 L
Mistroke
.2366 .45137 L
.23924 .45592 L
.24052 .45767 L
.24173 .459 L
.24282 .4599 L
.24399 .46053 L
.24515 .46075 L
.24624 .46057 L
.24742 .45988 L
.24869 .45852 L
.24933 .45758 L
.25003 .45635 L
.25129 .45356 L
.25365 .44633 L
.25589 .43732 L
.25827 .42602 L
.26253 .40364 L
.27193 .35733 L
.27721 .33706 L
.28204 .32288 L
.2863 .31376 L
.28871 .3099 L
.29096 .30708 L
.29334 .30483 L
.29549 .30339 L
.29669 .30282 L
.29798 .30237 L
.29921 .3021 L
.30033 .30197 L
.30159 .30196 L
.30278 .30207 L
.30386 .30226 L
.30502 .30256 L
.30629 .30298 L
.30763 .30354 L
.31005 .30478 L
.31437 .30762 L
.31913 .31143 L
.3299 .32113 L
.33979 .32969 L
.34901 .33632 L
.35911 .34162 L
.36437 .34357 L
.36926 .34496 L
.37443 .34607 L
.37996 .34692 L
.38528 .34753 L
.39018 .34799 L
.40128 .34895 L
.42142 .35136 L
Mistroke
.44176 .35473 L
.46079 .3579 L
.47904 .36035 L
.49865 .36231 L
.5198 .36391 L
.53989 .3652 L
.57811 .36725 L
.59944 .36814 L
.61877 .3688 L
.65792 .36979 L
.67718 .37015 L
.69801 .37047 L
.71757 .37071 L
.73903 .37093 L
.77854 .37121 L
.79806 .37132 L
.81898 .37141 L
.86036 .37156 L
.90023 .37168 L
.93858 .37178 L
.97619 .37187 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.06244 .23876 L
.08255 .36444 L
.10458 .48507 L
.11448 .53038 L
.11992 .55188 L
.12507 .5693 L
.12986 .58234 L
.13256 .58805 L
.13385 .59027 L
.13506 .59205 L
.13616 .59337 L
.13716 .59433 L
.13827 .59509 L
.13947 .59553 L
.14062 .59554 L
.14187 .59508 L
.14305 .59414 L
.14415 .59279 L
.14544 .59058 L
.1468 .58743 L
.14923 .57942 L
.15058 .57346 L
.15185 .56679 L
.15472 .54709 L
.15723 .52383 L
.15952 .497 L
.16467 .41697 L
.16925 .3358 L
.17166 .29908 L
.17299 .28255 L
.17423 .26961 L
.1754 .25972 L
.17646 .25246 L
.17765 .24624 L
.17893 .24146 L
.17994 .23891 L
.18105 .23721 L
.18221 .23645 L
.18328 .23657 L
.18456 .23756 L
.1852 .23837 L
.18591 .23947 L
.18833 .24465 L
.19116 .2528 L
.1938 .26186 L
.20374 .30197 L
.21263 .33925 L
.22233 .37556 L
.22773 .39198 L
Mistroke
.23035 .39852 L
.23273 .40339 L
.23392 .40537 L
.2352 .40714 L
.23641 .40841 L
.23752 .40919 L
.2387 .40956 L
.24 .40937 L
.24065 .40901 L
.24135 .4084 L
.24261 .40669 L
.24386 .40415 L
.245 .40094 L
.24626 .39636 L
.2476 .39018 L
.24984 .37653 L
.25232 .35687 L
.26115 .27295 L
.26608 .23416 L
.26877 .21694 L
.27127 .20343 L
.2757 .18508 L
.27804 .17796 L
.28054 .17203 L
.28324 .16724 L
.28476 .16518 L
.28617 .16363 L
.2875 .16244 L
.28875 .16154 L
.29005 .16081 L
.29073 .1605 L
.29148 .16021 L
.29276 .15984 L
.29398 .15963 L
.29517 .15953 L
.29627 .15952 L
.29745 .15959 L
.29876 .15976 L
.29941 .15987 L
.30012 .16001 L
.30141 .16032 L
.30635 .16194 L
.31096 .16373 L
.31644 .16578 L
.32142 .16726 L
.32394 .16779 L
.32535 .16802 L
.32666 .16817 L
.32781 .16827 L
.32907 .16834 L
Mistroke
.33038 .16836 L
.33162 .16833 L
.33229 .16829 L
.33302 .16824 L
.33436 .1681 L
.33566 .16792 L
.33687 .16771 L
.3396 .16709 L
.34251 .16623 L
.3625 .15758 L
.37302 .1535 L
.37831 .15198 L
.38135 .15129 L
.38412 .15078 L
.38661 .1504 L
.38933 .15008 L
.39082 .14994 L
.3922 .14984 L
.3936 .14975 L
.39492 .14969 L
.39604 .14965 L
.39724 .14962 L
.3979 .14961 L
.39858 .1496 L
.39981 .1496 L
.40109 .14961 L
.40229 .14963 L
.4036 .14966 L
.405 .14971 L
.40748 .14981 L
.41018 .14996 L
.41506 .1503 L
.4242 .15104 L
.43448 .15184 L
.44409 .15244 L
.44893 .15267 L
.45412 .15287 L
.45988 .15303 L
.46514 .15314 L
.46993 .15322 L
.47502 .15328 L
.48418 .15338 L
.49499 .15352 L
.50492 .1537 L
.51524 .15394 L
.52639 .15424 L
.54658 .15483 L
.58614 .15581 L
.62418 .15655 L
.66468 .15725 L
Mistroke
.70366 .15784 L
.74509 .1584 L
.78501 .15889 L
.82341 .15934 L
.86426 .15979 L
.9036 .16022 L
.94142 .16063 L
.97619 .161 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.06244 .23874 L
.08255 .36443 L
.10458 .48507 L
.11448 .53041 L
.11992 .55191 L
.12507 .56935 L
.12986 .58243 L
.13256 .58816 L
.13385 .5904 L
.13506 .59219 L
.13616 .59353 L
.13716 .5945 L
.13827 .59528 L
.13947 .59574 L
.14062 .59578 L
.14187 .59535 L
.14305 .59445 L
.14415 .59314 L
.14544 .59098 L
.1468 .5879 L
.14796 .58455 L
.14923 .58004 L
.15207 .56637 L
.15472 .54832 L
.15723 .52554 L
.15952 .49931 L
.16467 .42134 L
.16925 .34211 L
.17166 .30595 L
.17299 .28955 L
.17423 .27663 L
.1754 .26669 L
.17646 .25936 L
.17765 .25304 L
.17893 .24816 L
.17994 .24554 L
.18105 .24376 L
.18221 .24296 L
.18328 .24305 L
.18456 .24404 L
.1852 .24486 L
.18591 .24597 L
.18833 .25126 L
.19116 .25963 L
.1938 .26897 L
.20374 .3107 L
.22233 .39018 L
.22731 .40829 L
.23273 .42533 L
Mistroke
.23522 .43193 L
.23786 .43794 L
.24036 .44246 L
.24143 .444 L
.24261 .44538 L
.24378 .44637 L
.24501 .447 L
.24614 .44715 L
.24721 .44689 L
.24846 .44604 L
.2496 .44471 L
.25092 .44251 L
.25216 .43974 L
.2544 .43322 L
.25647 .4257 L
.26115 .4056 L
.27092 .3614 L
.27605 .34039 L
.28144 .32128 L
.28619 .3074 L
.29138 .29545 L
.29609 .28728 L
.30047 .28172 L
.30284 .2794 L
.3054 .27735 L
.30767 .27589 L
.31006 .27465 L
.31222 .27375 L
.31459 .27296 L
.31876 .2719 L
.324 .27091 L
.32896 .26996 L
.33342 .2689 L
.33827 .26736 L
.34318 .26528 L
.34839 .26247 L
.35776 .256 L
.37866 .23862 L
.38802 .23147 L
.39811 .22502 L
.41638 .21669 L
.42594 .2136 L
.4364 .21078 L
.45749 .20584 L
.47872 .20124 L
.49802 .19755 L
.51831 .19442 L
.53703 .19216 L
.55619 .19034 L
.57698 .18874 L
Mistroke
.59731 .18748 L
.61635 .18656 L
.63459 .18588 L
.65421 .18536 L
.66432 .18516 L
.67536 .18499 L
.6804 .18493 L
.68578 .18487 L
.69048 .18483 L
.69545 .1848 L
.70082 .18477 L
.70575 .18475 L
.70849 .18474 L
.71106 .18473 L
.71253 .18473 L
.71387 .18473 L
.71461 .18473 L
.71541 .18473 L
.71617 .18473 L
.71688 .18473 L
.71803 .18473 L
.71928 .18473 L
.72045 .18473 L
.72153 .18473 L
.72273 .18473 L
.72403 .18473 L
.72666 .18474 L
.72927 .18474 L
.73205 .18475 L
.73705 .18477 L
.74731 .18483 L
.75842 .18491 L
.77857 .18512 L
.81951 .1857 L
.85893 .18642 L
.89684 .18718 L
.9372 .18804 L
.97604 .18889 L
.97619 .18889 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.06244 .23865 L
.08255 .36432 L
.10458 .48502 L
.11448 .53044 L
.11992 .55201 L
.12507 .56954 L
.12986 .58274 L
.13256 .58856 L
.13385 .59086 L
.13506 .5927 L
.13616 .59409 L
.13716 .59512 L
.13827 .59596 L
.13947 .5965 L
.14062 .59663 L
.14187 .5963 L
.14305 .5955 L
.14415 .59431 L
.14544 .5923 L
.1468 .58939 L
.14796 .58621 L
.14923 .58191 L
.1506 .57624 L
.15207 .56884 L
.15472 .55149 L
.15739 .52795 L
.15993 .49923 L
.16467 .42836 L
.169 .35389 L
.17136 .31709 L
.17359 .28908 L
.17598 .26726 L
.17725 .25903 L
.17791 .25561 L
.17862 .25246 L
.17981 .24848 L
.18105 .24576 L
.18221 .24438 L
.18328 .24395 L
.18456 .24435 L
.1852 .24488 L
.18591 .24569 L
.18716 .24764 L
.18833 .24998 L
.19097 .25671 L
.1938 .26561 L
.20374 .30339 L
.21338 .34122 L
.22233 .37151 L
Mistroke
.22723 .38439 L
.22998 .38985 L
.23118 .39176 L
.23246 .39339 L
.23314 .39407 L
.23388 .39467 L
.23519 .39529 L
.23593 .39537 L
.23672 .39522 L
.23747 .39483 L
.23815 .39426 L
.23947 .39248 L
.24021 .39105 L
.2409 .38942 L
.24216 .38558 L
.2435 .38017 L
.24588 .36659 L
.24721 .3564 L
.24844 .34535 L
.25306 .29083 L
.25816 .22832 L
.26101 .20204 L
.2636 .18413 L
.26603 .1716 L
.26866 .16172 L
.26987 .15823 L
.27115 .15515 L
.27225 .15293 L
.27343 .15097 L
.27461 .14939 L
.27568 .14826 L
.27676 .14737 L
.27778 .14674 L
.27897 .14626 L
.28007 .14603 L
.28128 .14598 L
.28257 .14615 L
.28384 .14651 L
.28501 .14701 L
.28629 .14771 L
.28764 .14862 L
.29241 .15292 L
.2976 .15906 L
.30328 .16688 L
.32451 .19795 L
.33454 .2101 L
.34381 .2187 L
.35343 .225 L
.3585 .22743 L
.36387 .2295 L
Mistroke
.38282 .23476 L
.42068 .24623 L
.44173 .253 L
.46098 .25791 L
.48088 .26154 L
.49978 .26405 L
.53799 .26786 L
.55932 .26952 L
.57865 .27074 L
.59882 .27173 L
.6178 .27245 L
.6379 .27304 L
.65637 .27347 L
.67521 .27381 L
.69588 .27408 L
.71541 .27426 L
.72635 .27434 L
.73633 .2744 L
.75543 .27449 L
.76621 .27452 L
.77619 .27455 L
.79487 .27459 L
.8055 .27461 L
.81548 .27462 L
.85418 .27465 L
.89534 .27469 L
.93499 .27473 L
.97312 .27477 L
.97619 .27477 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.06244 .23831 L
.08255 .36401 L
.10458 .48499 L
.11448 .5307 L
.11992 .55254 L
.12507 .57044 L
.12986 .58414 L
.13238 .58997 L
.13506 .59492 L
.13731 .59797 L
.13859 .5992 L
.13979 .59999 L
.14089 .60038 L
.14189 .60045 L
.14305 .60014 L
.14415 .59946 L
.1454 .59819 L
.1461 .59723 L
.14674 .59618 L
.1479 .59385 L
.14918 .59063 L
.1514 .5832 L
.15374 .57249 L
.15629 .55701 L
.15902 .53548 L
.16396 .48303 L
.16859 .42219 L
.17113 .38891 L
.17351 .36107 L
.1757 .34002 L
.17771 .32516 L
.1788 .31888 L
.17994 .31355 L
.18109 .30941 L
.18234 .30617 L
.18303 .30492 L
.18368 .30404 L
.18489 .30314 L
.1862 .30312 L
.18694 .30349 L
.18761 .30406 L
.18875 .30543 L
.19 .30748 L
.19252 .31306 L
.19824 .33052 L
.20358 .35019 L
.22371 .42957 L
.23411 .46675 L
.23924 .48287 L
Mistroke
.24399 .49608 L
.24865 .50695 L
.25286 .5146 L
.25527 .51784 L
.25638 .51901 L
.25754 .52003 L
.25879 .52086 L
.25994 .52138 L
.26118 .52168 L
.26188 .52174 L
.26253 .52172 L
.2638 .52147 L
.26444 .52125 L
.26514 .52093 L
.26639 .52019 L
.26755 .5193 L
.27018 .51667 L
.27301 .51303 L
.28292 .49667 L
.29255 .48036 L
.30149 .46798 L
.30652 .46254 L
.31109 .45854 L
.31616 .45504 L
.32157 .45225 L
.32679 .45032 L
.32973 .4495 L
.33244 .44887 L
.33742 .44796 L
.34268 .44721 L
.35214 .44595 L
.35736 .44511 L
.3623 .44413 L
.37188 .44163 L
.38062 .4387 L
.41892 .4241 L
.43867 .41859 L
.45967 .4144 L
.49739 .40868 L
.53756 .40374 L
.57621 .40028 L
.61732 .39758 L
.65691 .39564 L
.69499 .39426 L
.73552 .39318 L
.77453 .3924 L
.816 .39177 L
.85595 .39129 L
.89438 .3909 L
.93527 .39053 L
Mistroke
.97464 .39021 L
.97619 .3902 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.06244 .23869 L
.08255 .36437 L
.10458 .48506 L
.11448 .53044 L
.11992 .552 L
.12507 .5695 L
.12986 .58266 L
.13256 .58845 L
.13385 .59073 L
.13506 .59255 L
.13616 .59393 L
.13716 .59495 L
.13827 .59577 L
.13947 .59629 L
.14062 .5964 L
.14187 .59605 L
.14305 .59523 L
.14415 .594 L
.14544 .59196 L
.1468 .58903 L
.14796 .58582 L
.14923 .58149 L
.15207 .56836 L
.15472 .55099 L
.15723 .5291 L
.15952 .50394 L
.16467 .42917 L
.16925 .35245 L
.17166 .31674 L
.17299 .30029 L
.17423 .28717 L
.17646 .2693 L
.17765 .26261 L
.17893 .25731 L
.18004 .25416 L
.1812 .25208 L
.18219 .25118 L
.18328 .25101 L
.1846 .25177 L
.18582 .25328 L
.18645 .25434 L
.18715 .25569 L
.18857 .25896 L
.19356 .27477 L
.20289 .31369 L
.21384 .36296 L
.22384 .40493 L
.23315 .43812 L
.23806 .45237 L
Mistroke
.24075 .45891 L
.24329 .46406 L
.24469 .46644 L
.24621 .46856 L
.24759 .47005 L
.24885 .47103 L
.25005 .47157 L
.25136 .47172 L
.25202 .4716 L
.25273 .47134 L
.25401 .4705 L
.25532 .46915 L
.25674 .46717 L
.25933 .46235 L
.26418 .45036 L
.28361 .39462 L
.28893 .38226 L
.29466 .37143 L
.30006 .36357 L
.30502 .35819 L
.30976 .35443 L
.31418 .35192 L
.31671 .35082 L
.31902 .34999 L
.32418 .34856 L
.33467 .34647 L
.33928 .34548 L
.34434 .34414 L
.35368 .34071 L
.36356 .33566 L
.38437 .32234 L
.40549 .30988 L
.42476 .30164 L
.44472 .29548 L
.46364 .29061 L
.50193 .28188 L
.5213 .27821 L
.54268 .27485 L
.58192 .27018 L
.60287 .26826 L
.62209 .26681 L
.64211 .26558 L
.66074 .26467 L
.67965 .26395 L
.70034 .26335 L
.71084 .26312 L
.72077 .26294 L
.72961 .2628 L
.73935 .26268 L
.74906 .26259 L
Mistroke
.75401 .26255 L
.75934 .26251 L
.76431 .26249 L
.76886 .26247 L
.77344 .26245 L
.77778 .26244 L
.78038 .26243 L
.78165 .26243 L
.78282 .26243 L
.78386 .26243 L
.78501 .26243 L
.78616 .26243 L
.78738 .26243 L
.78807 .26243 L
.78872 .26243 L
.78993 .26243 L
.79124 .26243 L
.79198 .26243 L
.79267 .26243 L
.79381 .26243 L
.79506 .26243 L
.7976 .26243 L
.79999 .26244 L
.80217 .26244 L
.80709 .26245 L
.816 .26248 L
.82581 .26253 L
.83493 .26258 L
.85564 .26272 L
.89471 .26306 L
.93622 .26348 L
.97619 .2639 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.06244 .2382 L
.08255 .36391 L
.10458 .48498 L
.11448 .53078 L
.11992 .5527 L
.12507 .5707 L
.12986 .58453 L
.13238 .59045 L
.13506 .59552 L
.13731 .5987 L
.13859 .60001 L
.13979 .60089 L
.14089 .60137 L
.14189 .60152 L
.14305 .60133 L
.14415 .60077 L
.1454 .59966 L
.1461 .59879 L
.14674 .59783 L
.1479 .5957 L
.14918 .59271 L
.1514 .58577 L
.15374 .57572 L
.15629 .56118 L
.15902 .54096 L
.16396 .49172 L
.16859 .43426 L
.17351 .37509 L
.17553 .35545 L
.17771 .33861 L
.17896 .33105 L
.1801 .32541 L
.18119 .3211 L
.18234 .31763 L
.18356 .31504 L
.18486 .31338 L
.18609 .31273 L
.1872 .31282 L
.18852 .31365 L
.18925 .31442 L
.18994 .31531 L
.19252 .32 L
.19508 .32627 L
.19789 .33454 L
.20358 .35402 L
.22371 .43127 L
.23368 .46679 L
.24315 .49539 L
.24838 .50801 L
Mistroke
.25113 .51347 L
.25407 .51819 L
.25547 .51999 L
.25679 .5214 L
.25797 .52241 L
.25925 .52325 L
.26046 .52378 L
.26175 .52406 L
.26284 .52407 L
.26405 .52386 L
.26536 .52337 L
.26657 .52269 L
.26789 .5217 L
.2693 .5204 L
.27428 .51414 L
.28359 .49854 L
.29367 .48155 L
.29896 .47397 L
.30452 .46729 L
.30939 .46256 L
.31471 .45849 L
.31954 .45568 L
.32403 .4537 L
.32867 .45217 L
.33288 .45114 L
.33774 .45025 L
.34232 .44959 L
.35207 .44831 L
.3574 .44747 L
.36238 .4465 L
.37118 .44427 L
.38084 .44111 L
.41972 .42644 L
.44093 .4207 L
.46105 .41683 L
.49935 .41117 L
.5401 .40633 L
.57933 .40297 L
.61705 .40059 L
.65722 .39867 L
.69587 .39733 L
.73698 .39629 L
.77657 .39556 L
.81465 .39502 L
.85518 .39457 L
.89419 .3942 L
.93566 .39387 L
.97561 .39357 L
.97619 .39357 L
Mfstroke
0 .206 1 r
.02381 .01472 m
.06244 .23859 L
.08255 .36426 L
.10458 .48501 L
.11448 .53048 L
.11992 .55211 L
.12507 .56971 L
.12986 .58301 L
.13256 .58891 L
.13506 .59313 L
.13607 .59447 L
.13716 .59564 L
.13835 .5966 L
.13947 .59715 L
.14073 .59735 L
.14192 .5971 L
.14299 .59647 L
.14415 .59532 L
.1448 .59447 L
.14548 .59338 L
.1467 .59093 L
.14802 .58752 L
.14946 .58277 L
.15205 .57123 L
.15447 .55639 L
.15683 .53741 L
.15898 .51575 L
.16382 .45097 L
.16898 .36654 L
.1717 .32584 L
.1732 .30713 L
.17459 .29239 L
.17591 .2811 L
.17711 .27283 L
.17845 .2658 L
.17915 .26293 L
.17989 .26048 L
.18111 .25758 L
.18224 .25599 L
.18347 .25532 L
.18417 .25537 L
.1848 .25566 L
.18599 .25676 L
.18711 .25837 L
.18833 .26069 L
.18965 .26372 L
.19478 .27946 L
.20398 .31512 L
.21477 .3578 L
.22478 .39148 L
Mistroke
.22969 .40412 L
.23243 .40952 L
.23364 .41142 L
.23491 .41306 L
.23559 .41376 L
.23634 .41438 L
.23765 .41506 L
.23838 .41518 L
.23917 .4151 L
.23992 .41478 L
.2406 .41429 L
.24192 .4127 L
.24266 .4114 L
.24335 .40992 L
.24461 .40642 L
.24595 .40149 L
.24833 .38928 L
.25089 .37085 L
.25552 .32721 L
.26098 .27613 L
.26606 .2394 L
.2707 .21504 L
.2733 .2049 L
.27565 .19765 L
.27824 .19162 L
.2797 .18901 L
.28105 .18708 L
.28233 .18562 L
.28352 .18456 L
.28477 .18374 L
.28543 .18343 L
.28614 .18317 L
.28682 .18299 L
.28754 .18289 L
.28885 .18289 L
.28957 .18299 L
.29025 .18315 L
.291 .18338 L
.2918 .18371 L
.29317 .18442 L
.2946 .18536 L
.29717 .18748 L
.30198 .19265 L
.30725 .19951 L
.31816 .21532 L
.32847 .22947 L
.33773 .23988 L
.34251 .24419 L
.34778 .24809 L
.35252 .2509 L
Mistroke
.35763 .25327 L
.36302 .25517 L
.36807 .25653 L
.38679 .26011 L
.42803 .2704 L
.44864 .27593 L
.46776 .27989 L
.48626 .28264 L
.50598 .28484 L
.52596 .28666 L
.54758 .28835 L
.56669 .28961 L
.58766 .29071 L
.60762 .29152 L
.62869 .29217 L
.64821 .29263 L
.66913 .29302 L
.69039 .2933 L
.70015 .2934 L
.71051 .29349 L
.71999 .29356 L
.73044 .29363 L
.74886 .29372 L
.75896 .29375 L
.76822 .29378 L
.77903 .2938 L
.78908 .29382 L
.80802 .29385 L
.82873 .29387 L
.86779 .2939 L
.90931 .29394 L
.94931 .29398 L
.97619 .29401 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.06244 .23864 L
.08255 .36431 L
.10458 .48502 L
.11448 .53045 L
.11992 .55203 L
.12507 .56958 L
.12986 .5828 L
.13256 .58864 L
.13385 .59094 L
.13506 .59279 L
.13616 .59419 L
.13716 .59523 L
.13827 .59609 L
.13947 .59664 L
.14062 .59679 L
.14187 .59648 L
.14305 .59571 L
.14415 .59453 L
.14544 .59255 L
.1468 .58969 L
.14796 .58655 L
.14923 .5823 L
.1506 .5767 L
.15207 .56938 L
.15472 .55224 L
.15739 .529 L
.15993 .50067 L
.16467 .4309 L
.169 .35759 L
.17136 .32125 L
.17359 .29348 L
.17598 .27173 L
.17725 .26349 L
.17791 .26007 L
.17862 .2569 L
.17981 .2529 L
.18105 .25015 L
.18221 .24876 L
.18328 .24833 L
.18456 .24873 L
.1852 .24927 L
.18591 .25009 L
.18716 .25207 L
.18833 .25445 L
.19097 .26129 L
.1938 .27034 L
.20374 .30881 L
.21338 .3475 L
.22233 .37903 L
Mistroke
.22723 .39301 L
.22974 .39885 L
.23246 .40386 L
.23401 .40599 L
.2347 .40672 L
.23544 .40738 L
.23615 .40785 L
.23681 .40813 L
.23751 .40827 L
.23825 .40821 L
.23893 .40796 L
.23966 .40747 L
.24036 .40676 L
.241 .4059 L
.24221 .40363 L
.2435 .40022 L
.24474 .39582 L
.24588 .39073 L
.24844 .37508 L
.25069 .35625 L
.25306 .33223 L
.25859 .27298 L
.261 .25079 L
.2636 .23036 L
.26617 .21373 L
.26853 .20117 L
.27093 .19082 L
.27317 .18309 L
.27554 .1767 L
.2769 .17375 L
.27814 .17147 L
.28067 .16789 L
.28206 .16646 L
.28338 .16543 L
.28444 .16481 L
.2856 .16431 L
.28681 .164 L
.28795 .16386 L
.28901 .16388 L
.28999 .164 L
.29106 .16424 L
.29218 .1646 L
.29333 .16508 L
.29455 .16571 L
.29676 .1671 L
.30176 .17124 L
.32165 .19256 L
.3271 .19785 L
.33287 .20262 L
.33786 .20596 L
Mistroke
.34323 .20871 L
.34586 .20976 L
.34836 .21059 L
.35079 .21126 L
.35305 .21176 L
.35745 .21249 L
.35977 .21276 L
.36224 .21299 L
.37315 .21364 L
.37793 .21395 L
.38318 .21442 L
.38819 .21505 L
.39347 .21592 L
.40461 .21841 L
.42478 .22429 L
.44594 .23029 L
.46523 .23442 L
.47481 .236 L
.48522 .23743 L
.50415 .23957 L
.52355 .24143 L
.54496 .24321 L
.56546 .24462 L
.58424 .24563 L
.6036 .24643 L
.62447 .24708 L
.6434 .24753 L
.66411 .24789 L
.68373 .24813 L
.69472 .24824 L
.70469 .24831 L
.71402 .24837 L
.72389 .24842 L
.73472 .24846 L
.74469 .24848 L
.75414 .2485 L
.75934 .24851 L
.76428 .24852 L
.76886 .24852 L
.77386 .24853 L
.77806 .24853 L
.7826 .24853 L
.78538 .24853 L
.78794 .24853 L
.79033 .24853 L
.79295 .24853 L
.79532 .24853 L
.79752 .24853 L
.79871 .24854 L
.79984 .24854 L
Mistroke
.80114 .24854 L
.80233 .24854 L
.80353 .24854 L
.80422 .24854 L
.80487 .24854 L
.80616 .24854 L
.80689 .24854 L
.80756 .24854 L
.80874 .24854 L
.81003 .24854 L
.81239 .24854 L
.81513 .24853 L
.81806 .24853 L
.82332 .24853 L
.8336 .24853 L
.839 .24853 L
.84472 .24853 L
.84972 .24853 L
.8511 .24853 L
.85257 .24853 L
.85384 .24853 L
.85522 .24853 L
.85587 .24853 L
.85657 .24853 L
.85782 .24853 L
.85899 .24853 L
.86028 .24853 L
.86142 .24853 L
.86265 .24853 L
.86382 .24853 L
.86489 .24853 L
.86737 .24853 L
.86962 .24853 L
.87223 .24853 L
.87468 .24853 L
.87906 .24853 L
.8838 .24853 L
.89457 .24854 L
.9045 .24854 L
.92325 .24855 L
.94389 .24857 L
.97619 .24861 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.06244 .23873 L
.08255 .36441 L
.10458 .48506 L
.11448 .53041 L
.11992 .55193 L
.12507 .56939 L
.12986 .5825 L
.13256 .58825 L
.13385 .5905 L
.13506 .5923 L
.13616 .59365 L
.13716 .59463 L
.13827 .59543 L
.13947 .59591 L
.14062 .59597 L
.14187 .59556 L
.14305 .59468 L
.14415 .5934 L
.14544 .59127 L
.1468 .58823 L
.14796 .58492 L
.14923 .58046 L
.15207 .56693 L
.15472 .54905 L
.15723 .52649 L
.15952 .50051 L
.16467 .42322 L
.16925 .34445 L
.17166 .30836 L
.17299 .29194 L
.17423 .27897 L
.1754 .26897 L
.17646 .26156 L
.17765 .25515 L
.17893 .25017 L
.17994 .24747 L
.18105 .2456 L
.18221 .24471 L
.18328 .24472 L
.18456 .24561 L
.1852 .24638 L
.18591 .24745 L
.18833 .25255 L
.19116 .26072 L
.1938 .26986 L
.20374 .31061 L
.22233 .38695 L
.22731 .40379 L
.22993 .41163 L
Mistroke
.23273 .419 L
.23542 .42493 L
.23786 .4291 L
.23904 .43063 L
.24031 .43188 L
.24151 .43262 L
.24261 .43289 L
.24369 .43273 L
.24484 .43204 L
.24593 .43085 L
.24692 .42928 L
.24808 .42679 L
.24934 .42324 L
.25163 .41447 L
.25403 .40234 L
.25658 .3871 L
.26115 .35751 L
.27055 .30059 L
.27548 .27572 L
.28066 .25452 L
.28522 .2402 L
.28764 .23418 L
.29021 .22885 L
.29259 .22482 L
.29474 .22184 L
.29692 .21941 L
.29895 .21759 L
.30127 .21598 L
.3026 .21526 L
.30382 .2147 L
.3063 .21385 L
.30767 .21351 L
.30896 .21327 L
.31007 .21311 L
.31125 .21298 L
.31226 .2129 L
.31337 .21283 L
.31456 .21279 L
.31585 .21276 L
.31706 .21274 L
.31818 .21273 L
.31939 .21273 L
.32068 .21271 L
.3219 .21269 L
.32301 .21266 L
.32432 .21261 L
.32506 .21257 L
.32574 .21252 L
.32699 .21241 L
.32831 .21227 L
Mistroke
.33093 .21187 L
.33339 .21135 L
.33609 .21061 L
.33899 .20959 L
.34423 .20722 L
.3491 .20447 L
.36014 .19704 L
.36979 .19039 L
.38023 .18426 L
.38574 .1817 L
.39081 .17977 L
.39556 .17832 L
.40077 .17708 L
.40545 .17625 L
.40982 .17566 L
.41444 .1752 L
.41938 .17484 L
.42467 .17457 L
.42957 .17439 L
.44064 .17405 L
.46076 .17328 L
.48103 .1723 L
.49095 .17187 L
.50005 .17155 L
.50891 .17133 L
.51336 .17125 L
.51823 .17118 L
.52314 .17113 L
.52589 .17111 L
.52838 .17109 L
.53071 .17108 L
.53203 .17108 L
.53324 .17108 L
.5343 .17107 L
.53546 .17107 L
.53668 .17107 L
.53782 .17107 L
.53907 .17107 L
.53977 .17107 L
.54041 .17107 L
.54164 .17107 L
.54281 .17107 L
.54542 .17108 L
.54824 .17108 L
.55339 .1711 L
.55812 .17112 L
.57666 .17121 L
.59554 .17133 L
.61622 .1715 L
.63579 .1717 L
Mistroke
.65672 .17197 L
.69815 .17257 L
.73807 .17323 L
.77647 .17392 L
.81733 .1747 L
.85666 .17548 L
.89449 .17625 L
.93476 .17707 L
.97352 .17786 L
.97619 .17792 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.06244 .23841 L
.08255 .36411 L
.10458 .48501 L
.11448 .53063 L
.11992 .55239 L
.12507 .57018 L
.12986 .58374 L
.13238 .58947 L
.13506 .59429 L
.13614 .59583 L
.13731 .5972 L
.13859 .59833 L
.13979 .59902 L
.14096 .59932 L
.14207 .59923 L
.14306 .59883 L
.14415 .59802 L
.1448 .59733 L
.14548 .59645 L
.1467 .5944 L
.14802 .5915 L
.14946 .5874 L
.15205 .57737 L
.15447 .56445 L
.15683 .54801 L
.15898 .52936 L
.16382 .47423 L
.16911 .39999 L
.172 .36133 L
.17472 .33161 L
.17702 .31293 L
.17832 .3051 L
.17951 .29951 L
.18074 .29519 L
.18144 .29335 L
.18209 .29199 L
.1834 .29024 L
.18413 .28977 L
.1848 .28964 L
.18599 .29002 L
.18725 .2912 L
.18832 .29274 L
.18951 .29494 L
.19215 .30136 L
.19461 .30882 L
.20388 .34365 L
.22464 .42812 L
.23505 .46494 L
.24018 .48048 L
Mistroke
.24493 .49281 L
.24923 .50178 L
.25163 .50568 L
.2538 .50842 L
.25505 .50962 L
.25619 .51047 L
.25745 .51112 L
.25809 .51133 L
.25878 .51148 L
.25995 .51152 L
.26121 .51129 L
.26239 .51082 L
.26347 .51018 L
.26465 .50928 L
.26576 .50825 L
.26829 .50532 L
.27341 .49744 L
.28259 .48019 L
.29272 .46192 L
.29824 .45365 L
.30336 .44729 L
.30843 .44224 L
.31303 .43865 L
.31814 .4356 L
.32359 .43327 L
.32816 .43187 L
.33312 .43077 L
.3421 .42933 L
.3524 .42772 L
.36202 .42558 L
.37205 .42245 L
.38307 .41815 L
.40169 .41022 L
.42195 .40282 L
.44317 .3973 L
.46328 .39351 L
.50403 .38734 L
.54326 .38266 L
.58098 .37943 L
.62115 .37689 L
.65981 .37508 L
.70092 .37372 L
.74051 .37279 L
.77858 .37215 L
.81911 .37165 L
.85813 .37128 L
.89959 .37098 L
.93954 .37072 L
.97619 .37052 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.06244 .23839 L
.08255 .36407 L
.10458 .48498 L
.11448 .53062 L
.11992 .5524 L
.12507 .57021 L
.12986 .58379 L
.13238 .58954 L
.13506 .59438 L
.13614 .59593 L
.13731 .59731 L
.13859 .59846 L
.13979 .59917 L
.14096 .59948 L
.14207 .59941 L
.14306 .59902 L
.14415 .59822 L
.1448 .59755 L
.14548 .59667 L
.1467 .59465 L
.14802 .59177 L
.14946 .58769 L
.15205 .57771 L
.15447 .56482 L
.15683 .54839 L
.15898 .52972 L
.16382 .47435 L
.16911 .39963 L
.172 .36083 L
.17472 .33115 L
.17702 .31257 L
.17832 .30479 L
.17951 .29924 L
.18074 .29493 L
.18144 .29309 L
.18209 .29174 L
.1834 .28995 L
.18413 .28946 L
.1848 .2893 L
.18599 .28961 L
.18725 .29069 L
.18832 .29214 L
.18951 .2942 L
.19215 .30026 L
.19461 .30727 L
.20388 .33941 L
.21453 .37856 L
.22464 .41222 L
.22934 .42553 L
Mistroke
.23435 .4371 L
.23583 .43985 L
.23723 .44207 L
.23859 .44385 L
.23984 .44512 L
.24103 .44595 L
.24229 .44637 L
.24355 .44627 L
.24426 .44596 L
.24493 .44548 L
.24608 .4442 L
.24734 .44211 L
.24852 .43939 L
.24962 .43622 L
.25169 .42841 L
.25388 .41774 L
.26347 .3604 L
.26805 .33584 L
.27286 .31446 L
.27539 .30521 L
.27814 .29662 L
.28068 .29009 L
.28298 .28523 L
.28518 .28147 L
.28756 .27831 L
.28888 .27695 L
.29008 .27591 L
.29131 .27506 L
.29246 .27444 L
.29344 .27404 L
.2945 .27373 L
.29567 .27353 L
.29674 .27347 L
.29785 .27352 L
.29907 .27371 L
.30021 .274 L
.30127 .27436 L
.30368 .27547 L
.30589 .2768 L
.31088 .28066 L
.31991 .28944 L
.33057 .30047 L
.3405 .3096 L
.34964 .31621 L
.35432 .31886 L
.3594 .32119 L
.36498 .32317 L
.37024 .32456 L
.37537 .32558 L
.3801 .32631 L
Mistroke
.40043 .32863 L
.41947 .33142 L
.45732 .33843 L
.47758 .34139 L
.49611 .34337 L
.53584 .34638 L
.57405 .34859 L
.59374 .34947 L
.61472 .35023 L
.63471 .35082 L
.65632 .35133 L
.69641 .35202 L
.71636 .35226 L
.73743 .35247 L
.77542 .35274 L
.79495 .35284 L
.81587 .35293 L
.85725 .35308 L
.89711 .35319 L
.93546 .3533 L
.97619 .35341 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.06244 .23849 L
.08255 .36418 L
.10458 .48502 L
.11448 .53058 L
.11992 .55229 L
.12507 .57001 L
.12986 .58347 L
.13238 .58912 L
.13506 .59385 L
.13614 .59535 L
.13731 .59666 L
.13859 .59773 L
.13979 .59835 L
.14096 .59857 L
.14207 .59841 L
.14306 .59793 L
.14415 .59701 L
.1448 .59627 L
.14548 .59531 L
.1467 .59312 L
.14802 .59004 L
.14946 .58571 L
.15205 .57517 L
.15447 .56161 L
.15683 .54434 L
.15898 .52474 L
.16382 .46672 L
.16911 .3891 L
.172 .34943 L
.17472 .31962 L
.17702 .30136 L
.17832 .29388 L
.17951 .28864 L
.18074 .2847 L
.18144 .28307 L
.18209 .28192 L
.1834 .28055 L
.18413 .28029 L
.1848 .28034 L
.18599 .28103 L
.18725 .28251 L
.18832 .28429 L
.18951 .28673 L
.19461 .30151 L
.20388 .33759 L
.22464 .42371 L
.23462 .45912 L
.23953 .47396 L
.24409 .48565 L
Mistroke
.24683 .4915 L
.24931 .49589 L
.25207 .49956 L
.2528 .5003 L
.25358 .50098 L
.25432 .50151 L
.25501 .50191 L
.25621 .50236 L
.25685 .50248 L
.25754 .50252 L
.25825 .50245 L
.25893 .5023 L
.26021 .50176 L
.2614 .501 L
.2625 .50008 L
.26498 .4973 L
.26963 .4901 L
.27463 .48046 L
.28368 .46155 L
.29354 .44317 L
.29874 .43535 L
.3043 .42863 L
.30976 .42357 L
.31471 .42014 L
.31969 .41761 L
.32438 .41589 L
.32966 .41452 L
.33452 .41358 L
.34549 .41183 L
.35018 .41097 L
.35521 .40985 L
.36429 .40721 L
.38495 .39867 L
.40474 .3898 L
.41518 .38579 L
.42628 .38223 L
.44695 .37721 L
.46609 .37366 L
.50381 .36776 L
.54398 .36285 L
.58263 .35951 L
.62374 .35693 L
.64424 .35593 L
.66333 .35514 L
.70141 .35394 L
.72184 .35346 L
.74042 .3531 L
.7612 .35276 L
.78037 .35251 L
.81881 .35212 L
Mistroke
.83755 .35198 L
.85818 .35185 L
.89849 .35164 L
.93728 .35149 L
.97619 .35136 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.06244 .23872 L
.08255 .36439 L
.10458 .48505 L
.11448 .53041 L
.11992 .55194 L
.12507 .5694 L
.12986 .58251 L
.13256 .58827 L
.13385 .59053 L
.13506 .59233 L
.13616 .59368 L
.13716 .59467 L
.13827 .59547 L
.13947 .59595 L
.14062 .59601 L
.14187 .59561 L
.14305 .59473 L
.14415 .59345 L
.14544 .59133 L
.1468 .58829 L
.14796 .58499 L
.14923 .58053 L
.15207 .56701 L
.15472 .54911 L
.15723 .5265 L
.15952 .50044 L
.16467 .42271 L
.16925 .34324 L
.17166 .30678 L
.17299 .29019 L
.17423 .27709 L
.1754 .26698 L
.17646 .25948 L
.17765 .25299 L
.17893 .24792 L
.17994 .24516 L
.18105 .24323 L
.18221 .24227 L
.18328 .24221 L
.18456 .24302 L
.1852 .24375 L
.18591 .24477 L
.18833 .24973 L
.19116 .25771 L
.1938 .26668 L
.20374 .30665 L
.21263 .3439 L
.22233 .38034 L
.22773 .39704 L
Mistroke
.23035 .4038 L
.23273 .40895 L
.23392 .41111 L
.2352 .41309 L
.23641 .41459 L
.23752 .41562 L
.2387 .41629 L
.24 .41648 L
.24065 .41633 L
.24135 .41597 L
.24261 .41476 L
.24386 .41278 L
.245 .41017 L
.24626 .40633 L
.2476 .40105 L
.24984 .38913 L
.25232 .37161 L
.26115 .29294 L
.26608 .25333 L
.27127 .21896 L
.2757 .19639 L
.27819 .1865 L
.28054 .17891 L
.28328 .17194 L
.28577 .16717 L
.28845 .16341 L
.28996 .16183 L
.29135 .16067 L
.29248 .15992 L
.29368 .15928 L
.295 .15875 L
.29624 .15841 L
.2969 .15828 L
.29763 .15818 L
.29894 .15809 L
.30022 .15811 L
.30141 .1582 L
.30258 .15836 L
.30382 .1586 L
.30603 .15913 L
.31102 .1607 L
.31538 .16216 L
.32005 .16353 L
.32271 .16413 L
.32514 .16453 L
.32631 .16467 L
.32758 .16478 L
.32877 .16484 L
.32988 .16487 L
.33116 .16484 L
Mistroke
.33237 .16478 L
.33368 .16467 L
.33443 .16458 L
.3351 .16448 L
.33794 .16396 L
.34064 .16326 L
.34567 .16155 L
.35024 .15965 L
.36046 .15499 L
.36941 .15136 L
.37391 .14992 L
.37885 .14869 L
.38136 .14821 L
.38404 .1478 L
.38658 .14751 L
.38778 .14741 L
.38889 .14733 L
.38997 .14726 L
.39116 .14721 L
.39236 .14717 L
.39363 .14715 L
.39474 .14715 L
.39594 .14716 L
.39708 .14718 L
.39811 .14722 L
.39933 .14727 L
.40063 .14733 L
.40296 .14749 L
.40826 .14797 L
.41894 .14927 L
.43887 .1518 L
.4501 .15288 L
.46046 .15363 L
.46971 .15413 L
.47989 .15459 L
.50046 .15545 L
.54082 .15736 L
.57966 .15886 L
.60085 .15946 L
.62096 .15993 L
.65922 .16067 L
.69994 .16125 L
.73914 .16168 L
.7808 .16208 L
.82094 .16244 L
.85956 .16279 L
.90063 .16316 L
.94019 .16352 L
.97619 .16386 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.06244 .2387 L
.08255 .36439 L
.10458 .48506 L
.11448 .53044 L
.11992 .55198 L
.12507 .56947 L
.12986 .58261 L
.13256 .58839 L
.13385 .59066 L
.13506 .59248 L
.13616 .59385 L
.13716 .59486 L
.13827 .59568 L
.13947 .59618 L
.14062 .59628 L
.14187 .59591 L
.14305 .59507 L
.14415 .59383 L
.14544 .59177 L
.1468 .5888 L
.14796 .58557 L
.14923 .58121 L
.15207 .56797 L
.15472 .55048 L
.15723 .52844 L
.15952 .50309 L
.16467 .42782 L
.16925 .35083 L
.17166 .31518 L
.17299 .29881 L
.17423 .2858 L
.1754 .27568 L
.17646 .26814 L
.17765 .26157 L
.17893 .2564 L
.17994 .25355 L
.18105 .25155 L
.18221 .25052 L
.18328 .25042 L
.18456 .25122 L
.1852 .25194 L
.18591 .25297 L
.18716 .25529 L
.18833 .25799 L
.1938 .27533 L
.20374 .31677 L
.22233 .39664 L
.22731 .41523 L
.23273 .43315 L
Mistroke
.23752 .44633 L
.24014 .45223 L
.24261 .45671 L
.24379 .45842 L
.24504 .4599 L
.24569 .46052 L
.24641 .46108 L
.24766 .46171 L
.2488 .46189 L
.25003 .46163 L
.25118 .46093 L
.25223 .45989 L
.25337 .45833 L
.25443 .45651 L
.25682 .45116 L
.26115 .43818 L
.27092 .40309 L
.28144 .36754 L
.28628 .35409 L
.29138 .3424 L
.29614 .33374 L
.30047 .32765 L
.305 .32286 L
.30732 .32093 L
.30983 .3192 L
.31431 .31685 L
.31854 .31528 L
.32353 .31394 L
.32881 .31278 L
.33827 .31044 L
.34322 .30875 L
.34773 .30683 L
.35789 .30111 L
.37621 .28754 L
.39688 .27264 L
.40598 .26741 L
.41602 .26268 L
.43459 .25613 L
.45432 .25079 L
.49449 .24161 L
.51295 .23823 L
.53315 .23527 L
.55316 .23301 L
.57426 .23114 L
.59384 .22977 L
.61478 .22866 L
.62501 .22824 L
.63611 .22787 L
.64658 .22759 L
.65625 .22739 L
Mistroke
.66091 .22731 L
.66593 .22724 L
.67026 .22719 L
.67499 .22715 L
.67786 .22712 L
.68052 .22711 L
.68327 .22709 L
.68577 .22708 L
.68695 .22708 L
.68822 .22707 L
.68933 .22707 L
.69054 .22707 L
.69183 .22707 L
.69253 .22707 L
.69319 .22707 L
.69436 .22707 L
.69562 .22707 L
.69684 .22707 L
.69754 .22707 L
.69819 .22707 L
.6995 .22707 L
.70091 .22707 L
.70346 .22708 L
.7058 .22709 L
.7112 .22711 L
.71688 .22715 L
.72649 .22724 L
.737 .22736 L
.75663 .22766 L
.77758 .22808 L
.8191 .22909 L
.8591 .23021 L
.89759 .23136 L
.93853 .2326 L
.97619 .23372 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.06244 .23864 L
.08255 .36433 L
.10458 .48505 L
.11448 .53048 L
.11992 .55206 L
.12507 .56961 L
.12986 .58283 L
.13256 .58868 L
.13385 .59099 L
.13506 .59284 L
.13616 .59425 L
.13716 .59529 L
.13827 .59616 L
.13947 .59672 L
.14062 .59688 L
.14187 .59658 L
.14305 .59583 L
.14415 .59468 L
.14544 .59273 L
.1468 .5899 L
.14796 .58681 L
.14923 .58262 L
.15207 .56989 L
.15472 .55304 L
.15723 .53184 L
.15952 .50749 L
.16467 .43518 L
.16925 .36055 L
.17166 .32535 L
.17423 .29577 L
.17646 .27757 L
.17774 .27021 L
.17893 .26507 L
.18002 .26171 L
.18102 .25963 L
.18212 .25831 L
.18328 .25789 L
.18452 .25836 L
.18521 .25901 L
.18585 .25981 L
.18703 .26176 L
.18828 .26441 L
.19283 .27785 L
.20302 .31929 L
.22139 .39944 L
.23083 .43498 L
.23603 .45161 L
.24096 .46479 L
.24318 .46968 L
Mistroke
.24554 .47405 L
.2469 .47611 L
.24813 .47766 L
.24937 .47889 L
.25053 .47973 L
.2516 .4802 L
.25272 .48039 L
.25368 .48029 L
.25474 .4799 L
.25587 .47915 L
.25709 .478 L
.25928 .47506 L
.26185 .47045 L
.26458 .46452 L
.26948 .45222 L
.28056 .42253 L
.29025 .40027 L
.2957 .39053 L
.30069 .38348 L
.30524 .37849 L
.3102 .37441 L
.31271 .37282 L
.31538 .37141 L
.3202 .36948 L
.32257 .36876 L
.32514 .3681 L
.32979 .36712 L
.33849 .36553 L
.34798 .36328 L
.35337 .36153 L
.35841 .35953 L
.37946 .34835 L
.39808 .33781 L
.41834 .32882 L
.42936 .32518 L
.43956 .32238 L
.45967 .31774 L
.4989 .31002 L
.53662 .30426 L
.55595 .30202 L
.57679 .30001 L
.59642 .29843 L
.6179 .29699 L
.63864 .29587 L
.65749 .29506 L
.67708 .2944 L
.69802 .29386 L
.71718 .29351 L
.72799 .29336 L
.73797 .29324 L
Mistroke
.747 .29316 L
.75671 .29309 L
.76228 .29306 L
.76737 .29304 L
.7722 .29302 L
.77734 .29301 L
.78 .293 L
.78251 .293 L
.78476 .29299 L
.78592 .29299 L
.7872 .29299 L
.78832 .29299 L
.78951 .29299 L
.79078 .29299 L
.79196 .29299 L
.79314 .29299 L
.79425 .29299 L
.79525 .29299 L
.79634 .29299 L
.79762 .29299 L
.79882 .29299 L
.80156 .29299 L
.80423 .293 L
.80711 .293 L
.81231 .29301 L
.81707 .29302 L
.82688 .29305 L
.83601 .29309 L
.85671 .29319 L
.89578 .29345 L
.9373 .29377 L
.97619 .29408 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.06244 .23856 L
.08255 .36425 L
.10458 .48504 L
.11448 .53054 L
.11992 .55219 L
.12507 .56982 L
.12986 .58317 L
.13238 .58875 L
.13376 .59132 L
.13506 .59338 L
.13623 .59494 L
.13731 .59608 L
.1385 .59703 L
.13979 .59763 L
.14086 .59777 L
.14202 .59753 L
.14313 .59689 L
.14415 .59592 L
.14544 .59414 L
.1468 .59152 L
.14796 .58862 L
.14923 .58469 L
.15207 .57268 L
.15472 .55678 L
.15723 .53678 L
.15952 .51387 L
.16467 .44595 L
.16933 .37407 L
.17161 .3419 L
.1737 .31719 L
.17589 .29729 L
.17704 .28934 L
.17825 .28271 L
.1795 .27762 L
.18065 .27427 L
.18192 .27196 L
.18264 .27121 L
.18328 .27085 L
.18455 .2709 L
.18573 .27174 L
.18702 .27342 L
.18838 .27594 L
.19067 .28153 L
.19319 .28921 L
.20237 .32464 L
.22313 .41226 L
.2331 .44829 L
.23802 .46326 L
.24257 .47493 L
Mistroke
.24532 .48066 L
.2478 .48485 L
.24912 .48663 L
.25056 .48816 L
.25134 .48882 L
.25207 .4893 L
.25276 .48965 L
.25349 .48989 L
.25468 .49002 L
.25595 .48979 L
.25716 .48922 L
.25825 .48842 L
.25953 .48716 L
.26093 .48543 L
.26347 .48147 L
.28289 .43668 L
.2932 .41554 L
.29899 .40652 L
.3043 .40014 L
.30903 .39582 L
.31419 .39235 L
.3168 .39101 L
.31958 .38983 L
.32459 .38823 L
.32973 .38706 L
.33457 .38619 L
.34362 .3846 L
.35337 .38222 L
.35828 .38061 L
.36367 .37853 L
.38214 .36958 L
.40326 .3591 L
.42253 .35181 L
.43208 .34907 L
.44249 .34658 L
.46141 .3428 L
.50216 .33595 L
.52238 .33314 L
.54139 .33093 L
.57911 .32759 L
.61776 .32513 L
.63778 .32417 L
.65887 .32334 L
.67881 .32273 L
.69695 .32229 L
.71653 .32191 L
.73748 .32161 L
.75664 .32141 L
.76745 .32133 L
.77743 .32127 L
Mistroke
.78646 .32122 L
.79617 .32119 L
.80173 .32117 L
.80682 .32116 L
.81165 .32115 L
.8168 .32114 L
.81946 .32113 L
.82197 .32113 L
.82441 .32113 L
.82665 .32113 L
.82879 .32113 L
.82987 .32113 L
.83105 .32113 L
.83223 .32113 L
.8335 .32113 L
.8347 .32113 L
.8358 .32113 L
.83708 .32113 L
.83773 .32113 L
.83845 .32113 L
.83971 .32113 L
.8409 .32113 L
.84357 .32113 L
.84644 .32113 L
.8517 .32113 L
.85653 .32114 L
.86634 .32115 L
.87546 .32117 L
.89617 .32122 L
.93523 .32133 L
.97619 .32147 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.06244 .23831 L
.08255 .36402 L
.10458 .48499 L
.11448 .5307 L
.11992 .55254 L
.12507 .57043 L
.12986 .58411 L
.13238 .58994 L
.13506 .59488 L
.13731 .59792 L
.13859 .59914 L
.13979 .59992 L
.14089 .6003 L
.14189 .60036 L
.14305 .60004 L
.14415 .59935 L
.1454 .59806 L
.1461 .59709 L
.14674 .59603 L
.1479 .59369 L
.14918 .59044 L
.1514 .58296 L
.15374 .57218 L
.15629 .55661 L
.15902 .53494 L
.16396 .48216 L
.16859 .421 L
.17113 .38761 L
.17351 .35974 L
.1757 .33871 L
.17771 .32387 L
.1788 .31761 L
.17994 .31229 L
.18109 .30817 L
.18234 .30494 L
.18303 .30368 L
.18368 .3028 L
.18489 .30189 L
.1862 .30185 L
.18694 .30221 L
.18761 .30276 L
.18875 .30411 L
.19 .30614 L
.19252 .31167 L
.19824 .32902 L
.20358 .34864 L
.22371 .4281 L
.23411 .46519 L
.23924 .48118 L
Mistroke
.24399 .49419 L
.24865 .50476 L
.25286 .51198 L
.25402 .5135 L
.25527 .51489 L
.25636 .51588 L
.25754 .51672 L
.25881 .51734 L
.2595 .51756 L
.26014 .51768 L
.2613 .51772 L
.26253 .5175 L
.26375 .51703 L
.26445 .51666 L
.2651 .51625 L
.26783 .51386 L
.27019 .51105 L
.27273 .50742 L
.28381 .48783 L
.29343 .47109 L
.29852 .46362 L
.30394 .45696 L
.3094 .45163 L
.31435 .44788 L
.31933 .44502 L
.32402 .44302 L
.3293 .4414 L
.33416 .44033 L
.33949 .43945 L
.34514 .43866 L
.3546 .43722 L
.35991 .43616 L
.36475 .43499 L
.38307 .42879 L
.40375 .42034 L
.42289 .41357 L
.44145 .40874 L
.46119 .40498 L
.4989 .39932 L
.53907 .39449 L
.57773 .39116 L
.61884 .38857 L
.65843 .38674 L
.69651 .38547 L
.73703 .3845 L
.77605 .38383 L
.81751 .38331 L
.85746 .38292 L
.8959 .38263 L
.93678 .38236 L
Mistroke
.97615 .38212 L
.97619 .38212 L
Mfstroke
.055 0 1 r
.02381 .01472 m
.06244 .23808 L
.08255 .36382 L
.10458 .48497 L
.11448 .53086 L
.11992 .55285 L
.12507 .57095 L
.12986 .58491 L
.13238 .59093 L
.13506 .59612 L
.13731 .59942 L
.13859 .60081 L
.13979 .60177 L
.14089 .60234 L
.14189 .60258 L
.14305 .6025 L
.14415 .60206 L
.1454 .6011 L
.1461 .60032 L
.14674 .59945 L
.14793 .59745 L
.14918 .59473 L
.15135 .5884 L
.15374 .57883 L
.15629 .56516 L
.15902 .54614 L
.16396 .49981 L
.16859 .44535 L
.17351 .38783 L
.17553 .36811 L
.17771 .35076 L
.17896 .34277 L
.1801 .33668 L
.18119 .33194 L
.18234 .32793 L
.18357 .32479 L
.18471 .32278 L
.18541 .32195 L
.18607 .32142 L
.1873 .32104 L
.1886 .32142 L
.1898 .32238 L
.19112 .32403 L
.19252 .32636 L
.19524 .3323 L
.19779 .33917 L
.20358 .35787 L
.22371 .43341 L
.23411 .47023 L
.24399 .49985 L
Mistroke
.24829 .51031 L
.25286 .51928 L
.25549 .5232 L
.25788 .52585 L
.25903 .5268 L
.26028 .52758 L
.26145 .52807 L
.26253 .52832 L
.2638 .52836 L
.265 .52816 L
.26607 .52779 L
.26724 .52719 L
.26852 .52633 L
.26987 .52517 L
.27229 .52258 L
.28139 .5089 L
.29135 .49208 L
.29658 .48416 L
.30207 .47699 L
.30694 .47172 L
.31225 .46708 L
.31709 .46379 L
.32158 .46143 L
.32622 .45958 L
.33043 .45832 L
.33529 .45725 L
.33987 .4565 L
.34873 .45536 L
.35823 .45402 L
.36368 .453 L
.36865 .45185 L
.37839 .44901 L
.39831 .44159 L
.41936 .4339 L
.43842 .42858 L
.45917 .42445 L
.49992 .41842 L
.53916 .41377 L
.57688 .41049 L
.61705 .40792 L
.6557 .40606 L
.69681 .40461 L
.7364 .40359 L
.77448 .40285 L
.81501 .40225 L
.85402 .40179 L
.89549 .40137 L
.93544 .40102 L
.97387 .40072 L
.97619 .4007 L
Mistroke
Mfstroke
.079 0 1 r
.02381 .01472 m
.06244 .23821 L
.08255 .3639 L
.10458 .48495 L
.11448 .53074 L
.11992 .55265 L
.12507 .57064 L
.12986 .58447 L
.13238 .59038 L
.13506 .59545 L
.13731 .59861 L
.13859 .59992 L
.13979 .60078 L
.14089 .60125 L
.14189 .6014 L
.14305 .6012 L
.14415 .60063 L
.1454 .59949 L
.1461 .59862 L
.14674 .59765 L
.1479 .59549 L
.14918 .59247 L
.1514 .58547 L
.15374 .57533 L
.15629 .56067 L
.15902 .54027 L
.16396 .49058 L
.16859 .43268 L
.17351 .37347 L
.17553 .35404 L
.17771 .33754 L
.17896 .33022 L
.1801 .32481 L
.18119 .32073 L
.18234 .3175 L
.18356 .31516 L
.18486 .31373 L
.18609 .31329 L
.1872 .31355 L
.18852 .31456 L
.18925 .31541 L
.18994 .31637 L
.19252 .3212 L
.19789 .33551 L
.20358 .35389 L
.21328 .38734 L
.22371 .42185 L
.22895 .4375 L
.23393 .45055 L
.23841 .46007 L
Mistroke
.24093 .46418 L
.24216 .46575 L
.24328 .46691 L
.24443 .4678 L
.24568 .46836 L
.24678 .46848 L
.24793 .46818 L
.24898 .46751 L
.24995 .46651 L
.25101 .46497 L
.25215 .46279 L
.25469 .45593 L
.25709 .44709 L
.26159 .42643 L
.27127 .37923 L
.27657 .35748 L
.28154 .34117 L
.28576 .33057 L
.29031 .32231 L
.29277 .31909 L
.29536 .31656 L
.29756 .31503 L
.29881 .31439 L
.29997 .31395 L
.30126 .31361 L
.3019 .31349 L
.30261 .31341 L
.30387 .31336 L
.30504 .31343 L
.30575 .31352 L
.30642 .31363 L
.30769 .31393 L
.30905 .31437 L
.31053 .31496 L
.31569 .31781 L
.32047 .32125 L
.33907 .33668 L
.34804 .34307 L
.35771 .34827 L
.36325 .35041 L
.36833 .3519 L
.37319 .35296 L
.37831 .35377 L
.3833 .35434 L
.38784 .35474 L
.39802 .35548 L
.40694 .35621 L
.41638 .35723 L
.42635 .3586 L
.43554 .36007 L
Mistroke
.45633 .36353 L
.47611 .36631 L
.49419 .36822 L
.51361 .36976 L
.53449 .37113 L
.57422 .3733 L
.61244 .37482 L
.63212 .37539 L
.6531 .37589 L
.67309 .37628 L
.6947 .37662 L
.73479 .37708 L
.75474 .37725 L
.77581 .37739 L
.81381 .37759 L
.85425 .37775 L
.89318 .37788 L
.93456 .37801 L
.97442 .37812 L
.97619 .37813 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.06244 .2387 L
.08255 .36438 L
.10458 .48506 L
.11448 .53044 L
.11992 .55198 L
.12507 .56948 L
.12986 .58263 L
.13256 .58841 L
.13385 .59069 L
.13506 .59251 L
.13616 .59388 L
.13716 .59489 L
.13827 .59571 L
.13947 .59622 L
.14062 .59632 L
.14187 .59596 L
.14305 .59513 L
.14415 .5939 L
.14544 .59184 L
.1468 .58888 L
.14796 .58566 L
.14923 .58131 L
.15207 .56812 L
.15472 .55067 L
.15723 .5287 L
.15952 .50343 L
.16467 .42843 L
.16925 .35173 L
.17166 .3162 L
.17299 .29989 L
.17423 .28691 L
.1754 .27682 L
.17646 .2693 L
.17765 .26274 L
.17893 .25758 L
.17994 .25474 L
.18105 .25273 L
.18221 .25171 L
.18328 .2516 L
.18456 .25239 L
.1852 .25311 L
.18591 .25413 L
.18716 .25644 L
.18833 .25912 L
.1938 .27633 L
.20374 .31724 L
.22233 .39519 L
.22731 .41305 L
.23273 .43 L
Mistroke
.23522 .43663 L
.23786 .44274 L
.24034 .44739 L
.24142 .44905 L
.24261 .45056 L
.24379 .45171 L
.24502 .45251 L
.24567 .45275 L
.24637 .45286 L
.24763 .45265 L
.24889 .45185 L
.25009 .45052 L
.25117 .44882 L
.25234 .44645 L
.25456 .44046 L
.25692 .43231 L
.26115 .41479 L
.27077 .37164 L
.28088 .33176 L
.28952 .30688 L
.29441 .29683 L
.29895 .28985 L
.30148 .28682 L
.30387 .28446 L
.30833 .28111 L
.31083 .27974 L
.31314 .27872 L
.31834 .27707 L
.32913 .27478 L
.3344 .27347 L
.33921 .27187 L
.34386 .26987 L
.34828 .26753 L
.35801 .26101 L
.37866 .24441 L
.3883 .23741 L
.39855 .23136 L
.4073 .22738 L
.41696 .22408 L
.42704 .22153 L
.43628 .2197 L
.45713 .21635 L
.47763 .21341 L
.49672 .21107 L
.51513 .20937 L
.52543 .20866 L
.5348 .20815 L
.55396 .20739 L
.56477 .20708 L
.57475 .20687 L
Mistroke
.58443 .2067 L
.59349 .20659 L
.59868 .20654 L
.60343 .2065 L
.60605 .20649 L
.60891 .20647 L
.61022 .20647 L
.61161 .20647 L
.61291 .20646 L
.61412 .20646 L
.61536 .20646 L
.61602 .20646 L
.61673 .20646 L
.61747 .20646 L
.61817 .20646 L
.61948 .20646 L
.62071 .20646 L
.62185 .20646 L
.62309 .20646 L
.62442 .20647 L
.62715 .20647 L
.62971 .20648 L
.63555 .20652 L
.64062 .20656 L
.64526 .2066 L
.65572 .20672 L
.67466 .20702 L
.69537 .20745 L
.73595 .2085 L
.77501 .20971 L
.81653 .21113 L
.85653 .21257 L
.89502 .21398 L
.93596 .21546 L
.97538 .21685 L
.97619 .21688 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36435 L
.10458 .48505 L
.11448 .53047 L
.11992 .55204 L
.12507 .56958 L
.12986 .58278 L
.13256 .58861 L
.13385 .59091 L
.13506 .59275 L
.13616 .59415 L
.13716 .59519 L
.13827 .59604 L
.13947 .59659 L
.14062 .59673 L
.14187 .59642 L
.14305 .59565 L
.14415 .59448 L
.14544 .5925 L
.1468 .58965 L
.14796 .58652 L
.14923 .5823 L
.15207 .56946 L
.15472 .5525 L
.15723 .53115 L
.15952 .50664 L
.16467 .434 L
.16925 .35939 L
.17166 .32441 L
.17299 .30818 L
.17423 .29518 L
.17646 .27731 L
.17765 .27055 L
.17893 .26516 L
.18004 .26191 L
.1812 .25972 L
.18219 .25872 L
.18328 .25845 L
.1846 .25908 L
.18582 .26048 L
.18645 .26148 L
.18715 .26277 L
.18857 .26591 L
.19356 .28122 L
.20289 .31888 L
.21384 .36621 L
.22384 .40632 L
.22862 .42335 L
.23382 .43974 L
Mistroke
.23879 .45265 L
.24095 .45718 L
.24329 .46117 L
.2447 .46304 L
.246 .46436 L
.24723 .46523 L
.24854 .46568 L
.24921 .46572 L
.24992 .4656 L
.25121 .46497 L
.25199 .46431 L
.25274 .46349 L
.25413 .46146 L
.25535 .45918 L
.25663 .45627 L
.25895 .45001 L
.26418 .43264 L
.2738 .39727 L
.28392 .36418 L
.29255 .3433 L
.29744 .33476 L
.30199 .32874 L
.30452 .3261 L
.3069 .32401 L
.31136 .321 L
.31387 .31973 L
.31617 .31878 L
.32137 .31719 L
.33216 .31494 L
.33743 .31372 L
.34224 .3123 L
.35131 .30854 L
.36104 .30291 L
.3817 .28825 L
.39171 .28154 L
.40237 .27552 L
.41224 .27109 L
.42151 .26783 L
.4397 .26316 L
.45981 .25929 L
.49846 .25315 L
.51848 .2508 L
.52867 .24987 L
.53957 .24904 L
.55929 .24789 L
.57764 .24712 L
.58787 .24679 L
.59897 .2465 L
.60944 .24629 L
.61911 .24614 L
Mistroke
.62377 .24609 L
.62879 .24605 L
.63122 .24603 L
.63352 .24602 L
.63579 .24601 L
.63785 .246 L
.63904 .246 L
.64033 .24599 L
.64104 .24599 L
.64169 .24599 L
.64297 .24599 L
.64407 .24599 L
.64528 .24599 L
.64654 .24599 L
.64772 .24599 L
.64839 .24599 L
.64911 .24599 L
.65044 .24599 L
.65172 .24599 L
.65291 .246 L
.65561 .24601 L
.65848 .24602 L
.66338 .24605 L
.66786 .24608 L
.67797 .24618 L
.69625 .24644 L
.71519 .24679 L
.7359 .24725 L
.77648 .24835 L
.81554 .24955 L
.85706 .25091 L
.89706 .25225 L
.93555 .25352 L
.97619 .25481 L
Mfstroke
.15 0 1 r
.02381 .01472 m
.06244 .23865 L
.08255 .36433 L
.10458 .48503 L
.11448 .53045 L
.11992 .55203 L
.12507 .56956 L
.12986 .58277 L
.13256 .5886 L
.13385 .5909 L
.13506 .59274 L
.13616 .59414 L
.13716 .59517 L
.13827 .59603 L
.13947 .59657 L
.14062 .59671 L
.14187 .5964 L
.14305 .59561 L
.14415 .59443 L
.14544 .59244 L
.1468 .58957 L
.14796 .58642 L
.14923 .58216 L
.15207 .56921 L
.15472 .55205 L
.15723 .5304 L
.15952 .50546 L
.16467 .43106 L
.16925 .35424 L
.17166 .31832 L
.17299 .30173 L
.17423 .28846 L
.17646 .2703 L
.17765 .26344 L
.17893 .25796 L
.18004 .25464 L
.1812 .25238 L
.18219 .25133 L
.18328 .25098 L
.1846 .25153 L
.18582 .25285 L
.18645 .2538 L
.18715 .25504 L
.18857 .25807 L
.19356 .27295 L
.20289 .30943 L
.21384 .35423 L
.22384 .39015 L
.22862 .40406 L
.23114 .41017 L
Mistroke
.23382 .41549 L
.23515 .41759 L
.2364 .41917 L
.23752 .42024 L
.23873 .42098 L
.23989 .42122 L
.24111 .42092 L
.24215 .42017 L
.24329 .41876 L
.24396 .4176 L
.24469 .41605 L
.24602 .4124 L
.24732 .4077 L
.24851 .40227 L
.25122 .38595 L
.2541 .36341 L
.26418 .27877 L
.26876 .24806 L
.27358 .22245 L
.2761 .21182 L
.27886 .20229 L
.28139 .1953 L
.28369 .19028 L
.28605 .18628 L
.28828 .18345 L
.29063 .18131 L
.29195 .18045 L
.29317 .17985 L
.29423 .17946 L
.29522 .1792 L
.2963 .17903 L
.29746 .17896 L
.29867 .179 L
.29982 .17914 L
.30086 .17933 L
.30199 .17962 L
.30431 .18041 L
.30682 .18151 L
.31137 .18391 L
.32174 .18976 L
.32707 .19223 L
.32998 .19328 L
.33269 .19406 L
.335 .19456 L
.3363 .19477 L
.33748 .19492 L
.33878 .19503 L
.33951 .19508 L
.34018 .1951 L
.34142 .19512 L
Mistroke
.34273 .1951 L
.34394 .19504 L
.34526 .19493 L
.3465 .19479 L
.34766 .19463 L
.35216 .19378 L
.35706 .19254 L
.36228 .19104 L
.36692 .18971 L
.37182 .18843 L
.37636 .18746 L
.38059 .18677 L
.38296 .18649 L
.38418 .18638 L
.3855 .18628 L
.38625 .18623 L
.38695 .18619 L
.3876 .18616 L
.38832 .18614 L
.38956 .18611 L
.39089 .1861 L
.39159 .18611 L
.39233 .18612 L
.39365 .18616 L
.39439 .18619 L
.39507 .18622 L
.39663 .18632 L
.39923 .18654 L
.40202 .18685 L
.40746 .18765 L
.41259 .18858 L
.42219 .19059 L
.44052 .19452 L
.45094 .19642 L
.46068 .1979 L
.48057 .20019 L
.50162 .20205 L
.54046 .20508 L
.56022 .20638 L
.58176 .20751 L
.6024 .20835 L
.62154 .20896 L
.64039 .20945 L
.66074 .20987 L
.68221 .21021 L
.70239 .21046 L
.72239 .21065 L
.74347 .21081 L
.78151 .21103 L
.82201 .21122 L
Mistroke
.86099 .21139 L
.90242 .21159 L
.94234 .21179 L
.97619 .21198 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.06244 .23827 L
.08255 .36395 L
.10458 .48495 L
.11448 .5307 L
.11992 .55257 L
.12507 .57051 L
.12986 .58426 L
.13238 .59013 L
.13506 .59513 L
.13731 .59822 L
.13859 .59948 L
.13979 .6003 L
.14089 .60073 L
.14189 .60082 L
.14305 .60056 L
.14415 .59992 L
.1454 .59871 L
.1461 .59778 L
.14674 .59676 L
.1479 .5945 L
.14918 .59135 L
.1514 .58407 L
.15374 .57357 L
.15629 .55838 L
.15902 .53722 L
.16396 .48563 L
.16859 .4257 L
.17113 .39287 L
.17351 .36535 L
.1757 .3445 L
.17771 .32972 L
.17877 .32357 L
.17994 .31811 L
.18111 .31387 L
.18234 .31065 L
.18303 .30936 L
.18368 .30844 L
.18489 .30744 L
.1862 .3073 L
.18694 .30759 L
.18761 .30808 L
.18875 .30932 L
.19 .3112 L
.19252 .31636 L
.19824 .33249 L
.20358 .3504 L
.22371 .41926 L
.22868 .43409 L
.23411 .44807 L
Mistroke
.2366 .4534 L
.23924 .45812 L
.24052 .45998 L
.24173 .46142 L
.24282 .46244 L
.24399 .4632 L
.24515 .46358 L
.24624 .46355 L
.24742 .46306 L
.24869 .46195 L
.24933 .46115 L
.25003 .46007 L
.25129 .45758 L
.25365 .451 L
.25589 .44264 L
.25827 .43203 L
.26253 .41061 L
.27193 .36473 L
.27686 .34516 L
.28204 .32901 L
.2866 .31858 L
.28919 .31414 L
.29159 .31089 L
.29381 .30859 L
.29582 .30702 L
.29693 .30636 L
.29814 .30579 L
.29928 .30539 L
.30033 .30513 L
.30159 .30495 L
.30278 .30491 L
.30386 .30497 L
.30502 .30513 L
.30629 .30542 L
.30763 .30583 L
.31005 .30684 L
.31437 .30932 L
.31913 .3128 L
.3299 .32197 L
.33979 .33018 L
.34901 .33654 L
.35389 .33923 L
.35911 .34157 L
.36437 .3434 L
.36926 .34468 L
.37486 .34574 L
.37996 .34642 L
.40074 .34812 L
.40986 .34899 L
.41991 .35026 L
Mistroke
.43857 .35327 L
.45834 .3566 L
.4794 .35948 L
.49865 .36139 L
.53744 .36412 L
.57717 .36627 L
.61538 .36774 L
.63507 .3683 L
.65605 .36878 L
.67604 .36915 L
.69765 .36948 L
.73774 .36992 L
.75769 .37008 L
.77876 .37021 L
.81675 .37041 L
.8572 .37057 L
.89612 .3707 L
.93751 .37083 L
.97619 .37095 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.06244 .23846 L
.08255 .36416 L
.10458 .48502 L
.11448 .53061 L
.11992 .55234 L
.12507 .57009 L
.12986 .58358 L
.13238 .58927 L
.13506 .59403 L
.13614 .59554 L
.13731 .59688 L
.13859 .59798 L
.13979 .59863 L
.14096 .59888 L
.14207 .59875 L
.14306 .5983 L
.14415 .59743 L
.1448 .59671 L
.14548 .59578 L
.1467 .59365 L
.14802 .59064 L
.14946 .58642 L
.15205 .5761 L
.15447 .56284 L
.15683 .54596 L
.15898 .52683 L
.16382 .47033 L
.16911 .39477 L
.172 .35592 L
.17472 .32644 L
.17702 .30816 L
.17832 .30058 L
.17951 .29522 L
.18074 .29112 L
.18144 .28939 L
.18209 .28814 L
.1834 .28656 L
.18413 .28618 L
.1848 .28611 L
.18599 .2866 L
.18725 .28785 L
.18832 .28944 L
.18951 .29167 L
.19215 .2981 L
.19461 .30553 L
.20388 .3401 L
.22464 .4242 L
.23505 .46047 L
.24018 .47547 L
Mistroke
.24493 .48703 L
.24714 .49145 L
.24923 .49494 L
.25038 .49656 L
.25163 .49804 L
.25275 .49911 L
.2538 .49989 L
.25497 .50048 L
.25625 .50079 L
.2575 .50075 L
.2582 .50058 L
.25884 .50034 L
.25998 .49971 L
.26122 .49875 L
.26347 .49631 L
.26581 .49298 L
.26833 .48867 L
.27289 .47955 L
.28328 .45655 L
.29333 .43679 L
.29864 .42849 L
.3043 .42143 L
.30976 .41628 L
.31471 .41283 L
.31969 .41032 L
.32438 .40863 L
.32966 .40728 L
.33452 .40637 L
.34549 .40459 L
.35018 .40369 L
.35521 .4025 L
.36429 .3997 L
.38495 .39082 L
.40474 .38188 L
.41518 .37792 L
.42628 .37446 L
.44695 .36966 L
.46609 .36629 L
.50381 .36068 L
.52476 .35808 L
.54398 .3561 L
.58263 .35307 L
.60314 .35183 L
.62223 .35085 L
.6603 .34935 L
.68073 .34876 L
.69932 .34833 L
.72009 .34795 L
.73927 .34768 L
.75793 .34747 L
Mistroke
.7777 .34731 L
.78712 .34725 L
.79725 .34719 L
.81555 .34711 L
.82567 .34708 L
.8367 .34706 L
.84175 .34705 L
.84713 .34704 L
.8568 .34703 L
.86216 .34702 L
.86709 .34702 L
.86968 .34702 L
.87251 .34702 L
.87394 .34702 L
.87547 .34702 L
.8769 .34702 L
.87823 .34702 L
.87949 .34702 L
.88082 .34702 L
.88152 .34702 L
.88217 .34702 L
.88288 .34702 L
.88365 .34702 L
.88495 .34702 L
.88561 .34702 L
.88633 .34702 L
.8876 .34702 L
.88878 .34702 L
.89122 .34702 L
.89343 .34702 L
.8984 .34702 L
.90326 .34702 L
.90839 .34702 L
.9176 .34703 L
.9384 .34705 L
.97619 .34709 L
Mfstroke
.221 0 1 r
.02381 .01472 m
.06244 .23816 L
.08255 .36385 L
.10458 .48494 L
.11448 .53077 L
.11992 .55272 L
.12507 .57076 L
.12986 .58464 L
.13238 .5906 L
.13506 .59572 L
.13731 .59894 L
.13859 .60029 L
.13979 .60119 L
.14089 .60171 L
.14189 .60189 L
.14305 .60175 L
.14415 .60123 L
.1454 .60017 L
.1461 .59933 L
.14674 .59841 L
.1479 .59634 L
.14918 .59343 L
.1514 .58665 L
.15374 .57681 L
.15629 .56258 L
.15902 .54277 L
.16396 .49456 L
.16859 .43824 L
.17351 .37995 L
.17553 .36052 L
.17771 .34382 L
.17896 .33632 L
.1801 .33073 L
.18119 .32645 L
.18234 .32301 L
.18356 .32045 L
.18486 .3188 L
.18609 .31815 L
.1872 .31823 L
.18852 .31903 L
.18925 .31978 L
.18994 .32064 L
.19252 .32514 L
.19508 .33111 L
.19789 .33888 L
.20358 .35681 L
.22371 .42411 L
.22848 .43848 L
.23368 .45246 L
.23606 .45806 L
Mistroke
.2386 .4633 L
.24079 .4671 L
.24194 .46878 L
.24315 .47028 L
.24389 .47103 L
.24469 .47172 L
.24542 .4722 L
.24611 .47253 L
.24681 .47272 L
.24745 .47278 L
.24818 .47268 L
.24888 .47241 L
.25017 .47147 L
.25137 .47003 L
.25268 .46778 L
.25407 .46461 L
.25652 .45713 L
.25882 .44824 L
.26405 .42398 L
.2739 .37795 L
.27928 .3576 L
.28427 .34281 L
.28855 .33331 L
.29094 .32921 L
.29312 .32619 L
.29551 .32359 L
.29676 .3225 L
.29809 .32155 L
.29926 .32087 L
.30054 .32029 L
.3017 .31989 L
.30279 .31964 L
.30404 .31947 L
.30468 .31944 L
.30538 .31944 L
.30662 .31952 L
.30778 .3197 L
.30845 .31984 L
.30915 .32002 L
.3104 .32042 L
.31322 .3216 L
.31794 .32435 L
.32311 .32809 L
.34166 .34295 L
.35192 .34959 L
.36125 .35389 L
.36641 .35556 L
.36913 .35626 L
.37202 .35689 L
.37731 .35777 L
Mistroke
.38219 .35835 L
.40196 .35976 L
.41061 .36049 L
.42005 .36155 L
.43001 .36297 L
.43947 .36449 L
.46035 .36787 L
.48004 .37048 L
.50102 .3725 L
.52244 .37405 L
.54262 .37529 L
.58119 .37728 L
.60114 .37808 L
.62221 .37876 L
.66021 .37968 L
.67973 .38003 L
.70065 .38034 L
.72048 .38058 L
.74203 .38078 L
.7819 .38107 L
.8227 .38127 L
.86198 .38143 L
.89976 .38156 L
.93998 .38168 L
.97619 .3818 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.06244 .23862 L
.08255 .36431 L
.10458 .48505 L
.11448 .5305 L
.11992 .55211 L
.12507 .56968 L
.12986 .58295 L
.13256 .58883 L
.13506 .59302 L
.13607 .59435 L
.13716 .59551 L
.13835 .59645 L
.13947 .59699 L
.14073 .59718 L
.14192 .59691 L
.14299 .59626 L
.14415 .5951 L
.1448 .59423 L
.14548 .59313 L
.1467 .59066 L
.14802 .58724 L
.14946 .58247 L
.15205 .57093 L
.15447 .55612 L
.15683 .53726 L
.15898 .51581 L
.16382 .45223 L
.16898 .37043 L
.1717 .33122 L
.1732 .3132 L
.17459 .29901 L
.17591 .28814 L
.17711 .2802 L
.17845 .27348 L
.17915 .27076 L
.17989 .26845 L
.18111 .26577 L
.18224 .26437 L
.18347 .26389 L
.18417 .26405 L
.1848 .26443 L
.18599 .26569 L
.18711 .26745 L
.18965 .27313 L
.19212 .28039 L
.19478 .28954 L
.20398 .32692 L
.22478 .41367 L
.23491 .44795 L
Mistroke
.23769 .45572 L
.24064 .46298 L
.24341 .46865 L
.24595 .47271 L
.24723 .47425 L
.24857 .47548 L
.24926 .47595 L
.24991 .47627 L
.25063 .4765 L
.25139 .47659 L
.25205 .47654 L
.25276 .47634 L
.25407 .4756 L
.25533 .47442 L
.2565 .47294 L
.25871 .46924 L
.26114 .464 L
.26606 .45096 L
.2763 .42004 L
.28707 .39086 L
.29627 .37275 L
.30147 .36549 L
.30631 .36048 L
.30874 .3585 L
.31137 .35672 L
.31369 .35541 L
.31614 .35426 L
.32078 .35262 L
.32505 .35153 L
.3347 .3497 L
.34001 .34862 L
.34505 .34735 L
.35531 .34366 L
.36466 .339 L
.38299 .32797 L
.40119 .31775 L
.41155 .31312 L
.42129 .30961 L
.44104 .30433 L
.46204 .30007 L
.50069 .29343 L
.52032 .29073 L
.5418 .2884 L
.5623 .28668 L
.58139 .28539 L
.6001 .28437 L
.6204 .28349 L
.63149 .2831 L
.64173 .2828 L
.65213 .28255 L
Mistroke
.66187 .28236 L
.67166 .2822 L
.68061 .28209 L
.69055 .282 L
.69603 .28196 L
.70124 .28194 L
.70383 .28193 L
.70628 .28192 L
.70849 .28191 L
.71084 .28191 L
.71206 .28191 L
.7134 .2819 L
.71461 .2819 L
.71575 .2819 L
.71644 .2819 L
.71709 .2819 L
.71831 .2819 L
.71963 .2819 L
.72037 .2819 L
.72106 .2819 L
.72212 .2819 L
.72325 .2819 L
.7253 .28191 L
.72774 .28191 L
.72998 .28191 L
.7346 .28193 L
.73945 .28195 L
.74901 .282 L
.75921 .28207 L
.77758 .28224 L
.8191 .28278 L
.8591 .28341 L
.89759 .28408 L
.93853 .2848 L
.97619 .28545 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.06244 .23835 L
.08255 .36406 L
.10458 .48501 L
.11448 .53069 L
.11992 .5525 L
.12507 .57035 L
.12986 .58399 L
.13238 .58978 L
.13506 .59467 L
.13614 .59625 L
.13731 .59766 L
.13859 .59885 L
.13979 .5996 L
.14096 .59996 L
.14207 .59994 L
.14306 .59961 L
.14415 .59887 L
.1448 .59824 L
.14548 .59741 L
.1467 .59549 L
.14802 .59273 L
.14946 .58882 L
.15205 .57921 L
.15447 .56682 L
.15683 .55104 L
.15898 .53318 L
.16382 .48046 L
.16911 .40931 L
.172 .37179 L
.17472 .34244 L
.17702 .32356 L
.17832 .31547 L
.17951 .30957 L
.18074 .30488 L
.18209 .30124 L
.18276 .29995 L
.18349 .29892 L
.1848 .29795 L
.18608 .29794 L
.18727 .29866 L
.18856 .30015 L
.18922 .30114 L
.18994 .30239 L
.1948 .31445 L
.20388 .3465 L
.22464 .42863 L
.23462 .4636 L
.24409 .49044 L
.24931 .50125 L
Mistroke
.25074 .50356 L
.25227 .50564 L
.25358 .50712 L
.25428 .50777 L
.25501 .50836 L
.25568 .5088 L
.25641 .50919 L
.2577 .50962 L
.25902 .50972 L
.26024 .50951 L
.26144 .50904 L
.26253 .50839 L
.26379 .50739 L
.26498 .50622 L
.26959 .49999 L
.27466 .4909 L
.28493 .4701 L
.29392 .4536 L
.30336 .44041 L
.3082 .43545 L
.31348 .43128 L
.31829 .42846 L
.32275 .42652 L
.32804 .42487 L
.33285 .4238 L
.34362 .42209 L
.35296 .4205 L
.35767 .41946 L
.36284 .41808 L
.37368 .4144 L
.38365 .41029 L
.40477 .40124 L
.42405 .39456 L
.4336 .39201 L
.444 .3897 L
.46292 .38631 L
.50367 .38039 L
.5239 .37793 L
.54291 .37598 L
.58062 .373 L
.61928 .37077 L
.6389 .36988 L
.66039 .36907 L
.69998 .36796 L
.71957 .36756 L
.74051 .3672 L
.7604 .36694 L
.78197 .36671 L
.82192 .36641 L
.84177 .3663 L
Mistroke
.86281 .36621 L
.90066 .36609 L
.94097 .366 L
.97619 .36594 L
Mfstroke
.292 0 1 r
.02381 .01472 m
.06244 .23821 L
.08255 .36393 L
.10458 .48499 L
.11448 .53078 L
.11992 .55268 L
.12507 .57066 L
.12986 .58447 L
.13238 .59038 L
.13506 .59543 L
.13731 .59858 L
.13859 .59988 L
.13979 .60074 L
.14089 .6012 L
.14189 .60134 L
.14305 .60113 L
.14415 .60055 L
.1454 .59941 L
.1461 .59853 L
.14674 .59755 L
.1479 .59539 L
.14918 .59236 L
.1514 .58533 L
.15374 .57517 L
.15629 .56048 L
.15902 .54005 L
.16396 .49033 L
.16859 .43238 L
.17351 .37292 L
.17553 .35328 L
.17771 .33648 L
.17896 .32896 L
.1801 .32335 L
.18119 .31908 L
.18234 .31564 L
.18356 .31309 L
.18486 .31145 L
.18609 .31082 L
.1872 .31092 L
.18852 .31176 L
.18925 .31254 L
.18994 .31344 L
.19252 .31812 L
.19508 .32439 L
.19789 .33265 L
.20358 .35215 L
.22371 .4295 L
.23368 .46488 L
.24315 .4931 L
.24838 .5053 L
Mistroke
.25113 .51044 L
.25265 .51281 L
.25407 .51472 L
.25538 .51617 L
.25679 .51741 L
.25807 .51823 L
.25925 .51872 L
.26036 .51895 L
.26158 .51894 L
.26286 .51866 L
.26405 .51815 L
.26531 .51736 L
.26666 .51626 L
.26907 .51369 L
.27452 .50569 L
.28444 .48748 L
.29413 .47043 L
.30301 .45815 L
.30759 .45327 L
.3124 .44916 L
.31724 .44597 L
.32252 .44338 L
.3271 .44176 L
.332 .44049 L
.33662 .43961 L
.34081 .43896 L
.35015 .43763 L
.36003 .4358 L
.3652 .43453 L
.37087 .43285 L
.38084 .4293 L
.40196 .4207 L
.42124 .41377 L
.44119 .40855 L
.46011 .405 L
.49841 .39939 L
.53916 .39464 L
.57839 .3914 L
.61611 .38913 L
.65628 .38735 L
.69494 .38613 L
.71495 .38565 L
.73604 .38524 L
.77412 .38466 L
.79371 .38443 L
.81465 .38422 L
.85612 .3839 L
.89606 .38367 L
.9345 .38349 L
.97539 .38332 L
Mistroke
.97619 .38332 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.06244 .23813 L
.08255 .36386 L
.10458 .48498 L
.11448 .53083 L
.11992 .55279 L
.12507 .57085 L
.12986 .58475 L
.13238 .59073 L
.13506 .59587 L
.13731 .59912 L
.13859 .60048 L
.13979 .6014 L
.14089 .60193 L
.14189 .60213 L
.14305 .60201 L
.14415 .60152 L
.1454 .60049 L
.1461 .59968 L
.14674 .59877 L
.14793 .59669 L
.14918 .59388 L
.15135 .58736 L
.15374 .57753 L
.15629 .56351 L
.15902 .544 L
.16396 .49653 L
.16859 .44089 L
.17351 .38267 L
.17553 .36296 L
.17771 .34577 L
.17896 .33793 L
.1801 .33199 L
.18119 .32741 L
.18234 .32358 L
.18357 .32062 L
.18471 .31878 L
.18541 .31805 L
.18607 .31761 L
.1873 .3174 L
.1886 .31793 L
.1898 .31904 L
.19112 .32083 L
.19252 .32329 L
.19779 .33653 L
.20358 .35558 L
.22371 .43171 L
.23368 .46707 L
.24315 .49559 L
.24838 .50816 L
Mistroke
.25113 .5136 L
.25407 .51827 L
.25547 .52005 L
.25679 .52143 L
.25797 .52242 L
.25925 .52321 L
.26046 .5237 L
.26175 .52394 L
.26284 .52392 L
.26405 .52366 L
.26536 .52311 L
.26657 .52238 L
.26789 .52133 L
.2693 .51997 L
.27428 .51349 L
.28359 .49747 L
.29367 .48008 L
.29896 .47232 L
.30452 .4655 L
.30939 .46067 L
.31471 .45652 L
.31954 .45366 L
.32403 .45164 L
.32867 .4501 L
.33288 .44905 L
.33774 .44815 L
.34232 .44747 L
.35207 .44614 L
.3574 .44526 L
.36238 .44426 L
.37118 .44197 L
.38084 .43873 L
.41972 .42397 L
.44093 .41827 L
.46105 .41446 L
.49935 .40887 L
.5401 .40412 L
.57933 .40086 L
.61705 .39856 L
.65722 .39674 L
.69587 .39547 L
.73698 .39452 L
.77657 .39386 L
.81465 .3934 L
.85518 .39302 L
.89419 .39273 L
.93566 .39247 L
.97561 .39225 L
.97619 .39225 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36434 L
.10458 .48504 L
.11448 .53045 L
.11992 .55202 L
.12507 .56955 L
.12986 .58275 L
.13256 .58857 L
.13385 .59087 L
.13506 .59271 L
.13616 .59411 L
.13716 .59514 L
.13827 .59599 L
.13947 .59653 L
.14062 .59666 L
.14187 .59634 L
.14305 .59556 L
.14415 .59437 L
.14544 .59238 L
.1468 .5895 L
.14796 .58635 L
.14923 .58209 L
.15207 .56914 L
.15472 .552 L
.15723 .5304 L
.15952 .50556 L
.16467 .43167 L
.16925 .35565 L
.17166 .32016 L
.17299 .30375 L
.17423 .29065 L
.17646 .27272 L
.17765 .26596 L
.17893 .26058 L
.18004 .25734 L
.1812 .25517 L
.18219 .25418 L
.18328 .25391 L
.1846 .25455 L
.18582 .25594 L
.18645 .25693 L
.18715 .25821 L
.18857 .26132 L
.19356 .27648 L
.20289 .31347 L
.21384 .35913 L
.22384 .39651 L
.22862 .41157 L
.23114 .4185 L
Mistroke
.23382 .42492 L
.2364 .42996 L
.23873 .43334 L
.23986 .43449 L
.24108 .43533 L
.24223 .4357 L
.24329 .43562 L
.2445 .435 L
.2458 .43362 L
.24702 .43158 L
.24814 .42902 L
.24945 .42513 L
.25087 .41976 L
.25346 .40712 L
.26418 .33741 L
.26911 .30677 L
.27441 .27777 L
.27908 .25661 L
.284 .23923 L
.28649 .23228 L
.28921 .22602 L
.29172 .22139 L
.29399 .21803 L
.29676 .2149 L
.29817 .21365 L
.29971 .21254 L
.30113 .21171 L
.30244 .2111 L
.30369 .21065 L
.30502 .21028 L
.30623 .21005 L
.30692 .20995 L
.30756 .20988 L
.30872 .2098 L
.30996 .20978 L
.31107 .20981 L
.31211 .20987 L
.31325 .20996 L
.31448 .2101 L
.31942 .2108 L
.32212 .21119 L
.32463 .2115 L
.32576 .21162 L
.32683 .2117 L
.32807 .21178 L
.32919 .21182 L
.33044 .21183 L
.33159 .21181 L
.33285 .21175 L
.33349 .2117 L
Mistroke
.33419 .21164 L
.33533 .21151 L
.33637 .21136 L
.33872 .21091 L
.34089 .21037 L
.34296 .20974 L
.35255 .20559 L
.36278 .19988 L
.37236 .19466 L
.38117 .19082 L
.38618 .1892 L
.39146 .18793 L
.39421 .18745 L
.39677 .18711 L
.39958 .18683 L
.40116 .18672 L
.40184 .18668 L
.4026 .18665 L
.40385 .1866 L
.40453 .18658 L
.40518 .18657 L
.40632 .18656 L
.40756 .18656 L
.40822 .18657 L
.40893 .18658 L
.40968 .1866 L
.41038 .18662 L
.41163 .18666 L
.41296 .18672 L
.4156 .18688 L
.4181 .18706 L
.42277 .18746 L
.4411 .18936 L
.45152 .19031 L
.46126 .19103 L
.48115 .19208 L
.5022 .19302 L
.54104 .19507 L
.58234 .19708 L
.62212 .19851 L
.66038 .19961 L
.7011 .20057 L
.7403 .20136 L
.78196 .20212 L
.82209 .20281 L
.86072 .20347 L
.90179 .20417 L
.94135 .20484 L
.97619 .20543 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.06244 .23866 L
.08255 .36434 L
.10458 .48505 L
.11448 .53046 L
.11992 .55204 L
.12507 .56957 L
.12986 .58278 L
.13256 .58861 L
.13385 .59091 L
.13506 .59275 L
.13616 .59415 L
.13716 .59519 L
.13827 .59604 L
.13947 .59659 L
.14062 .59673 L
.14187 .59642 L
.14305 .59565 L
.14415 .59448 L
.14544 .5925 L
.1468 .58964 L
.14796 .58652 L
.14923 .58229 L
.15207 .56944 L
.15472 .55245 L
.15723 .53105 L
.15952 .50648 L
.16467 .4336 L
.16925 .35871 L
.17166 .32366 L
.17299 .30742 L
.17423 .29441 L
.17646 .27657 L
.17765 .26982 L
.17893 .26445 L
.18004 .26121 L
.1812 .25903 L
.18219 .25804 L
.18328 .25776 L
.1846 .2584 L
.18582 .2598 L
.18645 .26079 L
.18715 .26207 L
.18857 .2652 L
.19356 .28039 L
.20289 .31753 L
.21384 .36371 L
.22384 .4022 L
.22862 .41816 L
.23382 .43301 L
Mistroke
.2362 .43865 L
.23873 .44365 L
.23997 .44564 L
.24112 .44722 L
.24217 .44836 L
.24329 .44928 L
.2446 .44988 L
.24582 .44994 L
.24652 .44974 L
.24716 .4494 L
.24789 .44881 L
.24859 .44804 L
.24998 .44586 L
.25127 .44308 L
.25268 .43917 L
.25418 .43408 L
.26418 .38664 L
.27358 .34026 L
.27851 .31917 L
.28369 .30054 L
.28826 .2874 L
.29324 .27643 L
.29777 .26921 L
.30199 .26448 L
.30462 .26232 L
.30705 .26079 L
.30972 .25953 L
.31254 .25857 L
.31499 .25799 L
.31728 .25759 L
.31979 .25727 L
.32248 .25701 L
.32487 .25679 L
.32747 .25653 L
.32977 .25625 L
.33221 .25588 L
.3344 .25546 L
.33682 .25489 L
.34108 .25357 L
.34599 .25153 L
.35116 .2488 L
.36041 .2428 L
.37048 .23556 L
.38125 .22837 L
.38656 .22536 L
.39158 .22292 L
.39646 .22094 L
.40097 .21944 L
.40516 .2183 L
.40978 .21732 L
Mistroke
.41441 .21656 L
.41933 .21598 L
.42182 .21575 L
.42453 .21555 L
.42693 .2154 L
.42948 .21527 L
.43429 .21508 L
.43875 .21495 L
.45964 .21449 L
.47963 .21395 L
.49014 .21369 L
.49543 .21359 L
.49847 .21355 L
.50124 .21351 L
.50392 .21349 L
.50645 .21347 L
.50785 .21346 L
.50913 .21346 L
.5098 .21345 L
.51054 .21345 L
.51132 .21345 L
.51204 .21345 L
.51328 .21345 L
.51457 .21345 L
.51568 .21346 L
.51689 .21346 L
.5182 .21347 L
.5196 .21348 L
.52212 .2135 L
.5273 .21356 L
.53219 .21363 L
.54133 .2138 L
.57981 .21473 L
.62075 .21579 L
.66017 .21687 L
.69808 .21796 L
.73844 .21914 L
.77728 .22029 L
.81858 .22153 L
.85836 .22272 L
.89663 .22387 L
.93734 .22507 L
.97619 .22618 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.06244 .23818 L
.08255 .36387 L
.10458 .48494 L
.11448 .53075 L
.11992 .55268 L
.12507 .5707 L
.12986 .58456 L
.13238 .5905 L
.13506 .5956 L
.13731 .5988 L
.13859 .60013 L
.13979 .60102 L
.14089 .60152 L
.14189 .60169 L
.14305 .60152 L
.14415 .60098 L
.1454 .5999 L
.1461 .59905 L
.14674 .5981 L
.1479 .596 L
.14918 .59305 L
.1514 .58619 L
.15374 .57625 L
.15629 .56186 L
.15902 .54184 L
.16396 .49313 L
.16859 .4363 L
.17351 .37781 L
.17553 .35843 L
.17771 .34187 L
.17896 .33446 L
.1801 .32896 L
.18119 .32478 L
.18234 .32143 L
.18356 .31897 L
.18486 .31742 L
.18609 .31687 L
.1872 .31703 L
.18852 .31792 L
.18925 .31872 L
.18994 .31962 L
.19252 .32427 L
.19508 .33036 L
.19789 .33824 L
.20358 .35634 L
.22371 .42389 L
.22848 .43826 L
.23368 .45223 L
.23606 .45781 L
Mistroke
.2386 .46302 L
.24079 .46679 L
.24194 .46845 L
.24315 .46992 L
.24389 .47065 L
.24469 .47132 L
.24542 .47178 L
.24611 .47208 L
.24681 .47225 L
.24745 .47228 L
.24818 .47215 L
.24888 .47186 L
.25017 .47085 L
.25137 .46935 L
.25268 .46704 L
.25407 .46381 L
.25652 .45625 L
.25882 .44733 L
.26405 .42315 L
.2739 .37723 L
.27928 .35683 L
.28427 .34196 L
.28855 .33238 L
.29074 .32855 L
.29312 .32517 L
.29573 .32231 L
.29692 .32127 L
.29819 .32036 L
.29933 .31969 L
.30058 .3191 L
.30172 .3187 L
.30279 .31843 L
.30404 .31824 L
.30468 .3182 L
.30538 .31819 L
.30662 .31825 L
.30778 .31841 L
.30845 .31855 L
.30915 .31872 L
.3104 .31909 L
.31322 .32024 L
.31794 .32293 L
.32311 .32662 L
.34166 .34125 L
.34694 .34483 L
.35192 .34775 L
.35645 .34998 L
.36125 .35191 L
.36647 .35352 L
.37129 .35463 L
Mistroke
.37648 .35548 L
.37943 .35584 L
.38219 .35612 L
.40074 .35735 L
.41124 .35821 L
.42098 .35934 L
.44213 .3626 L
.46223 .36582 L
.48276 .36844 L
.50138 .37018 L
.54146 .37287 L
.58003 .37488 L
.59999 .37568 L
.62106 .37637 L
.65905 .37729 L
.67857 .37764 L
.69949 .37795 L
.71932 .37819 L
.74087 .3784 L
.78074 .37868 L
.82154 .37889 L
.86083 .37905 L
.8986 .37919 L
.93882 .37932 L
.97619 .37945 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.06244 .23856 L
.08255 .36422 L
.10458 .485 L
.11448 .5305 L
.11992 .55215 L
.12507 .56979 L
.12986 .58314 L
.13238 .58872 L
.13376 .59129 L
.13506 .59334 L
.13623 .5949 L
.13731 .59605 L
.1385 .59699 L
.13979 .59758 L
.14086 .59772 L
.14202 .59747 L
.14313 .59682 L
.14415 .59584 L
.14544 .59403 L
.1468 .59139 L
.14796 .58846 L
.14923 .58449 L
.1506 .57922 L
.15207 .57233 L
.15472 .5562 L
.15739 .53436 L
.15993 .5078 L
.16467 .44247 L
.16893 .37416 L
.17117 .34071 L
.17352 .31118 L
.17477 .29844 L
.17615 .28698 L
.17741 .27865 L
.17855 .27277 L
.17974 .26824 L
.181 .26492 L
.18218 .26308 L
.18328 .26228 L
.18445 .26231 L
.18569 .26318 L
.18675 .2645 L
.18791 .2665 L
.19051 .27258 L
.19294 .27983 L
.20319 .31858 L
.22161 .38903 L
.22659 .40441 L
.22922 .41145 L
Mistroke
.23202 .41789 L
.2334 .4206 L
.23471 .42282 L
.23598 .42463 L
.23714 .42595 L
.23826 .42687 L
.23943 .42744 L
.24061 .42755 L
.2419 .42706 L
.24314 .4259 L
.24432 .42411 L
.24538 .42186 L
.24653 .41864 L
.24778 .41416 L
.24911 .40821 L
.25149 .39439 L
.26044 .32368 L
.26501 .29071 L
.26983 .26224 L
.27235 .24992 L
.27511 .23853 L
.27765 .22989 L
.27995 .2235 L
.28215 .2186 L
.28453 .21451 L
.28584 .21277 L
.28705 .21145 L
.28828 .21038 L
.28943 .2096 L
.29041 .20911 L
.29147 .20873 L
.29264 .2085 L
.29371 .20845 L
.29482 .20853 L
.29603 .20879 L
.29718 .20917 L
.29824 .20963 L
.30065 .21105 L
.30286 .21272 L
.30785 .21747 L
.31688 .22796 L
.32754 .24045 L
.33747 .24998 L
.34217 .25348 L
.34661 .25617 L
.35172 .25856 L
.35637 .26017 L
.35888 .26084 L
.36153 .26142 L
.3663 .26221 L
Mistroke
.36894 .26254 L
.37142 .2628 L
.37706 .26328 L
.38203 .26368 L
.38745 .26418 L
.39223 .26472 L
.39733 .26543 L
.40694 .26718 L
.41586 .26919 L
.43585 .27426 L
.45746 .27913 L
.47834 .28251 L
.49754 .28471 L
.53705 .28808 L
.57504 .29048 L
.59457 .29137 L
.61549 .2921 L
.63674 .29267 L
.65687 .29308 L
.67679 .2934 L
.69522 .29362 L
.7139 .29378 L
.7345 .29391 L
.75387 .294 L
.77473 .29407 L
.79478 .29411 L
.81589 .29415 L
.85402 .29421 L
.8946 .29427 L
.93366 .29434 L
.97518 .29443 L
.97619 .29443 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.06244 .2386 L
.08255 .36429 L
.10458 .48505 L
.11448 .53051 L
.11992 .55213 L
.12507 .56973 L
.12986 .58302 L
.13256 .58892 L
.13506 .59314 L
.13607 .59448 L
.13716 .59566 L
.13835 .59661 L
.13947 .59717 L
.14073 .59738 L
.14192 .59713 L
.14299 .59651 L
.14415 .59538 L
.1448 .59453 L
.14548 .59345 L
.1467 .59103 L
.14802 .58765 L
.14946 .58296 L
.15205 .57158 L
.15447 .55699 L
.15683 .53841 L
.15898 .51732 L
.16382 .4549 L
.16898 .3746 L
.1717 .33591 L
.1732 .31805 L
.17459 .30393 L
.17591 .29307 L
.17711 .2851 L
.17845 .27833 L
.17915 .27557 L
.17989 .27322 L
.18111 .27046 L
.18224 .26899 L
.18347 .26844 L
.18417 .26855 L
.1848 .26889 L
.18599 .27008 L
.18711 .27176 L
.18833 .27416 L
.18965 .27728 L
.19478 .29331 L
.20398 .32984 L
.22478 .41431 L
.23491 .44749 L
Mistroke
.23769 .45491 L
.24064 .46175 L
.24341 .46695 L
.24462 .46879 L
.24595 .47047 L
.24723 .4717 L
.24792 .4722 L
.24857 .47256 L
.24928 .47282 L
.24993 .47293 L
.25068 .47291 L
.25139 .47273 L
.25266 .472 L
.25384 .47088 L
.25513 .46915 L
.2565 .46676 L
.26105 .45559 L
.26606 .43969 L
.2763 .40436 L
.28188 .38667 L
.28707 .37245 L
.29189 .36148 L
.29627 .35345 L
.30113 .34654 L
.30365 .3437 L
.30631 .3412 L
.30869 .33936 L
.3113 .3377 L
.31589 .33554 L
.31847 .33466 L
.32124 .33392 L
.32625 .33294 L
.33098 .3322 L
.33601 .33139 L
.34031 .33054 L
.34505 .32932 L
.35029 .32756 L
.35521 .32551 L
.36627 .31965 L
.38638 .30734 L
.39619 .30197 L
.40654 .29733 L
.41537 .29421 L
.42503 .29156 L
.43529 .2894 L
.44462 .28781 L
.46556 .28482 L
.48634 .28218 L
.50551 .28008 L
.52417 .2785 L
Mistroke
.5337 .27786 L
.54395 .27729 L
.5635 .27645 L
.5818 .27588 L
.59192 .27563 L
.60295 .27541 L
.61337 .27525 L
.62305 .27514 L
.62813 .27509 L
.63362 .27505 L
.63615 .27504 L
.63881 .27503 L
.64112 .27502 L
.64358 .27501 L
.64482 .27501 L
.64599 .27501 L
.64712 .27501 L
.64818 .275 L
.64917 .275 L
.65023 .275 L
.65129 .275 L
.65246 .275 L
.65372 .275 L
.65488 .275 L
.65615 .27501 L
.65748 .27501 L
.65973 .27501 L
.6622 .27502 L
.66749 .27504 L
.67248 .27506 L
.68182 .27513 L
.69188 .27522 L
.70278 .27534 L
.74372 .27596 L
.78314 .27675 L
.82105 .27761 L
.86141 .27859 L
.90025 .27955 L
.94155 .28056 L
.97619 .28137 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.06244 .23847 L
.08255 .36414 L
.10458 .48498 L
.11448 .53056 L
.11992 .55228 L
.12507 .57001 L
.12986 .58348 L
.13238 .58915 L
.13506 .59389 L
.13614 .59539 L
.13731 .59672 L
.13859 .59779 L
.13979 .59842 L
.14096 .59865 L
.14207 .59849 L
.14306 .59801 L
.14415 .5971 L
.1448 .59636 L
.14548 .5954 L
.1467 .59322 L
.14802 .59013 L
.14946 .5858 L
.15205 .57523 L
.15447 .56161 L
.15683 .54422 L
.15898 .52442 L
.16382 .46552 L
.16911 .38636 L
.172 .34603 L
.17472 .31593 L
.17702 .2976 L
.17832 .29013 L
.17951 .28492 L
.18074 .28099 L
.18144 .27938 L
.18209 .27823 L
.1834 .27687 L
.18413 .27661 L
.1848 .27665 L
.18599 .27733 L
.18725 .27877 L
.18832 .28052 L
.18951 .2829 L
.19461 .29722 L
.20388 .33129 L
.21473 .37273 L
.22464 .40627 L
.22942 .41967 L
.23194 .42569 L
Mistroke
.23462 .43106 L
.23595 .43325 L
.2372 .43498 L
.23832 .43622 L
.23953 .43719 L
.24069 .43772 L
.24191 .4378 L
.24295 .43743 L
.24409 .43652 L
.24476 .43571 L
.24549 .43458 L
.24682 .4318 L
.24812 .42812 L
.24931 .42383 L
.25202 .41081 L
.2549 .39285 L
.26498 .32516 L
.26956 .30025 L
.27438 .27933 L
.2769 .27057 L
.27966 .26268 L
.28219 .25688 L
.28449 .25275 L
.28685 .24953 L
.28908 .24736 L
.2903 .24649 L
.29143 .24588 L
.29267 .24541 L
.29397 .24512 L
.29502 .24503 L
.29615 .24507 L
.29721 .24522 L
.29817 .24546 L
.29931 .24584 L
.30054 .24638 L
.30279 .24764 L
.30762 .25139 L
.31217 .25581 L
.32254 .26724 L
.33276 .27808 L
.33834 .28318 L
.34353 .28722 L
.34857 .29048 L
.35316 .29287 L
.35825 .29496 L
.36369 .29661 L
.36825 .29763 L
.3732 .29845 L
.38219 .29952 L
.42308 .30563 L
Mistroke
.44341 .31001 L
.46245 .3136 L
.48069 .31619 L
.5003 .31823 L
.54155 .32138 L
.56215 .32265 L
.58128 .32363 L
.61949 .32506 L
.64003 .32561 L
.65864 .326 L
.67952 .32636 L
.69872 .32662 L
.71748 .32681 L
.73729 .32697 L
.77529 .3272 L
.79481 .32728 L
.81573 .32735 L
.85711 .32748 L
.89698 .32759 L
.93533 .32769 L
.97613 .32781 L
.97619 .32781 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.06244 .23863 L
.08255 .36432 L
.10458 .48505 L
.11448 .53049 L
.11992 .55209 L
.12507 .56965 L
.12986 .5829 L
.13256 .58876 L
.13385 .59108 L
.13506 .59294 L
.13616 .59436 L
.13716 .59541 L
.13827 .59629 L
.13947 .59687 L
.14062 .59705 L
.14187 .59678 L
.14305 .59604 L
.14415 .59492 L
.14544 .593 L
.1468 .59022 L
.14796 .58717 L
.14923 .58303 L
.15207 .57046 L
.15472 .55384 L
.15723 .53294 L
.15952 .50897 L
.16467 .43801 L
.16925 .36493 L
.17166 .33041 L
.17423 .30131 L
.17646 .28333 L
.17774 .27602 L
.17893 .27091 L
.18002 .26756 L
.18102 .26547 L
.18212 .26413 L
.18328 .26366 L
.18452 .26409 L
.18521 .26469 L
.18585 .26546 L
.18703 .26734 L
.18828 .2699 L
.19283 .2829 L
.20302 .32267 L
.22139 .3983 L
.23083 .43106 L
.23603 .44574 L
.23859 .45176 L
.24096 .45644 L
Mistroke
.24318 .45986 L
.24442 .46132 L
.24554 .46232 L
.24678 .46303 L
.24747 .46324 L
.24811 .4633 L
.24929 .46306 L
.25053 .4623 L
.25158 .46123 L
.25269 .45964 L
.2547 .45564 L
.2571 .44917 L
.25928 .44202 L
.26934 .40225 L
.28001 .36144 L
.28913 .33491 L
.29431 .324 L
.29917 .31634 L
.30388 .311 L
.30624 .30896 L
.30882 .30716 L
.31104 .30591 L
.3134 .30483 L
.31766 .30343 L
.32024 .30283 L
.32303 .30231 L
.32809 .30154 L
.33266 .30082 L
.33756 .29984 L
.34246 .2985 L
.34705 .29684 L
.35747 .29161 L
.37853 .27758 L
.38868 .27117 L
.39974 .26547 L
.41019 .2615 L
.41986 .25888 L
.42947 .25703 L
.4385 .25572 L
.45909 .25344 L
.47754 .25165 L
.49775 .24995 L
.50742 .2493 L
.51776 .24875 L
.52868 .24831 L
.53885 .24801 L
.54417 .2479 L
.54908 .24781 L
.55436 .24773 L
.56017 .24767 L
Mistroke
.56523 .24762 L
.56995 .24759 L
.57495 .24757 L
.57775 .24755 L
.58032 .24755 L
.58161 .24754 L
.58282 .24754 L
.58392 .24754 L
.58509 .24754 L
.58636 .24754 L
.58753 .24754 L
.58879 .24754 L
.58951 .24754 L
.59017 .24754 L
.59136 .24754 L
.59248 .24754 L
.59349 .24754 L
.59459 .24754 L
.59705 .24755 L
.59932 .24755 L
.6041 .24757 L
.60937 .2476 L
.61488 .24763 L
.62005 .24767 L
.64024 .2479 L
.65875 .24819 L
.6984 .24902 L
.73653 .24998 L
.77711 .25114 L
.81617 .25233 L
.85769 .25363 L
.89769 .25488 L
.93618 .25606 L
.97619 .25725 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.06244 .23855 L
.08255 .36422 L
.10458 .485 L
.11448 .53051 L
.11992 .55218 L
.12507 .56983 L
.12986 .58319 L
.13238 .58878 L
.13376 .59136 L
.13506 .59342 L
.13623 .59498 L
.13731 .59614 L
.1385 .59709 L
.13979 .5977 L
.14086 .59785 L
.14202 .59761 L
.14313 .59698 L
.14415 .59602 L
.14544 .59424 L
.1468 .59163 L
.14796 .58874 L
.14923 .5848 L
.1506 .5796 L
.15207 .57278 L
.15472 .55683 L
.15739 .53526 L
.15993 .50907 L
.16467 .44481 L
.16893 .37777 L
.17117 .34493 L
.17352 .31586 L
.17477 .30328 L
.17615 .29194 L
.17741 .28367 L
.17855 .27783 L
.17974 .27331 L
.181 .26999 L
.18218 .26814 L
.18328 .26734 L
.18445 .26734 L
.18569 .26819 L
.18675 .26949 L
.18791 .27146 L
.19051 .27748 L
.19294 .28465 L
.20319 .32302 L
.22161 .39351 L
.22659 .40931 L
.22922 .41668 L
Mistroke
.23202 .4236 L
.23471 .42915 L
.23714 .433 L
.23832 .43438 L
.23959 .43547 L
.24079 .43606 L
.2419 .43618 L
.24297 .43586 L
.24413 .435 L
.24521 .43362 L
.2462 .43184 L
.24736 .42907 L
.24863 .42515 L
.25092 .41549 L
.25332 .40205 L
.25586 .3851 L
.26044 .35267 L
.26983 .29438 L
.27511 .26961 L
.27995 .25252 L
.28421 .24168 L
.28662 .23713 L
.28886 .23384 L
.29009 .23238 L
.29124 .23122 L
.2934 .22955 L
.29461 .22888 L
.29572 .22841 L
.29694 .22806 L
.29824 .22786 L
.29945 .22781 L
.30014 .22784 L
.30078 .22791 L
.30194 .22811 L
.30319 .22843 L
.30533 .22922 L
.3077 .23038 L
.31785 .23743 L
.32677 .24427 L
.33618 .2502 L
.34099 .25241 L
.34353 .25333 L
.34625 .25413 L
.34876 .2547 L
.35104 .25508 L
.35214 .25523 L
.35333 .25536 L
.35446 .25546 L
.3555 .25552 L
.3567 .25558 L
Mistroke
.35799 .25561 L
.35921 .25562 L
.36032 .25561 L
.36162 .25558 L
.36236 .25555 L
.36304 .25552 L
.36562 .25538 L
.37082 .25496 L
.37635 .25448 L
.37896 .25428 L
.38171 .25409 L
.38406 .25397 L
.3854 .25392 L
.38664 .25389 L
.38734 .25387 L
.38809 .25386 L
.3888 .25386 L
.38946 .25385 L
.3907 .25386 L
.39202 .25388 L
.3927 .25389 L
.39343 .25391 L
.39476 .25397 L
.39633 .25405 L
.39778 .25414 L
.40247 .25456 L
.40761 .2552 L
.41795 .25699 L
.43922 .26149 L
.45853 .26513 L
.47863 .26787 L
.4976 .26974 L
.53608 .27273 L
.55558 .27401 L
.57702 .27518 L
.59739 .27605 L
.61644 .27669 L
.65529 .27763 L
.67648 .27799 L
.69658 .27826 L
.71645 .27846 L
.73485 .27861 L
.77405 .27886 L
.81571 .27905 L
.85584 .27922 L
.89447 .27938 L
.93554 .27957 L
.9751 .27975 L
.97619 .27976 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.06244 .23852 L
.08255 .36422 L
.10458 .48504 L
.11448 .53057 L
.11992 .55226 L
.12507 .56994 L
.12986 .58335 L
.13238 .58897 L
.13376 .59156 L
.13506 .59365 L
.13623 .59524 L
.13731 .59641 L
.1385 .5974 L
.13979 .59804 L
.14086 .59822 L
.14202 .59804 L
.14313 .59745 L
.14415 .59654 L
.14544 .59484 L
.1468 .59231 L
.14796 .58952 L
.14923 .58571 L
.15207 .57407 L
.15472 .55865 L
.15723 .53929 L
.15952 .51714 L
.16467 .45172 L
.16933 .38241 L
.1737 .32683 L
.17589 .30702 L
.17712 .2985 L
.17825 .29225 L
.17942 .28726 L
.1807 .28333 L
.18135 .28189 L
.18204 .28074 L
.18328 .27953 L
.18456 .27933 L
.18529 .27963 L
.18595 .28014 L
.18718 .28159 L
.18848 .28378 L
.19072 .28885 L
.19319 .29587 L
.20237 .32931 L
.22313 .41285 L
.2331 .44722 L
.23802 .46127 L
.24257 .47187 L
Mistroke
.2451 .47645 L
.2464 .47836 L
.2478 .48005 L
.2486 .48082 L
.24934 .4814 L
.25004 .48183 L
.25079 .48215 L
.25208 .48235 L
.25281 .48226 L
.25349 .48204 L
.25479 .48126 L
.25601 .48009 L
.25711 .47869 L
.25831 .47683 L
.26347 .46551 L
.28289 .40825 L
.28821 .39487 L
.29394 .38303 L
.29935 .37437 L
.3043 .36844 L
.30905 .3643 L
.31346 .36158 L
.316 .3604 L
.3183 .35954 L
.32099 .35874 L
.32347 .35815 L
.32845 .35727 L
.33384 .35654 L
.33856 .35588 L
.34362 .35499 L
.3487 .35381 L
.35334 .35242 L
.36242 .34885 L
.38307 .33821 L
.39309 .33308 L
.40375 .32838 L
.41362 .32488 L
.42289 .32231 L
.44108 .31871 L
.46119 .31585 L
.49984 .31126 L
.51986 .30938 L
.54095 .30786 L
.56066 .30681 L
.57902 .30604 L
.59774 .30542 L
.61804 .3049 L
.62913 .30467 L
.63936 .30451 L
.64976 .30437 L
Mistroke
.6595 .30427 L
.66853 .30421 L
.6736 .30418 L
.67824 .30416 L
.6833 .30414 L
.68616 .30414 L
.68753 .30413 L
.68882 .30413 L
.69005 .30413 L
.69137 .30413 L
.69258 .30413 L
.69369 .30413 L
.69489 .30413 L
.69621 .30413 L
.69688 .30413 L
.69759 .30413 L
.69887 .30413 L
.70009 .30413 L
.70144 .30413 L
.70285 .30413 L
.70416 .30413 L
.70906 .30414 L
.71184 .30415 L
.71439 .30416 L
.72013 .30418 L
.72993 .30422 L
.74025 .30429 L
.76001 .30445 L
.77838 .30463 L
.81745 .30512 L
.85897 .30571 L
.89897 .30633 L
.93745 .30692 L
.97619 .30751 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.06244 .23852 L
.08255 .36422 L
.10458 .48504 L
.11448 .53057 L
.11992 .55226 L
.12507 .56994 L
.12986 .58335 L
.13238 .58897 L
.13376 .59156 L
.13506 .59365 L
.13623 .59524 L
.13731 .59642 L
.1385 .5974 L
.13979 .59805 L
.14086 .59823 L
.14202 .59805 L
.14313 .59747 L
.14415 .59655 L
.14544 .59485 L
.1468 .59233 L
.14796 .58954 L
.14923 .58574 L
.15207 .5741 L
.15472 .55869 L
.15723 .53934 L
.15952 .5172 L
.16467 .45175 L
.16933 .38232 L
.1737 .32657 L
.17589 .30667 L
.17712 .29811 L
.17825 .29183 L
.17942 .2868 L
.1807 .28284 L
.18135 .2814 L
.18204 .28023 L
.18328 .27901 L
.18456 .2788 L
.18529 .27909 L
.18595 .2796 L
.18718 .28106 L
.18848 .28325 L
.19072 .28834 L
.19319 .29541 L
.20237 .32916 L
.22313 .41391 L
.2331 .44909 L
.23802 .4637 L
.24257 .47501 L
Mistroke
.24532 .4805 L
.2478 .48441 L
.24922 .48613 L
.25056 .48736 L
.25129 .48786 L
.25197 .48821 L
.25271 .48847 L
.25349 .4886 L
.25468 .48849 L
.25595 .48798 L
.25716 .48713 L
.25825 .48606 L
.26093 .48236 L
.26347 .47769 L
.28172 .43127 L
.28673 .41922 L
.29211 .40797 L
.29676 .3999 L
.30185 .39284 L
.30689 .38751 L
.30945 .38538 L
.31219 .38347 L
.31476 .38198 L
.3171 .38086 L
.32166 .37918 L
.32437 .37843 L
.32686 .37786 L
.33248 .37684 L
.3374 .37606 L
.34268 .37515 L
.34776 .37407 L
.3524 .37283 L
.36148 .36964 L
.38214 .35959 L
.40281 .34948 L
.4119 .34589 L
.42195 .34263 L
.44051 .33818 L
.46025 .3347 L
.50042 .32884 L
.53907 .32466 L
.55909 .32311 L
.58018 .3218 L
.61826 .32002 L
.63784 .31936 L
.65879 .31883 L
.66901 .31862 L
.68011 .31844 L
.6897 .31831 L
.70025 .31819 L
Mistroke
.7105 .3181 L
.7201 .31803 L
.7253 .31801 L
.73024 .31799 L
.73593 .31797 L
.73861 .31796 L
.74114 .31796 L
.74356 .31795 L
.74617 .31795 L
.74733 .31795 L
.74855 .31795 L
.74959 .31795 L
.75073 .31794 L
.75142 .31794 L
.75207 .31794 L
.75329 .31794 L
.7546 .31794 L
.75534 .31794 L
.75602 .31794 L
.75716 .31795 L
.75842 .31795 L
.75973 .31795 L
.76096 .31795 L
.76321 .31795 L
.76558 .31795 L
.76981 .31796 L
.77437 .31797 L
.77935 .31799 L
.78964 .31802 L
.79898 .31807 L
.81993 .31819 L
.85993 .3185 L
.89842 .31885 L
.93936 .31924 L
.97619 .3196 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.06244 .23847 L
.08255 .36417 L
.10458 .48503 L
.11448 .53061 L
.11992 .55233 L
.12507 .57006 L
.12986 .58353 L
.13238 .58921 L
.13506 .59395 L
.13614 .59546 L
.13731 .59679 L
.13859 .59787 L
.13979 .59851 L
.14096 .59875 L
.14207 .5986 L
.14306 .59814 L
.14415 .59724 L
.1448 .59651 L
.14548 .59557 L
.1467 .59342 L
.14802 .59038 L
.14946 .58611 L
.15205 .57571 L
.15447 .56234 L
.15683 .54533 L
.15898 .52606 L
.16382 .46916 L
.16911 .39324 L
.172 .35435 L
.17472 .32496 L
.17702 .30681 L
.17832 .29931 L
.17951 .29402 L
.18074 .29 L
.18144 .28831 L
.18209 .28709 L
.1834 .28557 L
.18413 .28522 L
.1848 .28518 L
.18599 .28571 L
.18725 .28699 L
.18832 .2886 L
.18951 .29084 L
.19215 .29728 L
.19461 .3047 L
.20388 .33913 L
.22464 .42279 L
.23505 .45867 L
.24018 .47335 L
Mistroke
.24493 .48448 L
.24714 .48862 L
.24923 .4918 L
.25038 .49322 L
.25163 .49445 L
.25276 .49529 L
.2538 .49582 L
.25496 .49611 L
.25604 .4961 L
.25723 .49578 L
.2585 .49509 L
.25914 .49461 L
.25984 .494 L
.2611 .49264 L
.26347 .48935 L
.28289 .44595 L
.2932 .42456 L
.29899 .41532 L
.3043 .40872 L
.30903 .40422 L
.31419 .40058 L
.3168 .39918 L
.31958 .39794 L
.32459 .39627 L
.32706 .39564 L
.32973 .39508 L
.33457 .39423 L
.34362 .39279 L
.35311 .39076 L
.3585 .38919 L
.36353 .38743 L
.38459 .37792 L
.4032 .3693 L
.42347 .36219 L
.43448 .35938 L
.44468 .35726 L
.4648 .35382 L
.50403 .34821 L
.54175 .34413 L
.56107 .34258 L
.58192 .34121 L
.60154 .34012 L
.62303 .33914 L
.64376 .33838 L
.66262 .33783 L
.68221 .33738 L
.70315 .33701 L
.72231 .33677 L
.73312 .33666 L
.7431 .33658 L
Mistroke
.75213 .33652 L
.76184 .33647 L
.7674 .33645 L
.77249 .33643 L
.77732 .33642 L
.78247 .33641 L
.78764 .3364 L
.79232 .33639 L
.79459 .33639 L
.79703 .33639 L
.79816 .33639 L
.79934 .33639 L
.80036 .33639 L
.80147 .33638 L
.80213 .33638 L
.80286 .33638 L
.80418 .33638 L
.80546 .33638 L
.80664 .33638 L
.80792 .33638 L
.80865 .33639 L
.80933 .33639 L
.81219 .33639 L
.8147 .33639 L
.81701 .33639 L
.8222 .3364 L
.82694 .3364 L
.83201 .33641 L
.84113 .33643 L
.86184 .33649 L
.90336 .33665 L
.94336 .33684 L
.97619 .337 L
Mfstroke
.601 0 1 r
.02381 .01472 m
.06244 .23839 L
.08255 .3641 L
.10458 .48502 L
.11448 .53066 L
.11992 .55244 L
.12507 .57024 L
.12986 .58382 L
.13238 .58957 L
.13506 .59441 L
.13614 .59596 L
.13731 .59734 L
.13859 .59849 L
.13979 .5992 L
.14096 .59952 L
.14207 .59945 L
.14306 .59907 L
.14415 .59828 L
.1448 .59761 L
.14548 .59674 L
.1467 .59473 L
.14802 .59188 L
.14946 .58784 L
.15205 .57796 L
.15447 .56524 L
.15683 .54905 L
.15898 .53073 L
.16382 .47671 L
.16911 .40418 L
.172 .36631 L
.17472 .33703 L
.17702 .31844 L
.17832 .31057 L
.17951 .30489 L
.18074 .30043 L
.18144 .29849 L
.18209 .29704 L
.1834 .29506 L
.18413 .29446 L
.1848 .2942 L
.18599 .29433 L
.18725 .29523 L
.18832 .29653 L
.18951 .29845 L
.19215 .30423 L
.19461 .3111 L
.20388 .34398 L
.22464 .42608 L
.23505 .46201 L
.24018 .47695 L
Mistroke
.24493 .4885 L
.24923 .49644 L
.25046 .49818 L
.25163 .49957 L
.25266 .50059 L
.2538 .50146 L
.25498 .50207 L
.25622 .50239 L
.25737 .50239 L
.25845 .50214 L
.25972 .50152 L
.26087 .50069 L
.2622 .49942 L
.26347 .49794 L
.26807 .49069 L
.27315 .48038 L
.28342 .4572 L
.2924 .439 L
.30185 .4246 L
.30668 .41925 L
.31197 .41481 L
.31677 .41186 L
.32123 .40986 L
.32396 .40892 L
.32653 .40819 L
.33133 .40713 L
.3421 .40541 L
.35185 .40365 L
.35676 .40246 L
.36216 .40086 L
.38062 .39344 L
.40174 .38395 L
.42101 .37706 L
.43057 .37448 L
.44097 .37218 L
.45989 .36886 L
.50064 .36311 L
.52087 .36073 L
.53987 .35887 L
.57759 .35608 L
.61625 .35405 L
.63626 .35325 L
.65736 .35257 L
.6773 .35206 L
.69543 .35169 L
.71502 .35137 L
.73596 .35112 L
.75512 .35095 L
.76593 .35088 L
.77591 .35083 L
Mistroke
.78494 .35079 L
.79465 .35076 L
.80022 .35074 L
.8053 .35073 L
.81013 .35072 L
.81528 .35071 L
.82045 .35071 L
.82514 .3507 L
.8274 .3507 L
.82859 .3507 L
.82985 .3507 L
.83095 .3507 L
.83216 .3507 L
.83326 .3507 L
.83428 .3507 L
.83557 .3507 L
.8363 .3507 L
.83697 .3507 L
.8382 .3507 L
.83952 .3507 L
.84069 .3507 L
.84178 .3507 L
.84429 .3507 L
.84698 .3507 L
.84945 .3507 L
.85501 .35071 L
.85976 .35071 L
.86482 .35072 L
.87395 .35073 L
.89465 .35077 L
.93617 .35087 L
.97617 .35098 L
.97619 .35098 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.06244 .23859 L
.08255 .36428 L
.10458 .48503 L
.11448 .53051 L
.11992 .55213 L
.12507 .56974 L
.12986 .58305 L
.13256 .58895 L
.13506 .59319 L
.13607 .59453 L
.13716 .59571 L
.13835 .59668 L
.13947 .59724 L
.14073 .59746 L
.14192 .59722 L
.14299 .59661 L
.14415 .59549 L
.1448 .59465 L
.14548 .59358 L
.1467 .59117 L
.14802 .58781 L
.14946 .58314 L
.15205 .5718 L
.15447 .55726 L
.15683 .53873 L
.15898 .51768 L
.16382 .45531 L
.16898 .3749 L
.1717 .33613 L
.1732 .31823 L
.17459 .30407 L
.17591 .29319 L
.17711 .2852 L
.17845 .2784 L
.17915 .27563 L
.17989 .27326 L
.18111 .27049 L
.18224 .26901 L
.18347 .26844 L
.18417 .26854 L
.1848 .26887 L
.18599 .27005 L
.18711 .27173 L
.18833 .27411 L
.18965 .27722 L
.19478 .29313 L
.20398 .32905 L
.22478 .40987 L
.22969 .42554 L
Mistroke
.23491 .4396 L
.23792 .44604 L
.24064 .45051 L
.24196 .4521 L
.24265 .45277 L
.24338 .45334 L
.24402 .45371 L
.24472 .45398 L
.24595 .45407 L
.2466 .45391 L
.24731 .45356 L
.24858 .45241 L
.24983 .45064 L
.25098 .44839 L
.25222 .44529 L
.25359 .4411 L
.25636 .43042 L
.26606 .38248 L
.27551 .33719 L
.28066 .31673 L
.28544 .30123 L
.29065 .28827 L
.2934 .28298 L
.29634 .27841 L
.29903 .2751 L
.30157 .27267 L
.30384 .27098 L
.30631 .26962 L
.30868 .26869 L
.31001 .26831 L
.31122 .26804 L
.31234 .26785 L
.31357 .26771 L
.31473 .26761 L
.3158 .26756 L
.31704 .26755 L
.3182 .26756 L
.31948 .2676 L
.32019 .26764 L
.32085 .26768 L
.32623 .26807 L
.32859 .26823 L
.32992 .2683 L
.33112 .26834 L
.3318 .26836 L
.33255 .26837 L
.33325 .26837 L
.3339 .26837 L
.33515 .26834 L
.33578 .26831 L
Mistroke
.33648 .26828 L
.33788 .26817 L
.33917 .26804 L
.34065 .26785 L
.34206 .26762 L
.34456 .26711 L
.34728 .26639 L
.3526 .26456 L
.35761 .26238 L
.36697 .25759 L
.37717 .25224 L
.38275 .24963 L
.38795 .24751 L
.39296 .24582 L
.39753 .24459 L
.4026 .24355 L
.4054 .24311 L
.40804 .24279 L
.41027 .24257 L
.41264 .24239 L
.41466 .24228 L
.41581 .24224 L
.41689 .2422 L
.41807 .24217 L
.41931 .24215 L
.42037 .24215 L
.42153 .24214 L
.42278 .24215 L
.42348 .24216 L
.42411 .24217 L
.42535 .24219 L
.42652 .24222 L
.42891 .24229 L
.43115 .24238 L
.43625 .24262 L
.44655 .24318 L
.45538 .24364 L
.465 .24405 L
.47542 .24439 L
.48531 .24464 L
.50385 .24511 L
.52357 .24575 L
.54457 .24659 L
.58622 .24821 L
.62636 .24946 L
.66498 .25051 L
.70606 .2515 L
.74562 .25238 L
.78366 .25319 L
.82416 .25403 L
Mistroke
.86314 .25484 L
.90457 .25568 L
.94449 .25649 L
.97619 .25711 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.06244 .23821 L
.08255 .36394 L
.10458 .485 L
.11448 .53079 L
.11992 .55269 L
.12507 .57068 L
.12986 .58449 L
.13238 .59039 L
.13506 .59545 L
.13731 .5986 L
.13859 .5999 L
.13979 .60076 L
.14089 .60123 L
.14189 .60137 L
.14305 .60116 L
.14415 .60058 L
.1454 .59944 L
.1461 .59856 L
.14674 .59759 L
.1479 .59542 L
.14918 .5924 L
.1514 .58537 L
.15374 .57523 L
.15629 .56055 L
.15902 .54015 L
.16396 .49049 L
.16859 .43262 L
.17351 .37316 L
.17553 .35347 L
.17771 .33661 L
.17896 .32904 L
.1801 .32339 L
.18119 .3191 L
.18234 .31559 L
.18357 .31296 L
.18471 .31142 L
.18541 .31086 L
.18607 .31058 L
.1873 .31065 L
.1886 .31147 L
.1898 .31281 L
.19112 .31484 L
.19252 .31754 L
.19779 .33151 L
.20358 .35115 L
.22371 .42821 L
.23368 .46338 L
.24315 .49119 L
.24838 .50297 L
Mistroke
.25133 .5081 L
.25274 .51008 L
.25407 .51164 L
.25529 .5128 L
.25661 .51373 L
.2578 .5143 L
.2589 .51457 L
.2601 .51461 L
.2614 .51434 L
.26206 .51408 L
.26277 .51373 L
.26405 .51287 L
.26527 .51181 L
.26662 .51039 L
.26935 .50681 L
.27425 .4986 L
.28533 .47661 L
.29584 .45772 L
.30043 .45106 L
.30546 .44503 L
.31003 .44063 L
.31491 .43697 L
.32006 .43411 L
.32484 .43219 L
.32755 .43135 L
.33048 .4306 L
.33579 .42955 L
.34571 .42806 L
.35068 .42728 L
.35601 .42627 L
.36563 .42382 L
.37566 .42039 L
.38669 .4159 L
.40647 .40769 L
.41691 .40396 L
.42801 .40066 L
.44869 .39609 L
.46783 .39294 L
.50555 .3878 L
.52649 .3854 L
.54572 .38356 L
.58437 .38073 L
.62396 .37865 L
.66204 .37721 L
.68163 .37665 L
.70257 .37617 L
.72246 .3758 L
.74403 .37548 L
.76305 .37525 L
.78398 .37506 L
Mistroke
.80384 .37492 L
.82487 .3748 L
.84429 .37472 L
.86518 .37465 L
.88633 .37459 L
.90642 .37456 L
.94463 .3745 L
.97619 .37447 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.06244 .23823 L
.08255 .36391 L
.10458 .48494 L
.11448 .53072 L
.11992 .55262 L
.12507 .5706 L
.12986 .58441 L
.13238 .59032 L
.13506 .59537 L
.13731 .59852 L
.13859 .59982 L
.13979 .60068 L
.14089 .60114 L
.14189 .60128 L
.14305 .60107 L
.14415 .60048 L
.1454 .59934 L
.1461 .59845 L
.14674 .59747 L
.1479 .5953 L
.14918 .59226 L
.1514 .58522 L
.15374 .57503 L
.15629 .56028 L
.15902 .53977 L
.16396 .48983 L
.16859 .43172 L
.17351 .37254 L
.17553 .35321 L
.17771 .33685 L
.17896 .32962 L
.1801 .3243 L
.18119 .3203 L
.18234 .31715 L
.18356 .31489 L
.18486 .31356 L
.18609 .31321 L
.1872 .31354 L
.18852 .31462 L
.18925 .31553 L
.18994 .31652 L
.19252 .32149 L
.19789 .336 L
.20358 .35452 L
.21328 .38808 L
.22371 .42268 L
.22895 .4384 L
.23393 .45155 L
.23841 .4612 L
Mistroke
.24093 .46542 L
.24216 .46704 L
.24328 .46826 L
.24443 .46922 L
.24568 .46986 L
.24678 .47006 L
.24793 .46986 L
.24898 .46928 L
.24995 .46838 L
.25101 .46697 L
.25215 .46494 L
.25337 .46217 L
.25469 .45847 L
.25709 .45008 L
.26159 .43027 L
.27182 .38134 L
.27682 .36077 L
.28141 .34525 L
.28622 .33262 L
.28875 .32746 L
.2914 .32306 L
.29414 .31955 L
.29667 .31715 L
.29813 .3161 L
.29946 .31535 L
.30019 .31502 L
.30099 .31471 L
.30173 .31448 L
.30243 .31431 L
.30366 .31412 L
.30479 .31404 L
.30601 .31408 L
.3067 .31415 L
.30733 .31424 L
.30839 .31445 L
.30955 .31476 L
.31192 .31563 L
.3145 .31688 L
.31729 .31853 L
.32234 .32208 L
.33239 .33007 L
.3434 .33835 L
.34841 .34151 L
.35376 .34437 L
.35839 .34638 L
.36341 .3481 L
.36637 .3489 L
.36909 .34952 L
.37165 .35001 L
.37446 .35045 L
Mistroke
.37934 .35103 L
.38201 .35127 L
.38451 .35146 L
.39349 .35199 L
.40306 .35259 L
.40857 .35304 L
.41356 .35353 L
.4233 .35476 L
.44445 .35814 L
.46454 .36131 L
.4838 .3637 L
.50463 .36557 L
.54565 .36824 L
.56609 .36934 L
.58516 .37022 L
.62315 .37155 L
.64352 .37206 L
.66208 .37245 L
.68279 .37281 L
.70194 .37308 L
.74029 .37348 L
.75897 .37363 L
.77958 .37376 L
.8198 .37397 L
.85851 .37414 L
.89967 .37429 L
.93931 .37444 L
.97619 .37457 L
Mfstroke
.696 0 1 r
.02381 .01472 m
.06244 .23847 L
.08255 .36414 L
.10458 .48498 L
.11448 .53056 L
.11992 .55228 L
.12507 .57001 L
.12986 .58348 L
.13238 .58914 L
.13506 .59388 L
.13614 .59538 L
.13731 .59671 L
.13859 .59778 L
.13979 .59841 L
.14096 .59864 L
.14207 .59848 L
.14306 .598 L
.14415 .59709 L
.1448 .59635 L
.14548 .59539 L
.1467 .5932 L
.14802 .59013 L
.14946 .5858 L
.15205 .57524 L
.15447 .56164 L
.15683 .54428 L
.15898 .52454 L
.16382 .46584 L
.16911 .38703 L
.172 .34684 L
.17472 .31682 L
.17702 .29854 L
.17832 .29109 L
.17951 .2859 L
.18074 .28201 L
.18144 .28041 L
.18209 .27928 L
.1834 .27797 L
.18413 .27774 L
.1848 .27781 L
.18599 .27853 L
.18725 .28004 L
.18832 .28183 L
.18951 .28428 L
.19461 .29886 L
.20388 .33335 L
.21473 .37525 L
.22464 .40943 L
.22942 .42332 L
.23194 .4297 L
Mistroke
.23462 .43555 L
.2372 .44006 L
.23842 .44173 L
.23953 .44296 L
.24066 .44389 L
.24188 .44447 L
.24296 .44459 L
.24409 .44426 L
.24539 .44325 L
.24658 .44167 L
.24724 .44051 L
.24795 .43898 L
.24925 .43551 L
.25175 .42615 L
.25406 .41458 L
.26498 .34716 L
.26963 .32148 L
.27463 .2982 L
.27936 .28093 L
.28368 .26918 L
.28617 .26408 L
.28849 .26035 L
.29103 .25728 L
.29245 .25599 L
.29373 .25506 L
.2944 .25467 L
.29509 .25432 L
.29635 .25385 L
.29704 .25366 L
.29769 .25353 L
.29841 .25344 L
.29917 .25341 L
.29983 .25342 L
.30055 .25348 L
.30185 .25371 L
.30312 .25406 L
.3043 .2545 L
.30671 .25567 L
.30892 .25702 L
.31391 .2608 L
.32294 .26889 L
.33361 .27812 L
.33881 .28189 L
.34353 .28475 L
.34792 .28689 L
.35267 .28869 L
.35528 .28946 L
.35769 .29004 L
.35998 .29049 L
.36244 .29088 L
Mistroke
.3649 .29118 L
.36722 .29139 L
.36863 .29149 L
.36997 .29157 L
.37248 .29168 L
.37376 .29172 L
.37512 .29176 L
.37757 .29181 L
.38027 .29185 L
.38313 .2919 L
.38568 .29195 L
.38849 .29202 L
.39104 .29212 L
.39342 .29224 L
.3988 .29261 L
.40181 .29289 L
.40455 .29319 L
.41492 .29467 L
.42473 .29647 L
.44296 .30012 L
.46308 .30365 L
.48287 .30619 L
.50388 .30813 L
.5441 .31097 L
.58281 .31304 L
.60287 .31382 L
.62397 .31446 L
.6621 .3153 L
.68172 .31561 L
.70268 .31587 L
.72404 .31607 L
.7442 .31622 L
.78268 .31644 L
.82362 .31661 L
.86305 .31676 L
.90095 .3169 L
.94131 .31706 L
.97619 .3172 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.06244 .23856 L
.08255 .36424 L
.10458 .48502 L
.11448 .53051 L
.11992 .55217 L
.12507 .5698 L
.12986 .58315 L
.13238 .58873 L
.13376 .59129 L
.13506 .59335 L
.13623 .5949 L
.13731 .59605 L
.1385 .59699 L
.13979 .59758 L
.14086 .59772 L
.14202 .59748 L
.14313 .59683 L
.14415 .59585 L
.14544 .59406 L
.1468 .59142 L
.14796 .58851 L
.14923 .58456 L
.15207 .57248 L
.15472 .55648 L
.15723 .53633 L
.15952 .51321 L
.16467 .44458 L
.16933 .37196 L
.17161 .3396 L
.1737 .31488 L
.17589 .29508 L
.17704 .28722 L
.17825 .2807 L
.1795 .27571 L
.18065 .27246 L
.18192 .27025 L
.18264 .26955 L
.18328 .26923 L
.18455 .26935 L
.18573 .27025 L
.18702 .27198 L
.18838 .27452 L
.19067 .28012 L
.19319 .28772 L
.20237 .32204 L
.21321 .36565 L
.22313 .4021 L
.2279 .41734 L
.2331 .43138 L
Mistroke
.23548 .43661 L
.23802 .44113 L
.23925 .44285 L
.24041 .44415 L
.24145 .44502 L
.24257 .44561 L
.24388 .44578 L
.2451 .44538 L
.2458 .44488 L
.24644 .44425 L
.24718 .44329 L
.24787 .44215 L
.24926 .43913 L
.25055 .43544 L
.25346 .42394 L
.25832 .39768 L
.26347 .3669 L
.27286 .31574 L
.27779 .29411 L
.28298 .27617 L
.28754 .26443 L
.29012 .25934 L
.29253 .25552 L
.2947 .25276 L
.29676 .25071 L
.29789 .24978 L
.29912 .24893 L
.30127 .24781 L
.30251 .24735 L
.30364 .24704 L
.30494 .2468 L
.30618 .24667 L
.30731 .24664 L
.30837 .24667 L
.30953 .24678 L
.31076 .24695 L
.31199 .24718 L
.31331 .24749 L
.31571 .24818 L
.32118 .25009 L
.32604 .25186 L
.33124 .25353 L
.33422 .25428 L
.33693 .25481 L
.33824 .255 L
.33966 .25517 L
.34031 .25523 L
.341 .25528 L
.34224 .25534 L
.34348 .25537 L
Mistroke
.34461 .25537 L
.34592 .25532 L
.34716 .25524 L
.3483 .25514 L
.34936 .25502 L
.35177 .25466 L
.35443 .25414 L
.35685 .25357 L
.36226 .25203 L
.37324 .24846 L
.37806 .24698 L
.38335 .24559 L
.38819 .24456 L
.39272 .24385 L
.39522 .24357 L
.39749 .24338 L
.39875 .24329 L
.40012 .24322 L
.40141 .24318 L
.40261 .24315 L
.4038 .24314 L
.40509 .24314 L
.4063 .24316 L
.40741 .24319 L
.40864 .24323 L
.40999 .2433 L
.41271 .24347 L
.4154 .24369 L
.41827 .24397 L
.42343 .24457 L
.44336 .24738 L
.45385 .24876 L
.46495 .24999 L
.48577 .2517 L
.50495 .25293 L
.54286 .25524 L
.56396 .2564 L
.58322 .25729 L
.62207 .25866 L
.66185 .25966 L
.70011 .26039 L
.74083 .26099 L
.78003 .26147 L
.82168 .26194 L
.86182 .26239 L
.90045 .26281 L
.94152 .26327 L
.97619 .26365 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.06244 .23814 L
.08255 .36388 L
.10458 .48499 L
.11448 .53083 L
.11992 .55278 L
.12507 .57083 L
.12986 .58472 L
.13238 .59068 L
.13506 .59581 L
.13731 .59904 L
.13859 .60039 L
.13979 .60131 L
.14089 .60183 L
.14189 .60202 L
.14305 .60188 L
.14415 .60138 L
.1454 .60033 L
.1461 .59951 L
.14674 .59859 L
.14793 .59649 L
.14918 .59366 L
.15135 .58709 L
.15374 .57718 L
.15629 .56306 L
.15902 .54343 L
.16396 .49564 L
.16859 .43967 L
.17351 .3812 L
.17553 .36143 L
.17771 .34423 L
.17896 .33639 L
.1801 .33046 L
.18119 .3259 L
.18234 .32207 L
.18357 .31913 L
.18471 .3173 L
.18541 .31657 L
.18607 .31614 L
.1873 .31593 L
.1886 .31647 L
.1898 .31757 L
.19112 .31936 L
.19252 .32183 L
.19779 .33506 L
.20358 .35412 L
.22371 .43031 L
.23368 .46555 L
.24315 .49375 L
.24838 .50598 L
Mistroke
.25113 .51116 L
.25265 .51355 L
.25407 .51547 L
.25538 .51695 L
.25679 .51821 L
.25807 .51904 L
.25925 .51954 L
.26036 .51978 L
.26158 .51978 L
.26286 .5195 L
.26405 .51899 L
.26531 .5182 L
.26666 .51709 L
.26907 .5145 L
.27452 .50641 L
.28444 .48795 L
.29413 .47063 L
.30301 .45812 L
.30759 .45316 L
.3124 .44896 L
.31724 .44571 L
.32252 .44308 L
.3271 .44143 L
.332 .44015 L
.33662 .43926 L
.34081 .4386 L
.35015 .43726 L
.36003 .43542 L
.3652 .43414 L
.37087 .43246 L
.38084 .4289 L
.40196 .42027 L
.42124 .41337 L
.44119 .40821 L
.46011 .40471 L
.49841 .3992 L
.51777 .39681 L
.53916 .39455 L
.57839 .39141 L
.61856 .38909 L
.65722 .38747 L
.67724 .38683 L
.69833 .38628 L
.7364 .38552 L
.75599 .38522 L
.77693 .38496 L
.79682 .38477 L
.8184 .38459 L
.85835 .38434 L
.89923 .38416 L
Mistroke
.9386 .38403 L
.97619 .38392 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.06244 .23832 L
.08255 .36399 L
.10458 .48495 L
.11448 .53066 L
.11992 .5525 L
.12507 .57039 L
.12986 .58408 L
.13238 .5899 L
.13506 .59484 L
.13731 .59788 L
.13859 .5991 L
.13979 .59988 L
.14089 .60026 L
.14189 .60031 L
.14305 .59999 L
.14415 .59929 L
.1454 .598 L
.1461 .59702 L
.14674 .59595 L
.1479 .5936 L
.14918 .59034 L
.1514 .58281 L
.15374 .57196 L
.15629 .55626 L
.15902 .53439 L
.16396 .48098 L
.16859 .41909 L
.17113 .38548 L
.17351 .35763 L
.1757 .33681 L
.17771 .32227 L
.1788 .31619 L
.17994 .31107 L
.18109 .30714 L
.18234 .30411 L
.18303 .30297 L
.18368 .30219 L
.18489 .30144 L
.1862 .30156 L
.18694 .30201 L
.18761 .30263 L
.18875 .30407 L
.19 .30617 L
.19252 .31175 L
.19824 .32868 L
.20358 .34717 L
.22371 .41713 L
.22868 .43198 L
.23411 .44582 L
Mistroke
.2366 .45102 L
.23924 .45553 L
.24052 .45725 L
.24173 .45854 L
.24282 .4594 L
.24399 .45997 L
.24515 .46013 L
.24624 .45987 L
.24742 .45909 L
.24869 .45763 L
.24933 .45663 L
.25003 .45533 L
.25129 .45241 L
.25365 .44499 L
.25827 .42462 L
.26253 .4025 L
.27154 .35775 L
.27626 .33846 L
.28123 .32229 L
.28389 .31543 L
.28679 .30929 L
.28945 .30482 L
.29187 .30166 L
.29437 .29924 L
.29575 .29823 L
.29704 .29749 L
.29824 .29696 L
.29935 .2966 L
.30056 .29634 L
.30185 .29622 L
.30306 .29622 L
.30375 .29628 L
.30439 .29637 L
.30555 .2966 L
.3068 .29694 L
.30894 .29776 L
.31131 .29894 L
.31654 .30235 L
.32146 .30623 L
.33979 .32138 L
.3496 .32769 L
.35454 .33011 L
.35995 .33219 L
.36457 .33354 L
.36952 .33461 L
.3742 .33533 L
.37844 .3358 L
.38853 .33654 L
.39922 .33724 L
.40835 .33807 L
Mistroke
.41839 .33932 L
.45683 .34578 L
.47788 .3487 L
.49713 .35063 L
.53593 .35339 L
.57565 .35556 L
.61387 .35703 L
.63356 .35759 L
.65453 .35806 L
.67452 .35843 L
.69613 .35875 L
.73622 .35918 L
.75617 .35934 L
.77724 .35948 L
.81524 .35967 L
.85568 .35984 L
.89461 .35998 L
.93599 .36013 L
.97586 .36027 L
.97619 .36028 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.06244 .23859 L
.08255 .36428 L
.10458 .48504 L
.11448 .53052 L
.11992 .55215 L
.12507 .56976 L
.12986 .58307 L
.13256 .58898 L
.13506 .59322 L
.13607 .59457 L
.13716 .59576 L
.13835 .59673 L
.13947 .5973 L
.14073 .59752 L
.14192 .59729 L
.14299 .59669 L
.14415 .59558 L
.1448 .59475 L
.14548 .59368 L
.1467 .59129 L
.14802 .58796 L
.14946 .58331 L
.15205 .57205 L
.15447 .5576 L
.15683 .53922 L
.15898 .51834 L
.16382 .45663 L
.16898 .37716 L
.1717 .33876 L
.1732 .32098 L
.17459 .30689 L
.17591 .29602 L
.17711 .28803 L
.17845 .28121 L
.17915 .27843 L
.17989 .27605 L
.18111 .27324 L
.18224 .27173 L
.18347 .27112 L
.18417 .27121 L
.1848 .27152 L
.18599 .27266 L
.18711 .2743 L
.18833 .27665 L
.18965 .27971 L
.19478 .29549 L
.20398 .33128 L
.22478 .41303 L
.23491 .44425 L
Mistroke
.23769 .45093 L
.24064 .45679 L
.24208 .45909 L
.24343 .46085 L
.24464 .46208 L
.24595 .46298 L
.24721 .46338 L
.24839 .46331 L
.24967 .46269 L
.25039 .46208 L
.25105 .46135 L
.25238 .45938 L
.25382 .45648 L
.25643 .44933 L
.26143 .43078 L
.26606 .41099 L
.27506 .37249 L
.28476 .33832 L
.29031 .32384 L
.2954 .31389 L
.30026 .30705 L
.3027 .30446 L
.30537 .3022 L
.30792 .30052 L
.31068 .29915 L
.31328 .29821 L
.31568 .29759 L
.31784 .29719 L
.31907 .29702 L
.32022 .29689 L
.32254 .2967 L
.32384 .29662 L
.32502 .29656 L
.33018 .29632 L
.33159 .29624 L
.33309 .29613 L
.33578 .29588 L
.33828 .29556 L
.34063 .29516 L
.34599 .29388 L
.35067 .2923 L
.3558 .29011 L
.36615 .28463 L
.38464 .27415 L
.3949 .26949 L
.40423 .26639 L
.40939 .26513 L
.415 .26408 L
.42029 .26334 L
.42517 .26284 L
Mistroke
.42984 .26249 L
.43485 .26222 L
.43958 .26203 L
.44391 .2619 L
.46454 .26139 L
.48515 .26083 L
.49518 .26058 L
.50427 .26041 L
.50885 .26034 L
.51126 .26032 L
.5138 .2603 L
.51603 .26028 L
.51721 .26027 L
.51847 .26027 L
.51964 .26027 L
.5207 .26026 L
.52176 .26026 L
.52277 .26026 L
.5239 .26026 L
.52515 .26026 L
.52645 .26026 L
.52768 .26027 L
.52882 .26027 L
.52986 .26028 L
.53222 .26029 L
.53722 .26033 L
.54248 .26038 L
.56224 .26066 L
.58061 .26097 L
.61968 .26167 L
.66119 .2625 L
.7012 .26338 L
.73968 .26426 L
.78062 .26523 L
.82004 .26619 L
.85795 .26711 L
.89831 .2681 L
.93716 .26903 L
.97619 .26994 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.06244 .23812 L
.08255 .36382 L
.10458 .48493 L
.11448 .53079 L
.11992 .55276 L
.12507 .57083 L
.12986 .58476 L
.13238 .59075 L
.13506 .59591 L
.13731 .59918 L
.13859 .60055 L
.13979 .60148 L
.14089 .60203 L
.14189 .60224 L
.14305 .60213 L
.14415 .60166 L
.1454 .60065 L
.1461 .59985 L
.14674 .59896 L
.14793 .5969 L
.14918 .59412 L
.15135 .58765 L
.15374 .5779 L
.15629 .56398 L
.15902 .54461 L
.16396 .49751 L
.16859 .44239 L
.17351 .38492 L
.17553 .36555 L
.17771 .34877 L
.17896 .34117 L
.1801 .33546 L
.18119 .33109 L
.18234 .32748 L
.18357 .32475 L
.18471 .32312 L
.18541 .32251 L
.18607 .32218 L
.1873 .32215 L
.1886 .32286 L
.1898 .3241 L
.19112 .32599 L
.19252 .32853 L
.19779 .34156 L
.20358 .35946 L
.22371 .42629 L
.22848 .44072 L
.23368 .45489 L
.23827 .46541 L
Mistroke
.24079 .47009 L
.24315 .47358 L
.24458 .47517 L
.24539 .47586 L
.24613 .47637 L
.24744 .4769 L
.2481 .47698 L
.24882 .47692 L
.25013 .47637 L
.25087 .4758 L
.25154 .4751 L
.25284 .47325 L
.25407 .47088 L
.25656 .46427 L
.25885 .45624 L
.26405 .43362 L
.27305 .39179 L
.27778 .37263 L
.28275 .35594 L
.2854 .3486 L
.2883 .34183 L
.29097 .33673 L
.29339 .33297 L
.29589 .32991 L
.29717 .32864 L
.29856 .32749 L
.29985 .32661 L
.30103 .32595 L
.30217 .32545 L
.30336 .32506 L
.30458 .32479 L
.30527 .32469 L
.3059 .32463 L
.30707 .32461 L
.30831 .3247 L
.30942 .32486 L
.31046 .32508 L
.3116 .3254 L
.31283 .32582 L
.3154 .32695 L
.31812 .32842 L
.32298 .33162 L
.3413 .34555 L
.35083 .35161 L
.35607 .35424 L
.36102 .35623 L
.36563 .35768 L
.37064 .35886 L
.37518 .35963 L
.37938 .36015 L
Mistroke
.38404 .36055 L
.38906 .36087 L
.39812 .36134 L
.40365 .36166 L
.4089 .36204 L
.41875 .36302 L
.42835 .36429 L
.43857 .36586 L
.45696 .36882 L
.47695 .37156 L
.49857 .37371 L
.51945 .37524 L
.53865 .37643 L
.57816 .37849 L
.61615 .37991 L
.63568 .38045 L
.6566 .38092 L
.67642 .38128 L
.69798 .38161 L
.73784 .38205 L
.75763 .38221 L
.77864 .38235 L
.81641 .38255 L
.85664 .38273 L
.89534 .38288 L
.9365 .38303 L
.97615 .38317 L
.97619 .38317 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.06244 .23829 L
.08255 .36402 L
.10458 .48501 L
.11448 .53073 L
.11992 .55258 L
.12507 .57048 L
.12986 .58418 L
.13238 .59001 L
.13506 .59496 L
.13731 .59801 L
.13859 .59924 L
.13979 .60003 L
.14089 .60042 L
.14189 .60048 L
.14305 .60018 L
.14415 .5995 L
.1454 .59823 L
.1461 .59726 L
.14674 .59621 L
.1479 .59389 L
.14918 .59066 L
.1514 .58323 L
.15374 .57252 L
.15629 .55707 L
.15902 .53558 L
.16396 .4833 L
.16859 .42278 L
.17113 .38971 L
.17351 .36202 L
.1757 .34103 L
.17771 .32613 L
.17877 .31991 L
.17994 .31437 L
.18111 .31005 L
.18234 .30673 L
.18303 .30538 L
.18368 .3044 L
.18489 .30329 L
.1862 .30304 L
.18694 .30327 L
.18761 .3037 L
.18875 .30485 L
.19 .30665 L
.19252 .31172 L
.19527 .31895 L
.19824 .32812 L
.20358 .34705 L
.22371 .42511 L
.23384 .46058 L
Mistroke
.23919 .47675 L
.24488 .49116 L
.2477 .49691 L
.25035 .50128 L
.25274 .50418 L
.25339 .50479 L
.25408 .50535 L
.25531 .5061 L
.25646 .50651 L
.2577 .50665 L
.25886 .50648 L
.25992 .50609 L
.26117 .50535 L
.26252 .50423 L
.26498 .50142 L
.26985 .49355 L
.27441 .48434 L
.2848 .46152 L
.29504 .4419 L
.30019 .43416 L
.30582 .42744 L
.31089 .42283 L
.3163 .41922 L
.32141 .41682 L
.32604 .41528 L
.33062 .41418 L
.33557 .4133 L
.34456 .41196 L
.35405 .41022 L
.35944 .40888 L
.36447 .40736 L
.38553 .3989 L
.40414 .3909 L
.4244 .38412 L
.43542 .38142 L
.44562 .37938 L
.46573 .37615 L
.50497 .37096 L
.54268 .36714 L
.56201 .36567 L
.58286 .36437 L
.60248 .36334 L
.62396 .3624 L
.66356 .36111 L
.68314 .36065 L
.70408 .36026 L
.7254 .35996 L
.74555 .35975 L
.75525 .35967 L
.76554 .3596 L
Mistroke
.78398 .3595 L
.7934 .35947 L
.80353 .35944 L
.81309 .35941 L
.82184 .3594 L
.82661 .35939 L
.82923 .35939 L
.83169 .35939 L
.834 .35939 L
.83649 .35939 L
.83876 .35939 L
.84084 .35939 L
.84204 .35939 L
.84333 .35938 L
.84454 .35938 L
.84565 .35938 L
.84694 .35938 L
.84768 .35938 L
.84836 .35938 L
.8496 .35938 L
.85092 .35938 L
.85218 .35939 L
.85353 .35939 L
.85598 .35939 L
.8589 .35939 L
.86157 .35939 L
.87138 .3594 L
.88051 .35941 L
.90121 .35944 L
.94028 .35951 L
.97619 .35959 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.06244 .23854 L
.08255 .36423 L
.10458 .48504 L
.11448 .53056 L
.11992 .55223 L
.12507 .56989 L
.12986 .58328 L
.13238 .58888 L
.13376 .59147 L
.13506 .59354 L
.13623 .59512 L
.13731 .59628 L
.1385 .59725 L
.13979 .59788 L
.14086 .59805 L
.14202 .59784 L
.14313 .59724 L
.14415 .5963 L
.14544 .59457 L
.1468 .59201 L
.14796 .58918 L
.14923 .58533 L
.15207 .57356 L
.15472 .55799 L
.15723 .53844 L
.15952 .51608 L
.16467 .45006 L
.16933 .38029 L
.1737 .3247 L
.17589 .30503 L
.17712 .29661 L
.17825 .29048 L
.17942 .2856 L
.1807 .2818 L
.18135 .28044 L
.18204 .27935 L
.18328 .27827 L
.18456 .27819 L
.18529 .27855 L
.18595 .27911 L
.18718 .28066 L
.18848 .28293 L
.19072 .28813 L
.19319 .29526 L
.20237 .32878 L
.22313 .41111 L
.2331 .44434 L
.23802 .45756 L
.24257 .46707 L
Mistroke
.2451 .47084 L
.24583 .47167 L
.24652 .47235 L
.2478 .47331 L
.24849 .47365 L
.24922 .47387 L
.25053 .47386 L
.25126 .47362 L
.25195 .47325 L
.25269 .47266 L
.25349 .47183 L
.25478 .47005 L
.25617 .46753 L
.25871 .46155 L
.26347 .44684 L
.27282 .41278 L
.28289 .37871 L
.28866 .36311 L
.29394 .35186 L
.29899 .34372 L
.30177 .34024 L
.3043 .33763 L
.30901 .33397 L
.3116 .33252 L
.31404 .33147 L
.3163 .3307 L
.31839 .33016 L
.32067 .3297 L
.32309 .32934 L
.33299 .32845 L
.33585 .32819 L
.33855 .32788 L
.34101 .32752 L
.34362 .32705 L
.3485 .32589 L
.35301 .32446 L
.36323 .32012 L
.38156 .31036 L
.39091 .30567 L
.40101 .30146 L
.41053 .29843 L
.41928 .29639 L
.42906 .29478 L
.43818 .2937 L
.45887 .29196 L
.49788 .28922 L
.50811 .28864 L
.5192 .28812 L
.52968 .28774 L
.53935 .28747 L
Mistroke
.54903 .28726 L
.55809 .28712 L
.56803 .28699 L
.57872 .2869 L
.58883 .28683 L
.59456 .2868 L
.59987 .28678 L
.6025 .28677 L
.60497 .28676 L
.60722 .28676 L
.6096 .28675 L
.61083 .28675 L
.61219 .28675 L
.61343 .28675 L
.61458 .28675 L
.61528 .28675 L
.61594 .28675 L
.61718 .28675 L
.61787 .28675 L
.61851 .28675 L
.61922 .28675 L
.61996 .28675 L
.6211 .28675 L
.62235 .28675 L
.62486 .28675 L
.62718 .28676 L
.62934 .28676 L
.63423 .28678 L
.63945 .2868 L
.64903 .28685 L
.65773 .28691 L
.67693 .28709 L
.69774 .28733 L
.73867 .28793 L
.7781 .28862 L
.816 .28935 L
.85636 .29018 L
.89521 .29098 L
.9365 .29183 L
.97619 .29262 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.06244 .2384 L
.08255 .36411 L
.10458 .48503 L
.11448 .53066 L
.11992 .55243 L
.12507 .57023 L
.12986 .58379 L
.13238 .58953 L
.13506 .59435 L
.13614 .5959 L
.13731 .59727 L
.13859 .59841 L
.13979 .5991 L
.14096 .59941 L
.14207 .59933 L
.14306 .59893 L
.14415 .59812 L
.1448 .59745 L
.14548 .59656 L
.1467 .59453 L
.14802 .59164 L
.14946 .58756 L
.15205 .57759 L
.15447 .56475 L
.15683 .54841 L
.15898 .52991 L
.16382 .47537 L
.16911 .40224 L
.172 .36421 L
.17472 .33493 L
.17702 .31644 L
.17832 .30864 L
.17951 .30302 L
.18074 .29864 L
.18144 .29674 L
.18209 .29532 L
.1834 .29341 L
.18413 .29284 L
.1848 .29261 L
.18599 .29279 L
.18725 .29373 L
.18832 .29505 L
.18951 .297 L
.19215 .30282 L
.19461 .30971 L
.20388 .34254 L
.22464 .42408 L
.23505 .45937 L
.24018 .47377 L
Mistroke
.24493 .48459 L
.24714 .48856 L
.24923 .49154 L
.25038 .49284 L
.25163 .49392 L
.25276 .49461 L
.2538 .49498 L
.25496 .49509 L
.25604 .49489 L
.25723 .49436 L
.2585 .49342 L
.25984 .49205 L
.2611 .49043 L
.26347 .48664 L
.28172 .44262 L
.29211 .41952 L
.29719 .41072 L
.30185 .40424 L
.3065 .39916 L
.31139 .39517 L
.3163 .3923 L
.31908 .39109 L
.32166 .39018 L
.32441 .38941 L
.32699 .38882 L
.33183 .38796 L
.34268 .38641 L
.35243 .38449 L
.35734 .38314 L
.36274 .38133 L
.3812 .37328 L
.40232 .36374 L
.42159 .35731 L
.43115 .35501 L
.44155 .35301 L
.46047 .35012 L
.50122 .34504 L
.52145 .34298 L
.54045 .34141 L
.57817 .33915 L
.59833 .33825 L
.61683 .33757 L
.63733 .33696 L
.65642 .33652 L
.67482 .3362 L
.69449 .33595 L
.70472 .33585 L
.71582 .33576 L
.72629 .3357 L
.73596 .33567 L
Mistroke
.74062 .33565 L
.74564 .33564 L
.74807 .33563 L
.75037 .33563 L
.75264 .33563 L
.7547 .33563 L
.75589 .33563 L
.75718 .33562 L
.75789 .33562 L
.75854 .33562 L
.75982 .33562 L
.76092 .33562 L
.76213 .33562 L
.76339 .33562 L
.76457 .33562 L
.76524 .33562 L
.76596 .33562 L
.76729 .33562 L
.76857 .33562 L
.76976 .33563 L
.77246 .33563 L
.77533 .33563 L
.78023 .33564 L
.78471 .33565 L
.79482 .33568 L
.8131 .33574 L
.83204 .33584 L
.85275 .33596 L
.89333 .33623 L
.93239 .33652 L
.97391 .33684 L
.97619 .33685 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.06244 .2385 L
.08255 .36417 L
.10458 .485 L
.11448 .53055 L
.11992 .55225 L
.12507 .56996 L
.12986 .58339 L
.13238 .58904 L
.13506 .59375 L
.13614 .59524 L
.13731 .59654 L
.13859 .5976 L
.13979 .59821 L
.14096 .59841 L
.14207 .59823 L
.14306 .59773 L
.14415 .59679 L
.1448 .59603 L
.14548 .59506 L
.1467 .59283 L
.14802 .58971 L
.14946 .58532 L
.15205 .57464 L
.15447 .5609 L
.15683 .5434 L
.15898 .5235 L
.16382 .46451 L
.16911 .3857 L
.172 .34576 L
.17472 .31606 L
.17702 .29809 L
.17832 .29082 L
.17951 .28578 L
.18074 .28205 L
.18144 .28053 L
.18209 .27948 L
.1834 .2783 L
.18413 .27814 L
.1848 .27827 L
.18599 .2791 L
.18725 .28069 L
.18832 .28256 L
.18951 .28507 L
.19461 .29986 L
.20388 .33458 L
.21473 .37692 L
.22464 .4119 L
.22942 .42641 L
.23462 .43961 L
Mistroke
.237 .44442 L
.2383 .44665 L
.23953 .44844 L
.24068 .44981 L
.24192 .45093 L
.24305 .45158 L
.24409 .45183 L
.2453 .45167 L
.2466 .45088 L
.24782 .44948 L
.24894 .44762 L
.25025 .44466 L
.25167 .44048 L
.25426 .43041 L
.26498 .37235 L
.26991 .34605 L
.27521 .32114 L
.27988 .303 L
.2848 .28812 L
.28729 .28218 L
.29001 .27686 L
.29252 .27296 L
.29479 .27019 L
.29756 .26769 L
.29908 .2667 L
.30051 .26597 L
.30115 .26571 L
.30183 .26548 L
.30306 .26516 L
.30437 .26495 L
.30512 .26489 L
.30582 .26487 L
.30707 .26492 L
.30771 .26498 L
.30841 .26507 L
.30965 .2653 L
.31081 .26559 L
.31343 .26644 L
.31625 .26761 L
.32614 .27269 L
.33079 .27505 L
.33575 .27726 L
.34043 .27892 L
.34265 .27953 L
.34469 .28 L
.34705 .28042 L
.34829 .28059 L
.34961 .28074 L
.35075 .28083 L
.35182 .2809 L
Mistroke
.35299 .28094 L
.35425 .28096 L
.35494 .28096 L
.35559 .28095 L
.3563 .28093 L
.35705 .2809 L
.35777 .28086 L
.35845 .28082 L
.35971 .28072 L
.36211 .28048 L
.36471 .28014 L
.37477 .27844 L
.38009 .27751 L
.3858 .27666 L
.38857 .27632 L
.3912 .27606 L
.39356 .27588 L
.39478 .27581 L
.39612 .27574 L
.39737 .27569 L
.39855 .27566 L
.39979 .27564 L
.40049 .27564 L
.40113 .27564 L
.4022 .27565 L
.40338 .27567 L
.40461 .2757 L
.40575 .27574 L
.4085 .27588 L
.41109 .27607 L
.41594 .27654 L
.42682 .278 L
.44516 .28094 L
.46531 .28372 L
.4852 .28567 L
.50625 .2872 L
.54661 .28969 L
.58545 .29159 L
.60664 .29235 L
.62675 .29293 L
.66501 .29378 L
.68474 .29411 L
.70573 .29441 L
.74739 .29487 L
.78752 .29523 L
.82615 .29553 L
.86722 .29584 L
.90678 .29614 L
.94483 .29644 L
.97619 .29668 L
Mistroke
Mfstroke
.933 0 1 r
.02381 .01472 m
.06244 .23816 L
.08255 .36384 L
.10458 .48493 L
.11448 .53077 L
.11992 .55272 L
.12507 .57076 L
.12986 .58466 L
.13238 .59063 L
.13506 .59576 L
.13731 .599 L
.13859 .60035 L
.13979 .60126 L
.14089 .60179 L
.14189 .60198 L
.14305 .60185 L
.14415 .60134 L
.1454 .6003 L
.1461 .59948 L
.14674 .59857 L
.14793 .59647 L
.14918 .59364 L
.15135 .58707 L
.15374 .57717 L
.15629 .56305 L
.15902 .54342 L
.16396 .49567 L
.16859 .4399 L
.17351 .38213 L
.17553 .36282 L
.17771 .34619 L
.17896 .3387 L
.1801 .3331 L
.18119 .32885 L
.18234 .32537 L
.18357 .32277 L
.18471 .32125 L
.18541 .32071 L
.18607 .32045 L
.1873 .32054 L
.1886 .32136 L
.1898 .32269 L
.19112 .32469 L
.19252 .32732 L
.19779 .34066 L
.20358 .35878 L
.22371 .42593 L
.22848 .44038 L
.23368 .45454 L
.23827 .46502 L
Mistroke
.24079 .46967 L
.24315 .47311 L
.24458 .47466 L
.24539 .47533 L
.24613 .47581 L
.24744 .47629 L
.2481 .47635 L
.24882 .47626 L
.25013 .47564 L
.25087 .47503 L
.25154 .4743 L
.25284 .47238 L
.25407 .46995 L
.25656 .46324 L
.25885 .45516 L
.26405 .43258 L
.27305 .39083 L
.27778 .37166 L
.28275 .35493 L
.2854 .34755 L
.2883 .34074 L
.29339 .3318 L
.29589 .3287 L
.29726 .32733 L
.29856 .32623 L
.29977 .32538 L
.30108 .32463 L
.30227 .3241 L
.30336 .32373 L
.30462 .32343 L
.30582 .32328 L
.30689 .32323 L
.30805 .32327 L
.30932 .32343 L
.30996 .32355 L
.31067 .32371 L
.31308 .32446 L
.31534 .32542 L
.31777 .32669 L
.32217 .32947 L
.33203 .33681 L
.34282 .34472 L
.34783 .34789 L
.35318 .35078 L
.35781 .35283 L
.36284 .35459 L
.36579 .35542 L
.36852 .35606 L
.37107 .35656 L
.37388 .35701 L
Mistroke
.37876 .35759 L
.38143 .35782 L
.38393 .35799 L
.39291 .35845 L
.40248 .35892 L
.40799 .35929 L
.41298 .35972 L
.42272 .36081 L
.44387 .36402 L
.46396 .36713 L
.48322 .36951 L
.50405 .37138 L
.54507 .37402 L
.56551 .3751 L
.58458 .37598 L
.62257 .3773 L
.64294 .37781 L
.6615 .3782 L
.68221 .37856 L
.70137 .37884 L
.73972 .37924 L
.75839 .37939 L
.779 .37953 L
.81922 .37975 L
.85793 .37992 L
.89909 .38008 L
.93874 .38024 L
.97619 .38038 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.06244 .23822 L
.08255 .36389 L
.10458 .48493 L
.11448 .53072 L
.11992 .55264 L
.12507 .57063 L
.12986 .58446 L
.13238 .59037 L
.13506 .59544 L
.13731 .59861 L
.13859 .59992 L
.13979 .60079 L
.14089 .60127 L
.14189 .60142 L
.14305 .60122 L
.14415 .60066 L
.1454 .59953 L
.1461 .59866 L
.14674 .5977 L
.1479 .59555 L
.14918 .59255 L
.1514 .58557 L
.15374 .57548 L
.15629 .56087 L
.15902 .54056 L
.16396 .49111 L
.16859 .43355 L
.17351 .37476 L
.17553 .35548 L
.17771 .33911 L
.17896 .33185 L
.1801 .32649 L
.18119 .32245 L
.18234 .31926 L
.18356 .31696 L
.18486 .31558 L
.18609 .31518 L
.1872 .31548 L
.18852 .31652 L
.18925 .3174 L
.18994 .31837 L
.19252 .32327 L
.19789 .33765 L
.20358 .35604 L
.21328 .38946 L
.22371 .42407 L
.22895 .43988 L
.23393 .45319 L
.23841 .46309 L
Mistroke
.24093 .4675 L
.24328 .47059 L
.24443 .47168 L
.24568 .4725 L
.24685 .47289 L
.24793 .47288 L
.24891 .47254 L
.24999 .47179 L
.25111 .47054 L
.25215 .46892 L
.25338 .46647 L
.25454 .4636 L
.25671 .45685 L
.26159 .43685 L
.27038 .3953 L
.27985 .35701 L
.28527 .34097 L
.28764 .3354 L
.29024 .33029 L
.29253 .32658 L
.29498 .32341 L
.29757 .32087 L
.29997 .3192 L
.30131 .31854 L
.30254 .31808 L
.30319 .31789 L
.30389 .31773 L
.30463 .3176 L
.30532 .31753 L
.30659 .31748 L
.30775 .31755 L
.30839 .31762 L
.30909 .31774 L
.31036 .31802 L
.31149 .31835 L
.31273 .31879 L
.31526 .3199 L
.31979 .3225 L
.33075 .33046 L
.34081 .33786 L
.35022 .34356 L
.35495 .3458 L
.36013 .34776 L
.36535 .34923 L
.36827 .34986 L
.37093 .35033 L
.37341 .35069 L
.3761 .351 L
.38098 .35141 L
.39036 .35187 L
Mistroke
.39553 .35208 L
.40044 .3523 L
.40622 .35266 L
.41151 .35309 L
.42187 .35425 L
.46124 .36034 L
.48128 .36288 L
.49945 .36457 L
.51914 .36599 L
.54012 .36728 L
.561 .36842 L
.5802 .36933 L
.61877 .37071 L
.63761 .37121 L
.65828 .37166 L
.67944 .37203 L
.69872 .37231 L
.73765 .37273 L
.75675 .37288 L
.77752 .37302 L
.81832 .37325 L
.85761 .37343 L
.89538 .37358 L
.9356 .37374 L
.97431 .3739 L
.97619 .37391 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.06244 .23853 L
.08255 .36422 L
.10458 .48503 L
.11448 .53056 L
.11992 .55225 L
.12507 .56992 L
.12986 .58333 L
.13238 .58895 L
.13376 .59154 L
.13506 .59363 L
.13623 .59522 L
.13731 .59639 L
.1385 .59738 L
.13979 .59802 L
.14086 .5982 L
.14202 .59801 L
.14313 .59743 L
.14415 .59652 L
.14544 .59482 L
.1468 .5923 L
.14796 .58951 L
.14923 .58571 L
.15207 .57409 L
.15472 .55871 L
.15723 .53941 L
.15952 .51736 L
.16467 .45234 L
.16933 .38355 L
.1737 .32838 L
.17589 .30871 L
.17712 .30026 L
.17825 .29408 L
.17942 .28914 L
.1807 .28527 L
.18135 .28387 L
.18204 .28274 L
.18328 .28159 L
.18456 .28144 L
.18529 .28176 L
.18595 .28229 L
.18718 .28378 L
.18848 .28599 L
.19072 .29108 L
.19319 .29808 L
.20237 .33104 L
.22313 .41172 L
.2331 .44413 L
.23802 .45688 L
.24041 .46198 L
Mistroke
.24257 .46582 L
.24379 .4676 L
.2451 .46918 L
.24583 .46988 L
.24649 .47041 L
.2478 .4711 L
.24912 .47131 L
.24987 .47119 L
.25057 .47091 L
.25131 .47044 L
.25198 .46984 L
.25276 .46895 L
.25349 .4679 L
.25598 .46299 L
.25827 .45673 L
.26347 .43847 L
.27324 .39908 L
.27837 .37959 L
.28376 .36165 L
.28851 .34855 L
.29369 .33727 L
.29841 .32962 L
.30279 .32449 L
.30515 .3224 L
.30772 .3206 L
.31014 .31929 L
.31237 .31838 L
.31439 .31776 L
.3166 .31727 L
.31772 .31708 L
.31891 .31692 L
.32004 .31681 L
.32107 .31673 L
.32228 .31666 L
.32356 .31661 L
.32466 .31659 L
.32587 .31658 L
.32717 .31658 L
.32789 .31658 L
.32856 .31658 L
.32987 .31659 L
.33109 .3166 L
.33216 .3166 L
.3333 .3166 L
.33456 .31658 L
.33572 .31655 L
.33692 .31651 L
.33822 .31645 L
.33945 .31637 L
.34059 .31627 L
Mistroke
.34302 .316 L
.34525 .31567 L
.34782 .31518 L
.35027 .3146 L
.35933 .31161 L
.37996 .30194 L
.38955 .29764 L
.39978 .29398 L
.40475 .2926 L
.40943 .29153 L
.41395 .2907 L
.41817 .29008 L
.42283 .28955 L
.42794 .28912 L
.43293 .28883 L
.43572 .2887 L
.43826 .2886 L
.44776 .28835 L
.45674 .28817 L
.49509 .28727 L
.5053 .28706 L
.5103 .28698 L
.51488 .28692 L
.51969 .28687 L
.52221 .28686 L
.52487 .28684 L
.52619 .28683 L
.5276 .28683 L
.52828 .28683 L
.52893 .28683 L
.53014 .28682 L
.53084 .28682 L
.53157 .28682 L
.53221 .28682 L
.5329 .28682 L
.53365 .28682 L
.53445 .28682 L
.5352 .28682 L
.53589 .28683 L
.53719 .28683 L
.53841 .28683 L
.54068 .28684 L
.54313 .28685 L
.54577 .28686 L
.55493 .28693 L
.57567 .28713 L
.61675 .28759 L
.65631 .28811 L
.69435 .2887 L
.73485 .28937 L
Mistroke
.77383 .29007 L
.81526 .29084 L
.85518 .2916 L
.89358 .29234 L
.93444 .29312 L
.97378 .29385 L
.97619 .29389 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.06244 .23813 L
.08255 .36388 L
.10458 .485 L
.11448 .53084 L
.11992 .5528 L
.12507 .57084 L
.12986 .58474 L
.13238 .5907 L
.13506 .59584 L
.13731 .59907 L
.13859 .60042 L
.13979 .60134 L
.14089 .60186 L
.14189 .60205 L
.14305 .60192 L
.14415 .60142 L
.1454 .60037 L
.1461 .59955 L
.14674 .59864 L
.14793 .59654 L
.14918 .59371 L
.15135 .58715 L
.15374 .57726 L
.15629 .56315 L
.15902 .54354 L
.16396 .4958 L
.16859 .43984 L
.17351 .3813 L
.17553 .36148 L
.17771 .3442 L
.17896 .33632 L
.1801 .33035 L
.18119 .32574 L
.18234 .32188 L
.18357 .31889 L
.18471 .31703 L
.18541 .31628 L
.18607 .31582 L
.1873 .31557 L
.1886 .31607 L
.1898 .31714 L
.19112 .31889 L
.19252 .32131 L
.19524 .32742 L
.19779 .33442 L
.20358 .35338 L
.22371 .42944 L
.23411 .46596 L
.23924 .48177 L
Mistroke
.24399 .49462 L
.24865 .505 L
.25067 .50869 L
.25286 .51199 L
.25412 .51354 L
.25527 .51472 L
.25638 .51562 L
.25754 .51632 L
.25878 .51678 L
.25992 .51695 L
.26118 .51685 L
.26189 .51667 L
.26253 .51643 L
.26371 .51579 L
.26482 .51498 L
.26735 .51246 L
.26982 .50921 L
.27247 .50503 L
.28165 .48754 L
.29158 .46842 L
.29683 .45975 L
.30243 .45199 L
.30788 .44596 L
.31284 .44172 L
.31781 .43848 L
.32251 .43622 L
.32778 .4344 L
.33264 .43322 L
.33798 .43226 L
.34362 .43143 L
.35308 .42995 L
.35839 .42888 L
.36323 .42768 L
.38156 .42135 L
.40223 .41273 L
.42137 .40593 L
.43993 .40119 L
.45967 .39759 L
.49739 .39227 L
.51834 .38975 L
.53756 .38777 L
.57621 .38475 L
.61581 .38255 L
.65388 .38102 L
.67347 .38042 L
.69441 .3799 L
.7143 .3795 L
.73588 .37916 L
.75489 .37892 L
.77583 .37871 L
Mistroke
.79568 .37855 L
.81671 .37842 L
.83614 .37833 L
.85702 .37826 L
.87817 .3782 L
.89826 .37816 L
.91808 .37813 L
.93648 .37811 L
.97563 .37807 L
.97619 .37807 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.06244 .23845 L
.08255 .36413 L
.10458 .485 L
.11448 .53059 L
.11992 .55233 L
.12507 .57009 L
.12986 .5836 L
.13238 .5893 L
.13506 .59407 L
.13614 .59559 L
.13731 .59694 L
.13859 .59804 L
.13979 .5987 L
.14096 .59896 L
.14207 .59884 L
.14306 .5984 L
.14415 .59754 L
.1448 .59682 L
.14548 .5959 L
.1467 .59379 L
.14802 .5908 L
.14946 .58659 L
.15205 .57632 L
.15447 .56309 L
.15683 .54626 L
.15898 .52716 L
.16382 .47073 L
.16911 .39523 L
.172 .35646 L
.17472 .32714 L
.17702 .30901 L
.17832 .30152 L
.17951 .29624 L
.18074 .29223 L
.18144 .29055 L
.18209 .28934 L
.1834 .28784 L
.18413 .2875 L
.1848 .28747 L
.18599 .28801 L
.18725 .28932 L
.18832 .29094 L
.18951 .2932 L
.19461 .30696 L
.20388 .34024 L
.21473 .3817 L
.22464 .41671 L
.22942 .43157 L
.23462 .4455 L
Mistroke
.237 .45082 L
.23953 .45555 L
.24077 .45743 L
.24192 .45892 L
.24297 .46 L
.24409 .46085 L
.2454 .4614 L
.24662 .46143 L
.24732 .46122 L
.24796 .46087 L
.24869 .46027 L
.24939 .4595 L
.25078 .45737 L
.25207 .45464 L
.25498 .44592 L
.25983 .42535 L
.26498 .39996 L
.27438 .35519 L
.27931 .33547 L
.28449 .31865 L
.28906 .30729 L
.29147 .30254 L
.29404 .29836 L
.29642 .29526 L
.29857 .29302 L
.30074 .29128 L
.30279 .29004 L
.30394 .28951 L
.30519 .28906 L
.30636 .28874 L
.30743 .28853 L
.30868 .28838 L
.30939 .28833 L
.31005 .28832 L
.31125 .28835 L
.31253 .28846 L
.31375 .28863 L
.31506 .28888 L
.31743 .28947 L
.32284 .29127 L
.3324 .2949 L
.33706 .29642 L
.3413 .2975 L
.34368 .29796 L
.34592 .29829 L
.34715 .29843 L
.34829 .29853 L
.34954 .29861 L
.35086 .29866 L
.3521 .29868 L
Mistroke
.35279 .29867 L
.35343 .29866 L
.35467 .29862 L
.35584 .29855 L
.3572 .29845 L
.35846 .29833 L
.36132 .29797 L
.36668 .29704 L
.37153 .29601 L
.38241 .29359 L
.38729 .29263 L
.39245 .29181 L
.39685 .29127 L
.39934 .29105 L
.40167 .29089 L
.40297 .29082 L
.40437 .29076 L
.40502 .29074 L
.4057 .29072 L
.40693 .29069 L
.40811 .29068 L
.40921 .29068 L
.41042 .29069 L
.41173 .29071 L
.41303 .29074 L
.41446 .29079 L
.41735 .29093 L
.42002 .2911 L
.4225 .29129 L
.46156 .2955 L
.48292 .29716 L
.50308 .29828 L
.54157 .30014 L
.56107 .30102 L
.58251 .30186 L
.62193 .30302 L
.66229 .30388 L
.70113 .3045 L
.74243 .30503 L
.78221 .30546 L
.82047 .30585 L
.86119 .30626 L
.90039 .30665 L
.94205 .30706 L
.97619 .3074 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.06244 .23854 L
.08255 .36423 L
.10458 .48503 L
.11448 .53055 L
.11992 .55222 L
.12507 .56988 L
.12986 .58326 L
.13238 .58886 L
.13376 .59144 L
.13506 .59352 L
.13623 .59509 L
.13731 .59626 L
.1385 .59723 L
.13979 .59785 L
.14086 .59802 L
.14202 .59781 L
.14313 .59721 L
.14415 .59627 L
.14544 .59454 L
.1468 .59198 L
.14796 .58915 L
.14923 .58529 L
.15207 .57353 L
.15472 .55795 L
.15723 .5384 L
.15952 .51604 L
.16467 .45004 L
.16933 .3803 L
.1737 .32475 L
.17589 .30513 L
.17712 .29675 L
.17825 .29065 L
.17942 .28581 L
.1807 .28206 L
.18135 .28072 L
.18204 .27966 L
.18328 .27863 L
.18456 .2786 L
.18529 .27899 L
.18595 .27958 L
.18718 .28117 L
.18848 .28349 L
.19072 .28875 L
.19319 .29593 L
.20237 .32933 L
.21321 .37263 L
.22313 .4099 L
.23243 .43979 L
.23769 .45314 L
Mistroke
.24021 .45821 L
.24257 .46197 L
.24388 .46356 L
.24457 .46424 L
.2453 .46483 L
.24658 .46551 L
.24777 .46571 L
.24842 .46563 L
.24913 .46538 L
.2504 .46448 L
.25118 .46363 L
.25191 .46262 L
.25329 .46015 L
.25583 .45377 L
.25817 .44605 L
.26347 .42461 L
.27324 .38167 L
.27837 .36116 L
.28376 .34269 L
.28851 .32951 L
.29369 .31842 L
.29597 .31458 L
.29841 .31113 L
.30279 .3064 L
.30534 .30441 L
.30768 .30302 L
.31026 .30189 L
.31156 .30146 L
.31299 .30108 L
.31424 .30082 L
.31538 .30064 L
.31671 .30049 L
.31796 .30039 L
.31911 .30033 L
.32018 .30031 L
.32136 .30031 L
.3226 .30033 L
.32717 .30054 L
.32966 .30068 L
.33088 .30074 L
.33198 .30079 L
.333 .30083 L
.33397 .30085 L
.33499 .30086 L
.33609 .30087 L
.33723 .30085 L
.33843 .30081 L
.33946 .30076 L
.34059 .30069 L
.3418 .30058 L
Mistroke
.34292 .30046 L
.34542 .3001 L
.34774 .29967 L
.34994 .29916 L
.35477 .29774 L
.36003 .29577 L
.37831 .2873 L
.38845 .28295 L
.39799 .27977 L
.40328 .27846 L
.409 .2774 L
.41153 .27703 L
.41419 .27671 L
.41648 .27648 L
.41897 .27628 L
.42152 .27612 L
.42394 .276 L
.42508 .27596 L
.42629 .27592 L
.42742 .27589 L
.42846 .27587 L
.42966 .27585 L
.43095 .27583 L
.43209 .27583 L
.43329 .27582 L
.43461 .27582 L
.43584 .27583 L
.43655 .27583 L
.43719 .27583 L
.43862 .27585 L
.44098 .27587 L
.44315 .27591 L
.44806 .27599 L
.45696 .27615 L
.46164 .27622 L
.46667 .27628 L
.4691 .2763 L
.47141 .27632 L
.47368 .27633 L
.47574 .27634 L
.47823 .27635 L
.48087 .27635 L
.48332 .27636 L
.48562 .27636 L
.49076 .27637 L
.49367 .27637 L
.49639 .27638 L
.49886 .27638 L
.50112 .27639 L
.50372 .2764 L
Mistroke
.50619 .27642 L
.51114 .27645 L
.51652 .27651 L
.52613 .27664 L
.53501 .27681 L
.57435 .27773 L
.61217 .27855 L
.65245 .27936 L
.69121 .28012 L
.73242 .2809 L
.77211 .28165 L
.81029 .28237 L
.85093 .28315 L
.89004 .2839 L
.93161 .28468 L
.97167 .28542 L
.97619 .2855 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.06244 .2382 L
.08255 .36393 L
.10458 .48501 L
.11448 .5308 L
.11992 .55271 L
.12507 .5707 L
.12986 .58451 L
.13238 .59043 L
.13506 .59549 L
.13731 .59865 L
.13859 .59995 L
.13979 .60081 L
.14089 .60128 L
.14189 .60142 L
.14305 .60122 L
.14415 .60064 L
.1454 .59951 L
.1461 .59863 L
.14674 .59766 L
.1479 .5955 L
.14918 .59249 L
.1514 .58548 L
.15374 .57536 L
.15629 .56072 L
.15902 .54036 L
.16396 .49084 L
.16859 .43308 L
.17351 .37363 L
.17553 .35391 L
.17771 .33698 L
.17896 .32938 L
.1801 .32369 L
.18119 .31936 L
.18234 .3158 L
.18357 .31313 L
.18471 .31155 L
.18541 .31097 L
.18607 .31066 L
.1873 .31069 L
.1886 .31146 L
.1898 .31276 L
.19112 .31474 L
.19252 .31739 L
.19779 .33118 L
.20358 .35067 L
.22371 .42739 L
.23368 .46237 L
.24315 .48982 L
.24838 .50126 L
Mistroke
.25133 .50611 L
.25274 .50793 L
.25407 .50932 L
.25529 .51029 L
.25661 .51102 L
.2578 .51138 L
.2589 .51146 L
.2601 .51126 L
.2614 .51074 L
.26206 .51035 L
.26277 .50986 L
.26405 .50874 L
.26662 .50575 L
.26935 .50165 L
.27425 .49262 L
.28533 .46931 L
.29502 .45108 L
.30011 .4434 L
.30546 .43685 L
.31033 .4322 L
.31564 .42837 L
.32048 .42584 L
.32497 .42413 L
.32961 .42285 L
.33382 .42199 L
.34326 .42054 L
.35261 .41901 L
.35731 .418 L
.36248 .41665 L
.37332 .41301 L
.3833 .40894 L
.40442 .40001 L
.42369 .3935 L
.43324 .39106 L
.44364 .38887 L
.46256 .38571 L
.50331 .38026 L
.52354 .37801 L
.54255 .37623 L
.58027 .37357 L
.61892 .37162 L
.63894 .37084 L
.66003 .37017 L
.69811 .36929 L
.71769 .36897 L
.73863 .36871 L
.75995 .3685 L
.7801 .36836 L
.7898 .36831 L
.80009 .36827 L
Mistroke
.81853 .36821 L
.82795 .36818 L
.83808 .36817 L
.84299 .36816 L
.84764 .36815 L
.85215 .36815 L
.85639 .36815 L
.85881 .36815 L
.86142 .36814 L
.8636 .36814 L
.86598 .36814 L
.86858 .36814 L
.86999 .36814 L
.87131 .36814 L
.87255 .36814 L
.87368 .36814 L
.87498 .36814 L
.87621 .36814 L
.87726 .36814 L
.87843 .36814 L
.87965 .36814 L
.88079 .36814 L
.88283 .36814 L
.88502 .36814 L
.88746 .36814 L
.89002 .36814 L
.8946 .36814 L
.90416 .36815 L
.91436 .36816 L
.93273 .36818 L
.97425 .36823 L
.97619 .36823 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.06244 .23839 L
.08255 .36407 L
.10458 .48498 L
.11448 .53062 L
.11992 .55241 L
.12507 .57023 L
.12986 .58382 L
.13238 .58958 L
.13506 .59443 L
.13614 .59599 L
.13731 .59738 L
.13859 .59854 L
.13979 .59925 L
.14096 .59957 L
.14207 .59952 L
.14306 .59914 L
.14415 .59836 L
.1448 .5977 L
.14548 .59683 L
.1467 .59483 L
.14802 .59198 L
.14946 .58795 L
.15205 .57808 L
.15447 .56534 L
.15683 .54911 L
.15898 .53071 L
.16382 .47629 L
.16911 .40305 L
.172 .36494 L
.17472 .33567 L
.17702 .31724 L
.17832 .3095 L
.17951 .30396 L
.18074 .29967 L
.18144 .29782 L
.18209 .29647 L
.1834 .29468 L
.18413 .29418 L
.1848 .29402 L
.18599 .29433 L
.18725 .29541 L
.18832 .29686 L
.18951 .29892 L
.19215 .30498 L
.19461 .312 L
.20388 .34423 L
.21453 .38383 L
.22464 .41866 L
.22934 .43293 L
Mistroke
.23435 .44603 L
.23723 .45225 L
.23984 .45677 L
.2411 .45849 L
.24176 .45926 L
.24246 .45997 L
.24375 .46093 L
.24493 .46142 L
.24609 .46147 L
.24714 .46112 L
.24836 .46019 L
.24951 .45876 L
.25057 .45694 L
.25155 .45481 L
.25377 .44844 L
.25601 .44007 L
.25848 .42916 L
.26347 .40437 L
.27292 .35809 L
.27807 .33691 L
.28285 .32093 L
.28806 .30777 L
.29081 .30253 L
.29375 .29814 L
.29644 .2951 L
.29776 .29393 L
.29898 .29303 L
.30125 .29175 L
.30245 .29127 L
.30372 .29091 L
.30494 .29068 L
.30563 .2906 L
.30626 .29056 L
.30743 .29056 L
.30867 .29065 L
.30978 .29081 L
.31081 .29102 L
.31318 .29169 L
.31573 .29267 L
.31807 .29374 L
.32334 .29657 L
.33219 .3017 L
.34166 .30637 L
.34679 .30824 L
.35145 .30947 L
.3537 .30991 L
.35613 .31027 L
.35725 .31041 L
.35844 .31052 L
.35953 .31061 L
Mistroke
.36056 .31067 L
.36184 .31073 L
.36301 .31076 L
.36427 .31078 L
.36499 .31078 L
.36565 .31077 L
.36686 .31075 L
.36795 .31071 L
.36922 .31066 L
.37041 .3106 L
.37562 .31023 L
.38125 .30975 L
.38585 .30936 L
.39077 .30903 L
.39222 .30895 L
.39359 .30889 L
.39493 .30884 L
.39617 .3088 L
.39734 .30877 L
.39858 .30875 L
.39983 .30874 L
.40054 .30874 L
.40121 .30875 L
.40244 .30876 L
.40314 .30877 L
.40379 .30878 L
.4051 .30882 L
.4065 .30887 L
.40904 .30899 L
.41135 .30914 L
.41697 .30962 L
.42228 .3102 L
.46076 .31563 L
.48065 .31774 L
.5017 .31933 L
.53961 .32156 L
.5607 .32264 L
.57997 .32348 L
.61881 .32475 L
.63785 .32521 L
.65859 .32563 L
.69931 .32625 L
.73851 .32667 L
.78017 .32702 L
.82031 .3273 L
.85893 .32756 L
.9 .32783 L
.93956 .32809 L
.97619 .32833 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.06244 .23842 L
.08255 .36414 L
.10458 .48503 L
.11448 .53064 L
.11992 .55239 L
.12507 .57017 L
.12986 .58369 L
.13238 .5894 L
.13506 .5942 L
.13614 .59572 L
.13731 .59708 L
.13859 .5982 L
.13979 .59886 L
.14096 .59914 L
.14207 .59903 L
.14306 .59861 L
.14415 .59777 L
.1448 .59707 L
.14548 .59616 L
.1467 .59407 L
.14802 .59113 L
.14946 .58697 L
.15205 .57682 L
.15447 .56376 L
.15683 .54716 L
.15898 .52836 L
.16382 .47296 L
.16911 .39892 L
.172 .36067 L
.17472 .33146 L
.17702 .31319 L
.17832 .30555 L
.17951 .30011 L
.18074 .2959 L
.18144 .2941 L
.18209 .29278 L
.1834 .29106 L
.18413 .29059 L
.1848 .29044 L
.18599 .29077 L
.18725 .29185 L
.18832 .29329 L
.18951 .29534 L
.19215 .30137 L
.19461 .3084 L
.20388 .34135 L
.22464 .42162 L
.23505 .45559 L
.24018 .46899 L
Mistroke
.24267 .47438 L
.24493 .47846 L
.24599 .48007 L
.24714 .48157 L
.24814 .48265 L
.24923 .48357 L
.25039 .48423 L
.25161 .48455 L
.25274 .48448 L
.2538 .48408 L
.25505 .48318 L
.25624 .48192 L
.25731 .48044 L
.25847 .47851 L
.26347 .46693 L
.28289 .40701 L
.28821 .3932 L
.29394 .38109 L
.29935 .37237 L
.3043 .3665 L
.3066 .36439 L
.30905 .36251 L
.31346 .35997 L
.31616 .35886 L
.31871 .35807 L
.32099 .35753 L
.32347 .35709 L
.3259 .35678 L
.32857 .35652 L
.33396 .35615 L
.33858 .35581 L
.3412 .35556 L
.34362 .35527 L
.34615 .3549 L
.34885 .35441 L
.35381 .35324 L
.36311 .35016 L
.38401 .34075 L
.39359 .33652 L
.40368 .33274 L
.4123 .33018 L
.42173 .32804 L
.43174 .32639 L
.44105 .32524 L
.4619 .32332 L
.50091 .32026 L
.52223 .31894 L
.54238 .31804 L
.56237 .31741 L
.58081 .31698 L
Mistroke
.59955 .31663 L
.61033 .31647 L
.62018 .31635 L
.62947 .31625 L
.63961 .31617 L
.64516 .31613 L
.65032 .3161 L
.65562 .31608 L
.66049 .31606 L
.66557 .31605 L
.66825 .31605 L
.66961 .31605 L
.67107 .31604 L
.67235 .31604 L
.67353 .31604 L
.6747 .31604 L
.67582 .31604 L
.67712 .31604 L
.67831 .31604 L
.67963 .31604 L
.6803 .31604 L
.68103 .31604 L
.6822 .31604 L
.68344 .31604 L
.68565 .31604 L
.68803 .31605 L
.69063 .31605 L
.6953 .31606 L
.69964 .31607 L
.71017 .31611 L
.72011 .31616 L
.73871 .31627 L
.77719 .31661 L
.81813 .31706 L
.85755 .31755 L
.89546 .31806 L
.93582 .3186 L
.97467 .31911 L
.97619 .31913 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.06244 .23828 L
.08255 .36401 L
.10458 .48502 L
.11448 .53075 L
.11992 .5526 L
.12507 .57051 L
.12986 .58423 L
.13238 .59006 L
.13506 .59503 L
.13731 .59809 L
.13859 .59933 L
.13979 .60012 L
.14089 .60052 L
.14189 .60059 L
.14305 .6003 L
.14415 .59962 L
.1454 .59837 L
.1461 .59741 L
.14674 .59636 L
.1479 .59406 L
.14918 .59085 L
.1514 .58346 L
.15374 .5728 L
.15629 .55742 L
.15902 .53603 L
.16396 .48401 L
.16859 .42373 L
.17113 .39073 L
.17351 .36304 L
.1757 .342 L
.17771 .32703 L
.17877 .32077 L
.17994 .31518 L
.18111 .3108 L
.18234 .30743 L
.18303 .30604 L
.18368 .30504 L
.18489 .30388 L
.1862 .30356 L
.18694 .30376 L
.18761 .30416 L
.18875 .30526 L
.19 .307 L
.19252 .31196 L
.19527 .31908 L
.19824 .32814 L
.20358 .34688 L
.22371 .42438 L
.23384 .45954 L
Mistroke
.23919 .47547 L
.24488 .48951 L
.2477 .495 L
.24908 .49726 L
.25035 .49905 L
.25149 .5004 L
.25274 .5016 L
.25399 .50248 L
.25531 .50304 L
.25658 .50321 L
.25773 .50306 L
.25837 .50285 L
.25906 .50252 L
.26032 .50167 L
.26149 .5006 L
.26274 .49918 L
.26498 .49601 L
.28472 .45259 L
.29335 .43497 L
.30279 .42077 L
.30768 .41553 L
.31223 .41182 L
.31704 .40892 L
.31973 .40768 L
.32217 .40675 L
.32733 .40528 L
.33024 .40467 L
.33291 .4042 L
.34304 .40274 L
.34773 .402 L
.35276 .40101 L
.36184 .39859 L
.37264 .39464 L
.3825 .39037 L
.40317 .38141 L
.41226 .3781 L
.42231 .37505 L
.44087 .37091 L
.46061 .36779 L
.50078 .36273 L
.53943 .35902 L
.55945 .35762 L
.58054 .35642 L
.61862 .35478 L
.6382 .35414 L
.65914 .35359 L
.68047 .35317 L
.70061 .35287 L
.71032 .35276 L
.7206 .35266 L
Mistroke
.73904 .35252 L
.74846 .35246 L
.75859 .35242 L
.7635 .3524 L
.76816 .35239 L
.77266 .35238 L
.7769 .35237 L
.77932 .35237 L
.78193 .35236 L
.78411 .35236 L
.7865 .35236 L
.78909 .35236 L
.7905 .35236 L
.79182 .35235 L
.79306 .35235 L
.79419 .35235 L
.79549 .35235 L
.79672 .35235 L
.79778 .35235 L
.79894 .35235 L
.80016 .35235 L
.8013 .35235 L
.80334 .35236 L
.80553 .35236 L
.80797 .35236 L
.81053 .35236 L
.81511 .35237 L
.82467 .35238 L
.83487 .3524 L
.85324 .35245 L
.89476 .35261 L
.93476 .35279 L
.97325 .35298 L
.97619 .35299 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.06244 .23836 L
.08255 .36403 L
.10458 .48496 L
.11448 .53063 L
.11992 .55245 L
.12507 .5703 L
.12986 .58394 L
.13238 .58973 L
.13506 .59463 L
.13614 .59621 L
.13731 .59762 L
.13859 .59881 L
.13979 .59955 L
.14096 .59991 L
.14207 .59989 L
.14306 .59955 L
.14415 .59881 L
.1448 .59818 L
.14548 .59735 L
.1467 .59541 L
.14802 .59264 L
.14946 .5887 L
.15205 .57904 L
.15447 .56656 L
.15683 .55066 L
.15898 .53261 L
.16382 .47921 L
.16911 .40704 L
.172 .3692 L
.17472 .33989 L
.17702 .32128 L
.17832 .31339 L
.17951 .30771 L
.18074 .30326 L
.18144 .30133 L
.18209 .2999 L
.1834 .29796 L
.18413 .29739 L
.1848 .29716 L
.18599 .29736 L
.18725 .29833 L
.18832 .29968 L
.18951 .30166 L
.19215 .30755 L
.19461 .31443 L
.20388 .34613 L
.21453 .38504 L
.22464 .41918 L
.22934 .43312 L
Mistroke
.23435 .44582 L
.23723 .45177 L
.23984 .456 L
.2411 .45757 L
.24176 .45825 L
.24246 .45886 L
.24375 .45963 L
.24493 .45991 L
.24609 .45974 L
.24714 .45916 L
.24836 .45796 L
.24951 .45623 L
.25057 .45411 L
.25155 .45169 L
.25377 .44462 L
.25848 .42388 L
.26347 .39806 L
.27286 .35191 L
.27779 .33224 L
.28298 .31598 L
.28754 .30546 L
.29012 .30098 L
.29253 .2977 L
.29474 .29537 L
.29676 .29379 L
.29787 .29311 L
.29908 .29253 L
.30022 .29212 L
.30127 .29185 L
.30253 .29166 L
.30372 .2916 L
.30479 .29165 L
.30596 .29179 L
.30722 .29205 L
.30857 .29243 L
.31099 .29338 L
.3153 .2957 L
.32007 .29893 L
.33084 .30716 L
.34072 .31406 L
.35013 .31902 L
.35487 .32081 L
.36005 .32226 L
.36278 .32284 L
.36527 .32325 L
.36813 .32363 L
.37084 .32389 L
.37335 .32407 L
.37566 .3242 L
.3782 .32429 L
Mistroke
.37949 .32433 L
.3809 .32436 L
.38566 .32445 L
.38817 .32449 L
.39086 .32454 L
.39343 .3246 L
.39576 .32468 L
.40032 .32488 L
.40302 .32505 L
.40594 .32526 L
.41123 .32576 L
.4212 .32701 L
.44076 .33021 L
.46223 .33364 L
.48266 .33612 L
.50173 .33779 L
.54066 .34035 L
.56049 .34144 L
.58204 .34245 L
.62191 .34382 L
.6417 .3443 L
.66271 .34473 L
.70048 .34529 L
.71984 .34551 L
.7407 .34569 L
.78186 .34598 L
.82151 .34619 L
.85964 .34638 L
.90022 .34656 L
.93928 .34674 L
.97619 .34691 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.06244 .23809 L
.08255 .36379 L
.10458 .48492 L
.11448 .53081 L
.11992 .5528 L
.12507 .5709 L
.12986 .58486 L
.13238 .59088 L
.13506 .59607 L
.13731 .59937 L
.13859 .60076 L
.13979 .60172 L
.14089 .60229 L
.14189 .60253 L
.14305 .60246 L
.14415 .60201 L
.1454 .60105 L
.1461 .60027 L
.14674 .59941 L
.14793 .5974 L
.14918 .59468 L
.15135 .58835 L
.15374 .57878 L
.15629 .56511 L
.15902 .5461 L
.16396 .49987 L
.16859 .4457 L
.17351 .38886 L
.17553 .36955 L
.17771 .35269 L
.17896 .34501 L
.1801 .3392 L
.18119 .33474 L
.18234 .33102 L
.18357 .32817 L
.18471 .32642 L
.18541 .32575 L
.18607 .32536 L
.1873 .32522 L
.1886 .32582 L
.1898 .32696 L
.19112 .32875 L
.19252 .33119 L
.19779 .34391 L
.20358 .36154 L
.22371 .42803 L
.23368 .45686 L
.2386 .46833 L
.24099 .4729 L
Mistroke
.24315 .47629 L
.24437 .47783 L
.24568 .47915 L
.24641 .47971 L
.24707 .48011 L
.24838 .48056 L
.2497 .4805 L
.25045 .48022 L
.25115 .47979 L
.25189 .47915 L
.25256 .47838 L
.25407 .47604 L
.25535 .47338 L
.25653 .47037 L
.2592 .46181 L
.26405 .4418 L
.27305 .40063 L
.28275 .36385 L
.2883 .34888 L
.29073 .34378 L
.29339 .33918 L
.29574 .33591 L
.29825 .33318 L
.29964 .33199 L
.3009 .3311 L
.30217 .33036 L
.30336 .32981 L
.30448 .32942 L
.30568 .32912 L
.30637 .329 L
.30701 .32892 L
.30823 .32887 L
.30951 .32892 L
.31069 .32907 L
.31199 .32933 L
.31337 .32971 L
.31563 .33054 L
.31775 .33152 L
.32259 .33433 L
.33272 .34154 L
.3434 .3491 L
.35302 .3546 L
.35848 .35695 L
.36356 .35863 L
.36824 .35979 L
.3725 .36057 L
.37485 .36089 L
.37741 .36118 L
.38205 .36156 L
.39143 .362 L
Mistroke
.3966 .36218 L
.40151 .36238 L
.40729 .3627 L
.41258 .36309 L
.42294 .36418 L
.44177 .36691 L
.46231 .37007 L
.482 .37253 L
.50298 .37442 L
.54458 .37708 L
.56546 .37817 L
.58466 .37905 L
.62324 .38037 L
.64207 .38084 L
.66274 .38127 L
.6839 .38163 L
.70319 .3819 L
.74212 .38231 L
.76121 .38246 L
.78198 .3826 L
.82278 .38282 L
.86207 .383 L
.89984 .38316 L
.94006 .38332 L
.97619 .38347 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.06244 .23827 L
.08255 .36394 L
.10458 .48494 L
.11448 .53069 L
.11992 .55257 L
.12507 .57051 L
.12986 .58427 L
.13238 .59015 L
.13506 .59516 L
.13731 .59827 L
.13859 .59954 L
.13979 .60037 L
.14089 .6008 L
.14189 .6009 L
.14305 .60066 L
.14415 .60003 L
.1454 .59883 L
.1461 .59791 L
.14674 .5969 L
.1479 .59466 L
.14918 .59154 L
.1514 .58432 L
.15374 .5739 L
.15629 .55883 L
.15902 .53784 L
.16396 .48673 L
.16859 .42739 L
.17113 .39485 L
.17351 .36755 L
.1757 .34683 L
.17771 .33212 L
.17877 .32599 L
.17994 .32056 L
.18111 .31635 L
.18234 .31315 L
.18303 .31187 L
.18368 .31096 L
.18489 .30998 L
.1862 .30987 L
.18694 .31019 L
.18761 .31069 L
.18875 .31195 L
.19 .31386 L
.19252 .31907 L
.19824 .33526 L
.20358 .35315 L
.22371 .42217 L
.22868 .43725 L
.23411 .45168 L
Mistroke
.2366 .45733 L
.23924 .46247 L
.24052 .46458 L
.24173 .4663 L
.2429 .46767 L
.24399 .46868 L
.24507 .46939 L
.24625 .46981 L
.2474 .4698 L
.24864 .46931 L
.24978 .46835 L
.25087 .46697 L
.25184 .46532 L
.2529 .46309 L
.25533 .45628 L
.25791 .4468 L
.26253 .42609 L
.27193 .38138 L
.27686 .36087 L
.28204 .34312 L
.2866 .33102 L
.28902 .32595 L
.29159 .32148 L
.29397 .31819 L
.29612 .31583 L
.29829 .31402 L
.30033 .31279 L
.30149 .31228 L
.30273 .31187 L
.30391 .31161 L
.30498 .31148 L
.30623 .31143 L
.30694 .31146 L
.3076 .31152 L
.3088 .31169 L
.31008 .31198 L
.31129 .31234 L
.3126 .31281 L
.31498 .31387 L
.32039 .31702 L
.33885 .33035 L
.34841 .33612 L
.35382 .33863 L
.35887 .34045 L
.36161 .34124 L
.36421 .34187 L
.36906 .34277 L
.37178 .34313 L
.37429 .3434 L
.37704 .34362 L
Mistroke
.37996 .34379 L
.3901 .34414 L
.3951 .34429 L
.39973 .34447 L
.40392 .34469 L
.40838 .345 L
.41781 .34593 L
.428 .3473 L
.43724 .34874 L
.45812 .35207 L
.479 .35477 L
.49821 .35657 L
.53678 .35916 L
.57629 .36121 L
.61428 .36262 L
.6338 .36315 L
.65472 .36361 L
.67455 .36397 L
.6961 .36429 L
.73597 .36472 L
.75576 .36488 L
.77677 .36502 L
.81454 .36524 L
.85476 .36543 L
.89347 .3656 L
.93463 .36578 L
.97427 .36595 L
.97619 .36596 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.06244 .23833 L
.08255 .36406 L
.10458 .48503 L
.11448 .53071 L
.11992 .55253 L
.12507 .57039 L
.12986 .58403 L
.13238 .58982 L
.13506 .59472 L
.13614 .5963 L
.13731 .59772 L
.13859 .59891 L
.13979 .59965 L
.14096 .60002 L
.14207 .6 L
.14306 .59966 L
.14415 .59893 L
.1448 .5983 L
.14548 .59747 L
.1467 .59555 L
.14802 .59279 L
.14946 .58888 L
.15205 .57929 L
.15447 .56692 L
.15683 .55118 L
.15898 .53337 L
.16382 .48088 L
.16911 .41011 L
.172 .37274 L
.17472 .34346 L
.17702 .32458 L
.17832 .31648 L
.17951 .31056 L
.18074 .30583 L
.18209 .30215 L
.18276 .30082 L
.18349 .29977 L
.1848 .29871 L
.18608 .29862 L
.18727 .29926 L
.18856 .30063 L
.18922 .30156 L
.18994 .30275 L
.19245 .30805 L
.1948 .3143 L
.20388 .34533 L
.22464 .42535 L
.23505 .46031 L
.24018 .47462 L
Mistroke
.24493 .48536 L
.24714 .4893 L
.24923 .49225 L
.25038 .49352 L
.25163 .49458 L
.25276 .49524 L
.2538 .49558 L
.25496 .49565 L
.25604 .49541 L
.25723 .49481 L
.2585 .4938 L
.25984 .49234 L
.2611 .49062 L
.26347 .48662 L
.28172 .44083 L
.28673 .42858 L
.29211 .41707 L
.29676 .40878 L
.30185 .40152 L
.30689 .39604 L
.30945 .39384 L
.31219 .39188 L
.31476 .39037 L
.3171 .38923 L
.32166 .38756 L
.32437 .38685 L
.32686 .38632 L
.33248 .38545 L
.3374 .38486 L
.34268 .3842 L
.34776 .3834 L
.3524 .38245 L
.36148 .37986 L
.37209 .37574 L
.38214 .37121 L
.40033 .36323 L
.4107 .35951 L
.42044 .35671 L
.42994 .35456 L
.44019 .35274 L
.46119 .34991 L
.50229 .34544 L
.52279 .34363 L
.54188 .34229 L
.57996 .34039 L
.60039 .33965 L
.61897 .33909 L
.63813 .33864 L
.65892 .33826 L
.67878 .33801 L
Mistroke
.68879 .33791 L
.69981 .33783 L
.70996 .33777 L
.71923 .33773 L
.72436 .33771 L
.72706 .33771 L
.72994 .3377 L
.73271 .33769 L
.73522 .33769 L
.73774 .33769 L
.74012 .33768 L
.74128 .33768 L
.74253 .33768 L
.74371 .33768 L
.74478 .33768 L
.74604 .33768 L
.74675 .33768 L
.7474 .33768 L
.74861 .33768 L
.74989 .33768 L
.75111 .33768 L
.75242 .33768 L
.7548 .33769 L
.75762 .33769 L
.76021 .33769 L
.76921 .33771 L
.77374 .33772 L
.77869 .33774 L
.79831 .33782 L
.81927 .33793 L
.86079 .33821 L
.90079 .33853 L
.93927 .33885 L
.97619 .33916 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.06244 .23849 L
.08255 .36418 L
.10458 .48502 L
.11448 .53058 L
.11992 .55229 L
.12507 .57 L
.12986 .58346 L
.13238 .58911 L
.13506 .59384 L
.13614 .59533 L
.13731 .59665 L
.13859 .59772 L
.13979 .59834 L
.14096 .59856 L
.14207 .59839 L
.14306 .59791 L
.14415 .59699 L
.1448 .59625 L
.14548 .59529 L
.1467 .5931 L
.14802 .59002 L
.14946 .58569 L
.15205 .57516 L
.15447 .56162 L
.15683 .54439 L
.15898 .52486 L
.16382 .46719 L
.16911 .39043 L
.172 .3514 L
.17472 .32216 L
.17702 .3043 L
.17832 .29701 L
.17951 .29191 L
.18074 .28808 L
.18144 .2865 L
.18209 .28538 L
.1834 .28406 L
.18413 .28382 L
.1848 .28387 L
.18599 .28454 L
.18725 .28597 L
.18832 .28769 L
.18951 .29003 L
.19461 .30412 L
.20388 .33794 L
.21473 .38021 L
.22464 .41606 L
.22942 .43136 L
.23462 .44583 L
Mistroke
.237 .45145 L
.23953 .45654 L
.24077 .45863 L
.24192 .46033 L
.24305 .4617 L
.24409 .46271 L
.2453 .46354 L
.24595 .4638 L
.24664 .46395 L
.24736 .46395 L
.24804 .46378 L
.24932 .46302 L
.25052 .46174 L
.25163 .46005 L
.25284 .45762 L
.25413 .45439 L
.25929 .43604 L
.26498 .41039 L
.27443 .36735 L
.28437 .33125 L
.28957 .31774 L
.29233 .3121 L
.29526 .30716 L
.29797 .30351 L
.30043 .30088 L
.30291 .29882 L
.30524 .29736 L
.3064 .29679 L
.30764 .29629 L
.30871 .29593 L
.30988 .29562 L
.31059 .29547 L
.31125 .29535 L
.31255 .29518 L
.31373 .29509 L
.31498 .29505 L
.3162 .29507 L
.31751 .29515 L
.31875 .29526 L
.31988 .29539 L
.32529 .29628 L
.32988 .29715 L
.33421 .29788 L
.33661 .2982 L
.33787 .29833 L
.33921 .29844 L
.34034 .29851 L
.34158 .29857 L
.3427 .29859 L
.34376 .29859 L
Mistroke
.34502 .29856 L
.34622 .2985 L
.3473 .29843 L
.34847 .29832 L
.3511 .29799 L
.35354 .29757 L
.35796 .29655 L
.36266 .29518 L
.38335 .28784 L
.39364 .28491 L
.39944 .28371 L
.4022 .28327 L
.40477 .28292 L
.40722 .28265 L
.40945 .28246 L
.41193 .28229 L
.4133 .28222 L
.41459 .28217 L
.41584 .28213 L
.41652 .28211 L
.41717 .2821 L
.4183 .28208 L
.41955 .28207 L
.42021 .28207 L
.42091 .28208 L
.42215 .28209 L
.42284 .2821 L
.42349 .28211 L
.42495 .28214 L
.42758 .28222 L
.43001 .28232 L
.43548 .28259 L
.44542 .28321 L
.46402 .28428 L
.47372 .2847 L
.48279 .28501 L
.50344 .28557 L
.54228 .28676 L
.58358 .28808 L
.62336 .28906 L
.66162 .28983 L
.70234 .29055 L
.74154 .29116 L
.7832 .29178 L
.82334 .29237 L
.86196 .29293 L
.90304 .29352 L
.94259 .2941 L
.97619 .29457 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.06244 .23838 L
.08255 .36407 L
.10458 .485 L
.11448 .53066 L
.11992 .55245 L
.12507 .57028 L
.12986 .58389 L
.13238 .58965 L
.13506 .59452 L
.13614 .59608 L
.13731 .59748 L
.13859 .59865 L
.13979 .59937 L
.14096 .59971 L
.14207 .59967 L
.14306 .59931 L
.14415 .59854 L
.1448 .59789 L
.14548 .59704 L
.1467 .59507 L
.14802 .59226 L
.14946 .58828 L
.15205 .57854 L
.15447 .56597 L
.15683 .54999 L
.15898 .53191 L
.16382 .47861 L
.16911 .40703 L
.172 .36957 L
.17472 .34053 L
.17702 .32205 L
.17832 .31421 L
.17951 .30855 L
.18074 .3041 L
.18144 .30217 L
.18209 .30072 L
.1834 .29875 L
.18413 .29815 L
.1848 .29788 L
.18599 .29802 L
.18725 .29891 L
.18832 .30019 L
.18951 .30208 L
.19215 .30777 L
.19461 .31448 L
.20388 .346 L
.21453 .38577 L
.22464 .42153 L
.23435 .45067 L
Mistroke
.23701 .4572 L
.23984 .46318 L
.24251 .46768 L
.24369 .46924 L
.24493 .47056 L
.24607 .47145 L
.24732 .47202 L
.24846 .47214 L
.24952 .47189 L
.25077 .47108 L
.25192 .46985 L
.25323 .46782 L
.25448 .46529 L
.25672 .45937 L
.25879 .45252 L
.26347 .43378 L
.27324 .39056 L
.27837 .36984 L
.28376 .35129 L
.28851 .33817 L
.29101 .33249 L
.29369 .32734 L
.29616 .32339 L
.29841 .32042 L
.30049 .31815 L
.30279 .31615 L
.30515 .31459 L
.30636 .31396 L
.30765 .31342 L
.30886 .31301 L
.30996 .31272 L
.31108 .3125 L
.31213 .31236 L
.31335 .31227 L
.31464 .31224 L
.31575 .31227 L
.31697 .31237 L
.31828 .31252 L
.31969 .31274 L
.32224 .31326 L
.33174 .31584 L
.33638 .31707 L
.34059 .31799 L
.34296 .31839 L
.34521 .31868 L
.34644 .3188 L
.34757 .31889 L
.34882 .31896 L
.35014 .31901 L
.35138 .31902 L
Mistroke
.35208 .31901 L
.35271 .319 L
.35395 .31895 L
.35512 .31889 L
.35648 .31878 L
.35774 .31866 L
.3606 .31828 L
.36596 .3173 L
.37082 .31618 L
.3817 .31336 L
.39106 .31115 L
.39618 .31018 L
.40096 .30947 L
.40366 .30916 L
.40613 .30892 L
.40887 .30872 L
.41038 .30863 L
.41181 .30857 L
.41301 .30852 L
.41429 .30849 L
.41538 .30846 L
.41659 .30845 L
.41788 .30844 L
.4186 .30844 L
.41927 .30845 L
.42049 .30846 L
.42178 .30848 L
.42302 .30851 L
.42436 .30855 L
.42679 .30864 L
.43134 .30887 L
.44154 .30956 L
.45991 .3109 L
.4798 .31198 L
.48983 .31237 L
.50085 .31272 L
.54121 .31399 L
.58005 .3152 L
.62135 .31617 L
.66113 .31688 L
.6994 .31745 L
.74011 .31797 L
.77931 .31843 L
.82097 .3189 L
.86111 .31936 L
.89973 .31979 L
.94081 .32026 L
.97619 .32066 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.06244 .23848 L
.08255 .36418 L
.10458 .48503 L
.11448 .53059 L
.11992 .55231 L
.12507 .57003 L
.12986 .58349 L
.13238 .58916 L
.13506 .59389 L
.13614 .59539 L
.13731 .59672 L
.13859 .59779 L
.13979 .59842 L
.14096 .59865 L
.14207 .59849 L
.14306 .59802 L
.14415 .59712 L
.1448 .59638 L
.14548 .59543 L
.1467 .59327 L
.14802 .59021 L
.14946 .58592 L
.15205 .57548 L
.15447 .56207 L
.15683 .54502 L
.15898 .52571 L
.16382 .46882 L
.16911 .39318 L
.172 .35457 L
.17472 .32549 L
.17702 .30762 L
.17832 .30028 L
.17951 .29512 L
.18074 .29123 L
.18144 .28961 L
.18209 .28846 L
.1834 .28706 L
.18413 .28677 L
.1848 .28678 L
.18599 .28738 L
.18725 .28873 L
.18832 .29038 L
.18951 .29265 L
.19461 .30644 L
.20388 .33989 L
.21473 .38219 L
.22464 .41852 L
.22942 .43422 L
.23462 .44936 L
Mistroke
.237 .4554 L
.23953 .46105 L
.24191 .46547 L
.24409 .46865 L
.24541 .47008 L
.24608 .47065 L
.24681 .47114 L
.24754 .47149 L
.24832 .47169 L
.24906 .47171 L
.24974 .47157 L
.25105 .47087 L
.25179 .47021 L
.25247 .46943 L
.25372 .46755 L
.25505 .46494 L
.25749 .45863 L
.25978 .45124 L
.26498 .43112 L
.27394 .39385 L
.2835 .35941 L
.28899 .34426 L
.29398 .33373 L
.29639 .3297 L
.29899 .32603 L
.30372 .32107 L
.30614 .31926 L
.3088 .31776 L
.31014 .31717 L
.31158 .31666 L
.31282 .3163 L
.31418 .31599 L
.31552 .31575 L
.31676 .3156 L
.31795 .3155 L
.31921 .31543 L
.32033 .31541 L
.32139 .31542 L
.32255 .31545 L
.3238 .3155 L
.32867 .31586 L
.33135 .31609 L
.33388 .31627 L
.33532 .31636 L
.33607 .3164 L
.33687 .31643 L
.33755 .31645 L
.33829 .31647 L
.33959 .31648 L
.34029 .31648 L
Mistroke
.34092 .31647 L
.34165 .31646 L
.34234 .31643 L
.34357 .31637 L
.34427 .31632 L
.34491 .31627 L
.34753 .31599 L
.35 .31561 L
.3546 .31462 L
.35957 .31319 L
.36493 .31128 L
.37499 .30715 L
.38602 .30265 L
.39565 .2994 L
.40096 .298 L
.40598 .29693 L
.41168 .296 L
.41438 .29567 L
.41687 .2954 L
.42175 .29502 L
.42432 .29488 L
.42704 .29477 L
.42943 .2947 L
.43063 .29468 L
.43194 .29465 L
.43306 .29464 L
.43426 .29463 L
.4354 .29462 L
.43642 .29461 L
.43772 .29461 L
.43892 .29461 L
.44023 .29462 L
.4409 .29462 L
.44162 .29463 L
.44416 .29465 L
.44653 .29467 L
.45528 .29478 L
.4599 .29482 L
.46243 .29485 L
.46482 .29486 L
.46618 .29487 L
.46765 .29488 L
.46888 .29488 L
.47022 .29489 L
.47149 .29489 L
.47219 .29489 L
.47283 .29489 L
.47399 .29489 L
.47523 .29489 L
.47651 .29489 L
Mistroke
.47723 .29489 L
.47789 .29489 L
.47911 .29489 L
.48041 .29489 L
.48512 .29487 L
.4948 .29483 L
.49903 .29481 L
.50127 .2948 L
.50366 .2948 L
.50497 .29479 L
.50616 .29479 L
.50735 .29479 L
.50848 .29479 L
.50963 .29479 L
.51068 .29479 L
.51184 .29479 L
.51306 .29479 L
.51427 .2948 L
.51556 .2948 L
.51789 .29481 L
.52066 .29482 L
.52318 .29484 L
.52768 .29488 L
.53258 .29493 L
.54148 .29504 L
.58225 .29571 L
.62151 .29631 L
.65924 .29687 L
.69944 .29748 L
.73811 .29807 L
.77924 .2987 L
.81885 .29934 L
.85695 .29996 L
.89749 .30062 L
.93653 .30125 L
.97619 .30188 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.06244 .23845 L
.08255 .36416 L
.10458 .48503 L
.11448 .53062 L
.11992 .55236 L
.12507 .57011 L
.12986 .5836 L
.13238 .58929 L
.13506 .59406 L
.13614 .59558 L
.13731 .59692 L
.13859 .59802 L
.13979 .59867 L
.14096 .59893 L
.14207 .5988 L
.14306 .59836 L
.14415 .59749 L
.1448 .59677 L
.14548 .59585 L
.1467 .59373 L
.14802 .59074 L
.14946 .58653 L
.15205 .57626 L
.15447 .56306 L
.15683 .54628 L
.15898 .52729 L
.16382 .47135 L
.16911 .39679 L
.172 .35847 L
.17472 .32937 L
.17702 .3113 L
.17832 .30381 L
.17951 .29849 L
.18074 .29443 L
.18144 .29271 L
.18209 .29147 L
.1834 .28989 L
.18413 .28949 L
.1848 .28942 L
.18599 .28986 L
.18725 .29106 L
.18832 .29259 L
.18951 .29473 L
.19215 .30093 L
.19461 .30807 L
.20388 .3411 L
.21453 .38264 L
.22464 .4201 L
.23435 .45093 L
Mistroke
.23984 .46464 L
.24246 .46981 L
.24375 .47193 L
.24493 .4736 L
.24601 .47488 L
.24719 .47598 L
.24839 .47674 L
.24964 .47712 L
.25071 .47708 L
.25185 .47665 L
.25293 .47585 L
.25391 .47478 L
.25513 .473 L
.25626 .47093 L
.25882 .46485 L
.26347 .45015 L
.27324 .41337 L
.28376 .37716 L
.2886 .36398 L
.29369 .35291 L
.29804 .34568 L
.30279 .33987 L
.30534 .33754 L
.30776 .33578 L
.30992 .33453 L
.31227 .33348 L
.31483 .33265 L
.31612 .33233 L
.31753 .33206 L
.31874 .33188 L
.32004 .33173 L
.32126 .33162 L
.32238 .33156 L
.32351 .33152 L
.3247 .3315 L
.32573 .3315 L
.32686 .3315 L
.32806 .33153 L
.32937 .33156 L
.33173 .33162 L
.33289 .33165 L
.33398 .33168 L
.33511 .3317 L
.33635 .33171 L
.33742 .33171 L
.3384 .3317 L
.33952 .33167 L
.34059 .33163 L
.34174 .33158 L
.34297 .33149 L
Mistroke
.34521 .33129 L
.34786 .33094 L
.35029 .33053 L
.35557 .3293 L
.36058 .32774 L
.37902 .32009 L
.38935 .31576 L
.39907 .31237 L
.4078 .31006 L
.41271 .30907 L
.41723 .30834 L
.4218 .30775 L
.42681 .30725 L
.43204 .30686 L
.43692 .30659 L
.44222 .30637 L
.44705 .30621 L
.4579 .30592 L
.47861 .30532 L
.49777 .30471 L
.50736 .30445 L
.51637 .30424 L
.52576 .30409 L
.53074 .30403 L
.53611 .30398 L
.53852 .30397 L
.54108 .30395 L
.54329 .30394 L
.5457 .30393 L
.54717 .30393 L
.54852 .30392 L
.54979 .30392 L
.55119 .30392 L
.55244 .30392 L
.55361 .30392 L
.55484 .30392 L
.55554 .30392 L
.55617 .30392 L
.55747 .30392 L
.5582 .30392 L
.55886 .30392 L
.56014 .30392 L
.56135 .30392 L
.56407 .30392 L
.567 .30393 L
.57236 .30394 L
.57727 .30395 L
.59615 .30402 L
.61683 .30411 L
.6364 .30423 L
Mistroke
.65733 .3044 L
.69876 .30483 L
.73868 .30532 L
.77708 .30586 L
.81794 .30647 L
.85728 .30709 L
.8951 .30769 L
.93537 .30833 L
.97413 .30894 L
.97619 .30897 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.06244 .23813 L
.08255 .36382 L
.10458 .48492 L
.11448 .53078 L
.11992 .55275 L
.12507 .57082 L
.12986 .58474 L
.13238 .59073 L
.13506 .59589 L
.13731 .59915 L
.13859 .60052 L
.13979 .60146 L
.14089 .602 L
.14189 .60222 L
.14305 .60211 L
.14415 .60163 L
.1454 .60063 L
.1461 .59983 L
.14674 .59893 L
.14793 .59688 L
.14918 .5941 L
.15135 .58764 L
.15374 .57789 L
.15629 .56398 L
.15902 .54464 L
.16396 .49761 L
.16859 .44263 L
.17351 .38538 L
.17553 .36611 L
.17771 .34942 L
.17896 .34187 L
.1801 .3362 L
.18119 .33186 L
.18234 .32829 L
.18357 .32559 L
.18471 .32399 L
.18541 .3234 L
.18607 .32308 L
.1873 .32308 L
.1886 .32382 L
.1898 .32508 L
.19112 .327 L
.19252 .32955 L
.19779 .34263 L
.20358 .36055 L
.22371 .42745 L
.22848 .44197 L
.23368 .4563 L
.23827 .46705 L
Mistroke
.24079 .4719 L
.24315 .47559 L
.24458 .47732 L
.24533 .47806 L
.24613 .4787 L
.2468 .47912 L
.24753 .47945 L
.24882 .47965 L
.25013 .47934 L
.25087 .47891 L
.25154 .47836 L
.25284 .47681 L
.25407 .47475 L
.25656 .46885 L
.25885 .46149 L
.26405 .44017 L
.27305 .39904 L
.28275 .36227 L
.2883 .34726 L
.29073 .34215 L
.29339 .33754 L
.29574 .33424 L
.29825 .3315 L
.29964 .3303 L
.3009 .32939 L
.30217 .32864 L
.30336 .32808 L
.30448 .32768 L
.30568 .32737 L
.30637 .32724 L
.30701 .32716 L
.30823 .32709 L
.30951 .32713 L
.31069 .32727 L
.31199 .32751 L
.31337 .32788 L
.31563 .32869 L
.31775 .32965 L
.32259 .33239 L
.33272 .33945 L
.3434 .3468 L
.35302 .35208 L
.35848 .35431 L
.36356 .35589 L
.36824 .35695 L
.3725 .35765 L
.37485 .35793 L
.37741 .35818 L
.37982 .35837 L
.38205 .3585 L
Mistroke
.39185 .35884 L
.39725 .35899 L
.40239 .35919 L
.40714 .35944 L
.41233 .35981 L
.42142 .36072 L
.44106 .3635 L
.45928 .36631 L
.47809 .36874 L
.49843 .37067 L
.51986 .37219 L
.54003 .3734 L
.55959 .37445 L
.58105 .37545 L
.62056 .37684 L
.64009 .37734 L
.66101 .37778 L
.68083 .37812 L
.70239 .37842 L
.74225 .37884 L
.76204 .379 L
.78305 .37914 L
.82082 .37935 L
.86105 .37954 L
.89976 .37971 L
.94091 .37989 L
.97619 .38003 L
Mfstroke
1 0 .617 r
.02381 .01472 m
.06244 .23819 L
.08255 .36387 L
.10458 .48493 L
.11448 .53074 L
.11992 .55267 L
.12507 .57069 L
.12986 .58455 L
.13238 .59049 L
.13506 .59559 L
.13731 .59879 L
.13859 .60012 L
.13979 .60101 L
.14089 .60151 L
.14189 .60168 L
.14305 .60152 L
.14415 .60098 L
.1454 .5999 L
.1461 .59905 L
.14674 .59811 L
.1479 .59601 L
.14918 .59307 L
.1514 .58622 L
.15374 .5763 L
.15629 .56195 L
.15902 .54198 L
.16396 .49343 L
.16859 .43686 L
.17351 .37872 L
.17553 .35948 L
.17771 .34304 L
.17896 .3357 L
.1801 .33025 L
.18119 .32612 L
.18234 .32282 L
.18356 .32041 L
.18486 .31892 L
.18609 .31841 L
.1872 .31862 L
.18852 .31956 L
.18925 .32038 L
.18994 .3213 L
.19252 .32602 L
.19508 .33217 L
.19789 .34009 L
.20358 .35822 L
.22371 .42593 L
.22848 .44047 L
.23368 .45474 L
.23827 .46532 L
Mistroke
.24079 .47004 L
.24315 .47355 L
.24458 .47514 L
.24539 .47584 L
.24613 .47634 L
.24744 .47688 L
.2481 .47697 L
.24882 .47691 L
.25013 .47637 L
.25087 .4758 L
.25154 .47511 L
.25284 .47329 L
.25407 .47096 L
.25656 .46451 L
.25885 .45672 L
.26405 .43476 L
.27305 .39337 L
.28275 .35683 L
.28546 .34904 L
.2883 .34206 L
.29094 .33667 L
.29339 .33256 L
.29589 .32919 L
.29816 .3268 L
.30068 .32484 L
.30206 .32405 L
.30336 .32348 L
.30452 .3231 L
.30577 .32281 L
.30694 .32266 L
.30801 .32262 L
.30926 .32267 L
.30997 .32274 L
.31063 .32284 L
.31183 .32308 L
.31311 .32343 L
.31564 .32435 L
.31801 .32546 L
.32342 .32862 L
.34188 .34131 L
.3517 .34669 L
.35664 .34872 L
.36204 .35042 L
.36667 .35148 L
.36926 .35192 L
.37162 .35225 L
.37382 .3525 L
.3762 .35271 L
.37846 .35287 L
.38054 .35298 L
Mistroke
.39034 .35326 L
.39292 .35331 L
.39574 .35337 L
.40087 .35352 L
.40337 .35363 L
.40603 .35376 L
.41081 .35408 L
.41559 .35449 L
.41991 .35494 L
.45776 .3605 L
.47865 .36318 L
.49785 .36497 L
.53642 .36751 L
.57593 .36954 L
.61392 .37094 L
.63344 .37147 L
.65436 .37193 L
.67419 .37229 L
.69574 .37261 L
.73561 .37305 L
.7554 .37322 L
.77641 .37336 L
.81418 .37359 L
.85441 .37379 L
.89311 .37397 L
.93427 .37415 L
.97392 .37433 L
.97619 .37434 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.06244 .2383 L
.08255 .36397 L
.10458 .48495 L
.11448 .53067 L
.11992 .55253 L
.12507 .57044 L
.12986 .58417 L
.13238 .59001 L
.13506 .59498 L
.13731 .59806 L
.13859 .5993 L
.13979 .6001 L
.14089 .60051 L
.14189 .60058 L
.14305 .6003 L
.14415 .59963 L
.1454 .59839 L
.1461 .59744 L
.14674 .5964 L
.1479 .5941 L
.14918 .59091 L
.1514 .58354 L
.15374 .57292 L
.15629 .55757 L
.15902 .5362 L
.16396 .48416 L
.16859 .4239 L
.17113 .39103 L
.17351 .36362 L
.1757 .34296 L
.17771 .32842 L
.1788 .3223 L
.17994 .31711 L
.18109 .3131 L
.18234 .30999 L
.18303 .30879 L
.18368 .30796 L
.18489 .30712 L
.1862 .30716 L
.18694 .30755 L
.18761 .30812 L
.18875 .30949 L
.19 .31151 L
.19252 .31694 L
.19824 .33352 L
.20358 .35173 L
.22371 .42177 L
.22868 .43707 L
.23411 .45178 L
Mistroke
.2366 .45756 L
.23924 .46286 L
.24173 .46687 L
.24281 .46823 L
.24399 .46944 L
.24516 .47031 L
.24639 .47083 L
.24752 .47091 L
.24858 .47061 L
.24984 .46974 L
.25098 .46844 L
.2523 .46629 L
.25354 .46361 L
.25578 .4573 L
.25785 .44997 L
.26253 .42985 L
.27154 .38735 L
.28123 .34882 L
.28679 .33288 L
.28922 .32739 L
.29187 .3224 L
.29423 .31879 L
.29674 .31574 L
.29812 .31438 L
.29939 .31333 L
.30066 .31245 L
.30185 .31178 L
.30306 .31123 L
.30417 .31084 L
.30539 .31053 L
.30671 .31034 L
.30798 .31027 L
.30869 .31028 L
.30935 .31032 L
.31057 .31046 L
.31186 .3107 L
.31294 .31097 L
.31411 .31133 L
.31623 .31212 L
.32107 .31448 L
.33101 .32053 L
.34188 .32689 L
.34689 .32926 L
.35225 .33127 L
.35485 .33205 L
.3573 .33267 L
.35949 .33312 L
.3619 .33353 L
.36445 .33387 L
.36576 .334 L
Mistroke
.36716 .33412 L
.36847 .33421 L
.36967 .33427 L
.37087 .33432 L
.37202 .33435 L
.37333 .33438 L
.37407 .33438 L
.37474 .33439 L
.37604 .33439 L
.37726 .33437 L
.37796 .33436 L
.3787 .33435 L
.38002 .33432 L
.38299 .33424 L
.38786 .33408 L
.39026 .33401 L
.39248 .33396 L
.39371 .33394 L
.39503 .33392 L
.39634 .33391 L
.39709 .3339 L
.3978 .3339 L
.39901 .3339 L
.40013 .33391 L
.40135 .33393 L
.40264 .33395 L
.40379 .33398 L
.40484 .33402 L
.40718 .33411 L
.40935 .33422 L
.4114 .33435 L
.416 .33472 L
.42098 .33522 L
.44048 .33788 L
.46192 .34095 L
.48229 .3432 L
.50134 .34472 L
.54019 .34705 L
.55995 .34806 L
.58148 .34901 L
.62126 .35031 L
.64099 .35079 L
.66198 .3512 L
.68201 .35153 L
.70364 .35182 L
.74378 .35223 L
.78485 .35254 L
.82441 .35279 L
.86245 .35302 L
.90295 .35325 L
Mistroke
.94193 .35347 L
.97619 .35366 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.06244 .23823 L
.08255 .36391 L
.10458 .48494 L
.11448 .53072 L
.11992 .55262 L
.12507 .5706 L
.12986 .58441 L
.13238 .59032 L
.13506 .59538 L
.13731 .59853 L
.13859 .59983 L
.13979 .60069 L
.14089 .60116 L
.14189 .6013 L
.14305 .60109 L
.14415 .60051 L
.1454 .59937 L
.1461 .59849 L
.14674 .59751 L
.1479 .59535 L
.14918 .59232 L
.1514 .58529 L
.15374 .57512 L
.15629 .56041 L
.15902 .53995 L
.16396 .49016 L
.16859 .43227 L
.17351 .37336 L
.17553 .35412 L
.17771 .33784 L
.17896 .33065 L
.1801 .32536 L
.18119 .32138 L
.18234 .31826 L
.18356 .31603 L
.18486 .31473 L
.18609 .3144 L
.1872 .31475 L
.18852 .31586 L
.18925 .31678 L
.18994 .31779 L
.19252 .3228 L
.19789 .33738 L
.20358 .35593 L
.22371 .42451 L
.23314 .45201 L
.23586 .45868 L
.23844 .46425 L
.24078 .46853 L
Mistroke
.24207 .47051 L
.24328 .47208 L
.24443 .47329 L
.24567 .47425 L
.24679 .47479 L
.24783 .47496 L
.2488 .47481 L
.24988 .47428 L
.251 .4733 L
.25204 .47195 L
.25328 .4698 L
.25446 .46722 L
.25665 .46103 L
.26159 .44205 L
.27038 .40148 L
.27985 .36247 L
.28527 .34555 L
.28764 .33956 L
.29024 .33397 L
.29498 .32622 L
.29757 .32324 L
.29997 .32117 L
.30122 .32035 L
.30256 .31963 L
.30383 .31911 L
.305 .31876 L
.30606 .31854 L
.30722 .3184 L
.30843 .31836 L
.30956 .31841 L
.31019 .31848 L
.31088 .31858 L
.31214 .31883 L
.31336 .31915 L
.31449 .31952 L
.31979 .32191 L
.33063 .32874 L
.34081 .33534 L
.34978 .34003 L
.35482 .34202 L
.35945 .34343 L
.36424 .34448 L
.36695 .34491 L
.36948 .34523 L
.37215 .34547 L
.37458 .34563 L
.37593 .3457 L
.37739 .34576 L
.37877 .3458 L
.38004 .34582 L
Mistroke
.38129 .34584 L
.38248 .34585 L
.38354 .34586 L
.38471 .34586 L
.38597 .34586 L
.38667 .34586 L
.38731 .34586 L
.38857 .34586 L
.38972 .34585 L
.39081 .34585 L
.39196 .34585 L
.39312 .34585 L
.39439 .34586 L
.39549 .34586 L
.39666 .34587 L
.39777 .34589 L
.39878 .34591 L
.40006 .34593 L
.40142 .34597 L
.40386 .34605 L
.40648 .34616 L
.40938 .34633 L
.41456 .34672 L
.41941 .34719 L
.43961 .34993 L
.45812 .35271 L
.47866 .35524 L
.49777 .35695 L
.53589 .35939 L
.57496 .36136 L
.59489 .36215 L
.61648 .36284 L
.65648 .36378 L
.67637 .36412 L
.69742 .36443 L
.73532 .36484 L
.77568 .36516 L
.81453 .3654 L
.85582 .36562 L
.89561 .36582 L
.93387 .36601 L
.97459 .36622 L
.97619 .36622 L
Mfstroke
1 0 .545 r
.02381 .01472 m
.06244 .23835 L
.08255 .36404 L
.10458 .48498 L
.11448 .53066 L
.11992 .55248 L
.12507 .57034 L
.12986 .58398 L
.13238 .58978 L
.13506 .59468 L
.13614 .59626 L
.13731 .59768 L
.13859 .59888 L
.13979 .59963 L
.14096 .6 L
.14207 .59998 L
.14306 .59965 L
.14415 .59893 L
.1448 .5983 L
.14548 .59748 L
.1467 .59556 L
.14802 .59282 L
.14946 .58892 L
.15205 .57936 L
.15447 .56702 L
.15683 .55132 L
.15898 .53355 L
.16382 .48116 L
.16911 .41057 L
.172 .37341 L
.17472 .34442 L
.17702 .32584 L
.17832 .31792 L
.17951 .31216 L
.18074 .30761 L
.18144 .30562 L
.18209 .30413 L
.1834 .30205 L
.18413 .3014 L
.1848 .30109 L
.18599 .30115 L
.18725 .30197 L
.18832 .3032 L
.18951 .30504 L
.19215 .31062 L
.19461 .31723 L
.20388 .34833 L
.21453 .38743 L
.22464 .42253 L
.23435 .45105 L
Mistroke
.23701 .45739 L
.23984 .46315 L
.24122 .4655 L
.24251 .4674 L
.24366 .4688 L
.24493 .47 L
.2461 .47075 L
.24719 .47111 L
.24834 .47109 L
.24957 .47059 L
.25072 .46962 L
.25181 .46826 L
.25278 .46663 L
.25384 .46445 L
.25627 .45788 L
.25884 .44885 L
.26347 .42926 L
.27309 .38526 L
.27833 .36376 L
.2832 .34686 L
.28773 .33419 L
.29184 .32525 L
.2964 .31798 L
.29891 .31507 L
.30127 .31294 L
.30362 .31137 L
.30481 .31077 L
.30612 .31023 L
.30723 .30988 L
.30842 .30961 L
.30955 .30943 L
.31058 .30934 L
.31186 .30931 L
.31305 .30936 L
.31436 .30949 L
.31502 .30958 L
.31575 .30971 L
.31828 .31029 L
.32065 .311 L
.33082 .31498 L
.33636 .31717 L
.34152 .31891 L
.34618 .32011 L
.34878 .32061 L
.35115 .32096 L
.3525 .32111 L
.35375 .32122 L
.35511 .32131 L
.3558 .32134 L
.35656 .32136 L
Mistroke
.35784 .32138 L
.35855 .32138 L
.35921 .32138 L
.36048 .32134 L
.36168 .32129 L
.36285 .32122 L
.3639 .32114 L
.36627 .32092 L
.37053 .32038 L
.38018 .3188 L
.38955 .31728 L
.39427 .31666 L
.39944 .31615 L
.40215 .31596 L
.40364 .31588 L
.40505 .31582 L
.40637 .31578 L
.40706 .31576 L
.40779 .31574 L
.40909 .31572 L
.41029 .31571 L
.41147 .31572 L
.41274 .31573 L
.41394 .31575 L
.41503 .31578 L
.41625 .31582 L
.41758 .31587 L
.42027 .316 L
.42556 .31636 L
.43055 .31679 L
.43989 .31775 L
.46085 .31994 L
.47058 .32078 L
.48088 .32152 L
.49933 .32255 L
.53724 .32423 L
.5776 .32583 L
.61644 .32694 L
.65774 .32778 L
.69752 .32838 L
.73579 .32884 L
.7765 .32925 L
.81571 .32961 L
.85736 .32999 L
.8975 .33035 L
.93612 .33069 L
.97619 .33105 L
Mfstroke
1 0 .522 r
.02381 .01472 m
.06244 .23839 L
.08255 .3641 L
.10458 .48502 L
.11448 .53066 L
.11992 .55244 L
.12507 .57025 L
.12986 .58384 L
.13238 .58959 L
.13506 .59443 L
.13614 .59599 L
.13731 .59737 L
.13859 .59853 L
.13979 .59924 L
.14096 .59956 L
.14207 .59949 L
.14306 .59912 L
.14415 .59833 L
.1448 .59767 L
.14548 .5968 L
.1467 .5948 L
.14802 .59195 L
.14946 .58792 L
.15205 .57807 L
.15447 .56538 L
.15683 .54925 L
.15898 .53099 L
.16382 .47723 L
.16911 .40515 L
.172 .36755 L
.17472 .33849 L
.17702 .32006 L
.17832 .31227 L
.17951 .30665 L
.18074 .30226 L
.18144 .30035 L
.18209 .29893 L
.1834 .297 L
.18413 .29642 L
.1848 .29618 L
.18599 .29634 L
.18725 .29726 L
.18832 .29856 L
.18951 .30047 L
.19215 .30619 L
.19461 .31294 L
.20388 .34471 L
.21453 .38505 L
.22464 .42152 L
.23435 .45153 L
Mistroke
.23701 .45836 L
.23984 .46473 L
.24229 .46931 L
.24357 .47131 L
.24493 .47307 L
.24618 .47433 L
.24688 .47488 L
.24754 .47528 L
.2487 .47569 L
.24994 .47569 L
.25121 .47518 L
.25241 .4742 L
.25349 .47288 L
.25466 .47099 L
.25688 .46611 L
.25924 .45931 L
.26347 .44416 L
.27309 .40473 L
.2832 .36771 L
.28738 .35562 L
.29184 .3451 L
.29673 .33632 L
.30127 .33051 L
.30378 .32814 L
.3065 .32618 L
.30775 .32547 L
.30907 .32483 L
.31021 .32436 L
.31143 .32395 L
.31262 .32363 L
.3137 .3234 L
.31479 .32322 L
.31583 .32309 L
.31703 .323 L
.31814 .32296 L
.31936 .32296 L
.32065 .323 L
.32194 .32308 L
.32311 .32319 L
.32577 .3235 L
.33057 .32421 L
.33586 .32498 L
.33739 .32517 L
.33883 .32532 L
.34014 .32543 L
.34152 .32553 L
.34269 .32559 L
.34397 .32564 L
.34513 .32565 L
.34622 .32565 L
Mistroke
.3475 .32562 L
.34867 .32556 L
.34932 .32552 L
.35003 .32547 L
.35131 .32535 L
.3536 .32507 L
.35604 .32468 L
.36043 .32375 L
.37128 .3205 L
.38112 .31708 L
.39049 .31405 L
.40038 .31155 L
.40555 .31058 L
.40829 .31016 L
.41123 .30979 L
.41393 .30951 L
.41639 .3093 L
.41868 .30914 L
.4212 .309 L
.4224 .30895 L
.42369 .3089 L
.4248 .30887 L
.42602 .30884 L
.42732 .30882 L
.42802 .30881 L
.42868 .3088 L
.42986 .30879 L
.43113 .30879 L
.43231 .30879 L
.4336 .3088 L
.43482 .30881 L
.43594 .30882 L
.43806 .30885 L
.4403 .30889 L
.45032 .30915 L
.46107 .30943 L
.46632 .30954 L
.47131 .30962 L
.47578 .30968 L
.48066 .30973 L
.48526 .30976 L
.49016 .30979 L
.49898 .30982 L
.504 .30984 L
.5093 .30987 L
.51511 .30991 L
.52044 .30995 L
.53008 .31006 L
.54063 .31021 L
.58113 .31092 L
Mistroke
.62011 .3115 L
.66154 .31206 L
.70146 .31258 L
.73986 .31307 L
.78071 .3136 L
.82005 .31412 L
.85787 .31463 L
.89815 .31518 L
.93691 .3157 L
.97619 .31623 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.06244 .23832 L
.08255 .36401 L
.10458 .48497 L
.11448 .53067 L
.11992 .55251 L
.12507 .5704 L
.12986 .58408 L
.13238 .5899 L
.13506 .59484 L
.13731 .59788 L
.13859 .5991 L
.13979 .59988 L
.14089 .60026 L
.14189 .60031 L
.14305 .6 L
.14415 .5993 L
.1454 .59801 L
.1461 .59704 L
.14674 .59597 L
.1479 .59363 L
.14918 .59038 L
.1514 .58288 L
.15374 .5721 L
.15629 .55652 L
.15902 .53487 L
.16396 .48218 L
.16859 .42134 L
.17113 .38826 L
.17351 .36077 L
.1757 .34012 L
.17771 .32564 L
.1788 .31957 L
.17994 .31444 L
.18109 .31049 L
.18234 .30744 L
.18303 .30627 L
.18368 .30547 L
.18489 .30468 L
.1862 .30475 L
.18694 .30517 L
.18761 .30576 L
.18875 .30715 L
.19 .3092 L
.19252 .31467 L
.19824 .33137 L
.20358 .34978 L
.22371 .421 L
.22868 .43664 L
.23411 .45173 L
Mistroke
.2366 .45772 L
.23924 .46327 L
.24172 .46751 L
.2428 .46903 L
.24399 .47041 L
.24517 .47146 L
.2464 .47219 L
.24705 .4724 L
.24775 .47249 L
.24901 .47226 L
.25027 .47147 L
.25147 .47018 L
.25255 .46855 L
.25372 .46627 L
.25594 .46051 L
.2583 .4526 L
.26253 .43518 L
.27215 .39095 L
.27739 .36885 L
.28226 .35131 L
.28679 .33806 L
.2909 .32863 L
.29546 .32092 L
.29797 .31781 L
.30033 .31553 L
.30269 .31384 L
.30387 .31318 L
.30518 .31261 L
.30629 .31222 L
.30749 .31192 L
.30861 .31172 L
.30964 .31162 L
.31093 .31158 L
.31212 .31163 L
.31342 .31177 L
.31408 .31187 L
.31481 .31201 L
.31734 .31264 L
.31972 .31343 L
.32988 .31795 L
.33542 .32056 L
.34059 .32274 L
.34563 .32449 L
.35021 .32569 L
.35283 .32619 L
.3553 .32655 L
.35666 .3267 L
.35791 .32681 L
.35929 .32691 L
.35998 .32694 L
Mistroke
.36075 .32697 L
.36198 .327 L
.36315 .32701 L
.3642 .327 L
.36535 .32697 L
.36659 .32693 L
.36792 .32686 L
.3703 .32669 L
.37499 .32624 L
.37924 .32575 L
.38861 .32463 L
.39373 .32413 L
.39623 .32393 L
.3985 .32379 L
.401 .32366 L
.40238 .32361 L
.40368 .32358 L
.40436 .32356 L
.40509 .32355 L
.4064 .32353 L
.40712 .32353 L
.4078 .32353 L
.40855 .32354 L
.40935 .32355 L
.41056 .32357 L
.41125 .32358 L
.41189 .3236 L
.41456 .3237 L
.41687 .32381 L
.41933 .32397 L
.42958 .32489 L
.44069 .32618 L
.46085 .32856 L
.48074 .33037 L
.49076 .33107 L
.50179 .33172 L
.54215 .33371 L
.58099 .33532 L
.60218 .336 L
.62229 .33652 L
.66055 .33729 L
.70127 .3379 L
.74047 .33833 L
.78212 .33871 L
.82226 .33904 L
.86089 .33934 L
.90196 .33965 L
.94152 .33996 L
.97619 .34023 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.06244 .23829 L
.08255 .36397 L
.10458 .48496 L
.11448 .53069 L
.11992 .55255 L
.12507 .57047 L
.12986 .5842 L
.13238 .59005 L
.13506 .59503 L
.13731 .59811 L
.13859 .59936 L
.13979 .60016 L
.14089 .60058 L
.14189 .60066 L
.14305 .60038 L
.14415 .59973 L
.1454 .59849 L
.1461 .59755 L
.14674 .59652 L
.1479 .59423 L
.14918 .59106 L
.1514 .58373 L
.15374 .57317 L
.15629 .55791 L
.15902 .5367 L
.16396 .4851 L
.16859 .4254 L
.17113 .39278 L
.17351 .36549 L
.1757 .34485 L
.17771 .33025 L
.17877 .32419 L
.17994 .31883 L
.18111 .31468 L
.18234 .31155 L
.18303 .3103 L
.18368 .30943 L
.18489 .3085 L
.1862 .30844 L
.18694 .30878 L
.18761 .3093 L
.18875 .31059 L
.19 .31252 L
.19252 .31778 L
.19824 .33407 L
.20358 .35214 L
.22371 .42254 L
.22868 .4381 L
.23411 .45318 L
Mistroke
.2366 .45919 L
.23924 .46479 L
.24172 .46912 L
.24399 .47213 L
.24517 .47325 L
.2464 .47406 L
.24764 .47446 L
.24835 .47448 L
.24901 .47435 L
.2502 .47376 L
.25128 .47277 L
.25254 .47109 L
.25372 .46894 L
.25592 .46357 L
.25794 .45715 L
.26253 .43891 L
.2723 .39431 L
.27743 .3727 L
.28282 .3534 L
.28757 .33985 L
.29008 .33403 L
.29275 .32881 L
.29523 .32485 L
.29747 .32193 L
.29956 .31974 L
.30185 .31788 L
.30421 .3165 L
.3055 .31596 L
.30671 .31557 L
.30784 .31531 L
.30887 .31516 L
.31006 .31507 L
.31119 .31506 L
.31241 .31514 L
.31371 .3153 L
.31481 .31551 L
.31603 .3158 L
.31875 .31664 L
.32131 .31764 L
.33965 .32656 L
.34473 .32861 L
.34947 .33013 L
.35205 .33078 L
.3544 .33126 L
.35702 .33169 L
.35837 .33186 L
.35981 .332 L
.36094 .3321 L
.36218 .33218 L
.36331 .33223 L
Mistroke
.36437 .33226 L
.36562 .33228 L
.36676 .33228 L
.36807 .33226 L
.36932 .33223 L
.3704 .33219 L
.37155 .33213 L
.37362 .33201 L
.37831 .33163 L
.3886 .33066 L
.39142 .33042 L
.3944 .3302 L
.39697 .33005 L
.39839 .32998 L
.39973 .32993 L
.40098 .32988 L
.40164 .32987 L
.40234 .32985 L
.40357 .32983 L
.40471 .32982 L
.40585 .32981 L
.40692 .32982 L
.40809 .32983 L
.40935 .32985 L
.41064 .32988 L
.41204 .32993 L
.41486 .33006 L
.41748 .33021 L
.41991 .33039 L
.43044 .33142 L
.44038 .33264 L
.45897 .33497 L
.479 .33697 L
.49746 .33829 L
.53688 .34039 L
.57479 .34207 L
.59588 .34281 L
.61515 .34337 L
.65399 .34421 L
.69377 .34484 L
.73204 .34528 L
.77276 .34565 L
.81196 .34596 L
.85361 .34626 L
.89375 .34655 L
.93237 .34682 L
.97345 .34712 L
.97619 .34714 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.06244 .23837 L
.08255 .36409 L
.10458 .48502 L
.11448 .53068 L
.11992 .55247 L
.12507 .5703 L
.12986 .5839 L
.13238 .58967 L
.13506 .59453 L
.13614 .59609 L
.13731 .59749 L
.13859 .59865 L
.13979 .59937 L
.14096 .5997 L
.14207 .59966 L
.14306 .59929 L
.14415 .59852 L
.1448 .59787 L
.14548 .59702 L
.1467 .59504 L
.14802 .59222 L
.14946 .58823 L
.15205 .57846 L
.15447 .56588 L
.15683 .54989 L
.15898 .53179 L
.16382 .47852 L
.16911 .40699 L
.172 .36951 L
.17472 .3404 L
.17702 .32184 L
.17832 .31395 L
.17951 .30824 L
.18074 .30374 L
.18144 .30177 L
.18209 .3003 L
.1834 .29826 L
.18413 .29762 L
.1848 .29733 L
.18599 .2974 L
.18725 .29822 L
.18832 .29945 L
.18951 .30129 L
.19215 .30686 L
.19461 .31349 L
.20388 .34508 L
.22464 .42261 L
.22962 .43919 L
.23505 .45534 L
Mistroke
.23984 .46729 L
.24246 .47263 L
.24493 .47664 L
.24611 .47816 L
.24736 .47944 L
.24801 .47996 L
.24872 .48041 L
.24998 .48088 L
.25112 .48091 L
.25234 .48051 L
.2535 .47969 L
.25455 .47857 L
.25569 .47694 L
.25674 .47506 L
.25913 .46962 L
.26347 .45645 L
.27324 .42028 L
.28376 .38402 L
.2886 .37072 L
.29369 .35953 L
.29804 .35219 L
.30279 .3463 L
.30534 .34394 L
.30776 .34217 L
.30992 .34092 L
.31227 .33988 L
.31483 .33908 L
.31612 .33878 L
.31753 .33853 L
.31874 .33837 L
.32004 .33825 L
.32126 .33818 L
.32238 .33815 L
.32351 .33814 L
.3247 .33816 L
.32573 .33819 L
.32686 .33824 L
.32937 .3384 L
.33173 .33857 L
.33394 .33873 L
.33632 .33888 L
.33747 .33894 L
.33855 .33899 L
.33953 .33902 L
.34059 .33905 L
.34177 .33906 L
.34302 .33905 L
.3441 .33903 L
.34527 .33898 L
.34655 .33891 L
Mistroke
.34792 .33881 L
.3504 .33854 L
.35317 .33813 L
.35581 .33762 L
.36075 .3364 L
.36959 .33349 L
.37924 .32976 L
.38938 .32593 L
.39893 .32289 L
.40422 .32154 L
.40994 .32034 L
.41513 .31949 L
.41991 .31888 L
.42461 .31843 L
.42965 .31807 L
.43441 .31783 L
.43875 .31768 L
.44383 .31755 L
.44936 .31745 L
.45942 .3173 L
.47921 .31694 L
.50022 .31644 L
.5096 .31624 L
.51452 .31615 L
.5197 .31607 L
.52426 .31602 L
.52924 .31597 L
.53378 .31593 L
.53799 .31591 L
.54062 .3159 L
.54304 .31589 L
.54431 .31589 L
.54571 .31589 L
.54641 .31589 L
.54716 .31589 L
.54787 .31589 L
.54852 .31588 L
.5498 .31588 L
.55047 .31588 L
.55119 .31588 L
.55187 .31588 L
.55252 .31588 L
.55372 .31588 L
.55491 .31589 L
.556 .31589 L
.55846 .31589 L
.5607 .31589 L
.56278 .3159 L
.56751 .31591 L
.57705 .31594 L
Mistroke
.61603 .3161 L
.63733 .31621 L
.65747 .31635 L
.69587 .31668 L
.73672 .3171 L
.77606 .31755 L
.81388 .31803 L
.85416 .31856 L
.89292 .31909 L
.93413 .31966 L
.97383 .32019 L
.97619 .32022 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.06244 .23827 L
.08255 .36395 L
.10458 .48495 L
.11448 .5307 L
.11992 .55257 L
.12507 .57051 L
.12986 .58427 L
.13238 .59014 L
.13506 .59514 L
.13731 .59825 L
.13859 .59951 L
.13979 .60034 L
.14089 .60077 L
.14189 .60087 L
.14305 .60062 L
.14415 .59999 L
.1454 .59878 L
.1461 .59786 L
.14674 .59685 L
.1479 .59461 L
.14918 .59149 L
.1514 .58426 L
.15374 .57384 L
.15629 .55878 L
.15902 .53783 L
.16396 .4869 L
.16859 .42789 L
.17113 .39555 L
.17351 .36842 L
.1757 .3478 L
.17771 .33315 L
.17877 .32705 L
.17994 .32163 L
.18111 .31742 L
.18234 .31422 L
.18303 .31293 L
.18368 .31202 L
.18489 .31103 L
.1862 .3109 L
.18694 .31121 L
.18761 .3117 L
.18875 .31293 L
.19 .31482 L
.19252 .31998 L
.19824 .33606 L
.20358 .35392 L
.22371 .42359 L
.22868 .43904 L
.23411 .45403 L
Mistroke
.2366 .46001 L
.23924 .46559 L
.24172 .4699 L
.24399 .47291 L
.24517 .47403 L
.2464 .47485 L
.24764 .47525 L
.24835 .47528 L
.24901 .47516 L
.2502 .47458 L
.25128 .47361 L
.25254 .47195 L
.25372 .46982 L
.25592 .46449 L
.25794 .4581 L
.26253 .43989 L
.2723 .39519 L
.27743 .37356 L
.28282 .35429 L
.28757 .34082 L
.29008 .33505 L
.29275 .32989 L
.29523 .326 L
.29747 .32313 L
.29972 .32086 L
.30185 .31922 L
.30404 .318 L
.30528 .3175 L
.30644 .31714 L
.30767 .31689 L
.30878 .31675 L
.31008 .31669 L
.3113 .31674 L
.31235 .31685 L
.31346 .31703 L
.31441 .31723 L
.31546 .3175 L
.32 .31914 L
.32487 .32152 L
.33013 .32442 L
.33965 .32958 L
.34427 .33172 L
.34921 .33362 L
.35204 .33451 L
.35462 .33518 L
.35707 .33571 L
.35967 .33615 L
.36096 .33633 L
.36237 .3365 L
.36368 .33662 L
Mistroke
.36487 .33671 L
.36627 .3368 L
.36705 .33683 L
.36778 .33686 L
.36909 .33689 L
.36983 .3369 L
.37051 .33691 L
.37116 .33691 L
.37185 .3369 L
.37311 .33688 L
.37434 .33685 L
.37547 .33682 L
.37804 .33671 L
.38076 .33656 L
.39025 .33598 L
.39298 .33584 L
.39556 .33574 L
.39789 .33566 L
.3992 .33563 L
.40041 .33561 L
.40146 .3356 L
.40259 .3356 L
.40366 .3356 L
.40464 .33561 L
.40573 .33562 L
.40691 .33564 L
.40815 .33568 L
.40931 .33571 L
.4117 .33582 L
.41387 .33594 L
.41875 .33629 L
.42361 .33675 L
.42874 .33733 L
.43795 .33852 L
.45875 .34133 L
.47834 .34347 L
.49666 .34492 L
.5355 .34717 L
.5768 .3491 L
.59745 .34985 L
.61658 .35041 L
.65485 .35127 L
.69405 .35189 L
.7357 .35236 L
.77584 .3527 L
.81446 .35297 L
.85554 .35324 L
.8951 .3535 L
.93314 .35374 L
.97364 .354 L
Mistroke
.97619 .35401 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.06244 .2383 L
.08255 .364 L
.10458 .48499 L
.11448 .53071 L
.11992 .55256 L
.12507 .57047 L
.12986 .58418 L
.13238 .59002 L
.13506 .59498 L
.13731 .59805 L
.13859 .59928 L
.13979 .60008 L
.14089 .60048 L
.14189 .60055 L
.14305 .60026 L
.14415 .59959 L
.1454 .59833 L
.1461 .59738 L
.14674 .59633 L
.1479 .59403 L
.14918 .59083 L
.1514 .58345 L
.15374 .57283 L
.15629 .55749 L
.15902 .53617 L
.16396 .4844 L
.16859 .42454 L
.17113 .39184 L
.17351 .36446 L
.1757 .34372 L
.17771 .32902 L
.17877 .32291 L
.17994 .31749 L
.18111 .31328 L
.18234 .31008 L
.18303 .3088 L
.18368 .30788 L
.18489 .30688 L
.1862 .30674 L
.18694 .30703 L
.18761 .30751 L
.18875 .30873 L
.19 .31059 L
.19252 .31572 L
.19824 .33187 L
.20358 .35001 L
.22371 .42176 L
.22868 .43776 L
.23411 .45338 L
Mistroke
.2389 .4649 L
.24152 .46999 L
.24281 .47209 L
.24399 .47375 L
.24515 .47511 L
.24642 .47624 L
.24769 .47698 L
.24839 .4772 L
.24904 .47727 L
.2502 .47707 L
.25125 .47651 L
.25246 .47538 L
.25361 .47382 L
.25469 .47191 L
.25583 .46943 L
.25789 .46387 L
.26253 .44723 L
.27215 .40563 L
.28226 .36618 L
.28644 .35337 L
.2909 .34231 L
.29346 .33716 L
.29579 .33321 L
.30033 .32734 L
.30283 .32505 L
.30512 .32346 L
.30764 .32221 L
.30892 .32177 L
.30963 .32156 L
.31031 .3214 L
.31154 .32118 L
.31266 .32105 L
.31386 .32099 L
.31517 .321 L
.31632 .32107 L
.31753 .3212 L
.31857 .32135 L
.31972 .32156 L
.32489 .3229 L
.33048 .32473 L
.33571 .32647 L
.34059 .3279 L
.34521 .32896 L
.34779 .3294 L
.35014 .3297 L
.35149 .32982 L
.35272 .32991 L
.35337 .32994 L
.35408 .32997 L
.35483 .32999 L
Mistroke
.35552 .33 L
.3568 .33 L
.35797 .32998 L
.35862 .32996 L
.35932 .32992 L
.3606 .32985 L
.36204 .32973 L
.36338 .3296 L
.3659 .32928 L
.37154 .32836 L
.3817 .32628 L
.39147 .32435 L
.39681 .32351 L
.40179 .3229 L
.40604 .32253 L
.40843 .32238 L
.4106 .32228 L
.41184 .32224 L
.41298 .32221 L
.41423 .32218 L
.41487 .32217 L
.41556 .32217 L
.41673 .32217 L
.41799 .32217 L
.41918 .32219 L
.42027 .32221 L
.42155 .32224 L
.42275 .32228 L
.42501 .32237 L
.43008 .32264 L
.4392 .3233 L
.45991 .32501 L
.46964 .32569 L
.47994 .32628 L
.4984 .32707 L
.5363 .32837 L
.57666 .32971 L
.61551 .33068 L
.6568 .33144 L
.69658 .33201 L
.73485 .33248 L
.77557 .33291 L
.81477 .33331 L
.85642 .33373 L
.89656 .33413 L
.93519 .33452 L
.97619 .33492 L
Mfstroke
1 0 .379 r
.02381 .01472 m
.06244 .23807 L
.08255 .36377 L
.10458 .48492 L
.11448 .53082 L
.11992 .55283 L
.12507 .57095 L
.12986 .58495 L
.13238 .59099 L
.13506 .59621 L
.13731 .59954 L
.13859 .60095 L
.13979 .60193 L
.14089 .60252 L
.14189 .60278 L
.14305 .60273 L
.14415 .60231 L
.1454 .60138 L
.1461 .60063 L
.14674 .59978 L
.14793 .59783 L
.14918 .59516 L
.15135 .58893 L
.15374 .5795 L
.15629 .56603 L
.15902 .5473 L
.16396 .50173 L
.16859 .44826 L
.17351 .39188 L
.17553 .37258 L
.17771 .35565 L
.17896 .34789 L
.1801 .342 L
.18119 .33745 L
.18234 .33363 L
.18357 .33068 L
.18471 .32884 L
.18541 .32811 L
.18607 .32767 L
.1873 .32744 L
.1886 .32795 L
.1898 .329 L
.19112 .33072 L
.19252 .33308 L
.19779 .34555 L
.20358 .36299 L
.22371 .42927 L
.23368 .45832 L
.2386 .47002 L
.24099 .47476 L
Mistroke
.24315 .47834 L
.24437 .48 L
.24568 .48148 L
.24641 .48213 L
.24707 .48263 L
.24838 .48328 L
.2497 .48346 L
.25045 .48333 L
.25115 .48304 L
.25189 .48256 L
.25256 .48196 L
.25334 .48106 L
.25407 .48 L
.25656 .47493 L
.25885 .46831 L
.26405 .44822 L
.27382 .40436 L
.27895 .38354 L
.28434 .36527 L
.28908 .3527 L
.29159 .3474 L
.29427 .34272 L
.29674 .33926 L
.29898 .33677 L
.30124 .33486 L
.30336 .33354 L
.3045 .33302 L
.30555 .33264 L
.30671 .33233 L
.30796 .33213 L
.30926 .33204 L
.3105 .33206 L
.31161 .33217 L
.31281 .33237 L
.31385 .33261 L
.315 .33295 L
.31733 .33381 L
.32152 .33588 L
.34117 .34896 L
.35058 .35439 L
.35531 .35655 L
.36049 .35842 L
.36321 .35921 L
.36612 .35991 L
.36882 .36044 L
.37136 .36085 L
.37387 .36117 L
.37659 .36144 L
.37906 .36162 L
.38134 .36175 L
Mistroke
.39114 .36203 L
.39372 .36208 L
.39654 .36213 L
.40167 .36227 L
.40417 .36236 L
.40683 .36248 L
.41161 .36277 L
.41639 .36316 L
.42071 .36359 L
.44021 .36621 L
.45856 .369 L
.47696 .37137 L
.49713 .3733 L
.51709 .37473 L
.53816 .37598 L
.5786 .37802 L
.61753 .37941 L
.63879 .37996 L
.65891 .38039 L
.69726 .381 L
.71705 .38124 L
.73806 .38145 L
.77583 .38174 L
.81606 .38198 L
.85476 .38218 L
.89592 .38237 L
.93557 .38254 L
.9737 .38271 L
.97619 .38273 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.06244 .23829 L
.08255 .36401 L
.10458 .485 L
.11448 .53072 L
.11992 .55257 L
.12507 .57048 L
.12986 .58419 L
.13238 .59002 L
.13506 .59498 L
.13731 .59804 L
.13859 .59927 L
.13979 .60007 L
.14089 .60046 L
.14189 .60053 L
.14305 .60024 L
.14415 .59956 L
.1454 .5983 L
.1461 .59734 L
.14674 .59629 L
.1479 .59398 L
.14918 .59078 L
.1514 .58338 L
.15374 .57273 L
.15629 .55736 L
.15902 .536 L
.16396 .48413 L
.16859 .42415 L
.17113 .39137 L
.17351 .36391 L
.1757 .3431 L
.17771 .32835 L
.17877 .3222 L
.17994 .31675 L
.18111 .31251 L
.18234 .30927 L
.18303 .30796 L
.18368 .30703 L
.18489 .30599 L
.1862 .30581 L
.18694 .30608 L
.18761 .30654 L
.18875 .30773 L
.19 .30956 L
.19252 .31464 L
.19824 .33074 L
.20358 .34893 L
.22371 .42145 L
.22868 .43769 L
.23411 .45361 L
Mistroke
.2389 .46545 L
.24152 .47076 L
.24399 .47478 L
.24517 .47629 L
.24642 .47757 L
.24707 .4781 L
.24779 .47855 L
.24904 .47902 L
.25018 .47904 L
.25141 .47861 L
.25256 .47775 L
.25361 .47656 L
.25475 .47482 L
.25581 .4728 L
.25819 .46687 L
.26253 .45227 L
.2723 .41176 L
.27743 .39101 L
.28282 .37174 L
.28757 .35761 L
.29275 .3455 L
.29503 .34125 L
.29747 .33739 L
.30185 .3321 L
.3044 .32988 L
.30675 .32834 L
.30932 .32713 L
.31062 .32669 L
.31205 .32633 L
.3133 .3261 L
.31445 .32596 L
.31577 .32588 L
.31702 .32587 L
.31818 .32591 L
.31925 .32599 L
.32042 .32611 L
.32167 .32629 L
.32607 .32715 L
.33021 .32816 L
.3351 .32938 L
.33965 .33038 L
.34211 .33082 L
.34434 .33115 L
.34553 .33129 L
.34682 .33142 L
.34752 .33148 L
.34818 .33153 L
.34947 .3316 L
.3507 .33163 L
.35186 .33165 L
Mistroke
.35312 .33163 L
.35384 .33161 L
.35449 .33159 L
.35579 .33152 L
.35722 .33141 L
.35981 .33112 L
.36225 .33077 L
.36445 .33038 L
.3694 .32932 L
.37831 .32702 L
.38767 .32455 L
.39757 .32239 L
.40274 .32156 L
.40548 .3212 L
.40842 .32088 L
.41112 .32065 L
.41358 .32049 L
.41476 .32043 L
.41605 .32037 L
.41727 .32032 L
.41839 .32029 L
.41953 .32027 L
.42073 .32025 L
.42193 .32024 L
.42325 .32023 L
.42439 .32024 L
.42561 .32025 L
.42676 .32027 L
.4278 .32029 L
.43036 .32035 L
.43314 .32045 L
.43818 .32067 L
.45919 .32184 L
.46947 .32233 L
.47909 .32268 L
.48911 .32297 L
.50013 .32321 L
.53898 .32408 L
.58027 .32511 L
.62005 .32589 L
.65832 .32649 L
.69904 .32704 L
.73824 .32751 L
.77989 .32798 L
.82003 .32844 L
.85866 .32887 L
.89973 .32935 L
.93929 .3298 L
.97619 .33022 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.06244 .23812 L
.08255 .36381 L
.10458 .48492 L
.11448 .53079 L
.11992 .55277 L
.12507 .57085 L
.12986 .5848 L
.13238 .5908 L
.13506 .59597 L
.13731 .59925 L
.13859 .60063 L
.13979 .60158 L
.14089 .60213 L
.14189 .60236 L
.14305 .60227 L
.14415 .60181 L
.1454 .60082 L
.1461 .60003 L
.14674 .59915 L
.14793 .59712 L
.14918 .59437 L
.15135 .58797 L
.15374 .5783 L
.15629 .56451 L
.15902 .54532 L
.16396 .49867 L
.16859 .44409 L
.17351 .38711 L
.17553 .36785 L
.17771 .35112 L
.17896 .34353 L
.1801 .33781 L
.18119 .33343 L
.18234 .3298 L
.18357 .32705 L
.18471 .32539 L
.18541 .32477 L
.18607 .32443 L
.1873 .32438 L
.1886 .32506 L
.1898 .32628 L
.19112 .32815 L
.19252 .33067 L
.19779 .34362 L
.20358 .36143 L
.22371 .42833 L
.23368 .45742 L
.2386 .46906 L
.24099 .47374 L
Mistroke
.24315 .47725 L
.24437 .47886 L
.24568 .48027 L
.24641 .48088 L
.24707 .48134 L
.24838 .4819 L
.2497 .48197 L
.25045 .48178 L
.25115 .48143 L
.25189 .48088 L
.25256 .48021 L
.25407 .4781 L
.25535 .47565 L
.25653 .47286 L
.2592 .46482 L
.26405 .44568 L
.27382 .4018 L
.27895 .38099 L
.28434 .36274 L
.28908 .35018 L
.29159 .34488 L
.29427 .34021 L
.29674 .33674 L
.29898 .33424 L
.30124 .33232 L
.30336 .33099 L
.3045 .33047 L
.30555 .33008 L
.30671 .32977 L
.30796 .32955 L
.30926 .32945 L
.3105 .32946 L
.31161 .32956 L
.31281 .32975 L
.31385 .32998 L
.315 .3303 L
.31733 .33113 L
.32152 .33313 L
.34117 .34575 L
.35058 .35089 L
.35531 .35288 L
.36049 .35459 L
.36321 .35529 L
.36612 .35591 L
.36882 .35636 L
.37136 .3567 L
.37387 .35695 L
.37519 .35706 L
.37659 .35716 L
.37776 .35722 L
Mistroke
.37906 .35729 L
.38134 .35737 L
.39213 .3575 L
.39346 .3575 L
.39471 .35751 L
.39615 .35752 L
.39745 .35754 L
.39983 .35758 L
.40116 .35761 L
.40239 .35764 L
.40687 .35781 L
.40913 .35793 L
.4116 .35808 L
.4168 .35848 L
.42165 .35896 L
.44037 .36147 L
.46044 .36444 L
.48169 .367 L
.50182 .36873 L
.54017 .37111 L
.55957 .37213 L
.58097 .3731 L
.62026 .37445 L
.63962 .37493 L
.66048 .37537 L
.68014 .3757 L
.70164 .376 L
.74128 .37642 L
.78186 .37673 L
.82093 .37696 L
.86245 .37718 L
.90245 .37737 L
.94093 .37756 L
.97619 .37773 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.06244 .23822 L
.08255 .3639 L
.10458 .48494 L
.11448 .53073 L
.11992 .55264 L
.12507 .57063 L
.12986 .58445 L
.13238 .59037 L
.13506 .59544 L
.13731 .59861 L
.13859 .59992 L
.13979 .60079 L
.14089 .60126 L
.14189 .60141 L
.14305 .60122 L
.14415 .60065 L
.1454 .59953 L
.1461 .59866 L
.14674 .5977 L
.1479 .59555 L
.14918 .59256 L
.1514 .58559 L
.15374 .57552 L
.15629 .56096 L
.15902 .54071 L
.16396 .49151 L
.16859 .43433 L
.17351 .37593 L
.17553 .35675 L
.17771 .34046 L
.17896 .33323 L
.1801 .32789 L
.18119 .32387 L
.18234 .32069 L
.18356 .3184 L
.18486 .31704 L
.18609 .31664 L
.1872 .31694 L
.18852 .31798 L
.18925 .31886 L
.18994 .31984 L
.19252 .32472 L
.19789 .33907 L
.20358 .35743 L
.22371 .42593 L
.23314 .4538 L
.23834 .46624 L
.2409 .4712 L
.24328 .47489 L
Mistroke
.24442 .4763 L
.2455 .47737 L
.24674 .47826 L
.24786 .47872 L
.24911 .47882 L
.25026 .47847 L
.25152 .47757 L
.25215 .47691 L
.25285 .476 L
.25503 .47199 L
.25626 .46898 L
.25737 .46579 L
.26159 .45058 L
.27165 .40559 L
.27716 .38212 L
.28233 .36326 L
.28709 .34923 L
.29144 .3393 L
.29628 .33139 L
.29882 .32843 L
.3002 .32713 L
.30149 .3261 L
.30265 .32533 L
.3039 .32464 L
.30495 .32417 L
.30609 .32377 L
.30733 .32346 L
.30865 .32325 L
.30986 .32317 L
.311 .32319 L
.31214 .32328 L
.31323 .32344 L
.3142 .32364 L
.31526 .3239 L
.31764 .32467 L
.31983 .32557 L
.33017 .33119 L
.33987 .33687 L
.34884 .34117 L
.35388 .34298 L
.35851 .34422 L
.36099 .34473 L
.3633 .34511 L
.36583 .34543 L
.36854 .34568 L
.36991 .34576 L
.37062 .3458 L
.37139 .34584 L
.37205 .34586 L
.37278 .34588 L
Mistroke
.37407 .34591 L
.37533 .34593 L
.37603 .34593 L
.37667 .34593 L
.37792 .34592 L
.37911 .3459 L
.38035 .34588 L
.3817 .34584 L
.38414 .34576 L
.3887 .3456 L
.39129 .34551 L
.39403 .34543 L
.39636 .34538 L
.397 .34537 L
.39769 .34536 L
.39893 .34535 L
.40016 .34534 L
.4013 .34534 L
.40254 .34534 L
.40317 .34535 L
.40387 .34536 L
.40503 .34538 L
.40628 .34541 L
.40855 .34548 L
.41078 .34558 L
.41313 .34571 L
.41732 .34601 L
.42687 .34697 L
.43708 .34829 L
.45545 .35088 L
.47537 .35327 L
.49697 .35513 L
.51778 .35646 L
.53697 .35752 L
.57639 .35941 L
.6143 .36071 L
.63376 .3612 L
.65466 .36164 L
.67442 .36199 L
.69595 .3623 L
.73573 .36274 L
.77645 .36308 L
.81565 .36334 L
.85731 .36359 L
.89745 .36383 L
.93607 .36405 L
.97619 .36428 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.06244 .23821 L
.08255 .3639 L
.10458 .48495 L
.11448 .53074 L
.11992 .55266 L
.12507 .57066 L
.12986 .58449 L
.13238 .59041 L
.13506 .59549 L
.13731 .59866 L
.13859 .59997 L
.13979 .60085 L
.14089 .60133 L
.14189 .60148 L
.14305 .60129 L
.14415 .60073 L
.1454 .59962 L
.1461 .59875 L
.14674 .5978 L
.1479 .59566 L
.14918 .59267 L
.1514 .58573 L
.15374 .5757 L
.15629 .56118 L
.15902 .54101 L
.16396 .49201 L
.16859 .43505 L
.17351 .37675 L
.17553 .35754 L
.17771 .34117 L
.17896 .33389 L
.1801 .32849 L
.18119 .32441 L
.18234 .32118 L
.18356 .31882 L
.18486 .31738 L
.18609 .31692 L
.1872 .31716 L
.18852 .31814 L
.18925 .31898 L
.18994 .31992 L
.19252 .3247 L
.19508 .33091 L
.19789 .33889 L
.20358 .35719 L
.22371 .42606 L
.23368 .45572 L
.2386 .46754 L
.24099 .47228 L
Mistroke
.24315 .47584 L
.24437 .47748 L
.24568 .47891 L
.24641 .47953 L
.24707 .47999 L
.24838 .48057 L
.2497 .48066 L
.25045 .48046 L
.25115 .48012 L
.25189 .47957 L
.25256 .47891 L
.25407 .47681 L
.25535 .47439 L
.25653 .47163 L
.2592 .46371 L
.26405 .44491 L
.27382 .40145 L
.27895 .38049 L
.28434 .36182 L
.28908 .34875 L
.29159 .34315 L
.29427 .33814 L
.29674 .33435 L
.29898 .33156 L
.30124 .32934 L
.30336 .32774 L
.30555 .32653 L
.3068 .32604 L
.30796 .32569 L
.30918 .32543 L
.3103 .32528 L
.31159 .32521 L
.31281 .32524 L
.31386 .32534 L
.31498 .3255 L
.31593 .32568 L
.31698 .32593 L
.31932 .32664 L
.32152 .32746 L
.34117 .33718 L
.34625 .33932 L
.35098 .34092 L
.35592 .34216 L
.35853 .34264 L
.35998 .34286 L
.36132 .34303 L
.36371 .34326 L
.36497 .34334 L
.36562 .34338 L
.36631 .34341 L
Mistroke
.36746 .34345 L
.36855 .34347 L
.36983 .34348 L
.37101 .34347 L
.37213 .34345 L
.37317 .34343 L
.37431 .34339 L
.37553 .34333 L
.37982 .34307 L
.39012 .34229 L
.39294 .34209 L
.39592 .34192 L
.39846 .34179 L
.39989 .34174 L
.40125 .3417 L
.40251 .34167 L
.40323 .34165 L
.40389 .34164 L
.40505 .34163 L
.40629 .34163 L
.40692 .34163 L
.40761 .34163 L
.40885 .34165 L
.40957 .34166 L
.41033 .34168 L
.41169 .34172 L
.4141 .34181 L
.41634 .34192 L
.42142 .34227 L
.42648 .34272 L
.43196 .34331 L
.4419 .34453 L
.46049 .34686 L
.48038 .34886 L
.50143 .35035 L
.53934 .35235 L
.5797 .35411 L
.61854 .35532 L
.63973 .35581 L
.65984 .35619 L
.6981 .35677 L
.73882 .35723 L
.77802 .35757 L
.81967 .35788 L
.85981 .35816 L
.89844 .35842 L
.93951 .3587 L
.97619 .35895 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.06244 .23814 L
.08255 .36383 L
.10458 .48493 L
.11448 .53078 L
.11992 .55274 L
.12507 .5708 L
.12986 .58471 L
.13238 .59069 L
.13506 .59584 L
.13731 .5991 L
.13859 .60046 L
.13979 .60139 L
.14089 .60193 L
.14189 .60213 L
.14305 .60202 L
.14415 .60153 L
.1454 .60051 L
.1461 .59971 L
.14674 .59881 L
.14793 .59674 L
.14918 .59394 L
.15135 .58745 L
.15374 .57765 L
.15629 .56369 L
.15902 .54427 L
.16396 .49709 L
.16859 .442 L
.17351 .38478 L
.17553 .36556 L
.17771 .34895 L
.17896 .34144 L
.1801 .33581 L
.18119 .33152 L
.18234 .328 L
.18357 .32535 L
.18471 .32379 L
.18541 .32322 L
.18607 .32293 L
.1873 .32297 L
.1886 .32375 L
.1898 .32504 L
.19112 .327 L
.19252 .32959 L
.19779 .34277 L
.20358 .36077 L
.22371 .42814 L
.23368 .45744 L
.2386 .46919 L
.24099 .47393 L
Mistroke
.24315 .47751 L
.24437 .47917 L
.24568 .48063 L
.24641 .48127 L
.24707 .48176 L
.24838 .48238 L
.2497 .48253 L
.25045 .48238 L
.25115 .48208 L
.25189 .48158 L
.25256 .48095 L
.25334 .48003 L
.25407 .47896 L
.25656 .47387 L
.25885 .46728 L
.26405 .44743 L
.27382 .40387 L
.27895 .38293 L
.28434 .36438 L
.28908 .35149 L
.29159 .34601 L
.29427 .34113 L
.29674 .33747 L
.29898 .33481 L
.30124 .33272 L
.30336 .33125 L
.3045 .33064 L
.30555 .33018 L
.30671 .32979 L
.30796 .3295 L
.30926 .32931 L
.3105 .32925 L
.31161 .32928 L
.31281 .32939 L
.31385 .32956 L
.315 .32981 L
.31733 .33051 L
.32152 .33229 L
.33176 .3382 L
.34117 .34388 L
.35058 .34853 L
.35531 .35029 L
.36049 .35173 L
.36322 .35231 L
.36571 .35272 L
.36858 .35309 L
.36989 .35322 L
.37129 .35334 L
.37248 .35342 L
.37379 .35349 L
Mistroke
.37499 .35355 L
.37611 .35358 L
.37742 .35361 L
.37863 .35363 L
.37929 .35364 L
.38002 .35364 L
.38134 .35364 L
.38199 .35363 L
.38267 .35363 L
.38389 .35361 L
.38521 .35359 L
.38666 .35357 L
.39167 .35346 L
.394 .35342 L
.39529 .3534 L
.39651 .35339 L
.39764 .35338 L
.39887 .35338 L
.39999 .35338 L
.40103 .35338 L
.40223 .35339 L
.40352 .35341 L
.40474 .35343 L
.40586 .35346 L
.40846 .35355 L
.4112 .35368 L
.41636 .35401 L
.422 .35451 L
.43229 .35572 L
.44163 .35702 L
.46258 .35995 L
.48178 .36211 L
.50259 .36379 L
.54352 .36618 L
.58295 .36801 L
.62085 .36925 L
.64032 .36972 L
.66121 .37014 L
.68098 .37047 L
.70251 .37076 L
.74229 .37118 L
.78301 .3715 L
.82221 .37175 L
.86387 .37199 L
.904 .37221 L
.94263 .37242 L
.97619 .3726 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.06244 .23822 L
.08255 .3639 L
.10458 .48494 L
.11448 .53073 L
.11992 .55265 L
.12507 .57065 L
.12986 .58448 L
.13238 .5904 L
.13506 .59548 L
.13731 .59865 L
.13859 .59997 L
.13979 .60084 L
.14089 .60133 L
.14189 .60148 L
.14305 .6013 L
.14415 .60074 L
.1454 .59963 L
.1461 .59876 L
.14674 .59781 L
.1479 .59568 L
.14918 .5927 L
.1514 .58578 L
.15374 .57576 L
.15629 .56129 L
.15902 .54117 L
.16396 .49233 L
.16859 .43559 L
.17351 .37749 L
.17553 .35835 L
.17771 .34204 L
.17896 .33478 L
.1801 .32941 L
.18119 .32535 L
.18234 .32213 L
.18356 .31979 L
.18486 .31837 L
.18609 .31793 L
.1872 .31818 L
.18852 .31917 L
.18925 .32002 L
.18994 .32097 L
.19252 .32577 L
.19789 .33995 L
.20358 .35818 L
.22371 .42664 L
.23314 .4547 L
.23834 .46735 L
.2409 .47246 L
.24328 .47633 L
Mistroke
.24442 .47784 L
.2455 .47902 L
.24674 .48005 L
.24786 .48066 L
.24911 .48093 L
.25026 .48077 L
.25152 .4801 L
.25215 .47955 L
.25285 .47878 L
.25399 .47714 L
.25503 .47522 L
.25737 .4695 L
.26159 .45502 L
.27165 .41081 L
.27716 .38728 L
.28233 .36815 L
.28709 .35376 L
.29144 .34346 L
.29628 .33512 L
.29882 .33194 L
.30149 .3294 L
.30273 .32848 L
.3039 .32775 L
.30497 .3272 L
.30609 .32672 L
.30732 .32632 L
.30845 .32606 L
.30966 .32588 L
.31035 .32583 L
.311 .3258 L
.31214 .32582 L
.31323 .32592 L
.3142 .32605 L
.31526 .32626 L
.31764 .32689 L
.31983 .32768 L
.32955 .33249 L
.33987 .33816 L
.34923 .34232 L
.35449 .34401 L
.35699 .34463 L
.35932 .3451 L
.36154 .34547 L
.36357 .34574 L
.36581 .34596 L
.36705 .34605 L
.36822 .34612 L
.36935 .34618 L
.37055 .34621 L
.37158 .34623 L
Mistroke
.37271 .34624 L
.37393 .34624 L
.37523 .34623 L
.37646 .3462 L
.37759 .34617 L
.38009 .34607 L
.38236 .34597 L
.38745 .34569 L
.39221 .34544 L
.3943 .34534 L
.39659 .34525 L
.3978 .34522 L
.39909 .34518 L
.3998 .34517 L
.40045 .34515 L
.40172 .34514 L
.40243 .34513 L
.40309 .34513 L
.40381 .34513 L
.40457 .34513 L
.40585 .34514 L
.40658 .34515 L
.40727 .34516 L
.4085 .34519 L
.40979 .34522 L
.41211 .34531 L
.4146 .34544 L
.41732 .34561 L
.42261 .34605 L
.4276 .34656 L
.43694 .3477 L
.4579 .3505 L
.47623 .35256 L
.49639 .35421 L
.51628 .35544 L
.53733 .35656 L
.57768 .35841 L
.61653 .35969 L
.63772 .3602 L
.65783 .3606 L
.69609 .3612 L
.73681 .36165 L
.77601 .36198 L
.81766 .36228 L
.8578 .36254 L
.89643 .36278 L
.9375 .36304 L
.97619 .36328 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.06244 .23829 L
.08255 .36402 L
.10458 .48501 L
.11448 .53073 L
.11992 .55258 L
.12507 .57048 L
.12986 .58418 L
.13238 .59001 L
.13506 .59496 L
.13731 .59801 L
.13859 .59924 L
.13979 .60003 L
.14089 .60042 L
.14189 .60048 L
.14305 .60017 L
.14415 .59949 L
.1454 .59822 L
.1461 .59725 L
.14674 .5962 L
.1479 .59388 L
.14918 .59065 L
.1514 .58322 L
.15374 .57252 L
.15629 .55708 L
.15902 .53563 L
.16396 .48351 L
.16859 .42327 L
.17113 .39036 L
.17351 .36282 L
.1757 .34196 L
.17771 .32718 L
.17877 .32104 L
.17994 .31558 L
.18111 .31134 L
.18234 .30811 L
.18303 .30681 L
.18368 .30588 L
.18489 .30485 L
.1862 .30467 L
.18694 .30494 L
.18761 .3054 L
.18875 .30659 L
.19 .30843 L
.19252 .31351 L
.19824 .32966 L
.20358 .34796 L
.22371 .42124 L
.23411 .4539 L
.23924 .46681 L
Mistroke
.24173 .47196 L
.24399 .47581 L
.24506 .47731 L
.24621 .47868 L
.24729 .4797 L
.24829 .48039 L
.24935 .48084 L
.25051 .48096 L
.25173 .48065 L
.25286 .47992 L
.25412 .47861 L
.25531 .47688 L
.25753 .47235 L
.25993 .46582 L
.26253 .45721 L
.27188 .42035 L
.28195 .38242 L
.28772 .36508 L
.293 .35272 L
.29805 .34401 L
.30059 .34068 L
.30336 .33777 L
.30602 .33562 L
.30853 .33409 L
.31079 .3331 L
.31206 .33267 L
.31322 .33236 L
.31448 .3321 L
.31566 .33193 L
.31695 .33181 L
.31768 .33176 L
.31834 .33174 L
.31903 .33174 L
.31967 .33174 L
.32037 .33177 L
.32111 .3318 L
.32236 .3319 L
.32375 .33204 L
.32619 .33238 L
.32844 .33274 L
.33351 .33366 L
.33831 .33445 L
.34041 .33473 L
.34268 .33498 L
.34395 .33508 L
.34511 .33516 L
.34623 .33521 L
.34741 .33524 L
.34866 .33525 L
.34982 .33524 L
Mistroke
.3511 .3352 L
.35181 .33516 L
.35247 .33512 L
.3547 .33493 L
.35597 .33479 L
.35714 .33463 L
.36158 .33386 L
.36684 .33261 L
.3716 .33126 L
.38227 .3279 L
.39164 .32513 L
.40154 .32283 L
.40671 .32194 L
.40945 .32156 L
.41238 .32123 L
.41508 .32097 L
.41755 .32078 L
.42002 .32063 L
.42236 .32053 L
.4235 .32049 L
.42473 .32045 L
.42579 .32043 L
.42696 .3204 L
.42824 .32039 L
.42895 .32038 L
.4296 .32038 L
.43077 .32037 L
.43202 .32038 L
.43272 .32038 L
.43335 .32038 L
.43405 .32039 L
.43479 .3204 L
.4374 .32044 L
.43973 .32048 L
.44229 .32054 L
.46071 .32108 L
.46593 .32122 L
.47088 .32132 L
.47538 .3214 L
.48017 .32146 L
.48536 .32151 L
.49017 .32155 L
.50107 .32161 L
.51139 .32167 L
.5172 .32171 L
.52254 .32176 L
.53236 .32187 L
.54272 .32202 L
.58077 .32266 L
.62126 .32323 L
Mistroke
.66025 .32371 L
.70168 .3242 L
.7416 .32467 L
.78 .32512 L
.82085 .3256 L
.86019 .32609 L
.89801 .32656 L
.93829 .32706 L
.97619 .32752 L
Mfstroke
1 0 .19 r
.02381 .01472 m
.06244 .23826 L
.08255 .36396 L
.10458 .48497 L
.11448 .53072 L
.11992 .5526 L
.12507 .57054 L
.12986 .5843 L
.13238 .59018 L
.13506 .59518 L
.13731 .59829 L
.13859 .59956 L
.13979 .60038 L
.14089 .60082 L
.14189 .60092 L
.14305 .60067 L
.14415 .60004 L
.1454 .59884 L
.1461 .59792 L
.14674 .59691 L
.1479 .59468 L
.14918 .59156 L
.1514 .58435 L
.15374 .57395 L
.15629 .55893 L
.15902 .53805 L
.16396 .48732 L
.16859 .42854 L
.17113 .39627 L
.17351 .3691 L
.1757 .34839 L
.17771 .33362 L
.17877 .32743 L
.17994 .32192 L
.18111 .31762 L
.18234 .31432 L
.18303 .31297 L
.18368 .31201 L
.18489 .31092 L
.1862 .31068 L
.18694 .31092 L
.18761 .31136 L
.18875 .3125 L
.19 .3143 L
.19252 .31929 L
.19824 .33513 L
.20358 .35295 L
.22371 .42342 L
.22868 .43916 L
.23411 .45454 L
Mistroke
.2389 .46588 L
.24152 .47088 L
.24281 .47293 L
.24399 .47455 L
.24515 .47586 L
.24642 .47694 L
.24769 .47763 L
.24839 .47781 L
.24904 .47785 L
.2502 .4776 L
.25125 .47698 L
.25246 .47578 L
.25361 .47415 L
.25469 .47217 L
.25583 .46961 L
.25789 .46389 L
.26253 .44685 L
.27215 .40441 L
.27739 .3824 L
.28226 .36456 L
.28679 .35081 L
.2909 .34083 L
.29546 .33245 L
.29797 .32898 L
.30033 .32637 L
.30269 .32435 L
.30398 .32348 L
.30518 .3228 L
.3073 .32189 L
.30843 .32155 L
.30964 .32129 L
.31094 .32111 L
.31167 .32106 L
.31235 .32104 L
.31359 .32106 L
.31491 .32117 L
.31609 .32134 L
.31719 .32154 L
.31972 .32218 L
.32495 .32402 L
.32976 .32605 L
.33499 .32834 L
.34059 .33057 L
.34571 .33226 L
.35038 .3334 L
.35262 .33382 L
.35381 .334 L
.35506 .33416 L
.35616 .33428 L
.35736 .33439 L
Mistroke
.35846 .33447 L
.35949 .33452 L
.36077 .33457 L
.36149 .33458 L
.36216 .33459 L
.36339 .33458 L
.3647 .33455 L
.36598 .3345 L
.3672 .33444 L
.36946 .33427 L
.37214 .33402 L
.37461 .33374 L
.38018 .333 L
.38927 .33176 L
.39428 .33117 L
.39902 .33074 L
.4017 .33056 L
.40311 .33048 L
.40461 .33041 L
.40587 .33037 L
.40654 .33035 L
.40726 .33033 L
.40852 .3303 L
.40971 .33029 L
.41092 .33029 L
.41161 .33029 L
.41225 .33029 L
.41354 .33031 L
.41426 .33032 L
.41492 .33034 L
.41737 .33041 L
.41969 .33052 L
.42432 .3308 L
.42942 .33121 L
.43972 .33223 L
.45817 .33422 L
.47764 .33592 L
.48856 .33664 L
.49853 .33718 L
.53831 .33898 L
.57658 .34049 L
.59795 .34116 L
.6173 .34165 L
.6565 .34244 L
.69664 .34304 L
.73526 .34349 L
.77634 .34389 L
.8159 .34423 L
.85394 .34455 L
.89444 .34489 L
Mistroke
.93342 .34521 L
.97485 .34555 L
.97619 .34556 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.06244 .23823 L
.08255 .36396 L
.10458 .485 L
.11448 .53077 L
.11992 .55266 L
.12507 .57062 L
.12986 .58439 L
.13238 .59028 L
.13506 .5953 L
.13731 .59842 L
.13859 .5997 L
.13979 .60054 L
.14089 .60098 L
.14189 .6011 L
.14305 .60086 L
.14415 .60025 L
.1454 .59907 L
.1461 .59816 L
.14674 .59716 L
.1479 .59495 L
.14918 .59187 L
.1514 .58472 L
.15374 .57442 L
.15629 .55953 L
.15902 .53884 L
.16396 .4886 L
.16859 .43023 L
.17351 .37067 L
.17553 .35115 L
.17771 .33458 L
.17896 .32723 L
.1801 .32179 L
.18119 .31768 L
.18234 .31442 L
.18356 .31204 L
.18486 .31059 L
.18609 .31011 L
.1872 .31033 L
.18852 .31129 L
.18925 .31213 L
.18994 .31306 L
.19252 .31784 L
.19508 .3241 L
.19789 .33221 L
.20358 .35102 L
.22371 .42292 L
.23368 .45404 L
.2386 .4666 L
.24315 .4757 L
Mistroke
.24568 .47931 L
.24641 .48011 L
.2471 .48076 L
.24838 .48167 L
.24907 .48199 L
.2498 .48218 L
.25111 .48213 L
.25184 .48187 L
.25252 .48147 L
.25327 .48085 L
.25407 .47997 L
.25536 .47809 L
.25675 .4754 L
.25929 .46891 L
.26405 .45255 L
.2734 .41413 L
.28347 .3765 L
.28924 .35991 L
.29452 .3484 L
.29957 .34054 L
.30211 .33764 L
.30488 .33517 L
.30616 .33426 L
.30754 .33343 L
.30876 .33281 L
.31005 .33227 L
.31121 .33188 L
.31249 .33154 L
.31365 .33131 L
.31474 .33116 L
.31539 .3311 L
.3161 .33105 L
.31739 .33102 L
.31865 .33105 L
.31982 .33113 L
.32107 .33126 L
.32246 .33145 L
.32526 .33196 L
.33448 .33416 L
.33951 .33531 L
.3442 .33612 L
.34652 .3364 L
.34782 .33653 L
.34901 .33661 L
.35031 .33668 L
.35104 .3367 L
.35172 .33672 L
.35296 .33672 L
.35428 .3367 L
.35537 .33666 L
Mistroke
.35655 .33659 L
.35766 .33651 L
.35868 .33641 L
.36116 .33612 L
.36352 .33576 L
.36869 .33474 L
.37349 .33359 L
.38437 .33071 L
.39495 .32819 L
.40014 .32721 L
.40491 .3265 L
.40926 .326 L
.41145 .32581 L
.41385 .32564 L
.41626 .32551 L
.41762 .32545 L
.41885 .32541 L
.42 .32538 L
.42125 .32536 L
.42243 .32534 L
.42352 .32533 L
.4247 .32533 L
.42594 .32534 L
.427 .32535 L
.42816 .32536 L
.42941 .32539 L
.43075 .32542 L
.43316 .32549 L
.43789 .32568 L
.4422 .32588 L
.46281 .32696 L
.47213 .32735 L
.482 .32767 L
.49283 .32794 L
.50281 .32813 L
.54071 .32891 L
.58107 .32986 L
.61992 .33059 L
.66121 .3312 L
.701 .33171 L
.73926 .33216 L
.77998 .33261 L
.81918 .33305 L
.86083 .33351 L
.90097 .33397 L
.9396 .33441 L
.97619 .33481 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.06244 .23816 L
.08255 .36385 L
.10458 .48493 L
.11448 .53077 L
.11992 .55272 L
.12507 .57076 L
.12986 .58465 L
.13238 .59061 L
.13506 .59574 L
.13731 .59897 L
.13859 .60032 L
.13979 .60124 L
.14089 .60176 L
.14189 .60195 L
.14305 .60181 L
.14415 .60131 L
.1454 .60026 L
.1461 .59944 L
.14674 .59852 L
.14793 .59642 L
.14918 .59359 L
.15135 .58702 L
.15374 .57712 L
.15629 .56302 L
.15902 .54342 L
.16396 .49582 L
.16859 .44034 L
.17351 .38293 L
.17553 .36373 L
.17771 .3472 L
.17896 .33976 L
.1801 .3342 L
.18119 .32995 L
.18234 .32652 L
.18356 .32397 L
.18486 .32232 L
.18609 .32168 L
.1872 .32175 L
.18852 .32255 L
.18925 .32329 L
.18994 .32415 L
.19252 .32862 L
.19508 .33456 L
.19789 .34227 L
.20358 .36011 L
.22371 .42791 L
.23368 .45742 L
.2386 .46931 L
.24099 .47412 L
Mistroke
.24315 .47778 L
.24437 .47948 L
.24568 .48101 L
.24641 .48169 L
.24707 .48221 L
.24838 .48291 L
.2497 .48314 L
.25045 .48304 L
.25115 .48279 L
.25189 .48235 L
.25256 .48178 L
.25334 .48092 L
.25407 .47991 L
.25528 .47783 L
.25656 .47505 L
.25885 .46866 L
.26405 .44921 L
.27366 .4066 L
.27891 .38505 L
.28378 .36788 L
.28831 .35489 L
.29241 .34565 L
.29698 .3381 L
.29949 .33508 L
.30185 .33288 L
.3042 .33127 L
.30539 .33066 L
.30669 .33013 L
.30781 .32979 L
.309 .32953 L
.31013 .32938 L
.31116 .32932 L
.31244 .32934 L
.31363 .32945 L
.31494 .32966 L
.3156 .32979 L
.31633 .32997 L
.31886 .33074 L
.32123 .33168 L
.3314 .33699 L
.3421 .34289 L
.34675 .34507 L
.35173 .347 L
.35458 .34791 L
.35718 .34861 L
.35982 .34919 L
.36226 .34962 L
.36448 .34993 L
.36682 .35018 L
.36804 .35028 L
Mistroke
.36918 .35036 L
.37043 .35042 L
.37113 .35045 L
.37177 .35047 L
.37292 .3505 L
.37418 .35051 L
.37529 .35051 L
.37647 .35051 L
.37763 .35049 L
.37872 .35047 L
.38076 .3504 L
.39053 .34997 L
.39311 .34986 L
.39587 .34975 L
.39721 .34971 L
.39848 .34968 L
.39961 .34966 L
.40085 .34964 L
.40191 .34963 L
.40307 .34962 L
.40429 .34962 L
.40543 .34963 L
.40649 .34964 L
.40747 .34966 L
.40854 .34969 L
.40966 .34972 L
.41206 .34981 L
.41428 .34992 L
.41933 .35026 L
.42439 .35071 L
.42986 .35131 L
.4398 .35257 L
.45839 .35507 L
.47789 .35726 L
.49933 .35898 L
.53876 .36123 L
.57912 .36308 L
.61796 .36435 L
.63915 .36485 L
.65926 .36525 L
.69752 .36584 L
.73824 .36629 L
.77744 .36662 L
.8191 .36691 L
.85923 .36716 L
.89786 .3674 L
.93893 .36765 L
.97619 .36788 L
Mfstroke
1 0 .119 r
.02381 .01472 m
.06244 .23824 L
.08255 .36396 L
.10458 .48499 L
.11448 .53075 L
.11992 .55263 L
.12507 .57059 L
.12986 .58436 L
.13238 .59023 L
.13506 .59525 L
.13731 .59837 L
.13859 .59964 L
.13979 .60047 L
.14089 .60091 L
.14189 .60102 L
.14305 .60078 L
.14415 .60016 L
.1454 .59898 L
.1461 .59806 L
.14674 .59706 L
.1479 .59484 L
.14918 .59174 L
.1514 .58458 L
.15374 .57424 L
.15629 .55931 L
.15902 .53857 L
.16396 .48819 L
.16859 .42975 L
.17351 .3703 L
.17553 .35088 L
.17771 .33444 L
.17896 .32717 L
.1801 .32181 L
.18119 .31777 L
.18234 .31459 L
.18356 .31229 L
.18486 .3109 L
.18609 .31049 L
.1872 .31078 L
.18852 .3118 L
.18925 .31267 L
.18994 .31364 L
.19252 .31851 L
.19508 .32484 L
.19789 .333 L
.20358 .35181 L
.22371 .42313 L
.23368 .45383 L
.2386 .46612 L
.24099 .4711 L
Mistroke
.24315 .47489 L
.24437 .47666 L
.24568 .47825 L
.24641 .47897 L
.24707 .47952 L
.24838 .48028 L
.2497 .48058 L
.25045 .48052 L
.25115 .4803 L
.25189 .47989 L
.25256 .47936 L
.25334 .47854 L
.25407 .47758 L
.25528 .47557 L
.25656 .47289 L
.25885 .46673 L
.26405 .44806 L
.27366 .40723 L
.27891 .38628 L
.28378 .36931 L
.28831 .35621 L
.29241 .34667 L
.29698 .3386 L
.29949 .33523 L
.30185 .33267 L
.3042 .33066 L
.30669 .32907 L
.30882 .32811 L
.31003 .3277 L
.31116 .32741 L
.31246 .32717 L
.3137 .32703 L
.31481 .32697 L
.31602 .32696 L
.31733 .32703 L
.31799 .32709 L
.31873 .32717 L
.32002 .32737 L
.32123 .32759 L
.32647 .32891 L
.33127 .3304 L
.33651 .33204 L
.3421 .33354 L
.34474 .33411 L
.34723 .33454 L
.34947 .33484 L
.35073 .33497 L
.35189 .33506 L
.35298 .33513 L
.354 .33517 L
Mistroke
.35511 .3352 L
.35632 .33521 L
.35757 .33519 L
.35876 .33514 L
.35984 .33509 L
.361 .33501 L
.36373 .33474 L
.3662 .33442 L
.37174 .33347 L
.3817 .33134 L
.39106 .32938 L
.39618 .32848 L
.40096 .3278 L
.40613 .32726 L
.40887 .32705 L
.41028 .32696 L
.41181 .32688 L
.4132 .32683 L
.41449 .32679 L
.41572 .32676 L
.41703 .32674 L
.41819 .32673 L
.41929 .32673 L
.42049 .32674 L
.42178 .32675 L
.42304 .32678 L
.42418 .32681 L
.42675 .32689 L
.43136 .3271 L
.44184 .32779 L
.46294 .32934 L
.48214 .33038 L
.49297 .33079 L
.50294 .33112 L
.54237 .33231 L
.58027 .33344 L
.62063 .33434 L
.65948 .335 L
.70077 .33557 L
.74056 .33603 L
.77882 .33644 L
.81954 .33686 L
.85874 .33726 L
.90039 .33768 L
.94053 .33809 L
.97619 .33845 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.06244 .23804 L
.08255 .36374 L
.10458 .48491 L
.11448 .53084 L
.11992 .55287 L
.12507 .57101 L
.12986 .58503 L
.13238 .59109 L
.13506 .59634 L
.13731 .5997 L
.13859 .60113 L
.13979 .60212 L
.14089 .60273 L
.14189 .60301 L
.14305 .60298 L
.14415 .60259 L
.1454 .60169 L
.1461 .60096 L
.14674 .60013 L
.14793 .59821 L
.14918 .59559 L
.15135 .58946 L
.15374 .58016 L
.15629 .56687 L
.15902 .54837 L
.16396 .50337 L
.16859 .4505 L
.17351 .39445 L
.17553 .37515 L
.17771 .35813 L
.17896 .35029 L
.1801 .34432 L
.18119 .33968 L
.18234 .33577 L
.18357 .33272 L
.18471 .33079 L
.18541 .33 L
.18607 .32951 L
.1873 .32919 L
.1886 .32961 L
.1898 .33059 L
.19112 .33223 L
.19252 .33451 L
.19779 .34676 L
.20358 .36402 L
.22371 .43016 L
.23368 .45937 L
.2386 .47125 L
.24315 .47982 L
Mistroke
.24446 .4817 L
.24568 .48317 L
.24636 .48386 L
.2471 .48448 L
.24838 .48527 L
.24907 .48551 L
.24982 .48563 L
.25061 .48557 L
.25134 .48535 L
.25266 .48449 L
.2534 .48375 L
.25407 .4829 L
.25535 .48084 L
.25653 .4784 L
.2592 .47111 L
.26405 .45294 L
.27382 .4096 L
.27895 .38858 L
.28434 .3699 L
.28908 .35689 L
.29159 .35134 L
.29427 .34641 L
.29674 .3427 L
.29898 .34001 L
.30124 .33789 L
.30336 .3364 L
.3045 .33579 L
.30555 .33532 L
.30671 .33493 L
.30796 .33463 L
.30926 .33445 L
.3105 .33439 L
.31161 .33443 L
.31281 .33456 L
.31385 .33474 L
.315 .33501 L
.31733 .33574 L
.32152 .33761 L
.34117 .35002 L
.35058 .35522 L
.35531 .35726 L
.36049 .35902 L
.36321 .35975 L
.36612 .36039 L
.36882 .36087 L
.37136 .36122 L
.37387 .3615 L
.37659 .36171 L
.37779 .36179 L
.37906 .36185 L
Mistroke
.38134 .36194 L
.39148 .36208 L
.3939 .36209 L
.39525 .36209 L
.39647 .3621 L
.39762 .36211 L
.39886 .36213 L
.40111 .36217 L
.4033 .36222 L
.40562 .36229 L
.40976 .36248 L
.41426 .36277 L
.41919 .36319 L
.42924 .36432 L
.43862 .36562 L
.4595 .3687 L
.47815 .37102 L
.49843 .37287 L
.51968 .37432 L
.53981 .37548 L
.58061 .37747 L
.60088 .37823 L
.6199 .37882 L
.65767 .37969 L
.67787 .38005 L
.69638 .38032 L
.73602 .38076 L
.77415 .38106 L
.81473 .38131 L
.85379 .38152 L
.89531 .38173 L
.93531 .38192 L
.9738 .3821 L
.97619 .38212 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.06244 .23807 L
.08255 .36377 L
.10458 .48492 L
.11448 .53082 L
.11992 .55283 L
.12507 .57095 L
.12986 .58494 L
.13238 .59097 L
.13506 .59619 L
.13731 .59951 L
.13859 .60092 L
.13979 .6019 L
.14089 .60249 L
.14189 .60275 L
.14305 .60269 L
.14415 .60227 L
.1454 .60134 L
.1461 .60058 L
.14674 .59973 L
.14793 .59777 L
.14918 .5951 L
.15135 .58886 L
.15374 .57941 L
.15629 .56593 L
.15902 .54717 L
.16396 .50156 L
.16859 .44808 L
.17351 .39173 L
.17553 .37247 L
.17771 .35558 L
.17896 .34784 L
.1801 .34197 L
.18119 .33744 L
.18234 .33364 L
.18357 .33071 L
.18471 .32889 L
.18541 .32817 L
.18607 .32774 L
.1873 .32753 L
.1886 .32805 L
.1898 .32913 L
.19112 .33086 L
.19252 .33323 L
.19779 .34574 L
.20358 .36322 L
.22371 .42976 L
.23368 .45907 L
.2386 .47098 L
.24099 .47585 L
Mistroke
.24315 .47958 L
.24437 .48134 L
.24568 .48294 L
.24641 .48366 L
.24707 .48423 L
.24838 .48503 L
.2497 .48539 L
.25045 .48537 L
.25115 .48519 L
.25189 .48483 L
.25256 .48434 L
.25334 .48359 L
.25407 .48267 L
.25528 .48074 L
.25656 .47812 L
.25885 .47199 L
.26405 .45288 L
.27366 .41034 L
.27891 .38877 L
.28378 .37161 L
.28831 .35864 L
.29241 .34944 L
.29698 .34196 L
.29949 .33898 L
.30185 .33684 L
.3042 .33528 L
.30539 .3347 L
.30669 .33421 L
.30781 .3339 L
.309 .33368 L
.31013 .33357 L
.31116 .33355 L
.31244 .33362 L
.31363 .33377 L
.31494 .33402 L
.31633 .33439 L
.31866 .33519 L
.32123 .33632 L
.33212 .34265 L
.3421 .34882 L
.35151 .35357 L
.35625 .35538 L
.36143 .35689 L
.36416 .35749 L
.36664 .35794 L
.36951 .35834 L
.37222 .35862 L
.37344 .35871 L
.37473 .3588 L
.37584 .35886 L
Mistroke
.37704 .35891 L
.37833 .35896 L
.37953 .35899 L
.38027 .359 L
.38097 .35901 L
.38227 .35903 L
.38352 .35903 L
.38422 .35903 L
.38487 .35903 L
.38605 .35902 L
.38731 .35901 L
.39187 .35896 L
.39422 .35894 L
.39554 .35893 L
.39675 .35892 L
.39743 .35892 L
.39817 .35892 L
.39887 .35892 L
.39951 .35893 L
.40077 .35893 L
.4014 .35894 L
.4021 .35895 L
.40326 .35897 L
.40448 .35899 L
.40666 .35905 L
.40901 .35914 L
.41158 .35927 L
.4162 .35957 L
.42049 .35994 L
.43102 .36113 L
.44096 .3625 L
.45955 .36517 L
.47788 .36738 L
.49804 .36917 L
.51793 .37049 L
.53898 .37168 L
.57934 .37363 L
.61818 .37495 L
.63937 .37548 L
.65948 .3759 L
.69774 .3765 L
.71747 .37673 L
.73846 .37694 L
.78011 .37727 L
.82025 .37752 L
.85888 .37774 L
.89995 .37796 L
.93951 .37816 L
.97619 .37835 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.06244 .23816 L
.08255 .36387 L
.10458 .48495 L
.11448 .53078 L
.11992 .55272 L
.12507 .57075 L
.12986 .58463 L
.13238 .59058 L
.13506 .59569 L
.13731 .59891 L
.13859 .60025 L
.13979 .60115 L
.14089 .60166 L
.14189 .60184 L
.14305 .60169 L
.14415 .60116 L
.1454 .6001 L
.1461 .59926 L
.14674 .59833 L
.1479 .59625 L
.14918 .59334 L
.1514 .58654 L
.15374 .5767 L
.15629 .56246 L
.15902 .54267 L
.16396 .49459 L
.16859 .43856 L
.17351 .3807 L
.17553 .36142 L
.17771 .34486 L
.17896 .33742 L
.1801 .33187 L
.18119 .32764 L
.18234 .32424 L
.18356 .32171 L
.18486 .32009 L
.18609 .31947 L
.1872 .31957 L
.18852 .32039 L
.18925 .32115 L
.18994 .32202 L
.19252 .32654 L
.19508 .33253 L
.19789 .34032 L
.20358 .35834 L
.22371 .42695 L
.23368 .45679 L
.2386 .46882 L
.24099 .4737 L
Mistroke
.24315 .47742 L
.24437 .47917 L
.24568 .48073 L
.24641 .48144 L
.24707 .48198 L
.24838 .48273 L
.2497 .48302 L
.25045 .48296 L
.25115 .48274 L
.25189 .48233 L
.25256 .4818 L
.25334 .48098 L
.25407 .48001 L
.25528 .478 L
.25656 .47529 L
.25885 .46905 L
.26405 .44991 L
.27366 .40769 L
.27891 .38614 L
.28378 .36885 L
.28831 .35565 L
.29241 .34619 L
.29698 .33837 L
.29949 .33518 L
.30185 .33283 L
.3042 .33106 L
.30539 .33037 L
.30669 .32975 L
.30781 .32934 L
.309 .329 L
.31013 .32878 L
.31116 .32865 L
.31244 .32859 L
.31363 .32861 L
.31494 .32873 L
.3156 .32882 L
.31633 .32894 L
.31886 .32954 L
.32123 .33032 L
.33127 .33485 L
.3421 .34002 L
.34672 .34183 L
.35166 .34338 L
.3545 .34407 L
.35708 .34457 L
.35967 .34496 L
.36212 .34522 L
.36334 .34532 L
.36467 .3454 L
.36535 .34543 L
Mistroke
.36607 .34545 L
.36738 .34548 L
.36868 .34549 L
.36992 .34548 L
.37103 .34546 L
.37224 .34542 L
.37368 .34536 L
.37499 .34529 L
.37793 .34509 L
.38321 .34464 L
.39258 .34381 L
.3973 .34348 L
.39997 .34333 L
.40247 .34323 L
.40388 .34319 L
.40457 .34318 L
.40521 .34316 L
.40641 .34315 L
.40771 .34314 L
.409 .34314 L
.40974 .34315 L
.41043 .34315 L
.41116 .34317 L
.41182 .34318 L
.41332 .34322 L
.41564 .3433 L
.41818 .34342 L
.4233 .34377 L
.42859 .34424 L
.43358 .34476 L
.44292 .34586 L
.46388 .34833 L
.48391 .35015 L
.50236 .35136 L
.54179 .35333 L
.5797 .35492 L
.60079 .35561 L
.62005 .35613 L
.6589 .35694 L
.69868 .35754 L
.73694 .35797 L
.77766 .35833 L
.81686 .35864 L
.85852 .35894 L
.89866 .35923 L
.93728 .35951 L
.97619 .35979 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.06244 .2381 L
.08255 .3638 L
.10458 .48493 L
.11448 .5308 L
.11992 .55279 L
.12507 .57089 L
.12986 .58484 L
.13238 .59085 L
.13506 .59604 L
.13731 .59933 L
.13859 .60072 L
.13979 .60168 L
.14089 .60224 L
.14189 .60248 L
.14305 .6024 L
.14415 .60195 L
.1454 .60098 L
.1461 .6002 L
.14674 .59933 L
.14793 .59732 L
.14918 .59459 L
.15135 .58824 L
.15374 .57865 L
.15629 .56496 L
.15902 .54593 L
.16396 .49969 L
.16859 .44559 L
.17351 .38891 L
.17553 .36968 L
.17771 .3529 L
.17896 .34526 L
.1801 .3395 L
.18119 .33507 L
.18234 .33138 L
.18357 .32857 L
.18471 .32686 L
.18541 .3262 L
.18607 .32583 L
.1873 .32572 L
.1886 .32635 L
.1898 .32751 L
.19112 .32933 L
.19252 .33179 L
.19779 .34457 L
.20358 .36226 L
.22371 .4293 L
.23368 .4588 L
.2386 .47078 L
.24315 .47945 L
Mistroke
.24568 .48286 L
.24641 .4836 L
.2471 .4842 L
.24838 .48501 L
.24907 .48528 L
.2498 .48541 L
.25111 .48525 L
.25184 .48493 L
.25252 .48446 L
.25327 .48377 L
.25407 .48281 L
.25536 .48079 L
.25675 .47791 L
.25929 .47099 L
.26405 .45345 L
.2734 .4123 L
.28347 .37322 L
.28924 .35671 L
.29176 .35099 L
.29452 .34576 L
.29696 .34198 L
.29957 .33876 L
.30101 .33732 L
.30232 .33621 L
.30354 .33534 L
.30488 .33455 L
.30607 .33398 L
.30734 .33352 L
.30804 .33331 L
.30868 .33317 L
.30994 .33296 L
.31108 .33287 L
.31233 .33287 L
.31351 .33296 L
.3146 .33311 L
.31585 .33336 L
.31702 .33366 L
.3197 .33456 L
.32512 .33707 L
.3442 .34785 L
.34928 .3502 L
.35401 .35198 L
.35895 .3534 L
.36156 .35398 L
.36436 .35447 L
.36675 .35479 L
.368 .35493 L
.36934 .35505 L
.3705 .35514 L
.37179 .35522 L
Mistroke
.37295 .35527 L
.37404 .35531 L
.37518 .35534 L
.37626 .35536 L
.37723 .35537 L
.37829 .35537 L
.37944 .35536 L
.38066 .35534 L
.38181 .35532 L
.38285 .3553 L
.39222 .35499 L
.3945 .35492 L
.39694 .35486 L
.39834 .35483 L
.39962 .35481 L
.4009 .3548 L
.40211 .3548 L
.40342 .3548 L
.40409 .3548 L
.40482 .35481 L
.4061 .35483 L
.40731 .35485 L
.40873 .35489 L
.41003 .35493 L
.41296 .35506 L
.41529 .35519 L
.41782 .35536 L
.42294 .3558 L
.43322 .35696 L
.44257 .35821 L
.46352 .36103 L
.48272 .36309 L
.50352 .36469 L
.54446 .367 L
.58388 .36877 L
.62179 .36997 L
.64125 .37043 L
.66215 .37084 L
.68191 .37117 L
.70345 .37146 L
.74323 .37188 L
.78395 .3722 L
.82315 .37246 L
.8648 .37272 L
.90494 .37295 L
.94356 .37317 L
.97619 .37336 L
Mfstroke
1 0 0 r
.02381 .01472 m
.06244 .23813 L
.08255 .36383 L
.10458 .48494 L
.11448 .53079 L
.11992 .55276 L
.12507 .57082 L
.12986 .58473 L
.13238 .59072 L
.13506 .59587 L
.13731 .59912 L
.13859 .60049 L
.13979 .60142 L
.14089 .60195 L
.14189 .60216 L
.14305 .60205 L
.14415 .60156 L
.1454 .60055 L
.1461 .59974 L
.14674 .59884 L
.14793 .59678 L
.14918 .59398 L
.15135 .58749 L
.15374 .57771 L
.15629 .56376 L
.15902 .54437 L
.16396 .49727 L
.16859 .44227 L
.17351 .38507 L
.17553 .36583 L
.17771 .34917 L
.17896 .34163 L
.1801 .33598 L
.18119 .33166 L
.18234 .3281 L
.18357 .32543 L
.18471 .32384 L
.18541 .32325 L
.18607 .32295 L
.1873 .32296 L
.1886 .32371 L
.1898 .32497 L
.19112 .3269 L
.19252 .32946 L
.19779 .34257 L
.20358 .36056 L
.22371 .42832 L
.23368 .45799 L
.2386 .47002 L
.24099 .47493 L
Mistroke
.24315 .47869 L
.24437 .48047 L
.24568 .48207 L
.24641 .48281 L
.24707 .48338 L
.24838 .48419 L
.2497 .48456 L
.25045 .48454 L
.25115 .48436 L
.25189 .48401 L
.25256 .48353 L
.25334 .48277 L
.25407 .48186 L
.25528 .47994 L
.25656 .47734 L
.25885 .47126 L
.26405 .45235 L
.27366 .41013 L
.27891 .38851 L
.28378 .37116 L
.28831 .35793 L
.29241 .34845 L
.29698 .34063 L
.29949 .33746 L
.30185 .33513 L
.3042 .33339 L
.30539 .33272 L
.30669 .33212 L
.30781 .33173 L
.309 .33141 L
.31013 .33121 L
.31116 .33111 L
.31244 .33107 L
.31363 .33113 L
.31494 .33128 L
.3156 .33139 L
.31633 .33153 L
.31886 .33221 L
.32123 .33306 L
.3314 .33806 L
.3421 .34368 L
.34675 .34575 L
.35173 .34758 L
.35458 .34842 L
.35718 .34907 L
.35982 .34959 L
.36226 .34998 L
.36448 .35024 L
.36682 .35044 L
.36804 .35052 L
Mistroke
.36918 .35057 L
.37043 .35061 L
.37113 .35063 L
.37177 .35064 L
.37292 .35064 L
.37398 .35064 L
.37514 .35062 L
.37638 .35059 L
.37756 .35055 L
.37868 .35051 L
.38076 .35041 L
.39053 .34983 L
.39311 .34968 L
.39587 .34954 L
.39843 .34944 L
.39969 .3494 L
.40085 .34936 L
.40192 .34934 L
.40306 .34932 L
.4042 .34931 L
.40546 .34931 L
.40651 .34931 L
.40763 .34932 L
.40869 .34933 L
.40966 .34935 L
.41083 .34938 L
.41191 .34941 L
.41437 .34951 L
.41677 .34964 L
.41933 .34981 L
.42958 .35075 L
.44069 .3521 L
.46085 .35469 L
.48074 .35675 L
.50179 .3583 L
.53969 .36035 L
.58005 .36214 L
.6189 .36337 L
.64009 .36387 L
.66019 .36426 L
.69846 .36484 L
.73918 .36529 L
.77838 .36562 L
.82003 .36592 L
.86017 .36619 L
.89879 .36644 L
.93987 .36671 L
.97619 .36694 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 370.812},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001LR000`400?l00000o`00003ooooooooo
oooooe[ooooo0021ooooo`?o00001?ooool2o`0000Cooooo0_l0001Pooooo`Go00000oooool2o`00
00Cooooo0_l0001Pooooo`?o00001?ooool2o`0000Cooooo0_l0001Rooooo`?o00000oooool2o`00
00Cooooo0_l0001Qooooo`?o00001?ooool2o`0000Cooooo0_l00009ooooo`00P_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000H?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000G_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0001Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool008;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00067ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
06;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo05gooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000Hoooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool008;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0006;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0G_ooool2o`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001Oooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0001Sooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`00P_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Gooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0001Rooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0001Oooooo`Co00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Sooooo0021ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0005oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000G_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0001Qooooo`;o0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005oooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo000J
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0001Q
ooooo`?o00001?ooool2o`0000Cooooo0_l0001Pooooo`?o00001?ooool2o`0000Cooooo0_l0001S
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000H?ooool5o`0000?ooooo0_l00004
ooooo`;o00002Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03
o`000?oooooooooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo
?Oooool001[ooooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooo
oooo0?oooooooooooolmooooo`006_ooool00ol0003oooooooooo`3ooooooooooooo?Oooool001[o
oooo00?o0000ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooo
oooooolmooooo`003?ooool>o`000003ool00?l0003o00000?oo0000ool0000lo`00007ooooo000J
ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool001[ooooo00?oo`00oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0=ooooo`006_ooool00ooo003oooooooooo`1/ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool03Oooool001[ooooo00?o0000ool00?ooool0
K?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
KOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00gooooo000Jooooo`03o`000?oo
003ooooo0?oooooooooooolmooooo`006_ooool00ol0003oo`00ooooo`3ooooooooooooo?Oooool0
01[ooooo00?o0000ool00?ooool0ooooooooooooocgooooo000Jooooo`03o`000?oo003ooooo0?oo
oooooooooolmooooo`006_ooool00ol0003oo`00ooooo`3ooooooooooooo?Oooool001[ooooo00?o
0000oooooooo0000ooooooooooooocgooooo000Jooooo`03o`000?ooooooo`000?oooooooooooolm
ooooo`006_ooool2o`000003ool00?oooooooooo0?oooooooooooolkooooo`006_ooool00ol0003o
ooooool0003ooooooooooooo?Oooool001[ooooo00?o0000oooooooo0000ooooooooooooocgooooo
000Jooooo`03o`000?ooooooo`000?oooooooooooolmooooo`006_ooool01?l0003ooooooooooooo
003ooooooooooooo??ooool001[ooooo00Co0000ooooooooooooo`00oooooooooooooccooooo000J
ooooo`04o`000?ooooooooooool00?oooooooooooollooooo`006_ooool01?l0003ooooooooooooo
003ooooooooooooo??ooool001[ooooo00Co0000ooooooooooooo`00oooooooooooooccooooo000J
ooooo`04o`000?ooooooooooool00?oooooooooooollooooo`006_ooool01Ol0003ooooooooooooo
ooooo`000?oooooooooooolkooooo`006_ooool01Ol0003oooooooooooooooooo`000?oooooooooo
oolkooooo`006_ooool01Ol0003oooooooooooooooooo`000?oooooooooooolkooooo`006_ooool3
o`000003oooooooo003ooooo0?ooooooooooooljooooo`006_ooool01Ol0003ooooooooooooooooo
o`000?oooooooooooolkooooo`006_ooool01Ol0003oooooooooooooooooo`000?oooooooooooolk
ooooo`006_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhoooo
o`006_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhooooo`00
6_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhooooo`006_oo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhooooo`006_ooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhooooo`006_ooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo0?oooooooooooolhooooo`006_ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo0?oooooooooooolgooooo`006_ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo0?oooooooooooolgooooo`006_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo0?oooooooooooolgooooo`006_ooool3o`0000?ooooo00?oo`00
ooooooooool0ooooooooooooocOooooo000Jooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool0ooooooooooooocOooooo000Jooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool0ooooooooooooocOooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
ooooooooooooocKooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0oooo
ooooooooocKooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0oooooooo
ooooocKooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0oooooooooooo
ocKooooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0ooooooooooooocKo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0ooooooooooooocKooooo
000Jooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0ooooooooooooocGooooo000J
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0ooooooooooooocGooooo000Joooo
o`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0ooooooooooooocGooooo000Jooooo`?o
00001Oooool00ooo003oooooooooo`3ooooooooooooo=Oooool001[ooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`3ooooooooooooo=Oooool001[ooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`3ooooooooooooo=Oooool001[ooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`3ooooooooooooo=?ooool001[ooooo00?o0000ooooooooool01_ooool00ooo
003oooooooooo`3ooooooooooooo=?ooool001[ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`3ooooooooooooo=?ooool001[ooooo00?o0000ooooooooool01_ooool00ooo003ooooo
ooooo`3ooooooooooooo=?ooool001[ooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`3ooooooooooooo=?ooool001[ooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`3o
oooooooooooo=?ooool001[ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`3ooooo
oooooooo<oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000:ooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0oooooooooooooc?ooooo00001Ooooooo0000
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
00Oooooo00?oo`00ooooooooool0Qoooool00ol0XOooooooooooo`3oooooojSooooo00001Ooooooo
0000oooooooooooo000000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03ool00?oooooooooo08Cooooo0ol0XOl01?oooooo0:7oo`2Qool0XOooooooojOooooo00001Ooo
oooo0000oooooooooooo000000_ooooo00?o0000ooooooooool01oooool4o`0000Kooooo00?oo`00
ooooooooool0Q?ooool00ol0XOooooooooooo`04ooooo`03o`2Qoooooooooooo0?ooooooY?ooool0
0005ooooool0003oooooooooool000001oooool4o`0000[ooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`23ooooo`03o`2Qoooooooooooo00Kooooo0_l0XOooooooojCooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo087ooooo00Co0:7ooooooooooooooooo1Ol0ROl3ooooo`03o`2Qoooo
oooooooo0?ooooooXOooool000;ooooo0_l00008ooooo`Go00002Oooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo083ooooo00Co0:7ooooooooooooooooo0_l0ROl2o`3Zo`;ooooo00Go
08Woooooooooooooooooo`2Qo`3ooooooj;ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0P?ooool01?l0XOooooooooooool0ROl4ooooo`;o0>[o00Goooooo`29ool0ROoo
ooooo`2Qo`3ooooooj;ooooo000Jooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
P?ooool00ol0XOooooooo`29o`07ooooo`06o`3Zooooooooooooo`29oooooooo0:7ooooooonQoooo
o`006_ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo083ooooo00?o0:7oo`3Zool0
ROl02?ooool01_l0j_ooooooooooool0ROooooooo`2QooooooooX?ooool001[ooooo00?o0000oooo
ooooool02Oooool00ooo003oooooooooo`1nooooo`03o`2Qoooooooo08Wo00Sooooo0_l0Vol2oooo
o`04o`29ooooooooooooo`2QooooooooWoooool001[ooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`1nooooo`04o`2Qool0j_oo08Woooooo`Go0?Ko0_l0Vol00ooooooo09_oo`2Ko`02
o`2Ko`04o`29ooooooooooooo`2QooooooooW_ooool001[ooooo00?o0000ooooooooool02Oooool0
0ooo003oooooooooo`1nooooo`07o`2Qool0ROooooooooooool0m_ooooooo`3o^P02o`2Ko`03o`3o
^_l0m_oooooo00;ooooo00Co0>[ooooooooooooo08Wo0_ooool00ol0XOooooooooooo`3ooooooi_o
oooo000Jooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0OOooool01_l0XOoooooo
o`29oooooooo0?Koooooo`;o0?nj00Go09_ooooooooooooo0?njo`3fo`04o`1[o`;ooooo00Co08Wo
o`2Koooooooo0:7ooooooonLooooo`006_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo07gooooo00So0:7oooooool0ROoo0?Koooooool0ok[oooooo`2Ko`?ooooo0_l0Jol01?l0m_oo
0?njooooool0j_l2o`1[o`05ooooool0ROoo09_oo`2Kool0XOl0oooooonKooooo`006_ooool3o`00
00Wooooo00?oo`00ooooooooool0O?ooool02Ol0XOooooooo`3Zool0ROoo0?Koooooool0ok[ooooo
o`2Ko`02ooooo`09o`1[ooooooooooooo`3foooooooo0?njooooool0j_oooooo00;o06_o00Co08Wo
ooooool0Vooo0:7ooooooonJooooo`006_ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooo
oooo07_ooooo00So0:7oooooool0ROoo0?Koooooool0ok[oooooo`2Ko`;ooooo00?o06_ooooooooo
ool00_ooool01Ol0m_ooooooo`3o^_oooooo0>[o00;ooooo0_l0Jol00ooooooo09_oo`2Ko`3ooooo
oiWooooo000Jooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Noooool02_l0XOoo
ooooo`29ool0m_ooooooo`3o^_oooooo09_oo`2^ool0Jol3o`2^o`?ooooo00Go0?Koo`3o^_oooooo
ooooo`3Zo`02ooooo`05o`29ool0Joooooooooooool0Vol0oooooonHooooo`006_ooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo07_ooooo00Oo0:7oo`3Zool0ROoo0?Koo`3o^_oooooo
09_o00;o0:ko1Ol0C?l3ooooo`04o`3fool0ok[oooooo`3Zo`?ooooo00Co08Woo`1[oooooooooooo
0_l0VooooooooiKooooo000Jooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0Nooo
ool02?l0XOoo08Woooooool0m_oo0?njooooool0Vooooooo0_l0C?l4ooooo`;o04co00Koooooo`3f
oooooooo0?njooooool0j_l3ooooo`06o`29ool0Joooooooooooool0XOoo09_o9ooooolDo`0@oooo
ooooF_ooool001[ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`1kooooo`09o`2Q
ool0ROoo0?Koo`3o^_oooooo0:koo`2Koooooooo04co00Gooooo00Wo0?o0o`2^ool0C?ooooooo`3f
oooooooo0?njooooool0j_l00oooool00ol0ROoo06_oooooo`02ooooo`;o09_o8?ooool5o`0@o`Co
09_o4?l0FOl9o`0@ooooooooDOooool001[ooooo00?o0000ooooooooool02_ooool00ooo003ooooo
ooooo`1kooooo`08o`2Qool0ROoo0?Koo`3o^_oooooo09_oooooool0C?l2o`3oM`04o`3oOOl0ol3o
0?o0o`3o`0;o0?mm00Oo0:koo`1<ool0ol3o0?Koo`3o^_oooooo0>[o00Cooooo00?o08Woo`1[ool0
Jol00_ooool00ol0XOoo09_oooooo`0Kooooo`?o013o0_l0Vol7o`1Io`Cooooo2ol0Vol5ooooo`Go
05Wo2Ol04?ooooooodSooooo000Jooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0
N_ooool02_l0ROooooooo`3fool0ok[oooooo`2Kool0C?oo06_oooooool0ogd2o`3o`00<ooooool0
ogOoooooooooool0oggo0:koo`1<ool0m_ooooooo`3o^_oooooo0>[o1?ooool00ol0ROooooooo`1[
o`02ooooo`03o`2Qool0Vooooooo01Oooooo0ol04?l2ooooo`?o05Wo5_ooool5o`2Ko`_ooooo0ol0
FOl=o`0@oa[o05WooooooolQooooo`006_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo07[ooooo00_o08Woo`3foooooooo0?njo`2^ool0Vooo04coo`1[ool0oggoooooo`3o`003oooo
o`;o0?mg00Woooooo`3oOOl0C?ooooooo`3foooooooo0?njooooool0j_l01?ooool01_l0ROoooooo
o`1[ool0Joooooooo`2Qo`;o09_o4Oooool3o`2Ko`;o013o0oooool2o`1Ioakooooo1_l0VolEoooo
oa[o013o8Ol0FOooooooo`006_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo07[o
oooo00[o08Woo`3fool0ok[oooooo`2Koooooooo04coooooool0oggo0?o01_ooool01ol0ogOooooo
o`2^ool0C?oo0?Koo`3o`?l0okX00_ooool00ol0j_ooooooooooo`02ooooo`05o`29oooooooooooo
o`1[ooooool00_l0XOl3o`2Ko`_ooooo0ol0Vol00ooooooo013oo`0@o`03ooooo`;o05Wo9_ooool6
o`2KobWooooo3?l04?lEooooobgo05Wod_ooool001[ooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1iooooo`0:o`2Qool0ROooooooo`3o^_l0[_oo09_oo`1<ool0Jooo0?mmo`3o`0So
oooo00?o0?mgooooool0[_l01_l04?l5ooooo`03o`29oooooooooooo00?o06_o00?o0:7ooooooooo
ool02ol0Vol2ooooo`;o013o0oooool2o`1Io`Gooooo3?l0JolMooooo`Ko09_o;ooooolSo`0@oaoo
ooooG_l0FOmdooooo`006_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo07Wooooo
00[o0:7oo`29oooooooo0?njo`2^ool0Vooo04coo`1[ool0oggo0?o02?ooool01Ol0FOoo013oo`0@
ool0FOoo04co00Co05Wo0ol04?l3ooooo`03o`29oooooooooooo00;ooooo0_l0Jol<ooooo`;o013o
0_ooool3o`1Io`Oo06_o3?ooool7o`1[oacooooo2Ol0Vom9oooooago013oH?oooom5o`1Ioboooooo
000Jooooo`?o00002oooool00ooo003oooooooooo`1iooooo`09o`2Qool0ROoo0?njooooool0[_oo
04coo`1[ool0oggo0?o000Sooooo00Oo05Woo`0@ool0ogOoooooo`2^ool0C?oo0?Ko00;ooooo00Co
0?o0o`1Iool0FOoo05Wo1Ol04?l5ooooo`;o06_o1oooool3o`0@o`;ooooo0_l0FOl3o`1[oa[ooooo
1Ol0JolPooooo`co09_oF_oooomNo`0@odOooooo8?l0FOl?ooooo`006_ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo07Sooooo00Wo0:7oo`29ool0ok[oooooo`2Kool0C?oo06_oo`3o
OOl0ol001_ooool02_l0FOoo02koo`0@ool0;_ooooooo`3oMooooooo0:koo`1<ool0m_l2ooooo`03
o`3o`?l0j_oooooo00;o05Wo0oooool2o`0@o`Cooooo00Co0:7oo`1[ool0Jooo06_o1?l04?l3o`1[
o`;o05Wo0_l0JolRooooo`?o06_o:Oooool;o`2KojgoooooIol04?l?ooooo`006_ooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo07Sooooo00Wo0:7oo`29ool0ok[oooooo`2Kool0C?oo
06_oooooool0ol001Oooool2o`0^o`03o`0@oooooooo02ko00?o02ko00?oooooo`2^ool0C?l00_oo
ool00ol0ok[o0?o0o`3Zo`02ooooo`05o`1Iooooooooooooooooool0ROl02?l04?l4ooooo`?o05Wo
:Oooool4o`1[oc3ooooo3Ol0VooooooooaOooooo000Jooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool0N?ooool02?l0XOoo08Woo`3o^_l0[_oo09_oo`1<ool0oggo0?o01Oooool00ol0
;_oo05Woo`0@o`05ooooo`05o`3oMol0;_oo0:koo`3oOOl0C?l00_ooool00ol0ok[o0?o0o`3Zo`02
ooooo`Go05Wo1_ooool2o`2Qo`?o05Wo<?ooool7o`1[ocKooooo4_l0Voooooooo`Gooooo000Joooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0N?ooool02?l0XOoo08Woo`3o^_l0[_oo
04coo`1[oooooooo0?o01?ooool01?l0;_ooooooo`1Iool04?l5ooooo`06o`3oMooooooo02koo`2^
ool0C?oo0?Ko0_ooool00ol0ok[o0?o0o`3Zo`06ooooo`So05Wo00?oooooo`2Qool0XOl00_l0XOle
ooooo`Ko06_o@_oooolFo`2Konkooooo000Jooooo`03o`000?oooooooooo00cooooo00?oo`00oooo
ooooool0Moooool02Ol0XOoo0>[oo`29ool0ok[o0:koo`1<ool0Joooooooo`3o`004ooooo`03o`0^
ool0FOoo013o00Oooooo00Go0?mgooooool0;_oo0:koo`1<o`03ooooo`03o`3o^_l0j_oooooo00Ko
oooo00?o08Woooooooooool02OoooolCo`2QobSooooo1Ol0JomCoooooaOo09_oeoooool001[ooooo
00?o0000ooooooooool03?ooool00ooo003oooooooooo`1gooooo`08o`2Qool0ROoo0?Koo`2^ool0
Vooo04coo`1[ool0ol04ooooo`04o`0^ool0FOooooooo`0@o`Cooooo0_l0ohl2ooooo`05o`3oMooo
oooo02koooooool0C?l00oooool00ol0ok[o0>[oooooo`06ooooo`03o`29oooooooooooo01_ooooo
1_l0XOlWooooo`Ko06_o0ooooonBo`0XojKooooo000Jooooo`03o`000?oooooooooo00gooooo00?o
o`00ooooooooool0M_ooool02?l0XOoo08Woo`3fool0[_oo09_oo`1<ool0Jooo0?o00oooool01_l0
;_ooooooo`1Ioooooooo013oooooo`?o0?n?00?oooooo`3oSol0ohl00_l0ohl01Ooooooo02koo`2^
ool0m_oo04co00?ooooo00?o0?njo`3Zooooool01_ooool2o`29ob7ooooo1Ol0XOlFoooooaGo02So
0ol0JomfoooooaWo09_o;_l0:?mhooooo`006_ooool00ol0003oooooooooo`0=ooooo`03ool00?oo
oooooooo07Kooooo00So0:7oo`29ool0ok[o0:koo`2Kool0C?ooooooo`3o`0?ooooo00Ko02kooooo
ool0FOoo013oooooool0ohl8ooooo`;o0?n?00Co02koooooool0C?oo0?mm0_ooool00ol0ok[o0>[o
o`3o`008ooooo`03o`29oooooooooooo02?ooooo1?l0XOl2oooooa3o02So6?ooool9o`1[oigooooo
5ol0Vol^o`0Xod[ooooo000Jooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0M_oo
ool01ol0XOoo08Woo`3o^_l0[_oo04coo`1[ool0ol000oooool01_l0;_ooooooo`1Ioooooooo013o
o`3oS`[ooooo00Ko0?mgo`3oSol0;_ooooooo`1<ool0ogd2ooooo`04o`3o^_l0j_oo0?o0o`3o`0Oo
oooo0ol0ROlRooooo`Ko02So00?o0:7oooooooooool0;_oooolAo`1[ok[ooooo5ol0Vol^o`0Xo`go
09_o3oooool001[ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`1fooooo`07o`2Q
ool0ROoo0?njo`2^ool0C?oo06_oo`3o`003ooooo`06o`0^oooooooo05Woo`0@oooooooo0?n?1_oo
ool4obH0o`06o`3oMooooooo0:koo`0^ool0m_oo04co0oooool01?l0ok[o0>[oooooool0ol09oooo
o`;o08Wo6oooool2o`3oaP?o02So1ol0olH3o`2Qo`[o0?o6=?oooolAo`1[of;oooooM?l0ooHHoooo
o`go02So3oooool001[ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`1fooooo`07
o`2Qool0ROoo0?njo`2Kool0C?oo06_oo`3o`003ooooo`05o`0^oooooooo05Woo`0@ool0ohl00_l0
oc@2ooooo`03o`3oa_lV0?oo9P3o00?o0?o600SoooooobH0oolV0?oo9P3oo`2^ool0;_oo04coo`3o
O@?ooooo00?o0?njo`3Zooooool00_l0ol09ooooo`03o`29oooooooooooo01;ooooo1_l0olH2o`0X
o`gooooo0ol0XOl7oooooaCo0?o6<Oooool<o`1[obSooooo;_l0ooJXooooo`006_ooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo07Gooooo00So0:7oo`3Zool0ROoo0:koo`1<oooooooo
06_oo`3o`0;ooooo00Go02koooooool0FOoo0?o`o`0@o`04o`3ol003o`3oa_lV0?oooooo00Cooooo
0_l0olH01ol0ogOoooooobH0oolV0?oo02koo`1<ool0ogd00oooool01Ol0j_oooooooooooooooooo
0?o000Wooooo1Ol0ROl<ooooo`?o0?o60oooool3o`0Xoa;ooooo0ol0XOlHoooooa[o0?o68ooooolT
o`1[o`Co0?ofe_ooool001[ooooo0ol0000>ooooo`03ool00?oooooooooo07Cooooo00Oo0:7oo`3Z
ool0ROoo0:koo`1<oooooooo06_o00?ooooo00Go02koooooool0FOoo013oo`3oS`02ooooo`;o03Co
00Co9P3oo`0dool0=?oo03Co1Oooool3o`3oaP05o`2^oolV0?oo9P3oo`1<ool0ogd00oooool01?l0
j_ooooooooooooooool3o`3o`0_ooooo1ol0ROl2ooooo`?o0?o60oooool3o`0XoaSooooo1?l0XOl^
oooooaco0?o64Ol0ooHJoooooe;o06_oR?ooool001[ooooo00?o0000ooooooooool03_ooool00ooo
003oooooooooo`1dooooo`07o`2Qool0ROoo0?Koo`2^ool0C?oo06_oo`3o`003ooooo`05o`0^ool0
FOoo0?o`o`0@ooooool00_l0=?l01Ol0ob;o9P3oo`3o8_l0oo3o0?lR00;o03Co1_ooool01ol0ogOo
0?o6o`2^ool0olKo9P3oo`1<ool0ohl00oooool00ol0j_ooooooooooo`03ooooo`?o0?o03oooool6
o`29o`;o02So1?ooool6obH0oaGooooo1?l0XOleoooooa7o0?of5ol0olHAooooogko05;oD?l0Jol?
ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo07Cooooo00Oo0:7oo`29
ool0m_oo0:koo`1<ool0Jooo0?o000;ooooo00Wo02koooooool0FOooooooo`0@ool0=?oo0?lRo`3o
a_lV0?l00oooool01?l0oo3oooooo`3o=?l0=?l5ooooo`05o`3oMooooooo0:koooooool0m_l00_lV
0?l01Ol0ohoooooooooooooooooo0>[o00Oooooo1?l0ol09ooooo`;o0?o61Ol0ol08obH0o`03o`3o
`?mG0?ooE`3o01SoE`3o0oooool4o`2QobGooooo3?l0ooHRoooooaOo05;o1_l0olIhooooobgo05;o
<_ooool001[ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`1dooooo`07o`2Qool0
ROoo0?njo`2^ool0C?oo06_oo`3o`002ooooo`09o`0^ool0oo3o05Woooooool04?oo03Coooooool0
olKo9P3o00Cooooo00Co0?o`o`3o=?l0ob;o03Co1Oooool02?l0ogOoooooo`2^oooooooo0?Koo`0^
oolV0?oo0?o60oooool00ol0j_ooooooooooo`08ooooo`Oo0?o00_l0olH00ol0ol3oooooooooo`02
ooooo`;o9P3o1_ooool3oeL0o`?o08Wo1?ooool6o`3o`0Co9P3o2Oooool8oeL0o`?o0:7o5_ooool;
o`3omR;ooooo3?l0D_lMoooooaSo0?o6SOoooolSo`1Bo`oooooo000Jooooo`03o`000?oooooooooo
00kooooo00?oo`00ooooooooool0M?ooool04Ol0XOoo08Woo`3o^_l0[_oo04coo`1[ool0ol3ooooo
o`0^oooooooo0?o`o`1Iool04?ooooooo`0dool0olKo9P3o00Gooooo00Go0?o`ooooool0ocCo0?lR
o`0do`05ooooo`06o`3oMol0[_ooooooo`3foooooooo02ko0olV0?l2ooooo`03o`3Zoooooooooooo
00_ooooo0ol0olH00ooooooo9P3oobH0o`04obH0o`Gooooo0omG0?l00ooooooo0?n?o`3oS`03o`3o
S`?o08Wo0ol0ohl6ooooo`;o0?o01_lV0?l;ooooo`ooE`3o0_ooool8o`3omR7ooooo3?l0D_m1oooo
oaOo0?o6ROooool@o`3oc0oooooo000Jooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0M?ooool04Ol0XOoo08Woo`3o^_l0Vooo04coo`1[ool0ol3oooooo`0^ool0oo3o05Woo`3oSol0
4?oo03Coo`3oa_oooooo9P3o00Kooooo00Go0?o`ooooool0ocCo0?lRo`0do`04ooooo`09o`3oMooo
oooo0:koooooool0m_oo04coo`0^oooooooo0?o600;o9P3o00?o0?o6o`3Zool0okX01Oooool6o`3o
aP04oooooolV0?oo9P3oobH0o`?ooooo00?o02Soooooooooool00_ooool3oeL0o`Co0?n?2?ooool3
o`29o`So0?n?0oooool3o`3o`0Go9P3o3?ooool5o`2Qo`Co0?of6?mG0?l8ooooo`_o05;oI?ooool`
o`3oaT7ooooo6?l0ol`00ooooooo0<coo`3<o`0=o`3<o`oooooo000Jooooo`03o`000?oooooooooo
00oooooo00?oo`00ooooooooool0Loooool01_l0XOoo08Woo`2^ool0C?oo06_oo`3o`0;ooooo00So
02koo`3ol?l0FOoo0?n?o`0@ool0=?oo0?o6obH0o`Sooooo00Go0?o`ooooool0ocCo03Coo`3o8P04
ooooo`0:o`3oMol0[_ooooooooooool0m_oo04coo`0^oooooooo0?mmooooo`Co9P3o1?l0olH2oooo
o`Go9P3o1Oooool01?l0:?ooooooo`3oSol0ohl2oeL0oa;ooooo0ol0ROl5ooooo`Ko0?n?00?ooooo
o`3o`?l0ol000_l0ol06obH0o`03ooooool0ooKo0?of00Oo0?of00?oooooo`2Qool0XOl00ol0XOlF
ooooo`03o`1BoomG0?ooE`3o00WoE`3oW?ooool[o`3oaRoo0<co7_ooool001[ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`1cooooo`06o`2Qool0ROoo0:koo`1<ool0Jooo0?o00_oo
ool02?l0;_oo0?ldo`1Iool04?oo03Coo`3oa_oooooo9P3o2Oooool01Ol0oo3o0?ldooooool0=?oo
0?lR00Cooooo00go0?mgo`2^oooooooo0?Koooooool0C?oo02koooooool0oggoooooo`3oSol0j_oo
0?n?00Oo9P3o1oooool01?l0ohoo02Soo`3oSol0ohl2oeL0oaOooooo0ol0ROl8ooooo`Co0?n?1ol0
ooH6obH0o`[ooooo2Ol0XOl8ooooo`Go05;o3?oooolBoeL0ohOooooo;_l0c?l4o`3oc1Kooooo9?l0
olH?ooooo`006_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo07?ooooo013o08Wo
o`3fool0[_oo04coo`1[ool0ol3oooooo`0^ool0oo3o0?ldo`1Iool04?ooooooo`3oa_oooooo9P3o
2Oooool01_l0oo3oooooo`3o=?oooooo03Coo`3o8P?ooooo00Oo0?mgooooool0[_ooooooo`3foooo
oooo04co00;o02ko00Ko0?mmoooooooooooo0>[oo`3oSol0okX;o`3oS`;o02So00?ooooooeL0oomG
0?l07?ooool3o`29o`?ooooo1_l0ooH00ooooooo0?n?o`3oS`03o`3oS`Go0?o00_ooool6obH0o`go
oooo0_l0XOl6o`1Bo`?o0:7o8?oooolHoeL0oeSooooo5ol0c?lFoooooa7o0?o<7ooooolHo`3oPago
oooo000Jooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0Loooool03ol0ROoo0?Ko
o`2^ool0C?oo06_oo`3o`?oooooo02koo`3ol?oooooo05Woo`0@oooooooo0?o6obH0o`0;ooooo`06
o`3ol?oooooo0?ldooooool0=?oo0?lR0oooool01_l0ogOo0:koooooool0m_ooooooo`1<o`;ooooo
00Ko02koo`3oOOl0oggoooooo`3Zooooool2o`3o^POooooo0_l0:?l00oooooooE`3ooeL0o`0Noooo
o`?o0?of0ol0ROl=ooooo`Co0?n?1_l0ol02ooooo`Go9P3o1?ooool6o`1Bo`Wooooo3Ol0XOl[oooo
obkoE`3o4ooooolGo`3<oa_ooooo4_l0ol`IoooooaOo0?n3=Oooool001[ooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1cooooo`0?o`29ool0ok[o0:koo`1<ool0Jooo0?o0ooooool0
;_oo0?ldo`1Iool0ohoo013oo`3oa_oooooo9P3o00cooooo00Ko0?o`ooooool0ocCo03Coooooool0
ob82ooooo`07o`3oMooooooo0:koooooool0m_ooooooo`1<o`02ooooo`05o`0^oooooooo0?mmo`3o
OOl0j_l00_ooool00ol0ok[oooooooooo`03ooooo`04o`0XoooooooooooooeL0oacooooo1?l0ooH6
ooooo`?o08Wo4Oooool3o`3oS`Ko0?o000?o05;oobH0oolV0?l02?lV0?lFooooo`co0:7oCOooool_
oeL0o`_ooooo2ol0ol`CoooooaSo0?n3C?ooool001[ooooo00?o0000ooooooooool03oooool00ooo
003oooooooooo`1booooo`06o`2Qool0ROoo0:koooooool0C?oo06_o0_ooool01ol0;_oo0?ldo`1I
ool04?ooooooo`3oa_lV0?l03_ooool01_l0oo3oooooo`3o=?l0=?ooooooo`3o8P;ooooo00Oo0?mg
o`2^ooooooooooooo`3foooooooo04co00;ooooo0_l0;_l01Ooooooo0?mmo`3Zool0j_oooooo00?o
0?nj0_l0:?l00oooooooE`3ooeL0o`0Jooooo`?o0?of3Oooool3o`29oa?ooooo1?l0D_l9o`3o`0;o
0?n?3?lV0?lFooooo`co0:7o=_ooool<o`3<obOooooo1ol0ol`_oeL0oekooooo000Jooooo`?o0000
4?ooool00ooo003oooooooooo`1aooooo`06o`2Qool0ROoo0:koo`3oMol0C?oo06_o0_ooool01ol0
;_ooooooo`1Iool04?oo0?o6oooooolV0?l00_ooool6o`2?o`Kooooo00Oo0?o`ooooool0ocCooooo
o`0doooooooo0?lR00;ooooo00Co0?mgo`2^oooooooo0?Ko0_ooool02_l0C?oooooooooooooooooo
02koooooool0oggoooooo`3Zooooool2o`0Xo`;o0?nj00?oE`3oooooooooool05oooool3o`3omQ?o
oooo0ol0ROl<ooooo`Co05;o3Oooool9o`3o`0?o0?n?0_ooool;obH0oaOooooo4?l0XOlJooooo`co
0<co8OoooolBo`3oc0So0?n3;_oooom5oeL0oaWooooo000Jooooo`03o`000?oooooooooo013ooooo
00?oo`00ooooooooool0LOooool03ol0XOoo08Woo`2^ool0ogOo04coo`3o`?oooooo0?o`o`0^oooo
oooo05Woo`0@ool0olKoooooobH0o`02o`2?o`Kooooo00?o08ooooooooooool01?ooool01?l0oo3o
ooooo`3o=?l0=?l2ooooo`04o`3o8_oooooo0?mgo`2^o`;ooooo00Co0?Kooooooooooooo04co0ooo
ool2o`0^o`;o0?mm00?o02Soo`3Zooooool00_mG0?l01?oooooo0?njo`3o^_l0okXCooooo`?o0?of
6Oooool3o`29o`Gooooo1?l0D_lJooooo`Oo0?o01?l0ohl5oooooaSo9P3o0oooool[oaX0oagooooo
2ol0ol`?o`3oPgkooooo2_mG0?l?ooooo`006_ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo077ooooo017o0:7oo`29ool0[_oo0?mgo`1<ool0ol3oooooo`3ol?l0;_ooooooo`0dool0
4?oo0?o6obH0oooooooo08ooooooo`04o`3oC0?ooooo00?o08ooooooooooool00oooool01Ol0oo3o
ooooooooool0ocCo03Co00;ooooo00Co0?lRooooool0ogOo0:ko0_ooool01?l0m_ooooooooooool0
C?l4ooooo`;o02So0omG0?l6ooooo`Co0?nj3?ooool3o`3omQoooooo1Ol0D_lUooooo`Oo0?o000?o
0?n?oaX0oolJ0?l05olJ0?lHobH0o`Ko0<co0_ooool>o`2QobKo6P3oZ?ooool001[ooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`1aooooo`0?o`2Qool0ROoo0:koo`2Kool0C?oo0?o0
ooooool0;_oo0?ldo`1Iool0=?oo013ooooooolV0?oo08oo00;o0?m<0oooool7ofT0o`?ooooo2?mG
0?l01_l0ob;oooooo`3oMol0[_ooooooo`3fo`?ooooo00Co04coooooool0:?oo02So0_mG0?l2o`0^
o`04o`3oOOl0j_oo0>[oo`3Zo`Oooooo1_l0okX5ooooo`03o`3om_oooooooooo01cooooo1?l0D_l3
ooooo`Go08Wo7?ooool>oaX0o`Wo0?o01?l0ohlHooooo`So0<co1?oooolRobH0o`Oo0?o<4oooool_
oaX0odCo0:7o=Oooool001[ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`1aoooo
o`0@o`2Qool0ROoo0:koo`1<ool0Jooo0?o0ooooool0;_ooooooo`1Iool0=?oo013ooooooolV0?oo
ooooo`3oC0?ooooo0_mY0?l2ooooo`05o`3oC?ooooooooooo`2?oomY0?l00_mG0?l2ooooo`04o`3o
l?oooooo0?ldo`0do`;ooooo3OmG0?l4ooooo`Go02ko00Co0>[oo`3oOOl0oggo0?mm2?ooool3o`3o
^P;o0?of7?ooool3o`1Bo`cooooo1Ol0ROl<ooooo`_o6P3o5oooool<o`3o`0?o0?n?1Oooool8o`3<
o`Oooooo4_l0oh<<ooooo`So0?o<00?oooooobH0oolV0?l0YolV0?l:o`2Qo`oooooo000Jooooo`03
o`000?oooooooooo013ooooo00?oo`00ooooooooool0LOooool03ol0XOoo08Woo`2^ool0C?oo06_o
o`3o`?oooooo02koooooool0=?ooooooo`0@oooooooo9P3oo`3oC003ooooo`03ofT0oooooooooooo
00;ooooo00Ko0?m<ooooooooooooE`3oo`2?oomY0?l2ooooo`oo02So0_ooool00ol0C?oooooooooo
o`09ooooo`Oo02ko1_l0ogd00ooooooo0?ofooooo`04o`3o^QKooooo0ol0D_lDooooo`?o08Wo2OlJ
0?l7oooooa3oG@3o5oooool8o`3<o`Co0?o00ol0ohl8o`3oPaGo0?mB2Ol0olaZo`3oDQOo6P3o:_oo
ool7o`3odP[o9P3o3oooool001[ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1`
ooooo`0>o`2Qool0ROoo0:koo`1<ool0Joooooooo`3ol?l0;_oo05Woo`0dool04?oo0?o6oooooolV
0?l3ooooo`03ofT0oooooooooooo00Cooooo00Oo0?m<oeL0ooooooooooooo`2?oomY0?oo02So00;o
oooo00Co0?o`oooooooooooo03Co1?ooool01Ol0ob;o0?mgo`2^oooooooo0?Ko00?ooooo00?o04co
ooooooooool02_ooool3o`3Zo`;ooooo3_l0;_l3o`3o^Pkooooo1?l0D_l2ooooobSoG@3o1oooool9
o`3oDR_oG@3o0ol0ol04o`3oS`Kooooo2ol0ola7ooooobCo08?o7ooooolGoaX0oa?o0?oB8?ooool0
01[ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1`ooooo`0>o`2Qool0ROoo0:ko
o`1<ool0Joooooooo`3ol?l0;_oo05Woo`0dool04?oo0?o6obH0ool0Sol3ooooo`03ofT0oooooooo
oooo00Cooooo00?oE`3oo`3oC?ooool00_l0:?l01OooooooJ@3ooooooooooooo0?o`00?ooooo00?o
03Coooooooooool00_ooool01Ol0ob;o0:kooooooooooooo0?Ko00?ooooo00?o04coooooooooool0
3?ooool4o`3Zo`03ooooool0ooKo0?of00Oooooo0_l0ogd5o`0^o`;o0?nj1Oooool;oed0o`cooooo
1_lJ0?l8ooooo`?o0?mB2?l0ROl:o`3oDQ;ooooo1ol0c?l6o`3oPaGooooo;omM0?l6ooooob[o08?o
9?oooolfo`23obCo6P3o3oooool001[ooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`1`ooooo`0=o`29ool0m_oo0:koo`1<ool0Joooooooo`3ol?l0;_oo05Woo`0dool04?ooooooobH0
o`03ooooo`03ofT0oooooooooooo00Cooooo00CoE`3ooooooooooooo02So0_ooool00ol0Sooooooo
ofT0o`02ooooo`05o`3ol?ooooooooooo`0dool0oc@01?ooool01?l0ob;o0:koooooool0m_l4oooo
o`03o`1<oooooooooooo00kooooo00Co0?ofo`3Zool0j_oo0>[o3Oooool00ol0oggo02kooed0o`05
oed0o`03o`1Boooooooooooo00gooooo1olJ0?l>o`3oDP_ooooo2ol0ROl9ooooo`;o0?n31_l0c?l2
o`3oPa_ooooo2?l0ol`<ooooo`go0?o04ol0PolGoed0oe;ooooo2ol0om8_ooooo`_o08?o3oooool0
01[ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1`ooooo`0=o`29ool0m_oo0:ko
o`1<ool0Joooooooo`0^oooooooo05Woo`0dool04?oo0?m<obH0o`03ooooo`03ofT0ool0okCo0?nd
00?o0?nd00GooooooeL0ool0:?oo02Soo`3oC003ooooo`03o`2?oomY0?oooooo00;ooooo00Co0?o`
oooooooooooo03Co1Oooool01?l0ogOo0:koooooool0m_l4ooooo`;o04co3?ooool2o`3omPCooooo
1?l0j_l9ooooo`;oG@3o0_ooool2o`1Bo`?o02ko00?o0?njooooooooool01oooool5oaX0o`Co0?mB
9oooool;o`29oacooooo1ol0ol`Eooooo`co08?o4_l0ol0HooooobkoG@3o6Oooool;o`3odUCooooo
000=ooooo`?o00002_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo073ooooo00co
08Woo`2^ool0ogOo04coo`1[oooooooo02koooooool0FOoo03Coo`0@oolV0?l3ooooo`03ofT0oooo
oooo0?nd00Cooooo00?oE`3oo`0Xooooool00_ooool01_l0odcoooooooooool0SoooooooofT0o`;o
oooo00Go0?o`ooooooooooooooooo`0do`05ooooo`04o`2^ool0ob;oooooo`3fo`Gooooo0_l0C?l9
ooooo`03o`3om_oooooooooo00Sooooo0ol0j_l3ooooo`?oG@3o0_ooool2o`1Bo`Cooooo00Co0?mm
o`0^ool0;_oo02ko0_l0okX00ol0oe;o6P3ooaX0o`02oaX0ob[ooooo1ol0oh<5o`3<o`Gooooo2ol0
ROl:ooooo`Oo0?o<4?ooool<o`23oa_ooooo0ol0ohlGo`3o`2oooooo6?mM0?l00ol0om;ooooooooo
o`1Mooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?oo`00
ooooooooool0L?ooool03?l0ROoo0:koo`1<ool0Jooo0?o0ooooool0;_ooooooo`0doooooooo013o
obH0o`?ooooo00?oJ@3oo`3o]?ooool01?ooool00omG0?oo02Soooooo`03ooooo`06o`3oC?oooooo
ooooo`2?ooooooooJ@3o0_ooool01Ol0oo3ooooooooooooooooo03Co00Gooooo00?o0:koo`3o8_l0
m_l01oooool2o`1<o`Gooooo0_l0ooH>ooooo`?oG@3o0oooool2o`1Bo`;ooooo1Ol0oe82ooooo`04
o`3oOOlJ0?oo6P3ooaX0o`;o0?nj9Oooool7o`3oP`?ooooo1?l0c?lEooooo`co08Wo2Oooool<o`23
oc;ooooo3ol0ohlGo`3o`1Gooooo4Ol0om8:oooooaOoG@3oBOooool000kooooo00?o0000oooooooo
ool02Oooool4o`00017ooooo00?oo`00ooooooooool0Koooool03?l0ROoo0:koo`1<ool0Jooo0?o0
ooooool0;_ooooooo`0doooooooo013oobH0o`?ooooo00?oJ@3oooooooooool00oooool01?mG0?oo
02Soooooool0ok@4ooooo`08o`3oC?ooooooooooo`2?ooooooooJ@3oooooool0oo03ooooo`03o`0d
ool0ocCooooo00Cooooo00?o0:koooooool0m_l02?ooool2o`1<o`03ooooool0ooKo0?of00gooooo
0omM0?l3ooooo`04o`3Zool0D_oo05;oooooo`?o0?mB1Oooool3oaX0o`?ooooo0ol0;_l2o`3o^Qco
oooo1_l0oh<5ooooo`Go0<co5oooool6o`3oc0Sooooo2Ol0Pol3o`29odcooooo5Ol0ohl5o`3o`13o
0?oB0ol0ol0_ooooobooG@3o2ol0oeT?ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01;ooooo00?oo`00ooooooooool0Koooool03?l0ROoo0:koo`1<ool0Jooo0?o0o`3o
l?l0;_oo05Woo`0dool04?oo08ooobH0o`;ooooo00?oJ@3oooooooooool00oooool00omG0?oooooo
o`0Xo`02ooooo`05o`3o]?ooooooooooooooool0od`00_ooool01_l0SooooooooooooomY0?oooooo
o`3ol0?ooooo00?o03Coo`3o=?ooool01?ooool01Ol0[_ooooooo`3fool0m_oo0?lR00Kooooo00?o
0?ofo`1<ooooool03Oooool00omM0?ooooooooooo`04ooooo`03o`1Bool0oe;o0?mB00?o0>[o0ooo
ool3oaX0o`Wooooo1?l0;_l00ol0ok[oooooooooo`0Booooo`Go0?n31oooool4o`3<oaKooooo1_l0
ol`8ooooo`Ko08?o3?ooool/o`29ob7o00[o4Oooool8o`3odQ?o0?n?5_l0ol0eoooooa;o0?mI00?o
oooooed0oomM0?l02OmM0?l?ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01;ooooo00?oo`00ooooooooool0Koooool02ol0ROoo0:koo`1<ool0Jooo0?o0o`0^oooooooo
05Woo`0dool04?oo9P3o00?ooooo00?oJ@3oooooooooool00oooool00omG0?oo02Soooooo`07oh40
o`04o`3oC?ooooooooooo`2?o`;ooooo00?oJ@3oo`3ol?ooool00oooool00ol0=?oo0?ldooooo`04
ooooo`04o`2^ooooooooooooo`3fo`?o0?lR0_ooool00ol0ooKoooooooooo`03o`1<o`Wooooo0_mM
0?l5ooooo`;o05;o00?o0?mBooooooooool00oooool3oaX0o`go0?lj0_ooool00ol0oggo02koo`0^
o`02o`0^o`_ooooo1_l0oh<9ooooo`?o0<co5?ooool6o`3oc0Wooooo1Ol0PolIooooobGo00[o0ooo
oolNo`29obgo00[oJ?l0ROl?ooooo`003Oooool2o`0000_ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`1_ooooo`0;o`29ool0[_oo04coo`1[oooooooo02koooooool0FOoo03Coo`0@
oolV0?l00_ooool00omY0?ooooooooooo`03ooooo`03oeL0oooooooo02So00;oP@3o0_l0ocX01?l0
okCo0?ljo`3o>_l0ocX3oh40o`06ooooool0SooooooooooooomY0?oo0?o`1?ooool00ol0=?oo0?ld
ooooo`04ooooo`04o`2^ool0ogOoooooo`3fo`;ooooo00?o0?lRo`3om_l0ob800_l0ob83ooooo`?o
04co1Oooool00omM0?ooooooooooo`02ooooo`;o0?mB00?o05;oooooooooool00ol0ocX3oaX0o`?o
0?lj0ol0j_l:ooooo`Go0?lj0_l0ogd4o`0^o`;o0?lj1Ol0oh<3o`3o>PSooooo1?l0c?lBooooo`Go
0?o<2Oooool6o`23oa;ooooo3?l02_m5ooooo`[o0?oB9?ooool_o`0:oaGo0?n?9?l0ol0?ooooo`00
3_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0
Koooool02ol0ROoo0:koo`1<ool0Joooooooo`0^oooooooo05Woo`0dool04?oo9P3o00;ooooo00?o
J@3oooooooooool00oooool00omG0?oo02Sooh40o`03o`3o>P;ooooo00So0?ndoooooooooooooooo
o`3o>_l0odcoP@3oo`2?o`?ooooo00?oJ@3oo`3ol?ooool00oooool00ol0=?oo0?ldooooo`04oooo
o`06o`2^ool0ogOoooooo`3foooooooo0?of1?ooool6o`3o8P?o04co0_mM0?l2o`3o8P?o0?mB0_l0
D_l3o`3o>P03o`3o8_lJ0?oo6P3o00Wooooo1?l0j_l?ooooo`;o0?n31?l0;_l6ooooo`Go0?lj0ol0
c?l@o`3o>PKo0?o<1ol0ocX00ooooooo08?oo`23o`04o`23o`cooooo3?l02_m6ooooo`_o0?oBE_oo
ool7o`3oFAOo00[o00?oooooo`3oSol0ohl07ol0ohl?ooooo`006_ooool00ol0003oooooooooo`0B
ooooo`03ool00?oooooooooo04Cooooo0ol0VolXooooo`0>o`29ool0[_oo04coo`1[oooooooo02ko
ooooool0FOoo03Coo`0@oolV0?ooooooo`3o]?mY0?l5ooooo`03oeL0oon10?ooP@3o00Kooooo00Ko
0?ndooooooooooooooooo`3oC?ooool2oh40o`04o`3o>_ooooooooooofT0o`Gooooo00?o03Coo`3o
=?ooool01?ooool2o`2^o`03o`3om_l0m_oooooo00cooooo00?oG@3oooooool0C?l00_l0C?l2o`3o
>P03o`1Bool0oc[o0?lj00;ooooo0_lJ0?l2ooooo`Co0?lR2Oooool3o`3Zo`Sooooo1?l0oh<5oooo
o`06o`3o^_l0;_oo02koo`0^ool0ok[o0?mm0oooool3o`3<o`kooooo1Ol0ol`8ooooo`Ko08?o1_l0
ocX<o`0:odKooooo3?l0om9Eooooo`co0?mI2_l0obPDooooob;o00[o3oooool001[ooooo00?o0000
ooooooooool04oooool00ooo003oooooooooo`12ooooo`03o`2Kool0olKo0?o600;o09_o9_ooool0
3_l0XOoo08Woo`2^ool0C?oo06_oooooool0;_ooooooo`0dool0odco013oobH0ooooooooJ@3o1Ooo
ool01?mG0?oo02Sooh40ool0ocX3oeOo00?ooooo00?o0?ndooooooooool00_ooool01?l0odcooooo
o`2?oon10?l2o`3o>P03oooooomY0?oooooo00Cooooo00?o03Coo`3o=?l0oc@00_ooool3o`3omP03
o`2^oooooooo0?Ko00[ooooo0_mM0?l2o`3oDP;o0?lj00?oooooo`1<ool0C?l00_l0C?l00ooooooo
6P3ooaX0o`08ooooo`Ko0?lR1_ooool3o`3Zo`Go0?n33Oooool5o`0^o`03o`3o^_l0oggooooo00Wo
oooo1Ol0ol`8ooooo`Go08?o0oooool9o`0:o`[ooooo5ol0ocXVooooo`_o0?oBEOooool<o`3oF@_o
0?lXD?ooool001[ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`12ooooo`05o`2K
ool0FOoo05Woo`29ool0Vol09_ooool02ol0XOoo08Woo`2^ool0C?oo06_oo`3ol?l0;_ooooooo`0d
ool0Sooo9P3o00;ooooo00CoJ@3ooooooooooooooooo0_mGo`000omG0?ooP@3oo`3o>P06ocko00;o
oooo00?o0?ndooooooooool01?l0ooH01_l0SoooP@3oo`3om_l0oc[o0?o`ofT0o`?ooooo0_l0ooH0
1?l0=?oo0?ofo`3om_l0ooH4ooooo`03o`2^ool0ogOo0?Ko00Sooooo00CoG@3oo`3o>_l0oe;o0?lj
1?ooool01Ol0D_oooooooooooooooooo6P3o00;o04co3_ooool4o`3o8PGo0?n30ol0j_l=ooooo`?o
0<co1?ooool<o`0^o`Wooooo1?l0Pol2ooooo`Ko00[o:_oooolHo`3o>PGooooo2Ol0om9Cooooo`03
o`3o:?l0oeWo0?mI00[o0?mI1Ol0obQRooooo`006_ooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooooooo04;ooooo00Ko05Woo`1[ool0Jooo05Woo`29ool0VolUooooo`0>o`2Qool0ROoo0:ko
o`1<ool0ol3o0?o`o`0^ool0ob;o03Coo`0@oolV0?ooooooo`3o]?mY0?l3ooooo`04oeOo0?oooooo
E`3ooh40o`Kooooo00?oEol0ocko0?l0ooH01?l0ooH2ooooo`04o`3oC?oooooo08oooh40o`?o0?of
00?oJ@3oo`3om_l0ooH00oooool01?l0=?ooooooo`3o=?l0oc@4ooooo`03o`2^ool0ogOo0?Ko00Go
oooo00Co0?ljoed0ool0oe;o0?mB1?ooool2o`1Bo`?ooooo00Co6P3ooooooooooooooooo0ol0C?l;
ooooo`Co0?n30_ooool6o`3o8PCo0>[o1Oooool4o`3<o`_ooooo1?l0ol`2o`3oO@;o0?nj1Ol0;_l4
o`23o`Ko00[oAoooool6o`3odQ;o0?lj?oooool<o`3oFEGooooo3ol0o`X?ooooo`006_ooool00ol0
003oooooooooo`0Cooooo`03ool00?oooooooooo04;ooooo00Ko05Woo`1[ool0c?oo06_oo`1Iool0
VolUooooo`0>o`2Qool0ROoo04coo`1[ool0ol3o0?o`o`0^ool0ob;o03Coo`0@oolV0?ooooooo`3o
]?mY0?l2ooooo`05oeOo0?ooooooE`3ooh40ool0ocX01oooool01Ol0ooKo?_l0ocko0?oooooo0?nd
00?ooooo00Go0?m<ooooool0Sooooooooh40o`02ooooo`03o`3ol?mY0?oooooo00;o0?lj0_ooool0
1?l0=?ooooooooooool0oc@4ooooo`04o`2^ool0ogOo0?Koo`3fo`?o0?lj00?oG@3oo`3oD_ooool0
1?ooool00ol0D_ooooooooooo`02ooooo`03oaX0oooooooooooo00Gooooo0ol0C?l5ooooo`?o0?n3
3?ooool4o`3o8P03o`3Zool0c?oo0<co00;o0<co2oooool4o`3oc0Wooooo0ol0Pol5o`0:o`Go02ko
0_l0okXoooooo`Oo0?oB6?oooolYo`3o>PCooooo1_l0obP<o`3oFC?ooooo;_l0o`XNooooo`006_oo
ool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo047ooooo00Oo09_oo`1Iool04?oo013o
o`3<ool0FOoo09_o02Gooooo01Co0:7oo`29ool0C?oo06_oo`3o`?l0;_ooooooo`3oSol0=?oo013o
obH0ool0okCoooooofT0ooooooooEol0oooooolno`3oP@3oo`0Xo`Oooooo00Ko0?ofoooooomGo`3o
ooooocko0?l0ok@4ooooo`05o`3oC?oooooo08oooooooon10?l00_ooool01?mY0?oooooooooooooo
ool3o`3o>P03o`0doooooooooooo00;o0?ld00?oooooo`3o>_l0ocX00_l0[_l01?l0oc[o0?Kooooo
oomM0?l6ooooo`03o`1Boooooooooooo00;ooooo00?o6P3oooooooooool02Oooool3o`1<o`;o0?n3
3_nO0?l2ooooo`Co0<co00?oooooo`3o8_l0ob800ol0j_l00ol0ob;oooooooooo`02ooooo`Co0?o<
2_ooool00ol0Pooo00[oo`0:o`03o`0:o`Kooooo1?l0ogd<o`0^oboooooo1_l0om8kooooo`co0?lX
2ol0oeU^o`3o>Qgooooo000Jooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0@Ooo
ool02?l0Vooo05Woo`0@ool0C?oo013oo`1[ool0FOoo09_o9?ooool03Ol0XOoo08Woo`1<ool0Jooo
0?o0o`0^oooooooo05Woo`0dool04?oo9P3oo`3o]?mY0?l00_ooool01OmGo`3o?_l0oooooon10?oo
0?lj00Gooooo0_l0ooH3ooooo`04oeOo0?oooooo?_l0o`3o]0Cooooo00So0?m<ooooool0Sooooooo
oh40oooooooo0?o`ofT0o`Gooooo00?o0?ljo`0dool0=?l00ol0ocX4ooooo`04o`2^oomM0?ooG@3o
o`3fo`Cooooo0_l0D_l4ooooo`03oaX0oooooooooooo00?ooooo4onh0?l6ooooo`03o`3<oonO0?oo
W`3o01?oW`3o1_ooool5o`0:oa?ooooo1_l0ogd2o`3o^Pco02ko7?ooool7o`3odSKooooo2ol0obP<
o`3oFAcooooo5ol0o`Y6ooooo`ko0?lj3oooool001[ooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`10ooooo`03o`1Iool04?oo02So00;o02So00?o013oo`1Iool0Vol09?ooool04ol0
XOoo08Woo`1<ool0Jooo0?o`o`0^oooooooo05Woo`0doolV0?ooooooo`3o]?mY0?oooooooeOo0?oo
oooo?_l0oh40ool0:?l00oooool6ogD0o`;ooooo1?l0oe800ol0okCo0?mBooooo`02ooooo`04o`3o
C?l0Soooooooooooo`;oP@3o00?o0?o`ofT0ooooool01_ooool00ol0=?ooooooooooo`03o`3o=0;o
G@3o0_l0[_l01Ol0ogOo0?Koo`3foooooooo05;o00Cooooo0_lJ0?l6okP0o`KoW`3o1oooool3o`1<
o`?ooooo1onh0?l9ooooo`Co0?o<0oooool4o`3Zo`03o`3o8_nO0?ooW`3o02CoW`3o1_l0ogd6o`3o
^QOo02ko1Ol0om8aooooo`co0?lX2ol0oeTAoooooaOo0?l:N_ooool001[ooooo0ol0000Dooooo`03
ool00?oooooooooo03oooooo00[o09_oo`1Iool04?oo04coo`3Tool0:?oo013oo`1Iool0ROoo0:7o
8oooool04ol0XOoo08Woo`1<ool0Jooo0?o`o`0^oooooooo03Coo`2?oolV0?oo0?ndoooooomY0?oo
oooooeOo0?lno`3ooooooh40ool0:?l00_ooool2ogD0o`06o`3om_ooooooooooooooool0oe;oM@3o
2?nh0?l4o`3oDP04o`2?ooooooooooooooooo`;oP@3o00?oJ@3oooooooooool01Oooool00ol0=?oo
ooooooooo`02oed0o`?o0?ld00Ooooooo`2^ooooooooooooo`1Bool0m_oo0?mg00;ooooo0onh0?l3
ooooo`?oW`3o0_ooool2o`3oP`cooooo1?l0C?l2o`3<o`Cooooo2Onh0?l9ooooo`Co00[o0_l0Pol8
o`3o8Q_ooooo4_nO0?lVog/0od[o803oT?ooool001[ooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`0oooooo`03o`2Kool0FOoo013o00?o02ko00Co02Soo`0@ool0FOoo09_o8oooool0
3?l0XOoo08Woo`1<ool0Jooo0?o`o`0^ool0ob;o03Coo`2?oolV0?oo0?ndofT0o`;ooooo00CoEol0
ocko0?ooooooP@3o0oooool01?me0?ooooooo`3om_ooool2o`3oDP;o^03o00SoooooogD0oooooooo
oooooeOo0?lno`3o0?ndooooo`?o^03o00?o0?m<o`3oD_l0Sol01?l0oe82oh40o`Cooooo0ol0oe82
oed0o`Gooooo0_l0oc@01?l0[_oo05;oooooooooool3okP0o`03o`3oMooooooooooo00;ooooo00?o
W`3oooooooooool00_ooool00ol0oh?oooooooooo`0=ooooo`?o0<co0ol0C?l5ooooo`?o0?o<1?oo
ool6okP0o`?o00[o0ol0Pol2ooooo`So0>[o00?oooooo`3o8_l0ob801Ol0ob8Qog/0o`Go803o6?nO
0?l>oooooc?oN`3o5ol0;_lHob00ofWo02ko3oooool001[ooooo00?o0000ooooooooool05?ooool0
0ooo003oooooooooo`0oooooo`0:o`1Iool0Jooo013oo`0:oolV0?oo0=Soo`0^ool04?oo05Woo`2K
ob?ooooo01?o08Woo`2^ool0C?oo06_oo`3ol?l0;_oo0?lRo`0dool04?oo9P3oo`3o]?mY0?oooooo
oeOo0?oooooo?_l0oh40ool0:?oooooo00;oM@3o00Co0?mOo`3om_l0oeoo0?mB0_nh0?l4ooooo`06
ogD0oooooooooooooeOo0?lno`3o0?nd0oooool3okP0o`06o`2?ooooooooooooo`3oD_l0oo3o0?mB
0on10?l01?l0oe;ooooooooooomM0?l2ooooo`;o03Co1?ooool2o`1Bo`?o^03o00?o6P3oooooool0
m_l00_l0m_l00ol0ogOoW`3ooil0o`03ooooo`;o0?n33_ooool2o`3<o`Kooooo0ol0C?l2o`3oc0Oo
oooo1?l02_l2ooooo`Wo^03o1oooool8og/0o`;o0>[o00?oooooo`3o8_l0ob800_l0ob8<ob00oa3o
oooo1Ol0om82ooooo`[o0?mm1Oooool5o`3o^RkoW`3o4ooooolGog/0oaSooooo;olP0?m9ooooo`00
6_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo03oooooo00_o05Woo`0@ool0:?oo
9P3ooaX0oolV0?oo02koo`0@ool0FOoo08Woo`2Qo`0Rooooo`0Co`29ool0[_oo04coo`1[ool0oo3o
02koo`3o8_l0=?oo013oobH0ool0okCoJ@3ooooooomGo`3o?_l0oooooon10?oo02SoogD0o`02o`3o
G`04ooooool0ooKooooookP0o`;o0?mO0_lho`03ooooo`;oM@3o00CooooooeOo0?lno`3o0?nd1?oo
ool01?l0odco^03ookP0oonh0?l2ooooo`05o`3ol?ooooooooooofT0oon10?l00_mM0?l5ooooo`03
o`0doooooooooooo00?o^03o00CooooooaX0oolJ0?oo0?ld0_l0[_l3oil0o`;o0?Ko00?o0?mgo`3o
Pol0oh<03_ooool2o`3<o`Gooooo1?l0ol`2ooooo`?o04co0_ooool4o`0:o`;ooooo1?l0Pol5oooo
o`CoN`3o3?nh0?l4ooooo`Ko803o0_l0j_l00ooooooo0?lRo`3o8P05o`3o8Pgooooo1Ol0om84oooo
o`go0?l:3?l0ogd:o`3o:0Kooooo6?l0okX4ooooobooW`3o:_mk0?lHoooooaOo803o<_ooool001[o
oooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0oooooo`03o`1Iool04?oo00[o00;o
E`3o00Ko6P3oobH0ool0:?oo013oo`1Iool0VolRooooo`0>o`29ool0[_oo04coo`3o`?l0oo3o02ko
o`3oSol0=?oo013oobH0ool0okCoJ@3ooeOo0?lno`02ooooo`03oh40ooooooooM@3o00;ooooo00Co
0?ofocSo0?l0oe;o^03o1Onb0?l3ocSo0005oooooome0?oooooooeOo0?l0ok@01?ooool01?l0odco
ooooo`2?ooooool3okP0o`04o`3ol?ooooooG@3oofT0o`?oP@3o0oooool4okP0o`04o`0doooooooo
oooooaX0o`?ooooo0_nO0?l@oh40o`Cooooo0_l0c?l4ooooo`?o0?o<1oooool4o`0:o`?o04co3?mk
0?l=ooooo`?o803o4Onh0?l2o`3Zo`03ooooool0ob;o0?lR00Ko0?lR1Ol0om89o`3o2Pgooooo2ol0
obP00ooooooo0?mmo`3oO@0@o`3oO@Go0?mI4OoooolFo`3o^Qgooooo;_nO0?lDog/0oaOooooo5olP
0?lKooooo`006_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo03kooooo00Go05Wo
o`0@oolV0?ooE`3oo`0do`02oeL0o`04o`0^ool04?oo05Woo`2Kob;ooooo01;o08Woo`2^ool0C?oo
0?o0o`3ol?l0;_oo05Woo`0dool04?oo9P3ooooooomY0?ooEol0ocko0?ooooooE`3ooh40oome0?l2
ooooo`05o`3om_l0g_oo0=kookP0oonb0?l00_l0g_l00ooooooo0?mOooooo`03ok80o`06ocSo0?oo
ooooM@3ooooooomGo`3o0?nd1?ooool00ol0odcoooooo`2?o`03oed0o`[o^03o2On10?l2oil0o`03
oh40oooooooooooo00;ooooo00Go0?n3o`2^ool0[_oo0:koo`3o=003o`3fo`05o`3o=?l0ogOo0?mg
o`3oMoooool01on10?l3o`3oc0Oooooo00?o00[oog/0oomk0?l01omk0?l5o`1<o`cooooo2?lP0?lD
oooooa7o^03o2?l0ob83ooooo`[o0?lX3oooool9o`3oF@Kooooo5_l0ogdFoooooaOo0?nj=?ooool`
oil0oa;oN`3o3?lP0?l?ooooo`006_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
03kooooo00_o013oo`0XoomG0?oo03Cooed0ool0of_oE`3oo`3Hool0:?oo013oo`29o`0Rooooo`0B
o`29ool0[_oo04coo`3o`?l0;_ooooooo`1Iool0=?oo9P3oo`3o]?mY0?oooooooeOo0?lno`3ooooo
oh40ool0:?ooM@3o0_ooool2o`3No`03ok80oonh0?oooooo00;ooooo00?o0=koooooool0oel00ooo
ool2ok80o`03ogD0ooooooooG@3o00SoG@3o00?o08ooooooooooool00_ooool00ol0oo3ooooooooo
o`03ooooo`03ofT0oooooooo05;o00?ooooo0_lJ0?l00oooooooW`3ooil0o`03o`0do`?ooooo00?o
0?n3ooooooooool00_ooool3o`2^o`06ooooool0m_oo0?Koo`3fool0ocCo0?mg0_l0c?l00ol0ogOo
ooooooooo`02o`3oc0GoP@3o00?oooooog/0oomk0?l00omk0?l2ooooo`?o08?o2Oooool5o`1<o`Oo
803o4oooool;o`3o2PCo0?oB1_ooool5o`3Zoago^03o00?oooooo`3oFOl0oeT01?l0oeTUoooooaOo
0?mm5_oooom7o`3o^Qgooooo7_nO0?l?ooooo`006_ooool00ol0003oooooooooo`0Eooooo`03ool0
0?oooooooooo03kooooo00_o013oo`0XoomG0?ooG@3oob00oomM0?ooE`3oobH0ool0:?oo013oo`1I
o`0Rooooo`0=o`29ool0[_oo04coo`3ol?l0;_ooooooo`0dool0Sooo9P3oo`3o]?mY0?ooEol0ocko
0002ooooo`03oh40ool0:?ooM@3o00;o0=ko00?o>?l0o`3oD_nh0?l01Oooool00ol0g_ooooooo`3o
G`02ooooo`;oG@3o00Go/P3oogD0oolho`3oooooo`3o]002ocko00?ooooo00?o0?m<ooooool0Sol0
1?ooool00ol0oo3oooooooooo`03ooooo`?oJ@3o00?ooooooaX0ooooool00_nO0?l5ooooo`Go03Co
1_ooool4o`2^o`;o0<co00Go0?Koooooool0ocCo0?mgo`3oc002o`3oM`;ooooo0omk0?l4oh40o`04
ooooool0Pooo08?oo`23o`_ooooo1_lP0?l4o`1<o`[ooooo3?l0o`X6ooooo`Go0?oB2_ooool8o`3o
:0Cooooo4_l0j_l4o`3oFAOo^03o;?oooolHo`3oOD;ooooo0omMo`0ko`3o^Poooooo000Jooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0?_ooool01?l04?oo6P3ooed0oolP0?l2o`2?
o`06oed0oomG0?oo0>Coo`0@ool0FOoo0:7o8?ooool06?l0XOoo08Woo`1<ool0Jooo0?o`o`0^ool0
ob;o03Coo`2?oolV0?ooooooofT0oomGo`3o?_l0ooooool0oc[oP@3oogD0oooooooo0=koo`3om_l0
oe;o/P3ookP0o`Kooooo00Co0=kooooooomM0?ooG@3o0oooool01onb0?ooM@3oocSo0?mGo`3o0?nd
oooooolno`000_ooool01?l0odcoooooooooool0Sol4ooooo`05o`3ol?ooooooooooooooool0D_l0
0_ooool01?lJ0?ooJ@3ooil0oonO0?l6ooooo`;o0?n31?ooool5o`0do`?ooooo0_l0c?l3o`2^o`?o
0?Ko0_ooool3og/0o`;o00[o00Go0?ldooooooooooooooooo`23o`04oh40o`Oooooo1?lP0?l9oooo
o`03o`3o2_l0C?oobP3o04[obP3o6?l0j_m6okP0oaGo0?mm:omMo`0`ooooo`ko0>Co3oooool001[o
oooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0mooooo`05o`2Kool04?oo9P3ooed0
ool0Sol00_mY0?l01_mM0?ooE`3oobH0ool04?oo04coo`2Kob3ooooo01Oo0:7oo`29ool0C?oo06_o
o`3ol?l0;_oo0?lRo`0dool04?oo9P3ooooooomY0?ooEol0ocko0?ooooooP@3ooeL0oome0?oo0=ko
ocSo0?l0ooKo/P3ookP0o`07ooooo`04o`3NoomM0?ooooooo`3oG`Cooooo00Oo/P3oogD0oolho`3o
>?l0o`3o]?oooooo?_l000;ooooo00Co0?m<oooooooooooo08oo1?ooool00ol0oo3o05;oo`1Bo`02
ooooo`03oaX0oonO0?ooW`3o00;ooooo2?mY0?l9ooooo`Co03Co0_ooool2o`3oc0;o0:ko0omk0?l2
o`0:o`?ooooo00?o0?mgolX0ooo:0?l07?o:0?l2oego00So04co2OmMo`04o`3odP?oGOl02?l0obPH
ooooo`Oo0?mI2_ooool_olX0oa?o0>[o7?l0@?mMokP0oa?o0>Co1_l0ofDGooooo`006_ooool00ol0
003oooooooooo`0Eooooo`03ool00?oooooooooo03gooooo00Co09_oo`0@oomG0?ooG@3o0omk0?l0
1_mY0?oo00CooeL0ool0:?oo013oo`29ob3ooooo01Ko0:7oo`29ool0C?oo06_oo`3ol?l0;_oo0?lR
o`0dool04?oo9P3ooooooomY0?ooooooocko0?ooooooP@3oo`0Xoome0?oo0=koo`3om_nb0?oo^03o
2?ooool01OmM0?oo0=kooooooooooooo0?mO00Cooooo00Oo/P3oogD0oooooooo>?l0o`3o]?oooooo
?_l000;ooooo00Co0?m<oooooooooooo08oo0oooool00ol0D_oo0?o`o`3ol003oil0o`Oooooo00?o
0?n3ooooooooool00_ooool=ofT0o`?o03Co0omk0?l00ooooooo00[oo`0:o`06olX0o`03o`23oooo
oooooooo00?o0?mg00?o0?ldob00oolP0?l00_lP0?l2oego00GoP@3o00?o0?l:oego0?mMo`001OmM
o`0>ooooo`co04co1?l0obPHooooo`So0?mI;_oooolBo`10obkobP3o4ol0j_l_o`3To`;o0>[o6_l0
@?lQokP0o`oooooo000Jooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0??ooool0
1Ol0FOoo00[ooeL0oomM0?ooN`3o00;oB_l000KoN`3ooed0oomG0?oo02Soo`0@ool0ROlPooooo`0F
o`2Qool0ROoo04coo`1[ool0oo3o02koo`3oSol0=?oo013oobH0ooooooooJ@3oocko0?oooooo0?lj
oh40oome0?oo0=koocSo0?l0ooKo/P3ookP0o`Oooooo2OoX0?l2ooooo`06ok80oome0?ooooooo`3o
]?lho`3ooooo0_lno`001Ooooooo0?m<oooooooooooo08oo00;o05;o00Cooooooil0oonO0?oo6P3o
1oooool2o`3oP`gooooo0_l0c?l00ooooooo0?o<ooooo`03og/0o`KobP3o0_ooool2o`23o`04o`2^
ool0m_oo0?Koo`3fo`Go803o0ol0ogL3o`3o=003o`3o2_oooooooooo00;ooooo2On10?l=ooooo`Co
0?oB1?l0obP4ooooo`_o04co2_ooool7o`3oFB[ooooo3?l0@?lEooooobOo0?lR1?l0i?l^olX0oaKo
oooo5_l0ofDdooooo`006_ooool3o`0001Kooooo00?oo`00ooooooooool0??ooool01?l0FOoo6P3o
oed0oomk0?l3oh40o`07og/0oomY0?ooE`3oobH0ool04?oo05Woo`2Qo`0Oooooo`0Fo`2Qool0ROoo
04coo`1[ool0oo3o02koo`1Iool0=?oo013oobH0ooooooooJ@3oocko0?ooooooP@3ooeL0oome0?oo
>?l0o`3om_nb0?oo0?mBokP0o`Gooooo0_oX0?l4ooooo`03o`3NooooooooW`3o00;oW`3o0_oX0?l0
0onO0?oo/P3ooil0o`02oil0o`06ocSo0?ooooooooooocko0?oooooo05;o1OnO0?l2oaX0o`03oooo
ool0oo3o0?o`00?ooooo0_l0oh<>ooooo`03o`3<oooooooo0?o<00?oN`3o0oo:0?l00oooooooJ@3o
ofT0o`03ofT0o`Co03Co1?lP0?l00ol0[_oo0?Koo`3fo`03o`3o2P;ooooo1?l0ogL3o`3o=0[ooooo
3?n10?l00ol0om;o0?lXo`3o:00Eooooo`_o04co9Oooool;o`10oc3ooooo6?l0i?l2oooooaOo0?lR
6Oooool_olX0oc7ooooo000Jooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0??oo
ool01Ol0FOoo9P3ooed0oomk0?ooP@3o00;o^03o00OoP@3oofT0oomM0?ooE`3oo`0@ool0FOoo08Wo
01oooooo01Go0:7oo`29ool0C?oo06_oo`0^oooooooo05Woo`0dool04?oo9P3oofT0oooooooo?_l0
oooooon10?ooE`3oogD0oolho`3o0?ofok80oonh0?l00_ooool3ogGo0003onP0oomM0?oooooo00?o
oooo0onO0?l00ooooooo0?mOooooo`02ooooo`;oj03o0_nb0?l00oooooooW`3ooil0o`05oil0o`;o
oooo00?o08oooaX0ooooool01?ooool00ol0oo3o0?n3o`3oP`0>ooooo`;o0<co00?oooooog/0oomk
0?l00oo:0?l2ooooo`;o00[o00?oGOl0ooooooooool00_l0Pol4ofT0o`Co03Co00Coooooo`2^ool0
[_oo0:ko0_l0m_l6ooooo`?o0?mg0ol0oc@<ooooo`Co0?oB00?o0?lXooooooooool02on10?l<oooo
o`Go0?mI1oooool<o`1<o`gooooo3?l0@?lZoooooa7o0>Co<OoooolAo`3o8Pco0?mU4ol0ob8Hoooo
oaOobP3o6_ooool001[ooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`0looooo`05
o`1IoomG0?ooG@3oog/0oonh0?l00_o:0?l01onh0?ooP@3oofT0oomG0?oo013oo`1<ool0ROl07ooo
ool05Ol0XOoo08Woo`1<ool0Jooo02koooooool0=?oo08ooo`0@oolV0?ooJ@3oocko0?oooooo0?lj
oh40oome0?ooooooocSo0?l0ooKo/P3ookP0o`02ogGo00;ooooo00?oj03ooooooomM0?l00_mSo`02
oil0o`?oHol000?o0=koof?o0?l0oel00oooool01?l0D_ooj03oonP0oonb0?l2o`1Bo`06oooooolh
o`3ooooooooooolno`3o0?m<0_lJ0?l00ooooooo08ooooooo`03ooooo`03o`3oPol0oo3o0?o`00go
oooo00Co0<cooooooomk0?ooN`3o0_o:0?l3oego00;o00[o0oooool2o`23o`?o803o00?o0?l:of?o
0?mSo`001?mY0?l4o`0do`?o0:ko1?l0m_l4of?o00Go0?mg1_l0oc@4o`3odQ;oHol02on10?l00ol0
oeWoooooooooo`0Fooooo`03o`1<ool0@?oo043o00[o043o:oooool;o`3Tod;ooooo4Ol0ofDOoooo
oboo0?lR2oo:0?l?ooooo`006_ooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo03co
oooo00Co05;ooeL0oomY0?ooW`3o0_o:0?l02?l0oaKobP3ooh40oomY0?ooE`3oobH0ool04?oo06_o
7oooool05Ol0XOoo08Woo`1<ool0ol3o02koooooool0=?oo0?o6obH0ooooooooJ@3oocko0?oooooo
0?ljoh40oome0?oo>?l0o`3om_nb0?oooooookP0o`03ooooo`08onP0oomSo`3oG@3oof?o0?oooooo
W`3ooooooomeo`04ooooo`03o`3Nool0D_oo05;o00;o05;o0oooool2onP0o`04o`3o]?mGo`3ooooo
ocSo00?o6P3o00Co?_l0o`3oC?oooooooooo0_l0Sol2o`3oP`?ooooo00?o0?o`ooooooooool02Ooo
ool00ol0c?ooooooog/0o`02olX0o`;oGOl000?oooooo`0:ool02_l00omSo`02o`23o`;o803o2_oo
ool4ofT0o`Co03Co0_l0[_l00ooooooo0?Koo`3fo`03o`3fo`Cooooo0_l0ogL4o`3odPWo0?ld3Ooo
ool3of?o00Co0?mI1?mSo`0<oh40o`?oHol02ol0@?l;of?o02;o04co2_l0i?lloooooa7o0?mUNOoo
ool001[ooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`0kooooo`06o`2Kool04?oo
G@3oog/0oonO0?oobP3o0_l0oel02?o:0?oo^03oog/0oomM0?ooE`3oo`0@ool0FOoo0:7o7_ooool0
5Ol0XOoo08Woo`1<ool0ol3o02koo`3o8_l0=?oo013oobH0ooooooooJ@3oocko0?ooooooP@3oogD0
ool0g_oo>?l0o`3om_nb0?oo^03oogGo0003ooooo`03onP0ool07?ooG@3o00;o01co00GoW`3oo`0L
ooooooooMOl0ooooo`03o`1Bo`03o`3Noooooooo0?mO00;oHol00_ooool2oaX0o`06onP0oolJ0?oo
6P3ooaX0oooooooo>?l00_ooool00olno`3o0?m<o`3oP`02o`3oP`03o`2?oooooooooooo00?ooooo
0_l0oo07ooooo`;o0<co00Co0?o<olX0ooo:0?oooooo0omSo`001?l02_ooooooooooooooool2o`23
o`;o803o4?ooool4ofT0o`Co03Co0_l0[_l2ooooo`Go0?Ko00?o0?oBooooooooool00_ooool6o`3o
M`?ooooo1Ol0oc@6ooooo`Go0?mI3_ooool6o`10o`coP@3o4Oooool@of?o00co0>Co0_ooooo1o`1<
o`oooooo000Jooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0>oooool04?l0Vooo
013ooed0oomk0?oobP3oo`80oomeo`3oM@3oo`3oGoo:0?ooP@3oofT0oomG0?oo013oo`1<ool0ROlN
ooooo`0Do`2Qool0ROoo04coo`3o`?l0;_oo0?lRo`0dool04?oo9P3ooooooomY0?ooooooo`3o>_n1
0?ooM@3oocSo0?oooooo/P3ooooooonh0?l3ooooo`03onP0oomSo`3oG@3o00;ooooo00KoW`3ooooo
oooooooo01coooooool0D_l2ooooo`;o0?n300?o0=koo`3oPol0oh<00olJ0?l3o`3oP`;oj03o1ol0
oh<01?lno`3o0?m<ooooooooool2o`2?o`Gooooo0ol0oo03ooooo`04o`3<oomMo`3obP3oolX0oa?o
j03oAOoo0?83o`10o`Wooooo2Om_0?lHoh40oe_oK`3oOOmSo`0?ooooo`006_ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo03[ooooo00Ko05Woo`0@oomM0?ooP@3oolX0oome0?l2onP0
o`08ogD0ooo:0?ooW`3oog/0oomG0?oo9P3oo`1<ool0ROlNooooo`0Eo`29ool0[_oo04coo`3o`?l0
;_oo0?lRo`0dool04?oo9P3oofT0oolno`3oooooo`3oGon10?ooM@3oocSo0?l0ooKo/P3oogGo0?nh
0?oooooo00;o01co00Goj03ookko0?mM0?oo__l0oil0o`02okko0004ooooool0D_oo01coo`0Lo`;o
0?n30_ooool3oaX0o`Cooooo0omSo`001?nb0?ooj03oonP0oooX0?l4ooooo`;o>?l00_l0od`2oooo
o`;o08oo1?ooool2ocSo0004o`3ol?l0c?oo0<coolX0o`?oj03o00?o>?l0ooooooooool00_l02_l2
o`3o2P03o`23oolP0?oo803o00Cooooo1Ooo0?85ooooo`Koj03o00?oooooo`3o:?l0obP00ol0obP2
ocSo0003o`3od_mY0?ooJ@3o00;oJ@3o1Ol0=?l4o`2^o`;o0?Ko2Oooool00ol0oeWo0?mgo`3oM`07
o`3oM`;ooooo1?l0oc@5o`10o`;o0?ld0_m_0?lTool0lPSo0>Co00?ooooooh40oon10?l0>?n10?l;
o`3oIAKooooo;_m_0?lBoooooaSoKol05Oooool00onbo`3o8?l0ob3o000=ob3o00oooooo000Joooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0>_ooool01Ol0FOoo013ooed0oonh0?oo
bP3o00Coo`3b00So0?mOolX0oomk0?ooJ@3oobH0ool04?oo06_oo`2Qoacooooo01Co0:7oo`29ool0
ok[o04coo`3ol?l0;_oo0?n?o`0dool04?oo9P3oofT0oolno`3oooooo`3oGon10?ooE`3oocSo0?l0
ooKo/P3ookP0o`;ooooo00Ko01coof?o0?oX0?ooG@3ooooooonO0?l3ooooo`04o`1Bool0oh?oGOl0
oego00Co6P3o00CoGOl0ooooool0g_oo0?mO1_ooool01?mSo`3o/P3oo`3o]?mGo`04onP0o`Cooooo
00Co0?m<ocSo0?lho`3o>?l00_l0Sol2ocSo0003oooooooX0?ooj03o00?oj03o0ol0oo02ooooo`04
o`0:ool0o`[o0?l:ooooo`;o803o1_oo0?8=ooooo`?o0?lX1OoX0?l3o`3odP?ooooo0_lho`05ofT0
o`Ko03Co0ol0[_l5o`3fo`03o`3oFOoooooooooo00Cooooo4Om_0?l;o`3o=1?ooooo2?l0i?l_ool0
lPOooooo3?l0ofD00oooooooP@3ooh40o`2Loh40o`oooooo000Jooooo`03o`000?oooooooooo01Oo
oooo00?oo`00ooooooooool0>_ooool01_l0FOoo9P3oog/0ooo:0?oo0?mOool0lP;onP3o00Woo`3b
ogD0ooo:0?ooW`3oofT0oomG0?oo013oo`1Iool0Vol07?ooool07ol0XOoo08Woo`2Kool0C?oo0?o`
o`0^ool0ohoo03Coo`0@oolV0?ooJ@3oocko0?oooooo0?mOoh40oomG0?oooooook80oomeo`3o^03o
ooooool07?ooHol0onP0ooooooooG@3oo`3o4?nO0?oooooooego0?l0D_l00_ooool01Onno`3o6P3o
okko0?l07?ooMOl000;ooooo0_mMo`000ol0g_oo0?mOooooo`06ooooo`04ok80ool0okCo0?ndoeOo
00;ooooo3OoX0?l01?l0c?oobP3oolX0oomk0?l4ooooo`05o`3ol?l02_oo0?o`oooooolP0?l00ooo
0?8?ooooo`Co0?lX1Oooool3o`3odPKoj03o1oooool6ofT0o`Go03Co1?l0[_l00ol0m_ooK`3oofl0
o`03ofl0o`?o0?Ko0ol0@?l:ooooo`co0?mg2ol0oc@8o`3Toc?ooooo1?l0ofE5ool0lP;ooooo5om_
o`0Xok;o00_o8?l08Om_0?l?ooooo`006_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooo
oooo03[ooooo00Ko05WooeL0oomk0?oobP3oo`3oGooo0?82o`3oo009ooX0oooo0?;obP3ooil0oomk
0?ooE`3oobH0ool0C?oo08Wo01cooooo02;o0:7oo`29ool0C?oo06_oo`3ol?l0;_oo05Woo`0dool0
4?oo9P3oofT0oolno`3o0?mOoh40oome0?oo>?l0o`3om_nb0?oooooookP0oooooooo01coonP0oooo
ooooG@3oo`3o4?nO0?ooGOl0o`3o4?l0oh?o05;oo`3o4?oooooo6P3o0_ooool00onno`3o01coogGo
0004ooooo`03o`3Nool0oeooGOl000;oGOl01?ooool3ok80o`;oEol02?mSo`03o`3oC005o`3<ooo:
0?oobP3oog/0ool0Sol00olno`001?l0o`[o00[oo`0:oolno`03ool0lP?o0?o`0olno`0Qool0_0;o
j03o0_ooool5o`3oF@03oooooomY0?ooK`3o00SoK`3o1?l0=?l4o`10o`;o>?l02ol0m_l<ooooo`Co
0?mg1ol0i?l00ooooooo0?ldo`3o=00:o`3o=0coooooJoln0?l_ool0lPGo?P3o3OlPo`0kooooo`00
6_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo03[ooooo00Ko013ooeL0oomk0?oo
bP3oom`0oooo0?83ool0_008ool0l_oX0?oobP3ooh40oomY0?oo9P3oo`1<ool0ROlLooooo`0Ko`2Q
ool0ROoo04coo`1[ool0;_ooooooo`0dool0olKo013oobH0oomY0?ooooooo`3oGon10?ooM@3oocSo
0?l0ooKo/P3ookP0oooooooo01cooooooooX0?oo0?l@oed0ooooooooW`3o00;o0?oZ00Go05;ookSo
0?lJ0?oo6P3oo`3o4003ooooo`03okko0?l07?ooMOl000?ooooo00?o0=koooooool0oel00_ooool5
oego0003ogD0oooooooo/P3o00;o/P3o0_ooool5oego00;ooooo0_o:0?l01?mk0?oo0?m<oooooooo
ool3o`2?o`05o`0:ooooooooo`3bool0l_lP0?l00_ooool6ool0_0;o0?o`1?lno`03o`3o:0Kooooo
0ol0om8>ooooo`03o`3oFOoo0;coo`2l01Coo`2l2?mY0?l5o`0do`?ooooo0olho`09o`3fo`Oo0>Co
1?lho`03ooooo`co0?mg00?oooooo`3o=?ln0?l02_ln0?l:ooooo`co0?mU9?ooool;ofoo00oo/_l0
<?oooolFob3o033oo`3b0oln0?lJooooo`006_ooool00ol0003oooooooooo`0Gooooo`03ool00?oo
oooooooo03[ooooo01;o013ooed0oonh0?oobP3oool0l_oo0;coT`3oool0/?oo0;coo`3bonP0ooo:
0?ooW`3oofT0oomG0?oo013oo`1Iool0XOlKooooo`0Fo`2Qool0ROoo04coo`1[ool0;_ooooooo`0d
ool0olKo013oobH0oomY0?ooooooo`3oGon10?ooE`3ooooooonb0?ooMOl0okP0oooooooo01coonP0
o`;ooooo00OoG@3ooil0ool0on[o0?oZo`1Bool0on[o6P3o00;o0?oZ00?o^?l0o`3o4?ooool00_oo
ool00onno`3o01coogGo0003ooooo`03o`3Noooooooo0?mO00Gooooo0_mMo`001_me0?ooGOl0o`3o
]?mMo`3o/P3ooeOo00Gooooo0_o:0?l2og/0o`;ooooo0ol0od`01_oooooo00[oool0l_oo0?;o803o
o`23o`?oo`2l2?ooool4o`3ol0;ooooo1?lno`03o`3odPgooooo1om_0?l9ooooo`_oj03o:Ooo0;`5
och0ocSog03o1Onbo`0Bofoo00Co/_l0;_oooolHob3o04Kooooo3_oo0?8?ooooo`006_ooool3o`00
01Sooooo00?oo`00ooooooooool0>?ooool01_l0Vooo013ooed0oonh0?oobP3oool0lP;oo`2`00_o
o`3hool0/?oo0;coo`3bonP0oonh0?ooN`3ooeL0ool04?oo05Woo`29o`0Kooooo`0Lo`2Qool0ROoo
04coo`1[ool0;_ooooooo`0dool04?oo9P3oofT0oolno`3oooooo`3oGon10?ooE`3oo`3om_nb0?oo
oooookP0ool07?ooooooonP0ooooooooG@3ooil0oomMo`3o0?n3o`1Bo`;ooooo00Co6P3ooooooooo
oooo0?oZ1Ooo0?P00onno`3o01coogGo0003ooooo`03o`3Nool0oeoooooo00Oooooo0_me0?l01?l0
okCooooook80oomGo`02ooooo`;obP3o0_mk0?l3ooooo`;o0?l:00Goooooo`0:oooo0?;oo`3bob00
o`03ool0_003o`3oC?l0Sooo08oo00?o08oo1?ooool3o`3o:0;ooooo1Ol0oo000ol0om;ooooooooo
o`06ocko0003oooooooj0?oonP3o02[onP3o2OoX0?l?om`0o`OonP3o6?oo0;`ZooX0odOog03oN?oo
ool001[ooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0hooooo`07o`2Kool04?oo
G@3ookP0oooo0?;onP3oool0/003ool0Z@09oi<0oooo0;coj03oolX0oon10?ooE`3oobH0ool0C?oo
08Wo01_ooooo01oo0:7oo`29ool0C?oo06_oo`0^oooooooo03Coo`0@oolV0?ooJ@3oocko0?l0oc[o
0?mOoh40oolho`3o0?ofok80oonh0?oo01cookko0?l0oa3oj03oo`3oj_mM0?ooW`3oooooool0Yooo
05;oo`2WoolJ0?oo0:Oo00?oo`3h00Co0?oZooooool0oa3o^?l01Ooo0?P3ooooo`03o`3Nool0oeoo
oooo00Sooooo00CoM@3oo`3o]?l0okCo/P3o0_o:0?l2ok80o`?ooooo0_l0o`X2ooooo`;oo`3b0ooo
0;`01?l0Poooooooooooooooool5o`3oC0Co08oo1_ooool2o`3odPconP3o0_m_0?l2o`3oF@Co?_l0
2Oooool5o`10o`;ooooo5OoL0?l00ooooooo0>Coo`3To`03o`3To`03ooooooln0?ooj03o01Ooj03o
1_l0=?l4ooooo`Oo0?mU1Ol0m_l]ool0_4;onP3o0_ooool^om`0od[ooooo000Jooooo`03o`000?oo
oooooooo01Sooooo00?oo`00ooooooooool0>?ooool01ol0Vooo013ooed0oonh0?ooo`3bool0_?oo
0:T00_oo0>002_oo0:Woo`2`ool0_?oX0?oobP3ooil0oomY0?oo9P3oo`0@ool0JolKooooo`0Ko`2Q
ool0ROoo04coo`1[ool0;_oo0?lRo`0dool04?oo9P3oofT0oolno`3o0?mOoh40oome0?ooooooo`3o
m_nb0?oo^03oo`0LoomSo`3oj03ooooooomM0?ooW`3ooego0?l0Yooo05;o00;ooooo00?o6P3oool0
e?oo0=@00_oo0=@5ool0iP04okSo0?oooooo__l0o`0Lo`;oo`3h0_ooool00ol0g_oo0?mOooooo`08
ooooo`;oM@3o00GobP3oo`3<oomk0?ooN`3ooeOo0005ok80o`04ool0l_oo0;coo`2lool0_0Wo/P3o
5ooo0?P2o`3ol0?o0?mI1_oooolAom`0oa7ooooo0_l0i?l9och0o`03ok;o0?oooooooooo01Gooooo
00?oJ@3oonP0oooX0?l03ooX0?l5ofT0o`So03Co1?oooolGo`3fo`[oooooB?oo0;`YooX0o`03o`3o
=?oL0?oog03o02gog03o6oooool001[ooooo00?o0000ooooooooool06?ooool00ooo003ooooooooo
o`0hooooo`07o`1Iool02_ooN`3oolX0oooo0?;oo`2lool0Z@03on80o`0:ool0ZOoo0;3oo`2lonP0
oonh0?ooJ@3ooeL0ool04?oo05Woo`2Qoa[ooooo01[o0:7oo`29ool0C?oo0?o0o`0^ool0ob;o03Co
o`0@oolV0?ooJ@3oocko0?l0oeooP@3oogD0oooooooo0?ofok80oonh0?oo01coo`3o4?oX0?oo0?oZ
oed0oonO0?oo0:Ooo`1Bo`;o2?l00ooo0=@00ol8o`3oooooo`2Wo`03ool0e003ooooool0oa3oo`3V
00;oo`3V00?o__l0o`0Loomeo`000ooo0?P00ol0g_oo0?mOooooo`07ooooo`;obP3o0_mk0?l2ogD0
o`;o0?l:0_mGo`03ool0_005oeOo0?lP0?oo803oo`23ooooool01ooo0?P7ok80o`?onP3o0_nb0?l4
o`2?o`?oK`3o0oooool00ol0oeWoo`3hool0n006ool0n0?og03o0_ooool4o`10o`?ooooo1Olno`08
ooooo`Go/_l02Oln0?lFooooo`KoKol02?l0ofD?oooooagoj03o8omY0?l00ol0=?oo00Coo`04o`0g
o`04odKoo`2l4_oj0?l00ol0ogOog03oom`0o`0:om`0o`oooooo000Jooooo`03o`000?oooooooooo
01Sooooo00?oo`00ooooooooool0>?ooool01ol0FOoo6P3oog/0ooo:0?ooo`2lool0/?oo0:T00ooo
0>H02_oR0?ooo`2Yool0_?oX0?oobP3oog/0oomG0?oo013oo`1<ool0ROlJooooo`0Jo`2Qool0ROoo
04coo`3o`?l0;_oo0?n?o`0dool04?oo9P3oofT0oolno`3o0?mOoh40oome0?oo0?ofok80oonh0?oo
01coof?o0?l0oa3oj03ooed0oomMo`3oW`3oo`1Booooool3ool0e0?ooooo0ol8o`000ol0Yoooo`2l
ool0_006ool0_004o`0Loomeo`3oooooooooo`?oo`3h0_ooool5olX0o`;oN`3o00Goooooo`3o2_l0
okCo0?l:ogD0o`03ool0_005o`0:ooooooooooooob00ool0Pol00ooo0?P6oeOo00;o0?lX0oooool3
ooX0o`03o`3od_oooooooooo00;ooooo0onb0?mFool0/37oooooGooX0?m4ofT0oaooo`2l3oooool0
01[ooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0hooooo`07o`1IoolV0?ooN`3o
onP0oooo0;coo`2`ool0Z@03ool0Q@0:ool0i_oo0:Woo`2`ool0l_o:0?ooP@3ooeL0oolV0?oo04co
o`29oa[ooooo01co0:7oo`29ool0C?oo0?o0o`0^ool0=?oo05Woo`0@oolV0?ooJ@3oooooool0oeoo
P@3ooeL0ool0ooKo/P3ookP0ool07?oo0?l@onP0ool0on[oG@3ooil0ool8o`3o05;ooooooooo0=Co
o`3V1Oo40?l4ool0_004o`2Woooo0=Coo`3Do`3o40;obP3o00?oo`3Vool0_?oo0;`01?oo0;`01?o:
0?ooo`3hool0n?oo0?P2o`3<o`;oN`3o0ol0o`X01_ooooooo`2lool0_?oo0;coo`3bo`0:o`Koo`3h
1oooool2o`3o:0;oEol00ooj0?l2o`3odP03oeOo0?ooooooo`2`00Koo`2`1?oL0?l5ok80o`03o`2?
oooooooooooo00;ooooo1?l0@?l3o`3ol0;o/_l05ooo0?P>ocko00OoKol00oooool6o`3oI@[ooooo
AOoo0;1;ooooof?oj03o3oooool001[ooooo00?o0000ooooooooool06Oooool00ooo003ooooooooo
o`0gooooo`07o`1IoomG0?ooP@3oonP0oooo0;3oo`2Yool0h003ool0L`0:ool0QOoo0:Woo`2`ool0
_?oX0?ooW`3oofT0oolV0?oo013oo`1[oa[ooooo01_o0:7oo`29ool0C?oo0?o`o`0^ool0=?oo05Wo
o`0@oomY0?oo?_l0o`3o>_l0oeooP@3oooooool0ooKo/P3ookP0ool07?ooooooonP0oonho`3oG@3o
oil0ool0D_ooooooool0e?oo0>H00_o40?l2ooooo`?oo`2l00?ooooool@0ool8o`000oo:0?l00ooo
0=Co0?o<o`3oc002o`3oc0;oo`3V00?o0?o<o`3<ool0c?l03?oo0;`2ool0lP?oo`3h00?o0?ndob00
oome0?l01_me0?l2ooooo`;o0?lX00GoooooooX0oooj0?oonP3oooooo`02o`3odP04oooooooo0;3o
o`2`ool0/0;oK`3o1?oL0?l2o`3oF@Cooooo1?nbo`05ok80o`Go/_l00_ooool4o`3ol0Cooooo1_ln
0?l4o`3To`Oooooo4Ooo0?P2ocko00Go0?mU2?lno`0Fooooo`co00Co2_ooool;ob3o01KoooooA_oo
0;12o`1mo`?ooooo5ol0oiDKooooo`006_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooo
oooo03Oooooo01Go013ooeL0oonO0?ooj03oool0/?oo0:Woo`1cool0]_l0]?ooo`2fool0Looo08Go
o`2Yool0_?oX0?oo^03oofT0oomG0?oo013oo`1Iool0XOl06Oooool06ol0ROoo0:koo`1<ool0oo3o
02koo`0dool0olKo013oofT0oolno`3o0?mOoooooon10?ooooooo`3om_nb0?oo^03oo`3o4?oooooo
j03ooed0ool0YoooW`3oo`1Booooooooo`3Dool0iP02ooooo`;o0?l:00?oo`2looooooooool00oo:
0?l01?o40?oo0?o<ool0l_oo0?82ool0e0Coo`3b00Coo`3VogGo0?meo`3ooooo0_mk0?l00ooooooo
o`3bool0lP05ool0lP?ooooo00Go00[ooooooooooooo803oo`23o`02o`3o]0Gooooo0_me0?l3ooX0
o`;oM@3o00?oooooo`3od_oo0;000_oo0;02ofl0o`?og03o0ol0oeT6oeOo0003ok;o0?oooooooooo
00?o043o1?ooool5ok80o`Gooooo1Oln0?l00ol0oo3oooooo`3To`03o`3To`Wooooo2?m_o`08oooo
o`?o0?mU4Ooo0?P8ocko00co00Co2_ooool<ob3o01oooooo:?l0OOlPooooobkoo`2`5ol0oiDboooo
o`006_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo03Oooooo00Oo013ooeL0oonO
0?ooo`2lool0ZOoo0>3oo`1c00?oo`2;00_oo`32ool0Looo0:Woo`2`ool0l_o:0?ooN`3ooeL0oolV
0?oo04coo`29o`0Iooooo`0Jo`29ool0C?oo06_oo`3ol?l0;_oo03Coo`3oa_lV0?ooJ@3oocko0?l0
oeooP@3oogD0ool0ooKo0?mBokP0ool07?ooHol0onP0oonho`3oG@3ooil0ool0D_ooooooool0e?oo
0>H2ooooo`03o`3o2_oo0;coo`2l00;o05oo00?obP3oo`3oc?oo0?801?oo0?800ol0Yooo0<coo`3<
o`02ool0e0;oN`3o00?oo`3bool0i_oo0>H01?oo0?800ol0g_oo0?mOooooo`05ooooo`;o00[o0_oo
ool00olP0?oo08?oooooo`02ooooo`?o0?nd00Co0?lXooX0oooj0?oonP3o1?ooool3ool0/0?oM@3o
0_oL0?l00ome0?oo0?mIo`3oF@04ok;o00Gooooo0ol0@?l4oeOo00Oooooo00?o0?m<ok80oonb0?l0
1?nb0?l00ooooooo0>Coo`3To`03o`3To`Ko0?o`1om_o`0;ooooo`Go0?mU4_ooool2o`04oakoo`3h
6oooool@o`1moekooooo6?l0oiDjool0/0oooooo000Jooooo`03o`000?oooooooooo01Wooooo00?o
o`00ooooooooool0=oooool02?l04?ooG@3oolX0oooo0;coo`2Yool0i_oo07?oo`2;0_oo0=X02ooo
08_oo`1cool0ZOoo0;3oo`2lolX0oon10?ooJ@3oobH0ool0C?oo08Wo01Wooooo01ko08Woo`1<ool0
Jooo02koooooool0=?oo013oobH0oomY0?oo?_l0o`3oGon10?ooM@3oo`3om_nb0?oo^03oo`0Loooo
ooooj03ooooooomM0?ooW`3oo`1Boooo0=Coo`3Vool0n?l0o?oo05ooool0_?nIo`02o`3lo`03olX0
ool0Goooo`3b00?o0<co00?ok_l0ol@0ooo40?l01?mk0?l01Ooo0=Cooooooooooonho`3o01co00;o
o`3V0oooool00ol0g_oo0?mOooooo`02ooooo`;o00[o0_ooool2ob00o`03o`23oooooooooooo00Co
oooo0_oj0?l3o`3o]0Coo`2`00?oooooofl0oom_0?l00ooL0?l00ooooooo0?mIo`3oF@08ogD0o`?o
043o1oooool5oeOo00Co?P3o0_ooool2o`3To`03o`2?oonb0?oo/P3o00Co/P3o1Om_o`000ooooooo
0?o`o`3ol007o`3ol0Cooooo1Ol0ofD>ooooob3oo`2Y1_ooool3ocko02ooo`3h@ooooolGo`3oUACo
oooo<?oXo`0>o`3Ho`oooooo000Jooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0
=oooool02?l04?ooG@3oolX0oooo0;3oo`2Yool0QOoo07?oo`1o0ooo03H02_oo08_oo`1cool0ZOoo
0;coj03ooil0oomY0?ooE`3oo`0@ool0JolHooooo`0Jo`2Qool0ROoo04coo`1[ool0;_ooooooo`0d
ool04?oo9P3oofT0oolno`3o0?mOoh40ool0:?oo0?ofok80oonh0?oo0?l@oooooooX0?ooG@3ooil0
ool0oh?oo`3Dol@0oooo0>H2o`1Oo`05o`3o2_oo0;co;03oob`0ooo:0?l00_oo0?800ol0c?oo05oo
o`1Oo`02og/0o`07ooooool8o`3oa03oo`2Wool0on[oooooo`3o4002ool0e0;ooooo00Co01cookSo
0?oo0>Koo`3V0_ooool01?l0g_oo0?mOo`0:ool02_l2ooooo`;o803o00?o08?oooooooooool01?oo
ool2ooX0o`;ooooo0ooo0;001?oooooo0?oBo`3o]?m_0?l3om`0o`;ooooo0_l0oeT00onbo`3ooooo
ooooo`05ooooo`;o043o1_me0?l5ooooo`Co?P3o00?ooooooeOo0?l0i?l00ol0i?l6ofoo00;o0?m<
9ooo0:T4o`04o`Sooooo1olPo`0=ooooofCoo`2Y6Ooo0?PFohL0od?o0=So00?oooooofWo0?mYo`00
2omYo`0?ooooo`006_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo03Oooooo00So
013oofT0ooo:0?ooo`2`ool0ZOoo07?oo`2;ool0=P;oo`1K00coo`0fool0Rooo07?oo`2Yool0/?oX
0?oo^03oog/0oomG0?oo013oo`1Iool0XOlGooooo`0Qo`2Qool0ROoo04coo`1[ool0;_oo0?lRo`0d
ool04?oo9P3oofT0ool0oc[o0?mOoh40ool0:?oo0?ofok80oonh0?oo0?l@o`3oj_oX0?ooG@3ooil0
ool0D_ooo`3Dool0i_l0GoooVOl0o`3o2_oo0;co;03oo`3Booo:0?ooo`3b00;o0<co0omk0?l01Ol0
Gooooooooooooooooooo2?l000;oa03o00Co0?oZooooool0oa3ooooo0_oo0=@01?oooooo01cookSo
0?meo`03ool0iP05o`0:oooooooo0?mOo`3oGolP0?l00_l0Pol5ooooo`;onP3o00Coooooool0/?oo
0;3oo`2`0_ooool2o`3odP03ofl0oooL0?oog03o00;ooooo00?o/_l0o`3o]?l0ok@00ol0ok@5oooo
o`;o043o1_oooolIool0Z@Cooooo0_l0od`00ol0Sooo/P3ook80o`07ok80o`Gooooo1_oXo`02o`3o
l0Oo00Co0ol0oo05onSo00Go8?l05_n70?l<o`1mobWoj?l05olno`0Eo`3oU@?o0=SoAOoo0:Tkool0
n0oooooo000Jooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0=_ooool02?l02_oo
J@3oonP0oooo0:Woo`3Pool0Looo08_oo`0f0_oo07T03?oo05_oo`0fool0Looo0>Koo`2Yool0l_o:
0?ooP@3ooeL0oolV0?oo04coo`29oaOooooo02?o0:7oo`29ool0C?oo06_oo`0^ool0ob;o03Coo`0@
oomY0?oo?_l0o`3oGoooooooP@3oooooool0ooKo/P3ookP0ooooooooj03oo`2WoomM0?ooW`3oo`1B
oooo0=Coo`3Vo`1Oool0o`[o;03oool0_?l0odKo0?o<olX0oooo0?;o0?m6og/0o`03o`3Bo`03ob`0
ool0Gooo05oo00;ooooo00Ko2?l0ooooooo40?oo0?oZooooool0oa02ooooo`04ool0e?oooooo01co
okko00;o00[o00Ooooooool0i_oo0>Koo`3Vob00ool0Pooo0?mO00Cooooo0_oj0?l00oooooooo`2`
ool0/004ooooo`06o`3od_oooooog03oom`0oooooooo/_l02Ooo0>H4ool0]PGoo`2Y4?oo08D:onSo
00KoEol00_oXo`05o`3oI@;oj?l00_l0od`00ol0Sooo/P3ook80o`0:ok80o`03o`04oooooooooooo
00Gooooo00?o8?l0ohL0oon70?l02_n70?l8o`3ol0;ooooo3?l0OOlkooooo`ko0?nE6?l0f?l00ooo
oooo?_l0ocko0015ocko03_oo`2Y3oooool001[ooooo0ol0000Jooooo`03ool00?oooooooooo03Ko
oooo01Ko6P3ooh40oooX0?ooo`2Yool0QOoo07?oo`1oool0=_oo02[oo`0Nool0NOoo03Koo`2;ool0
Looo0:Woo`2lolX0oon10?ooJ@3oobH0ool0C?oo08Wo5oooool06Ol0XOoo08Woo`1<ool0Jooo02ko
o`0dool0FOoo013oofT0oolno`3o0?mOoh40oome0?oo0?ofo`3oD_nb0?oo^03ooooooooX0?ooG@3o
oil0ool0oh?oo`3Dool0n?oo0>H00_l0d_l01_oo0;coooooo`3oc?o:0?ooo`3booo/00[oo`2;00Oo
ooooo`So0?ooooooa03oo`3oj_o^o`3o0?l@00;ooooo00Goo`3Do`0:ool02_oo01cookko0003ob00
o`03o`23oooo0>Koo`3V00Ooo`3V00?oo`2`ool0i_oo0>H02_oo0>H00ol0oeWoooooooooo`05ool0
]P[oo`251_oo0>H3o`3To`03oooooooo0;Koo`2f00Coo`2f@ooo08D4o`1moa3o0?o`;?ooool2o`3o
UAOo0=SoB?oooolHofWo0003oooooon7o`3oQol001GoQol05oooool<o`;o00oooooo000Jooooo`03
o`000?oooooooooo01[ooooo00?oo`00ooooooooool0=_ooool01olV0?ooP@3oonP0oooo0:Woo`1c
ool0Rooo03H00_oo01h03Ooo033oo`0Nool0:_oo03Koo`1cool0ZOoo0;3oj03ooil0oomY0?ooE`3o
o`0@ool0ROl05oooool08?l0XOoo08Woo`1<ool0Jooo02koo`0dool0FOoo013oofT0oolno`3o0?mO
oh40oome0?oo0?ofok80oonh0?oo0?l@o`3oj_oX0?ooG@3ooil0ool0D_ooo`3Dool0i_oooooo;03o
ool0_?oooooo0?o<olX0oooo0?;oo`2G0_oo08/7ool0O`03ool0Uol0Goooo`2;00;oo`2;00?ooooo
ol@0ool0onX00ol02_l00oooooooo`3Dob00o`02ob00o`03okko0?l0Pooo08?o00;o^?l000Gooooo
o`3Noooj0?oonP3oo`3oG`03ool0/0Cooooo00?o0?oBom`0oooL0?l00_nbo`000ooooooo0?mIool0
]P04ool0]P03oooooooo08Goo`2500;oo`2500?oo`2YonSo0?oXo`000ooXo`001Ooooooo?P3ooch0
ooln0?ooKol000?o0?nd0_l0i?l8ool0iPCooooo00?oM@3oool0]_oo0;H06?oo0;H8ohL0o`?o8?l0
0omGo`06ooooo`;o08oo00?o07gook80oonb0?l03Onb0?m7ool0QD?ooooo5omYo`000oooooooQol0
ohOo000FohOo01Sooooo5_l2o`0<ooCo00oooooo000Jooooo`03o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0=_ooool02?mG0?ooW`3oonP0oooo0:Woo`1cool0Oooo03Koo`0N0_n/0?l03Ooo
033oo`0Nool0Fooo03Koo`1cool0ZOoo0?;o^03oog/0oomG0?oo013oo`1<ool0XOl05_ooool08?l0
XOoo08Woo`1<ool0ol3o02koo`0dool0FOoo013oofT0oolno`3o0?mOoh40oomG0?oo0?ofok80oonh
0?oo0?l@onP0ool0YoooG@3ooil0ool0D_ooo`3Dool0i_l/0?ooooooool0_?mko`3obP3oool0b?oo
09Ooo`2;0ooo07l2ool0]P04onSo0?oo0<Soo`38ool0b0?oo`1o0_oo0;H3ool0R`03ol@0ool0on[o
803o00;o803o0_oo0=@01Ol0Pooo01coo`0LooooooooMOl000?onP3o0ooo0;02o`3oG`?ooooo0_l0
om800ooL0?ooK`3oooooo`04ool0]P03oooooonho`3oo`2500?oo`2500?oo`2Yo`10oonho`001?nh
o`001?m_o`3o?P3ooch0ooln0?l4okSo00?o0>Co00?o^?l0ooooooooool01Ol0ok@2ooooo`Ooo`3V
0_l0ofD6ogD0o`03oooooon70?ooQ`3o00WoQ`3o1?lPo`0Wool0]P03o`2?oonb0?oo/P3o01_o/P3o
00?oooooo`3ol?l0oo001?l0oo0;o`3HoaKo0?o`G?oo08DBooooo`Gom?l06?l2o`0CooCo00Cooooo
2om@o`0?ooooo`006_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo03Gooooo00Wo
09_ooeL0ooo:0?ooo`2lool0ZOoo07?oo`0fool0Iooo01h00ooo09403?oo01koo`1iool0=_oo07?o
o`2Yool0l_o:0?ooP@3ooed0oolV0?oo04coo`29oaKooooo02;o0:7oo`29ool0C?oo0?o0o`0^ool0
=?oo0?o6obH0oomY0?oo?_l0o`3oGon10?oo02Soo`3om_nb0?oo^03ooooooooX0?oo0:Oooil0ool0
oh?oo`3Dool0i_l0d_oo;03oool0_?mko`3o0?o<ool0b?oo09Ooo`2;ool0Oon/0?ooo`2f1ooo07T2
ool0/003ool0Uooo07ooo`1o00?oo`2`0ooo08/3o`23o`04onko0?oo0=Coo`3DooX0o`Goo`2`0_nn
o`03o`3No`03o`3oGol0om;o0?oB00;og03o0ooo0;H00ol0oeWo^?l0okSo0003ool0Q@;oo`2Y00?o
j?l0o`10ool0@?l00oooool:ool0R`03o`3Tooo^o`3ok_l000;ok_l01onho`04o`3o]0Co0?mU00?o
ooooool0i_oo0>H01Ooo0>H2ohL0o`CoM@3o00?oooooob3o0?lPo`001?lPo`0>ooooo`Ko07go1?oo
oolXool0L`;oo`2f0_ooool5o`3Hoc_o/P3oBOl0oo16ool0QA[ooooo000Jooooo`03o`000?oooooo
oooo01[ooooo00?oo`00ooooooooool0=Oooool02Ol0VoooG@3oolX0oooo0;coo`25ool0Looo03Ko
o`0`ool07P02ool0B00=ool0o_oo06goo`0Nool0=_oo07?oo`2Yool0_?o:0?ooP@3oofT0oolV0?oo
04coo`29o`0Fooooo`0Ro`2Qool0ROoo04coo`3ol?l0;_oo03Coo`3oa_lV0?ooJ@3oo`3oGol0oc[o
P@3oo`0Xool0ooKo/P3ookP0ool0on[oj03ooed0oonO0?ooooooool0e?oo0?So;03oooo/0?oo0;co
06GoolX0oooo09Ooo`2;ool0Ool0oacoo`2fool0N@Soo`1]0ooo07T01?oo09Ooo`1oool0Oooj0?l3
ool0/0?oo`2;1?oo0;000ooo0=Co01coo`0Lo`02ooooo`?oMOl000?o/_l0ool0]_oo0;H01?oo0;H3
o`3oG`?oo`252ooo08/2och0o`Cooooo0ol0i?l00oooooooo`2;ool0R`08ool0R`03ooooool0ofGo
0?mU03Coo`1c3OoooolKool0h7Coo`1c;ooo0>0`ok80o`_oo`253oooool001[ooooo00?o0000oooo
ooooool06oooool00ooo003oooooooooo`0dooooo`09o`1IoomM0?oobP3oool0/?oo07?oo`0fool0
Fooo01koo`1800?oo`0l00coo`18ool0KOoo01koo`0fool0Looo0;3oj03ooh40oomY0?ooE`3oo`1<
ool0ROlFooooo`0Oo`2Qool0ROoo04coo`3ol?l0;_oo03Coo`0@oolV0?ooJ@3oo`3oGolho`3oP@3o
o`0Xool0oe;o/P3ookP0ool0on[oj03ooed0oonO0?ooooooool0e?lJ0?oo;03oool0_?l0olco503o
ool0Uooo08_oo`1ooo@0o`03ool0K@Goo`2A00?onP3oob00oon/0?l00_oo06d01?oo0<Soo`1iool0
NOoo09L3ool0O`04ok;o0?o40?oo0?oZool0]P?oo`2;2_oo0;H01?l0om;og03oofl0oonno`02o`3N
o`?oo`250ooo08/3o`3oG`03o`10ool0oeooKol000;oKol000?ooooooch0ooln0?l01?ooool2o`3T
o`?ooooo3_oo07<6ool0R`03ooooool01?oo00Co00?o00Co1?lPo`02ooooo`;o^?l05Ooo0>HHool0
h0Wok_l02_l0f?l3o`3oU@Cok_l000?ooooooeOo0?mGo`005OmGo`000ooooooo0?m<o`3oC003o`3o
C2_oS@3o;?oo0;I5ool0LbGoo`3P3oooool001[ooooo00?o0000ooooooooool06oooool00ooo003o
ooooooooo`0dooooo`09o`1IoomM0?oobP3oool0/?oo07?oo`0fool0<?oo01koo`0l00?oo`0<00go
o`0lool0o_oo01koo`0fool0Looo0:Woo`3bokP0oomk0?ooE`3oo`0@ool0C?oo0:7o01Gooooo01oo
0:7oo`1<ool0Jooo0?o`o`0^ool0=?oo013oofT0oolno`3o0?mOoh40oome0?oo0?ofok80oonh0?oo
0?l@onP0ool0YoooG@3ooil0oooo0=Coo`3ho`3o2_l/0?ooo`2lo`1Uooo:0?ooo`2Gool0Oood0?oo
o`1]00;oo`2A00Co>03oool0/?oj0?oo>03o0_oo03002?oo06Ooo`2Aool0TOlD0?oo[03oool0KOoo
0<SoVOl00_oo07T2ool0U`?oo`1o00Co0?oZok;o0?l0oa3o0?l@0ooo08/2ok;o00?oo`3D00?o0?oB
om`0oooL0?l00_oo08/3ool0Q@04ool0Rol0g_ooo`2Yool0Z@?o0=ko0_l0@?l2ofoo00;o0?mO0_ln
0?l4o`3oG`Coo`1K6?oo03H=ool0R`Kooooo0_l0OOl=ool0h003ogD0oooo0>Koo`3V00Woo`3V3Ooo
ool8o`3Ho`?o0?nE3_ooool00oo^o`3oS@3oohd0o`0Kohd0oa;oEol000?ok_l0ohOo0?n7o`003on7
o`05onko04;o0?m<1ol0l?lZool0]RGoo`1c3oooool001[ooooo00?o0000ooooooooool06oooool0
0ooo003oooooooooo`0dooooo`09o`1IoomM0?oobP3oool0ZOoo07?oo`0fool07_oo097oo`0<00?o
o`0T00goo`0<ool0TOoo01koo`0Zool0Looo0:Woo`2lolX0oon10?ooG@3oobH0ool0C?oo0:7o01Go
oooo023o08Woo`1<ool0Jooo0?o`o`0^ool0FOoo013oofT0oolno`3o0?mOoh40oomG0?oo0?ofok80
oonh0?oo0?oZonP0ool0YoooW`3ooiWo0?oo0=Coo`3hob`0oooo0;co0?o<oa@0oooo09Ooo`2;ool0
Oooo07Woo`1]o`ko00;oo`2`00GonP3oool0<?oo033oo`0`ocP0o`06ool0<0?oo`1]00Ko;03oool0
NOooooooo`2Go`So0?ooool2ool0O`;oj?l000?o0?l@onSo0?ooool01ooo08/3ool0Q@03oooooome
o`3oo`2Y00;oo`2Y0_meo`001?oooooo043oo`10oom_o`03o`3No`;o?P3o1Ooo05/5ool0=Pkoo`1W
1?l01?l4ob3o00;oo`1KEooo03HCooCo00Gooooo3on7o`2eo`80o`oooooo000Jooooo`03o`000?oo
oooooooo01_ooooo00?oo`00ooooooooool0=?ooool02Ol0FOooG@3oolX0oooo0:Woo`1cool0=_oo
01koo`18ool03003ool0000=ool03?oo03coo`2Aool07_oo03Koo`25ool0_?o:0?ooP@3oofT0oolV
0?oo04coo`29o`0Eooooo`0Po`29ool0C?oo06_oo`0^ool0=?oo05Woo`0@oomY0?oo?_l0o`3oGon1
0?ooE`3oo`3om_nb0?oo^03oo`3oj_oX0?ooG@3ooil0oooo0=Coo`3VoaX0ool/0?ooo`2lo`1Uoooo
0<Soo`2Gool0Oooo0;Koo`1]oo[o0?oo0;03ool0<0Koo`1>1?oo08D3ool0<0;oo`1]0_oo07T2ool0
U`05ooooool0Yoooo`1ool@0ooooool00_l0oa03om`0o`04ofl0oooo08Goo`25ool0Q@;oo`3D0ooo
0:T9ool0e003ogGo0?oo06Ooo`1K00;oo`1K1Ooo03H<ool0O`;o0?mO0_ooool3o`04o`Soo`1W3?oo
0>000ooooooo07goo`1mo`02o`1mo`?ooooo;Ooo05/5ohd0o`03ooCo0?oo0>Koo`3V00ooo`3V00?o
M@3oool0=_oo03H0AOoo03HXo`3`o`CoooooJOmGo`0?ooooo`006_ooool00ol0003oooooooooo`0K
ooooo`03ool00?oooooooooo03Cooooo01Wo013oog/0ooo:0?ooo`2Yool0Looo033oo`0Nool0??oo
003oo`1Dool01_oo05Coo`00ool03?oo03coo`0Nool0=_oo07?oo`2YonP0oon10?ooJ@3oobH0ool0
C?oo08Wo01Gooooo02?o08Woo`1<ool0Jooo02koo`0dool0FOoo013oofT0ool0oeoo0?ljoh40oomG
0?oo0?ofok80oonh0?oo0?oZonP0oomM0?ooW`3oool0e?oo0?So;03oool0_?l0IOooo`38ool0Uooo
07oom03oool0KOoo097oo`2Mool0C_oo033oo`1>ool0B005ool0?0;oo`180_oo04h01?ooooooo`2A
ool0TOl0odH2ool0<004ool0Iooo06goo`1iool0N@?oo`251?oo07l4ool0Q@03ooooool0oeWoo`2Y
00;oo`2Y0_ooool4o`0Lo`?oo`1o1?oo05/4ool0=POoo`3D6ooo02X=ool0Ia;ooooo2?l0ok@5o`3H
o`coS@3o1_ooool00ooo08_oo`1Kool0F`0/ool0FaSoo`3V3?m@o`0<o`3`o`03okSo0?oo03Koo`0f
05[oo`0f4_oooolGojco01oooooo00001?oooooo0000o`000?l00004ooooo`03o`000?oooooooooo
00;ooooo0ol0000:ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0=?ooool02ol0
4?ooN`3oolX0oooo0:Woo`1cool0<?oo01koo`0<ool00?oo00Koo`0B00;oo`0600goo`00ool03?oo
01koo`0Zool0Looo0:Woo`3bokP0oomk0?ooE`3oo`0@ool0C?oo0:7o01?ooooo01oo0:7oo`29ool0
C?oo06_oo`0^ool0=?oo05Woo`0@oomY0?oo0?mOo`3o>_n10?ooE`3ook80ool07?oo^03oonP0ool0
YoooG@3ooil0oooo0=Coo`3hob`0oooo0;co503oool0Uooo0?;oo`1oool0NOoo06goo`2M00;oo`0`
00Coo`18ool0??oo03coo`0l2_oo01h2ool0F`03o`3oA_ooI`3oo`0`00?oo`1W0ooo07T01?oo09Oo
0:Ooofl0ooo40?l=ool0O`Goo`1K00Ooo`1Wool0=_oo03Koo`0fo`0Loooooooo0>Co00;ooooo00?o
o`0Zool07_oo01h07_oo01hDool0:Q;oo`1W1_n=0?l:o`3o]0kooooo4Ol20?lHool0RdOoo`1KA_oo
0>Hiool0=Poooooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0009ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0<oooool02ol04?ooW`3oolX0
oooo0:Woo`1cool0<?oo01koo`0<ool00?oo01;oo`0H00;oo`0B00goo`06ool00?oo03coo`0Nool0
=_oo0:Woo`2lolX0oon10?ooE`3oo`0@ool0C?oo0:7o01?ooooo023o0:7oo`29ool0C?oo06_oo`0^
ool0=?oo05Woo`0@oomY0?oo0?mOo`3Noon10?ooE`3ook80oonh0?oo0?oZonP0ool0YoooW`3oool0
e?oo0>Ko;03oo`3o[_oo0;coo`38ool0Uooo07ooo`1iool0KOoo097oo`0`ool0CP;oo`0l00?oo`25
ool07_oo00`01ooo00`00oo^0?ooo`0lool0?003ool07P;oo`1K0ooo0306ool0I`03ool0Uoo40?oo
o`2Y00;oo`2Y0_l0oa02ooooo`03ool0Iooo05_oo`1K00;oo`1K00?oo`1Woooooooo03H00ooo03H3
ooooo`Koo`0N00Co01coohL0oon70?ooQ`3o0_l0ofD3ooooo`03ob3o0?oo0>3oo`3P00Coo`3P00?o
0=koool0e?oo0=@00ooo0=@3ooooo`?o0?mO1?l0OOl<ool07PSo__l0;?oo02X4o`80o`kooooo2ol2
o`0<ooooo`GoD?l04_l0l?l4oooooc3oo`2;G_oo05/Qool0iPoooooo0002ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool4o`0001_ooooo00?oo`00ooooooooool0<oooool0
2ol04?oobP3ookP0oooo08Goo`1cool0<?oo00coo`0Tool00?oo01Sooooo00;oo`0H00goo`06ool0
0?oo00coo`0Nool0=_oo07?oo`2lolX0oon10?ooJ@3oobH0ool0C?oo08Wo01?ooooo02;o0:7oo`29
ool0C?oo06_oo`0^ool0=?oo05WoobH0oomY0?oo0?mOoh40oome0?oo0?ofok80oonh0?oo0?oZonP0
oomM0?ooW`3oool0e?oo0>Ko;03oool0_?lD0?ooo`2Gool0Rooo07ooo`1]ool0TOoo09goo`0`ool0
Iooo03coo`120_oo00`00ooo02Coo`00ool00002ool000?oo`0T0_oo00`01?o^0?ooo`0lool0??oo
04P3ool07P03o`3Boooo0<Soo`0`00;oo`0`00?oo`1Kool0ZOoo07T01Ooo06L5ool0F`03ofoo0?oo
03Koo`0f00?oo`0f0_oo07<00oooooooo`0Zool07P02ool07P;oo`1i6Ooo03000omeo`3oo`3Dool0
e004ool0e0;om?l02Ol0oel4ooooo`03ool0Oooo01koo`0N01_oo`0N1Onno`000oooooooQol0o`80
o`08o`80o`Cooooo0ooo06M6ool0:R[ooooo5on/o`03ooooodSoo`2;8Ooo05/?ooooo`000_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool0
0ooo003oooooooooo`0cooooo`09o`0@ooo:0?ooj03oool0Looo08_oo`0Nool03?oo003oo`0600Co
oooo00goo`0Bool01_oo003oo`0`ool07_oo07?oo`2YonP0oon10?ooJ@3oobH0ool0;_oo04co01?o
oooo02?o0:7oo`29ool0C?oo06_oo`0^ool0=?oo08ooofT0oolno`3o0?mOoh40oomG0?oo0?ofok80
oonh0?oo0?oZonP0oomM0?ooo`3Dol@0oooo0>Ko;03oool0_?n/0?ooo`2Gool0Oooo07Woo`1]ool0
WOoo033oo`1Wool0??oo04;oo`0<oon50003ool000;oo`0600Coo`0Zool00?oo003oo`000_oo02@2
ool030;oo`0Z00?oo`0fool0B?oo09400ooo01h00ooo0:Woo`1]ool0<002ool0<0Goo`1K1?oo07T2
ool0=P;oo`1i0ooo07<4ool07PGoo`0`00?oooooohL0oon70?l00_l0ofD4ool0h0;o00Co0oooR`06
o`0Lo`Goo`1i2Ooo0305ool0e0Cooooo2?n=0?l00ol0oeoo0?nEo`3Ho`04o`3Ho`04ofWo0?oooooo
ooooooooo`ooo`1o5ooo01h8o`;o00coD?l01?l0ok@;o`3`o`Wo0?nd6_oo06M6ool0:T?o09Go5?l0
of/@ooo800oooooo0002ooooo`03o`000?oooooooooo00Oooooo1?l0000:ooooo`03o`000?oooooo
oooo01cooooo00?oo`00ooooooooool0<oooool02Ol02_oobP3oonP0oooo07?oo`1oool07_oo00co
o`00ool01P05ooooo`0=ool01_oo003oo`0lool07_oo07?oo`2Yool0l_nh0?ooJ@3ooeL0ool04?oo
04coo`2Qo`0Booooo`0So`2Qool0ROoo04coo`3ol?l0;_oo03Coo`0@oomY0?oo?_l0o`3oGon10?oo
E`3oo`3om_nb0?oo^03oo`3oj_oX0?ooG@3oool0e?oo0>Ko;03oo`3o[_oo0;coo`38ool0Rooo07oo
o`1]o`3o:?oo09goo`0`ool0??oo05Coo`0<ool0HOoo00000ooo00H2ool04PCoo`060ooo00000ooo
02Coo`0<ool03005ool0:P03ooo/0?oo01koo`0N00;oo`0N00?oo`1]ool0<?oo03001ooo0307ool0
7QKoo`2G1?oob003ooCo00Go01co1ooob002ool0N@_oo`0`0ooo0=@5o`3Ho`Co0?mO2ooob002ohOo
00Oo0P3o5ooo07l^ool07Q?oolP02On/o`0@o`3o]2oo09Go0ooo06MLool0:Q[ooooo00000ooooooo
0000o`000009ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ooo003o
ooooooooo`0cooooo`09oaX0ooo:0?ooo`3bool0Looo03Koo`0Nool00?oo00Koo`0B00Gooooo00go
o`0Bool00?oo00coo`0Nool0=_oo0:Woo`2lolX0oon10?ooJ@3oo`0@ool0C?oo0:7o01;ooooo023o
0:7oo`29ool0C?oo0?o`o`0^ool0=?oo013oofT0ool0oeoo0?ljoh40oomG0?oo/P3oo`0Loonh0?oo
j03oo`2WoonO0?ooo`3Dool0i_l/0?ooo`2loa@0oooo0<Soo`2;ool0Oooo06goo`2Mool0<?oo03co
o`18ool030;oo`0000Coo`06ool06?oo0:WoKol00_l0oeT2ool060?oo`0B00?oo`06ool0E?oo0000
0_oo0002ool030;oo`0l00?oo`18ool0:_oo02X00ooo02X:ool07PCoo`0Z00?ooh/0ol@0ooo40?l0
1?o40?l00ol0oa3oo`1]ool0K@0Dool0K@Goo`2G0_ooool6o`0Lo`;ooooo1?n=0?l8ool0N@Woo`0`
1_oo0=@00ol0oeoo0P3oo`80o`07o`80o`;o0?mO2OooR`02oonl00So0_l02?m@o`000ooo_03oo`1o
ool0O`0Lool0Oa3o__l0A_oo01iJon80o`;ooooo5ol0ok@00ooo06Ooo`0Zool0:P09ool0:Poooooo
0002ooooo`03o`000?oooooooooo00Oooooo1Ol00009ooooo`03o`000?oooooooooo01cooooo00?o
o`00ooooooooool0<oooool02OlV0?oobP3oool0_?oo07?oo`0fool07_oo003oo`06ool06006oooo
o`0<ool01_oo003oo`0`ool07_oo07?oo`2lolX0oon10?ooJ@3oobH0ool0C?oo08Wo4_ooool09?l0
XOoo08Woo`1<ool0oo3o02koo`0dool04?ooJ@3oo`3oGol0oc[oP@3ooeL0oonb0?oo^03oo`3oj_oX
0?oooooooil0oooo0=Coo`3Vob`0oooo0;coo`38ool0Uooo07ooo`1iool0KOoo033oo`1Wool0??oo
02Coo`00ool01_oo01;og03oool0Z@;o0?mI0_m_0?l3oonf0003oonA0?oo01Soo`0H00;oo`0600Co
o`1Dool0@_oo003oo`000_oo00`00ooo03coo`1>ool0B002ool0B003ooo/0?oo02[oo`0Z00Coo`0Z
0_l0@?l>ool0K@?oa03o0_oo0>0<ol@0o`?ooooo0_l0OOl7ool0K@Ooo`2G00GoS@3oo`0Lool07?oo
01coooooo`05o`3Ho`04o`3oUOooooooooooooooo`Soo`1i5Ooo030>o`3oG`03oe3o0?l0l?oo0?3o
00Wo0?3o6OooR`04on80od3oo`1o5_oo0<9eool07P[ohP3o3oooool001[ooooo00?o0000oooooooo
ool07?ooool00ooo003oooooooooo`0cooooo`08oeL0ooo:0?ooo`2lool0Looo03Koo`0Nool00?oo
0187ooooo`0=ool04_oo003oo`0`ool07_oo07?oo`2YonP0oonh0?ooJ@3oobH0ool0;_oo04coo`2Q
o`0@ooooo`0Uo`2Qool0ROoo04coo`1[ool0oo3o02koo`1Iool04?ooJ@3oo`3oGon10?ooM@3ooeL0
oonb0?oo^03oo`3oj_oX0?ooG@3oool0e?o40?ooo`3Vo`3o[_oo0;coo`38ool0Rooo07ooo`1]ool0
C_oo033oo`0lool0@_oo00coo`00ool06?oo03Koo`2Yo`3oF@02ofl0o`03oom80?oo:P3oo`1c00Go
o`1c00Coo`0Hool04_oo00Koo`060_oo04801Ooo003oo`0Tool03?oo00coo`0l00;oo`1>0_oo04P3
ool0L`;oo`380_ooool2och0o`?o2?l01Ol0Yol01?l0on[oQ`3oohL0ool0onX3ool0h003ob3o0?l0
1?oo00Co00?ooooo0oodo`05o`3o40Koa03o00?oooooofWo0?mYo`000omYo`09ool0K@Coo`2G1ol0
7?l01?oo_03oQol0ohOo0?n7o`06o`80o`;ooooo4Ooo07T00ooo0=Coo`0`ool0<00Eool0<1;ohP3o
;_oo0<86oon;00cool803?l0of/2oon;07Goo`1o5_oo0<8:ool07Poooooo000Jooooo`03o`000?oo
oooooooo01gooooo00?oo`00ooooooooool0<_ooool02?mG0?oobP3oool0/?oo07?oo`0fool07_oo
003oo`0H1oooool03Ooo01Soo`00ool03?oo01koo`0fool0ZOoo0?;o^03ooh40oolV0?oo02koo`1<
ool0XOl04?ooool09_l0XOoo08Woo`1<ool0Jooo0?o`o`0^ool0FOoo013oofT0ool0oeooP@3oogD0
oomG0?oo/P3ookP0ool0on[oj03ooed0oooo0=Coo`3hool0i_l0ojkoo`2lool0b?oo07ooo`1]ool0
WOoo033oo`0lool0@_oo02Coo`00ool01_oo03Koo`2YoomQ0?m_0?ooof400ooo07<2oom80004oolZ
0?oooooookH0oonf00;ooi4000Goo`0Hool04_oo00Koo`06ool0@P02ool00006ool09?oo00coo`0<
ool03?oo03coo`1>0ooo04P00ol0o?oo;03oool0b002ool0b0?oolP00_l0i?l00ol8o`3oolP0ooo8
0002ohL0o`03o`2Woooo0>3oo`3P00;o0:Oo0_l01?l7o`3ojP?ooooo0ol0OOl2ooooo`Co0?l@1Oo4
0?l00on=0?ooooooooooo`02ooooo`Co0=So00?oooooool0KOoo06d01ooo06d4ool0U`;o0P3o1Ol0
7?l7ooooo`Oo0_l000?ooooooe3o0?l0g_l00ol0g_lGool0N@03ool0e?oo033oo`0`01_oo`0`0_nC
0?lRooo2017o0?m[>oooZ@0GoooooaOob_l06_oooolPool0O`oooooo000Jooooo`03o`000?oooooo
oooo01gooooo00?oo`00ooooooooool0<_ooool02?mM0?oobP3oool0/?oo07?oo`0`ool03?oo003o
of402?ooool03?oo00Koo`00ool07_oo02[oo`25ool0_?o:0?ooP@3oofT0ool04?oo04coo`29oa3o
oooo02Ko0:7oo`29ool0C?oo06_oo`3ol?l0;_oo05Woo`0@oomY0?oo0?mOoh40oome0?ooE`3ook80
oonh0?ooGOl0onP0oomM0?ooo`3Dool0i_l/0?oo06Goool0_?oo09Ooo`1oool0KOoo04koo`0`ool0
??oo02Coo`0<ool00?oo02[oo`2Yo`3oFOoo4P3oK`3oool0L`Gook`000SoodP0ool`0?oo<03ooooo
oonf0?ooQ@3ooi40ool060;oo`0B00Coo`06ool0E?oo04;oo`000_oo02@01_oo09goo`0<ool03?oo
00coo`0lool0CPGoo`181_oo0<P2ohL0o`koo`182?oo00`:ool0B003o`3o4?o40?ooa03o00Coa03o
0oooool4ohOo00Ko0P3o1Ooo06d;ool0U`;o0_l02?m@o`03o`3`o`WohP3o00?o0=koool0`_oo0<80
3Ooo0<8Mool0N@03o`3oGooo033oo`0`03koo`0`<?oooolGol[o02kooooo6?ooL`0;ooob00oooooo
000Jooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0<_ooool01omM0?oobP3oool0
ZOoo07?oo`0Nool03?oo00002Oooool03Ooo01;oo`00ool0<?oo01koo`1cool0_?oX0?ooP@3oofT0
oolV0?oo04coo`29ool0XOl03oooool08ol0XOoo08Woo`1<ool0Jooo0?o`o`0^ool0FOoo9P3oofT0
ool0oeooP@3ooeL0oonb0?oo01cookP0oooX0?oo0:Oooil0oooo0=Coo`3Vo`3o[_oo0;coo`38ool0
Uooo06goo`2fool0<?oo03coo`12ool03?oo003oo`0Bool0ZOl0oeWoK`3o00;oo`1c00?ook`0oonS
0?ooX`000oooX`05oonl0006oonf0?ooQ@3ooi40oonA0?oo01Soo`0B0_oo00H01?oo05Coo`00ool0
0?oo0002ool0W@03oo@0oooo00coo`0<00;oo`0<0ooo04h8ool0B0;oo`383?oo00`4ool0b004oooo
ool0Yooo0:Ooo`2Wo`ooo`0<1Ooo04P2ol@0o`;o0P3o2ooooolDool0K@;oo`2G3?oo0<8;oi<0o`[o
09Go00?ool80o`3Nool0g_l03ol0g_l2oonY0003ogGo0?oo0=Coo`3D03ooo`1i0_l0oemdool0<0?o
oj<05OoolP0<od[o00oooooo000Jooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0
<_ooool01omM0?oobP3oool0ZOoo07?oo`0Nool03?oo00002Oooool03Ooo01Soo`00ool03?oo01ko
o`0fool0ZOoo0?;o^03oofT0oolV0?oo02koo`1<ool0XOl03oooool09?l0XOoo08Woo`1<ool0Jooo
02koo`0dool0FOooJ@3oocko0?l0oeooP@3ooeL0oonb0?oo^03oo`3oj_oX0?oo0?n3oil0oooo0=Co
o`3Vo`3o[_oo0;coo`38ool0Oooo06goo`2Mool0<?oo03coo`0<ool00?oo01;oo`0fom`0oom_0?oo
o`1coonS00Coo`H00oooool4oonS0005oolZ0?oo_03ook`0oonl0?ooQ@000_l0@?l2ool04P;oo`06
00?oo`1Dool0@_oo00000_oo00001?ln0?oo06Gooo@0oood0?l=ool031ooo`0l0_l0onX00on7o`3o
ooooool03008ool03004ool0B?o40?ooa03ool@0o`Ko0?l@0ol2o`03oe3o00CoofL000?o0?3oool0
`_oo0<802?oo0<8;ool0K@;oo`2G00?oT`3oo`0Lool07?l01ol07?l00ol0UOooojT0oonY000Goooo
o`Co0?m[:Ol0g_l7oonS0003ogGo0?oo0=Coo`3D017oo`3DMOoo07T00ooo0=Coo`0`ool0<00Rool0
<0oooooo000Jooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0<Oooool02?l0Vooo
G@3oolX0oooo0:Woo`1cool07_oo003oo`062_ooool03?oo00Koo`00ool07_oo03Koo`2Yool0_?nh
0?ooP@3oobH0ool0;_oo04coo`29o`oooooo02?o0:7oo`29ool0C?oo06_oo`0^ool0=?oo05WoofT0
oolno`3o0?mOoh40oomG0?oo/P3ookP0ool0on[oj03ooed0oonO0?ooo`3Dool0i_l0IOooo`2lool0
Uooo07Woo`1]ool0C_oo033oo`18ool03?oo003oo`0Zool0ZOoo_03oK`3oool0L`05oolN00Kom?l0
00?oof40oonS0?ooX`000ol0@?l3oonl0003ool06?oo01;oo`3>00;oo`0600Coo`1Dool0@_o^0?oo
o`000_oo02@2oa@0o`?om03o00?oQ`3oool0h?oo0>000ol0o?l00onIo`3o00Coo`04o`07o`1Oo`Oo
;03o0on=0?l3ooooo`Goo`2A1_oo04h6ool0?0;o0?oZ1OooX`09ool03003ool0B?oo0<;oo`3200Wo
o`3200CohP3oooo20?oo`P3oonH02OnC0?l00on/o`3oonH0oonY0003oonY00;o09Go4_oo06d8ool0
U`Cooj<02?l0of/6oonS01Sooooo3oooK@0<o`3NohCo<P3o9Ooo07T?ooooo`006_ooool00ol0003o
ooooooooo`0Mooooo`03ool00?oooooooooo037ooooo00So09_oog/0ooo:0?ooo`2Yool0=_oo01ko
o`00ool01P[ooooo00goo`0Bool00?oo01koo`0Zool0QOoo0;cobP3ooh40oomY0?oo013oo`1<ool0
ROoo0:7o00kooooo02;o0:7oo`29ool0C?oo06_oo`0^ool0=?oo013oofT0ool0oeooP@3oogD0oomG
0?oo/P3ookP0ooooooooj03ooed0oooo0=Coo`3Vob`0ool0IOooo`2lool0Uooo06goo`2Aool0<?oo
03coo`0<ool00?oo02[oo`2YoonS0?m_0?ooo`1c0_oo7P04ooCo00?oo``01_l0@?l00oodo`3o?P3o
och0o`05och0o`;oo`0B00?oo`3>ool01_oo05@00_oo0486ool000;oo`0T0_od0?l2oj`0o`;o00Co
0_l0o?l3oooooaOoo`000_ook0000ol8o`3oo`2Aool0T@06ool0T@Koo`0l00?o0?oZool0`_oo0<80
1ooo0<85ool030Soo`180onC0?l9o`3o40Ko09Go1?ooI`0@oom]01koo`1]4oooK@0Loc80oa;oog<0
0_ooool/ooob00;oB_l05_l0oi]Ao`3No`oooooo000Jooooo`?o00007_ooool00ooo003ooooooooo
o`0`ooooo`08o`1Ioomk0?oobP3oool0ZOoo03Koo`0Nool00?oo018:ooooo`0=ool06?oo003oo`0<
ool07_oo07?oo`2`onP0oon10?ooJ@3oo`0@ool0FOoo04coo`2Qo`0>ooooo`0Qo`29ool0[_oo04co
o`1[ool0;_oo03Coo`0@oomY0?oo0?mOoh40oome0?ooE`3ook80oonh0?oo2?l0onP0oomM0?ooo`3D
ool0i_l0ojkoo`2lool0b?oo07ooo`1]ool0WOoo033oo`0lool03?oo003oo`0Zool0ZOm_0?ooo`1c
00;oo``000?om?l0oooooooo=P001?oo=P001?l0@?ooo``0ool<0?oo3004och0o`;oodP01Oodo`00
1?o@o`3om?l0ool04_oo0183ool01P03ool0E?oo04;oo`1200?oo`123Ooo00000ood0?oo[03ooj`0
o`04o`3lo`;oS@3o1?ooX`000onIo`3o0=Soo`3Ho`02o`1Oo`03ob`0oooo02Coo`0T00;oo`0T1ooo
0003oe3o0003o`So0?oo0<Soo`2A00?oo`2A00?oo`1>ool0??oo03`01ooo03`01?l0l?ooonH0oooV
0?ooiP02ojco01[oo`0<1_l0oa05oomD00_o0?m[6?ooE004ool0UbOoo`1]2ooo09NVoiT0o`oooooo
000Jooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool0<?ooool02?l0FOooN`3oolX0
oooo0:Woo`0fool07_oo003oo`0H2oooool03?oo00Koo`00ool07_oo03Koo`2Yool0l_nh0?ooJ@3o
obH0ool0;_oo04coo`29o`gooooo02;o0:7oo`29ool0[_oo04coo`1[ool0;_oo03Coo`0@oomY0?oo
0?mOoh40oome0?ooE`3ook80oonh0?ooj03oo`3oPonO0?ooo`3Dool0i_l0IOooo`2lool0l_oo07Wo
o`1]ool0C_oo033oo`12ool00?oo00Koo`2Yofl0oooo07?oo``00_odo`02oolf00?ooooo0_l0@?l0
1?ooooooocH0och0ooln0?l2oolf00;ooah000Goof40oolB0?ooB03oobX0oonf0005o`3To`04ool0
6?oo01;oo`0Bool0cPGoo`0600?oH`3oool0@_oo04801Ooo0488ool0W@_oo`121_od0?l01?ooZ@3o
0P3oo`80ool20?l2oonY00;o05oo0_l/0?l00ooo0<;oo`00ool00007ool00003o`3`oooo097oo`2A
00Coo`2A0_oo0<P00ooo04koo`0lool0?009ool0?0;o0?oZ00?oooooo`2Eool0UOl01?l0UOl9oooo
o`;oa03o00?oo`18ool03?oo00`05?oo00`2o`3o40Cooooo6?lb0?l8oooooaWoV@3o1?oo0=Yfool0
KC7oo`2G2_oo0=X?ooooo`006_ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo033o
oooo00So05Woog/0oooo0?;oo`25ool0=_oo00coo`00ool060_ooooo00goo`0Bool00?oo01koo`0f
ool0ZOoo0;co^03ooh40oomY0?oo013oo`1<ool0ROoo0:7o00cooooo02?o0:7oo`29ool0[_oo04co
o`1[ool0;_oo03Coo`0@oomY0?oo0?mOoh40oome0?oo/P3ookP0ool0on[oj03oo`3oPonO0?ooo`3D
ool0i_l0IOooo`2lool0Uooo06goo`2Aool0<?oo03coo`0<ool00?oo02[oo`2Yofl0oooo07?om?l0
oolf0003ooooo`?o043o0_ooK@02och0o`?oofd000?ooooooolf0?l0i?l01Ol0i?l01?oo]P3ooc00
ohL0oon70?l2ool0h008ool06?oo067oo`0Bool04_oo0<kod03oool0Xooo05@6ool01P03of<0oooo
04;oo`1200Koo`124_oo00H6ool0@PCoo`3200?o0_l0oooV0?l0Gol00ol0Gol3ob`0o`03ool09?oo
003oo`0000[oo`0000?oo`2Aool0b?oo0<P01_oo0<P<ool0?0;o0?oZ0oooool6o`3oJ`cooooo2?o4
0?lBool030Goo`18:?oo0=XIo`0FoacoocH0;_l0ojLGoooooc_oo`1]3oooool001[ooooo00?o0000
ooooooooool07_ooool00ooo003oooooooooo`0`ooooo`07o`1Ioonh0?ooo`3bool0Looo033oo`0<
ool0000<ooooo`0=ool06?oo003oo`0<ool0:_oo08Goo`2lonP0oon10?ooJ@3oo`0@ool0C?oo08Wo
o`2Qo`0<ooooo`0Vo`2Qool0ROoo0:koo`1<ool0oo3o02koo`0dool04?ooJ@3oo`3oGon10?ooE`3o
ok80oonh0?oo0?oZonP0oomM0?ooa03oool0e?l0olco503oool0_?oo07ooo`1]oonf0?oo033oo`0l
ool01_oo003oo`2Yofl0oooo07?om?l0oolf0?oooooooaP0oom]0?l0@?l2ooooo`?o?P3o00?ooooo
oolH0?oo60000_l0i?l<ool0h0?o0?mU0ooo01P5ool04PGoo`1D2Ooo00H2ohd0o`;oH`3o2olD0?l0
0ol20?oo0=;oo`3Bo`07ool01PGoo`1200Co[03oo`3`ool0l?oo0?3o0_n/o`06oi<0o`?o;03o1Ooo
02@<ool000Woo`387_oo03`4ol[o00;oa03o3Ooo0=XMool032koo`185ol0ojMbooooo`ko6_l03ooo
ool001[ooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0`ooooo`07o`0@oonh0?oo
o`3bool0Looo01koo`0<ool0000=ooooo`0<ool00?oo00coo`0Nool0=_oo0;3oj03ookP0oomY0?oo
013oo`0^ool0C?oo08Wo3?ooool08_l0XOoo08Woo`2^ool0C?oo0?o`o`0^ool0=?oo9P3oofT0ool0
oeooP@3ooeL0oonb0?oo^03oo`So0?oX0?ooG@3oool0e?oo0>Ko0?o<ool0_?oo0<Soo`1iool0KOoo
04koo`0`ool09?oo003oo`0Zool0ZOm_0?ooo`1cooCo0?ooool2oom]0004o`10oooooooooooooch0
o`;ooooo0_l0i?l4ool0h0CoQ`3o1ol0ofD2oonf0005ooooooooQ@3ooi40om3o0?ooT@000ooo01P2
ool0H@Goo`0B00?oo`2Sool0E?oo05@06_oo05@00ooR0?oo503ooa@0o`02oa@0o`_oo`060ooo0482
ooll00Co05oo1_l/0?l9ool090;oo`2A3?oo0003ool0T@Koo`384Ooo04h00ooo0=[oo`0lool0?00E
ool0?1Woa03oG?oo00a7ool0B1Co6_l03_o4o`0?ooooo`006_ooool00ol0003oooooooooo`0Noooo
o`03ool00?oooooooooo033ooooo00Oo013oolX0oooo0?;oo`0fool07_oo003oo`0600gooooo00go
o`06ool00?oo01koo`0fool0ZOoo0;co^03ooh40oolV0?oo02koo`1<ool0ROoo0:7o00_ooooo023o
0:7oo`29ool0[_oo04coo`3o=?l0;_oo03CoofT0oolno`3o0?mOoh40oomG0?oo/P3ookP0ool8o`3o
j03ooed0oooo0=Coo`3Vo`1Uoooo0;coo`2Gool0KOoo097oo`0`ool0??oo00coo`00ool0ZOoo7P3o
o`1cooCo00;oofd00_ooool01Ol0@?oooooooch0oolPo`3o0>Co00?oo`3P0on70?l3o`3oI@04oooo
oooo603ooaP0ooooo`Coofd000GoocH0oom80?oo=P3ookH0oolZ0002oon500;od?l00_l01?l3ool0
60;oo`1Q0_oo0<hPool04PCoo`1D0onC0?l2oa@0o`;o0=;o0_oo09d6ool01PKoo`121?l0Gol8ob`0
o`koo`0T2ooo000?ool0TAOoo`1>00?o01Koool0??oo03`06ooo03`Co`3oY`Cooooo0oo40?lnomH0
ofWoo`0<3oooool001[ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0_ooooo`07
o`0@ooo:0?ooo`3bool0=_oo01koo`00ool01P0=ooooo`0=ool06?oo003oo`0Nool0:_oo0:Woo`2l
okP0oon10?ooJ@3oo`0@ool0C?oo08Woo`2Qo`0;ooooo`0Po`2Qool0ROoo09_oo`1<ool0ocCo02ko
o`1IoomY0?oo?_l0o`3Noon10?ooE`3ook80oonh0?ooj03oo`3oPonO0?ooo`3Dool0i_l0IOooo`2l
ool0Oooo06gookH0ool0<?oo03coo`00ool04_oo0:WoK`3oool0LoooK@03ooooo`06o`10oooooooo
?P3oob3o0?l0i?ooo`3P0on70?l8oonY0006oooooooo603ooaP0oolH0?ooooooof401?ooK@02oonf
00?o00Co00?oooooom3o0?o@o`000_mYo`0=ool060Goo`3>1?o@0?l3ool0`P04ocP0oooR0?oohP3o
on80o`;o>03o1Ooo0:<6ool04PKoo`1D0olD0?l01?l0UOooo`2Mool0WOoo09d9ool01P;oo`121ol0
Gol01?oo7P3o;03oob`0ool/0?l7oc80o`03ob`0oooo0=[oo`3J00Coo`3J1ooo02@Aool000ooo`2A
1_oo0<PNool0CUSoo`0l5_o4o`0Joomi01Kooah08ooocP0?ooooo`006_ooool00ol0003ooooooooo
o`0Oooooo`03ool00?oooooooooo02oooooo00Oo013oolX0oooo0;coo`0fool07_oo003oo`0B00ko
oooo00coo`00ool03?oo01koo`1cool0/?oX0?ooP@3oofT0ool04?oo04coo`2Kool0ROl:ooooo`0Q
o`2Qool0ROoo0:koo`1<ool0Jooo02koo`0dool0SoooJ@3oocko0?n10?ooM@3ooeL0oonh0?oo0?oZ
onP0ool0oh?oW`3oool0e?l0olco503oool0_?oo07ooo`1]ool0C_oo033oo`0<ool00?oo02[oo`2Y
ool0Loooooooofd000;ooooo00Co043oooooooln0?oo0>Co0_oo0>001?n70?ooooooooooooooool<
ofWo00;ooaP000?ooooooomQ0?ooH@000ol01?l6ofWo0003oom]0?o@o`3od?l000;o07go0_l>o`02
ohd0o`;o3_l00_n7o`000ol0oiGo0=Soool0600Eool06003ool0HOlh0?ookP3o00;okP3o0_oo0:<9
ool04P?oo`1D0olD0?l4o`3Bo`?oo`2M3?oo00H9ool0fP_o;03o00CooooooiWo0?nIo`3oVOl02_l0
5_l01Om:o`3o0?nKo`3oVol0oi_oo`0T02Woo`001?oo094@ool0b0co0?oZ@_oo04iYool0?0oooooo
000Jooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0;oooool01olJ0?oobP3oool0
_?oo03Koo`0Nool00?oo01803_ooool03Ooo003oo`0<ool07_oo03Koo`2`ool0l_nh0?ooJ@3oobH0
ool0;_oo04coo`29ool0XOl02Oooool08?l0XOoo08Woo`2^ool0C?oo06_oo`0^ool0=?oo013oofT0
oolno`3oP@3oogD0ool0ooKo^03oo`3oj_oX0?ooG@3ool@0oooo0=Co0?o<oa@0oooo0;coo`1]ool0
TOoo033oo`0lool03?oo003oo`2Yofl0oooo07?oofd00oooool01?l0@?oo?P3oo`3Toooo0>02ohL0
o`CoJOl01_ooool3ooll00;ooooo00?oojT0ofWo0?mYo`000ol01?l01OmYo`3oof40oom80?ooB03o
oa8000;ookH000OoocH0oon50?ooQ@3oohD0o`1mooooZ@3od?l000;oS@3o00GoojT0ohOo0?n7o`3o
Qol0o`3oU@02o`3Ho`?o3_l00_l20?l2ool0`P04ohgo0?oR0?oohP3oon80o`KoSOl000?o0?lLoi<0
oonC0?l00ooo0<h6ool06003ool0HOlh0?oo>03o00CokP3o0ooo0:<8ool04PCoo`1D1?lb0?l6ool0
fP;oo`2M00?oo`12ool01_oo00H04?oo00H2o`0Foa;o;03o1_nIo`000ol0ojOoeP3oomH0o`0:omH0
o`CoVOl000?oooooool09?oo02@04?oo02A<ool002coo`2A5ooo0<P2o`1goc[oo`1>3oooool001[o
oooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0_ooooo`07oaX0ooo:0?ooo`2`ool0
7_oo02[oo`00ool0600>ooooo`0=ool01_oo003oo`0Nool0=_oo0;3oo`2lokP0oon10?oo9P3oo`0@
ool0C?oo08Woo`2Qo`09ooooo`0Po`2Qool0ROoo0:koo`1<ool0Jooo02koo`0dool04?ooJ@3oo`3o
Gon10?ooE`3ook80oonh0?oo2?l0onP0oomM0?ooo`3Dool0i_l0IOooo`2lool0Oooo06goo`2Aool0
<?oo03coo`00ool0:_oo0:Woo`1coom]0?oo6002ooooo`05o`10ooln0?oo0>Coool0h?n70?l00_mY
o`0:ooooo`So00Co0_ooool8oonY00;ookH00_l0OOl00oooQ@3oS@3oohd0o`03ohOo0005om3o0?l0
oiGo0=Soo`3Hooo@o`000_ooT@02o`80o`;oo`320ooR0?l7o`ko00?oT`3o0_l>o`03ohgo00?o09Go
0ol0oa`9ool060?o>03o1_oo0:<5ool04P_oo`1D1?l0d_l5oj`0o`Woo`2M00?oo`12ool01_oo00H0
5_oo00H3omH0o`oo;03o00?ooc00oiWo0?nIo`005?nIo`0Foa[o00?oVOl0<?oo02Aoool000oooooo
000Jooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0;oooool01olV0?oobP3oool0
/?oo01koo`0<ool00?ooH@003_ooool03_oo01Soo`00ool03?oo02[oo`2Yool0/?nh0?ooP@3oofT0
ool04?oo04coo`2Kool0ROoo0:7o2?ooool07ol0XOoo08Woo`2^ool0C?oo06_oo`0^ool0=?oo013o
ofT0ool0oeooP@3ooeL0oonb0?oo^03oo`2WoooX0?ooG@3oool0e?oo0>Ko06Goool0_?oo07ooo`1]
ool0C_oo033oo`0<ool00?oo02[oK`3oool0Looo60000_ooool01_l0@?oo8?l0och0ool0ofGoo`3P
ofWo00;ooooo1_oo`P04o`04o`;ool801Oooool4ooll00Cooooo00?oof40o`1mool0OOl00_l0OOl0
0ooo903oS@3oohd0o`02ohOo00;ool8000?o0?nEo`3Hool0f?l00_ooQ@000oooiP3o0P3oo`80o`02
ool0`P;ohP3o00?o0_l0ojco0?n/o`001?o@o`03oi<0o`GoohD00ol0UOl6o`ko00?o0?lL1?l0of/2
ool0H@Woo`0H00?oo`3JoiT0oonI0?l00_oo0:<9ool04P;oH`3o3?oo05@6o`3Bo`;oeP3o4_oo09d4
oo@0o`03ool0@_oo00Koo`0601Coo`069Ol/0?l2olCo00Goo``000?o07Oood@0oom40?l06_m40?m2
ool0k53oo`0T3oooool001[ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0_oooo
o`06oeL0ooo:0?ooo`2Yool07_oo00coo`004?ooool03Ooo003oo`0<ool07_oo07?oo`2`onP0oon1
0?ooJ@3oo`0@ool0FOoo04coo`29ool0XOl02?ooool09ol0XOoo08Woo`2Kool0C?oo0?o`o`0^ool0
=?oo9P3oofT0ool0oeooP@3ooeL0oonb0?oo^03oonP0ool0oh?oW`3oool0e?oo0>Ko503oool0_?oo
07ooo`1]ool0<?oo03coo`0<ool00?oo0:WoK`3oool0Looo603oooooo`10oolPo`3o?P3oo`3oIOoo
0>3oQ`3oooooo`03ooo200?ooooo0_l01?l6ooooo`Sool8000?oooooooll0?l0OOl00ol0OOl3oomQ
00;oS@3o00?oQol0ooo20?oo`P000_l0oiD2o`3Ho`03ooll0?ooiP3oonH000;o0P3o0_oo0<82on80
o`;o[?l01?oo9003oi<0o`?oog<00_o@o`03o`2Eo`Ood?l01Ol0of/2o`ko0003oc80oooo0=[oo`3J
00Coo`3J1_oo0645ool060?o>03o0oo^0?l3ool0XaSoo`0B00?oo`1Do`3Bool0d_l03?l0d_l00on/
0?ooo`2Mool0W@0Dool0W@?om03o00?o[03oool0@_oo00H07?oo00HGool0@QGoo`3/@?l/0?l2o`3o
5QKoTol0;_ooCP0<o`0Ro`oooooo000Jooooo`03o`000?oooooooooo023ooooo00?oo`00oooooooo
ool0;_ooool01_mG0?oobP3oool0ZOoo01koo`0<ool0013ooooo00koo`06ool00?oo01koo`0fool0
/?oo0?;o^03oofT0oolV0?oo02koo`1<ool0Vooo08Woo`2Qo`Oooooo02Go08Woo`2^ool0C?oo06_o
o`0^ool0ohoo03CoobH0oomY0?oo0?mOoh40oomG0?oo/P3ookP0oooX0?oo0?n3oil0oooo0=Co0?o<
oa@0oooo0;coo`1]ool0TOoo033oo`0lool00?oo02[om?l0ool0Looo603oooooo`10oolPo`3o?P3o
o`3Toooo0>3oQ`3o00;ool801?ooool2o`04o`oooooo0ol0OOl3ooo20005ohOo0?n=0?ooS@3oohd0
oon7o`000_ooH@02o`3oU@;o0=So0oooiP02o`80o`;oo`320_oR0?l00on/o`3oooooooooo`02oooo
o`03o`3`oonC0?ooT`3o00;oog<00oooool3o`2Eo`Kooooo1?l0of/2om3o00Koo`3J0onI0?l4o`ko
00;ooa800on=o`02o`3o70?oo`1Q2Ooo01P3ocP0oaGoo`2S4_oo0186ool0E0ko0=;o8_oo09eIool0
1TKoo`127ol/0?l?ooooo`006_ooool3o`00023ooooo00?oo`00ooooooooool0;_ooool01_mM0?oo
o`3bool0ZOoo01koo`00ool01Q3ooooo00koo`0Hool00?oo01koo`0Zool0/?oo0;co^03ooh40oolV
0?oo013oo`1<ool0Vooo08Woo`2Qo`Kooooo01ko0:7oo`29ool0[_oo04coo`1[ool0;_oo05Woo`0d
oolV0?ooJ@3oo`3Noon10?oo0?ofokP0ool0on[oj03oo`3oPooo0=Coo`3Vo`3<oooo0;coo`1oool0
KOoo04koo`0`ool03?oo003oo`0Zofl0oooo07<2ooooo`06o`10ooln0?oo0>Coool0h?n70?oool80
1?ooool2o`04o`;ooooo2on7o`04o`1mo`CoQol00on=0?l4ooooo`;o0?nE0_l0f?l2oooV00?o0P3o
0_oo0<800ooR0?oo0_l0ojco0002oom800;ookH00onC0?l4oonf00?o09Go1_oo]P03o`3oJ`03oonf
0?oo0=[oo`3J00?oo`3J0_nI0?l4ooooo`Ood?l00_l>o`07o`0Fo`03oonA0?l0oaco0?lL00Koo`3>
00?oo`1Qool06?oo01P02_oo01P2ocP0o`03o`3o[_o^0?ookP3o00OokP3o3?oo0:<6of<0oaOoo`0B
00?oo`1Do`1gool0Mol00_l0MolKo`3Bo`Ko[03oD_oo09eUool01Poooooo000Jooooo`03o`000?oo
oooooooo023ooooo00?oo`00ooooooooool0;Oooool01ol0VoooG@3oool0l_oo0:Woo`0Nool00?oo
00H04Oooool03_oo003oo`0<ool07_oo0:Woo`2`onP0oon10?ooJ@3oo`0@ool0FOoo04coo`29ool0
j_oo0:7o1Oooool09Ol0XOoo08Woo`2^ool0C?oo06_oo`0^ool0FOoo03CoofT0oolno`3o0=kooh40
ool0ooKo^03oo`So0?oX0?ooG@3oool0e?oo0>Ko06Goool0_?oo07ooo`1]ool0<?oo03coo`0<ool0
0?oo0:Woo`1coom]0?oooooo043oob3o0?ln0?oo0?mUool0h?oo`P001?ooool00ol01?ooQol0ohOo
0002ohOo00CoonH01ol0OOl2oooV00KoS@3o00?ooooooooV0?ooiP000_ooiP02o`3oU@;o0=So00Go
onH0oe3o0?l20?oo0P3ooomQ0002ool0`P03on80ool2o`3o[?l000?ooooo00?oog<0oi<0oonC0?l0
1Oooool2o`2Eo`03ooooooooB03oodP000?oodP00ol0of/4ool0fPCoV@3o0_oo]P000oooB03ooooo
ooooo`06ooooo`Go01Ko0oo@o`02od[o00;o0?nK1ooF0?l2o`ko00?o0?nW2Ooo0<h00ooo067oo`0H
ool0600Fool061goo`2S7Ooo018=ool0E0Co02;o8?l0d_loojD0ob_o[03o9Ooo09d?ooooo`006_oo
ool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo02gooooo00Oo09_ooed0oooo0?;oo`1o
ool03?oo003oo`0B017ooooo00koo`06ool00?oo01koo`0fool0/?oX0?ooP@3oofT0oolV0?oo02ko
o`1<ool0Vooo08Woo`2Qo`Cooooo01ko0:7oo`3Zool0ROoo0:koo`1<ool0Jooo02koo`0dool04?oo
J@3oo`3o>_l0g_ooP@3ook80oonh0?oo0:OoonP0oomM0?ooo`3Dool0i_l0IOooo`2lool0Oooo06go
o`0`ool0??oo003oo`06ofl0oooo07<2ooooo`05o`10ooln0?oo0?mUool0h?n70?l01?ooool00ol0
1?ooQol0oooV0004ooooo`?o07go0oooool6ohd0o`?ooooo1?ooiP001?oooooo0?nEo`3oUOl0oiD2
o`3Ho`;oD?l00_l20?l01_ooooooo`32ool0`_oR0?oo[?l0ooooo`;oof400_ooL`02oi<0o`Goof40
0_l0UOl6oomQ00;o0?m[0ooo0=X3oiT0o`03ol[o0?oooooooooo00Cooooo1?oo]P05o`0Fo`05oom8
0?ooooooB_l0od[o0?l0oi/01ooF0?l2ooooo`;od?l01Ol0ojL3om3o00_o3_l02?l0oa`2ool0cPgo
o`1Q3?oo01P3ocP0o`ookP3o7?oo0:=Iool04TOoo`1D8?l0d_l?ooooo`006_ooool00ol0003ooooo
ooooo`0Pooooo`03ool00?oooooooooo02gooooo00Oo05Woog/0oooo0?;oo`0fool03?oo003oo`0B
017ooooo00ooo`0Hool00?oo01koo`0fool0/?oo0;co^03oofT0oolV0?oo013oo`1<ool0Jooo08Wo
o`3Zool0XOl00_ooool09Ol0XOoo0>[oo`3fool0ROoo04coo`1[ool0oo3o02koo`0dool04?ooJ@3o
o`3o>_n10?ooE`3ook80oonh0?oo0:OoonP0oonO0?ooo`3Dob`0oolD0?ooo`2Gool0KOoo097oo`0`
ool03?oo003oo`0Zool0LoooK@3oooooo`10ooooZ@3o?P3oool0h?n70?l01?ooool00ol01?ooQol0
ooooo`03ooooo`;o07go0_ooool4ohd0o`Wooooo1Ol0oiD3o`3Ho`;oD?l00_l20?l3ool0`P;o[?l0
1OooL`02oi<0o`Gooooo0_l0UOl5ooooo`;o0?m[0ooo0=X2oiT0o`03ol[o0?ooH@3oof4000Ooof40
1Ol05_l01?ooooooB_l0od[o0?m:o`06omH0o`GookH01_l0ojL7ooooo`;oogT02_o@o`000ol>o`3o
o`3/ool0k009ool0k003od@0ool0Mooo07Oo00So07Oo0oooQ@02ool0cPOoo`1Q:?oo01P7onh0odSo
o`2S4?oo0?iWool04Poooooo000Jooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0
;?ooool01ol0FOooN`3oool0l_oo03Koo`0<ool00?oo01P04_ooool03_oo003oo`0<ool07_oo0>3o
o`2`okP0oon10?ooJ@3oo`0@ool0FOoo04coo`2Kool0ROoo0>[o0ol0XOl07Ol0j_oo08Woo`2^ool0
C?oo06_oo`3ol?l0;_oo03Coo`0@oomY0?oo0?mOoh40oomG0?oo/P3ookP0oooX0?oo0?n3oil0oooo
0=Co0<coool0_?oo07ooo`1]ool0<?oo03coo`0<ool00?oo02[oo`1c00;ooooo00Co043ooch0ool0
ofGoo`3P1?ooool01?l01?ooooooooooooooool3o`1mo`;oog<00_n=0?l4oomc00Wo0?nE0_m@o`03
o`3Ho`;oD?l01Ooo0<800ooR0?oo[?l0oomc0002oomc00;ooooo0onC0?l5ooooo`;o09Go1Oooool0
1?l0of_oo`3Jool0f_oo0=X2oiT0o`Wooooo1?l05_l00oooH@3oB_l0od[o0006omH0o`Gooooo1_l0
ojL00ooooooookH0oonf0009oonf0004oomi0?ooooooooooooooo`[oo`3/00Co6_l0olCo0?o4o`3o
d?l02?l0MolAo`ko00GoohD000?o02;oojD0oonU0?l03OnU0?l00oo@0?ooo`1Qool0H@0Eool0HDCo
o`0H2oo^0?mgool0X`oooooo000Jooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0
;?ooool01ol0FOooN`3oool0_?oo03Koo`00ool01_ooH@004_ooool03_oo00Koo`00ool07_oo0:Wo
o`2`onP0oon10?ooJ@3oo`0@ool0;_oo04coo`2Koooooooo08Wo0ol0j_l08ol0m_oo08Woo`2^ool0
C?oo06_oo`3ol?l0;_oo03CoobH0oomY0?oo0?mOoh40oomG0?oo/P3ookP0oooX0?oo0?n3ool0e?oo
0>Ko06Goool0_?oo07ooo`1]ool0<?oo03coo`00ool01_m_0?ooo`1cooooool0@?oooc`0och0oooo
0>3oQ`3o00?ooooo00Go00Coooooooooooooooooo`1mo`02oomc00?oS@3o00?oD?l0o`3oUOl0oiD0
0ol0oiD4oe3o00Oo0=So00?o[?l0ool0`_oo0<800_oo0<82o`;o00;ohP3o0_ooL`04ooooo`;oT`3o
00?o0?3oooooooooool00oooool2o`2Eo`Cooooo00Cooo80o`3oJooo0=[oo`3J0_nI0?l9ooooo`?o
01Ko00?oooooomH0oooF0?l01?oF0?l00ol0oi_oooooooooo`02ooooo`03oomQ0?l0ojOo0?nW00?o
0?nW2?ooN@06ooooo`Soo`3/00?oA03ooa[o0?lJo`000_o4o`000ooo]P3o07Ooo`1go`06o`1go`So
oooo2oo@o`000ol08_ooY@3oojD0o`09ojD0oaKo3_l03_l0omPJool0cRgoo`1QP_oo01P?ooooo`00
6_ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo02cooooo00Ko013oog/0oooo0;co
o`0fool00?oo00HCooooo`0>ool06?oo003oo`0Nool0=_oo0;3oj03ooh40oomY0?oo9P3oo`0^ool0
C?oo06_oo`2^ool0ROl2o`3fo`;o08Wo01_oooooo`2^ool0C?oo06_oo`0^ool0ohoo03CoobH0oomY
0?oo0?mOoh40ool0ooKo^03oo`3oj_oX0?ooG@3oool0e?oo0>Ko06Goool0_?oo07ooo`1]ool0<?oo
02Coo`00ool01_oo07<00_ooool01?l0@?oo?P3oo`3Toooo0>03ooooo`06o`04ooooooooog<0oomc
0?l0OOoooooo0_n=0?l01?m@o`3o0?nEo`3oUOl0oiD4ojco0003ooooool0f?oo0=So00;o0=So0_n/
o`06ool0`P03o`80ool2o`3o0_l000?ohP3o1_ooool2oi<0o`03o`3`oooooooooooo00?ooooo0_l0
UOl3ooooo`;ooo800ooo0=X00onI0?ooooooooooo`07ooooo`;o01Ko1OoF0?l3o`3oV`Cooooo1Ol0
ojL4oomi00Oooooo2?oo0>`3od@0o`;oa?l000?oooooo`1gool0Mol01_l0Mol00ooocP3ooooooonf
000<oonf00;o02;o2onU0?l9oi?o00god?l00_l0omPGool0oQ[o3_l06?l0oo`AoomK00Co0?lL2_l8
0?mEool0cR?oo`1Q3oooool001[ooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0/
ooooo`06o`0@oonh0?ooo`2`ool0<?oo003oo`0B5?ooool03Ooo003oo`0<ool0:_oo0;3oo`2lokP0
oon10?oo9P3oo`0@ool0FOoo04coo`2Kooooool00ol0ROl2ooooo`0Po`2Kool0C?oo06_oo`0^ool0
=?oo013oobH0oomY0?oo0=kooh40ool0ooKo^03oo`2WoooX0?ooG@3oool0e?oo0>Ko503oool0Uooo
06goo`2Aool0<?oo00coo`00ool0:_oo07?oooooo`10oooooooo?P3oool0h?n70?l2ooooo`03ohOo
0?l01?ooog<000;ooooo00?o07goohd0oom@o`000_l0oiD2ooooo`Ko0=So1_oo0<84o`80o`03oooo
oooR0?oohP3o00;ohP3o1_ooool3oi<0o`03o`3`oooooooooooo00?ooooo0_l0UOl2ooooo`;ooo80
00?o0?m[ool0f_oo0=X00_nI0?l8ooooo`;o01Ko0ooF0?l01?m:o`3o0?nKo`3oVol0oi/3ooooo`Go
0?nW0oooN@06ooooo`Ooo`3/1Om40?l00oo4o`3oooooo`1go`06o`1go`03ooo>0?ooH@3oof4000Oo
of400_ooool4o`0Ro`WoY@3o00?o0?lFoi?o0?nCo`001OnCo`07ooooo`?ookH04Ooo0?h3oonf01Co
oooo0oo@o`0Eo`3oo003o`2jool80?oo203o00ko203o1om:0?mOokh0oc[o3_l03oooool001[ooooo
00?o0000ooooooooool08Oooool00ooo003oooooooooo`0/ooooo`06o`0@oonh0?ooo`2`ool07_oo
003oo`0B5?ooool03Ooo003oo`0<ool07_oo0>3oo`2`okP0oon10?ooJ@3oo`0@ool0;_oo04coo`2^
ool0Vol01?ooool08?l0[_oo09_oo`1<ool0Jooo02koo`0dool04?oo9P3oofT0ool0g_ooP@3oo`0L
oonh0?oo0:OoonP0oonO0?ooo`3Dool0n?oo0;coo`2Gool0KOoo033oo`0lool00?oo00KoK`3oool0
Looooooo043ooch0ool0i?ooo`3P0_ooool00on7o`3o00Cooomc0002ooooo`04o`1moon=0?oo0?nE
o`3oU@;ooooo0_l0f?l6ool0`PGo0P3o1_oR0?l8ooooo`;oT`3o0_l0l?l5ooooo`;o09Go0_ooool2
ooob0003o`3oJooo0=[oo`3J00;oV@3o2?ooool01Ol05_ooeP3oomH0oooF0?ooB_l000?o0?nK0_oo
ool4o`3oY`;oogT01oooool5ool0k0KoA03o00?oooooo`1gool0Mol01Ol0Mol:ooooo`Oo02;o1_nU
0?l2o`3o5PGoTol02OooH@0;ool0oP?o0?oH4OoooolEo`3oo003odX0oonn0?oo_P3o02co_P3o2ooo
oolmom3o01OoYOl05_l0od0To`3ogPoooooo000Jooooo`03o`000?oooooooooo027ooooo00?oo`00
ool06?ooool0;?ooool01_l04?oo^03oool0ZOoo01koo`00ool061Cooooo00goo`06ool00?oo01ko
o`0fool0/?oX0?ooP@3oofT0oolV0?oo02koo`3oSol0C?oo09_o00?ooooo02Go0:koo`2Kool0C?oo
06_oo`3ol?l0;_oo03Coo`0@oomY0?oo0?ljo`3Noon10?oo/P3ookP0oooX0?oo0?n3ool0e?oo0>Ko
0<coool0_?oo07ooo`1]ool0<?oo03coo`00ool01_oo07?oooooob3o0?l0@?oo?P3oool0h?n70?oo
ooooohOo0?l01?ooog<000;ooooo00Co07goojco0?n=0?oooooo0ol0f?l2ool0`P;ooooo0_l20?l7
on80o`_ooooo0onC0?l2o`3`o`Cooooo0ol0UOl01?oooooooo80ooob0?o:o`03ool0fP;oV@3o2?oo
ool3omH0o`;oB_l00_l0oi/2oomi00?o0?nW2Oooool4ool0k0GoA03o00?oolh0o`1gool0Mol01?l0
Mol;ooooo`Ko02;o1onU0?l00ol0oaKoTol0oi?o0002oi?o00Gooooo3?oo0?h3o`3of0?ooooo2?oo
H@0Ao`3oo0Co0?l44_nn0?lIooooobkookH05_nUo`16o`3ogQSo5?l03?oo]P0?ooooo`006_ooool0
0ol0003oooooooooo`0Rooooo`03ool00?oooooooooo02_ooooo00Ko6P3ookP0oooo0:Woo`0Nool0
0?l0on@Eooooo`0=ool00?oo01koo`0fool0/?oX0?ooP@3oofT0oolV0?oo013oo`1Iool0C?oo06_o
o`2Ko`03o`2^o`0So`2Kool0C?oo06_oo`3ol?l0;_oo03Coo`0@oomY0?oo0?ljoh40oomG0?oo/P3o
okP0oooX0?oo0?n3ool0e?oo0>Ko06Goool0_?oo07ooo`1]ool0<?oo02Coo`00ool01_oo07?ooooo
o`10ooln0?oo0>Coool0h?ooooooQol0o`04ooooL`000_ooool01Ol0OOooD?l0ohd0oooooooo0=So
00;o0_l000Coo`32o`80ool20?oo0P3o0ooR0?l?ooooo`?oT`3o0_l0l?l5ooooo`;o09Go00Gooooo
ooob0?oolP3ooo80o`3oJ`02ool0fP03oc80oonI0?ooV@3o00Sooooo0_oF0?l3od[o00;o0?nK00Co
ogT0o`3oYol0ojOo0?nW2?ooool01?o4o`3oo`3/ool0k?oo0>`4od@0o`;oolh01?l0Mol;ooooo`Go
02;o1onU0?l4oi?o0003oooh0?oo0?koo`3n00[oo`3n1Ol0omP:ooooo`_o0?ol2Ol0o`@00ol80?oo
_P3ookh0o`09okh0ob;oof407_ooool_o`3ogP;o0?m0;?lDo`0lo`16o`oooooo000Jooooo`03o`00
0?oooooooooo02;ooooo00?oo`00ooooooooool0:oooool01_lJ0?oobP3oool0ZOoo01koo`00oomQ
01Gooooo00goo`00ool03?oo01koo`2`ool0_?me0?ooP@3oobH0ool04?oo02koooooool0C?oo0?o0
00?o09_o02[o04coo`1[oooooooo0?o`o`0^ool0=?oo9P3oofT0ool0oeooP@3ooeL0oonb0?oo^03o
onP0oomM0?ooo`3Dool0i_l0IOooo`2Gool0NOoo06goo`0`ool03?oo003oo`0Zool0LolPo`3o043o
och0oooo`P3oo`3Poooooon7o`3o00Cooomc0?oooooo07gooe3o0?n=0?ooooooo`3Hooooool2ool0
`PCohP3o3Oooool2o`3`o`?oT`3o0_l0l?l6ooooo`;o09Go0ooolP001Ooooooo0?m[ool0f_oo0=[o
<P3o00;oV@3o1oooool00ol05_ooeP3oomH0o`02od[o00?o0?nK00?oogT0o`3oYol0ojL01_ooool0
0oo4o`3oo`3/ool0k003ool0k003od@0oolJo`3o6_l000?ooooo0ol0Mol9ooooo`Co02;o1onU0?l2
oi?o00[oo`3n00?oooooo`3of?l0omP01_l0omP8ooooo`[o0?ol2?l0o`@00ol0^_oo_P3ookh0o`0:
okh0obgooooo1oooH@0Go`3ogP?o0?m05?lDo`16o`16occoD03o3oooool001[ooooo0ol0000Roooo
o`03ool00?oooooooooo02_ooooo00Go9P3oool0l_oo0:Woo`0Nool0000Fooooo`0=ool01_oo003o
o`0Nool0ZOoo0;co^03ooh40oomY0?oo9P3oo`0^ool0oo3o06_oo`1<o`02o`3o`00]o`1<ool0ol3o
06_oooooool0;_ooooooo`0doolV0?ooJ@3oo`3oGon10?oo02SookP0ool0on[oj03ooed0oooo0=Co
o`3hoa@0oooo09Ooo`1]ool0<?oo03coo`00ool01_oo07?oooooob3o0?ln0?oo0?mUool0h?n70?oo
Qol0o`04ooooL`3oooooo`1moom@o`3oS@3oooooool2o`3o0=Soool0`_l20?oohP3o00_ooooo2?nC
0?l7ooooo`;ooo800_l0UOl2ooob0003ooooool0of_o0?m[00;oo`3J00?o<P3ooiT0oonI0?l01ooo
ool3omH0o`;oB_l00_l0oi/01?ooN@3oooooo`3oYol0ojL4ooooo`03olCo0?oo0>coo`3/00;oo`3/
0_m40?l2oa[o00?ooooo1?l0Mol6ooooo`03o`0RoonU0?ooY@3o00OoY@3o0_nCo`07ool0oPCooooo
1ol0omP8ooooo`So0?ol1ol0o`@00ol0^_oo_P3ookh0o`09okh0ob[ooooo5Ol0omh_o`16o`03o`2d
oom@0?ooD03o04?oD03o??l0>_l?ooooo`006_ooool00ol0003oooooooooo`0Rooooo`03ool00?oo
oooooooo02_ooooo00GoE`3oool0l_oo0:Woo`0<ool0000Fooooo`0=o`3oi?oo003oo`0Nool0=_oo
0;3oj03ooh40oomY0?oo9P3oo`0@ool0FOoo0?n?o`1[o`03o`1<o`0Qo`1[oooooooo0?o`o`0^ool0
FOoo013oobH0oomY0?oo0=kooh40ool07?oo^03oo`2WoooX0?ooW`3oool0e?oo0?Soo`2lool0Uooo
06goo`0`ool0??oo003oo`06ool0Looooooo043ooch0oooo`P3oo`3PoooV0?n7o`3o00Co00;ooooo
00Ko07gooooooon=0?oo0_l0o`3Hoooo0<82on80o`Cooooo0ooolP000ol0l?ooT`3ooi<0o`02oi<0
o`;o0?3o3?oolP03o`2Eo`?ob_l00_l0of/2ool0fP?oV@3o1oooool2omH0o`;oB_l000CoogT0o`3o
Vol0oi_ooooo0ol0ojL3ooooo`04olCo0?oo0>coo`3/ool0k0?oA03o00Co6_l0oooooooooooooooo
1?l0Mol3ooooo`SoY@3o0_l0oaH2oooh00Ooo`3n1Oooool6o`3of0Oooooo2?l0oo`4o`3o10co_P3o
8oooool@o`3ogQOo04Ko<?m@0?m5o`0jo`;ooooo5OooO`000olbo`3o0<Koo`36o`0Ro`36o`oooooo
000Jooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0:oooool01OmM0?ooo`3bool0
QOoo00coo`0001Oooooo00coo`00ool03?oo02[oo`2`onP0oon10?ooJ@3oobH0ool04?oo02koo`3o
l?ooool3o`1[o`;ooooo02Oo0?o`o`0^ool0=?oo013oobH0oomY0?oo0=kooh40ool07?oo^03oo`2W
oooX0?ooo`3Dool0i_l/0?ooo`2lool0Oooo06goo`0`ool09?oo003oo`0Zool0LolPo`3o043ooch0
oooo0>3oQ`3oohOo0?l01?ooog<0ooooool0OOoo[?l0ohd0ool2o`3o0=Sooooooooo0<800_ooool3
ooob00?o0?3o0_nC0?l>ooooo`Co09Go0_o:o`03o`3oJ`?oo`3J0_nI0?l7ooooo`05o`0FoooF0?oo
eP3ood[o0?ooN@000ol0oi/00ooooooo0?nWo`3oY`03ooooo`04olCo0?oo0>coo`3/ool0k0;oA03o
0_lJo`02ooooo`Co07Oo0oooool4ojD0o`05o`0Rool0oaKo0?lFo`3o5_oon0001ooo0?h7ooooo`Go
0?oH1Oooool00oooe03o0?olo`3oo005o`3oo0co_P3o00?o0;[oooooooooool07oooool;o`3ogQ;o
04Ko5om@0?l`o`0joaKooooo00?o<_l0o`36ool0a_l0A?l0a_lcooooo`006_ooool00ol0003ooooo
ooooo`0Sooooo`03ool00?oooooooooo02[ooooo00GoG@3oool0l_oo07?oo`0<ool0000Gooooo`0<
ool01_oo003oo`0Nool0/?oo0;coM@3ooh40ool0:?oo9P3oo`0^ool0FOoo0?n?1?ooool0:?l0ocCo
02koo`3oSol0=?oo013oobH0oomY0?ooP@3ooeL0oonb0?oo^03oonP0ool0oh?oo`3Dool0i_l0IOoo
o`2lool0Oooo06goo`0`ool03?oo003oo`0Zool0Lol0@?oo?P3oooo20?oo0>3oonH0ohOo0?l01?oo
ooooo`1moon/o`3oS@3oo`;o0?l0f?ooooooool0`_ooool2ooob0003ooooool0l?ooT`3o00?oT`3o
1_ooool4ol[o00Ko09Go0_o:o`02o`3oJ`Goo`3J0_nI0?l8ooooo`03o`0FoooF0?ooeP3o00;oogT0
0_l0oi/01?oooooo0?nWo`3oYol0ojL2ooooo`05olCo0?oo0>coo`3/ool0k?m40?l00olJo`02oooo
o`?o07Oo0oooool4ojD0o`?o0?lF1_oo0?h00onCo`3oooooooooo`05ooooo`Ko0?oH1?ooool2oooD
00?o0?ol2Onn0?l5o`2joakooooo2_l0omh7o`16oaOoD03o5ol0>_lIooooobko0<Ko6OoFo`13oooo
o`ko0?l^3oooool001[ooooo00?o0000ooooooooool08oooool00ooo003oooooooooo`0Zooooo`05
oed0oooo0?;oo`1cool00?oo00H05oooool03Ooo01Soo`00ool07_oo03Koo`2lokP0oon10?ooE`3o
obH0ool04?oo05Woo`3ol?l0oc@00oooool0:_l0oo3o02koo`1Iool0=?oo9P3oo`3o]?mY0?ooP@3o
oeL0oonb0?oo^03oonP0oomM0?ooo`3Dool0i_lD0?ooo`2Gool0NOoo06goo`0`ool00?oo00Koo`1c
oonY0?l0@?oo?P3oool0h?n70?ooQol0o`04oooooooo07goojco0?n=0?oo0_l0o`3Hooooooooo`32
on80oooolP3oooooo`3`o`;oT`3o0_ooool8ol[o00Co09Go0oooool3o`3oJ`Coo`3J0_ooool2oiT0
o`03oc80oooooooooooo00Gooooo00Co01KoomH0oooF0?ooeP3o0_ooN@02o`3oV`03ooooool0ojOo
0?nW00?ooooo00Coa?l0ool0k?oo0>coA03o0olJo`02ooooo`?o07Oo0_ooool4ojD0o`;o0?lF1Ooo
0?h00onCo`3oooooooooo`05ooooo`Ko0?oH1Oooool01?ooe03o0?olo`3oo?l0oo`6okh0o`Oo0;[o
6_ooool:o`3ogP03o`16oom@0?ooD03o00ooD03o5ol0>_lGooooo`;o<_l05ol0a_lFoc;o00;oe_l0
;?ooool_o`3o;RGo3P3o3oooool001[ooooo00?o0000ooooooooool08oooool00ooo003ooooooooo
o`0Yooooo`06o`2Koomk0?ooo`3bool0Looo003oo`066?ooool03?oo003oo`0Nool0=_oo0;3o^03o
oh40oomY0?oo9P3oo`0@ool0;_oo05Woo`3ol0?o0?ld02[o0?o`o`0^ool0FOoo03CoobH0oomY0?oo
0?ljoh40oomG0?oo/P3ookP0oooX0?ooG@3oool0e?oo0?Soo`2lool0Uooo06goo`0`ool0??oo003o
o`06ool0LolPo`3o043ooch0oooo0>3oonH0ohOo0?l01?ooooooo`1mooooooooS@3oo`3Hoooooooo
o`32on80oooolP3oooooo`3`oonC0?l2ooooo`;ob_l00_ooool6o`2Eo`?o0?m[1ooo0=X2ooooo`04
oc80oonI0?ooV@3ooiT0o`Oooooo00CoB_l0omH0oooF0?ooeP3o0_ooN@03o`3oV`03ooooool0ojOo
0?nW00;ooooo00Coa?l0ool0k?oo0>coo`3/0olJo`02ooooo`?o07Oo0_ooool3ojD0o`?o0?lF0ooo
0?h00onCo`3oooooooooo`05ooooo`Go0?oH1Oooool00oooe03o0?l4o`3oo002o`3oo0Go_P3o00?o
203oo`2jool0^_l00_l0^_lGooooo`03ojGo0?l0omko0?oN00Oo0?oN00?o04Kooe00oom@0?l02Om@
0?lAo`0joa[ooooo5_l0a_lHomKo01GoooooGOl>0?lHoh7o00go0?ma3oooool001[ooooo00?o0000
ooooooooool08oooool00ooo003oooooooooo`0Yooooo`06o`2Koomk0?ooo`2lool0Looo003oo`0B
6?ooool02ooo00Koo`00ool07_oo0;3oj03ooh40oomY0?oo02SoobH0ool04?oo02ko00Co0?o`02Go
0?n?o`0^ool0FOoo013oobH0oomY0?oo0=kooh40ool0:?oo^03oo`2WoooX0?ooo`3Dool0i_oo0?So
o`2lool0Uooo06goo`0`ool0??oo003oo`0Zool0Lol0@?oo?P3oool0h?n70?ooQol0o`04oooooooo
07goojco0?n=0?oo0_l0o`3Hooooooooo`3200;ooooo00?o0?3ooi<0ooooool00_o:o`001?oooooo
09Goo`2Eool0UOl4o`3oJ`Goo`3J00?ooooooc80oolb0?l00_lb0?l5oiT0o`Oooooo0_m:o`02omH0
o`;oogT00ol0oi/01?oooooo0?nWo`3oYol0ojL2ooooo`?oo`3/00?oA03ooa[o0?lJo`000_ooool3
o`1go`;ooooo0onU0?l3o`3o5P?oo`3n1_ooool5o`3of0Cooooo00?oom@0o`3o1?l0oo`00_l0oo`6
okh0o`?o0;[o4oooool4ojGo00Oo0?oN00?o04Kooe00oom@0?l02?m@0?l;o`0jo`03oon`0?oooooo
oooo013ooooo6?l0a_l2oc;o01;oe_l0;ol>0?lGon;o01WoPOl0D_l0`?l?ooooo`006_ooool00ol0
003oooooooooo`0Sooooo`03ool00?oooooooooo02Wooooo00Ko05Woog/0oooo0;coo`1cool00?oo
018Hooooo`0=ool06?oo003oo`0Nool0/?oX0?oo^03oofT0oomG0?oo9P3oo`0@oooooooo02koo`3o
8P02o`3oS`0Xo`0^oooooooo03Coo`0@oolV0?ooJ@3oo`3Noon10?oo01cookP0ool0Yoooj03oool0
e?oo0>Ko;03oool0_?oo07ooo`1]ool0<?oo00coo`00ofl0oooo07?o043ooch0oooo0>3oonH0ohOo
0?l01?oo07goojco0?n=0?oo0_l0o`3Hooooooooo`32on80oooooooo0?3ooi<0o`;ob_l000?ooooo
o`2Eool0UOl00_l0of/2ooooo`?oo`3J0_ooool2oc80o`KoV@3o2_ooool01Om:o`3oeP3oomH0oooF
0?ooogT000?o0?nK0_ooool2o`3oY`?ooooo0_oo0>`2od@0o`;o6_l00_ooool2o`1go`;ooooo0onU
0?l3o`3o5P?oo`3n1Oooool4o`3of0?ooooo00?ooe/0o`3o1?l0o`@00_l0oo`6okh0o`03o`P0ool0
^_oooooo013ooooo1OnUo`07o`3ogP03o`16oom@0?ooD03o00KoD03o2_l0>_l00ooo/03ooooooooo
o`0:oooooa7o0<Ko1_l0oj49oc;o00Koe_l05ol>0?lHo`3o;QOoPOl000?o0?mao`30ool0`?l0;Ol0
`?lFodCo01OoomX09OoLo`0?ooooo`006_ooool00ol0003oooooooooo`0Sooooo`03ool00?oo01So
oooo02Wooooo00Ko05Woog/0oooo0;3oo`0fool00?oo01PHooooo`0;o`3oi?oo003oo`0Nool0=_oo
0;co^03ooh40oomY0?oo9P3oo`0dool04?l00_l0;_l0:_oooooo02koo`0^ool0FOoo03Coo`0@oolV
0?ooJ@3oogD0oon10?oo01cookP0ool0Yoooj03oool0e?oo0>Ko06Goool0_?oo07ooo`1]ool0<?oo
00coo`00ool0LolPo`3o043oool0h?n70?ooQol0o`04oooooooo07goohd0ool2o`3o0=Sooooooooo
0<;ohP3oooooool0l?ooT`3ool[o00;ooooo00?o09Goo`3oJoooool01?oo0=X2ooooo`03oc80oonI
0?ooV@3o00;oV@3o2_ooool3oomi00;oB_l00_oF0?l01?ooN@3o0?nKo`3oVol0oi/3ooooo`;o0?nW
0_ooool3ool0k0;oA03o00?o6_l0ooooooooool00ol0Mol01OooooooY@3oojD0oonU0?oo02;o00;o
0?lF0ooo0?h5ooooo`?o0?oH00?ooooooomK0?ooe0000_l0o`@2o`3oo0Go_P3o00?o203oo`2joooo
ool04?ooool3ojGo00Oo0?oN00?o04Kooe00oom@0?l01_m@0?l8o`0jo`03oon`0?oooooooooo00Wo
oooo2ol0a_l;o`3oX@Co<_l01OoFo`0Bo`h0oaOo0?l^00?oPOl0o`30ool0`?l0;Ol0`?lFodCo01So
omX000?og?l0o`1aool0LOl0D?l0LOl?ooooo`006_ooool00ol0003oooooooooo`0Tooooo`03ool0
0?oooooooooo02Sooooo00Ko05;ookP0oooo0;3oo`0fool00?l0on@Iooooo`0;ool00?oo00coo`0N
ool0/?nh0?ooP@3oofT0ool0:?oo9P3oo`0@ooooool00_l0;_l2o`1Io`0Uo`3oC?l04?oo0?ndobH0
oomY0?ooM@3ooh40ool07?oo^03oonP0oomM0?ooo`3Dool0n?oo0;coo`2Gool0NOoo033oo`0lool0
0?oo00Koo`1co`10ooln0?ooo`3Poooooon7o`3o00Coo`1mool0oiGoS@3oo`3Hooooooooo`32on80
oooooooo0?3ooi<0o`02ooooo`;o09Go00Co0?m[oooooooo0=[ooooo0_ooN@04oiT0o`KoogT02_m:
o`03omH0o`?o0?nK1?ooool2o`3oY`05ooooooo4o`3oo`3/ool0k?ooool00_m40?l3ooooo`;o07Oo
00CoooooojD0oonU0?ooY@3o0_l08_l01?l0oaKoo`3nool0o_oo0?h5ooooo`?o0?oH0_ooe002o`3o
1003o`3oo?nn0?oo_P3o00?o_P3o0ol0^_l>ooooo`?oYOl01_l0omh00ol0A_ooD03ooe00o`06oe00
o`So03[o00?ook00ooooooooool01oooool:o`36o`_o0?nQ2OoFo`0;o`h0oa;o0?l^00?oPOl0o`30
ool0`?l05Ol0`?lFodCo00;oooooA_l0LOmBo`3oi0oooooo000Jooooo`03o`000?oooooooooo02Co
oooo00?oo`00ooooooooool0:?ooool01_l04?oo^03oool0ZOoo03Koo`00oomQ01Wooooo00_oo`06
ool00?oo01koo`2`onP0oonh0?ooG@3oofT0oolV0?oo08ooo`0@o`04ooooo`0]o`0dool04?oo9P3o
ocko0?mY0?ooP@3ooeL0oonb0?oo^03oonP0oomM0?ooo`3Dool0n?oo0;coo`2Gool0KOoo033oo`0l
ool00?oo02[oo`1co`10ooln0?ooo`3PohOo0?l01?ooooooo`1moon=0?oo0_l0o`3Hooooooooo`32
ooooool0l?oob_l0oi<0oooooooo09Goo`3oJoooooooogT0ool0f_ooN@3o<P3o00;oV@3o0oooool7
od[o00Gooooo00?o01KoomH0oooF0?l00_oF0?l3o`3oV`Gooooo0_l0ojL01Oo4o`3oo`3/ool0k?oo
0>co6_l000;oA03o0oooool2o`1go`03oooooonU0?ooY@3o00;o02;o00Co0?lFool0o_oo0?koo`3n
1Oooool3o`3of004oooD0?l0o`Co0?l4o`3oo0Co_P3o1?l0^_l<ooooo`;oYOl01_l0omh00ol0A_oo
D03ooe00o`05oe00o`03o`2dool0>_oo03[o00Go03[o0_oo/008ooooo`So0<Ko2_l0oj49omKo00_o
3P3o1_l0obh6on;o0003o`3oLOl0`?oo0<3o00oo0<3o5_m4o`000ooooooo077oo`1ao`0Fo`1aoaOo
0?n9;ol0on@Fooon0003oioo0?lVo`3o9_l003Wo9_l03oooool001[ooooo00?o0000ooooooooool0
9?ooool00ooo003oooooooooo`0Xooooo`05o`0@oonh0?ooo`2Yool0=_oo00006_ooool0=ol0LOoo
o`00ool07_oo0:Woj03ookP0oon10?ooJ@3oobH0ool0Sooo03Coo`0@oooooooo0?m<o`0doooooooo
013oobH0oomY0?oo0?mOoh40oomG0?oo^03oo`3oj_oX0?ooo`3Dool0i_oo0?Soo`2lool0Rooo06go
o`0`ool03?oo003oo`1co`3Tool0@?ooo`3Poooooon7o`3o00Coo`1mool0oiGoS@3oo`3Hoooooooo
o`32on80ool0l?oob_l0oi<0oooooooo09Goo`3oJoooN@000_oo0=X3oiT0o`GoB_l01oooool6omH0
o`Co0?nK1Oooool3o`3oY`?oo`3/00Cooooood@0oom40?ooA03o0_ooool3o`1go`03oooooonU0?oo
Y@3o00;o02;o0ooo0?h5ooooo`?o0?oH00Coom@0o`3o1?l0o`Co0?ol0onn0?l00ol80?oo0;[oo`2j
o`0;ooooo`03ojGo0?l0omko0?oN00Co0?oN00?o04Kooe00oom@0?l01Om@0?l00ol0]?oook00oon`
0005o`0jo`03oon`0?oooooooooo00Kooooo2?l0a_l8o`3oX@Soe_l02ol>0?l;on;o0003o`3oLOl0
`?oo0<3o00[o0<3o4Om4o`0Go`1aoboo0?oT5onOo`0_obKo04[ooooo000Jooooo`?o00009?ooool0
0ooo003oooooooooo`0Xooooo`05o`0@oonh0?ooo`2Yool0<?oo00006oooool03?oo003oo`0<ool0
=_oo0;co^03ooh40oomG0?ooJ@3oobH0ool0Sooo013oo`3oC0;o03Co02Go013ooooooolV0?ooJ@3o
o`3oGon10?oo01cookP0ool0Yoooj03oool0e?oo0>Ko;03oool0_?oo07ooo`1]ool0<?oo00coo`00
ool0Lol0@?oo?P3oool0h?n7o`3oog<0o`04ool0OOooS@3oo`3Hooooooooo`32on80ool0l?oob_l0
oi<0oooooooo09Go00;oogT000?oo`3JoiT0oonI0?l00_m:o`06ooooo`OoeP3o1Ol0oi/4ooooo`Ko
0?nW00?oa?l0ool0k?oo0>`01?m40?l3ooooo`;o07Oo00GoooooojD0oonU0?ooY@3oo`0Ro`03ool0
oPGooooo0ol0omP01?ooe03o0?l4o`3o1?l0oo`3okh0o`03o`P0oooooooooooo00Sooooo00?oYOl0
o`3og_l0omh01?l0omh7oe00o`04o`2doooo/03ook00oon`00Ko03[o1oooool7o`36o`So0?nQ1OoF
o`000ooooooo3P3oo`h0o`08o`h0o`[oh_l00_l0og4;o`30o`KoA?l05ol0LOlGo`3oi0;o;?l05?oo
oP02oioo02ko9_l0NOooool001[ooooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`0X
ooooo`05oaX0oooo0?;oo`2Yool07_oo00006oooool02ooo00Koo`00ool07_oo0;coj03ookP0oomM
0?ooJ@3oo`3om_lV0?oo08oo00?o013o02[oooooobH0oolno`3oJ@3oo`3Noon10?oo01cookP0ool0
Yoooj03oool0e?oo0>Koo`2lool0b?oo07ooo`1]ool0<?oo003oo`06ool0Lol0@?oo?P3oool0h?n7
o`3o00Coo`1mool0oiGoS@3oo`3Hooooooooo`32ooooool0l?ooT`3oooooool0UOooogT0oooooooo
0=[oV@3ooooooom:o`05ooooo`03o`0FoooF0?ooeP3o00?o0?nK2?ooool5o`3oY`Goa?l00_oo0>`2
od@0o`04oa[o0?ooooooooooooooo`?o07Oo00GoooooojD0oonU0?oo02;oo`3o5P02ool0oPGooooo
0ol0omP2oooD0003o`3o1?l0ooco_P3o00;o_P3o00?o203oooooooooool01_ooool2ojGo00Co0?oN
1_m@0?l2o`2do`Cook001Ol0>_l7ooooo`Ko0<Ko1ol0oj400ooFo`3oooooooooo`03ooooo`So3P3o
2OoRo`02o`3oL@_o0<3o4Ol0LOl00ooLo`3o;?l0obco0003obco017o0?oT00?o;?l0ooooooooool0
0ooooolAooon01So9_l0Yoooool001[ooooo00?o0000ooooooooool09Oooool00ooo003ooooooooo
o`0Wooooo`05oaX0oooo0?;oo`2Yool07_oo00006oooool02ol>0?ooo`00ool07_oo0;3oj03ookP0
oon10?ooE`3oofT0ool0oc[o9P3o00;o08oo0_ooool09_lV0?ooJ@3oo`3oGol0g_ooP@3oo`0Loonh
0?ooj03ooed0oooo0=Coo`3hool0_?oo09Ooo`1iool0<?oo03coo`00ool0:_oo07?o043oool0h?oo
ooooQol0o`04ool0OOoo0?nEohd0ooooooooo`32on80ool0l?oob_l0oi<0ool0UOooogT0oooooooo
0=[oV@3o0_m:o`03ooooo`06o`0FoooF0?ooeP3oomH0ool0oi_oolh01?o4o`07o`3oY`?oa?l00_oo
ool5ool0k004od@0oolJo`3oooooooooo`Co07Oo0_ooool2ojD0o`;o0?lF0_oo0?h4ooooo`?o0?oH
0oooe0001Ol0ooco_P3ookh0oonn0?oo203o00Oooooo0_nUo`001?l0od3o0?oNo`3og_l0omh4oe00
o`;o04Ko0_l0]?l2oon`00Ko03[o1_ooool6o`36o`Go0?nQ1oooool7o`h0o`Ooh_l03?l0`?l;o`1a
o`_o;?l03?l0on@;ooooo`Goooh000?oWol0obKo0?lVo`005OlVo`2oooooo`006_ooool00ol0003o
ooooooooo`0Uooooo`03ool00?oooooooooo02Oooooo00Go9P3oool0l_oo08Goo`0Nool0000Koooo
o`0;o`1aoooo003oo`0Nool0=_oo0;co^03ooh40oomG0?ooJ@3oo`3o]?lV0?l00oooool09olV0?oo
?_l0ofT0ool0oeooP@3ooeL0oonb0?oo^03oonP0oomM0?ooo`3Dool0n?oo0;coo`2;ool0KOoo033o
o`0<ool00?oo07?o043ooch0oooo0>3oQol0o`04ool0OOoo0?nEohd0ool0f?ooooooool0`_oooooo
0?3ooi<0ool0of_o09Gooooooooo0=[oV@3ood[o0003ooooo`?oeP3o1?o4o`05o`3oY`Sooooo1?oo
0>`3od@0o`03oa[o0?oooooooooo00?o07Oo0oooool01?oon03oY@3oojD0ool0oaH3ool0oPCooooo
0_l0omP01?ooF`3oom@0oooD0?l0o`@3okh0o`03o`P0oooooooooooo00Gooooo0_nUo`001?l0od3o
0?oNo`3og_l0omh3oe00o`;o04Ko0_l0]?l6o`0jo`Kooooo1_l0a_l3o`3oX@;oe_l01Oooool8o`h0
o`?oh_l02ol0`?l2odCo00[o077o2ol/o`0;o`3oi0Gooooo1onOo`0AobKo0=Kooooo000Jooooo`03
o`000?oooooooooo02Gooooo00?oo`00ooooooooool09oooool01OmG0?ooo`3bool0Looo01koo`00
01cooooo00[oo`06ool00?oo01koo`2lonP0oonh0?ooP@3oofT0ool0ooKo0?lj1?lV0?l09Olno`3o
J@3oo`3oGon10?ooE`3ookP0ool0on[oj03oool0e?oo0>Koo`3hool0_?oo08_oo`1]ool0<?oo00co
o`00ool0Lol0@?oo?P3oool0h?n7o`3o00Coo`1mool0oiGoS@3ooooooooo0<;ohP3oo`3`oonC0?oo
0?m[o`2Eooooooooo`3Joc80oonI0?l00oooool01?oF0?oo01Koo`3oVoo4o`04o`3oY`Kooooo00?o
6_l0ool0k?oo0>`01?oo0>`4od@0o`?ooooo0ol0Mol3ooooo`;oooP00_nU0?l00ol0oaKoo`3nool0
oP05ooooo`;o0?oH0oooe003okh0o`03o`P0oooooooooooo00Gooooo0_nUo`001?l0od3o0?oNo`3o
g_l0omh3oe00o`03o`16ool0]?oo03[o00Co03[o1_ooool6o`36o`03o`3oXOoFo`3oe_l000;oe_l0
0oooool8o`h0o`03o`3o;_oRo`3o0<3o00So0<3o0ol0og42odCo00So077o2_l/o`0;o`3oi0_oWol0
3?lVo`3Wooooo`006_ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo02Oooooo00Go
G@3oool0l_oo07?oo`0Nool0000Looooo`0;o`h0oooo003oo`0Nool0/?oX0?oo^03ooh40oomG0?oo
J@3oo`3om_l0ocX00olno`006Ol0oc[oJ@3oocSo0?n10?ooHol0okP0ool0on[oj03oool0e?oo0>Ko
06Goool0_?oo07ooo`1]ool0<?oo003oo`06ool0Lol0@?ooo`3PoooV0?l01?oo07goo`3oUOn=0?l0
0_ooool01Ooo0<;o0?3ool[o0?nC0?oo09Go00;ooooo00Soo`3JoiT0ooooooooooooo`3oVooF0?oo
0?nKolCo00;o0?nW0oooool2oa[o00Koo`3/1_m40?l4ooooo`?o07Oo1?oon0001?nCo`3oY@3oojD0
oonU0?l3ool0oPCooooo0ol0omP2oooD00?o_P3o00?o203oooooooooool01Oooool2ojGo0004o`3o
@?l0omko0?oNo`16o`?oD03o00?o0;Coo`0jool0>_l00_l0>_l5ooooo`Ko0<Ko00?o0?nQomKo0?oF
o`000_oFo`000ooooooo3P3oo`h0o`06o`h0o`?o0?l^00?oh_l0o`30ool0`?l01?l0`?l5o`3oL@;o
A?l01ol0LOl00ooLo`3o;?l0obco0003obco00co0?oT0ooooP08oioo00_o9_l0loooool001[ooooo
00?o0000ooooooooool09Oooool00ooo003oooooooooo`0Wooooo`05oed0oooo0?;oo`1cool03?oo
00007?ooool02ol0LOooo`00ool07_oo07ooo`2lokP0oome0?ooP@3ooeL0oomY0?oooooo00?o0?lj
02?oJ@3oo`3oGon10?ooM@3ook80oonh0?oo0:OoonP0oooo0=Coo`3Vool0_?oo0<Soo`1oool0KOoo
033oo`00ool0:_oo07?o?P3oool0h?n7o`3o00Coo`1mool0oiGoS@3ooooooooo0<;ohP3oo`3`oonC
0?oo09Gooomi0?ooooooo`3JoiT0o`02ooooo`05o`3oVooF0?ooa?l0olCo0?l0ojL00oooool01?lJ
o`3oo`3/ool0k?oo0>`6od@0o`Gooooo00?oooP0o`1gool0Mol00_l0Mol3oooh00GoY@3o00?o02;o
ool0o_oo0?h01?ooool00oooF`3o0?oHo`3of002oooD0004o`3o1?nn0?oo_P3oo`P0o`Oooooo0_nU
o`001?l0od3o0?oNo`3og_l0A_l3oe00o`Co03[o1?ooool5o`36o`?o0?nQ0_oFo`07o`h0o`Go0?l^
00?oh_l0o`30ool0`?l01?l0`?l3o`3oL@?oA?l01ol0LOl00ooLo`3o;?l0o`3oi00:o`3oi003oooo
oooooP3oooh000Coooh01OnOo`0;obKo0?kooooo000Jooooo`03o`000?oooooooooo02Kooooo00?o
o`00ooooooooool09_ooool01OmM0?ooo`3bool0Looo00coo`0001cooooo00_o0?oTool01_oo003o
o`0Nool0_?oX0?oo^03ooh40oomG0?oo02SoofT0o`02ooooo`0XofT0oooooooo0?mOoh40oome0?oo
/P3ookP0ool0Yoooj03oool0e?oo0?Soo`2lool0Uooo07ooo`0`ool03?oo003oo`1co`10ooln0?oo
o`3Po`04ooooL`3o07goohd0oooooooooo80ool0`_l0l?oob_l0oi<0ool0UOooooooool0f_lb0?oo
V@3oooooool0oi_oeP3oolCo00;o0?nW0olJo`02ool0k0;oA03o00?ooooooooh0?oon0001?oon006
o`1go`03oooooonCo`3oTol000CoY@3o0ol08_l3ool0oP?ooooo00Oooe/0o`3of?l0omSo0?oHoooD
0?l0o`Co0?ol00;o_P3o00?o203oooooooooool01?ooool2ojGo0004o`3o@?l0omko0?oNo`16o`?o
D03o0ol0>_l4ooooo`Co0<Ko1?l0oj46o`h0o`Ko0?l^00?oh_l0o`30ool0`?l01?l0`?l2o`3oL@Co
A?l01_l0LOl9o`3oi0Cooooo1OoooP02oioo00co9_l0ooooool:ooooo`006_ooool00ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo02Kooooo00GoN`3oool0l_oo07?oo`0<ool0000Mooooo`0:
okh0oooo003oo`0Nool0/?oX0?oo^03oogD0oon10?ooE`3oo`0Xo`;oJ@3o02_oooooo`3oGol0oe;o
P@3oogGo0?nb0?oo^03oonP0oomM0?ooo`3Dool0n?oo0;coo`2;ool0KOoo033oo`0<ool00?oo07?o
043oool0h?n7o`3o00Coo`1mool0oiGoS@3ooooooooo0<;ohP3oo`3`oonC0?oo09Gooomi0?oooooo
o`3JoiT0oooooooo0?nKomH0oooooooo0?nWoooooolJo`3ooooo00;oo`3/00CoA03ooooooooon03o
ooP01ol0Mol00onCo`3oY@3oojD0o`06ojD0o`;o02;o00?o0?lFooooooooool00_oo0?h2ooooo`03
oomK0?ooe03o0?oH00;o0?oH0_ooool01Ol0o`Co_P3ookh0oonn0?oo203o00Kooooo0_nUo`02o`3o
gP04o`16oom@0?ooD03ooe00o`?o03[o0oooool4o`36o`Co0?nQ1?l>0?l6o`3o;P03on;o0?l0`?oo
0<3o00Co0<3o00?o0?maodCo0?m4o`000om4o`06o`1ao`Ko0?oT1Oooool2ooon00;oWol02olVo`3o
oooooaKooooo000Jooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool09Oooool01_l0
VoooN`3oool0_?oo07?oo`00ool01Qgooooo00_o3P3oool00?oo01koo`1oool0_?oX0?oo/P3ooh40
oomG0?oo02Soo`3omP02ocSo000Zo`3oGol0:?ooP@3oof?o0?nb0?oo^03oonP0oooo0=Coo`3Vool0
n?oo0;coo`2;ool0KOoo033oo`00ool01_oo07?o?P3oool0h?n7o`3o00Coo`1mool0f?ooS@3oooob
0?oo0<;ohP3ool[o0?nC0?oo09Gooooooooo0=[oV@3oooooool0oi_o01KoomH0ool0ojOooooooa[o
0?ooooooo`3/0ooon003o`1go`?oTol000?oooooojD0oonU0?l00_nU0?l4o`0Ro`03o`3o5_oo0?ko
o`3n00Koo`3n0_ooF`001?ooe03o0?oHo`3of?l0omP2ooooo`05o`3o1?l0ooco_P3ookh0ool80?l0
1_ooool2ojGo0003o`3o@?l0omko04Ko00?oD03o00?o0;Coo`0jool0>_l00oooool3o`36o`Co0?nQ
00Coooooo`h0ool>0?oo3P3o1?l0obh00ooRo`3o0<3oo`30o`04o`30o`KoA?l01_l0LOl6o`3oi0?o
oooo00?oooh0oioo0?nOo`002OlVo`3oooooob7ooooo000<ooooo`Go00002Oooool00ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo02Gooooo00Ko09_oog/0oooo0;coo`1cool00?oo00HMoooo
o`0:o`1aoooo00Koo`00ool07_oo0;coj03ookP0oome0?ooP@3ooeL0o`;o02So0_l0ooH0:On10?oo
MOl0of?o0?nh0?oo0:OoonP0oooo0=Coo`3Voa@0oooo0;coo`1oool0KOoo033oo`00ool0:_l0@?oo
?P3oool0h?l01?oo07goo`3oUOn=0?oooo80ool0`_oR0?oo0?3ooi<0ool0UOooogT0od[o0?oo0=[o
V@3oo`3oVol05_ooeP3oo`3oYooooooo6_l0oooooooo0>coooP000?o07Oo00?oTol0ooooooooool0
1?nU0?l3o`0Ro`;ooooo1?oo0?h2oomK00Koom@00ol0omP01?oooooo0?l4o`3o1?l80?l3okh0o`03
o`2joooooooooooo00?ooooo0onUo`02o`3ogP?oD03o00Co0;Coo`0jool0>_oo03[o0_ooool3o`36
o`?o0?nQ0_ooool3o`h0o`;o0?l^00?oh_l0o`30ool0`?l00ol0`?l5odCo0003oooJ0?l0LOoo077o
00Co077o1_l0on@2ooooo`;oooh00_nOo`06obKo0?oooooo:_ooool000gooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo02Gooooo00Ko05Woog/0
oooo0;3oo`1cool00?oo018Nooooo`0:ool0o_oo003oo`0Nool0/?oX0?oo^03ooed0oome0?ooP@3o
oeL0o`;o02So02KoP@3oogD0oooooooo/P3ookP0ool0Yoooj03oool0e?oo0>Koo`2lool0b?oo07oo
o`1>ool07_oo003oo`1co`10oooo0>3oQol0o`04ool0OOoo0_l0ohd0ool20?ooo`32on80ooo:o`3o
T`3ooomi0?ooooooo`3JoiT0oooooooo01KoomH0ool0ojOooooooa[o00;oo`3/00KoTol0o`1goonC
o`3oTol0ooooool08_l2ojD0o`?ooe/01_oo0?h4oooD00So0?oH0ol0o`@01Ol80?oo_P3ookh0oonn
0?oo0;[o00Gooooo0onUo`02o`3ogP?oD03o00Co0;Coo`0jool0>_oo03[o0_ooool3o`36o`?o0?nQ
0_ooool3o`h0o`03o`3o;_oRo`3o0<3o00?o0<3o1?m4o`000ooofP3o077oo`1ao`04o`1ao`Ko0?oT
00?oooooooon0?oooP000_oooP000onOo`3o9_l0obKo0004obKo0?oooooo<?ooool000kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`03ool00?oo01Sooooo02Gooooo00Ko
05WookP0oooo0;3oo`0fool00?oo018Nooooo`09okh0oooo003oo`0Nool0Oooo0;coj03ookP0ool0
D_ooP@3o00;oE`3o02Sooooooh40oome0?ooHol0ok80oonh0?ooj03ooil0oooo0=Coo`3Vool0_?oo
08_oo`1oool0<?oo00coo`00ool0Loln0?ooo`3PohOo0?l01?oo07goohd0oooolP3o0P3oool0`_l0
l?ooT`3oo`2Eooooooooo`3JoiT0oooooooo01KoomH0ool0ojOooooooa[o0?oo0>coA03o0_l0Mol2
ooooo`?oY@3o00?ooe/0oooD0?oo0?h00_oo0?h5ooooo`Go0?oH1_l0o`@2o`3oo005o`P0oonn0?oo
_P3ookh0ool0^_l01_ooool2ojGo00;o0?oN0om@0?l2o`2do`;o03[o0_ooool3o`36o`?o0?nQ0_oo
ool3o`h0o`03on;o0?n1o`3o0<3o00;o0<3o0om4o`000ooooooo077oo`1ao`03o`1ao`Ko0?oT1Ooo
oP000onOo`3o9_l0obKo0004obKo0?oooooo=_ooool000oooooo00?o0000ooooooooool02?ooool4
o`0002Kooooo00?oo`00ooooooooool09?ooool01_l0D_oo^03oool0ZOoo03Koo`00ool061kooooo
00Wo3P3oool01_oo003oo`0Nool0_?oX0?oo/P3ookP0oome0?l00on10?l0:Ome0?ooHol0oooooonb
0?oo^03oonP0oooo0=Coo`3Vool0n?oo0;coo`2;ool0KOoo033oo`00ool01_oo07?o?P3oool0h?l0
1?oo07goo`3oUOn=0?oo0P3oool0`_oR0?ooT`3oo`2EooooN@3oooooool0f_nI0?oo0?nKo`0FoooF
0?oo0?nWoa[o0?oo0>coA03oo`1goooooooo0?lF00;oY@3o00?o02;ooooD0?oo0?h00_oo0?h00ooo
oooo0?oHo`3of005o`3of0Go0?l40_ooool2o`3oo0Go_P3o00?o0;[oooooooooool01?ooool3ojGo
0004o`3og_m@0?ooD03ooe00o`;o0;Co0ol0>_l01?ooooooogl0o`36ool0a_l3o`3oX@;ooooo0ol>
0?l00ooRo`3oPOl0o`30o`02o`30o`;oA?l000?oooooo`1aool0LOl00_l0LOl5o`3oi003oooooooo
oP3oooh000?oooh01_lVo`3ooooooccooooo000<ooooo`05o`000?ooooooooooooooool000002Ooo
ool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo02Cooooo00Ko013ookP0oooo0:Woo`0f
ool00?l0on@Nooooo`09o`1aoooo0?koo`00ool07_oo0;3oj03oob00oonh0?oo05;o00?oM@3o02[o
Hol0okko0?mMo`3o/P3ookP0oooX0?ooo`3Dool0i_l/0?ooo`2lool0Rooo06goo`0`ool00?oo03Ko
043oool0h?n7o`3o00Coo`1mool0f?ooS@3oo`80oooo0<;o0?3ooi<0ool0UOooooooool0f_nI0?oo
0?nKo`0FoooF0?oo0?nWoa[o0?m40?ooo`3/o`1goooooooo02;oojD0ool08_l3ool0oP;ooooo0_l0
omP6o`3o10[o_P3o00Co203oo`2jool0^_oo0;[o1Oooool3ojGo00;o0?oN0_m@0?l2o`2do`05oooo
ool0>_oo03[oooooooooO`000ol0a_l2o`3oX@;ooooo0ol>0?l00ooRo`3oPOl0o`30o`02o`30o`;o
A?l000Coooooo`1aool0LOoo077o1?l0on@00oooooooooh0ooon0002ooon00Ko9_l0oooooom2oooo
o`003?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool09oooool00ooo
003oooooooooo`0Tooooo`05o`0@oooo0?;oo`2Yool0<?oo00008?ooool02_nn0?ooo`00ool07_oo
07ooo`2lonP0oomM0?oo^03ookSo0?l0oh<2okko000Yoooooonb0?oo^03oonP0oonO0?ooo`3Dool0
i_lD0?ooo`2;ool0Oooo04koo`0Nool00?oo07?o?P3oool0h?n7o`3o00Coo`3oUOn=0?oo0P3ooooo
oooo0<;oT`3oo`2EooooN@3oB_l0ool0f_oooooo01KoomH0ool0ojOooooood@0oooo0>co07Ooo`3o
5_l08_ooY@3ooooD0?oo0?h00_ooool3o`3of0;o0?l400?ooooookh0oonn0?l00onn0?l4odX0o`?o
0;[o1_ooool4ojGo0004o`3o@?l0omko0?oNo`3ogP?oD03o0_l0]?l3o`0jo`04oomo0?l0a_oo0<Ko
o`36o`?o0?nQ00Koooooo`h0ool>0?oo3P3oo`3o;_n1o`03o`30o`;oA?l000CoomX0o`1aool0LOoo
077o0ol0on@01?ooooooooh0ooon0?oooP05obKo0003oioo0?oooooooooo0?ooooooAOooool000go
oooo0ol0000:ooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool09?ooool01OlJ0?oo
o`3bool0ZOoo01koo`00023ooooo00[o3P3oool01_oo003oo`0Nool0_?oX0?oo00[ookP0ool0D_oo
^?l00_l0oh<0:?nb0?oo^03oo`3oj_oX0?ooW`3oool0e?oo0>Koo`2lool0Rooo07ooo`1>ool03?oo
003oo`1coch0oooo0>3o00Coo`1mool2o`3oS@3oo`80oooo0<;ohP3ooi<0ool0UOooooooool0f_nI
0?oo0?nKomH0ool0ojOooooooa[o0?oo0>co07Ooo`3o5_l08_ooY@3ooooooooo0?h3o`3of0?ooooo
0onn0?l2o`P0o`;o0;[o2?ooool5ojGo00;o0?m01?l0omh3oe00o`;o0;Co00Coooooo`0jool0>_oo
ogl00ol0a_l3o`3oX@04ooooool>0?oo3P3oo`h0o`;o0?l^0ol0`?l2odCo0004oooJ0?l0LOoo077o
o`1ao`?o0?oT00?oooooooon0?oooP001?lVo`000onOo`3oooooooooo`3ooooood[ooooo000Joooo
o`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool09?ooool01OlJ0?ooo`3bool0QOoo01ko
o`00023ooooo00[o077oool0o_oo003oo`0Nool0/?oo0?;oj03ooaX0oonh0?oo/P3o0_nho`00:?nb
0?oo^03oonP0oomM0?ooo`3Dool0i_oo0?Soo`2lool0Rooo07ooo`0`ool00?oo00Ko043oohL0oooo
0>3o00Coo`1moon=0?oooo80o`80oooo0<;oT`3oo`2EooooN@3oB_l0ool0f_oooooo01KoomH0ool0
ojOo6_l0ool0k?l0Mooo0?lFo`0RoonU0?ooooooool0o_l0omP2o`3o1004ooooool0ooco_P3ookh0
o`;o203o0_l0^_l;ojGo0004ooooool0od3o0?m0o`3o@0?o0?oN00Go5?l0oe00oom@0?ooD03oo`16
o`02o`2do`?o03[o00?oogl0o`36ool0a_l00ol0oj401?oooooo3P3oo`h0ool>0?l2o`3o;P?o0<3o
0_m4o`001?oofP3o077oo`1aool0LOl3o`3oi003oooooooooP3oooh000?o9_l000?oWol0oooooooo
ool0oooooom>ooooo`006_ooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo02?ooooo
00GoE`3oool0l_oo07?oo`0Nool0000Qooooo`08ool0o_oo003oo`0Nool0Oooo0;coW`3oonP0oomM
0?l4okP0o`0Wo`3oj_oX0?ooG@3oool0e?oo0>Ko;03oool0_?oo07ooo`1]ool0<?oo003oo`0foch0
oooo0>3oQol0o`04ool2o`3oS@3oo`80oooo0<;ohP3ooi<0ool0UOooooooool0f_nI0?oo0?nKomH0
ool0ojOo6_l0od@0oooo0>co07Ooo`0RoonU0?ooooooool0o_l0omSo0?l400;ooooo00?o203ookh0
ool80?l00_l0^_l3ojGo00?ooooo0ol0od08o`3ogPGoD03o00?o04Koo`2dool0>_l00ol0>_l01?oo
O`3o0<Koo`36ool0a_l2o`3oX@04ooooool>0?oo3P3oo`h0o`;o0?l^0ol0`?l00ol0og7oA?l0oooJ
0003o`1ao`04o`3oROl0onCo0?oTooooo`;oooh00olVo`3ooooooeCooooo000Jooooo`03o`000?oo
oooooooo02Sooooo00?oo`00ooooooooool08oooool01OmM0?ooo`3bool0Looo01koo`00027ooooo
00_oD03oool01_oo003oo`0Nool0_?mk0?ooj03ooaX0oomM0?oo01cookP0o`02o`1Bo`0TonP0oonI
o`3oo`3Dool0i_oo0;coo`2;ool0Oooo06goo`0Nool00?oo03Ko?P3oool0h?l01?oo07goo`3Hoon=
0?oo0P3oool0`_nC0?oo09Gooomi0?m:o`3oo`3Jo`3oVol05_ooeP3ooa[o0?oon03oo`3/o`1gool0
8_ooooooojD0oooo0?ko0?l40_ooool01?l0ooco_P3ookh0ool0^_l3ojGo0003ooooool0od3o0?m0
00Go0?oN1?l0A_l5oe00o`;o0;Co00?oooooo`0jool0>_l00_l0>_l2oomo00?o0<Ko0ol0oj43o`h0
o`?o0?l^0_l0`?l00ol0og7oA?l0oooJ0003o`1ao`;o0?n90_l0on@2ooon00?o9_l0oooooomGoooo
o`006_ooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo02?ooooo00GoG@3oool0l_oo
07?oo`0<ool0000Qooooo`0bo`h0oooo0>coo`00ool07_oo0;3oo`3bob00oooX0?oo6P3ooed0ool0
on[o0?o<oed0oooX0?ooW`3oool0e?oo0?Soo`2lool0Rooo07ooo`1>ool03?oo003oo`1cohL0oooo
0>3o00Coo`3oUOn=0?oo0P3ooooooooo0<;oT`3oo`2EooooooooB_l0ool0f_l0oi_oeP3ooa[o0?oo
n03oo`3/o`1gool0oaKo02;oojD0oooo0?ko0?l4ooooool0oo`2okh0o`;oYOl000Coooooo`3o@?l0
od3o0?m00ol0omh9oe00o`So03[o0_ooO`001?oFo`3o0<Koo`36ool0a_l3o`3oX@?o3P3o0ol0obh0
1On1o`3o0<3oo`30ool0og7oomX000?o077o0_l0ohT3o`3oi004ooon0?lVo`3o9_l0obKo0?oooooo
F_ooool001[ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`0Sooooo`05oed0oooo
0?;oo`1cool03?oo00008Oooool02Ol0LOooo`3nool00?oo01koo`1oool0_?mk0?oo00[oonP0o`03
oed0o`0YonP0oonO0?ooo`3Dool0i_l/0?ooo`2lool0Rooo06goo`1>ool00?oo00Ko?P3oool0h?oo
L`3o00Coo`;o0?n=0?oo0P3oool0`_oR0?oo0?m[o`2Eoom:o`3oo`3Jo`3oVol05_ooeP3ooooh0?oo
ooooo`3/o`3o5_l08_ooY@3oool0o_l0omSoooooo`3oo?nn0?ooBP3oojGo0?ooool00_l0od02o`3o
gP04o`16oom@0?ooD03ooe00o`?o0;Co1_l0>_l00oooO`3oooooooooo`02ooooo`Ko0<Ko00?o0?nQ
ooooooooool00ol>0?l3o`3o;P06oh7o0?l0`?oo0<3oo`30ool0og7oomX00_l0LOl3o`3oR@;o0?oT
00Coooh0obKo0?lVo`3o9_l0oooooomMooooo`006_ooool00ol0003oooooooooo`0Xooooo`03ool0
0?oooooooooo02?ooooo00GoN`3oool0l_oo07?oo`0<ool0000Rooooo`07okh0oooo00Koo`00ool0
7_oo0?;oo`2log/0o`04onP0o`0Voil0oolJ0?ooo`3Dool0i_l0IOooo`2lool0Oooo06goo`0`ool0
0?oo03Ko?P3oool0h?l01?oo07goohd0ool20?ooooooool0`_nC0?oo09Gooooooom:o`3oo`3Jo`3o
VooF0?oo6_l0oooh0?oo0>co07Ooo`0RoonU0?ooo`3no`3of?oooooo0?olokh0ool0^_l2ooooo`04
o`3o@?l0omko04Koo`16o`;oD03o1_l0>_l2omKo00Co<_l01Ol0a_l3o`3oX@?ooooo00?oh_l0o`h0
ool>0?l00_l0obh2oh7o0004o`3oLOl0`?oo0<3oo`3oL@;oomX00_l0LOl2o`3oR@?o0?oT0olVo`3o
ooooof3ooooo000Jooooo`03o`000?oooooooooo02Sooooo00?oo`00ool06?ooool08oooool01Omk
0?ooo`3bool0Looo003oo`0602;ooooo00So3P3oool0k?oo003oo`0Nool0/?oo0;coN`3oo`23o`Co
W`3o02Go0?coool0e?oo0?Soo`2lool0b?oo07ooo`1]ool07_oo003oo`0fohL0oooo0>3o00Coo`;o
0?n=0?oo0P3oool0`_oR0?oo0?m[o`2Eoom:o`3oo`3Jo`3oVol05_ooeP3ooooh0?m40?ooo`3/o`0R
ooooooooY@3oool0o_oooooo0?olokh0ool0^_oooooo00;o0?m000Co0?oNoe00oom@0?ooD03o0_l0
>_l2omKo00;o<_l02?l0a_l4ooooo`So3P3o0_n1o`02o`3oL@?o0<3o0_oofP03o`1ao`04o`3oROl0
onCo0?oTo`3oi0?o9_l0oooooomSooooo`006_ooool00ol0003oooooooooo`0Yooooo`03ool00?oo
oooooooo02;ooooo00GoN`3oool0_?oo03Koo`00ool04P0Rooooo`0:o`h0oooo0?koo`00ool07_oo
08Goo`2`ool0_?mk0?oo08?oo`3odP;o0?lX02;oa03oool0e?l0ojkoo`2lool0Rooo07Woo`1>ool0
3?oo003o?P3oool0h?l01?oo07goohd0oooolP3o0P3oool0`_nC0?oo09Gooooooom:o`3oo`3Jo`0F
oooF0?oo6_l0oooh0?oo0>co0?lFo`0RoonU0?ooo`3nooooool0ooco_P3o0_ooool01?l0od3o0?oN
o`16oom@0?l3o`0jo`?o<_l00ol0a_l00ol0oj7oooooon;o0004on;o00Go3P3o1Ol0obh00on1o`3o
0<3oo`30o`04o`30o`03oooJ0?l0LOoo077o00;o077o00Co0?n9o`3oi?l0onCo0?oT0olVo`3ooooo
ofKooooo000Jooooo`?o0000:Oooool00ooo003oooooooooo`0Qooooo`06o`2Koon10?ooo`2lool0
=_oo003oo`0B8_ooool0;_l0LOooo`3nool01_oo003oo`0Nool0Rooo0;coo`3Do`0:ool0Poooon`0
o`3loooo0=Coo`3VolX0oooo0;coo`2;ool0KOoo033oo`00ool01_ln0?ooo`3Po`04ool0OOooS@3o
o`80ooooooooo`32oi<0ool0UOooB_l0ool0f_l0oi_o01KoomH0oooon03oo`3/o`1gool08_ooY@3o
ool0o_l0o`Co0?olokh0ooooool2o`3o@007o`3og_m@0?ooD03oo`0joooooooo<_l0omKo0003o`36
o`?oh_l01ol>0?l6oh7o00Go0<3o00?o0?maodCo0?oLo`001?l0LOl5o`3oi0?o9_l0oooooomYoooo
o`006_ooool00ol0003oooooooooo`0Yooooo`03ool00?oooooooooo027ooooo00Ko05WookP0oooo
0;3oo`0`ool00?oo01PSooooo`0`oe00oooo0>coo`00ool07_oo08Goo`3bool0_?oo0=Co00[oo`23
oooo0=Coo`3Vool0n?oo0;coo`38ool0Oooo06goo`0Nool00?oo03KoQ`3oool0h?l01?oo0_l0ohd0
ool20?ooo`32oi<0ool0UOoooooood[o0?oo0=[o01KoomH0oooon03oooooool0k?l08_ooY@3oo`3o
f?oo0?ko0?olokh0ool80?oo0?m0o`3og_l0A_ooD03o0_l0>_l2oc;o00;o0<Ko00?oh_l0o`3o;_l0
obh00ol>0?l2oh7o00;o0?ma2Ol0`?l00ol0og7oomX0oooJ0002omco00?o077o1?l0on@2ooon00?o
9_l0oooooom/ooooo`006_ooool00ol0003oooooooooo`0Yooooo`03ool00?oooooooooo027ooooo
00Ko05WookP0oooo0;3oo`0Nool00?l0LOlSooooo`08o`h0oooo0?koo`00ool03?oo01koo`2`ool0
_?oo0>H2ool0e00Wool0i_oo0?Soo`2lool0l_oo09Ooo`1oool0KOoo00coo`00ool0Looo0>3o00Co
o`1moon=0?oo0P3ooooooooo0<;oT`3oo`2Eoom:o`3oo`3Jo`3oVol05_ooeP3ooooh0?oo0>co07Oo
o`0RoonU0?ooo`3nooooool0ooco_P3oo`3o@?l0omko04Kooe00ool0>_oo<_l000?o0<Ko00?oh_l0
o`3o;_l0obh00_l>0?l2oh7o00Go0<3o00CoA?l0oooooooooooooooo2_l0LOl3o`3oi003oooooooo
oP3oooh000?o9_l0oooooom_ooooo`006_ooool00ol0003oooooooooo`0Yooooo`03ool00?oooooo
oooo027ooooo00Go05;oool0l_oo0:Woo`0Nool0000Tooooo`07o`1aoooo0?koo`0Hool00?oo01ko
o`2;ooX0o`02ool0_0;oo`3V02WobP3oool0_?oo0<Soo`2;ool0NOoo033oo`0<ool00?ln0?ooo`3P
o`04ool0OOooS@3oo`80oooo0<;ohP3oo`3oJol0UOooB_l0ool0f_l05_ooeP3ooooh0?nCo`3oo`3/
o`0RoonU0?oo0?oHool0o_l0ooco_P3oo`3o@?l0omko04Kooe00ool0>_ooooooo`36ooooooooh_l0
oh7o0003o`h0o`Co0<3o00?o0?maomco0?l0LOl01_l0LOl:o`3oi0?oWol00olVo`3oooooog;ooooo
000Jooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool08?ooool01Ol04?ooo`3bool0
ZOoo01koo`0002Gooooo00OoD03oool0k?oo003oo`0<ool0Oooj0?oo043o00Coo`2l02Coo`3bool0
Uooo07ooo`1]ool0<?oo003oo`06ohL0oooo0>3o00Coohd0ool20?ooooooool0`_nC0?oo09Good[o
0?oo0=[o0?nKo`0FoooF0?ooooP0ool0k?l0oaKo02;oojD0oooo0?ko0?olokh0oooo/03o0?oNoooo
oom@0?oo03[oooooool0a_l2on;o00;o3P3o0ol0`?l2ooooo`Co077o1ol0on@5oioo00So9_l0oooo
oomeooooo`006_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo023ooooo00Go013o
ool0l_oo0:Woo`0Nool0000Uooooo`07o`h0oooo0>coo`0Hool00?oo01koo`2;ooX0o`04ool0lP0[
ool0b?oo08_oo`1oool0KOoo01koo`00ool01_oo0>3o00Coo`1moon=0?oo0P3oool0`_oR0?oo0?m[
o`2Eoom:o`3oo`3Jo`0FoooF0?ooooP0ool0k?m40?oo02;oojD0oooo0?kooooookh0ool80?oo0?m0
o`3og_m@0?oo03[ooc;o0?l0a_ooh_l0o`3o;_l>0?ooooooo`30ool0og7oooooomco0002o`1ao`Co
0?oT0onOo`09obKo0?ooooooOOooool001[ooooo00?o0000ooooooooool0:_ooool00ooo003ooooo
ooooo`0Pooooo`05oaX0oooo0?;oo`25ool03?oo00009Oooool02?l>0?ooo`3nool0`_oo003oo`0N
ool0Oooo08_onP3o0_l0IOl09_lD0?ooo`38ool0Oooo07Woo`1Wool03?oo003oo`1cool0h?l01?oo
07goohd0ool20?ooo`32oi<0ool0UOooB_l0ool0f_nI0?oo01KoomH0oooon03oo`3/o`3o5_l08_oo
Y@3oool0o_l0ooco_P3oo`3o@?l0omko04Kooe00oolbo`3o0<Koon;o0?l0obko3P3o0_l0`?l01?oL
o`3o077oo`1aool0LOl2o`3oi0;oWol01OlVo`3oooooohKooooo000Jooooo`03o`000?oooooooooo
02[ooooo00?oo`00ooooooooool08?ooool01OlJ0?ooo`3bool0Looo00coo`0002Gooooo00Wo077o
ool0o_oo0>coo`00ool03?oo01koo`1oool0UolD0?l00_oo0<P0:?oo08_oo`1iool0KOoo033oo`0<
ool00?n70?ooo`3Po`1moon=0?oo0P3oo`3`oooo0<;o0?m[o`2Eoom:o`3oo`3Jo`0FoooF0?ooooP0
ool0k?m40?oo02;oojD0oooo0?ko0?olokh0ool0od3o0?oNo`16oom@0?oo03[oo`36oooooooo0?l^
o`h0ool0`?ooooooobco0?l0LOl3o`3oi0Co9_l0oooooon;ooooo`006_ooool00ol0003ooooooooo
o`0Zooooo`03ool00?oooooooooo023ooooo00GoG@3oool0l_oo07?oo`0<ool0000Vooooo`07oe00
oooo0>coo`32ool00?oo01koo`1]ool0O`03ool0R`0Uool0Oooo06goo`25ool07_oo003oo`06ool0
h?l0oiGo07goohd0ool20?ooo`32oi<0ool0UOooB_l0ool0f_nI0?oo01KoomH0oooon03oo`3/o`3o
5_nU0?oo0?l4ool0o_nn0?oook00o`3og_l0]?ooD03oo`0jool0a_ooooooo`3o;_l>0?oo0<3oomco
0002o`1ao`04o`3oi?lVo`3o9_l0obKo0?ooooooSoooool001[ooooo00?o0000ooooooooool0:_oo
ool00ooo003oo`0Hooooo`0Pooooo`05oed0oooo0?;oo`1cool00?oo00H09_ooool01ol>0?ooo`3n
ool0`_oo003oo`0<ool0<?oo06d00ooo07l09Ooo07Woo`1]ool0<?oo01koo`00ool01_oo0>3o07go
ohd0ool20?oo0?3oool0`_nC0?oo09Good[o0?oo0=[o01KoomH0oooon03oo`3/od@0ool08_ooY@3o
ool0o_l0^_oo_P3oo`3o@?l0omkoD03oo`0jool0a_ooh_l0o`3o;_l>0?oo0<3oomco0?l0LOl00_l0
on@00olVo`3oooooooooo`3ooooooi3ooooo000Jooooo`03o`000?oooooooooo02_ooooo00?oo`00
ooooooooool07oooool01OmM0?ooo`3bool0Looo003oo`0B02Kooooo00Oo077oool0o_oo0>coo`32
ool00?oo01koo`0`00;oo`1i0_oo06d09?oo033oo`18ool03?oo003oo`3Po`1mool2o`3oS@3oo`80
oooo0<;ohP3oo`2Eoom:o`3oo`3JoiT0ool05_ooeP3ooooh0?oo0>co02;oojD0ooooooooo`3nokh0
ool0od3o0?oNo`16oom@0?oo<_l0o`36ool0obko3P3oo`30oooLo`3o077oo`3oi0;o9_l0oooooonC
ooooo`006_ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo01oooooo00GoN`3oool0
l_oo03Koo`00ool0600Wooooo`07oe00oooo0>coo`32ool00?oo01koo`0`ool0I`02ool0K@0Uool0
QOoo033oo`0Nool00?oo00Koo`3Po`;o0?l0f?ooS@3oo`3`oooo0<;oT`3oo`2Eoom:o`3oo`3JolCo
0?l05_ooeP3oool0k?m40?oo02;oojD0oooo0?ko_P3oo`3o@?l0omko04Kooe00ool0>_oo0<Koo`3o
;_l>0?oo0<3oooooool0LOoo0?oTobKo003ooooooiGooooo000Jooooo`?o0000:oooool00ooo003o
ooooooooo`0Oooooo`05og/0oooo0?;oo`0fool00?l0LOl09oooool01_l>0?ooo`3nool0f_oo003o
o`0<ool07PCoo`0`02?oo`1Kool03?oo003oo`0Hool0h?l0f?ooS@3oo`80ool0l?ooo`32o`2Eoom:
o`3oooooool0f_l05_ooeP3ooi?o0?oo0>co02;oojD0ooooooooo`3nokh0ool0omko0;Cooe00ool0
>_oo0<Kooh7o0?l>0?oo0<3oooooool0LOoo0?oTobKo003ooooooiKooooo000Jooooo`03o`000?oo
oooooooo02_ooooo00?oo`00ooooooooool07oooool01?n10?ooo`2`ool07_oo000Xooooo`0/o`1a
oooo0?koo`3/ool0`_oo003oo`0<ool07_oo03Koo`1>ool0??oo01koo`0<ool00?oo0>3o0_l0o`3H
oon=0?oo0P3oool0`_nC0?oo09Good[o0?oo0=[oV@3oo`0FoooF0?ooo`3/od@0ool08_ooY@3oool0
o_nn0?oo0?m0o`3og_l0A_ooD03oo`36oon1o`3o0?l^o`h0oooLo`3o077oo`3oi?lVo`3ooooooiOo
oooo000Jooooo`03o`000?oooooooooo02_ooooo00?oo`00ool06?ooool07oooool01?nh0?ooo`2`
ool07_oo000Yooooo`06oe00oooo0>coo`3Jool06?oo003oo`0<0ooo01h08Ooo00coo`00ool0h?l2
o`3o0=Soohd0ool20?oo0?3oool0`_l0UOooB_l0oooooooo0=[o01KoomH0oonCo`3oo`3/o`0RoonU
0?ooo`3no`2joonn0?oo0?oNo`16oom@0?oo03[oo`36ool0obko3P3oo`30ool0LOoo0?oTobKo003o
oooooiSooooo000Jooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool07_ooool01?nh
0?ooo`2Yool07_oo000Yooooo`06o`h0oooo0?koo`3Jool0`_oo01Soo`000ooo00`2ool0000Nool0
h?l0f?ooooooohd0ool20?ooo`32oi<0ool0UOooB_l0ool0f_nI0?oo01KoomH0oooo0>coA03oo`0R
oonU0?ooo`3nokh0ool0omkoogl0o`16oom@0?oo0<Koo`3o;_l>0?oo0<3oo`1aool0onCo9_l0oooo
oonIooooo`006_ooool00ol0003oooooooooo`0/ooooo`03ool00?oooooooooo01gooooo00Go09_o
ool0l_oo0:Woo`0Nool0000Yooooo`05o`1aoooo0?koo`3/ool0`_oR0?l01Ooo00007_l0f?oooooo
oooooon=0?oo0P3ool[o0?oo0<;oT`3ood[o0?l0oi_oo`3Jo`0FoooF0?ooTol0ool0k?l08_ooY@3o
ool0o_nn0?oo0?m0o`3og_l0A_ooD03oo`0jool0obko3P3oo`30oooooooo077oobKo0?ooooooV_oo
ool001[ooooo00?o0000ooooooooool0;?ooool00ooo003oooooooooo`0Mooooo`05o`1Ioooo0?;o
o`2Yool03?oo0000:_ooool01Onn0?ooo`3/ool0f_oo0<;o09Go00?oo`060oooool06on=0?oo0?3o
o`80ool0of_oo`32oomi0?m:o`3oo`3JoiT0ool05_ooeP3oool0k?m40?oo02;oojD0oooo0?ko_P3o
o`3og_l0A_ooD03oo`0jool0obkoA?l0o`h0oooLo`3o077oo`3oi03ooooooi_ooooo000Jooooo`03
o`000?oooooooooo02cooooo00?oo`00ooooooooool07Oooool01Ol0D_ooo`3bool0QOoo00coo`00
02[ooooo00SoD03oool0o_oo0=[o<P3oool0`_l0UOoo0P3oohd0o`;o0?3o01coS@3oo`3`ool20?oo
0?m[ool0`_nC0?ooB_l0o`3oVooo0=[o01KoomH0oonCo`3oo`3/o`0RoonU0?ooo`3nokh0ool0od3o
0?oNo`16oom@0?oo0<Kooh7o0?l>0?oo0<3oo`1aool0onCo9_l0oooooonKooooo`006_ooool00ol0
003oooooooooo`0/ooooo`03ool00?oo01Sooooo01gooooo00Go013oool0l_oo07?oo`0<ool0000Z
ooooo`08o`1aoonn0?ooo`3/ool0f_lb0?ooo`32o`2Eool20?l2ohd0o`;o0P3o01Wo0?m[oooooooo
0<;oB_l0oooooooo0=[oV@3oo`0FoooF0?ooo`3/od@0oonU0?ooooooool0o_nn0?oo0?oNo`16oom@
0?oo03[ooh7o0?l>0?oo0<3oo`1aool0onCo9_l00?ooooooW?ooool001[ooooo00?o0000oooooooo
ool0;Oooool00ooo003oooooooooo`0Looooo`05o`0@oooo0?;oo`1cool00?oo00H0:oooool01onn
0?ooo`3/ool0f_l05_ooo`32on80ool0UOl01?l0of/06?l0UOooo`32oi<0oooooooo<P3oool0f_l0
5_ooeP3ooi?o0?oo0>co02;oojD0oooo0?ko_P3oo`3og_l0A_oo0;Cooe00ool0a_oo3P3oo`30ool/
o`3o077oobKo0?ooooooWOooool001[ooooo00?o0000ooooooooool0;Oooool00ooo003ooooooooo
o`0Looooo`05oaX0oooo0?;oo`1cool00?oo0180:oooool01om@0?ooo`3nool0k?oo0=[o<P3oool0
`_m:o`000_l0UOl06OoooooohP3oool0`_nC0?oooooooc80oooo0=[oV@3oo`0FoooF0?ooo`3/od@0
oonU0?ooo`3no`2joonn0?oo0?oNo`16oom@0?oo0<Koo`h0ool0`?oo;?l0o`1aool0on@0oooooonN
ooooo`006_ooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo01cooooo00Go6P3oool0
l_oo03Koo`00ool0600[ooooo`05o`1aoonn0?ooo`3/omH0oooo0=X00_oo0<82on80o`;oo`3201Oo
T`3oooooool0oi_o<P3oool0f_l05_ooeP3ooooooooo0>co02;oojD0oooo0?ko_P3oo`3og_l0A_oo
D03oo`0jool0a_oo3P3oo`30ool0LOoo0?oTobKo003ooooooikooooo000Jooooo`03o`000?oooooo
oooo02gooooo00?oo`00ooooooooool07?ooool01OmM0?ooo`3bool0=_oo003o077o02cooooo00Ko
_P3oool0o_oo0>coo`3JoiT0oooocP03ool0`P0God[o0?oooooo0?nKoc80oooo0=[o01Kooooh0?oF
0?ooo`3/oooD0?nU0?ooo`3no`2joonn0?oo04KoomKo0?m@0?oo0<Koo`h0ool0`?oo077oo`3oi?lV
o`00oooooonOooooo`006_ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo01_ooooo
00CoG@3oool0/?oo01koo`00;Oooool01om@0?oo_P3oool0k?oF0?ooo`3Joc80ooo4o`001?l0oi/0
5?o4o`3oV@3oool0f_ooooooeP3oo`3o5_oo0>co02;oojD0oooo0?ko_P3oo`3og_l0A_ooD03oo`36
ool0obko3P3oo`30ool0LOoo9_l0oooooonPooooo`006_ooool3o`0002kooooo00?oo`00oooooooo
ool06oooool01?mk0?ooo`2`ool07_oo000]ooooo`07o`1aoonn0?ooo`3/omH0oooo0=[oV@3ooc80
o`03olCo000Doc80oonI0?ooo`3JoooooooF0?oo0?lFod@0oooo0>coY@3oool0o_l0^_oo_P3oo`16
ool0]?ooD03oo`36ool>0?oo0<3oo`1aool0onCooooooj7ooooo000Jooooo`03o`000?oooooooooo
02kooooo00?oo`00ooooooooool06oooool01?n10?ooo`2Yool07_oo000^ooooo`04oe00oooo0?ko
o`3/omH0o`;oo`3J0olb0?l2ool0fP0BoooooooF0?ooTol0o`1goooo0>co02;oool0o_l0ooco203o
okh0ool0A_ooD03oo`36ool0obko3P3oo`30ool0LOoo9_l0oooooonQooooo`006_ooool00ol0003o
ooooooooo`0^ooooo`03ool00?oooooooooo01_ooooo00Co^03oool0ZOoo01koo`00;_ooool01_l0
LOoo_P3oool0k?l08_ooeP3oo`1go`Coo`3J0_oon0004?oF0?oo07Oood@0oooo0>coY@3oool0o_l0
^_oo_P3oo`16oom@0?oo0?nQo`36ool>0?oo0<3oo`1aoolVo`3ooooooj;ooooo000Jooooo`03o`00
0?oooooooooo02kooooo00?oo`00ool06?ooool06oooool01?nh0?ooo`25ool03?oo000^ooooo`05
o`3oi?nn0?ooo`3nool0k?m40?l00_oF0?l3oooh00;oeP3o00oo07Oood@0oooo0>co0?oHool0o_nU
o`3o203ookh0ool0A_ooD03oo`36ool0obko3P3oobco0?l0LOl0oooooonSooooo`006_ooool00ol0
003oooooooooo`0_ooooo`03ool00?oooooooooo01[ooooo00Coo`3bool0Looo003oo`06;oooool0
1Om@0?oo_P3oool0o_oo0>coA03o00CoeP3o0_l0Mol2ool0k00=o`3of?nU0?ooo`3no`2joonn0?oo
04Kooe00ool0oj7o0<Koo`h0ool0`?oo077oobKo003ooooooj?ooooo000Jooooo`03o`000?oooooo
oooo02oooooo00?oo`00ooooooooool06_ooool01?oo0?;oo`1cool00?oo018_ooooo`05o`1aoonn
0?ooBP3oool0o_oo0>`00_m40?l2o`1go`0@o`3o5_oo0>co02;oo`3of?nU0?ooo`3no`2joom:0?oo
_P3ooe00ool0>_oo0<Koo`3o;_l>0?oo077oo`3oi?ooooooY?ooool001[ooooo00?o0000oooooooo
ool0;oooool00ooo003oooooooooo`0Iooooo`05o`3oSooo0?;oo`1cool00?oo01P0;oooool01_l0
onCoD03ookh0oooo0?koY@3oool0k0?oA03o0_oo0>`03_l08_ooY@3oo`3oo?oo0?koBP3ookh0ool0
A_ooD03oo`36ool0obko3P3oo`30ool0LOoo9_l0oooooonTooooo`006_ooool00ol0003ooooooooo
o`0_ooooo`03ool00?oooooooooo01Wooooo00Go05Woool0l_oo03Koo`00o`1ao`0`ooooo`05o`h0
oom@0?oo_P3oool0o_nU0?l01?oo0>`03_l0omSoY@3oo`3oo?oo0?koBP3ookh0ool0]?ooD03oo`36
ool0obko0?mao`h0ool0LOoo9_l0oooooonUooooo`006_ooool00ol0003oooooooooo`0`ooooo`03
ool00?oooooooooo01Sooooo00Co05;oool0l_oo03Koo`00<Oooool01ol0LOoo3P3ooe00oonn0?oo
o`3nojD0ool0oo`00_ooool03OnU0?oo0?olool0o_m:0?oo_P3oo`3og_m@0?oo03[oo`36ool0og7o
3P3oo`30ool0LOl0oooooonVooooo`006_ooool00ol0003oooooooooo`0`ooooo`03ool00?oooooo
oooo01Sooooo00Co013oool0l_oo01koo`00<Oooool01?l0onCo3P3ooe00ool0A_l2ool0oP?oY@3o
00go0?olool0o_l80?oo_P3oo`3og_l0A_ooD03oo`36ool0obko3P3oo`30ool0LOoo9_l00?oooooo
Y_ooool001[ooooo00?o0000ooooooooool0<?ooool00ooo003oooooooooo`0Hooooo`04oaX0oooo
0;3oo`0Nool003;ooooo00Go077oo`h0oom@0?oo_P3oo`P0o`04ool0oP0;o`P0oonn0?oo0?oNo`16
oom@0?oo03[oo`3o;_l>0?oo0<3oooon0?l0LOl0oooooonWooooo`006_ooool00ol0003ooooooooo
o`0`ooooo`03ool00?oooooooooo01Sooooo00Co6P3oool0/?oo01koo`00<oooool00ol>0?oo0<Ko
oe00o`02okh0o`;oBP3o0_nn0?l02_ooO`3o04Kooc;o0?m@0?oo0?l^o`3oLOl>0?ooooh0o`1aoolV
o`3oooooojOooooo000Jooooo`?o0000<Oooool00ooo003oooooooooo`0Gooooo`04oed0oooo0:Wo
o`0<ool003?ooooo00Go077oo`h0oom@0?oo0;Coo`16o`03okh0o`0:o`2dool0A_oo0?nQoe00ool0
obko0?mao`h0ool/o`3o077oobKo0?ooooooZ?ooool001[ooooo00?o0000ooooooooool0<Oooool0
0ooo003oooooooooo`0Gooooo`04ofT0oooo0:Woo`00ool01SCooooo00Co3P3oo`3oLOm@0?ooD03o
1?l0A_l2oe00o`06o`3o;_m4o`3o3P3oobco0?l0LOoo0?oToooooonYooooo`006_ooool00ol0003o
ooooooooo`0aooooo`03ool00?oooooooooo01Oooooo00CoP@3oool0QOoo003oo`0B=?ooool01?l0
LOoo3P3oo`h0ool0a_l4oe00o`07o`0jool0obkoPOl0o`h0ool/o`3o077oo`3oi03ooooooj[ooooo
000Jooooo`03o`000?oooooooooo037ooooo00?oo`00ooooooooool05oooool01?n10?ooo`1cool0
0?oo01Peooooo`04o`1aool0`?oo3P3oo`3o;P;o0<Ko0_l0obh01Om4o`3o3P3oo`30ool0LOoo0?oT
0?ooooooZoooool001[ooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0Gooooo`04
okP0oooo07?oo`00o`1aocGooooo00Co0?oTo`1aool0`?oo3P3o0om4o`02o`h0o`03o`30ool0LOoo
0?oT0?oooooo[?ooool001[ooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`0Eoooo
o`04o`3oSooo0?;oo`0fool003Sooooo00?o077oo`h0ool>0?l00ol>0?l00ol/o`3o077oo`3oi03o
ooooojgooooo000Jooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool05Oooool01?l0
FOooo`3bool0=_oo000iooooo`04o`1aool0ohWo;?l0obco00;o077o00?o0?oTooooooooool0oooo
oon/ooooo`006_ooool00ol0003oooooooooo`0booooo`03ool00?oooooooooo01Gooooo00Co05;o
ool0l_oo01koo`00>Oooool00olVo`3o077oo`1ao`02o`1ao`03o`3oi?oooooooooo0?oooooo[Ooo
ool001[ooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`0Eooooo`04o`0@oooo0?;o
o`0Nool00?ooooook_ooool001[ooooo00?o0000ooooooooool0<oooool00ooo003oooooooooo`0D
ooooo`04oaX0oooo0;coo`0<ool00?ooooook_ooool000Go00000oooool00ol0003oooooooooo`02
ooooo`?o00002_ooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo01Cooooo00CoE`3o
ool0ZOoo003oo`06ooooooo^ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`0cooooo`03ool00?oooooooooo01Cooooo
00CoG@3oool0ZOoo003oo`0Booooooo^ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo1?l0000booooo`03ool00?oooooooooo01?ooooo00Go0?n?og/0oooo08Go
o`00ool0603oooooonkooooo0003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0dooooo`03ool00?oooooooooo01;ooooo00Go05Wooh40oooo03Ko
o`00o`1ao`3oooooonkooooo00001Ol0003ooooooooooooooooo000000Oooooo1?l0000:ooooo`03
o`000?oooooooooo03Cooooo00?oo`00ooooooooool04_ooool01?l0D_oo^03oool0=_oo003ooooo
onoooooo00001Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0dooooo`03ool00?oooooooooo01;ooooo00Co013oool0l_oo01koo`00ooooooo_
ooooo`0000Coooooo`000?l0003o00002?ooool5o`0000Wooooo00?o0000ooooooooool0=?ooool0
0ooo003oooooooooo`0Booooo`04oaX0oooo0?;oo`0Nool00?ooooookoooool001[ooooo00?o0000
ooooooooool0=?ooool00ooo003oooooooooo`0Booooo`04oed0oooo0;coo`0<ool00?ooooookooo
ool001[ooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`0Aooooo`04og/0oooo0:Wo
o`00ool01_ooooookoooool001[ooooo00?o0000ooooooooool0=Oooool00ooo003oooooooooo`0A
ooooo`04okP0oooo07ooo`00ool04_ooooookoooool001[ooooo00?o0000ooooooooool0=Oooool0
0ooo003oooooooooo`0Aooooo`04ool0l_oo03Koo`00ool06?ooooookoooool001[ooooo00?o0000
ooooooooool0=Oooool00ooo003oooooooooo`0Aooooo`03ool0l_oo01koo`000?ooooool?ooool0
01[ooooo00?o0000ooooooooool0=_ooool00ooo003oooooooooo`0?ooooo`04o`1Ioooo0;coo`0N
ool00?ooooool?ooool001[ooooo00?o0000ooooooooool0=_ooool00ooo003oooooooooo`0?oooo
o`04o`0@oooo0:Woo`0<ool00?ooooool?ooool001[ooooo00?o0000ooooooooool0=_ooool00ooo
003oooooooooo`0?ooooo`04oaX0oooo0:Woo`00ool04_ooooool?ooool001[ooooo0ol0000goooo
o`03ool00?oooooooooo00kooooo00CoG@3oool0QOoo003oo`0Hooooooo`ooooo`006_ooool00ol0
003oooooooooo`0gooooo`03ool00?oooooooooo00kooooo00?oN`3oool0Looo0000oooooooaoooo
o`006_ooool00ol0003oooooooooo`0gooooo`03ool00?oooooooooo00kooooo00?oo`3bool0=_oo
0000oooooooaooooo`006_ooool00ol0003oooooooooo`0gooooo`03ool00?oo0:Wooooo00kooooo
00?oo`3bool07_oo0000oooooooaooooo`006_ooool00ol0003oooooooooo`0hooooo`03ool00?oo
oooooooo00gooooo00?oo`2lool07_oo0000oooooooaooooo`006_ooool00ol0003oooooooooo`0h
ooooo`03ool00?oooooooooo00cooooo00Co05;oool0ZOoo00coo`00oooooooaooooo`006_ooool0
0ol0003oooooooooo`0hooooo`03ool00?oo0:Wooooo00cooooo00Co6P3oool0Looo003oo`0Boooo
oooaooooo`006_ooool00ol0003oooooooooo`0iooooo`03ool00?oooooooooo00_ooooo00CoG@3o
ool0Looo003o077ooooooooaooooo`006_ooool00ol0003oooooooooo`0iooooo`03ool00?oooooo
oooo00_ooooo00?obP3oool0=_oo0000ooooooobooooo`006_ooool00ol0003oooooooooo`0ioooo
o`03ool00?oo07?ooooo00[ooooo00Co02Soool0l_oo01koo`00ooooooobooooo`006_ooool00ol0
003oooooooooo`0jooooo`03ool00?oooooooooo00Wooooo00CoE`3oool0ZOoo00coo`00ooooooob
ooooo`006_ooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00Wooooo00CobP3oool0
=_oo003oo`0Booooooobooooo`006_ooool3o`0003[ooooo00?oo`00ool0Loooool02?ooool01Ol0
:?ooo`3bool07_oo003o077o0?ooooool_ooool001[ooooo00?o0000ooooooooool0>oooool00ooo
003oooooooooo`07ooooo`04oeL0oooo0:Woo`0<ool00?ooooooloooool001[ooooo00?o0000oooo
ooooool0>oooool00ooo003oo`3booooo`07ooooo`04olX0oooo07?oo`00ool04_ooooooloooool0
01[ooooo00?o0000ooooooooool0>oooool00ooo00Koo`00ooooo`07ooooo`04ool0l_oo03Koo`00
o`1aooooooooloooool001[ooooo00?o0000ooooooooool0??ooool00ooo003o6P3oooooo`05oooo
o`04o`1Ioooo0:Woo`0Nool00?oooooom?ooool001[ooooo00?o0000ooooooooool0??ooool00ooo
003oo`2Yo`0@o`04ooooo`05o`3oSomG0?ooo`1cool00?oo00H0ooooooodooooo`006_ooool00ol0
003oooooooooo`0looooo`04ool01_oo003oo`2YoeL0o`?ooooo00Go6P3oolX0oooo03Koo`00oomQ
003oooooooCooooo000Jooooo`03o`000?oooooooooo03gooooo00[oo`00ool03?oo0?;o6P3oo`1B
ool04?oobP3oool0/?oo01koo`00oooooooeooooo`006_ooool00ol0003oooooooooo`0nooooo`03
ool00?oo07?oo`3b00;obP3o00Coo`2Yool0=_oo003oo`0Boooooooeooooo`006_ooool00ol0003o
ooooooooo`0nooooo`08ool01_oo003oo`0fool0QOoo0:Woo`1cool03?oo003oooooooKooooo000J
ooooo`03o`000?oooooooooo03oooooo00Ooo`06ool00?oo01koo`0`ool07_oo003oo`060?oooooo
m_ooool001[ooooo00?o0000ooooooooool0@?ooool01Ooo01Soo`00ool00?oo003oo`060?oooooo
moooool001[ooooo0ol00011ooooo`03ool06?oo01;oo`0B0?oooooon?ooool001[ooooo00?o0000
ooooooooool0ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmoooo
o`006_ooool00ol0003oooooooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0
ooooooooooooocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`006_ooool0
0ol0003oooooooooo`3ooooooooooooo?Oooool001[ooooo00?o0000ooooooooool0oooooooooooo
ocgooooo000Jooooo`03o`000?oooooooooo0?oooooooooooolmooooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {369.812, 0}} -> {-23.4604, -0.132295, \
0.896044, 0.00810495}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(wuschelVsTime = 
        runPlot[sim, \ W /@ \((Range[n])\), {0, 300}, \ 
          PlotRange \[Rule] \ All, \ ImageSize \[Rule] \ 700, \ 
          holdLegend \[Rule] \ True, 
          PlotLabel \[Rule] 
            StyleForm[\ "\<WUS Concentration\>", 
              FontSlant \[Rule] \ Italic], \ 
          TextStyle \[Rule] \ {FontSize \[Rule] \ 30, \ 
              FontFamily \[Rule] \ Times}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 700 432.624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147147 0.613362 [
[.18254 .00221 -17 -32 ]
[.18254 .00221 17 0 ]
[.34127 .00221 -24.5 -32 ]
[.34127 .00221 24.5 0 ]
[.5 .00221 -24.5 -32 ]
[.5 .00221 24.5 0 ]
[.65873 .00221 -24.5 -32 ]
[.65873 .00221 24.5 0 ]
[.81746 .00221 -24.5 -32 ]
[.81746 .00221 24.5 0 ]
[.97619 .00221 -24.5 -32 ]
[.97619 .00221 24.5 0 ]
[.01131 .13739 -41.5 -16 ]
[.01131 .13739 0 16 ]
[.01131 .26006 -41.5 -16 ]
[.01131 .26006 0 16 ]
[.01131 .38273 -41.5 -16 ]
[.01131 .38273 0 16 ]
[.01131 .5054 -41.5 -16 ]
[.01131 .5054 0 16 ]
[.5 .63053 -123.25 0 ]
[.5 .63053 123.25 32 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01471 m
.18254 .02096 L
s
gsave
.18254 .00221 -78 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 .01471 m
.34127 .02096 L
s
gsave
.34127 .00221 -85.5 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 .01471 m
.5 .02096 L
s
gsave
.5 .00221 -85.5 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 .01471 m
.65873 .02096 L
s
gsave
.65873 .00221 -85.5 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 .01471 m
.81746 .02096 L
s
gsave
.81746 .00221 -85.5 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 .01471 m
.97619 .02096 L
s
gsave
.97619 .00221 -85.5 -36 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .01471 m
.05556 .01846 L
s
.0873 .01471 m
.0873 .01846 L
s
.11905 .01471 m
.11905 .01846 L
s
.15079 .01471 m
.15079 .01846 L
s
.21429 .01471 m
.21429 .01846 L
s
.24603 .01471 m
.24603 .01846 L
s
.27778 .01471 m
.27778 .01846 L
s
.30952 .01471 m
.30952 .01846 L
s
.37302 .01471 m
.37302 .01846 L
s
.40476 .01471 m
.40476 .01846 L
s
.43651 .01471 m
.43651 .01846 L
s
.46825 .01471 m
.46825 .01846 L
s
.53175 .01471 m
.53175 .01846 L
s
.56349 .01471 m
.56349 .01846 L
s
.59524 .01471 m
.59524 .01846 L
s
.62698 .01471 m
.62698 .01846 L
s
.69048 .01471 m
.69048 .01846 L
s
.72222 .01471 m
.72222 .01846 L
s
.75397 .01471 m
.75397 .01846 L
s
.78571 .01471 m
.78571 .01846 L
s
.84921 .01471 m
.84921 .01846 L
s
.88095 .01471 m
.88095 .01846 L
s
.9127 .01471 m
.9127 .01846 L
s
.94444 .01471 m
.94444 .01846 L
s
.25 Mabswid
0 .01471 m
1 .01471 L
s
.02381 .13739 m
.03006 .13739 L
s
gsave
.01131 .13739 -102.5 -20 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .26006 m
.03006 .26006 L
s
gsave
.01131 .26006 -102.5 -20 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .38273 m
.03006 .38273 L
s
gsave
.01131 .38273 -102.5 -20 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .5054 m
.03006 .5054 L
s
gsave
.01131 .5054 -102.5 -20 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04538 m
.02756 .04538 L
s
.02381 .07605 m
.02756 .07605 L
s
.02381 .10672 m
.02756 .10672 L
s
.02381 .16806 m
.02756 .16806 L
s
.02381 .19872 m
.02756 .19872 L
s
.02381 .22939 m
.02756 .22939 L
s
.02381 .29073 m
.02756 .29073 L
s
.02381 .3214 m
.02756 .3214 L
s
.02381 .35206 m
.02756 .35206 L
s
.02381 .4134 m
.02756 .4134 L
s
.02381 .44407 m
.02756 .44407 L
s
.02381 .47474 m
.02756 .47474 L
s
.02381 .53607 m
.02756 .53607 L
s
.02381 .56674 m
.02756 .56674 L
s
.02381 .59741 m
.02756 .59741 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -184.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 40 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 28.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 28.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(WUS) show
132.312 28.000 moveto
(Concentration) show
305.500 28.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 30.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 .024 0 r
.5 Mabswid
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01955 L
.05285 .01838 L
.06244 .01754 L
.07218 .0169 L
.0829 .01637 L
.09334 .016 L
.10458 .01571 L
.11468 .01552 L
.12571 .01537 L
.13613 .01527 L
.1458 .0152 L
.15637 .01514 L
.16633 .01511 L
.17526 .01508 L
.18493 .01506 L
.19444 .01504 L
.20487 .01503 L
.21013 .01503 L
.21577 .01502 L
.22594 .01502 L
.23122 .01502 L
.23611 .01501 L
.24137 .01501 L
.24718 .01501 L
.25221 .01501 L
.25693 .01501 L
.25954 .01501 L
.26192 .01501 L
.2673 .01501 L
.27722 .01501 L
.28278 .01501 L
.28782 .01501 L
.29765 .01501 L
.30692 .01501 L
.32543 .015 L
.34503 .015 L
.35456 .015 L
.36504 .015 L
.37458 .015 L
.3835 .015 L
.38848 .015 L
.3939 .015 L
Mistroke
.39903 .015 L
.40378 .015 L
.4085 .015 L
.41276 .015 L
.42232 .015 L
.43171 .015 L
.44161 .015 L
.45246 .015 L
.46244 .015 L
.48234 .015 L
.50046 .015 L
.52001 .015 L
.53077 .015 L
.54094 .015 L
.55062 .015 L
.56089 .015 L
.56966 .015 L
.57932 .015 L
.58425 .015 L
.58944 .015 L
.59871 .015 L
.60388 .015 L
.60868 .015 L
.61958 .015 L
.65867 .015 L
.67863 .015 L
.70022 .015 L
.71036 .015 L
.72107 .015 L
.7311 .015 L
.74026 .015 L
.74972 .015 L
.75493 .015 L
.75987 .015 L
.76412 .015 L
.76865 .015 L
.77361 .015 L
.7782 .015 L
.78057 .015 L
.78308 .015 L
.78755 .015 L
.79005 .015 L
.79237 .015 L
.79492 .015 L
.79765 .015 L
.80001 .015 L
.80257 .015 L
.80721 .015 L
.80941 .015 L
.81174 .015 L
Mistroke
.81592 .015 L
.81844 .015 L
.82084 .015 L
.82534 .015 L
.83018 .015 L
.83547 .015 L
.84496 .015 L
.85377 .015 L
.87431 .015 L
.89292 .015 L
.93301 .015 L
.97158 .015 L
.97619 .015 L
Mfstroke
1 .047 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01975 L
.05285 .01857 L
.06244 .01771 L
.07218 .01704 L
.0829 .0165 L
.09334 .01611 L
.10458 .01581 L
.11468 .01561 L
.12571 .01545 L
.13613 .01535 L
.1458 .01527 L
.15637 .01522 L
.16633 .01518 L
.17526 .01515 L
.18493 .01513 L
.19444 .01511 L
.20487 .0151 L
.21013 .0151 L
.21577 .01509 L
.22594 .01509 L
.23122 .01508 L
.23611 .01508 L
.24148 .01508 L
.24422 .01508 L
.24718 .01508 L
.24975 .01508 L
.25211 .01508 L
.25437 .01508 L
.25674 .01508 L
.258 .01508 L
.25935 .01508 L
.26063 .01508 L
.26178 .01508 L
.26244 .01508 L
.26314 .01508 L
.26391 .01508 L
.26462 .01508 L
.2659 .01508 L
.26662 .01508 L
.2673 .01508 L
.26855 .01508 L
.26925 .01508 L
Mistroke
.26988 .01508 L
.27113 .01508 L
.27228 .01508 L
.27293 .01508 L
.27362 .01508 L
.27431 .01508 L
.27507 .01508 L
.27573 .01508 L
.27644 .01508 L
.27771 .01508 L
.27898 .01508 L
.28036 .01508 L
.28167 .01508 L
.28288 .01508 L
.28516 .01508 L
.28759 .01508 L
.29214 .01508 L
.2964 .01508 L
.30612 .01507 L
.32464 .01507 L
.33512 .01507 L
.34486 .01507 L
.35539 .01507 L
.36494 .01507 L
.37516 .01507 L
.38077 .01507 L
.38605 .01507 L
.39109 .01507 L
.3958 .01507 L
.40071 .01507 L
.40611 .01507 L
.41077 .01507 L
.41502 .01507 L
.42457 .01507 L
.43381 .01507 L
.44363 .01507 L
.45441 .01507 L
.46439 .01507 L
.48405 .01507 L
.5021 .01507 L
.52143 .01507 L
.53158 .01506 L
.54227 .01506 L
.5518 .01506 L
.56199 .01506 L
.57161 .01506 L
.58035 .01506 L
.59032 .01506 L
.59951 .01506 L
.60961 .01506 L
Mistroke
.6203 .01506 L
.65816 .01506 L
.67921 .01506 L
.69846 .01506 L
.71836 .01506 L
.73725 .01506 L
.74685 .01506 L
.75708 .01506 L
.77547 .01506 L
.78576 .01506 L
.79689 .01506 L
.81707 .01506 L
.85809 .01506 L
.8976 .01506 L
.93559 .01506 L
.97604 .01506 L
.97619 .01506 L
Mfstroke
1 .071 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03163 .0212 L
.03279 .02107 L
.04262 .01976 L
.05217 .01865 L
.06244 .01772 L
.0728 .01702 L
.0825 .01653 L
.09403 .0161 L
.10458 .01582 L
.11442 .01562 L
.12357 .01549 L
.1336 .01538 L
.14429 .01529 L
.15457 .01523 L
.1657 .01519 L
.17621 .01515 L
.18587 .01513 L
.19561 .01512 L
.2047 .01511 L
.21467 .0151 L
.22026 .01509 L
.22536 .01509 L
.23016 .01509 L
.23527 .01509 L
.23969 .01508 L
.24444 .01508 L
.2471 .01508 L
.24953 .01508 L
.25201 .01508 L
.25431 .01508 L
.25685 .01508 L
.25819 .01508 L
.25962 .01508 L
.26112 .01508 L
.26186 .01508 L
.26254 .01508 L
.26382 .01508 L
.26449 .01508 L
.2652 .01508 L
.26633 .01508 L
.26752 .01508 L
.26883 .01508 L
.27004 .01508 L
Mistroke
.27129 .01508 L
.27246 .01508 L
.27351 .01508 L
.27464 .01508 L
.27528 .01508 L
.27598 .01508 L
.27672 .01508 L
.2774 .01508 L
.27863 .01508 L
.27994 .01508 L
.28124 .01508 L
.28247 .01508 L
.28478 .01508 L
.28699 .01508 L
.28934 .01508 L
.29356 .01508 L
.30309 .01508 L
.32282 .01508 L
.34089 .01507 L
.35016 .01507 L
.36028 .01507 L
.37045 .01507 L
.37596 .01507 L
.38115 .01507 L
.3861 .01507 L
.39145 .01507 L
.3959 .01507 L
.4008 .01507 L
.4061 .01507 L
.41171 .01507 L
.42176 .01507 L
.43176 .01507 L
.44125 .01507 L
.45218 .01507 L
.46215 .01507 L
.48035 .01507 L
.50045 .01507 L
.5202 .01507 L
.53103 .01507 L
.5412 .01507 L
.55102 .01507 L
.56136 .01507 L
.57019 .01507 L
.57986 .01507 L
.58513 .01507 L
.59011 .01507 L
.59944 .01507 L
.60467 .01507 L
.60949 .01507 L
.62039 .01507 L
Mistroke
.65976 .01507 L
.69761 .01507 L
.71703 .01507 L
.72794 .01507 L
.73277 .01507 L
.73792 .01507 L
.74309 .01507 L
.74777 .01507 L
.75004 .01507 L
.75248 .01507 L
.75478 .01507 L
.75692 .01507 L
.75942 .01507 L
.76075 .01507 L
.76217 .01507 L
.76288 .01507 L
.76366 .01507 L
.76435 .01507 L
.76507 .01507 L
.76573 .01507 L
.76645 .01507 L
.76772 .01507 L
.769 .01507 L
.77018 .01507 L
.77148 .01507 L
.77284 .01507 L
.77514 .01507 L
.77765 .01507 L
.78294 .01507 L
.78793 .01507 L
.79727 .01507 L
.81823 .01507 L
.82796 .01507 L
.83826 .01507 L
.84705 .01507 L
.85204 .01507 L
.85671 .01507 L
.8617 .01507 L
.86452 .01507 L
.86587 .01507 L
.86713 .01507 L
.86834 .01507 L
.86965 .01507 L
.87083 .01507 L
.87192 .01507 L
.8731 .01507 L
.8744 .01507 L
.87506 .01507 L
.87575 .01507 L
.87702 .01507 L
Mistroke
.87826 .01507 L
.87941 .01507 L
.88201 .01507 L
.8843 .01507 L
.88672 .01507 L
.89556 .01507 L
.93338 .01507 L
.97366 .01507 L
.97619 .01507 L
Mfstroke
1 .095 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02133 L
.03163 .02122 L
.03279 .02108 L
.04262 .01979 L
.05217 .01869 L
.06244 .01777 L
.0728 .01707 L
.0825 .01658 L
.09403 .01615 L
.10458 .01587 L
.11442 .01568 L
.12357 .01554 L
.1336 .01543 L
.14429 .01535 L
.15457 .01529 L
.1657 .01524 L
.17621 .01521 L
.18587 .01519 L
.19561 .01517 L
.2047 .01516 L
.21467 .01515 L
.22026 .01515 L
.22536 .01515 L
.23016 .01515 L
.23527 .01514 L
.23963 .01514 L
.24444 .01514 L
.24713 .01514 L
.2496 .01514 L
.25089 .01514 L
.2523 .01514 L
.25302 .01514 L
.25378 .01514 L
.25449 .01514 L
.25515 .01514 L
.25645 .01514 L
.25714 .01514 L
.25786 .01514 L
.25908 .01514 L
.25977 .01514 L
.26042 .01514 L
.26162 .01514 L
.26272 .01514 L
.2652 .01514 L
Mistroke
.26995 .01514 L
.27442 .01514 L
.27562 .01514 L
.27689 .01514 L
.27756 .01514 L
.27829 .01514 L
.27957 .01514 L
.28073 .01514 L
.28198 .01514 L
.28315 .01514 L
.28423 .01514 L
.2849 .01514 L
.2856 .01514 L
.28688 .01514 L
.28976 .01514 L
.29224 .01514 L
.29499 .01514 L
.30496 .01514 L
.32598 .01514 L
.33517 .01513 L
.34522 .01513 L
.35436 .01513 L
.3641 .01513 L
.3744 .01513 L
.38396 .01513 L
.38931 .01513 L
.39423 .01513 L
.39963 .01513 L
.40535 .01513 L
.41031 .01513 L
.41495 .01513 L
.42551 .01513 L
.4305 .01513 L
.43594 .01513 L
.44584 .01513 L
.46439 .01513 L
.48375 .01513 L
.50514 .01513 L
.51487 .01513 L
.52536 .01513 L
.53521 .01513 L
.54437 .01513 L
.55392 .01513 L
.56439 .01513 L
.57458 .01513 L
.58029 .01513 L
.58548 .01513 L
.59544 .01513 L
.60464 .01513 L
.62543 .01513 L
Mistroke
.6648 .01513 L
.70265 .01513 L
.72208 .01513 L
.73298 .01513 L
.74296 .01513 L
.76196 .01513 L
.77271 .01513 L
.78269 .01513 L
.82184 .01513 L
.86344 .01513 L
.90353 .01513 L
.9421 .01513 L
.97619 .01513 L
Mfstroke
1 .119 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03474 L
.02729 .04304 L
.02846 .04858 L
.02954 .05187 L
.03053 .0537 L
.03163 .05474 L
.03279 .05511 L
.03395 .05497 L
.0352 .05448 L
.03638 .0538 L
.03746 .05306 L
.04262 .04891 L
.0529 .04082 L
.06244 .03478 L
.07277 .0298 L
.08405 .02582 L
.09398 .02325 L
.10458 .02125 L
.11487 .01982 L
.12599 .01871 L
.1365 .01796 L
.14616 .01745 L
.1559 .01707 L
.16499 .01681 L
.17496 .01659 L
.18565 .01642 L
.19582 .01631 L
.20119 .01626 L
.20689 .01622 L
.21186 .01619 L
.21734 .01616 L
.22701 .01612 L
.23193 .01611 L
.2371 .01609 L
.24152 .01609 L
.24636 .01608 L
.24909 .01608 L
.25158 .01608 L
.25296 .01607 L
.25445 .01607 L
.25586 .01607 L
.25716 .01607 L
.25836 .01607 L
.25949 .01607 L
.26072 .01607 L
.26141 .01607 L
.26204 .01607 L
.26331 .01607 L
Mistroke
.26403 .01607 L
.2647 .01607 L
.26721 .01607 L
.27231 .01607 L
.27498 .01607 L
.27633 .01608 L
.2771 .01608 L
.27781 .01608 L
.27912 .01608 L
.28032 .01608 L
.28098 .01608 L
.2817 .01608 L
.283 .01608 L
.28421 .01607 L
.28548 .01607 L
.28778 .01607 L
.28998 .01607 L
.29235 .01607 L
.29663 .01607 L
.3064 .01606 L
.32608 .01604 L
.33649 .01603 L
.34759 .01602 L
.35837 .01601 L
.36815 .016 L
.37799 .016 L
.38726 .016 L
.39191 .016 L
.39701 .016 L
.40234 .01599 L
.40732 .01599 L
.41623 .01599 L
.42578 .01599 L
.43594 .01599 L
.447 .01599 L
.46711 .01599 L
.48647 .01599 L
.50786 .01598 L
.51759 .01598 L
.52809 .01598 L
.5471 .01598 L
.55665 .01598 L
.56711 .01598 L
.57803 .01598 L
.5882 .01598 L
.59871 .01598 L
.60864 .01598 L
.62722 .01598 L
.66565 .01598 L
.68511 .01598 L
Mistroke
.70654 .01598 L
.7271 .01598 L
.74591 .01598 L
.76533 .01598 L
.78621 .01598 L
.82594 .01598 L
.86416 .01598 L
.90482 .01598 L
.94397 .01598 L
.97619 .01598 L
Mfstroke
1 .142 0 r
.02381 .01472 m
.02499 .02009 L
.02605 .02112 L
.02729 .02149 L
.02846 .02158 L
.02954 .02156 L
.03053 .02149 L
.03163 .0214 L
.03279 .02127 L
.04262 .02 L
.05217 .01888 L
.06244 .01793 L
.0728 .0172 L
.0825 .01669 L
.09403 .01624 L
.10458 .01594 L
.11442 .01574 L
.12357 .01559 L
.1336 .01547 L
.14429 .01538 L
.15457 .01532 L
.1657 .01527 L
.17621 .01523 L
.18587 .01521 L
.19561 .01519 L
.2047 .01518 L
.21467 .01517 L
.22026 .01517 L
.22536 .01516 L
.23016 .01516 L
.23527 .01516 L
.23963 .01516 L
.24444 .01516 L
.24713 .01516 L
.2496 .01516 L
.2523 .01516 L
.25366 .01515 L
.25515 .01515 L
.25647 .01515 L
.25767 .01515 L
.25833 .01515 L
.25905 .01515 L
.26036 .01515 L
.26158 .01515 L
.26288 .01515 L
.26399 .01515 L
.2652 .01515 L
.26998 .01516 L
.2725 .01516 L
.27388 .01516 L
Mistroke
.27518 .01516 L
.27642 .01516 L
.27707 .01516 L
.27776 .01516 L
.27898 .01516 L
.28009 .01516 L
.28122 .01516 L
.28227 .01516 L
.28342 .01516 L
.28465 .01516 L
.28606 .01516 L
.28759 .01516 L
.29036 .01515 L
.29307 .01515 L
.29557 .01515 L
.30554 .01515 L
.32584 .01515 L
.33577 .01515 L
.34486 .01515 L
.35356 .01514 L
.36307 .01514 L
.37262 .01514 L
.38266 .01514 L
.38797 .01514 L
.39297 .01514 L
.39751 .01514 L
.40231 .01514 L
.40755 .01514 L
.41238 .01514 L
.42328 .01514 L
.43274 .01514 L
.44289 .01514 L
.46122 .01514 L
.481 .01514 L
.50255 .01514 L
.51257 .01514 L
.52322 .01514 L
.5332 .01514 L
.54236 .01514 L
.55171 .01514 L
.56181 .01514 L
.5707 .01514 L
.58008 .01514 L
.58507 .01514 L
.58961 .01514 L
.59449 .01514 L
.59979 .01514 L
.6047 .01514 L
.60923 .01514 L
.61815 .01514 L
Mistroke
.65752 .01514 L
.69538 .01514 L
.70534 .01514 L
.7148 .01514 L
.72002 .01514 L
.72571 .01514 L
.72822 .01514 L
.73089 .01514 L
.7334 .01514 L
.73569 .01514 L
.73689 .01514 L
.73801 .01514 L
.73925 .01514 L
.74057 .01514 L
.74123 .01514 L
.74195 .01514 L
.74326 .01514 L
.74454 .01514 L
.74572 .01514 L
.74682 .01514 L
.74785 .01514 L
.7502 .01514 L
.75248 .01514 L
.75495 .01514 L
.76024 .01514 L
.76582 .01514 L
.77577 .01514 L
.8139 .01514 L
.83517 .01514 L
.85448 .01514 L
.89355 .01514 L
.93355 .01514 L
.97204 .01514 L
.97619 .01514 L
Mfstroke
1 .166 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04314 L
.02846 .04881 L
.02954 .05228 L
.03053 .05427 L
.03163 .05548 L
.03279 .05599 L
.03395 .05597 L
.0352 .05557 L
.03638 .05496 L
.03746 .05426 L
.04262 .05019 L
.0529 .04197 L
.06244 .03575 L
.07277 .03058 L
.08405 .02642 L
.09398 .02374 L
.10458 .02163 L
.11487 .02013 L
.12599 .01896 L
.1365 .01816 L
.14616 .01762 L
.1559 .01722 L
.16499 .01693 L
.17496 .0167 L
.18565 .01652 L
.19582 .0164 L
.20119 .01635 L
.20689 .0163 L
.21186 .01627 L
.21734 .01624 L
.22701 .0162 L
.23193 .01618 L
.2371 .01617 L
.24152 .01616 L
.24636 .01616 L
.24909 .01615 L
.25158 .01615 L
.25296 .01615 L
.25445 .01615 L
.25574 .01615 L
.25716 .01615 L
.25847 .01615 L
.2597 .01615 L
.261 .01615 L
.26173 .01615 L
.26239 .01615 L
.26358 .01615 L
Mistroke
.26487 .01615 L
.26608 .01615 L
.26721 .01615 L
.27231 .01615 L
.27498 .01615 L
.27633 .01615 L
.2771 .01615 L
.27781 .01615 L
.27911 .01615 L
.27982 .01615 L
.2805 .01615 L
.2817 .01615 L
.283 .01615 L
.28421 .01615 L
.28548 .01615 L
.28657 .01615 L
.28778 .01615 L
.29019 .01615 L
.2924 .01615 L
.29739 .01614 L
.3064 .01613 L
.32696 .01611 L
.33698 .0161 L
.34607 .01609 L
.35494 .01608 L
.36453 .01607 L
.37467 .01607 L
.37962 .01607 L
.38423 .01607 L
.39372 .01606 L
.39875 .01606 L
.40415 .01606 L
.4098 .01606 L
.41516 .01606 L
.4252 .01606 L
.44509 .01606 L
.4635 .01606 L
.48373 .01605 L
.50273 .01605 L
.52088 .01605 L
.54045 .01605 L
.55001 .01605 L
.56047 .01605 L
.57139 .01605 L
.58156 .01605 L
.59207 .01605 L
.60199 .01605 L
.62057 .01605 L
.64056 .01605 L
.65901 .01605 L
Mistroke
.67934 .01605 L
.69838 .01605 L
.71662 .01605 L
.72687 .01605 L
.73623 .01605 L
.74609 .01605 L
.75523 .01605 L
.7605 .01605 L
.76527 .01605 L
.77078 .01605 L
.77596 .01605 L
.78062 .01605 L
.78574 .01605 L
.78831 .01605 L
.79107 .01605 L
.79346 .01605 L
.79606 .01605 L
.80102 .01605 L
.80572 .01605 L
.81453 .01605 L
.82394 .01605 L
.8293 .01605 L
.83432 .01605 L
.84444 .01605 L
.85534 .01605 L
.87539 .01605 L
.89649 .01605 L
.93462 .01605 L
.9752 .01605 L
.97619 .01605 L
Mfstroke
1 .19 0 r
.02381 .01472 m
.02499 .02568 L
.02605 .03423 L
.02729 .04156 L
.02846 .04596 L
.02954 .04831 L
.03053 .04948 L
.03163 .05003 L
.03279 .05009 L
.03395 .0498 L
.0352 .04925 L
.03746 .0479 L
.04262 .04424 L
.0521 .03777 L
.06244 .0321 L
.07373 .02749 L
.08445 .0243 L
.09489 .02203 L
.10458 .02047 L
.11515 .01921 L
.1251 .01835 L
.13404 .01776 L
.14371 .01729 L
.15321 .01694 L
.16365 .01666 L
.17454 .01645 L
.18471 .0163 L
.19516 .0162 L
.20506 .01613 L
.21395 .01608 L
.21894 .01606 L
.22362 .01604 L
.23302 .01602 L
.23801 .01601 L
.24058 .016 L
.2434 .016 L
.24598 .016 L
.24873 .01599 L
.25026 .01599 L
.25165 .01599 L
.25306 .01599 L
.25435 .01599 L
.25556 .01599 L
.25684 .01599 L
.25812 .01599 L
.25884 .01599 L
.25952 .01599 L
.26075 .01599 L
.26188 .01599 L
.26317 .01599 L
Mistroke
.2644 .01599 L
.27402 .01599 L
.27535 .01599 L
.27678 .01599 L
.27805 .01599 L
.27874 .01599 L
.27939 .01599 L
.28059 .01599 L
.28123 .01599 L
.28192 .01599 L
.28314 .01599 L
.28425 .01599 L
.28539 .01599 L
.2866 .01599 L
.28764 .01599 L
.28878 .01599 L
.29132 .01599 L
.2937 .01599 L
.29801 .01599 L
.30265 .01599 L
.32233 .01597 L
.33274 .01596 L
.34384 .01595 L
.35462 .01594 L
.36441 .01593 L
.37424 .01593 L
.38352 .01593 L
.38816 .01592 L
.39326 .01592 L
.39859 .01592 L
.40357 .01592 L
.40823 .01592 L
.41248 .01592 L
.42204 .01592 L
.46185 .01592 L
.50015 .01591 L
.51951 .01591 L
.5409 .01591 L
.55063 .01591 L
.56112 .01591 L
.58013 .01591 L
.58969 .01591 L
.60015 .01591 L
.62124 .01591 L
.64082 .01591 L
.66177 .01591 L
.70323 .01591 L
.72401 .01591 L
.74318 .01591 L
.78162 .01591 L
Mistroke
.82099 .01591 L
.85884 .01591 L
.89915 .01591 L
.93794 .01591 L
.97619 .01591 L
Mfstroke
1 .213 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03479 L
.02721 .04278 L
.02846 .04915 L
.02961 .05308 L
.03068 .05537 L
.0317 .05665 L
.03279 .05733 L
.03395 .05751 L
.0352 .05727 L
.03638 .05678 L
.03746 .05617 L
.04262 .05228 L
.06244 .03751 L
.07277 .03209 L
.08405 .0277 L
.09469 .02468 L
.10458 .0226 L
.11515 .02097 L
.1251 .01983 L
.13404 .01907 L
.14371 .01844 L
.15321 .01798 L
.16365 .01761 L
.17454 .01733 L
.18471 .01714 L
.19516 .01701 L
.20506 .01691 L
.21395 .01685 L
.21897 .01682 L
.22362 .0168 L
.22825 .01679 L
.23325 .01677 L
.23554 .01677 L
.23796 .01676 L
.24023 .01676 L
.24229 .01676 L
.24475 .01675 L
.2461 .01675 L
.24738 .01675 L
.24857 .01675 L
.24966 .01675 L
.25086 .01675 L
.25212 .01675 L
.2534 .01675 L
.25412 .01675 L
.25477 .01675 L
.25725 .01676 L
.26014 .01676 L
Mistroke
.26289 .01676 L
.2725 .01678 L
.27527 .01678 L
.27787 .01678 L
.28021 .01678 L
.28152 .01678 L
.28273 .01679 L
.2838 .01679 L
.28494 .01679 L
.28602 .01679 L
.287 .01679 L
.28816 .01679 L
.28941 .01679 L
.29059 .01678 L
.29169 .01678 L
.29387 .01678 L
.29627 .01678 L
.30113 .01677 L
.31125 .01676 L
.32052 .01674 L
.34139 .0167 L
.35056 .01668 L
.36035 .01667 L
.37109 .01666 L
.38106 .01665 L
.38641 .01665 L
.39133 .01664 L
.39663 .01664 L
.40245 .01664 L
.40752 .01664 L
.41225 .01664 L
.42261 .01664 L
.46149 .01663 L
.48128 .01663 L
.50282 .01662 L
.51284 .01662 L
.52349 .01662 L
.54263 .01662 L
.55199 .01662 L
.56208 .01662 L
.57154 .01662 L
.58035 .01662 L
.58991 .01662 L
.60037 .01661 L
.61056 .01661 L
.62146 .01661 L
.64278 .01661 L
.66292 .01661 L
.70136 .01661 L
.72121 .01661 L
Mistroke
.74224 .01661 L
.7801 .01661 L
.82041 .01661 L
.8592 .01661 L
.90044 .01661 L
.94017 .01661 L
.97619 .01661 L
Mfstroke
1 .237 0 r
.02381 .01472 m
.02499 .02009 L
.02605 .02113 L
.02729 .0215 L
.02846 .02159 L
.02954 .02157 L
.03053 .02151 L
.03163 .02142 L
.03279 .0213 L
.04262 .02007 L
.05217 .01898 L
.06244 .01806 L
.0728 .01735 L
.0825 .01685 L
.09403 .01641 L
.10458 .01611 L
.11442 .01591 L
.12357 .01577 L
.1336 .01565 L
.14429 .01556 L
.15457 .0155 L
.1657 .01545 L
.17621 .01541 L
.18587 .01539 L
.19561 .01537 L
.2047 .01536 L
.21467 .01535 L
.22026 .01535 L
.22536 .01535 L
.23016 .01535 L
.2328 .01534 L
.23527 .01534 L
.23755 .01534 L
.23963 .01534 L
.24076 .01534 L
.24195 .01534 L
.24314 .01534 L
.24444 .01534 L
.24512 .01534 L
.24584 .01534 L
.24653 .01534 L
.24717 .01534 L
.24837 .01534 L
.24964 .01534 L
.2503 .01534 L
.25101 .01534 L
.25229 .01534 L
.2552 .01534 L
.25788 .01534 L
.26043 .01535 L
Mistroke
.2652 .01535 L
.27482 .01535 L
.27758 .01535 L
.28019 .01535 L
.28252 .01535 L
.28384 .01535 L
.28505 .01535 L
.28612 .01535 L
.28726 .01535 L
.28834 .01535 L
.28932 .01535 L
.29047 .01535 L
.29173 .01535 L
.29291 .01535 L
.294 .01535 L
.29859 .01535 L
.30345 .01535 L
.34125 .01534 L
.3507 .01533 L
.36064 .01533 L
.37153 .01533 L
.38151 .01533 L
.39108 .01533 L
.39643 .01533 L
.40129 .01533 L
.40583 .01533 L
.41075 .01533 L
.41967 .01533 L
.42909 .01533 L
.43919 .01533 L
.45028 .01533 L
.46064 .01532 L
.50009 .01532 L
.51025 .01532 L
.52131 .01532 L
.53087 .01532 L
.54142 .01532 L
.55161 .01532 L
.56117 .01532 L
.57127 .01532 L
.58217 .01532 L
.59173 .01532 L
.60219 .01532 L
.61311 .01532 L
.62328 .01532 L
.64371 .01532 L
.66229 .01532 L
.68145 .01532 L
.69227 .01532 L
.70224 .01532 L
Mistroke
.71192 .01532 L
.72098 .01532 L
.72618 .01532 L
.73092 .01532 L
.73641 .01532 L
.73909 .01532 L
.74161 .01532 L
.74403 .01532 L
.74665 .01532 L
.74902 .01532 L
.75121 .01532 L
.75358 .01532 L
.75493 .01532 L
.75618 .01532 L
.75686 .01532 L
.75751 .01532 L
.75872 .01532 L
.76002 .01532 L
.76075 .01532 L
.76143 .01532 L
.76249 .01532 L
.76362 .01532 L
.76568 .01532 L
.76812 .01532 L
.77035 .01532 L
.77983 .01532 L
.78976 .01532 L
.79522 .01532 L
.80037 .01532 L
.80517 .01532 L
.8077 .01532 L
.81038 .01532 L
.81263 .01532 L
.81391 .01532 L
.81511 .01532 L
.81621 .01532 L
.81721 .01532 L
.81837 .01532 L
.81947 .01532 L
.82071 .01532 L
.82188 .01532 L
.82293 .01532 L
.82406 .01532 L
.8266 .01532 L
.82894 .01532 L
.83321 .01532 L
.83772 .01532 L
.84263 .01532 L
.8472 .01532 L
.8576 .01532 L
Mistroke
.87801 .01532 L
.89658 .01532 L
.9365 .01532 L
.9749 .01532 L
.97619 .01532 L
Mfstroke
1 .261 0 r
.02381 .01472 m
.02605 .03538 L
.02729 .04522 L
.02846 .05315 L
.02954 .05923 L
.03072 .06442 L
.0318 .06797 L
.03279 .07037 L
.03396 .07233 L
.03506 .07344 L
.03626 .07402 L
.03756 .0741 L
.03821 .07396 L
.03891 .07371 L
.0402 .07302 L
.04145 .07213 L
.04262 .07117 L
.06244 .051 L
.07295 .04252 L
.08284 .03634 L
.09424 .03101 L
.10458 .02745 L
.11434 .02494 L
.12466 .02296 L
.13346 .02169 L
.14313 .02062 L
.15334 .01979 L
.16264 .01922 L
.17338 .01873 L
.18355 .0184 L
.19321 .01817 L
.20346 .01799 L
.21222 .01788 L
.22188 .01779 L
.2268 .01776 L
.23198 .01773 L
.2364 .01772 L
.23888 .01771 L
.24123 .0177 L
.24254 .0177 L
.24397 .0177 L
.24515 .0177 L
.24646 .01769 L
.24787 .01769 L
.24864 .01769 L
.24936 .01769 L
.25065 .01769 L
.25137 .01769 L
.25204 .01769 L
.25332 .01769 L
Mistroke
.2545 .01769 L
.25581 .0177 L
.25719 .0177 L
.25976 .0177 L
.26209 .0177 L
.27147 .01773 L
.2766 .01774 L
.2791 .01774 L
.28137 .01775 L
.28266 .01775 L
.28387 .01775 L
.28516 .01775 L
.28588 .01775 L
.28655 .01775 L
.28786 .01775 L
.28861 .01775 L
.28931 .01775 L
.29004 .01775 L
.29071 .01775 L
.29223 .01775 L
.29455 .01775 L
.29709 .01774 L
.30221 .01773 L
.31251 .01769 L
.32186 .01766 L
.34282 .01759 L
.35216 .01756 L
.36204 .01754 L
.37288 .01752 L
.37809 .01751 L
.38285 .01751 L
.39232 .0175 L
.39753 .0175 L
.40247 .01749 L
.41124 .01749 L
.42079 .01749 L
.46154 .01748 L
.48177 .01747 L
.50078 .01746 L
.51914 .01746 L
.5385 .01745 L
.54812 .01745 L
.55865 .01745 L
.57715 .01745 L
.58741 .01745 L
.59674 .01745 L
.61768 .01745 L
.63684 .01745 L
.65763 .01745 L
.67709 .01745 L
Mistroke
.69852 .01745 L
.70831 .01745 L
.71885 .01744 L
.72872 .01744 L
.73789 .01744 L
.748 .01744 L
.75334 .01744 L
.75904 .01744 L
.76447 .01744 L
.76958 .01744 L
.77417 .01744 L
.77913 .01744 L
.78151 .01744 L
.78405 .01744 L
.78625 .01744 L
.78865 .01744 L
.79145 .01744 L
.79274 .01744 L
.79411 .01744 L
.79534 .01744 L
.79669 .01744 L
.79793 .01744 L
.79908 .01744 L
.80032 .01744 L
.80101 .01744 L
.80166 .01744 L
.80297 .01744 L
.80371 .01744 L
.80438 .01744 L
.80557 .01744 L
.80687 .01744 L
.80923 .01744 L
.81491 .01744 L
.82015 .01744 L
.82921 .01744 L
.83182 .01744 L
.83429 .01744 L
.83654 .01744 L
.83893 .01744 L
.84032 .01744 L
.84158 .01744 L
.84285 .01744 L
.84404 .01744 L
.84472 .01744 L
.84543 .01744 L
.84671 .01744 L
.84743 .01744 L
.84809 .01744 L
.84882 .01744 L
.8496 .01744 L
Mistroke
.85089 .01744 L
.85228 .01744 L
.85482 .01744 L
.85729 .01744 L
.85958 .01744 L
.86924 .01744 L
.87829 .01744 L
.89892 .01744 L
.93767 .01744 L
.97619 .01744 L
Mfstroke
1 .285 0 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01954 L
.05285 .01837 L
.06244 .01753 L
.07218 .01688 L
.0829 .01634 L
.09334 .01597 L
.10458 .01568 L
.11468 .01549 L
.12571 .01534 L
.13613 .01523 L
.1458 .01516 L
.15637 .01511 L
.16633 .01507 L
.17526 .01504 L
.18493 .01502 L
.19444 .01501 L
.20487 .015 L
.21013 .01499 L
.21577 .01499 L
.22594 .01498 L
.23122 .01498 L
.23611 .01498 L
.24137 .01497 L
.24718 .01497 L
.25221 .01497 L
.25693 .01497 L
.26192 .01497 L
.2673 .01497 L
.30844 .01497 L
.32896 .01497 L
.33897 .01497 L
.34806 .01496 L
.3569 .01496 L
.36649 .01496 L
.37175 .01496 L
.37661 .01496 L
.38617 .01496 L
.39084 .01496 L
.39586 .01496 L
.4006 .01496 L
.40493 .01496 L
.41 .01496 L
Mistroke
.41552 .01496 L
.42557 .01496 L
.43592 .01496 L
.44529 .01496 L
.46627 .01496 L
.48718 .01496 L
.49634 .01496 L
.50639 .01496 L
.51546 .01496 L
.52517 .01496 L
.53543 .01496 L
.54499 .01496 L
.55519 .01496 L
.56095 .01496 L
.56627 .01496 L
.57092 .01496 L
.57604 .01496 L
.57862 .01496 L
.58139 .01496 L
.58382 .01496 L
.58641 .01496 L
.58775 .01496 L
.58901 .01496 L
.59025 .01496 L
.59138 .01496 L
.59246 .01496 L
.5936 .01496 L
.59474 .01496 L
.596 .01496 L
.5967 .01496 L
.59737 .01496 L
.59862 .01496 L
.59931 .01496 L
.59996 .01496 L
.60142 .01496 L
.60259 .01496 L
.60388 .01496 L
.60649 .01496 L
.61737 .01496 L
.6276 .01496 L
.63741 .01496 L
.64235 .01496 L
.64515 .01496 L
.64776 .01496 L
.65016 .01496 L
.65135 .01496 L
.65244 .01496 L
.65341 .01496 L
.65448 .01496 L
.65556 .01496 L
Mistroke
.6567 .01496 L
.65794 .01496 L
.65907 .01496 L
.66039 .01496 L
.66163 .01496 L
.66278 .01496 L
.66384 .01496 L
.66625 .01496 L
.67134 .01496 L
.67683 .01496 L
.68679 .01496 L
.69144 .01496 L
.69642 .01496 L
.70112 .01496 L
.70335 .01496 L
.7054 .01496 L
.70652 .01496 L
.70774 .01496 L
.70898 .01496 L
.71029 .01496 L
.71144 .01496 L
.71268 .01496 L
.71385 .01496 L
.71492 .01496 L
.71618 .01496 L
.71735 .01496 L
.71863 .01496 L
.72 .01496 L
.72281 .01496 L
.72536 .01496 L
.73056 .01496 L
.7362 .01496 L
.74643 .01496 L
.76632 .01496 L
.78736 .01496 L
.82527 .01496 L
.86563 .01496 L
.90448 .01496 L
.94577 .01496 L
.97619 .01496 L
Mfstroke
1 .308 0 r
.02381 .01472 m
.02846 .05694 L
.03068 .07364 L
.03279 .0861 L
.03398 .09157 L
.03527 .0962 L
.03645 .0993 L
.03754 .1013 L
.03871 .10267 L
.04 .10337 L
.04065 .10345 L
.04135 .10336 L
.04262 .10281 L
.04393 .10182 L
.04516 .10059 L
.04793 .0971 L
.05297 .08947 L
.06244 .07487 L
.07295 .06111 L
.08284 .05091 L
.09424 .04202 L
.10458 .03606 L
.11434 .03184 L
.12466 .0285 L
.13346 .02634 L
.14313 .02454 L
.15334 .02312 L
.16264 .02215 L
.17338 .02133 L
.18355 .02076 L
.19321 .02037 L
.20346 .02007 L
.21222 .01988 L
.2172 .0198 L
.22188 .01974 L
.22698 .01969 L
.23172 .01965 L
.23431 .01963 L
.23666 .01962 L
.23927 .01961 L
.24071 .0196 L
.24207 .0196 L
.24314 .0196 L
.24431 .0196 L
.24554 .0196 L
.24669 .0196 L
.24776 .0196 L
.24874 .0196 L
.24987 .0196 L
.25095 .0196 L
Mistroke
.2521 .0196 L
.25334 .01961 L
.25555 .01961 L
.25819 .01963 L
.26057 .01964 L
.26996 .0197 L
.27508 .01974 L
.27986 .01977 L
.28236 .01978 L
.28364 .01979 L
.28504 .01979 L
.28583 .01979 L
.28656 .01979 L
.28726 .01979 L
.28801 .01979 L
.2893 .01979 L
.29003 .01979 L
.29071 .01979 L
.29194 .01979 L
.29322 .01979 L
.29432 .01979 L
.29552 .01979 L
.2982 .01978 L
.30069 .01977 L
.30576 .01974 L
.31124 .0197 L
.32119 .01962 L
.33979 .01947 L
.3597 .01936 L
.36974 .01931 L
.37539 .0193 L
.38076 .01928 L
.38564 .01927 L
.39095 .01926 L
.39536 .01925 L
.40024 .01925 L
.40551 .01924 L
.4111 .01924 L
.41628 .01923 L
.42115 .01923 L
.45981 .01922 L
.47982 .01921 L
.50091 .01919 L
.53899 .01917 L
.55858 .01916 L
.57952 .01915 L
.58974 .01915 L
.60084 .01915 L
.62098 .01914 L
.64084 .01914 L
Mistroke
.66187 .01914 L
.69973 .01914 L
.71915 .01913 L
.74003 .01913 L
.75976 .01913 L
.78128 .01913 L
.82101 .01913 L
.86167 .01913 L
.90082 .01913 L
.94242 .01913 L
.97619 .01913 L
Mfstroke
1 .332 0 r
.02381 .01472 m
.02846 .05681 L
.03068 .07316 L
.03279 .08505 L
.03398 .09011 L
.03527 .09425 L
.03645 .09691 L
.03754 .09854 L
.03871 .09955 L
.04 .09991 L
.04065 .09985 L
.04135 .09962 L
.04262 .09888 L
.04393 .09775 L
.04516 .09644 L
.04793 .09287 L
.05297 .08541 L
.06244 .07151 L
.07295 .05857 L
.08284 .04903 L
.09424 .04075 L
.10458 .03521 L
.11434 .03128 L
.12466 .02818 L
.13346 .02618 L
.14313 .02451 L
.15334 .0232 L
.16264 .02231 L
.17338 .02154 L
.18355 .02102 L
.19321 .02066 L
.20346 .02039 L
.21222 .02022 L
.2172 .02015 L
.22188 .0201 L
.22658 .02005 L
.23172 .02002 L
.23431 .02001 L
.23573 .02 L
.23708 .02 L
.23833 .01999 L
.23899 .01999 L
.23969 .01999 L
.24093 .01999 L
.24207 .01999 L
.24321 .01999 L
.24426 .01999 L
.24547 .01999 L
.24662 .01999 L
.24768 .02 L
Mistroke
.24866 .02 L
.25088 .02001 L
.25334 .02002 L
.25557 .02003 L
.26057 .02007 L
.26996 .02016 L
.27508 .02021 L
.27986 .02025 L
.28236 .02026 L
.28364 .02027 L
.28504 .02027 L
.28583 .02028 L
.28656 .02028 L
.28725 .02028 L
.28801 .02028 L
.28932 .02028 L
.29004 .02028 L
.29071 .02028 L
.29194 .02028 L
.29322 .02028 L
.29432 .02028 L
.29552 .02028 L
.2982 .02027 L
.30069 .02025 L
.30576 .02022 L
.31124 .02018 L
.32119 .02009 L
.33979 .01992 L
.3597 .01979 L
.36974 .01974 L
.37539 .01972 L
.38076 .0197 L
.38564 .01968 L
.39095 .01967 L
.40024 .01965 L
.40551 .01965 L
.4111 .01964 L
.41588 .01964 L
.42115 .01964 L
.46132 .01962 L
.49998 .01959 L
.54108 .01957 L
.56159 .01956 L
.58068 .01955 L
.59908 .01955 L
.60938 .01955 L
.61875 .01955 L
.63791 .01954 L
.64873 .01954 L
.6587 .01954 L
Mistroke
.69807 .01954 L
.73593 .01954 L
.77624 .01954 L
.81503 .01954 L
.85627 .01953 L
.896 .01953 L
.93421 .01953 L
.97488 .01953 L
.97619 .01953 L
Mfstroke
1 .356 0 r
.02381 .01472 m
.02499 .02009 L
.02605 .02112 L
.02729 .02149 L
.02846 .02158 L
.02954 .02156 L
.03053 .0215 L
.03163 .02141 L
.03279 .02128 L
.04262 .02003 L
.05217 .01894 L
.06244 .01802 L
.0728 .01731 L
.0825 .01681 L
.09403 .01637 L
.10458 .01608 L
.11442 .01588 L
.12357 .01574 L
.1336 .01562 L
.14429 .01553 L
.15457 .01547 L
.1657 .01542 L
.17621 .01538 L
.18587 .01536 L
.19561 .01534 L
.2047 .01533 L
.21467 .01532 L
.22026 .01532 L
.22536 .01532 L
.23016 .01532 L
.2328 .01531 L
.23527 .01531 L
.23755 .01531 L
.23963 .01531 L
.24195 .01531 L
.24316 .01531 L
.24444 .01531 L
.24574 .01531 L
.24693 .01531 L
.24758 .01531 L
.24829 .01531 L
.24958 .01531 L
.25079 .01531 L
.25207 .01531 L
.25436 .01531 L
.25703 .01531 L
.25952 .01531 L
.2652 .01532 L
.27018 .01532 L
.27561 .01532 L
Mistroke
.27809 .01532 L
.28074 .01532 L
.28323 .01532 L
.28549 .01532 L
.28665 .01532 L
.28788 .01532 L
.28893 .01532 L
.29008 .01532 L
.29132 .01532 L
.29202 .01532 L
.29265 .01532 L
.29388 .01532 L
.29504 .01532 L
.29613 .01532 L
.29728 .01532 L
.29935 .01532 L
.30403 .01532 L
.31342 .01532 L
.32354 .01531 L
.34183 .01531 L
.36191 .0153 L
.372 .0153 L
.37767 .0153 L
.38302 .0153 L
.38797 .0153 L
.39332 .0153 L
.39778 .0153 L
.40267 .0153 L
.40798 .0153 L
.41088 .0153 L
.41359 .0153 L
.41612 .0153 L
.41843 .0153 L
.41971 .0153 L
.4211 .0153 L
.42242 .0153 L
.42364 .0153 L
.42477 .0153 L
.42596 .0153 L
.42716 .0153 L
.42847 .0153 L
.42961 .0153 L
.43083 .0153 L
.43198 .0153 L
.43302 .0153 L
.43558 .0153 L
.43835 .0153 L
.44095 .0153 L
.44339 .0153 L
.4446 .0153 L
Mistroke
.44591 .0153 L
.44665 .0153 L
.44736 .0153 L
.448 .0153 L
.44869 .0153 L
.44943 .0153 L
.4501 .0153 L
.45087 .0153 L
.4516 .0153 L
.4529 .0153 L
.45431 .0153 L
.45553 .0153 L
.45686 .0153 L
.45956 .0153 L
.46206 .0153 L
.46439 .0153 L
.4694 .0153 L
.47485 .0153 L
.48475 .0153 L
.50331 .0153 L
.52271 .01529 L
.54412 .01529 L
.55387 .01529 L
.56438 .01529 L
.5834 .01529 L
.59298 .01529 L
.60346 .01529 L
.62456 .01529 L
.66514 .01529 L
.70421 .01529 L
.72414 .01529 L
.74573 .01529 L
.78573 .01529 L
.80562 .01529 L
.82667 .01529 L
.86457 .01529 L
.90493 .01529 L
.94378 .01529 L
.97619 .01529 L
Mfstroke
1 .379 0 r
.02381 .01472 m
.02499 .01999 L
.02605 .02089 L
.02729 .02115 L
.02846 .02116 L
.02954 .02109 L
.03053 .02099 L
.03279 .0207 L
.04262 .01934 L
.05285 .01818 L
.06244 .01735 L
.07218 .01672 L
.0829 .0162 L
.09334 .01584 L
.10458 .01556 L
.11468 .01538 L
.12571 .01524 L
.13613 .01514 L
.1458 .01507 L
.15637 .01502 L
.16633 .01498 L
.17526 .01496 L
.18493 .01494 L
.19444 .01493 L
.20487 .01492 L
.21577 .01491 L
.22594 .0149 L
.23094 .0149 L
.23639 .0149 L
.24119 .0149 L
.24629 .01489 L
.25087 .01489 L
.25593 .01489 L
.26485 .01489 L
.27494 .01489 L
.28419 .01489 L
.30505 .01489 L
.32558 .01489 L
.33558 .01489 L
.34467 .01489 L
.35351 .01489 L
.3631 .01489 L
.37322 .01489 L
.37816 .01489 L
.38278 .01489 L
.38773 .01489 L
.39225 .01489 L
.39727 .01489 L
.40266 .01489 L
.40782 .01489 L
Mistroke
.41345 .01489 L
.4237 .01489 L
.42903 .01489 L
.43404 .01489 L
.44341 .01489 L
.4644 .01489 L
.48281 .01489 L
.49326 .01489 L
.503 .01489 L
.51346 .01489 L
.52298 .01489 L
.53316 .01489 L
.53876 .01489 L
.54406 .01489 L
.54905 .01489 L
.55374 .01489 L
.55862 .01489 L
.56125 .01489 L
.56401 .01489 L
.56622 .01489 L
.56864 .01489 L
.57084 .01489 L
.57288 .01489 L
.57413 .01489 L
.57531 .01489 L
.57636 .01489 L
.57751 .01489 L
.57875 .01489 L
.58007 .01489 L
.5812 .01489 L
.58244 .01489 L
.58374 .01489 L
.58494 .01489 L
.58767 .01489 L
.59007 .01489 L
.59263 .01489 L
.60192 .01489 L
.62283 .01489 L
.63218 .01489 L
.64228 .01489 L
.6518 .01489 L
.66055 .01489 L
.66528 .01489 L
.67034 .01489 L
.67945 .01489 L
.70014 .01489 L
.71037 .01489 L
.72146 .01489 L
.73194 .01489 L
.74161 .01489 L
Mistroke
.78098 .01489 L
.81883 .01489 L
.85914 .01489 L
.89793 .01489 L
.93918 .01489 L
.97619 .01489 L
Mfstroke
1 .403 0 r
.02381 .01472 m
.02846 .05737 L
.03279 .08997 L
.03527 .10402 L
.03754 .11348 L
.03879 .11739 L
.04015 .12062 L
.04143 .12279 L
.04262 .12411 L
.04376 .12483 L
.04498 .12509 L
.04614 .1249 L
.0472 .12442 L
.04843 .12353 L
.04978 .12223 L
.05224 .1192 L
.06244 .10251 L
.08284 .07134 L
.09424 .05878 L
.10458 .0501 L
.11463 .04366 L
.12551 .03841 L
.13578 .03473 L
.14523 .03216 L
.15496 .03016 L
.16405 .02874 L
.17402 .02756 L
.18471 .02665 L
.19489 .02602 L
.20063 .02576 L
.20595 .02555 L
.21098 .0254 L
.21571 .02528 L
.22064 .02519 L
.22325 .02515 L
.22607 .02512 L
.22847 .0251 L
.22979 .02509 L
.23103 .02508 L
.23219 .02508 L
.23345 .02507 L
.23459 .02507 L
.23564 .02507 L
.2369 .02507 L
.23807 .02507 L
.23935 .02508 L
.24007 .02508 L
.24073 .02508 L
.24205 .02509 L
.24349 .0251 L
Mistroke
.24611 .02513 L
.2489 .02517 L
.25142 .02522 L
.25706 .02536 L
.26229 .02553 L
.26721 .02571 L
.277 .0261 L
.28193 .02625 L
.28473 .02632 L
.28597 .02634 L
.28733 .02636 L
.28858 .02638 L
.28973 .02639 L
.29083 .0264 L
.292 .02641 L
.29305 .02641 L
.29403 .02641 L
.2951 .02641 L
.29626 .02641 L
.29742 .0264 L
.29869 .02639 L
.30125 .02636 L
.30362 .02633 L
.30582 .02629 L
.31637 .02604 L
.32631 .02576 L
.34491 .02526 L
.35466 .02504 L
.36497 .02486 L
.37377 .02473 L
.38343 .02462 L
.38866 .02458 L
.39362 .02455 L
.39813 .02452 L
.40292 .0245 L
.40539 .02449 L
.40812 .02448 L
.41062 .02448 L
.41293 .02448 L
.41563 .02447 L
.41705 .02447 L
.41777 .02447 L
.41855 .02447 L
.41985 .02447 L
.42107 .02447 L
.42181 .02447 L
.42251 .02447 L
.42382 .02447 L
.42497 .02447 L
.42621 .02447 L
Mistroke
.42738 .02447 L
.42844 .02447 L
.43105 .02447 L
.43353 .02448 L
.43845 .02448 L
.44381 .02449 L
.45331 .02452 L
.46226 .02453 L
.46722 .02454 L
.46983 .02455 L
.47259 .02455 L
.47491 .02455 L
.47623 .02455 L
.47746 .02455 L
.4786 .02455 L
.47963 .02455 L
.48082 .02456 L
.48195 .02456 L
.48315 .02455 L
.48384 .02455 L
.48448 .02455 L
.48577 .02455 L
.48717 .02455 L
.48969 .02455 L
.492 .02455 L
.49732 .02454 L
.50292 .02453 L
.51248 .0245 L
.52268 .02447 L
.54105 .02441 L
.56098 .02434 L
.58257 .02429 L
.59268 .02427 L
.60339 .02425 L
.62257 .02422 L
.64216 .02421 L
.66048 .02419 L
.69932 .02417 L
.74062 .02416 L
.7804 .02414 L
.81867 .02413 L
.85938 .02412 L
.89858 .02411 L
.94024 .0241 L
.97619 .0241 L
Mfstroke
1 .427 0 r
.02381 .01472 m
.02605 .03537 L
.02729 .04513 L
.02846 .05291 L
.02954 .05878 L
.03072 .06366 L
.0318 .0669 L
.03279 .06902 L
.03396 .07066 L
.03506 .07151 L
.03626 .07186 L
.03756 .07174 L
.03821 .07153 L
.03891 .07121 L
.0402 .07043 L
.04262 .0685 L
.06244 .04928 L
.07302 .04133 L
.08429 .03493 L
.09493 .03046 L
.10458 .02742 L
.1146 .02505 L
.12383 .0234 L
.13395 .02204 L
.14465 .02098 L
.15412 .02029 L
.16428 .01974 L
.17387 .01936 L
.18262 .01909 L
.19253 .01887 L
.2017 .01872 L
.21177 .01861 L
.21685 .01856 L
.22246 .01853 L
.22738 .0185 L
.22985 .01849 L
.23256 .01848 L
.23487 .01848 L
.23615 .01848 L
.23735 .01847 L
.23847 .01847 L
.23969 .01847 L
.24079 .01847 L
.24181 .01847 L
.24301 .01847 L
.2443 .01847 L
.24552 .01847 L
.24663 .01847 L
.24794 .01848 L
.24936 .01848 L
Mistroke
.25194 .01848 L
.25464 .01849 L
.25751 .01851 L
.26267 .01853 L
.27298 .01859 L
.2758 .0186 L
.27878 .01862 L
.28133 .01863 L
.28276 .01863 L
.28412 .01863 L
.28538 .01864 L
.2861 .01864 L
.28676 .01864 L
.28793 .01864 L
.28916 .01864 L
.2898 .01864 L
.29049 .01864 L
.29173 .01864 L
.29245 .01864 L
.29321 .01864 L
.29456 .01863 L
.29698 .01863 L
.29922 .01862 L
.3043 .0186 L
.3434 .0184 L
.35367 .01836 L
.36478 .01833 L
.37528 .0183 L
.38495 .01828 L
.38964 .01828 L
.39467 .01827 L
.39902 .01827 L
.40375 .01826 L
.40929 .01826 L
.41455 .01826 L
.4244 .01825 L
.46515 .01823 L
.48538 .01822 L
.50439 .01821 L
.52253 .01821 L
.53274 .0182 L
.54211 .0182 L
.55124 .0182 L
.56101 .0182 L
.57172 .0182 L
.5817 .0182 L
.59192 .0182 L
.59731 .0182 L
.60302 .0182 L
.60801 .0182 L
Mistroke
.6135 .0182 L
.61812 .0182 L
.62316 .01819 L
.62837 .01819 L
.63331 .01819 L
.63564 .01819 L
.63812 .01819 L
.64045 .01819 L
.64259 .01819 L
.6453 .01819 L
.64672 .01819 L
.64823 .01819 L
.64954 .01819 L
.65076 .01819 L
.65146 .01819 L
.6521 .01819 L
.65284 .01819 L
.65354 .01819 L
.65474 .01819 L
.65601 .01819 L
.6571 .01819 L
.6583 .01819 L
.66097 .01819 L
.66347 .01819 L
.66817 .01819 L
.67331 .01819 L
.68367 .01819 L
.70218 .01819 L
.72344 .0182 L
.74276 .0182 L
.75241 .0182 L
.76286 .0182 L
.76765 .0182 L
.77273 .0182 L
.7774 .0182 L
.78182 .0182 L
.78419 .0182 L
.78676 .0182 L
.78913 .0182 L
.79127 .0182 L
.7925 .0182 L
.79382 .0182 L
.79455 .0182 L
.79522 .0182 L
.79653 .0182 L
.79767 .0182 L
.79891 .0182 L
.80021 .0182 L
.80141 .0182 L
.80255 .0182 L
Mistroke
.80379 .0182 L
.80605 .0182 L
.80824 .0182 L
.81026 .0182 L
.81486 .0182 L
.81973 .0182 L
.82914 .0182 L
.83926 .0182 L
.85755 .0182 L
.87868 .0182 L
.89877 .01819 L
.93695 .01819 L
.97619 .01819 L
Mfstroke
1 .451 0 r
.02381 .01472 m
.02499 .02012 L
.02605 .02121 L
.02729 .02162 L
.02846 .02174 L
.02954 .02174 L
.03053 .0217 L
.03163 .02162 L
.03279 .02151 L
.04262 .02033 L
.05217 .01926 L
.06244 .01833 L
.0728 .01761 L
.0825 .0171 L
.09403 .01665 L
.10458 .01635 L
.11442 .01614 L
.12357 .01599 L
.1336 .01587 L
.14429 .01577 L
.15457 .01571 L
.1657 .01565 L
.17621 .01562 L
.18587 .0156 L
.19561 .01558 L
.2047 .01557 L
.20991 .01556 L
.21467 .01556 L
.22016 .01555 L
.22284 .01555 L
.22536 .01555 L
.22775 .01555 L
.22995 .01555 L
.23238 .01555 L
.23366 .01555 L
.23501 .01555 L
.23624 .01555 L
.23755 .01555 L
.23879 .01555 L
.23991 .01555 L
.24123 .01555 L
.24198 .01555 L
.24267 .01555 L
.24393 .01555 L
.24527 .01555 L
.24745 .01555 L
.2498 .01555 L
.25404 .01555 L
.25908 .01555 L
.26369 .01556 L
Mistroke
.2729 .01556 L
.27796 .01557 L
.28043 .01557 L
.28271 .01557 L
.28543 .01557 L
.28685 .01557 L
.28758 .01557 L
.28836 .01557 L
.28962 .01557 L
.2908 .01557 L
.29152 .01557 L
.2922 .01557 L
.29347 .01557 L
.29468 .01557 L
.29596 .01557 L
.29705 .01557 L
.29825 .01557 L
.30093 .01557 L
.30345 .01557 L
.31331 .01556 L
.32367 .01556 L
.34219 .01555 L
.35176 .01554 L
.36197 .01554 L
.37154 .01554 L
.38035 .01553 L
.39062 .01553 L
.39602 .01553 L
.40174 .01553 L
.4067 .01553 L
.41134 .01553 L
.41644 .01553 L
.4219 .01553 L
.44169 .01553 L
.45287 .01553 L
.46323 .01553 L
.48214 .01553 L
.50304 .01552 L
.52327 .01552 L
.54227 .01552 L
.55209 .01552 L
.56243 .01552 L
.57126 .01552 L
.58093 .01552 L
.59119 .01552 L
.60052 .01552 L
.61128 .01552 L
.62146 .01552 L
.63116 .01552 L
.64145 .01552 L
Mistroke
.65023 .01552 L
.65989 .01552 L
.6651 .01552 L
.67004 .01552 L
.67453 .01552 L
.67932 .01552 L
.68203 .01552 L
.6845 .01552 L
.687 .01552 L
.6893 .01552 L
.692 .01552 L
.69342 .01552 L
.69492 .01552 L
.69622 .01552 L
.69744 .01552 L
.69813 .01552 L
.69877 .01552 L
.6995 .01552 L
.7002 .01552 L
.70134 .01552 L
.70257 .01552 L
.70373 .01552 L
.70479 .01552 L
.70726 .01552 L
.70986 .01552 L
.71477 .01552 L
.72012 .01552 L
.72967 .01552 L
.73855 .01552 L
.77761 .01552 L
.81913 .01552 L
.85913 .01552 L
.89762 .01552 L
.93856 .01552 L
.97619 .01552 L
Mfstroke
1 .474 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .02141 L
.03053 .02134 L
.03163 .02123 L
.03279 .0211 L
.04262 .01983 L
.05217 .01875 L
.06244 .01785 L
.0728 .01717 L
.0825 .01669 L
.09403 .01627 L
.10458 .016 L
.11442 .01581 L
.12357 .01568 L
.1336 .01557 L
.14429 .01548 L
.15457 .01543 L
.1657 .01538 L
.17621 .01535 L
.18587 .01533 L
.19561 .01531 L
.2047 .0153 L
.21467 .01529 L
.22026 .01529 L
.22536 .01529 L
.23016 .01529 L
.2328 .01528 L
.23527 .01528 L
.23755 .01528 L
.23963 .01528 L
.24074 .01528 L
.24195 .01528 L
.24316 .01528 L
.24444 .01528 L
.24512 .01528 L
.24584 .01528 L
.24653 .01528 L
.24717 .01528 L
.24837 .01528 L
.24964 .01528 L
.2503 .01528 L
.25101 .01528 L
.25229 .01528 L
.2552 .01528 L
.25788 .01528 L
.26043 .01528 L
Mistroke
.2652 .01529 L
.27482 .01529 L
.27758 .01529 L
.28019 .01529 L
.28255 .01529 L
.28384 .01529 L
.28505 .01529 L
.2862 .01529 L
.28725 .01529 L
.28841 .01529 L
.28966 .01529 L
.2907 .01529 L
.29183 .01529 L
.2929 .01529 L
.29389 .01529 L
.29503 .01529 L
.2961 .01529 L
.29853 .01529 L
.3009 .01529 L
.30345 .01529 L
.31304 .01529 L
.32353 .01528 L
.34464 .01528 L
.36429 .01527 L
.37528 .01527 L
.38525 .01527 L
.39012 .01527 L
.39526 .01527 L
.39971 .01527 L
.40448 .01527 L
.4096 .01527 L
.41439 .01527 L
.42009 .01527 L
.42529 .01527 L
.43531 .01527 L
.4408 .01527 L
.44596 .01527 L
.45505 .01527 L
.45989 .01527 L
.4651 .01527 L
.5034 .01527 L
.52302 .01527 L
.53341 .01527 L
.54451 .01526 L
.55524 .01526 L
.56501 .01526 L
.5841 .01526 L
.59406 .01526 L
.60326 .01526 L
.62405 .01526 L
Mistroke
.64279 .01526 L
.66342 .01526 L
.68447 .01526 L
.70373 .01526 L
.72385 .01526 L
.74252 .01526 L
.76152 .01526 L
.78225 .01526 L
.80278 .01526 L
.8214 .01526 L
.84066 .01526 L
.86148 .01526 L
.88144 .01526 L
.89148 .01526 L
.90251 .01526 L
.90775 .01526 L
.91272 .01526 L
.91724 .01526 L
.92203 .01526 L
.92451 .01526 L
.92724 .01526 L
.92972 .01526 L
.93205 .01526 L
.93339 .01526 L
.93411 .01526 L
.93479 .01526 L
.93599 .01526 L
.9373 .01526 L
.93804 .01526 L
.93873 .01526 L
.94003 .01526 L
.94076 .01526 L
.94143 .01526 L
.94295 .01526 L
.94401 .01526 L
.94501 .01526 L
.9469 .01526 L
.95113 .01526 L
.95479 .01526 L
.95878 .01526 L
.96782 .01526 L
.97619 .01526 L
Mfstroke
1 .498 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02133 L
.03163 .02122 L
.03279 .02108 L
.04262 .01979 L
.05217 .01869 L
.06244 .01777 L
.0728 .01707 L
.0825 .01658 L
.09403 .01615 L
.10458 .01587 L
.11442 .01568 L
.12357 .01554 L
.1336 .01543 L
.14429 .01534 L
.15457 .01528 L
.1657 .01524 L
.17621 .0152 L
.18587 .01518 L
.19561 .01517 L
.2047 .01516 L
.21467 .01515 L
.22026 .01514 L
.22536 .01514 L
.23016 .01514 L
.23527 .01514 L
.23963 .01514 L
.24444 .01513 L
.24713 .01513 L
.2496 .01513 L
.251 .01513 L
.2523 .01513 L
.25366 .01513 L
.25438 .01513 L
.25515 .01513 L
.25646 .01513 L
.2577 .01513 L
.2589 .01513 L
.26001 .01513 L
.26121 .01513 L
.26253 .01513 L
.2652 .01513 L
.26998 .01513 L
.27518 .01513 L
.27756 .01513 L
Mistroke
.27887 .01513 L
.28009 .01513 L
.28124 .01513 L
.28249 .01513 L
.28361 .01513 L
.28465 .01513 L
.28596 .01513 L
.28719 .01513 L
.28789 .01513 L
.28853 .01513 L
.28996 .01513 L
.29284 .01513 L
.29557 .01513 L
.30035 .01513 L
.30554 .01513 L
.32497 .01513 L
.33528 .01513 L
.34638 .01513 L
.35697 .01512 L
.36667 .01512 L
.37594 .01512 L
.38106 .01512 L
.3857 .01512 L
.39029 .01512 L
.39527 .01512 L
.398 .01512 L
.40052 .01512 L
.40308 .01512 L
.40548 .01512 L
.4077 .01512 L
.40973 .01512 L
.41081 .01512 L
.41199 .01512 L
.41323 .01512 L
.41441 .01512 L
.41554 .01512 L
.41679 .01512 L
.41809 .01512 L
.41932 .01512 L
.42045 .01512 L
.4215 .01512 L
.42386 .01512 L
.42633 .01512 L
.42859 .01512 L
.43364 .01512 L
.44276 .01512 L
.44798 .01512 L
.45352 .01512 L
.45825 .01512 L
.46093 .01512 L
Mistroke
.46214 .01512 L
.46345 .01512 L
.46473 .01512 L
.46592 .01512 L
.46706 .01512 L
.46827 .01512 L
.46946 .01512 L
.47059 .01512 L
.47159 .01512 L
.47268 .01512 L
.47388 .01512 L
.4752 .01512 L
.47785 .01512 L
.48031 .01512 L
.48261 .01512 L
.48786 .01512 L
.49265 .01512 L
.5034 .01512 L
.54326 .01512 L
.5615 .01512 L
.57188 .01512 L
.58161 .01512 L
.6014 .01512 L
.62242 .01512 L
.66112 .01512 L
.70228 .01512 L
.74193 .01512 L
.78005 .01512 L
.82064 .01512 L
.8597 .01512 L
.90122 .01512 L
.94122 .01512 L
.97619 .01512 L
Mfstroke
1 .522 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03478 L
.02721 .04273 L
.02846 .04904 L
.02961 .05288 L
.03068 .05508 L
.0317 .05628 L
.03279 .05688 L
.03395 .05699 L
.0352 .0567 L
.03638 .05615 L
.03746 .05551 L
.04262 .05153 L
.0529 .04319 L
.06244 .03678 L
.07277 .03141 L
.08405 .02707 L
.09398 .02425 L
.10458 .02204 L
.11487 .02046 L
.12599 .01922 L
.1365 .01838 L
.14616 .01781 L
.1559 .01738 L
.16499 .01708 L
.17496 .01683 L
.18565 .01664 L
.19582 .01651 L
.20119 .01646 L
.20689 .01641 L
.21186 .01638 L
.21734 .01634 L
.22701 .0163 L
.23193 .01628 L
.2371 .01627 L
.24152 .01626 L
.24636 .01625 L
.24909 .01625 L
.25158 .01625 L
.25296 .01625 L
.25445 .01625 L
.25586 .01625 L
.25716 .01625 L
.25836 .01625 L
.25949 .01625 L
.26072 .01625 L
.26141 .01625 L
.26204 .01625 L
.26331 .01625 L
Mistroke
.26403 .01625 L
.2647 .01625 L
.26721 .01625 L
.27231 .01625 L
.27498 .01625 L
.27645 .01625 L
.27781 .01625 L
.27901 .01625 L
.28029 .01625 L
.28102 .01625 L
.28171 .01625 L
.283 .01625 L
.28419 .01625 L
.28529 .01625 L
.2865 .01625 L
.28778 .01625 L
.28998 .01625 L
.29235 .01625 L
.29663 .01624 L
.3064 .01623 L
.32608 .01621 L
.33649 .01619 L
.34759 .01618 L
.35837 .01617 L
.36815 .01617 L
.37799 .01616 L
.38726 .01616 L
.39191 .01616 L
.39701 .01616 L
.40234 .01615 L
.40732 .01615 L
.41623 .01615 L
.42578 .01615 L
.447 .01615 L
.46711 .01615 L
.50541 .01614 L
.52516 .01614 L
.53526 .01614 L
.54616 .01614 L
.5563 .01614 L
.56561 .01614 L
.57444 .01614 L
.58388 .01614 L
.59366 .01614 L
.60278 .01614 L
.62347 .01614 L
.64479 .01614 L
.66493 .01614 L
.68323 .01614 L
.69363 .01614 L
Mistroke
.70337 .01614 L
.71374 .01614 L
.72322 .01614 L
.72807 .01614 L
.73336 .01614 L
.73894 .01614 L
.74425 .01614 L
.74681 .01614 L
.74957 .01614 L
.75084 .01614 L
.75218 .01614 L
.75334 .01614 L
.75458 .01614 L
.75579 .01614 L
.75689 .01614 L
.758 .01614 L
.75905 .01614 L
.76026 .01614 L
.76139 .01614 L
.76263 .01614 L
.76394 .01614 L
.76642 .01614 L
.76909 .01614 L
.77392 .01614 L
.77966 .01614 L
.78492 .01614 L
.82456 .01614 L
.86269 .01614 L
.90327 .01614 L
.94234 .01614 L
.97619 .01614 L
Mfstroke
1 .545 0 r
.02381 .01472 m
.02846 .05779 L
.03279 .09377 L
.03793 .12903 L
.04037 .14219 L
.04262 .15211 L
.04498 .16021 L
.04622 .16353 L
.04754 .16636 L
.04869 .16828 L
.04976 .16963 L
.05093 .17066 L
.0522 .17128 L
.05351 .17142 L
.05425 .17129 L
.05494 .17105 L
.0562 .17033 L
.05691 .16978 L
.05755 .16919 L
.06007 .16623 L
.06244 .16265 L
.08439 .11898 L
.09401 .10191 L
.10458 .0865 L
.11363 .07592 L
.12333 .06689 L
.13357 .05949 L
.14313 .05417 L
.1533 .04984 L
.16437 .04635 L
.17482 .04394 L
.18449 .0423 L
.18912 .04169 L
.19412 .04112 L
.20316 .04035 L
.20839 .04002 L
.21125 .03988 L
.2139 .03977 L
.21637 .03969 L
.21861 .03963 L
.2211 .03958 L
.22247 .03956 L
.22376 .03955 L
.22491 .03954 L
.22615 .03953 L
.22732 .03953 L
.22839 .03954 L
.22964 .03955 L
.23034 .03955 L
.231 .03956 L
Mistroke
.23348 .03961 L
.23483 .03964 L
.2361 .03967 L
.23846 .03976 L
.24102 .03987 L
.24377 .04003 L
.24845 .04038 L
.25339 .04088 L
.2576 .04144 L
.26222 .04218 L
.27227 .04414 L
.27721 .04508 L
.28177 .04579 L
.28432 .0461 L
.28702 .04635 L
.28842 .04645 L
.28974 .04652 L
.29118 .04658 L
.29199 .0466 L
.29273 .04662 L
.29393 .04663 L
.29505 .04663 L
.29628 .04662 L
.29759 .04659 L
.29825 .04657 L
.29897 .04655 L
.30027 .04649 L
.3027 .04636 L
.30761 .04598 L
.31219 .04553 L
.32262 .04433 L
.34367 .04189 L
.35411 .04089 L
.364 .04012 L
.37288 .03957 L
.38255 .03911 L
.39193 .03878 L
.39728 .03864 L
.4023 .03854 L
.40757 .03846 L
.4124 .03841 L
.41493 .03838 L
.41771 .03836 L
.4206 .03835 L
.4233 .03834 L
.42457 .03833 L
.42592 .03833 L
.42708 .03832 L
.42834 .03832 L
.42904 .03832 L
Mistroke
.42968 .03832 L
.43094 .03832 L
.43164 .03832 L
.43241 .03832 L
.43313 .03832 L
.4338 .03832 L
.4351 .03832 L
.43632 .03832 L
.43742 .03832 L
.43861 .03832 L
.44128 .03833 L
.44373 .03833 L
.44804 .03835 L
.45277 .03837 L
.46231 .03841 L
.46712 .03843 L
.47234 .03845 L
.47473 .03846 L
.47727 .03847 L
.47944 .03847 L
.48061 .03847 L
.48184 .03847 L
.48251 .03847 L
.48325 .03848 L
.48455 .03848 L
.48529 .03848 L
.48607 .03848 L
.48681 .03848 L
.48748 .03848 L
.48879 .03848 L
.48953 .03848 L
.49021 .03848 L
.49146 .03847 L
.49278 .03847 L
.49524 .03847 L
.49753 .03846 L
.50275 .03844 L
.50774 .03841 L
.51317 .03838 L
.52306 .0383 L
.5416 .03813 L
.56297 .03793 L
.58232 .03779 L
.59203 .03773 L
.60252 .03768 L
.62152 .03761 L
.63106 .03759 L
.64151 .03757 L
.66259 .03754 L
.70309 .03749 L
Mistroke
.74207 .03745 L
.7835 .0374 L
.82342 .03736 L
.86182 .03732 L
.90268 .03728 L
.94202 .03725 L
.97619 .03722 L
Mfstroke
1 .569 0 r
.02381 .01472 m
.02846 .05734 L
.03279 .08949 L
.03406 .09686 L
.03527 .10279 L
.03637 .1073 L
.03754 .11117 L
.0388 .11437 L
.03997 .11645 L
.04123 .11785 L
.04195 .11831 L
.04262 .11853 L
.04384 .11848 L
.04453 .11823 L
.04517 .11787 L
.04635 .11694 L
.04761 .11561 L
.05217 .10894 L
.06244 .09065 L
.07382 .07238 L
.08454 .05884 L
.09417 .04946 L
.10458 .04173 L
.11408 .0364 L
.12452 .03199 L
.13541 .02862 L
.14558 .0263 L
.15603 .02455 L
.16594 .02333 L
.17482 .0225 L
.18449 .02183 L
.19389 .02134 L
.20427 .02095 L
.20948 .0208 L
.2151 .02067 L
.22037 .02056 L
.22527 .02049 L
.2299 .02043 L
.23484 .02039 L
.23767 .02037 L
.24033 .02036 L
.24272 .02035 L
.24407 .02034 L
.24531 .02034 L
.24653 .02034 L
.24784 .02034 L
.24907 .02034 L
.25019 .02034 L
.25151 .02034 L
.25226 .02034 L
Mistroke
.25295 .02034 L
.25556 .02035 L
.25832 .02037 L
.26082 .02038 L
.26641 .02042 L
.2758 .02049 L
.27808 .02051 L
.28052 .02052 L
.28192 .02053 L
.2832 .02053 L
.28448 .02054 L
.2857 .02054 L
.28701 .02054 L
.28767 .02054 L
.2884 .02054 L
.28969 .02054 L
.2909 .02054 L
.2916 .02054 L
.29232 .02054 L
.29363 .02053 L
.29656 .02052 L
.29903 .02051 L
.30132 .02049 L
.30653 .02045 L
.32531 .02027 L
.34563 .02009 L
.35676 .02001 L
.36702 .01996 L
.37682 .01992 L
.38224 .01991 L
.38718 .01989 L
.39664 .01987 L
.40185 .01987 L
.40679 .01986 L
.41557 .01985 L
.42512 .01985 L
.46587 .01981 L
.4861 .01979 L
.5051 .01978 L
.52347 .01977 L
.54282 .01976 L
.55244 .01975 L
.56298 .01975 L
.57249 .01975 L
.58148 .01975 L
.59173 .01975 L
.60106 .01974 L
.62201 .01974 L
.64199 .01974 L
.66044 .01974 L
Mistroke
.68077 .01974 L
.69981 .01974 L
.71805 .01974 L
.7283 .01974 L
.73766 .01974 L
.74244 .01974 L
.74752 .01974 L
.75232 .01974 L
.75666 .01974 L
.75916 .01974 L
.76179 .01974 L
.76468 .01974 L
.76597 .01974 L
.76734 .01974 L
.76864 .01974 L
.76982 .01974 L
.77101 .01974 L
.77213 .01974 L
.77344 .01974 L
.77465 .01974 L
.77529 .01974 L
.77598 .01974 L
.77671 .01974 L
.77739 .01974 L
.77857 .01974 L
.77983 .01974 L
.78209 .01974 L
.78479 .01974 L
.78724 .01974 L
.79759 .01974 L
.8161 .01974 L
.83692 .01974 L
.8561 .01974 L
.89459 .01974 L
.93401 .01974 L
.97192 .01974 L
.97619 .01974 L
Mfstroke
1 .593 0 r
.02381 .01472 m
.02846 .05764 L
.03279 .09233 L
.03523 .10852 L
.03754 .12108 L
.03881 .12679 L
.0402 .13195 L
.04145 .13571 L
.04262 .13846 L
.04376 .14048 L
.045 .14195 L
.0457 .14249 L
.04637 .14281 L
.04762 .14296 L
.04894 .14254 L
.05016 .14171 L
.05086 .14105 L
.0515 .14037 L
.05293 .13854 L
.05783 .13017 L
.06244 .12081 L
.07312 .09905 L
.08439 .07955 L
.09401 .06638 L
.10458 .05517 L
.1142 .04738 L
.12452 .04104 L
.13425 .03653 L
.14313 .03338 L
.15304 .0307 L
.16222 .02883 L
.17228 .02728 L
.18298 .02608 L
.19235 .02532 L
.20245 .02471 L
.20709 .0245 L
.21198 .02431 L
.22073 .02406 L
.22573 .02395 L
.23027 .02388 L
.23279 .02385 L
.23411 .02384 L
.23552 .02383 L
.23674 .02382 L
.23809 .02381 L
.23932 .0238 L
.24047 .0238 L
.2416 .0238 L
.24284 .0238 L
.24401 .0238 L
Mistroke
.24509 .0238 L
.24617 .0238 L
.24714 .02381 L
.24827 .02381 L
.24932 .02382 L
.25171 .02384 L
.2539 .02386 L
.25883 .02393 L
.26872 .02414 L
.27415 .02426 L
.27683 .02431 L
.2793 .02436 L
.28157 .02439 L
.28408 .02442 L
.28538 .02443 L
.28661 .02444 L
.28789 .02445 L
.28862 .02445 L
.28928 .02445 L
.29038 .02445 L
.2914 .02445 L
.29252 .02445 L
.29371 .02444 L
.29497 .02444 L
.29616 .02443 L
.29837 .02441 L
.30299 .02435 L
.30788 .02427 L
.31663 .02409 L
.3364 .02368 L
.34586 .02351 L
.35601 .02335 L
.36553 .02324 L
.37434 .02316 L
.3845 .02309 L
.38985 .02306 L
.39555 .02303 L
.40015 .02302 L
.40511 .023 L
.41055 .02299 L
.41567 .02298 L
.45677 .02293 L
.49637 .02287 L
.53444 .02281 L
.55403 .02279 L
.57497 .02277 L
.5852 .02276 L
.59629 .02276 L
.61644 .02275 L
.63629 .02274 L
Mistroke
.65732 .02274 L
.69518 .02273 L
.7146 .02273 L
.73549 .02273 L
.7456 .02273 L
.75664 .02273 L
.76718 .02273 L
.77673 .02273 L
.79642 .02273 L
.8174 .02272 L
.85748 .02272 L
.89605 .02272 L
.93708 .02272 L
.97619 .02272 L
Mfstroke
1 .617 0 r
.02381 .01472 m
.02846 .05764 L
.03279 .09234 L
.03523 .10858 L
.03754 .12121 L
.03881 .12697 L
.0402 .13221 L
.04145 .13604 L
.04262 .13888 L
.04376 .14098 L
.045 .14255 L
.0457 .14315 L
.04637 .14352 L
.04762 .14377 L
.04894 .14346 L
.05016 .14271 L
.05086 .14211 L
.0515 .14147 L
.05293 .13973 L
.05783 .13158 L
.06244 .12232 L
.07312 .10058 L
.08439 .08095 L
.09401 .06763 L
.10458 .05626 L
.1142 .04835 L
.12452 .0419 L
.13425 .03731 L
.14313 .0341 L
.15304 .03136 L
.16222 .02945 L
.17228 .02787 L
.18298 .02665 L
.19235 .02586 L
.20245 .02525 L
.20709 .02503 L
.21198 .02484 L
.22073 .02458 L
.22573 .02448 L
.23027 .02441 L
.23279 .02438 L
.23411 .02437 L
.23552 .02436 L
.23674 .02435 L
.23809 .02434 L
.23932 .02434 L
.24047 .02433 L
.2416 .02433 L
.24284 .02433 L
.24401 .02434 L
Mistroke
.24509 .02434 L
.24617 .02434 L
.24714 .02435 L
.24932 .02437 L
.25168 .02439 L
.25422 .02442 L
.25883 .0245 L
.26829 .02472 L
.2735 .02486 L
.27842 .02497 L
.28121 .02502 L
.28268 .02504 L
.28424 .02506 L
.28554 .02508 L
.28624 .02508 L
.28699 .02509 L
.2883 .02509 L
.28953 .0251 L
.29079 .0251 L
.2915 .0251 L
.29217 .0251 L
.29287 .0251 L
.29351 .02509 L
.29494 .02509 L
.29616 .02508 L
.29749 .02506 L
.29989 .02504 L
.30466 .02496 L
.3099 .02486 L
.32048 .02462 L
.33943 .02419 L
.34943 .024 L
.35892 .02385 L
.36985 .02372 L
.37982 .02363 L
.38946 .02357 L
.39433 .02354 L
.39971 .02352 L
.40427 .02351 L
.4092 .0235 L
.41812 .02348 L
.45923 .02343 L
.49882 .02336 L
.5369 .0233 L
.55648 .02327 L
.57742 .02325 L
.58765 .02324 L
.59874 .02324 L
.61889 .02323 L
.63874 .02322 L
Mistroke
.65978 .02322 L
.69763 .02321 L
.71705 .02321 L
.73794 .0232 L
.75909 .0232 L
.77918 .0232 L
.799 .0232 L
.8174 .0232 L
.85655 .0232 L
.89815 .0232 L
.93823 .0232 L
.97619 .0232 L
Mfstroke
1 .64 0 r
.02381 .01472 m
.02846 .05733 L
.03279 .08935 L
.03406 .09664 L
.03527 .10249 L
.03637 .10691 L
.03754 .11068 L
.0388 .11378 L
.03997 .11579 L
.04123 .11714 L
.04195 .11757 L
.04262 .11777 L
.04384 .11772 L
.04453 .11747 L
.04517 .11712 L
.04635 .11622 L
.04761 .11495 L
.05217 .10855 L
.06244 .091 L
.07382 .07338 L
.08454 .06025 L
.09417 .05113 L
.10458 .04358 L
.11408 .03836 L
.12452 .03404 L
.13541 .03072 L
.14558 .02844 L
.15603 .02671 L
.16594 .02551 L
.17482 .02469 L
.18449 .02403 L
.19389 .02356 L
.20427 .02318 L
.20948 .02305 L
.2151 .02293 L
.22041 .02284 L
.22296 .02281 L
.22527 .02278 L
.22755 .02276 L
.23001 .02274 L
.23137 .02274 L
.23262 .02273 L
.23381 .02272 L
.23508 .02272 L
.23616 .02272 L
.23732 .02272 L
.23842 .02272 L
.23942 .02272 L
.24059 .02272 L
.24187 .02272 L
Mistroke
.24308 .02273 L
.2442 .02273 L
.24691 .02275 L
.24946 .02277 L
.25422 .02283 L
.25935 .02291 L
.2649 .02303 L
.26989 .02314 L
.27524 .02325 L
.27783 .02329 L
.28028 .02333 L
.28248 .02336 L
.28488 .02338 L
.28608 .02338 L
.28741 .02339 L
.28808 .02339 L
.2888 .0234 L
.2901 .0234 L
.29133 .0234 L
.29262 .02339 L
.29373 .02339 L
.29493 .02339 L
.29638 .02338 L
.2977 .02337 L
.30064 .02334 L
.30595 .02327 L
.3268 .02292 L
.34599 .02262 L
.36471 .0224 L
.37414 .02232 L
.37946 .02229 L
.38451 .02226 L
.38938 .02223 L
.39469 .02221 L
.40399 .02219 L
.40925 .02218 L
.41485 .02217 L
.4249 .02216 L
.46262 .0221 L
.48356 .02207 L
.50279 .02205 L
.52161 .02203 L
.54144 .02201 L
.55097 .02201 L
.56116 .022 L
.57952 .022 L
.58974 .02199 L
.60084 .02199 L
.60593 .02199 L
.61132 .02199 L
Mistroke
.61637 .02199 L
.62098 .02199 L
.62549 .02199 L
.6304 .02199 L
.6356 .02199 L
.64053 .02199 L
.64513 .02199 L
.6477 .02199 L
.65003 .02199 L
.65221 .02199 L
.65336 .02199 L
.65457 .02199 L
.65563 .02199 L
.65679 .02199 L
.65785 .02199 L
.65884 .02199 L
.6601 .02199 L
.66074 .02199 L
.66144 .02199 L
.66269 .02199 L
.66385 .02199 L
.66452 .02199 L
.66522 .02199 L
.66647 .02199 L
.6693 .02199 L
.67403 .02199 L
.67921 .02199 L
.68876 .02199 L
.69777 .02199 L
.7027 .02199 L
.70549 .02199 L
.70681 .02199 L
.70805 .02199 L
.70909 .02199 L
.71021 .02199 L
.71146 .02199 L
.71259 .02199 L
.71377 .02199 L
.71505 .02199 L
.71627 .02199 L
.71739 .02199 L
.71871 .02199 L
.72014 .02199 L
.72272 .02199 L
.72524 .02199 L
.72755 .02199 L
.7328 .02199 L
.73835 .02199 L
.74786 .02199 L
.75804 .02199 L
Mistroke
.77639 .02199 L
.81783 .02199 L
.85774 .02198 L
.89614 .02198 L
.937 .02198 L
.97619 .02198 L
Mfstroke
1 .664 0 r
.02381 .01472 m
.02499 .02578 L
.02605 .03482 L
.02721 .04291 L
.02846 .04953 L
.02961 .05378 L
.03068 .05641 L
.0317 .05802 L
.03279 .05902 L
.03395 .05951 L
.0352 .05956 L
.03638 .05928 L
.03746 .05884 L
.03873 .05816 L
.04011 .05728 L
.04262 .05545 L
.06244 .04067 L
.07302 .03484 L
.08429 .03016 L
.09493 .0269 L
.10458 .02468 L
.1146 .02294 L
.12383 .02174 L
.13395 .02074 L
.14465 .01997 L
.15412 .01946 L
.16428 .01906 L
.17387 .01878 L
.18262 .01859 L
.19253 .01842 L
.2017 .01832 L
.20649 .01827 L
.21177 .01823 L
.21729 .0182 L
.22246 .01818 L
.22716 .01816 L
.22982 .01815 L
.23229 .01815 L
.23364 .01815 L
.23492 .01815 L
.23606 .01815 L
.2373 .01815 L
.23794 .01815 L
.23865 .01815 L
.23939 .01815 L
.24008 .01815 L
.24132 .01815 L
.24201 .01815 L
.24265 .01815 L
.24379 .01815 L
Mistroke
.245 .01815 L
.24719 .01815 L
.24979 .01816 L
.25214 .01817 L
.25678 .01819 L
.26115 .01821 L
.27094 .01827 L
.27629 .0183 L
.27889 .01831 L
.28127 .01832 L
.28346 .01833 L
.28553 .01833 L
.28666 .01833 L
.28771 .01833 L
.28886 .01834 L
.29009 .01834 L
.29123 .01834 L
.29246 .01834 L
.29362 .01833 L
.29468 .01833 L
.29587 .01833 L
.29716 .01833 L
.29975 .01832 L
.30506 .01831 L
.31006 .01829 L
.3194 .01824 L
.34037 .01814 L
.35011 .0181 L
.36042 .01807 L
.37008 .01804 L
.37889 .01803 L
.38835 .01801 L
.39356 .018 L
.3985 .018 L
.40727 .01799 L
.41223 .01799 L
.41682 .01799 L
.45606 .01797 L
.49378 .01795 L
.5131 .01795 L
.52397 .01794 L
.53395 .01794 L
.54308 .01794 L
.55285 .01794 L
.56356 .01793 L
.57354 .01793 L
.58377 .01793 L
.58954 .01793 L
.59486 .01793 L
.59952 .01793 L
Mistroke
.60464 .01793 L
.60722 .01793 L
.60999 .01793 L
.61261 .01793 L
.61501 .01793 L
.61629 .01793 L
.61751 .01793 L
.6186 .01793 L
.61978 .01793 L
.62106 .01793 L
.62171 .01793 L
.62243 .01793 L
.62368 .01793 L
.62486 .01793 L
.62605 .01793 L
.62717 .01793 L
.62928 .01793 L
.63401 .01793 L
.63917 .01793 L
.64394 .01793 L
.65473 .01793 L
.69402 .01793 L
.73179 .01793 L
.77201 .01794 L
.81072 .01794 L
.85188 .01794 L
.87242 .01794 L
.89153 .01794 L
.92965 .01794 L
.96872 .01794 L
.97619 .01794 L
Mfstroke
1 .688 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03479 L
.02721 .04278 L
.02846 .04917 L
.02961 .05311 L
.03068 .05541 L
.0317 .05672 L
.03279 .05742 L
.03395 .05762 L
.0352 .05741 L
.03638 .05693 L
.03746 .05633 L
.04262 .0525 L
.06244 .03777 L
.07277 .03233 L
.08405 .02791 L
.09469 .02486 L
.10458 .02276 L
.11515 .0211 L
.1251 .01995 L
.13404 .01917 L
.14371 .01853 L
.15321 .01806 L
.16365 .01768 L
.17454 .01739 L
.18471 .0172 L
.19516 .01705 L
.20506 .01695 L
.21395 .01689 L
.21894 .01686 L
.22362 .01684 L
.22852 .01682 L
.23302 .01681 L
.23801 .0168 L
.24064 .0168 L
.24208 .01679 L
.2434 .01679 L
.2446 .01679 L
.24591 .01679 L
.24663 .01679 L
.24729 .01679 L
.24859 .01679 L
.24971 .01679 L
.25094 .01679 L
.25223 .01679 L
.25343 .01679 L
.25411 .01679 L
.25485 .01679 L
.25619 .01679 L
Mistroke
.25872 .01679 L
.26167 .0168 L
.2644 .0168 L
.2695 .01681 L
.275 .01682 L
.27753 .01682 L
.28019 .01683 L
.28247 .01683 L
.28375 .01683 L
.28497 .01683 L
.28613 .01683 L
.2874 .01683 L
.28855 .01683 L
.28962 .01683 L
.29077 .01683 L
.29204 .01683 L
.29267 .01683 L
.29336 .01683 L
.2946 .01683 L
.29689 .01683 L
.29929 .01683 L
.30359 .01682 L
.31316 .0168 L
.32337 .01678 L
.34175 .01674 L
.35201 .01673 L
.36313 .01671 L
.37363 .0167 L
.3833 .01669 L
.38798 .01669 L
.39302 .01668 L
.39736 .01668 L
.4021 .01668 L
.40498 .01668 L
.40764 .01668 L
.41014 .01668 L
.4129 .01668 L
.41536 .01668 L
.41767 .01668 L
.41895 .01668 L
.42012 .01668 L
.4214 .01668 L
.42204 .01668 L
.42275 .01668 L
.42407 .01668 L
.42528 .01668 L
.42592 .01668 L
.42661 .01668 L
.42803 .01668 L
.42927 .01668 L
Mistroke
.4306 .01668 L
.43301 .01668 L
.44234 .01668 L
.44795 .01668 L
.45071 .01668 L
.45328 .01668 L
.45559 .01668 L
.45678 .01668 L
.45806 .01668 L
.4588 .01668 L
.45947 .01668 L
.46012 .01668 L
.4608 .01668 L
.46198 .01668 L
.46328 .01668 L
.46459 .01668 L
.46579 .01668 L
.46642 .01668 L
.46712 .01668 L
.46853 .01668 L
.47109 .01668 L
.47349 .01668 L
.47798 .01668 L
.4828 .01668 L
.49372 .01668 L
.50372 .01667 L
.52427 .01667 L
.54337 .01666 L
.56181 .01666 L
.5815 .01666 L
.59175 .01665 L
.60286 .01665 L
.62301 .01665 L
.66395 .01665 L
.70338 .01665 L
.74128 .01665 L
.76075 .01665 L
.78164 .01664 L
.82294 .01664 L
.86272 .01664 L
.90099 .01664 L
.9417 .01664 L
.97619 .01664 L
Mfstroke
1 .711 0 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02123 L
.03053 .02114 L
.03279 .02087 L
.04262 .01953 L
.05285 .01836 L
.06244 .01751 L
.07218 .01686 L
.0829 .01633 L
.09334 .01596 L
.10458 .01566 L
.11468 .01548 L
.12571 .01533 L
.13613 .01522 L
.1458 .01515 L
.15637 .0151 L
.16633 .01506 L
.17526 .01503 L
.18493 .01501 L
.19444 .015 L
.20487 .01499 L
.21577 .01498 L
.22594 .01497 L
.23094 .01497 L
.23639 .01497 L
.24119 .01497 L
.24629 .01497 L
.25087 .01496 L
.25593 .01496 L
.26053 .01496 L
.26485 .01496 L
.30353 .01496 L
.32318 .01496 L
.33357 .01496 L
.34467 .01496 L
.35543 .01496 L
.3652 .01496 L
.37502 .01496 L
.3843 .01496 L
.38893 .01496 L
.39402 .01496 L
.39934 .01496 L
.40431 .01496 L
.41321 .01496 L
.42276 .01496 L
.43289 .01495 L
Mistroke
.44394 .01495 L
.46404 .01495 L
.4854 .01495 L
.50474 .01495 L
.51444 .01495 L
.52493 .01495 L
.53476 .01495 L
.54392 .01495 L
.55345 .01495 L
.55892 .01495 L
.5639 .01495 L
.57408 .01495 L
.57968 .01495 L
.58497 .01495 L
.58958 .01495 L
.59465 .01495 L
.59995 .01495 L
.60492 .01495 L
.60956 .01495 L
.6138 .01495 L
.62336 .01495 L
.66303 .01495 L
.68304 .01495 L
.69176 .01495 L
.70119 .01495 L
.70646 .01495 L
.70877 .01495 L
.71131 .01495 L
.7137 .01495 L
.71485 .01495 L
.71594 .01495 L
.71718 .01495 L
.71831 .01495 L
.71952 .01495 L
.72084 .01495 L
.72214 .01495 L
.72335 .01495 L
.72404 .01495 L
.72468 .01495 L
.72612 .01495 L
.72885 .01495 L
.73173 .01495 L
.73654 .01495 L
.74181 .01495 L
.75207 .01495 L
.76139 .01495 L
.78234 .01495 L
.82229 .01495 L
.86072 .01495 L
.90161 .01495 L
Mistroke
.94098 .01495 L
.97619 .01495 L
Mfstroke
1 .735 0 r
.02381 .01472 m
.02846 .05737 L
.03279 .08995 L
.03527 .10399 L
.03754 .11346 L
.03879 .11738 L
.04015 .12064 L
.04143 .12285 L
.04262 .12422 L
.04376 .12499 L
.04498 .12531 L
.04614 .12518 L
.0472 .12476 L
.04843 .12395 L
.04978 .12273 L
.05224 .11986 L
.06244 .10371 L
.08284 .07312 L
.09424 .06071 L
.10458 .05212 L
.11463 .04572 L
.12551 .04051 L
.13578 .03685 L
.14523 .0343 L
.15496 .0323 L
.16405 .03089 L
.17402 .02972 L
.18471 .02882 L
.19489 .02821 L
.20063 .02796 L
.20595 .02777 L
.21059 .02763 L
.21571 .02752 L
.21828 .02748 L
.22105 .02744 L
.22233 .02743 L
.22367 .02742 L
.22492 .02741 L
.22607 .0274 L
.22731 .0274 L
.22796 .02739 L
.22865 .02739 L
.2298 .02739 L
.23107 .02739 L
.23221 .02739 L
.23342 .02739 L
.23457 .0274 L
.23562 .02741 L
.23812 .02743 L
.23954 .02744 L
Mistroke
.24085 .02746 L
.24341 .02751 L
.24582 .02756 L
.25048 .02768 L
.25471 .02784 L
.26418 .02831 L
.27397 .02888 L
.27932 .02915 L
.28192 .02925 L
.2843 .02932 L
.28535 .02935 L
.28649 .02937 L
.28747 .02939 L
.28856 .0294 L
.28971 .02942 L
.29093 .02943 L
.29206 .02943 L
.29312 .02943 L
.2943 .02943 L
.29555 .02942 L
.29661 .02941 L
.29777 .02939 L
.30037 .02935 L
.30279 .0293 L
.30785 .02916 L
.31334 .02898 L
.32328 .0286 L
.34188 .0279 L
.3618 .02733 L
.37183 .02713 L
.38285 .02696 L
.38808 .02689 L
.39304 .02684 L
.40234 .02678 L
.40754 .02675 L
.41235 .02673 L
.42325 .0267 L
.46248 .0266 L
.5002 .02652 L
.51952 .02649 L
.54037 .02647 L
.56039 .02645 L
.57045 .02644 L
.57612 .02643 L
.58148 .02643 L
.5864 .02643 L
.59173 .02643 L
.59409 .02643 L
.59659 .02643 L
.59892 .02643 L
Mistroke
.60106 .02642 L
.60354 .02642 L
.60491 .02642 L
.60621 .02642 L
.60741 .02642 L
.60852 .02642 L
.60973 .02642 L
.61103 .02642 L
.61177 .02642 L
.61246 .02642 L
.614 .02642 L
.61535 .02642 L
.61679 .02642 L
.61928 .02643 L
.62201 .02643 L
.62725 .02643 L
.63222 .02643 L
.64153 .02643 L
.66245 .02644 L
.7008 .02646 L
.72059 .02646 L
.73058 .02647 L
.7416 .02647 L
.76096 .02647 L
.77185 .02647 L
.78182 .02647 L
.80076 .02647 L
.81149 .02647 L
.82147 .02647 L
.82652 .02647 L
.832 .02647 L
.83451 .02647 L
.83717 .02647 L
.83944 .02647 L
.84073 .02647 L
.84194 .02647 L
.8431 .02647 L
.84436 .02647 L
.84551 .02647 L
.84657 .02647 L
.84784 .02647 L
.84898 .02647 L
.85031 .02647 L
.85155 .02647 L
.85264 .02647 L
.8538 .02647 L
.85587 .02647 L
.85809 .02647 L
.86053 .02647 L
.8658 .02647 L
Mistroke
.87078 .02647 L
.8801 .02647 L
.89013 .02647 L
.90103 .02647 L
.94188 .02647 L
.97619 .02647 L
Mfstroke
1 .759 0 r
.02381 .01472 m
.02605 .03538 L
.02729 .04518 L
.02846 .05304 L
.02954 .05903 L
.03072 .0641 L
.0318 .06753 L
.03279 .06984 L
.03396 .0717 L
.03506 .07275 L
.03626 .0733 L
.03756 .07336 L
.03821 .07323 L
.03891 .07298 L
.0402 .07233 L
.04145 .0715 L
.04262 .07059 L
.06244 .05162 L
.07295 .04358 L
.08284 .03771 L
.09424 .03261 L
.10458 .0292 L
.11434 .02678 L
.12466 .02486 L
.13346 .02363 L
.14313 .02259 L
.15334 .02178 L
.16264 .02122 L
.17338 .02075 L
.18355 .02043 L
.19321 .02021 L
.1985 .02011 L
.20346 .02004 L
.21222 .01994 L
.21687 .01991 L
.21929 .01989 L
.22188 .01988 L
.22448 .01986 L
.22684 .01986 L
.22798 .01985 L
.22922 .01985 L
.23037 .01985 L
.23146 .01985 L
.23272 .01984 L
.23338 .01984 L
.2341 .01984 L
.23485 .01984 L
.23557 .01984 L
.23621 .01984 L
.2369 .01984 L
Mistroke
.23816 .01985 L
.23887 .01985 L
.23951 .01985 L
.24192 .01985 L
.24325 .01986 L
.24465 .01986 L
.24715 .01987 L
.24984 .01989 L
.2528 .01991 L
.25809 .01996 L
.26302 .02002 L
.2735 .02015 L
.27866 .02021 L
.28092 .02023 L
.28342 .02025 L
.28565 .02026 L
.28666 .02026 L
.28773 .02027 L
.28889 .02027 L
.28994 .02027 L
.29108 .02027 L
.29232 .02027 L
.29359 .02027 L
.29474 .02027 L
.29538 .02027 L
.29607 .02027 L
.29733 .02027 L
.29975 .02026 L
.30199 .02025 L
.30667 .02022 L
.3117 .02018 L
.32079 .0201 L
.34144 .01991 L
.3516 .01983 L
.36266 .01976 L
.3731 .01971 L
.38277 .01967 L
.38739 .01966 L
.39238 .01965 L
.40141 .01963 L
.40664 .01962 L
.41215 .01962 L
.422 .01961 L
.46008 .01958 L
.48131 .01956 L
.50061 .01954 L
.51023 .01953 L
.52067 .01952 L
.53962 .01951 L
.54907 .01951 L
Mistroke
.55947 .0195 L
.57034 .0195 L
.58051 .0195 L
.58548 .0195 L
.5909 .0195 L
.59568 .0195 L
.60077 .0195 L
.60581 .0195 L
.61038 .0195 L
.61259 .0195 L
.61497 .0195 L
.61607 .0195 L
.61723 .0195 L
.6183 .0195 L
.6193 .0195 L
.62052 .0195 L
.62116 .0195 L
.62185 .0195 L
.623 .0195 L
.62426 .0195 L
.62539 .0195 L
.6266 .0195 L
.62774 .0195 L
.62879 .0195 L
.63115 .0195 L
.63374 .0195 L
.63895 .0195 L
.64845 .0195 L
.65729 .0195 L
.69636 .0195 L
.73787 .0195 L
.77788 .0195 L
.81636 .01951 L
.8573 .01951 L
.89672 .01951 L
.93463 .01951 L
.97499 .01951 L
.97619 .01951 L
Mfstroke
1 .783 0 r
.02381 .01472 m
.02846 .05778 L
.03279 .09356 L
.03754 .12558 L
.0402 .13934 L
.04262 .14899 L
.04385 .15285 L
.04516 .1562 L
.04627 .15846 L
.0475 .16035 L
.04882 .16172 L
.04957 .16222 L
.05024 .16252 L
.05156 .16267 L
.05281 .16237 L
.05397 .16173 L
.0552 .16073 L
.05742 .15821 L
.06244 .15014 L
.08414 .10736 L
.09479 .09006 L
.10458 .07728 L
.11429 .06724 L
.12455 .059 L
.13486 .05269 L
.14616 .04753 L
.15637 .04408 L
.16567 .04171 L
.17641 .03967 L
.18659 .03829 L
.19624 .03735 L
.20111 .03699 L
.2065 .03668 L
.21107 .03647 L
.21347 .03638 L
.216 .0363 L
.21822 .03625 L
.22065 .0362 L
.22172 .03619 L
.22286 .03617 L
.22394 .03616 L
.22492 .03615 L
.22611 .03615 L
.22722 .03615 L
.22845 .03615 L
.22976 .03615 L
.23042 .03616 L
.23114 .03616 L
.23245 .03618 L
.23372 .0362 L
Mistroke
.2349 .03622 L
.23724 .03627 L
.23936 .03634 L
.2441 .03654 L
.24679 .03669 L
.24925 .03685 L
.25482 .03732 L
.25972 .03787 L
.2649 .03857 L
.2744 .03998 L
.27963 .04065 L
.2822 .04091 L
.28458 .04111 L
.28681 .04124 L
.28794 .0413 L
.28918 .04135 L
.29042 .04138 L
.29112 .0414 L
.29176 .04141 L
.29294 .04142 L
.29418 .04142 L
.29523 .04141 L
.29634 .04139 L
.2974 .04137 L
.29836 .04134 L
.30071 .04126 L
.30292 .04115 L
.30757 .04086 L
.31267 .04046 L
.32298 .03953 L
.34144 .03788 L
.36093 .03654 L
.37186 .036 L
.38183 .03563 L
.38663 .03549 L
.39173 .03536 L
.40089 .03519 L
.40598 .03512 L
.41075 .03508 L
.41599 .03503 L
.42165 .035 L
.4312 .03495 L
.44166 .03492 L
.44694 .0349 L
.45258 .03489 L
.46275 .03487 L
.48264 .03485 L
.48809 .03485 L
.49386 .03484 L
.50422 .03482 L
Mistroke
.51404 .03479 L
.52323 .03476 L
.54417 .03468 L
.56272 .03461 L
.58296 .03455 L
.59393 .03452 L
.59927 .03451 L
.60411 .03451 L
.60878 .0345 L
.61384 .0345 L
.61662 .0345 L
.61918 .03449 L
.62181 .03449 L
.6242 .03449 L
.62662 .03449 L
.62891 .03449 L
.63016 .03449 L
.63132 .03449 L
.6326 .03449 L
.63324 .03449 L
.63395 .03449 L
.63513 .03449 L
.63621 .03449 L
.63739 .03449 L
.63864 .03449 L
.63973 .03449 L
.64074 .03449 L
.64304 .03449 L
.64828 .03449 L
.65304 .03449 L
.66371 .0345 L
.67383 .0345 L
.68453 .03451 L
.69367 .03451 L
.69886 .03451 L
.70371 .03451 L
.7061 .03451 L
.70869 .03451 L
.70988 .03451 L
.71114 .03451 L
.71233 .03451 L
.71341 .03451 L
.71457 .03451 L
.71581 .03451 L
.71691 .03451 L
.71806 .03451 L
.7191 .03451 L
.72007 .03451 L
.72113 .03451 L
.72227 .03451 L
Mistroke
.72361 .03451 L
.72484 .03451 L
.72763 .03451 L
.7301 .03451 L
.73271 .03451 L
.7422 .03451 L
.7516 .03451 L
.76173 .0345 L
.78002 .0345 L
.82123 .03448 L
.86093 .03447 L
.89911 .03445 L
.93974 .03443 L
.97619 .03441 L
Mfstroke
1 .806 0 r
.02381 .01472 m
.02499 .02578 L
.02605 .03481 L
.02721 .04287 L
.02846 .04942 L
.02961 .05358 L
.03068 .05611 L
.0317 .05764 L
.03279 .05856 L
.03395 .05897 L
.0352 .05895 L
.03638 .05863 L
.03746 .05815 L
.04011 .05653 L
.04262 .05468 L
.06244 .04009 L
.07289 .03445 L
.08259 .03044 L
.09323 .02711 L
.10458 .02451 L
.11487 .02279 L
.12599 .02142 L
.1365 .02049 L
.14616 .01984 L
.1559 .01936 L
.16499 .01902 L
.17496 .01874 L
.18565 .01852 L
.19582 .01838 L
.20157 .01831 L
.20689 .01826 L
.21192 .01823 L
.21665 .0182 L
.22157 .01818 L
.22439 .01817 L
.22701 .01816 L
.22947 .01815 L
.23171 .01815 L
.23298 .01815 L
.23419 .01815 L
.23546 .01814 L
.23618 .01814 L
.23684 .01814 L
.23808 .01814 L
.23924 .01814 L
.24051 .01814 L
.24122 .01814 L
.24187 .01815 L
.24318 .01815 L
.2446 .01815 L
Mistroke
.24719 .01815 L
.24963 .01816 L
.25184 .01817 L
.2568 .01819 L
.26138 .01821 L
.2657 .01824 L
.27549 .01831 L
.28083 .01834 L
.28344 .01835 L
.28582 .01836 L
.288 .01837 L
.28901 .01837 L
.29007 .01837 L
.29121 .01837 L
.29226 .01837 L
.29339 .01837 L
.29463 .01838 L
.29589 .01837 L
.29704 .01837 L
.2983 .01837 L
.29962 .01837 L
.30186 .01837 L
.3043 .01836 L
.3096 .01834 L
.3146 .01832 L
.32395 .01828 L
.34491 .01817 L
.35466 .01813 L
.36497 .01809 L
.37462 .01807 L
.38343 .01805 L
.39289 .01803 L
.39811 .01802 L
.40305 .01802 L
.4073 .01801 L
.41182 .01801 L
.41678 .01801 L
.42137 .018 L
.42625 .018 L
.43073 .018 L
.44082 .018 L
.44965 .018 L
.45909 .01799 L
.46888 .01799 L
.47799 .01798 L
.49868 .01797 L
.51857 .01795 L
.54015 .01794 L
.55024 .01794 L
.56092 .01793 L
Mistroke
.5801 .01793 L
.58952 .01793 L
.59965 .01792 L
.61795 .01792 L
.6391 .01792 L
.6592 .01792 L
.69741 .01792 L
.7171 .01792 L
.73808 .01791 L
.74837 .01791 L
.7595 .01791 L
.76912 .01791 L
.77968 .01791 L
.79 .01791 L
.79963 .01791 L
.8098 .01791 L
.81546 .01791 L
.8207 .01791 L
.82554 .01791 L
.83088 .01791 L
.83625 .01791 L
.8392 .01791 L
.84196 .01791 L
.84442 .01791 L
.84566 .01791 L
.84701 .01791 L
.84817 .01791 L
.84941 .01791 L
.85058 .01791 L
.85164 .01791 L
.8523 .01791 L
.85298 .01791 L
.85422 .01791 L
.85491 .01791 L
.85555 .01791 L
.85701 .01791 L
.85946 .01791 L
.86208 .01791 L
.86734 .01791 L
.87222 .01791 L
.88327 .01791 L
.89301 .01791 L
.90338 .01791 L
.92485 .01791 L
.94503 .01791 L
.97619 .01791 L
Mfstroke
1 .83 0 r
.02381 .01472 m
.02605 .03538 L
.02729 .04518 L
.02846 .05305 L
.02954 .05904 L
.03072 .06413 L
.0318 .06758 L
.03279 .06991 L
.03396 .07179 L
.03506 .07285 L
.03626 .07342 L
.03756 .0735 L
.03821 .07338 L
.03891 .07315 L
.0402 .07251 L
.04145 .07168 L
.04262 .07077 L
.06244 .05169 L
.07295 .04355 L
.08284 .03758 L
.09424 .03238 L
.10458 .0289 L
.11434 .02642 L
.12466 .02445 L
.13346 .02318 L
.14313 .02211 L
.15334 .02127 L
.16264 .0207 L
.17338 .02021 L
.18355 .01987 L
.19321 .01964 L
.1985 .01954 L
.20346 .01946 L
.21222 .01935 L
.21687 .01931 L
.22188 .01927 L
.22428 .01926 L
.22684 .01925 L
.22906 .01924 L
.23146 .01923 L
.23292 .01923 L
.23428 .01922 L
.23557 .01922 L
.23623 .01922 L
.23694 .01922 L
.23817 .01922 L
.23931 .01922 L
.24001 .01922 L
.24068 .01922 L
.24192 .01922 L
Mistroke
.24261 .01922 L
.24326 .01922 L
.24446 .01922 L
.24576 .01923 L
.24716 .01923 L
.24969 .01924 L
.25202 .01925 L
.25737 .01928 L
.26302 .01933 L
.27253 .01942 L
.27776 .01947 L
.28033 .0195 L
.2827 .01951 L
.28489 .01953 L
.2873 .01954 L
.28847 .01954 L
.28973 .01954 L
.29042 .01955 L
.29106 .01955 L
.2923 .01955 L
.29336 .01955 L
.29434 .01955 L
.29542 .01955 L
.29657 .01955 L
.29778 .01955 L
.29892 .01955 L
.30105 .01954 L
.30345 .01953 L
.30569 .01952 L
.3108 .01949 L
.3211 .01942 L
.33957 .01928 L
.35818 .01916 L
.3687 .01911 L
.37844 .01907 L
.38873 .01904 L
.39392 .01903 L
.39966 .01902 L
.40465 .01901 L
.41003 .01901 L
.41511 .019 L
.41977 .019 L
.42225 .019 L
.4245 .019 L
.4271 .019 L
.42956 .019 L
.43183 .019 L
.43393 .019 L
.43867 .01899 L
.44386 .01899 L
Mistroke
.44872 .01899 L
.45116 .01899 L
.45379 .01899 L
.4567 .01899 L
.45936 .01899 L
.46413 .01899 L
.46922 .01899 L
.47836 .01898 L
.48924 .01897 L
.49909 .01896 L
.51998 .01894 L
.53918 .01892 L
.55794 .01891 L
.5675 .0189 L
.57775 .0189 L
.58803 .01889 L
.5974 .01889 L
.61574 .01889 L
.63484 .01888 L
.65561 .01888 L
.69641 .01887 L
.71668 .01887 L
.73569 .01887 L
.77347 .01887 L
.79366 .01887 L
.81217 .01887 L
.85182 .01887 L
.88995 .01886 L
.91121 .01886 L
.93053 .01886 L
.96959 .01886 L
.97619 .01886 L
Mfstroke
1 .854 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01975 L
.05285 .01856 L
.06244 .0177 L
.07218 .01703 L
.0829 .01649 L
.09334 .0161 L
.10458 .01579 L
.11468 .01559 L
.12571 .01544 L
.13613 .01533 L
.1458 .01526 L
.15637 .0152 L
.16633 .01516 L
.17526 .01513 L
.18493 .01511 L
.19444 .01509 L
.20487 .01508 L
.21013 .01508 L
.21577 .01507 L
.22594 .01506 L
.23122 .01506 L
.23611 .01506 L
.24148 .01506 L
.24718 .01506 L
.24955 .01506 L
.25211 .01506 L
.25432 .01506 L
.25674 .01506 L
.25942 .01506 L
.26079 .01506 L
.26225 .01506 L
.26362 .01506 L
.26486 .01506 L
.2673 .01506 L
.27211 .01506 L
.27447 .01506 L
.27662 .01506 L
.27888 .01506 L
.28132 .01506 L
.28397 .01506 L
.28648 .01506 L
.29166 .01506 L
Mistroke
.2973 .01505 L
.30728 .01505 L
.32864 .01505 L
.34798 .01505 L
.35768 .01505 L
.36817 .01505 L
.37298 .01505 L
.37806 .01505 L
.38716 .01505 L
.39213 .01505 L
.39666 .01505 L
.39917 .01505 L
.40189 .01505 L
.40314 .01505 L
.40446 .01505 L
.4057 .01505 L
.40684 .01505 L
.40789 .01505 L
.40901 .01505 L
.41012 .01505 L
.41134 .01505 L
.4124 .01505 L
.41353 .01505 L
.4146 .01505 L
.41556 .01505 L
.4168 .01505 L
.41794 .01505 L
.42052 .01505 L
.42518 .01505 L
.42987 .01505 L
.4349 .01505 L
.44398 .01505 L
.45471 .01505 L
.45943 .01505 L
.46464 .01505 L
.46701 .01505 L
.46956 .01505 L
.47097 .01505 L
.47226 .01505 L
.4735 .01505 L
.4748 .01505 L
.47612 .01505 L
.47686 .01505 L
.47753 .01505 L
.47884 .01505 L
.48007 .01505 L
.48077 .01505 L
.48152 .01505 L
.48285 .01505 L
.48428 .01505 L
Mistroke
.48585 .01505 L
.49086 .01505 L
.49367 .01505 L
.49624 .01505 L
.50597 .01505 L
.5457 .01505 L
.56574 .01505 L
.58391 .01505 L
.6036 .01505 L
.62457 .01505 L
.66466 .01504 L
.70323 .01504 L
.74425 .01504 L
.78376 .01504 L
.82175 .01504 L
.8622 .01504 L
.90113 .01504 L
.94251 .01504 L
.97619 .01504 L
Mfstroke
1 .877 0 r
.02381 .01472 m
.02846 .05721 L
.03068 .07467 L
.03279 .08848 L
.03398 .09497 L
.03527 .10085 L
.03635 .10483 L
.03754 .10828 L
.03882 .11099 L
.03952 .11206 L
.04018 .11283 L
.04135 .11367 L
.04262 .11392 L
.04393 .11359 L
.04516 .11284 L
.04586 .11224 L
.0465 .11162 L
.04793 .10997 L
.05297 .10242 L
.06244 .08631 L
.07287 .07045 L
.08414 .05688 L
.09479 .04719 L
.10458 .04044 L
.11432 .03534 L
.1234 .0317 L
.13338 .02867 L
.14407 .02626 L
.15424 .02458 L
.16531 .02324 L
.17576 .02233 L
.18543 .02172 L
.19506 .02126 L
.20409 .02095 L
.21401 .0207 L
.21958 .0206 L
.22469 .02052 L
.22943 .02047 L
.23204 .02045 L
.2345 .02043 L
.23679 .02041 L
.23928 .0204 L
.24037 .0204 L
.24154 .02039 L
.2426 .02039 L
.24362 .02039 L
.2449 .02039 L
.24607 .02039 L
.24734 .02039 L
.24805 .02039 L
Mistroke
.24871 .02039 L
.24992 .02039 L
.25102 .02039 L
.25228 .02039 L
.25348 .0204 L
.25619 .02041 L
.25869 .02043 L
.26432 .02047 L
.27343 .02056 L
.27844 .0206 L
.2809 .02062 L
.28318 .02063 L
.28448 .02063 L
.28587 .02064 L
.28653 .02064 L
.28725 .02064 L
.28804 .02064 L
.28878 .02064 L
.29008 .02064 L
.29073 .02064 L
.29144 .02064 L
.29271 .02064 L
.29388 .02064 L
.29518 .02064 L
.29641 .02063 L
.29871 .02062 L
.30386 .02059 L
.31361 .0205 L
.32391 .0204 L
.34238 .02022 L
.35184 .02015 L
.36199 .02008 L
.37157 .02003 L
.38032 .02 L
.38511 .01998 L
.39021 .01997 L
.39938 .01995 L
.40446 .01995 L
.40924 .01994 L
.41448 .01994 L
.42013 .01993 L
.43975 .01992 L
.46124 .01991 L
.48174 .0199 L
.50083 .01989 L
.53984 .01985 L
.55973 .01984 L
.57021 .01983 L
.58131 .01983 L
.60208 .01982 L
Mistroke
.62126 .01982 L
.64081 .01981 L
.65911 .01981 L
.67766 .01981 L
.6979 .01981 L
.71905 .0198 L
.73915 .0198 L
.75884 .0198 L
.76984 .0198 L
.77981 .0198 L
.79908 .0198 L
.8199 .0198 L
.86092 .0198 L
.90043 .0198 L
.93842 .0198 L
.97619 .0198 L
Mfstroke
1 .901 0 r
.02381 .01472 m
.02605 .0354 L
.02729 .04528 L
.02846 .05331 L
.02954 .05955 L
.03072 .065 L
.0318 .06885 L
.03279 .07158 L
.03396 .07394 L
.03506 .07543 L
.03626 .07644 L
.03756 .07693 L
.03821 .07699 L
.03891 .07694 L
.0402 .0766 L
.04145 .07601 L
.04262 .07529 L
.04765 .07106 L
.05221 .06656 L
.06244 .05668 L
.07287 .0482 L
.08414 .04104 L
.09479 .03594 L
.10458 .03237 L
.11432 .02966 L
.1234 .02771 L
.13338 .02608 L
.14407 .02479 L
.15424 .02388 L
.16531 .02315 L
.17576 .02266 L
.18543 .02233 L
.19506 .02209 L
.20409 .02194 L
.20926 .02187 L
.21401 .02182 L
.21921 .02179 L
.22183 .02177 L
.22332 .02177 L
.22469 .02176 L
.22593 .02176 L
.22723 .02176 L
.22854 .02176 L
.22928 .02176 L
.22998 .02176 L
.23124 .02176 L
.23239 .02176 L
.23302 .02176 L
.23371 .02176 L
.23497 .02176 L
Mistroke
.2362 .02177 L
.23732 .02177 L
.23981 .02178 L
.24213 .0218 L
.24431 .02182 L
.24955 .02187 L
.25438 .02194 L
.25967 .02205 L
.26526 .02218 L
.27476 .02242 L
.27999 .02253 L
.28256 .02257 L
.28493 .0226 L
.28717 .02263 L
.28829 .02264 L
.28954 .02264 L
.29078 .02265 L
.29148 .02265 L
.29212 .02265 L
.2933 .02266 L
.29454 .02266 L
.29558 .02265 L
.2967 .02265 L
.29776 .02265 L
.29871 .02264 L
.30106 .02263 L
.30328 .02261 L
.30792 .02256 L
.31303 .0225 L
.32333 .02234 L
.3418 .02205 L
.36128 .02181 L
.37222 .0217 L
.38219 .02163 L
.39209 .02158 L
.40125 .02155 L
.40603 .02153 L
.41131 .02152 L
.422 .0215 L
.46217 .02144 L
.50083 .02137 L
.52085 .02134 L
.53091 .02133 L
.54194 .02132 L
.55201 .02131 L
.56152 .0213 L
.57249 .0213 L
.58247 .0213 L
.59217 .02129 L
.59707 .02129 L
Mistroke
.60245 .02129 L
.60704 .02129 L
.60962 .02129 L
.61198 .02129 L
.61417 .02129 L
.61541 .02129 L
.61655 .02129 L
.61766 .02129 L
.61866 .02129 L
.61981 .02129 L
.6209 .02129 L
.62206 .02129 L
.62331 .02129 L
.62449 .02129 L
.62556 .02129 L
.62682 .02129 L
.62819 .02129 L
.63067 .02129 L
.63603 .02129 L
.64099 .02129 L
.64995 .02129 L
.65947 .02129 L
.69724 .0213 L
.73746 .02131 L
.77617 .02131 L
.81733 .02132 L
.85698 .02132 L
.8951 .02133 L
.93568 .02133 L
.97475 .02133 L
.97619 .02133 L
Mfstroke
1 .925 0 r
.02381 .01472 m
.02846 .05776 L
.03279 .09335 L
.03754 .12456 L
.0402 .13748 L
.04262 .14613 L
.04385 .14941 L
.04516 .15209 L
.04627 .15377 L
.0475 .155 L
.04882 .15566 L
.04957 .15577 L
.05024 .1557 L
.05156 .15519 L
.05281 .15428 L
.05397 .15312 L
.0552 .15159 L
.05742 .14823 L
.06244 .13875 L
.07287 .11662 L
.08414 .09486 L
.09388 .07949 L
.10458 .06618 L
.11511 .05616 L
.12624 .04823 L
.13654 .04274 L
.14616 .03887 L
.15661 .03571 L
.16651 .03348 L
.1754 .03197 L
.18507 .03073 L
.19447 .02984 L
.20484 .02914 L
.21006 .02888 L
.21568 .02865 L
.22099 .0285 L
.22354 .02844 L
.22585 .02839 L
.22813 .02836 L
.23059 .02833 L
.23195 .02832 L
.2332 .02831 L
.23439 .0283 L
.23566 .0283 L
.23674 .0283 L
.2379 .0283 L
.239 .0283 L
.24 .02831 L
.24117 .02832 L
.24245 .02833 L
Mistroke
.24478 .02836 L
.24751 .02841 L
.24998 .02846 L
.25552 .02864 L
.26065 .02886 L
.26548 .02912 L
.27527 .02969 L
.28061 .02997 L
.28322 .03007 L
.28559 .03015 L
.28664 .03017 L
.28778 .0302 L
.28877 .03022 L
.28985 .03024 L
.291 .03025 L
.29222 .03026 L
.29335 .03026 L
.29441 .03026 L
.2956 .03026 L
.29684 .03025 L
.29791 .03024 L
.29907 .03023 L
.30167 .03018 L
.30408 .03012 L
.30915 .02997 L
.31463 .02977 L
.32458 .02935 L
.34318 .02859 L
.36309 .02797 L
.37313 .02775 L
.37878 .02765 L
.38415 .02758 L
.38903 .02752 L
.39434 .02747 L
.39916 .02743 L
.40363 .0274 L
.40612 .02739 L
.40845 .02739 L
.41101 .02738 L
.41245 .02738 L
.41377 .02737 L
.41506 .02737 L
.41627 .02737 L
.41696 .02737 L
.4176 .02737 L
.41832 .02737 L
.41901 .02737 L
.41968 .02737 L
.42039 .02737 L
.42166 .02737 L
Mistroke
.42237 .02737 L
.42303 .02737 L
.42454 .02737 L
.42712 .02738 L
.42951 .02738 L
.43493 .0274 L
.4448 .02744 L
.45371 .02748 L
.45839 .0275 L
.46333 .02751 L
.46596 .02752 L
.46884 .02753 L
.47011 .02753 L
.47146 .02753 L
.47273 .02753 L
.47391 .02753 L
.47519 .02753 L
.47587 .02753 L
.47659 .02753 L
.47779 .02753 L
.47848 .02753 L
.47912 .02753 L
.48031 .02753 L
.48141 .02753 L
.48261 .02753 L
.48387 .02753 L
.4861 .02753 L
.48848 .02752 L
.49276 .02751 L
.49786 .02749 L
.50248 .02747 L
.54248 .02723 L
.56082 .02712 L
.58097 .02703 L
.60086 .02696 L
.62191 .02691 L
.64137 .02688 L
.66227 .02685 L
.68346 .02683 L
.70356 .02681 L
.74183 .02679 L
.78255 .02677 L
.82175 .02676 L
.8634 .02675 L
.90354 .02674 L
.94216 .02673 L
.97619 .02673 L
Mfstroke
1 .949 0 r
.02381 .01472 m
.02499 .02578 L
.02605 .0348 L
.02721 .04283 L
.02846 .04931 L
.02961 .05339 L
.03068 .05584 L
.0317 .05728 L
.03279 .05813 L
.03395 .05847 L
.0352 .05839 L
.03638 .05803 L
.03746 .05752 L
.04011 .05586 L
.04262 .05398 L
.06244 .03955 L
.07289 .03404 L
.08259 .03013 L
.09323 .02689 L
.10458 .02437 L
.11487 .0227 L
.12599 .02138 L
.1365 .02047 L
.14616 .01985 L
.1559 .01939 L
.16499 .01906 L
.17496 .01879 L
.18565 .01858 L
.19582 .01844 L
.20157 .01838 L
.20689 .01834 L
.21192 .0183 L
.21665 .01828 L
.22157 .01826 L
.22419 .01825 L
.22701 .01824 L
.22941 .01824 L
.23073 .01823 L
.23197 .01823 L
.23313 .01823 L
.23439 .01823 L
.23553 .01823 L
.23658 .01823 L
.23783 .01823 L
.239 .01823 L
.24029 .01823 L
.24101 .01823 L
.24167 .01823 L
.24299 .01823 L
.24443 .01824 L
Mistroke
.24705 .01824 L
.24983 .01825 L
.25235 .01826 L
.258 .01829 L
.26815 .01836 L
.27753 .01843 L
.28226 .01845 L
.28494 .01846 L
.28744 .01847 L
.28885 .01847 L
.29018 .01848 L
.29138 .01848 L
.29268 .01848 L
.29335 .01848 L
.29409 .01848 L
.29487 .01848 L
.2956 .01848 L
.2969 .01848 L
.29762 .01848 L
.29829 .01848 L
.30062 .01847 L
.30316 .01847 L
.30827 .01845 L
.31857 .0184 L
.32792 .01835 L
.34888 .01825 L
.36811 .01818 L
.37894 .01815 L
.38892 .01813 L
.39361 .01812 L
.39864 .01811 L
.40772 .0181 L
.41326 .0181 L
.41852 .0181 L
.42837 .01809 L
.44657 .01808 L
.45693 .01808 L
.46667 .01807 L
.48642 .01806 L
.50742 .01804 L
.52758 .01803 L
.54607 .01802 L
.55586 .01802 L
.56497 .01802 L
.57561 .01801 L
.58567 .01801 L
.59547 .01801 L
.6061 .01801 L
.61576 .01801 L
.62468 .01801 L
Mistroke
.63371 .01801 L
.64342 .01801 L
.65407 .01801 L
.66405 .01801 L
.67416 .01801 L
.67989 .01801 L
.6852 .01801 L
.6903 .01801 L
.69493 .01801 L
.69749 .01801 L
.70027 .01801 L
.70154 .01801 L
.70289 .01801 L
.70414 .01801 L
.70529 .01801 L
.70652 .01801 L
.70716 .01801 L
.70784 .01801 L
.70899 .01801 L
.71026 .01801 L
.71138 .01801 L
.71259 .01801 L
.71373 .01801 L
.71478 .01801 L
.71715 .01801 L
.71973 .01801 L
.72495 .01801 L
.72954 .01801 L
.73445 .01801 L
.74329 .01801 L
.76465 .01801 L
.7848 .01801 L
.82329 .01801 L
.86423 .01801 L
.90365 .01801 L
.94156 .01801 L
.97619 .01801 L
Mfstroke
1 .972 0 r
.02381 .01472 m
.02846 .05736 L
.03279 .08982 L
.03527 .10368 L
.03754 .1129 L
.03879 .11665 L
.03945 .11827 L
.04015 .11972 L
.04143 .12175 L
.04262 .12295 L
.04384 .1236 L
.04496 .12374 L
.04626 .12345 L
.04749 .12278 L
.04862 .12189 L
.04967 .12086 L
.05205 .11799 L
.06244 .10153 L
.07382 .08356 L
.08454 .06955 L
.09417 .05955 L
.10458 .05112 L
.11449 .04497 L
.12496 .04004 L
.1339 .03682 L
.14371 .03409 L
.15391 .03196 L
.16322 .0305 L
.17396 .02924 L
.18413 .02838 L
.19379 .02779 L
.19866 .02756 L
.20404 .02735 L
.20862 .0272 L
.21354 .02708 L
.2182 .02699 L
.22039 .02696 L
.22246 .02693 L
.22365 .02692 L
.22495 .02691 L
.22602 .0269 L
.2272 .02689 L
.22848 .02689 L
.22918 .02689 L
.22984 .02688 L
.23101 .02688 L
.23227 .02688 L
.23344 .02689 L
.23471 .02689 L
.23592 .0269 L
Mistroke
.23703 .0269 L
.23914 .02692 L
.24139 .02695 L
.24408 .02699 L
.24698 .02705 L
.25225 .0272 L
.25738 .02739 L
.26209 .02762 L
.27197 .0282 L
.27741 .02852 L
.28008 .02866 L
.28255 .02877 L
.28483 .02886 L
.28734 .02893 L
.28986 .02899 L
.29124 .02901 L
.29253 .02903 L
.29365 .02904 L
.29482 .02904 L
.29582 .02904 L
.29691 .02904 L
.2981 .02904 L
.29936 .02903 L
.30055 .02902 L
.30163 .029 L
.30401 .02897 L
.30652 .02891 L
.31102 .0288 L
.3212 .02845 L
.33965 .02776 L
.35949 .02712 L
.36816 .0269 L
.37759 .02671 L
.38759 .02655 L
.39708 .02644 L
.40234 .02639 L
.40793 .02635 L
.41271 .02633 L
.41798 .0263 L
.42289 .02629 L
.42806 .02628 L
.43247 .02627 L
.43731 .02626 L
.44822 .02625 L
.45815 .02623 L
.46298 .02621 L
.46822 .0262 L
.47774 .02616 L
.49868 .02606 L
.51814 .02596 L
Mistroke
.53957 .02587 L
.54937 .02583 L
.5599 .0258 L
.57894 .02576 L
.58905 .02575 L
.60009 .02573 L
.62018 .02571 L
.63987 .0257 L
.66085 .02569 L
.68084 .02568 L
.70245 .02567 L
.72157 .02566 L
.74254 .02566 L
.76249 .02565 L
.78356 .02565 L
.80309 .02565 L
.82401 .02565 L
.84526 .02564 L
.86539 .02564 L
.88531 .02564 L
.90374 .02564 L
.91337 .02564 L
.92241 .02564 L
.93233 .02564 L
.93791 .02564 L
.94302 .02564 L
.94699 .02564 L
.94921 .02564 L
.95123 .02564 L
.95312 .02564 L
.95418 .02564 L
.95516 .02564 L
.95602 .02564 L
.95696 .02564 L
.95795 .02564 L
.95887 .02564 L
.95994 .02564 L
.96111 .02564 L
.96221 .02564 L
.96323 .02564 L
.96516 .02564 L
.96722 .02564 L
.97193 .02564 L
.97619 .02564 L
Mfstroke
1 .996 0 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01955 L
.05285 .01838 L
.06244 .01753 L
.07218 .01688 L
.0829 .01635 L
.09334 .01598 L
.10458 .01568 L
.11468 .01549 L
.12571 .01534 L
.13613 .01524 L
.1458 .01517 L
.15637 .01512 L
.16633 .01508 L
.17526 .01505 L
.18493 .01503 L
.19444 .01502 L
.20487 .01501 L
.21013 .015 L
.21577 .015 L
.22594 .01499 L
.23122 .01499 L
.23611 .01499 L
.24137 .01498 L
.24718 .01498 L
.25221 .01498 L
.25693 .01498 L
.26192 .01498 L
.2673 .01498 L
.30844 .01498 L
.32896 .01498 L
.33897 .01498 L
.34806 .01497 L
.3569 .01497 L
.36649 .01497 L
.37175 .01497 L
.37661 .01497 L
.38161 .01497 L
.38617 .01497 L
.39084 .01497 L
.39325 .01497 L
.39586 .01497 L
.39828 .01497 L
Mistroke
.40052 .01497 L
.40266 .01497 L
.40376 .01497 L
.40493 .01497 L
.4056 .01497 L
.40633 .01497 L
.40762 .01497 L
.40834 .01497 L
.40912 .01497 L
.40985 .01497 L
.41051 .01497 L
.41181 .01497 L
.41254 .01497 L
.41321 .01497 L
.41445 .01497 L
.41577 .01497 L
.41817 .01497 L
.42043 .01497 L
.42557 .01497 L
.43543 .01497 L
.4458 .01497 L
.4555 .01497 L
.46431 .01497 L
.46668 .01497 L
.46924 .01497 L
.47145 .01497 L
.47388 .01497 L
.47647 .01497 L
.47788 .01497 L
.4792 .01497 L
.48043 .01497 L
.48156 .01497 L
.48286 .01497 L
.48409 .01497 L
.48515 .01497 L
.48631 .01497 L
.48752 .01497 L
.48866 .01497 L
.49289 .01497 L
.4953 .01497 L
.4975 .01497 L
.50247 .01497 L
.51226 .01497 L
.52137 .01497 L
.54207 .01497 L
.56078 .01497 L
.58108 .01497 L
.6024 .01497 L
.62254 .01497 L
.66343 .01497 L
Mistroke
.7028 .01497 L
.74066 .01497 L
.78096 .01497 L
.81976 .01497 L
.861 .01497 L
.90073 .01497 L
.93894 .01497 L
.97619 .01497 L
Mfstroke
.98 1 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03478 L
.02721 .04273 L
.02846 .04903 L
.02961 .05285 L
.03068 .05503 L
.0317 .05621 L
.03279 .05679 L
.03395 .05688 L
.0352 .05656 L
.03638 .056 L
.03746 .05535 L
.04262 .05133 L
.0529 .04298 L
.06244 .03658 L
.07277 .03124 L
.08405 .02693 L
.09398 .02414 L
.10458 .02194 L
.11487 .02038 L
.12599 .01916 L
.1365 .01832 L
.14616 .01776 L
.1559 .01734 L
.16499 .01704 L
.17496 .0168 L
.18565 .01661 L
.19582 .01648 L
.20119 .01643 L
.20689 .01638 L
.21186 .01635 L
.21734 .01631 L
.22701 .01627 L
.23193 .01626 L
.2371 .01624 L
.24152 .01623 L
.24636 .01623 L
.24909 .01622 L
.25158 .01622 L
.25296 .01622 L
.25445 .01622 L
.25586 .01622 L
.25716 .01622 L
.25836 .01622 L
.25949 .01622 L
.26072 .01622 L
.26141 .01622 L
.26204 .01622 L
.26331 .01622 L
Mistroke
.26403 .01622 L
.2647 .01622 L
.26721 .01622 L
.27231 .01622 L
.27498 .01622 L
.27645 .01622 L
.27781 .01622 L
.27911 .01622 L
.28029 .01622 L
.2816 .01622 L
.28232 .01622 L
.283 .01622 L
.28419 .01622 L
.28529 .01622 L
.2865 .01622 L
.28778 .01622 L
.28893 .01622 L
.28998 .01622 L
.29235 .01622 L
.29663 .01622 L
.30139 .01621 L
.3064 .01621 L
.3264 .01618 L
.34456 .01616 L
.35399 .01615 L
.36421 .01614 L
.375 .01614 L
.38026 .01614 L
.38517 .01613 L
.39466 .01613 L
.39969 .01613 L
.40508 .01613 L
.41074 .01613 L
.41609 .01613 L
.42614 .01613 L
.46444 .01612 L
.50519 .01612 L
.52542 .01612 L
.54442 .01612 L
.56257 .01611 L
.58214 .01611 L
.5917 .01611 L
.60216 .01611 L
.62325 .01611 L
.64283 .01611 L
.66378 .01611 L
.6851 .01611 L
.70524 .01611 L
.71495 .01611 L
.72523 .01611 L
Mistroke
.73487 .01611 L
.74368 .01611 L
.7531 .01611 L
.75794 .01611 L
.76323 .01611 L
.76809 .01611 L
.77261 .01611 L
.77726 .01611 L
.78153 .01611 L
.78661 .01611 L
.78923 .01611 L
.79211 .01611 L
.79695 .01611 L
.7996 .01611 L
.80207 .01611 L
.80448 .01611 L
.80567 .01611 L
.80677 .01611 L
.80775 .01611 L
.80882 .01611 L
.8099 .01611 L
.81105 .01611 L
.8123 .01611 L
.81344 .01611 L
.8147 .01611 L
.81602 .01611 L
.81717 .01611 L
.81825 .01611 L
.82068 .01611 L
.82574 .01611 L
.83121 .01611 L
.84115 .01611 L
.85975 .01611 L
.90068 .01611 L
.94011 .01611 L
.97619 .01611 L
Mfstroke
.957 1 0 r
.02381 .01472 m
.02846 .05727 L
.03279 .08934 L
.03527 .10304 L
.03754 .11233 L
.03879 .11624 L
.04015 .11957 L
.04143 .12192 L
.04262 .12348 L
.04376 .12448 L
.04498 .12509 L
.04614 .12527 L
.0472 .12514 L
.04843 .12468 L
.04913 .1243 L
.04978 .12387 L
.05224 .12171 L
.05718 .11566 L
.06244 .10801 L
.07287 .09258 L
.08414 .07797 L
.09388 .0677 L
.10458 .05876 L
.11511 .05198 L
.12624 .04656 L
.13654 .04279 L
.14616 .04011 L
.15661 .03792 L
.16651 .03637 L
.1754 .03532 L
.18507 .03448 L
.19447 .03389 L
.19982 .03365 L
.20484 .03347 L
.20741 .03339 L
.21012 .03332 L
.21246 .03328 L
.21495 .03324 L
.21637 .03322 L
.21765 .03321 L
.21894 .0332 L
.22016 .03319 L
.22085 .03319 L
.22158 .03319 L
.22289 .03318 L
.22362 .03318 L
.2243 .03319 L
.22505 .03319 L
.22585 .03319 L
.22654 .0332 L
Mistroke
.22719 .0332 L
.2284 .03321 L
.2297 .03323 L
.23111 .03325 L
.23365 .03329 L
.23598 .03335 L
.24136 .03353 L
.24406 .03365 L
.24703 .0338 L
.25205 .03415 L
.25743 .03464 L
.26713 .03583 L
.27733 .0372 L
.28012 .03751 L
.28309 .03778 L
.28562 .03796 L
.28698 .03804 L
.28841 .0381 L
.28966 .03815 L
.29032 .03817 L
.29102 .03819 L
.29226 .03821 L
.29341 .03823 L
.29411 .03823 L
.29487 .03823 L
.29558 .03823 L
.29624 .03822 L
.29748 .03821 L
.2988 .03818 L
.29996 .03815 L
.3012 .03812 L
.30344 .03803 L
.30854 .03777 L
.32833 .03633 L
.34987 .0348 L
.35989 .03423 L
.37054 .03375 L
.37964 .03342 L
.38968 .03316 L
.39459 .03305 L
.39976 .03296 L
.40901 .03285 L
.41416 .0328 L
.41896 .03276 L
.42986 .0327 L
.44857 .0326 L
.46887 .03251 L
.47996 .03247 L
.49019 .03244 L
.51033 .0324 L
Mistroke
.53067 .03237 L
.5497 .03234 L
.55906 .03233 L
.56795 .03232 L
.57285 .03231 L
.57562 .03231 L
.57819 .03231 L
.57942 .03231 L
.58057 .03231 L
.58162 .03231 L
.58273 .03231 L
.58394 .03231 L
.58505 .03231 L
.58625 .03231 L
.58756 .03231 L
.58887 .03231 L
.59007 .03231 L
.5914 .03231 L
.59281 .03231 L
.59517 .03231 L
.59777 .03231 L
.60258 .03232 L
.60708 .03232 L
.61715 .03233 L
.628 .03235 L
.66916 .03245 L
.70881 .03255 L
.74694 .03261 L
.78752 .03266 L
.82658 .0327 L
.8681 .03274 L
.9081 .03277 L
.94659 .03279 L
.97619 .0328 L
Mfstroke
.933 1 0 r
.02381 .01472 m
.03279 .0944 L
.04262 .16159 L
.04758 .18557 L
.05035 .19584 L
.05288 .20323 L
.05524 .20849 L
.05648 .21065 L
.0578 .21251 L
.05895 .21378 L
.06021 .21482 L
.06137 .21544 L
.06244 .21577 L
.0631 .21585 L
.06379 .21585 L
.06504 .21562 L
.06581 .21534 L
.06653 .21499 L
.06788 .21412 L
.07036 .21185 L
.07305 .20857 L
.08274 .19218 L
.10458 .14997 L
.12452 .11984 L
.13456 .10859 L
.14558 .09886 L
.15579 .09193 L
.16509 .08703 L
.17583 .08279 L
.18067 .08129 L
.18601 .07991 L
.19065 .07891 L
.19566 .07803 L
.20095 .07732 L
.20332 .07707 L
.20592 .07685 L
.20834 .07668 L
.2106 .07656 L
.21185 .07651 L
.21298 .07648 L
.21429 .07645 L
.21553 .07643 L
.21659 .07643 L
.21773 .07644 L
.21869 .07645 L
.21975 .07647 L
.2209 .07651 L
.22212 .07656 L
.22434 .07668 L
.22688 .07687 L
Mistroke
.22959 .07715 L
.23447 .07785 L
.23745 .07842 L
.24026 .07908 L
.24551 .08068 L
.25055 .08279 L
.25517 .08537 L
.26025 .08906 L
.26561 .09397 L
.27512 .10401 L
.28034 .10893 L
.28292 .11091 L
.28529 .11242 L
.28752 .11355 L
.28989 .11444 L
.29112 .11478 L
.29227 .11502 L
.29353 .11521 L
.29424 .11528 L
.29489 .11532 L
.29595 .11535 L
.29693 .11532 L
.29801 .11525 L
.29916 .11512 L
.30037 .11493 L
.30151 .1147 L
.30364 .11415 L
.30828 .11252 L
.31338 .1102 L
.32369 .10466 L
.34216 .09469 L
.36164 .08653 L
.37257 .08325 L
.38255 .08101 L
.38734 .08017 L
.39245 .07943 L
.39685 .07891 L
.40161 .07846 L
.40426 .07827 L
.40669 .07812 L
.40917 .07799 L
.41147 .0779 L
.414 .07783 L
.41534 .0778 L
.41677 .07777 L
.41749 .07776 L
.41828 .07775 L
.41902 .07775 L
.4197 .07774 L
.42099 .07774 L
Mistroke
.42164 .07774 L
.42236 .07775 L
.42365 .07775 L
.42485 .07777 L
.42616 .07779 L
.42756 .07781 L
.43016 .07788 L
.43251 .07795 L
.43729 .07815 L
.44178 .07839 L
.46267 .07992 L
.47244 .08065 L
.47778 .08099 L
.48276 .08126 L
.48702 .08145 L
.49157 .08159 L
.49417 .08165 L
.49545 .08168 L
.49663 .08169 L
.49768 .08171 L
.49884 .08172 L
.5 .08173 L
.50124 .08173 L
.50246 .08173 L
.50359 .08173 L
.50483 .08173 L
.50553 .08172 L
.50616 .08172 L
.50744 .08171 L
.50883 .08169 L
.51134 .08165 L
.51616 .08154 L
.5206 .0814 L
.53074 .081 L
.54146 .0805 L
.56128 .07953 L
.57937 .07878 L
.58936 .07846 L
.59883 .07822 L
.60883 .07803 L
.61449 .07794 L
.61973 .07788 L
.62483 .07783 L
.63033 .07779 L
.63553 .07776 L
.64031 .07774 L
.64463 .07773 L
.64937 .07772 L
.65432 .07771 L
.65893 .0777 L
Mistroke
.66942 .07769 L
.67458 .07768 L
.67934 .07767 L
.68824 .07765 L
.69791 .07761 L
.70757 .07757 L
.71663 .07752 L
.73725 .07738 L
.77601 .07706 L
.81722 .07673 L
.85692 .07643 L
.8951 .07615 L
.93573 .07584 L
.97485 .07556 L
.97619 .07555 L
Mfstroke
.909 1 0 r
.02381 .01472 m
.03279 .09402 L
.03793 .13061 L
.04262 .15664 L
.045 .16704 L
.04758 .17618 L
.04899 .18029 L
.0503 .18352 L
.05164 .18627 L
.05288 .1884 L
.05404 .18998 L
.05509 .19113 L
.05626 .19209 L
.05752 .19276 L
.05873 .19309 L
.06005 .19312 L
.06129 .19286 L
.06244 .19238 L
.06311 .19201 L
.06382 .19155 L
.06509 .19056 L
.06795 .18763 L
.07314 .18051 L
.08284 .16399 L
.10458 .12751 L
.11406 .1147 L
.12422 .10335 L
.13374 .09475 L
.14255 .08834 L
.15272 .08248 L
.16379 .07767 L
.17355 .07453 L
.17895 .07316 L
.18391 .07211 L
.19328 .0706 L
.1982 .07004 L
.20071 .06981 L
.20338 .06961 L
.20575 .06947 L
.20791 .06937 L
.20894 .06933 L
.21007 .06929 L
.21113 .06927 L
.21211 .06925 L
.21325 .06923 L
.21432 .06923 L
.21549 .06923 L
.21675 .06924 L
.21807 .06926 L
.21932 .0693 L
Mistroke
.22044 .06933 L
.22166 .06938 L
.22423 .06952 L
.22699 .06973 L
.22961 .06998 L
.23201 .07027 L
.23657 .07097 L
.24137 .07198 L
.24656 .07347 L
.25139 .07535 L
.25669 .07811 L
.26236 .08203 L
.27256 .09106 L
.27794 .09573 L
.28088 .09789 L
.28364 .09959 L
.28604 .10076 L
.28862 .10171 L
.29001 .10209 L
.29078 .10226 L
.29148 .10239 L
.29274 .10257 L
.2934 .10264 L
.29411 .10269 L
.29536 .10273 L
.29606 .10273 L
.29671 .10271 L
.29791 .10263 L
.29917 .1025 L
.30031 .10234 L
.30137 .10215 L
.30377 .10161 L
.30877 .10007 L
.31421 .09795 L
.3241 .09347 L
.34265 .08515 L
.3624 .0783 L
.37238 .07578 L
.3834 .07368 L
.38831 .07296 L
.39348 .07233 L
.39795 .07188 L
.40272 .07149 L
.40788 .07117 L
.41268 .07095 L
.41561 .07085 L
.41838 .07077 L
.42087 .07071 L
.42357 .07067 L
.42592 .07064 L
Mistroke
.42724 .07063 L
.42845 .07063 L
.42957 .07062 L
.43079 .07062 L
.43195 .07062 L
.43302 .07062 L
.43367 .07062 L
.43438 .07063 L
.43566 .07063 L
.43691 .07064 L
.43806 .07066 L
.44067 .07069 L
.44342 .07074 L
.44861 .07087 L
.45345 .07102 L
.46446 .07149 L
.48311 .07244 L
.49294 .0729 L
.50339 .07327 L
.50864 .07341 L
.51143 .07347 L
.51443 .07353 L
.51718 .07357 L
.5197 .0736 L
.52211 .07362 L
.52344 .07363 L
.52464 .07363 L
.52588 .07364 L
.52705 .07364 L
.52829 .07365 L
.52898 .07365 L
.52962 .07365 L
.5307 .07365 L
.53187 .07365 L
.5331 .07365 L
.53426 .07364 L
.53562 .07364 L
.5369 .07363 L
.53932 .07362 L
.54477 .07358 L
.55512 .07349 L
.56485 .0734 L
.57359 .07333 L
.57599 .07331 L
.57851 .0733 L
.58067 .07329 L
.58303 .07328 L
.58436 .07328 L
.58561 .07328 L
.58674 .07328 L
Mistroke
.58796 .07328 L
.5886 .07328 L
.5893 .07328 L
.59003 .07328 L
.59071 .07328 L
.59193 .07328 L
.59324 .07328 L
.59446 .07329 L
.59579 .07329 L
.59821 .0733 L
.60276 .07333 L
.60803 .07338 L
.61364 .07344 L
.62375 .0736 L
.66532 .07447 L
.68618 .07488 L
.69533 .07502 L
.70537 .07516 L
.71442 .07526 L
.72411 .07534 L
.73435 .07541 L
.74391 .07546 L
.75408 .07549 L
.75983 .07551 L
.76514 .07552 L
.77017 .07553 L
.7749 .07553 L
.77982 .07554 L
.78264 .07554 L
.78526 .07554 L
.78772 .07554 L
.78995 .07554 L
.79243 .07554 L
.7938 .07554 L
.79509 .07555 L
.79634 .07555 L
.79697 .07555 L
.79767 .07555 L
.7989 .07555 L
.80005 .07555 L
.80075 .07555 L
.80141 .07555 L
.80265 .07555 L
.80398 .07554 L
.80543 .07554 L
.80787 .07554 L
.81008 .07554 L
.81503 .07554 L
.81962 .07554 L
.82394 .07553 L
Mistroke
.83372 .07552 L
.84404 .07551 L
.86253 .07547 L
.88219 .07541 L
.90054 .07534 L
.93949 .07517 L
.97619 .07498 L
Mfstroke
.885 1 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04314 L
.02846 .04881 L
.02954 .05227 L
.03053 .05426 L
.03163 .05546 L
.03279 .05597 L
.03395 .05595 L
.0352 .05555 L
.03638 .05493 L
.03746 .05423 L
.04262 .05015 L
.0529 .04192 L
.06244 .0357 L
.07277 .03053 L
.08405 .02637 L
.09398 .02369 L
.10458 .02159 L
.11487 .02009 L
.12599 .01892 L
.1365 .01813 L
.14616 .01759 L
.1559 .01718 L
.16499 .0169 L
.17496 .01667 L
.18565 .01649 L
.19582 .01637 L
.20119 .01632 L
.20689 .01627 L
.21186 .01624 L
.21734 .01621 L
.22701 .01617 L
.23193 .01615 L
.2371 .01614 L
.24152 .01613 L
.24636 .01613 L
.24909 .01612 L
.25158 .01612 L
.25296 .01612 L
.25445 .01612 L
.25574 .01612 L
.25716 .01612 L
.25847 .01612 L
.2597 .01612 L
.261 .01612 L
.26173 .01612 L
.26239 .01612 L
.26358 .01612 L
Mistroke
.26487 .01612 L
.26608 .01612 L
.26721 .01612 L
.27231 .01612 L
.27498 .01612 L
.27645 .01612 L
.27781 .01612 L
.27901 .01612 L
.28029 .01612 L
.28102 .01612 L
.28171 .01612 L
.283 .01612 L
.28419 .01612 L
.28529 .01612 L
.2865 .01612 L
.28778 .01612 L
.28998 .01612 L
.29235 .01612 L
.29663 .01611 L
.30173 .01611 L
.3064 .01611 L
.32696 .01608 L
.34607 .01606 L
.35557 .01606 L
.36453 .01605 L
.37486 .01604 L
.38423 .01604 L
.38888 .01604 L
.39398 .01604 L
.39655 .01604 L
.39931 .01604 L
.40169 .01604 L
.40429 .01604 L
.40686 .01604 L
.40924 .01604 L
.41152 .01604 L
.41267 .01604 L
.41394 .01604 L
.41508 .01604 L
.41613 .01604 L
.41727 .01604 L
.41848 .01604 L
.41954 .01604 L
.42052 .01604 L
.4216 .01604 L
.42275 .01604 L
.42533 .01604 L
.42807 .01604 L
.43298 .01604 L
.44407 .01604 L
Mistroke
.45378 .01604 L
.45913 .01604 L
.46177 .01604 L
.46422 .01604 L
.46658 .01604 L
.46779 .01604 L
.4691 .01604 L
.46985 .01604 L
.47054 .01604 L
.4712 .01604 L
.4719 .01604 L
.4731 .01604 L
.47379 .01604 L
.47443 .01604 L
.47564 .01604 L
.47679 .01604 L
.47782 .01604 L
.47894 .01604 L
.48145 .01604 L
.48377 .01604 L
.48799 .01604 L
.49264 .01604 L
.50207 .01604 L
.54229 .01603 L
.56079 .01603 L
.581 .01603 L
.60106 .01603 L
.62216 .01603 L
.64179 .01603 L
.66274 .01602 L
.70426 .01602 L
.74426 .01602 L
.78275 .01602 L
.82369 .01602 L
.86311 .01602 L
.90102 .01602 L
.94138 .01602 L
.97619 .01602 L
Mfstroke
.862 1 0 r
.02381 .01472 m
.02499 .02568 L
.02605 .03419 L
.02729 .04139 L
.02846 .04559 L
.02954 .04774 L
.03053 .04874 L
.03163 .04913 L
.03279 .04906 L
.03395 .04867 L
.0352 .04804 L
.03746 .04661 L
.04262 .0429 L
.0521 .03653 L
.06244 .03103 L
.07373 .0266 L
.08445 .02354 L
.09489 .02137 L
.10458 .01988 L
.11515 .01869 L
.1251 .01787 L
.13404 .01732 L
.14371 .01687 L
.15321 .01654 L
.16365 .01628 L
.17454 .01608 L
.18471 .01594 L
.19516 .01584 L
.20506 .01578 L
.21395 .01573 L
.22362 .01569 L
.23302 .01567 L
.23837 .01566 L
.2434 .01565 L
.24867 .01564 L
.25351 .01564 L
.25881 .01564 L
.26148 .01564 L
.2644 .01563 L
.27533 .01563 L
.2807 .01563 L
.28565 .01563 L
.29016 .01563 L
.29492 .01563 L
.30496 .01562 L
.32514 .01561 L
.335 .0156 L
.34401 .0156 L
.35275 .01559 L
.36227 .01559 L
Mistroke
.37234 .01559 L
.3819 .01559 L
.38723 .01559 L
.39224 .01558 L
.39674 .01558 L
.40161 .01558 L
.40415 .01558 L
.40693 .01558 L
.40833 .01558 L
.40911 .01558 L
.40984 .01558 L
.41052 .01558 L
.41125 .01558 L
.41255 .01558 L
.41375 .01558 L
.41444 .01558 L
.41508 .01558 L
.41637 .01558 L
.4171 .01558 L
.41777 .01558 L
.42012 .01558 L
.42259 .01558 L
.42761 .01558 L
.43216 .01558 L
.44238 .01559 L
.45131 .01559 L
.46076 .01559 L
.46552 .01559 L
.46805 .01559 L
.47076 .01559 L
.47204 .01559 L
.47325 .01559 L
.47443 .01559 L
.47553 .01559 L
.47656 .01559 L
.47766 .01559 L
.47876 .01559 L
.47998 .01559 L
.48129 .01559 L
.48195 .01559 L
.48267 .01559 L
.48395 .01559 L
.48514 .01559 L
.48783 .01559 L
.49071 .01559 L
.49599 .01559 L
.50079 .01559 L
.51995 .01558 L
.54074 .01558 L
.5602 .01558 L
Mistroke
.58163 .01558 L
.60196 .01558 L
.621 .01558 L
.65979 .01558 L
.70103 .01558 L
.74076 .01558 L
.77897 .01558 L
.81964 .01558 L
.85879 .01558 L
.90039 .01558 L
.94048 .01558 L
.97619 .01558 L
Mfstroke
.838 1 0 r
.02381 .01472 m
.02846 .05719 L
.03068 .07452 L
.03279 .08804 L
.03398 .09426 L
.03527 .09976 L
.03645 .10365 L
.03754 .10636 L
.03871 .1084 L
.04 .10972 L
.04065 .11006 L
.04135 .11021 L
.04262 .11002 L
.04393 .10927 L
.04516 .10819 L
.04793 .10476 L
.05297 .09674 L
.06244 .08082 L
.07295 .06561 L
.08284 .05432 L
.09424 .04448 L
.10458 .03788 L
.11434 .03321 L
.12466 .02952 L
.13346 .02714 L
.14313 .02516 L
.15334 .02359 L
.16264 .02253 L
.17338 .02162 L
.18355 .021 L
.19321 .02057 L
.20346 .02023 L
.21222 .02003 L
.22188 .01987 L
.2268 .01981 L
.23198 .01976 L
.2364 .01973 L
.2389 .01972 L
.24123 .01971 L
.24254 .01971 L
.24322 .0197 L
.24395 .0197 L
.24458 .0197 L
.24528 .0197 L
.24651 .0197 L
.24771 .0197 L
.24899 .0197 L
.25021 .0197 L
.25131 .0197 L
.25198 .0197 L
Mistroke
.25269 .0197 L
.25396 .01971 L
.25684 .01972 L
.25959 .01973 L
.26209 .01975 L
.27147 .01981 L
.2766 .01985 L
.28137 .01988 L
.28387 .01989 L
.28528 .01989 L
.28655 .0199 L
.28723 .0199 L
.28795 .0199 L
.28874 .0199 L
.28947 .0199 L
.29078 .0199 L
.29153 .0199 L
.29223 .0199 L
.29345 .0199 L
.29474 .0199 L
.29584 .01989 L
.29703 .01989 L
.29972 .01988 L
.30221 .01987 L
.31276 .0198 L
.3227 .01972 L
.3413 .01957 L
.35105 .01951 L
.36136 .01945 L
.37101 .01941 L
.37982 .01938 L
.38928 .01936 L
.3945 .01935 L
.39944 .01934 L
.40399 .01934 L
.40821 .01933 L
.41041 .01933 L
.41284 .01933 L
.41406 .01933 L
.41538 .01933 L
.4166 .01933 L
.41776 .01933 L
.41901 .01933 L
.42015 .01933 L
.42138 .01933 L
.42207 .01933 L
.42271 .01933 L
.42377 .01933 L
.42495 .01933 L
.42617 .01933 L
Mistroke
.42732 .01933 L
.42995 .01933 L
.43236 .01933 L
.43778 .01933 L
.44872 .01934 L
.45404 .01934 L
.45636 .01934 L
.45887 .01934 L
.46134 .01934 L
.46242 .01934 L
.46361 .01934 L
.46465 .01934 L
.46578 .01934 L
.46696 .01934 L
.46807 .01934 L
.46933 .01934 L
.47004 .01934 L
.4707 .01934 L
.47191 .01934 L
.4732 .01934 L
.47434 .01934 L
.47542 .01934 L
.47787 .01934 L
.48041 .01934 L
.48308 .01934 L
.48785 .01933 L
.4986 .01933 L
.53673 .01929 L
.55799 .01927 L
.57731 .01926 L
.59741 .01925 L
.61637 .01924 L
.6364 .01923 L
.65486 .01923 L
.69428 .01922 L
.73219 .01922 L
.75328 .01922 L
.77255 .01921 L
.81139 .01921 L
.85117 .01921 L
.88944 .01921 L
.93016 .01921 L
.96936 .0192 L
.97619 .0192 L
Mfstroke
.814 1 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03163 .0212 L
.03279 .02107 L
.04262 .01976 L
.05217 .01865 L
.06244 .01772 L
.0728 .01701 L
.0825 .01652 L
.09403 .01609 L
.10458 .0158 L
.11442 .01561 L
.12357 .01547 L
.1336 .01536 L
.14429 .01528 L
.15457 .01522 L
.1657 .01517 L
.17621 .01514 L
.18587 .01511 L
.19561 .0151 L
.2047 .01509 L
.21467 .01508 L
.22026 .01507 L
.22536 .01507 L
.23016 .01507 L
.23527 .01507 L
.23969 .01507 L
.24444 .01507 L
.2471 .01506 L
.24953 .01506 L
.25431 .01506 L
.25685 .01506 L
.25962 .01506 L
.26102 .01506 L
.26251 .01506 L
.2652 .01506 L
.26644 .01506 L
.26777 .01506 L
.27018 .01506 L
.27269 .01506 L
.27545 .01506 L
.27699 .01506 L
.27846 .01506 L
.2799 .01506 L
.28122 .01506 L
Mistroke
.28377 .01506 L
.28655 .01506 L
.29167 .01506 L
.29631 .01506 L
.3067 .01506 L
.32761 .01506 L
.33677 .01506 L
.34682 .01506 L
.35589 .01505 L
.3656 .01505 L
.37586 .01505 L
.38542 .01505 L
.39072 .01505 L
.39562 .01505 L
.401 .01505 L
.4067 .01505 L
.42684 .01505 L
.44635 .01505 L
.46464 .01505 L
.48315 .01505 L
.50338 .01505 L
.52346 .01505 L
.53453 .01505 L
.54457 .01505 L
.55401 .01505 L
.56422 .01505 L
.57501 .01505 L
.58518 .01505 L
.59467 .01505 L
.6051 .01505 L
.61598 .01505 L
.62615 .01505 L
.66503 .01505 L
.67519 .01505 L
.68625 .01505 L
.6958 .01505 L
.70088 .01505 L
.70636 .01505 L
.71167 .01505 L
.71654 .01505 L
.7212 .01505 L
.72354 .01505 L
.72611 .01505 L
.72753 .01505 L
.72886 .01505 L
.73006 .01505 L
.73137 .01505 L
.73204 .01505 L
.73278 .01505 L
.73356 .01505 L
Mistroke
.73429 .01505 L
.73559 .01505 L
.73632 .01505 L
.73698 .01505 L
.73827 .01505 L
.73947 .01505 L
.74218 .01505 L
.74456 .01505 L
.74711 .01505 L
.75247 .01505 L
.75741 .01505 L
.76854 .01505 L
.78871 .01505 L
.82822 .01505 L
.86621 .01505 L
.90666 .01505 L
.94558 .01505 L
.97619 .01505 L
Mfstroke
.791 1 0 r
.02381 .01472 m
.02846 .05726 L
.03279 .08921 L
.03527 .10276 L
.03754 .11186 L
.03879 .11566 L
.04015 .11887 L
.04143 .12112 L
.04262 .12259 L
.04376 .12352 L
.04498 .12405 L
.04614 .12418 L
.0472 .12401 L
.04843 .12352 L
.04913 .12312 L
.04978 .12269 L
.05224 .12051 L
.05718 .11453 L
.06244 .10703 L
.07287 .09197 L
.08414 .07771 L
.09388 .06765 L
.10458 .05888 L
.11511 .05221 L
.12624 .04685 L
.13654 .04311 L
.14616 .04044 L
.15661 .03824 L
.16651 .03669 L
.1754 .03563 L
.18507 .03478 L
.19447 .03418 L
.19982 .03393 L
.20484 .03374 L
.20741 .03367 L
.21012 .0336 L
.21246 .03355 L
.21495 .03351 L
.21637 .03349 L
.21765 .03348 L
.21894 .03347 L
.22016 .03346 L
.22085 .03346 L
.22158 .03345 L
.22289 .03345 L
.22362 .03345 L
.2243 .03345 L
.22505 .03346 L
.22585 .03346 L
.22654 .03346 L
Mistroke
.22719 .03347 L
.2284 .03348 L
.2297 .03349 L
.23111 .03351 L
.23365 .03356 L
.23598 .03362 L
.24136 .0338 L
.24406 .03392 L
.24703 .03409 L
.25205 .03444 L
.25743 .03495 L
.26713 .03623 L
.27733 .03779 L
.28012 .03816 L
.28309 .0385 L
.28565 .03874 L
.28841 .03894 L
.28967 .03901 L
.29099 .03908 L
.29221 .03913 L
.29335 .03916 L
.29442 .03918 L
.29557 .0392 L
.29683 .03921 L
.29799 .03921 L
.29865 .0392 L
.29934 .0392 L
.30059 .03918 L
.30129 .03916 L
.30194 .03915 L
.30342 .0391 L
.30589 .03901 L
.30854 .03888 L
.3187 .03821 L
.32976 .03732 L
.34987 .03575 L
.36962 .03455 L
.3796 .0341 L
.39062 .03372 L
.4007 .03347 L
.40994 .0333 L
.41479 .03324 L
.4201 .03317 L
.43079 .03308 L
.47132 .03271 L
.51033 .03228 L
.52056 .03219 L
.53165 .0321 L
.54124 .03204 L
.5518 .03198 L
Mistroke
.56137 .03194 L
.57165 .03191 L
.58251 .03188 L
.59269 .03186 L
.6028 .03185 L
.60814 .03184 L
.61384 .03184 L
.6193 .03183 L
.62426 .03183 L
.62887 .03183 L
.63393 .03183 L
.63881 .03183 L
.64148 .03182 L
.64396 .03182 L
.64629 .03182 L
.64842 .03182 L
.64959 .03182 L
.65087 .03182 L
.65208 .03182 L
.65319 .03182 L
.65438 .03182 L
.65567 .03182 L
.65688 .03182 L
.65799 .03182 L
.65923 .03182 L
.66057 .03182 L
.66329 .03182 L
.66598 .03182 L
.66885 .03182 L
.67402 .03183 L
.68427 .03183 L
.69538 .03183 L
.71553 .03184 L
.75647 .03186 L
.7959 .03189 L
.8338 .03191 L
.87416 .03194 L
.91301 .03197 L
.9543 .032 L
.97619 .03202 L
Mfstroke
.767 1 0 r
.02381 .01472 m
.02846 .05751 L
.03279 .09123 L
.03523 .10643 L
.03754 .1179 L
.03881 .123 L
.0402 .12757 L
.04145 .13088 L
.04262 .13331 L
.04376 .13512 L
.045 .13648 L
.0457 .13701 L
.04637 .13736 L
.04762 .13765 L
.04894 .1375 L
.05016 .13699 L
.05086 .13656 L
.0515 .1361 L
.05293 .13481 L
.05783 .12857 L
.06244 .12124 L
.07312 .10333 L
.08439 .08639 L
.09483 .07361 L
.10458 .06409 L
.11419 .05668 L
.12296 .05132 L
.13269 .04665 L
.14313 .04283 L
.15304 .04009 L
.16222 .03815 L
.17228 .03654 L
.18298 .0353 L
.19235 .03451 L
.19762 .03418 L
.20245 .03393 L
.20706 .03373 L
.21135 .03359 L
.21583 .03349 L
.2182 .03344 L
.22073 .03341 L
.22196 .0334 L
.22331 .03339 L
.224 .03339 L
.22473 .03338 L
.22542 .03338 L
.22606 .03338 L
.22726 .03338 L
.22858 .03339 L
.22982 .0334 L
Mistroke
.23097 .03341 L
.23242 .03342 L
.23379 .03344 L
.23635 .03349 L
.2391 .03356 L
.24207 .03366 L
.24718 .0339 L
.25257 .03425 L
.25718 .03465 L
.26222 .0352 L
.27311 .03669 L
.27846 .03741 L
.28341 .03796 L
.28573 .03816 L
.2879 .03831 L
.29016 .03843 L
.29136 .03849 L
.29266 .03853 L
.29388 .03856 L
.29457 .03857 L
.29521 .03858 L
.29651 .03859 L
.29724 .03859 L
.2979 .03859 L
.29909 .03858 L
.30037 .03857 L
.30158 .03854 L
.3027 .03851 L
.30495 .03844 L
.30737 .03833 L
.31172 .0381 L
.32164 .0374 L
.34166 .03583 L
.36145 .03451 L
.37263 .03395 L
.38299 .03353 L
.39216 .03326 L
.40229 .03303 L
.40737 .03294 L
.41286 .03286 L
.41801 .03281 L
.4228 .03277 L
.43236 .0327 L
.44282 .03265 L
.45366 .03259 L
.46391 .03252 L
.48434 .03233 L
.50292 .03213 L
.52122 .03194 L
.54136 .03179 L
Mistroke
.56121 .03167 L
.57207 .03163 L
.58224 .0316 L
.59263 .03157 L
.60251 .03155 L
.62104 .03152 L
.63063 .03151 L
.64086 .0315 L
.65925 .03149 L
.68068 .03147 L
.70085 .03146 L
.71062 .03146 L
.72094 .03146 L
.73061 .03145 L
.73942 .03145 L
.74891 .03145 L
.75378 .03145 L
.75907 .03145 L
.76397 .03145 L
.76849 .03145 L
.77282 .03145 L
.775 .03145 L
.77741 .03145 L
.77977 .03145 L
.7811 .03145 L
.78234 .03145 L
.78365 .03145 L
.78484 .03145 L
.7855 .03145 L
.78622 .03145 L
.78752 .03145 L
.78863 .03145 L
.78986 .03145 L
.79114 .03145 L
.79233 .03145 L
.79678 .03145 L
.79947 .03145 L
.80203 .03145 L
.80683 .03145 L
.81764 .03145 L
.8375 .03145 L
.8559 .03145 L
.8951 .03146 L
.93676 .03147 L
.97619 .03147 L
Mfstroke
.743 1 0 r
.02381 .01472 m
.03279 .09423 L
.03793 .13168 L
.04262 .15924 L
.04758 .18095 L
.0503 .18956 L
.05156 .19273 L
.05288 .19558 L
.05402 .19762 L
.05527 .19944 L
.0564 .20073 L
.05747 .20164 L
.05872 .20235 L
.05987 .20269 L
.06119 .20272 L
.06244 .20243 L
.0631 .20216 L
.06381 .20178 L
.0651 .20088 L
.0675 .19854 L
.07031 .1949 L
.07289 .19088 L
.08259 .17244 L
.10458 .12965 L
.1234 .10242 L
.13409 .09112 L
.14407 .08285 L
.15452 .07613 L
.16442 .07126 L
.17331 .06791 L
.18298 .06514 L
.19238 .06319 L
.19773 .06235 L
.20275 .06174 L
.20532 .06148 L
.20802 .06125 L
.21036 .06109 L
.21286 .06095 L
.21427 .06088 L
.21556 .06084 L
.21686 .0608 L
.21806 .06077 L
.21875 .06076 L
.21947 .06075 L
.2202 .06074 L
.22099 .06074 L
.22168 .06074 L
.22242 .06074 L
.22312 .06075 L
.22376 .06075 L
Mistroke
.22505 .06078 L
.22627 .06081 L
.22736 .06085 L
.22854 .0609 L
.23119 .06105 L
.23363 .06123 L
.23808 .0617 L
.24032 .06201 L
.24278 .06241 L
.24796 .06351 L
.25351 .06517 L
.25875 .06732 L
.26352 .06985 L
.27358 .07656 L
.27909 .08025 L
.28426 .08307 L
.2864 .08398 L
.28864 .08477 L
.28982 .08511 L
.29111 .08542 L
.29227 .08565 L
.29337 .08583 L
.29469 .08598 L
.29589 .08608 L
.29718 .08613 L
.29791 .08613 L
.29858 .08613 L
.2997 .08609 L
.30093 .086 L
.30222 .08588 L
.30342 .08572 L
.3058 .08533 L
.30839 .08478 L
.3131 .08352 L
.32193 .08061 L
.3418 .07356 L
.36155 .06796 L
.37153 .0659 L
.37689 .06501 L
.38255 .06422 L
.38736 .06368 L
.39262 .06322 L
.39494 .06306 L
.39741 .06291 L
.39973 .0628 L
.40187 .06273 L
.40318 .06269 L
.40456 .06266 L
.40528 .06265 L
.40595 .06265 L
Mistroke
.40669 .06264 L
.40749 .06264 L
.40816 .06264 L
.40891 .06264 L
.40961 .06264 L
.41026 .06265 L
.41148 .06267 L
.41279 .0627 L
.41408 .06274 L
.41547 .06279 L
.418 .06291 L
.42046 .06306 L
.42272 .06323 L
.42742 .06367 L
.43246 .06427 L
.44156 .06564 L
.4523 .0675 L
.46223 .0691 L
.46707 .06974 L
.47241 .0703 L
.47518 .07053 L
.47778 .07069 L
.48052 .07082 L
.48207 .07087 L
.48281 .07089 L
.48348 .07091 L
.48466 .07093 L
.48591 .07094 L
.48707 .07094 L
.48817 .07094 L
.48945 .07093 L
.49062 .07091 L
.49192 .07088 L
.49329 .07084 L
.49583 .07074 L
.4982 .07062 L
.50361 .07026 L
.51402 .06933 L
.52391 .06827 L
.54245 .06617 L
.56254 .06415 L
.58072 .0627 L
.60044 .06154 L
.61126 .06105 L
.62143 .06067 L
.64157 .06009 L
.66006 .05969 L
.69962 .05906 L
.73766 .05858 L
.77816 .05818 L
Mistroke
.81714 .05789 L
.85857 .05764 L
.89849 .05745 L
.93689 .05728 L
.97619 .05713 L
Mfstroke
.719 1 0 r
.02381 .01472 m
.03279 .09425 L
.03793 .13186 L
.04262 .15982 L
.04758 .18234 L
.0503 .19156 L
.05288 .19828 L
.05404 .20068 L
.05527 .20284 L
.05633 .20439 L
.05747 .20574 L
.05869 .20684 L
.05984 .20756 L
.06053 .20786 L
.0612 .20805 L
.06244 .20817 L
.0631 .20811 L
.06381 .20796 L
.0651 .20747 L
.06635 .20675 L
.0675 .20587 L
.07012 .20325 L
.07289 .19968 L
.08259 .18309 L
.10458 .14159 L
.11406 .12651 L
.12422 .11298 L
.14255 .09486 L
.15272 .08771 L
.16379 .0818 L
.17424 .07766 L
.18391 .07485 L
.18855 .0738 L
.19354 .07286 L
.19786 .07221 L
.20258 .07164 L
.20511 .0714 L
.20781 .07119 L
.20931 .07109 L
.21067 .07102 L
.21205 .07096 L
.21332 .07091 L
.21451 .07088 L
.21576 .07085 L
.21701 .07084 L
.21773 .07084 L
.21839 .07084 L
.2196 .07085 L
.2207 .07087 L
.22197 .0709 L
Mistroke
.22318 .07094 L
.22443 .07099 L
.22578 .07107 L
.22822 .07124 L
.2306 .07146 L
.23279 .07171 L
.23777 .07247 L
.24028 .07297 L
.24302 .07363 L
.24762 .07503 L
.25255 .07705 L
.25719 .07957 L
.26142 .08247 L
.27149 .09148 L
.277 .09674 L
.28216 .10096 L
.28655 .10363 L
.28902 .1047 L
.29127 .10542 L
.29249 .1057 L
.29362 .1059 L
.29485 .10605 L
.29617 .10614 L
.29684 .10615 L
.29756 .10615 L
.29887 .10609 L
.30015 .10598 L
.30132 .10582 L
.30354 .1054 L
.30592 .1048 L
.31021 .10338 L
.31998 .0991 L
.3397 .08946 L
.34986 .08509 L
.36092 .08114 L
.37136 .07821 L
.38103 .07616 L
.38566 .0754 L
.39064 .07472 L
.39535 .07422 L
.39967 .07388 L
.40215 .07373 L
.40446 .07362 L
.40579 .07358 L
.40699 .07354 L
.40766 .07353 L
.40839 .07351 L
.4097 .0735 L
.41097 .07349 L
.41169 .07349 L
Mistroke
.41237 .07349 L
.41308 .0735 L
.41373 .0735 L
.41448 .07352 L
.4152 .07353 L
.41645 .07356 L
.41762 .0736 L
.42027 .07371 L
.42291 .07385 L
.42535 .07402 L
.43084 .07452 L
.4408 .07577 L
.45942 .07873 L
.46851 .08005 L
.47352 .08064 L
.47825 .08109 L
.48093 .0813 L
.48385 .08147 L
.4865 .0816 L
.48776 .08164 L
.48895 .08168 L
.49005 .0817 L
.49125 .08173 L
.49189 .08173 L
.49257 .08174 L
.49379 .08175 L
.49506 .08175 L
.49624 .08174 L
.49754 .08173 L
.49826 .08171 L
.49892 .0817 L
.50124 .08164 L
.50378 .08155 L
.50891 .0813 L
.51367 .081 L
.51812 .08067 L
.53893 .07875 L
.55751 .077 L
.57777 .07542 L
.58877 .07474 L
.59896 .07423 L
.61907 .07349 L
.62967 .07321 L
.63964 .073 L
.65827 .07269 L
.69689 .07216 L
.73797 .07158 L
.77753 .07106 L
.81557 .07063 L
.85607 .07024 L
Mistroke
.89505 .06989 L
.93648 .06956 L
.97619 .06926 L
Mfstroke
.696 1 0 r
.02381 .01472 m
.03279 .09421 L
.03793 .13176 L
.04262 .15982 L
.04758 .18291 L
.05012 .19216 L
.05288 .20033 L
.05544 .20624 L
.0578 .21041 L
.06005 .21332 L
.06119 .21443 L
.06244 .21538 L
.06309 .21576 L
.06379 .2161 L
.06455 .21639 L
.06525 .21658 L
.06597 .2167 L
.06665 .21674 L
.06792 .21666 L
.06917 .21639 L
.07032 .21599 L
.07159 .21538 L
.07293 .21457 L
.07571 .2124 L
.0783 .20987 L
.0842 .20283 L
.10458 .17367 L
.12322 .15002 L
.14349 .13138 L
.15452 .12417 L
.16473 .11908 L
.17448 .11544 L
.17941 .11401 L
.18485 .11273 L
.18977 .11182 L
.19245 .11142 L
.19494 .11111 L
.19726 .11088 L
.19936 .11071 L
.2017 .11057 L
.20298 .11052 L
.2042 .11048 L
.2054 .11046 L
.20609 .11045 L
.20673 .11045 L
.20802 .11045 L
.20874 .11047 L
.2094 .11048 L
.21058 .11052 L
.21187 .11058 L
Mistroke
.21308 .11065 L
.2142 .11073 L
.21696 .11099 L
.21946 .1113 L
.22234 .11175 L
.22505 .11229 L
.22972 .11348 L
.23484 .11527 L
.24019 .11782 L
.24517 .12103 L
.24984 .12503 L
.2541 .12976 L
.25901 .13679 L
.26366 .14514 L
.27333 .16596 L
.27864 .17678 L
.28123 .1813 L
.2836 .18487 L
.28562 .18742 L
.28783 .1897 L
.29004 .19146 L
.29125 .19219 L
.29237 .19274 L
.29363 .1932 L
.29482 .1935 L
.29589 .19365 L
.29705 .1937 L
.29831 .19362 L
.29895 .19354 L
.29965 .19341 L
.30088 .19309 L
.30204 .19269 L
.30463 .19149 L
.30703 .19004 L
.31247 .18582 L
.32236 .17612 L
.34091 .15678 L
.35955 .14084 L
.37017 .13399 L
.38015 .12898 L
.38996 .12529 L
.3949 .12385 L
.40031 .12256 L
.40493 .12168 L
.40988 .12094 L
.41455 .1204 L
.4188 .12002 L
.42364 .11969 L
.42608 .11957 L
.42877 .11945 L
Mistroke
.43106 .11937 L
.43232 .11934 L
.43352 .11931 L
.43463 .11929 L
.43584 .11927 L
.43694 .11926 L
.43796 .11926 L
.43927 .11925 L
.44001 .11925 L
.44068 .11926 L
.44193 .11926 L
.44324 .11928 L
.44442 .1193 L
.44553 .11932 L
.44803 .1194 L
.45074 .1195 L
.45321 .11962 L
.45875 .11998 L
.46868 .12088 L
.47785 .12194 L
.49862 .12451 L
.50761 .12546 L
.5173 .12628 L
.52284 .12665 L
.52793 .12693 L
.53275 .12715 L
.5379 .12734 L
.54772 .1276 L
.55684 .12777 L
.56762 .12796 L
.57755 .12818 L
.58253 .12832 L
.5878 .12851 L
.59891 .12903 L
.60851 .12962 L
.61907 .13042 L
.65943 .13451 L
.69827 .13841 L
.71946 .14004 L
.73957 .14127 L
.77783 .14301 L
.81855 .14443 L
.85775 .14551 L
.87778 .14594 L
.8994 .14632 L
.91894 .14659 L
.93954 .14682 L
.97619 .14712 L
Mfstroke
.672 1 0 r
.02381 .01472 m
.02846 .05738 L
.03279 .09019 L
.03527 .10465 L
.03754 .11476 L
.03879 .11913 L
.04015 .12297 L
.04143 .12577 L
.04262 .12773 L
.04376 .12908 L
.04498 .13003 L
.04614 .1305 L
.0472 .1306 L
.04843 .13039 L
.04913 .13013 L
.04978 .1298 L
.05097 .12901 L
.05224 .12795 L
.05759 .12168 L
.06244 .11464 L
.08269 .08548 L
.09409 .07267 L
.10458 .06341 L
.11387 .05694 L
.12406 .05139 L
.13471 .04697 L
.14465 .04385 L
.1551 .04136 L
.165 .03961 L
.17389 .03842 L
.18355 .03745 L
.19295 .03678 L
.19831 .0365 L
.20333 .03629 L
.2059 .0362 L
.2086 .03613 L
.21094 .03608 L
.21344 .03603 L
.21485 .03601 L
.21613 .036 L
.21743 .03599 L
.21864 .03598 L
.21933 .03598 L
.22006 .03597 L
.22138 .03597 L
.2221 .03597 L
.22279 .03597 L
.22353 .03598 L
.22434 .03598 L
.22567 .03599 L
Mistroke
.22688 .03601 L
.22959 .03605 L
.23211 .0361 L
.23447 .03617 L
.23978 .03637 L
.24277 .03653 L
.24551 .03671 L
.25018 .03708 L
.25529 .03762 L
.26063 .03836 L
.26561 .03919 L
.27609 .04112 L
.28124 .04191 L
.28351 .04218 L
.28601 .04243 L
.28823 .0426 L
.29032 .04272 L
.29148 .04277 L
.29253 .0428 L
.29369 .04283 L
.29491 .04284 L
.29606 .04284 L
.2973 .04284 L
.29847 .04282 L
.29953 .04279 L
.30077 .04276 L
.30212 .04271 L
.30457 .04259 L
.30948 .04227 L
.31406 .04189 L
.32449 .0409 L
.34555 .03887 L
.35598 .03803 L
.36587 .03736 L
.37469 .03687 L
.38442 .03645 L
.39406 .03613 L
.39899 .036 L
.40431 .03588 L
.4138 .03573 L
.42272 .03562 L
.46383 .03519 L
.48433 .03491 L
.50342 .03468 L
.52182 .03451 L
.53212 .03444 L
.54149 .03438 L
.5508 .03434 L
.56066 .0343 L
.57147 .03427 L
Mistroke
.58144 .03425 L
.59087 .03423 L
.59616 .03423 L
.60099 .03422 L
.60548 .03422 L
.61038 .03422 L
.61262 .03422 L
.61501 .03421 L
.61705 .03421 L
.6193 .03421 L
.62056 .03421 L
.62191 .03421 L
.62265 .03421 L
.62333 .03421 L
.62402 .03421 L
.62466 .03421 L
.62588 .03421 L
.6272 .03421 L
.62836 .03421 L
.62959 .03421 L
.63091 .03421 L
.63165 .03421 L
.63233 .03421 L
.63489 .03421 L
.63773 .03421 L
.64073 .03421 L
.64572 .03422 L
.65036 .03422 L
.6609 .03422 L
.68137 .03424 L
.69997 .03426 L
.73997 .0343 L
.77845 .03434 L
.81939 .03438 L
.85882 .03442 L
.89672 .03445 L
.93708 .03449 L
.97593 .03453 L
.97619 .03453 L
Mfstroke
.648 1 0 r
.02381 .01472 m
.02846 .05738 L
.03279 .09009 L
.03527 .10432 L
.03754 .11403 L
.03879 .1181 L
.04015 .12152 L
.04143 .12387 L
.04262 .12536 L
.04376 .12624 L
.04498 .12664 L
.04614 .12658 L
.0472 .1262 L
.04843 .12542 L
.04978 .12422 L
.05224 .12131 L
.06244 .10466 L
.08284 .07281 L
.09424 .05987 L
.10458 .05091 L
.11463 .04425 L
.12551 .03882 L
.13578 .035 L
.14523 .03234 L
.15496 .03026 L
.16405 .02878 L
.17402 .02756 L
.18471 .0266 L
.19489 .02595 L
.20063 .02566 L
.20595 .02545 L
.21098 .02529 L
.21571 .02516 L
.22064 .02506 L
.22345 .02502 L
.22607 .02498 L
.22834 .02496 L
.23077 .02494 L
.23215 .02493 L
.23346 .02492 L
.23463 .02492 L
.23591 .02492 L
.23715 .02492 L
.23786 .02492 L
.23852 .02492 L
.23922 .02492 L
.23986 .02492 L
.24129 .02493 L
.24251 .02493 L
.24384 .02494 L
Mistroke
.24626 .02497 L
.2487 .025 L
.25091 .02503 L
.25586 .02514 L
.26045 .02527 L
.26476 .02542 L
.27455 .0258 L
.2799 .026 L
.2825 .02607 L
.28488 .02614 L
.28692 .02618 L
.28914 .02621 L
.29036 .02623 L
.29148 .02624 L
.29256 .02625 L
.2937 .02625 L
.29484 .02626 L
.29607 .02626 L
.29723 .02625 L
.2983 .02625 L
.29948 .02624 L
.30077 .02623 L
.30336 .0262 L
.30591 .02617 L
.30867 .02612 L
.31367 .02601 L
.32301 .02577 L
.34398 .02519 L
.36389 .02476 L
.37393 .0246 L
.38495 .02447 L
.39018 .02442 L
.39514 .02438 L
.40443 .02432 L
.40963 .0243 L
.41444 .02428 L
.41972 .02427 L
.42239 .02427 L
.42534 .02426 L
.42768 .02426 L
.43025 .02426 L
.43154 .02426 L
.43292 .02426 L
.43423 .02426 L
.43542 .02426 L
.4366 .02426 L
.4377 .02426 L
.4389 .02426 L
.44017 .02426 L
.44128 .02426 L
Mistroke
.44231 .02426 L
.44466 .02426 L
.44595 .02426 L
.44735 .02426 L
.448 .02426 L
.44868 .02426 L
.44991 .02426 L
.45121 .02426 L
.45243 .02426 L
.45352 .02426 L
.45471 .02426 L
.45601 .02426 L
.45745 .02426 L
.45894 .02426 L
.46034 .02425 L
.46283 .02425 L
.46551 .02425 L
.4708 .02425 L
.47569 .02424 L
.48106 .02423 L
.48677 .02421 L
.50689 .02415 L
.54466 .02402 L
.56402 .02397 L
.57399 .02395 L
.58489 .02394 L
.60494 .02391 L
.61588 .0239 L
.62605 .02389 L
.66511 .02387 L
.70663 .02385 L
.72745 .02385 L
.74663 .02384 L
.78512 .02383 L
.80389 .02383 L
.82454 .02383 L
.8649 .02382 L
.90374 .02382 L
.94504 .02382 L
.97619 .02382 L
Mfstroke
.625 1 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02142 L
.02954 .02138 L
.03053 .0213 L
.03279 .02105 L
.04262 .01972 L
.05285 .01853 L
.06244 .01766 L
.07218 .01699 L
.0829 .01645 L
.09334 .01606 L
.10458 .01575 L
.11468 .01555 L
.12571 .0154 L
.13613 .01529 L
.1458 .01522 L
.15637 .01516 L
.16633 .01512 L
.17526 .01509 L
.18493 .01507 L
.19444 .01505 L
.20487 .01504 L
.21013 .01504 L
.21577 .01503 L
.22594 .01503 L
.23122 .01502 L
.23611 .01502 L
.24137 .01502 L
.24718 .01502 L
.25221 .01502 L
.25693 .01502 L
.26192 .01502 L
.26473 .01502 L
.2673 .01502 L
.30692 .01501 L
.32689 .01501 L
.34503 .01501 L
.35512 .01501 L
.36464 .01501 L
.37469 .01501 L
.38036 .01501 L
.38559 .01501 L
.39027 .01501 L
.39284 .01501 L
.39529 .01501 L
.39755 .01501 L
.40002 .01501 L
Mistroke
.40227 .01501 L
.40436 .01501 L
.40565 .01501 L
.40639 .01501 L
.40706 .01501 L
.4083 .01501 L
.4096 .01501 L
.41077 .01501 L
.41187 .01501 L
.41307 .01501 L
.41435 .01501 L
.41572 .01501 L
.41721 .01501 L
.41992 .01501 L
.42499 .01501 L
.43442 .01501 L
.44481 .01501 L
.45578 .01501 L
.46058 .01501 L
.46583 .01501 L
.4682 .01501 L
.47073 .01501 L
.47291 .01501 L
.47528 .01501 L
.47667 .01501 L
.47796 .01501 L
.47919 .01501 L
.48049 .01501 L
.48165 .01501 L
.48274 .01501 L
.48393 .01501 L
.48521 .01501 L
.48589 .01501 L
.48661 .01501 L
.4879 .01501 L
.48928 .01501 L
.49082 .01501 L
.49355 .01501 L
.49613 .01501 L
.50092 .01501 L
.50608 .01501 L
.5261 .01501 L
.54719 .01501 L
.56713 .01501 L
.58527 .01501 L
.60485 .01501 L
.6258 .01501 L
.66575 .01501 L
.70418 .01501 L
.74507 .01501 L
Mistroke
.78444 .01501 L
.82229 .01501 L
.8626 .01501 L
.90139 .01501 L
.94264 .01501 L
.97619 .01501 L
Mfstroke
.601 1 0 r
.02381 .01472 m
.02846 .0575 L
.03279 .09109 L
.03527 .10626 L
.03754 .11699 L
.03879 .12163 L
.04015 .12565 L
.04143 .12852 L
.04262 .13043 L
.04376 .13165 L
.04498 .13236 L
.04614 .13253 L
.0472 .1323 L
.04843 .13164 L
.04913 .1311 L
.04978 .13051 L
.05224 .12758 L
.05718 .11963 L
.06244 .10986 L
.07287 .09089 L
.08414 .07364 L
.09479 .06092 L
.10458 .05189 L
.11422 .04502 L
.1248 .0393 L
.13585 .03489 L
.14616 .03186 L
.15661 .02958 L
.16651 .02798 L
.1754 .02689 L
.18507 .02601 L
.19447 .02537 L
.20484 .02486 L
.21006 .02467 L
.21568 .02451 L
.22099 .02439 L
.22354 .02434 L
.22585 .0243 L
.22813 .02427 L
.23059 .02425 L
.23195 .02423 L
.2332 .02423 L
.23447 .02422 L
.23566 .02421 L
.23667 .02421 L
.23777 .02421 L
.23898 .0242 L
.24009 .0242 L
.24124 .02421 L
.24249 .02421 L
Mistroke
.24368 .02421 L
.24478 .02422 L
.24608 .02423 L
.24749 .02424 L
.25004 .02427 L
.25252 .0243 L
.2548 .02434 L
.26 .02445 L
.26548 .0246 L
.27498 .0249 L
.28021 .02505 L
.28278 .02511 L
.28515 .02515 L
.28739 .02518 L
.28853 .0252 L
.28976 .02521 L
.29098 .02522 L
.29214 .02522 L
.2928 .02523 L
.2935 .02523 L
.29476 .02523 L
.2958 .02523 L
.29692 .02522 L
.29798 .02522 L
.29894 .02521 L
.30129 .02519 L
.3035 .02517 L
.30815 .02509 L
.31325 .025 L
.32355 .02476 L
.34202 .02433 L
.36151 .02397 L
.37244 .02382 L
.37727 .02377 L
.38241 .02372 L
.38711 .02369 L
.39231 .02365 L
.39709 .02363 L
.40147 .02361 L
.40662 .0236 L
.40932 .02359 L
.4107 .02359 L
.41217 .02359 L
.41347 .02359 L
.41466 .02359 L
.41585 .02359 L
.41697 .02359 L
.41828 .02359 L
.41949 .02359 L
.42012 .02359 L
Mistroke
.42082 .02359 L
.42154 .02359 L
.42222 .02359 L
.42347 .02359 L
.4248 .02359 L
.42719 .02359 L
.43004 .02359 L
.43261 .0236 L
.44249 .02362 L
.4515 .02365 L
.46102 .02367 L
.4658 .02368 L
.46852 .02369 L
.47105 .02369 L
.47225 .02369 L
.47338 .02369 L
.4744 .02369 L
.4755 .02369 L
.47671 .02369 L
.47798 .02369 L
.47907 .02369 L
.48028 .02369 L
.48159 .02369 L
.48225 .02369 L
.48298 .02369 L
.48545 .02369 L
.48834 .02368 L
.49102 .02368 L
.4959 .02367 L
.5011 .02365 L
.52246 .02357 L
.54262 .02349 L
.56095 .02342 L
.58111 .02336 L
.601 .02331 L
.62205 .02327 L
.64151 .02325 L
.6624 .02323 L
.68359 .02322 L
.7037 .02321 L
.74197 .02319 L
.76169 .02319 L
.78268 .02318 L
.80271 .02318 L
.82434 .02318 L
.86448 .02317 L
.90555 .02317 L
.94511 .02317 L
.97619 .02317 L
Mfstroke
.577 1 0 r
.02381 .01472 m
.02846 .05765 L
.03279 .09252 L
.03754 .12239 L
.0402 .13464 L
.04262 .14294 L
.04385 .14617 L
.04516 .14891 L
.04627 .15072 L
.0475 .15218 L
.04882 .15319 L
.04957 .15352 L
.05024 .15369 L
.05156 .15367 L
.05281 .15327 L
.05397 .15261 L
.0552 .15164 L
.05742 .14931 L
.06244 .14205 L
.08414 .10374 L
.09479 .08795 L
.10458 .07615 L
.1141 .06693 L
.12455 .059 L
.13506 .05289 L
.14616 .04803 L
.15637 .04469 L
.16567 .04237 L
.17641 .04037 L
.18659 .039 L
.19624 .03807 L
.20111 .03772 L
.2065 .0374 L
.21107 .0372 L
.21347 .03711 L
.216 .03704 L
.21822 .03698 L
.21939 .03696 L
.22065 .03694 L
.22181 .03692 L
.22286 .03691 L
.22392 .0369 L
.22492 .0369 L
.22607 .03689 L
.22731 .03689 L
.22848 .03689 L
.22955 .0369 L
.23079 .03691 L
.23216 .03693 L
.23344 .03695 L
Mistroke
.23464 .03697 L
.23725 .03704 L
.23962 .03712 L
.24239 .03724 L
.24493 .03738 L
.2495 .03769 L
.25444 .03816 L
.25879 .03869 L
.26338 .03938 L
.27361 .04128 L
.27864 .0422 L
.28328 .04292 L
.2875 .04341 L
.28963 .04359 L
.29197 .04375 L
.29319 .0438 L
.29432 .04385 L
.29555 .04388 L
.29684 .0439 L
.29797 .04391 L
.29902 .0439 L
.30018 .04389 L
.30141 .04386 L
.30272 .04383 L
.30394 .04378 L
.30668 .04365 L
.31165 .04331 L
.32095 .04247 L
.34188 .04025 L
.35172 .0393 L
.36228 .03841 L
.3714 .03778 L
.38134 .03722 L
.39152 .03677 L
.40118 .03646 L
.40573 .03635 L
.41057 .03625 L
.41928 .03611 L
.42416 .03606 L
.42863 .03602 L
.43872 .03595 L
.457 .03585 L
.46678 .03577 L
.4759 .03568 L
.49659 .03542 L
.5153 .03517 L
.5356 .03493 L
.54669 .03482 L
.55692 .03474 L
.56732 .03468 L
Mistroke
.57707 .03462 L
.59581 .03455 L
.60575 .03452 L
.61644 .0345 L
.63759 .03446 L
.65768 .03443 L
.69589 .03439 L
.71558 .03438 L
.73656 .03437 L
.74685 .03436 L
.75799 .03436 L
.76761 .03436 L
.77816 .03435 L
.78848 .03435 L
.79811 .03435 L
.80829 .03435 L
.81395 .03435 L
.81918 .03435 L
.82403 .03435 L
.82937 .03435 L
.83474 .03435 L
.83768 .03435 L
.84044 .03435 L
.8429 .03435 L
.84414 .03435 L
.84485 .03435 L
.8455 .03435 L
.84666 .03435 L
.8479 .03435 L
.84904 .03435 L
.85013 .03435 L
.85139 .03435 L
.85203 .03435 L
.85273 .03435 L
.85398 .03435 L
.85514 .03435 L
.85775 .03435 L
.86057 .03435 L
.86583 .03435 L
.87071 .03435 L
.88176 .03435 L
.8915 .03435 L
.90186 .03435 L
.94352 .03435 L
.97619 .03436 L
Mfstroke
.553 1 0 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04313 L
.02846 .0488 L
.02954 .05225 L
.03053 .05423 L
.03163 .05542 L
.03279 .05591 L
.03395 .05588 L
.0352 .05547 L
.03638 .05484 L
.03746 .05413 L
.04262 .05003 L
.0529 .0418 L
.06244 .03558 L
.07277 .03042 L
.08405 .02628 L
.09398 .02361 L
.10458 .02151 L
.11487 .02002 L
.12599 .01886 L
.1365 .01807 L
.14616 .01753 L
.1559 .01713 L
.16499 .01685 L
.17496 .01662 L
.18565 .01644 L
.19582 .01632 L
.20119 .01627 L
.20689 .01622 L
.21186 .01619 L
.21734 .01616 L
.22701 .01612 L
.23193 .01611 L
.2371 .01609 L
.24152 .01608 L
.24636 .01608 L
.24909 .01607 L
.25158 .01607 L
.25296 .01607 L
.25445 .01607 L
.25574 .01607 L
.25716 .01607 L
.25847 .01607 L
.2597 .01607 L
.261 .01607 L
.26173 .01607 L
.26239 .01607 L
.26358 .01607 L
Mistroke
.26487 .01607 L
.26608 .01607 L
.26721 .01607 L
.26851 .01607 L
.26987 .01607 L
.27231 .01607 L
.27515 .01607 L
.27654 .01607 L
.27781 .01607 L
.27899 .01607 L
.2801 .01607 L
.28128 .01607 L
.28256 .01607 L
.28388 .01607 L
.28454 .01607 L
.28527 .01607 L
.28649 .01607 L
.28778 .01607 L
.29019 .01607 L
.2924 .01607 L
.29739 .01606 L
.3064 .01605 L
.3264 .01603 L
.34456 .01601 L
.35399 .01601 L
.36421 .016 L
.375 .016 L
.38026 .01599 L
.38517 .01599 L
.39466 .01599 L
.39969 .01599 L
.40508 .01599 L
.41609 .01599 L
.42614 .01599 L
.46595 .01598 L
.50425 .01598 L
.52361 .01598 L
.545 .01598 L
.56523 .01597 L
.58423 .01597 L
.59405 .01597 L
.60439 .01597 L
.62289 .01597 L
.64261 .01597 L
.66097 .01597 L
.6814 .01597 L
.69998 .01597 L
.70994 .01597 L
.71914 .01597 L
.72923 .01597 L
Mistroke
.73432 .01597 L
.73993 .01597 L
.74513 .01597 L
.75007 .01597 L
.75451 .01597 L
.75702 .01597 L
.75935 .01597 L
.76066 .01597 L
.76208 .01597 L
.76334 .01597 L
.76466 .01597 L
.76585 .01597 L
.76716 .01597 L
.76835 .01597 L
.76946 .01597 L
.77013 .01597 L
.77086 .01597 L
.77155 .01597 L
.77218 .01597 L
.77339 .01597 L
.77466 .01597 L
.77731 .01597 L
.78024 .01597 L
.78516 .01597 L
.79034 .01597 L
.7996 .01597 L
.82046 .01597 L
.85859 .01597 L
.89917 .01597 L
.93823 .01597 L
.97619 .01597 L
Mfstroke
.53 1 0 r
.02381 .01472 m
.03279 .09417 L
.03793 .13139 L
.04262 .15856 L
.04758 .17986 L
.0503 .18833 L
.05288 .19436 L
.05404 .19647 L
.05527 .19834 L
.05633 .19965 L
.05747 .20078 L
.05869 .20167 L
.05984 .20222 L
.06053 .20243 L
.0612 .20255 L
.06244 .20256 L
.0631 .20247 L
.06381 .20229 L
.0651 .20177 L
.06635 .20106 L
.0675 .20023 L
.07012 .19782 L
.07289 .19462 L
.08259 .18018 L
.10458 .14472 L
.11406 .13184 L
.12422 .12023 L
.14255 .10459 L
.15272 .0984 L
.16379 .09329 L
.17424 .08975 L
.1789 .08852 L
.18391 .0874 L
.18893 .0865 L
.19354 .08584 L
.19794 .08536 L
.20016 .08517 L
.20258 .08501 L
.20397 .08493 L
.20528 .08487 L
.20646 .08483 L
.20774 .0848 L
.2084 .08478 L
.20913 .08477 L
.20989 .08477 L
.21061 .08476 L
.21188 .08477 L
.2126 .08478 L
.21325 .08479 L
.21451 .08482 L
Mistroke
.21569 .08486 L
.21697 .08492 L
.21834 .08499 L
.22088 .08518 L
.22318 .08539 L
.22807 .08603 L
.23053 .08646 L
.23323 .08701 L
.23801 .08827 L
.24246 .08983 L
.24773 .09229 L
.25253 .09532 L
.25806 .10001 L
.2633 .10583 L
.27209 .11791 L
.2767 .12427 L
.28155 .12995 L
.28415 .13236 L
.28698 .13445 L
.28822 .13518 L
.28955 .13583 L
.29079 .13633 L
.29194 .1367 L
.2932 .137 L
.29387 .13712 L
.29457 .13721 L
.29575 .1373 L
.29705 .13731 L
.2982 .13723 L
.29944 .13708 L
.30061 .13686 L
.30168 .13661 L
.30421 .13583 L
.30655 .1349 L
.31185 .13222 L
.32149 .12608 L
.34251 .11194 L
.36115 .10187 L
.37177 .09754 L
.38175 .09435 L
.39156 .09193 L
.40191 .09007 L
.41074 .08892 L
.4204 .088 L
.46093 .08497 L
.47964 .08344 L
.49994 .08201 L
.51103 .08139 L
.52127 .08093 L
.53167 .08055 L
Mistroke
.54141 .08026 L
.55044 .08005 L
.56015 .07988 L
.56568 .0798 L
.57093 .07974 L
.5761 .07969 L
.58078 .07965 L
.58572 .07962 L
.59038 .0796 L
.59294 .07959 L
.59529 .07958 L
.59787 .07957 L
.59917 .07957 L
.59986 .07957 L
.6006 .07957 L
.60184 .07957 L
.603 .07957 L
.60414 .07957 L
.60519 .07957 L
.60633 .07957 L
.60758 .07957 L
.60889 .07957 L
.61012 .07957 L
.61235 .07958 L
.61439 .07958 L
.61899 .0796 L
.62374 .07962 L
.62881 .07964 L
.63793 .0797 L
.65864 .07989 L
.70016 .08039 L
.74016 .08088 L
.77864 .08134 L
.81958 .08181 L
.85901 .08226 L
.89691 .0827 L
.93727 .08315 L
.97612 .08357 L
.97619 .08358 L
Mfstroke
.506 1 0 r
.02381 .01472 m
.02846 .05703 L
.03068 .07389 L
.03279 .08651 L
.03398 .09202 L
.03527 .09661 L
.03645 .09961 L
.03754 .10148 L
.03871 .10264 L
.04 .10308 L
.04065 .10301 L
.04135 .10277 L
.04262 .10195 L
.04393 .10068 L
.04516 .09921 L
.04793 .09524 L
.05297 .08701 L
.06244 .07195 L
.07295 .05817 L
.08284 .04814 L
.09424 .03952 L
.10458 .0338 L
.11434 .02978 L
.12466 .02662 L
.13346 .02459 L
.14313 .0229 L
.15334 .02158 L
.16264 .02068 L
.17338 .01992 L
.18355 .01939 L
.19321 .01903 L
.20346 .01875 L
.21222 .01857 L
.22188 .01843 L
.2268 .01838 L
.23198 .01833 L
.2364 .01831 L
.24123 .01828 L
.24397 .01827 L
.24646 .01826 L
.24783 .01826 L
.24933 .01826 L
.25001 .01826 L
.25074 .01826 L
.25204 .01825 L
.25323 .01825 L
.25451 .01825 L
.25572 .01825 L
.25682 .01825 L
.25811 .01825 L
Mistroke
.25885 .01826 L
.25952 .01826 L
.26209 .01826 L
.26474 .01827 L
.26718 .01827 L
.27268 .01829 L
.27744 .0183 L
.28013 .0183 L
.28143 .01831 L
.28265 .01831 L
.28375 .01831 L
.28494 .01831 L
.28602 .01831 L
.28703 .01831 L
.28811 .01831 L
.2893 .01831 L
.29054 .01831 L
.29171 .01831 L
.29411 .0183 L
.29631 .0183 L
.30127 .01828 L
.3111 .01825 L
.32023 .0182 L
.34095 .01811 L
.3515 .01807 L
.36144 .01804 L
.37037 .01802 L
.38004 .01801 L
.38953 .01799 L
.39492 .01799 L
.39996 .01799 L
.40268 .01798 L
.40527 .01798 L
.40762 .01798 L
.41012 .01798 L
.4114 .01798 L
.41283 .01798 L
.41412 .01798 L
.41533 .01798 L
.41603 .01798 L
.41676 .01798 L
.41807 .01798 L
.41879 .01798 L
.41947 .01798 L
.42022 .01798 L
.42101 .01798 L
.42224 .01798 L
.4236 .01798 L
.42633 .01798 L
.42887 .01798 L
Mistroke
.43124 .01798 L
.44234 .01799 L
.45197 .01799 L
.45742 .01799 L
.46007 .01799 L
.46248 .01799 L
.4649 .01799 L
.46751 .01799 L
.46895 .01799 L
.47027 .01799 L
.47154 .01799 L
.47217 .01799 L
.47287 .01799 L
.47416 .01799 L
.47534 .01799 L
.47599 .01799 L
.47669 .01799 L
.47798 .01799 L
.47918 .01799 L
.48045 .01799 L
.48274 .01799 L
.48493 .01799 L
.48729 .01799 L
.49155 .01799 L
.50127 .01799 L
.52133 .01798 L
.54243 .01796 L
.56241 .01795 L
.58056 .01795 L
.60019 .01794 L
.62114 .01794 L
.64034 .01793 L
.66114 .01793 L
.70208 .01793 L
.7415 .01792 L
.77941 .01792 L
.81977 .01792 L
.85862 .01792 L
.89991 .01792 L
.93969 .01792 L
.97619 .01792 L
Mfstroke
.482 1 0 r
.02381 .01472 m
.02846 .05704 L
.03068 .07396 L
.03279 .08674 L
.03398 .09239 L
.03527 .09718 L
.03645 .10039 L
.03754 .10247 L
.03871 .10387 L
.04 .10455 L
.04065 .10461 L
.04135 .10449 L
.04262 .10387 L
.04393 .10277 L
.04516 .10145 L
.04793 .09772 L
.05297 .08972 L
.06244 .07464 L
.07295 .06061 L
.08284 .0503 L
.09424 .04137 L
.10458 .03541 L
.11434 .0312 L
.12466 .02788 L
.13346 .02575 L
.14313 .02396 L
.15334 .02256 L
.16264 .02161 L
.17338 .0208 L
.18355 .02024 L
.19321 .01986 L
.20346 .01956 L
.21222 .01937 L
.22188 .01923 L
.2268 .01918 L
.23198 .01913 L
.2364 .0191 L
.2389 .01909 L
.24123 .01908 L
.24254 .01908 L
.24395 .01908 L
.24528 .01907 L
.24651 .01907 L
.24762 .01907 L
.24885 .01907 L
.25012 .01907 L
.25131 .01907 L
.25198 .01907 L
.25271 .01907 L
.25403 .01907 L
Mistroke
.25532 .01908 L
.25651 .01908 L
.25921 .01909 L
.26209 .0191 L
.2724 .01916 L
.27782 .01919 L
.28078 .0192 L
.28222 .01921 L
.28354 .01921 L
.2847 .01921 L
.28596 .01922 L
.28666 .01922 L
.2873 .01922 L
.28856 .01922 L
.28983 .01922 L
.29055 .01922 L
.29123 .01922 L
.29194 .01922 L
.29259 .01922 L
.29331 .01922 L
.29406 .01922 L
.29522 .01921 L
.29645 .01921 L
.29868 .01921 L
.30372 .01919 L
.30907 .01916 L
.31399 .01913 L
.32511 .01906 L
.34527 .01893 L
.36407 .01884 L
.37475 .01881 L
.38473 .01879 L
.38972 .01878 L
.39516 .01877 L
.39996 .01876 L
.40505 .01876 L
.40963 .01875 L
.41469 .01875 L
.41928 .01875 L
.4236 .01875 L
.42869 .01875 L
.43342 .01875 L
.43836 .01874 L
.44376 .01874 L
.45263 .01874 L
.46226 .01874 L
.46772 .01874 L
.47276 .01874 L
.47758 .01874 L
.48269 .01874 L
Mistroke
.49153 .01873 L
.50127 .01873 L
.54158 .0187 L
.56013 .01869 L
.58037 .01867 L
.60152 .01867 L
.62162 .01866 L
.6413 .01866 L
.66228 .01865 L
.68371 .01865 L
.70388 .01865 L
.72398 .01865 L
.74245 .01865 L
.76129 .01865 L
.77198 .01865 L
.78196 .01865 L
.79242 .01865 L
.80233 .01865 L
.82089 .01865 L
.84081 .01865 L
.85924 .01865 L
.87792 .01865 L
.88867 .01865 L
.89853 .01865 L
.91789 .01865 L
.92805 .01865 L
.93875 .01865 L
.94813 .01865 L
.95329 .01865 L
.95815 .01865 L
.96269 .01865 L
.9676 .01865 L
.97619 .01865 L
Mfstroke
.458 1 0 r
.02381 .01472 m
.03279 .09427 L
.03793 .13184 L
.04262 .15951 L
.04758 .18119 L
.0503 .18965 L
.05156 .19273 L
.05288 .19546 L
.05402 .19737 L
.05527 .19903 L
.0564 .20017 L
.05747 .20091 L
.05872 .20142 L
.05987 .20156 L
.06119 .20135 L
.06244 .20082 L
.0631 .20043 L
.06381 .19991 L
.0651 .19876 L
.0675 .19595 L
.07289 .18727 L
.08259 .16741 L
.10458 .12327 L
.12452 .09469 L
.13456 .0844 L
.14558 .07563 L
.15579 .06945 L
.16509 .06511 L
.17583 .06133 L
.18601 .05872 L
.19566 .05696 L
.20054 .05629 L
.20592 .05571 L
.21049 .05534 L
.21306 .05518 L
.21542 .05506 L
.21749 .05498 L
.21868 .05494 L
.21976 .05491 L
.22091 .05489 L
.22213 .05488 L
.22327 .05487 L
.22434 .05487 L
.22549 .05488 L
.22673 .05489 L
.2279 .05491 L
.22897 .05494 L
.23022 .05498 L
.23158 .05504 L
.23406 .05517 L
Mistroke
.23664 .05535 L
.2394 .05561 L
.24435 .05623 L
.24675 .05662 L
.24934 .05712 L
.25403 .05827 L
.2586 .05974 L
.2628 .06144 L
.27269 .06652 L
.27812 .06947 L
.28327 .07186 L
.28559 .07273 L
.28805 .0735 L
.28934 .07384 L
.29075 .07415 L
.29206 .07439 L
.29325 .07457 L
.29435 .0747 L
.29551 .0748 L
.29667 .07487 L
.29794 .07491 L
.29905 .07491 L
.30022 .07489 L
.30133 .07484 L
.30234 .07477 L
.30348 .07467 L
.30472 .07453 L
.30724 .07418 L
.31174 .07335 L
.32191 .0708 L
.34037 .0656 L
.35985 .06105 L
.37078 .05918 L
.37562 .05851 L
.38076 .05792 L
.38546 .05747 L
.39066 .05709 L
.39293 .05696 L
.39538 .05684 L
.3977 .05676 L
.39881 .05673 L
.39982 .0567 L
.40103 .05668 L
.40232 .05667 L
.40351 .05666 L
.40464 .05667 L
.40596 .05668 L
.40718 .05669 L
.40781 .05671 L
.40851 .05672 L
Mistroke
.40992 .05677 L
.41257 .05688 L
.41542 .05705 L
.41811 .05725 L
.42057 .05748 L
.43043 .05879 L
.43957 .06045 L
.45025 .0626 L
.45548 .06358 L
.4603 .06437 L
.46501 .06501 L
.47017 .06553 L
.47285 .06573 L
.47536 .06586 L
.47674 .06591 L
.478 .06595 L
.4787 .06596 L
.47946 .06598 L
.48018 .06598 L
.48084 .06599 L
.4819 .06599 L
.48305 .06598 L
.48414 .06597 L
.48513 .06595 L
.48623 .06592 L
.48744 .06588 L
.48986 .06578 L
.49227 .06564 L
.49483 .06546 L
.49945 .06508 L
.52081 .06255 L
.54097 .05993 L
.5593 .05786 L
.57945 .05607 L
.59934 .05477 L
.62039 .0538 L
.63985 .05315 L
.66075 .05265 L
.68194 .05227 L
.70205 .05199 L
.74031 .05158 L
.76004 .05142 L
.78103 .05128 L
.82269 .05107 L
.86282 .05093 L
.90145 .05082 L
.94252 .05073 L
.97619 .05067 L
Mfstroke
.435 1 0 r
.02381 .01472 m
.03279 .09416 L
.03793 .13149 L
.04262 .15914 L
.04758 .18163 L
.0503 .19112 L
.05288 .19832 L
.05527 .20356 L
.05747 .20727 L
.05988 .21022 L
.0611 .2113 L
.0618 .21179 L
.06244 .21218 L
.06315 .21253 L
.06379 .21279 L
.0645 .21299 L
.06525 .21314 L
.06591 .2132 L
.06662 .2132 L
.06792 .21303 L
.06919 .21269 L
.06982 .21245 L
.07053 .21214 L
.07293 .21072 L
.07574 .20846 L
.07876 .20547 L
.0842 .19901 L
.10458 .17083 L
.12439 .14697 L
.13558 .13649 L
.14594 .1287 L
.15591 .12277 L
.16526 .11843 L
.17502 .11502 L
.1802 .11363 L
.18579 .11243 L
.19074 .11161 L
.19536 .11106 L
.19801 .11083 L
.20042 .11067 L
.20175 .11061 L
.20246 .11059 L
.2032 .11056 L
.20385 .11055 L
.20457 .11054 L
.20583 .11053 L
.2065 .11053 L
.20724 .11053 L
.20793 .11054 L
.20857 .11056 L
Mistroke
.20979 .11059 L
.21108 .11065 L
.21261 .11074 L
.21404 .11085 L
.21673 .11111 L
.21928 .11143 L
.22163 .1118 L
.22693 .11293 L
.23164 .11432 L
.23669 .11632 L
.24145 .11884 L
.24579 .12184 L
.25088 .12648 L
.25641 .13335 L
.26164 .14197 L
.26647 .15174 L
.27547 .17186 L
.2802 .1812 L
.28517 .18879 L
.28782 .19174 L
.28923 .19299 L
.29072 .19408 L
.2921 .19487 L
.29336 .19542 L
.29462 .19582 L
.29581 .19606 L
.29702 .19616 L
.2983 .19614 L
.2994 .19601 L
.3006 .19576 L
.30189 .19538 L
.30328 .19485 L
.30578 .19358 L
.31106 .1899 L
.31594 .18559 L
.327 .17425 L
.34711 .15387 L
.36575 .13922 L
.37637 .13305 L
.38635 .1286 L
.39616 .12534 L
.4011 .12408 L
.40651 .12294 L
.41113 .12215 L
.41608 .12146 L
.425 .12049 L
.43523 .11967 L
.44062 .11932 L
.44632 .11902 L
.45131 .11881 L
Mistroke
.45396 .11872 L
.4568 .11864 L
.45814 .11861 L
.45941 .11859 L
.46065 .11857 L
.46179 .11855 L
.46288 .11854 L
.46403 .11853 L
.46531 .11852 L
.46647 .11852 L
.46767 .11852 L
.4688 .11853 L
.47003 .11854 L
.47135 .11855 L
.47273 .11856 L
.47404 .11858 L
.4765 .11863 L
.48092 .11873 L
.48573 .11888 L
.50655 .11967 L
.51676 .12003 L
.52634 .1203 L
.53633 .12052 L
.54736 .12071 L
.56585 .12101 L
.57632 .12124 L
.58606 .12153 L
.59576 .12193 L
.60612 .12248 L
.62722 .12401 L
.66874 .12808 L
.70874 .132 L
.74723 .13507 L
.78817 .1378 L
.82759 .14022 L
.8655 .14239 L
.90586 .14449 L
.9447 .14631 L
.97619 .14769 L
Mfstroke
.411 1 0 r
.02381 .01472 m
.02846 .05766 L
.03279 .09268 L
.03754 .12325 L
.0402 .13629 L
.04262 .14558 L
.04385 .14942 L
.04516 .15285 L
.04629 .15531 L
.0475 .15748 L
.04881 .15928 L
.05003 .16051 L
.05077 .16107 L
.05148 .16146 L
.05212 .16171 L
.05281 .16188 L
.05408 .16192 L
.05523 .16169 L
.05587 .16146 L
.05656 .16114 L
.05781 .16037 L
.06022 .15831 L
.06244 .15588 L
.08253 .12516 L
.09317 .10947 L
.10458 .09537 L
.11526 .08478 L
.125 .0771 L
.13425 .07129 L
.14407 .06642 L
.15398 .06262 L
.16315 .05992 L
.17302 .05772 L
.17833 .05679 L
.18391 .05598 L
.18873 .05541 L
.19401 .0549 L
.1988 .05454 L
.20326 .05429 L
.20598 .05418 L
.20731 .05414 L
.20854 .0541 L
.20964 .05407 L
.21085 .05405 L
.21206 .05403 L
.21334 .05402 L
.21406 .05401 L
.21475 .05401 L
.21603 .05401 L
.21674 .05401 L
Mistroke
.21741 .05402 L
.21813 .05403 L
.21891 .05404 L
.22032 .05406 L
.22164 .05409 L
.22412 .05417 L
.22653 .05428 L
.22879 .05441 L
.23147 .05459 L
.23391 .0548 L
.23889 .05535 L
.24423 .05618 L
.24879 .05713 L
.25373 .05849 L
.2584 .06017 L
.26272 .06208 L
.27172 .06693 L
.27645 .06948 L
.28142 .07173 L
.28408 .07268 L
.28698 .07348 L
.28825 .07375 L
.28961 .07399 L
.2909 .07417 L
.29206 .0743 L
.29334 .07439 L
.29453 .07444 L
.29582 .07446 L
.29648 .07446 L
.2972 .07444 L
.2984 .07439 L
.2997 .0743 L
.30092 .07419 L
.30204 .07406 L
.30683 .07332 L
.31193 .07224 L
.3211 .06986 L
.34185 .06421 L
.3512 .06201 L
.3613 .05998 L
.37076 .05843 L
.37957 .05727 L
.38912 .05628 L
.3946 .05583 L
.39959 .05549 L
.40978 .05496 L
.41538 .05474 L
.42068 .05457 L
.45911 .05353 L
.47857 .05299 L
Mistroke
.4889 .05275 L
.5 .05252 L
.51062 .05234 L
.52033 .05221 L
.5302 .0521 L
.53937 .05202 L
.54933 .05194 L
.55837 .05189 L
.56319 .05187 L
.5684 .05185 L
.57391 .05183 L
.57641 .05183 L
.5791 .05182 L
.58167 .05182 L
.58402 .05182 L
.58515 .05182 L
.58638 .05182 L
.58754 .05181 L
.58861 .05181 L
.58985 .05181 L
.59102 .05181 L
.5923 .05181 L
.59302 .05181 L
.59367 .05182 L
.59493 .05182 L
.59629 .05182 L
.59905 .05182 L
.60182 .05182 L
.60433 .05183 L
.60997 .05184 L
.61519 .05186 L
.62012 .05188 L
.64015 .05198 L
.65861 .05211 L
.69803 .05241 L
.73594 .05269 L
.7763 .05294 L
.81514 .05317 L
.85644 .0534 L
.89622 .05361 L
.93448 .0538 L
.9752 .054 L
.97619 .054 L
Mfstroke
.387 1 0 r
.02381 .01472 m
.03279 .09448 L
.04262 .164 L
.04758 .19168 L
.05288 .21593 L
.05789 .23396 L
.06244 .24656 L
.06507 .25228 L
.06785 .25722 L
.07022 .26059 L
.07283 .26345 L
.07427 .26468 L
.07564 .26562 L
.07721 .26647 L
.07791 .26676 L
.07865 .26702 L
.07936 .26722 L
.08 .26736 L
.08126 .26752 L
.08196 .26755 L
.08272 .26754 L
.08344 .26749 L
.0841 .26741 L
.08529 .26718 L
.08656 .26683 L
.08885 .26593 L
.09158 .26447 L
.09406 .26282 L
.10458 .25346 L
.12528 .23105 L
.14443 .21272 L
.15401 .20543 L
.16301 .19984 L
.1724 .1953 L
.17738 .19342 L
.18275 .19178 L
.18771 .19064 L
.19009 .19021 L
.19233 .18989 L
.1936 .18973 L
.19498 .18959 L
.19613 .1895 L
.19739 .18942 L
.19809 .18938 L
.19875 .18936 L
.19945 .18933 L
.2002 .18932 L
.2009 .18931 L
.20156 .18932 L
.2028 .18934 L
Mistroke
.20348 .18936 L
.20413 .18939 L
.20533 .18946 L
.20663 .18956 L
.20803 .1897 L
.21056 .19004 L
.21289 .19046 L
.21824 .19182 L
.22094 .19274 L
.22389 .19395 L
.22915 .1967 L
.23413 .20017 L
.23859 .20419 L
.24344 .20979 L
.24872 .21777 L
.25432 .229 L
.26437 .25741 L
.27399 .29016 L
.27923 .30641 L
.2841 .31881 L
.28828 .32691 L
.29062 .33036 L
.29274 .33283 L
.29507 .33483 L
.29639 .33564 L
.2976 .33619 L
.29866 .33652 L
.29982 .33673 L
.30104 .33677 L
.30217 .33667 L
.30338 .3364 L
.30468 .33594 L
.30592 .33535 L
.30706 .33468 L
.31153 .33103 L
.31639 .32547 L
.32156 .31825 L
.34243 .28391 L
.35201 .26892 L
.3621 .25516 L
.37144 .24464 L
.38015 .23687 L
.38937 .2308 L
.39425 .22848 L
.39947 .22669 L
.40216 .22603 L
.40358 .22576 L
.40509 .22553 L
.4064 .22537 L
.40709 .22531 L
Mistroke
.40784 .22525 L
.40916 .22519 L
.41039 .22516 L
.41166 .22517 L
.41238 .2252 L
.41305 .22523 L
.41427 .22532 L
.41558 .22545 L
.41686 .22563 L
.41806 .22582 L
.42032 .22628 L
.42498 .22761 L
.42762 .2286 L
.43009 .22969 L
.44041 .23593 L
.44933 .24346 L
.45889 .2532 L
.47871 .27472 L
.48917 .28437 L
.4949 .28872 L
.50027 .29215 L
.50541 .29481 L
.51012 .29674 L
.51535 .29835 L
.51809 .29899 L
.52098 .29952 L
.52328 .29984 L
.52453 .29998 L
.52572 .3001 L
.52683 .30019 L
.52803 .30026 L
.52913 .30032 L
.53013 .30036 L
.53133 .30038 L
.53245 .3004 L
.53367 .3004 L
.53499 .30038 L
.53565 .30036 L
.53637 .30034 L
.53768 .30029 L
.54014 .30017 L
.5427 .29999 L
.54547 .29976 L
.55049 .29925 L
.55986 .2982 L
.56988 .29716 L
.57262 .29693 L
.57556 .29671 L
.57831 .29655 L
.58085 .29643 L
Mistroke
.58208 .29638 L
.58343 .29634 L
.58479 .2963 L
.58554 .29629 L
.58623 .29628 L
.58751 .29627 L
.58868 .29627 L
.58933 .29627 L
.59003 .29628 L
.59132 .29629 L
.59257 .29632 L
.59371 .29635 L
.59626 .29645 L
.59862 .29657 L
.60085 .29671 L
.60612 .29716 L
.61097 .2977 L
.62193 .29929 L
.64234 .30312 L
.6614 .30679 L
.67972 .30964 L
.68999 .31079 L
.69936 .31155 L
.70417 .31184 L
.7068 .31196 L
.70927 .31206 L
.71363 .3122 L
.71594 .31225 L
.71844 .31229 L
.71974 .3123 L
.72096 .31231 L
.72165 .31232 L
.72229 .31232 L
.72302 .31232 L
.72371 .31232 L
.72439 .31232 L
.7251 .31232 L
.72638 .31232 L
.72709 .31231 L
.72775 .31231 L
.72927 .3123 L
.73055 .31228 L
.73177 .31226 L
.73405 .31223 L
.7392 .31211 L
.74424 .31195 L
.7488 .31178 L
.75903 .31132 L
.77743 .31031 L
.81754 .30769 L
Mistroke
.85613 .30476 L
.89717 .30112 L
.9367 .29725 L
.97471 .29345 L
.97619 .2933 L
Mfstroke
.364 1 0 r
.02381 .01472 m
.03279 .09447 L
.04262 .16374 L
.04758 .19109 L
.05288 .21482 L
.05789 .23228 L
.06244 .24432 L
.06507 .24973 L
.06785 .25437 L
.07022 .25749 L
.07283 .26012 L
.0743 .26125 L
.07564 .26207 L
.07637 .26245 L
.07718 .2628 L
.07795 .26308 L
.07865 .26328 L
.07936 .26344 L
.08002 .26355 L
.08072 .26363 L
.08148 .26367 L
.08214 .26367 L
.08285 .26363 L
.0841 .26346 L
.08538 .26319 L
.08654 .26285 L
.08915 .26179 L
.09157 .26048 L
.09387 .25901 L
.10458 .24992 L
.1228 .23133 L
.14291 .21293 L
.15243 .206 L
.16268 .19996 L
.16834 .19728 L
.17352 .19521 L
.17844 .19359 L
.18369 .19222 L
.18633 .19167 L
.18883 .19125 L
.19126 .19091 L
.19349 .19068 L
.19459 .19059 L
.19562 .19052 L
.19669 .19047 L
.19787 .19043 L
.19907 .1904 L
.20016 .1904 L
.20142 .19042 L
.20262 .19047 L
Mistroke
.20392 .19054 L
.2051 .19062 L
.20775 .1909 L
.21021 .19127 L
.21252 .19171 L
.21771 .19307 L
.22063 .19408 L
.22332 .1952 L
.22803 .19763 L
.23308 .20104 L
.23784 .20521 L
.24218 .21005 L
.24727 .21734 L
.2528 .22779 L
.25803 .24058 L
.26286 .25497 L
.27263 .28825 L
.27776 .30475 L
.28315 .31922 L
.28789 .32879 L
.29058 .3328 L
.29308 .33561 L
.29427 .33665 L
.29539 .33746 L
.2964 .33805 L
.29748 .33853 L
.29865 .33889 L
.29973 .33908 L
.3009 .33913 L
.30217 .33901 L
.30339 .33874 L
.3047 .33828 L
.30595 .33769 L
.3071 .33701 L
.3116 .33335 L
.3165 .32781 L
.32172 .32064 L
.33998 .29119 L
.35965 .26203 L
.36826 .25182 L
.3777 .24275 L
.3871 .23593 L
.39224 .23315 L
.39702 .23116 L
.39973 .23028 L
.4023 .22961 L
.4046 .22915 L
.40589 .22895 L
.40709 .2288 L
.40839 .22867 L
Mistroke
.40908 .22862 L
.40981 .22858 L
.41059 .22855 L
.41132 .22853 L
.41198 .22853 L
.4127 .22853 L
.41399 .22858 L
.41472 .22862 L
.41538 .22866 L
.41666 .22878 L
.41787 .22893 L
.42028 .22932 L
.42253 .22981 L
.42764 .23136 L
.43262 .23347 L
.43796 .23645 L
.44763 .24367 L
.45644 .25204 L
.47715 .27467 L
.48626 .28397 L
.4963 .2927 L
.5059 .29924 L
.5149 .30376 L
.51986 .30565 L
.52441 .30705 L
.5294 .30826 L
.53465 .30924 L
.53966 .30995 L
.54421 .31044 L
.55441 .31126 L
.56333 .3119 L
.57278 .31275 L
.57754 .31332 L
.58277 .31407 L
.59198 .31576 L
.60273 .31837 L
.61278 .32138 L
.65163 .33555 L
.67139 .34224 L
.68182 .34522 L
.69292 .34791 L
.70376 .35007 L
.71357 .35165 L
.7327 .35389 L
.74276 .35472 L
.752 .35534 L
.76279 .35591 L
.77284 .35634 L
.79172 .35695 L
.80171 .35719 L
Mistroke
.80727 .3573 L
.8124 .35739 L
.81726 .35746 L
.82261 .35752 L
.8252 .35754 L
.82799 .35756 L
.82953 .35757 L
.83094 .35758 L
.83227 .35759 L
.8337 .35759 L
.83504 .3576 L
.83626 .3576 L
.83748 .3576 L
.83863 .3576 L
.83929 .3576 L
.83998 .3576 L
.84122 .3576 L
.84191 .3576 L
.84255 .3576 L
.84402 .35759 L
.84529 .35759 L
.8465 .35758 L
.84876 .35757 L
.85119 .35755 L
.85383 .35753 L
.85868 .35748 L
.86323 .35741 L
.8736 .35721 L
.88371 .35696 L
.8946 .35662 L
.93573 .35488 L
.97534 .35282 L
.97619 .35278 L
Mfstroke
.34 1 0 r
.02381 .01472 m
.03279 .09448 L
.04262 .16387 L
.04758 .19119 L
.05288 .21459 L
.05789 .23122 L
.06244 .24195 L
.06507 .24635 L
.0665 .24824 L
.06785 .24969 L
.06908 .25077 L
.07022 .25155 L
.07148 .25219 L
.07217 .25245 L
.07283 .25262 L
.07354 .25275 L
.07418 .25281 L
.07493 .25281 L
.07563 .25275 L
.07687 .25249 L
.07757 .25227 L
.07822 .25201 L
.07958 .25133 L
.08108 .25038 L
.0841 .24784 L
.08922 .24206 L
.09469 .23437 L
.10458 .21849 L
.12439 .18679 L
.13484 .17257 L
.14594 .15996 L
.15578 .1509 L
.16664 .14304 L
.17651 .13763 L
.18579 .13391 L
.19048 .13248 L
.19562 .13125 L
.19821 .13076 L
.20098 .13034 L
.20359 .13002 L
.20597 .12982 L
.20712 .12975 L
.20835 .12969 L
.20939 .12965 L
.21054 .12963 L
.21177 .12963 L
.21246 .12964 L
.21309 .12966 L
.21432 .1297 L
.21549 .12976 L
Mistroke
.21657 .12984 L
.21772 .12993 L
.21979 .13017 L
.22225 .13053 L
.22447 .13096 L
.22936 .13224 L
.23183 .13308 L
.23452 .13419 L
.2393 .13669 L
.24376 .1398 L
.24902 .14475 L
.25382 .15087 L
.25936 .16039 L
.26459 .17215 L
.27338 .19638 L
.28285 .22134 L
.28549 .22689 L
.28827 .23183 L
.29084 .23554 L
.29324 .23824 L
.29549 .24013 L
.29675 .24092 L
.29789 .24148 L
.29915 .24193 L
.29985 .24211 L
.30051 .24222 L
.30171 .24232 L
.30297 .24227 L
.30421 .24207 L
.30533 .24178 L
.30663 .2413 L
.30785 .24073 L
.31004 .23944 L
.31242 .23768 L
.32279 .22685 L
.34381 .19958 L
.36356 .1781 L
.37354 .17032 L
.37922 .16694 L
.38456 .16449 L
.38682 .16368 L
.38924 .16298 L
.39064 .16265 L
.3919 .1624 L
.39317 .16221 L
.39437 .16207 L
.39563 .16198 L
.39626 .16195 L
.39695 .16194 L
.39818 .16197 L
Mistroke
.39933 .16204 L
.40003 .16211 L
.40069 .1622 L
.40193 .16241 L
.40326 .16271 L
.40472 .16313 L
.40715 .16406 L
.40936 .16518 L
.41174 .16668 L
.41431 .16868 L
.4189 .17329 L
.42321 .17891 L
.43273 .19542 L
.44317 .21779 L
.45419 .24104 L
.459 .24966 L
.46424 .25744 L
.46676 .26053 L
.46945 .2633 L
.47193 .2654 L
.47427 .26696 L
.47644 .26806 L
.47766 .26853 L
.47878 .26887 L
.47994 .26913 L
.48121 .26932 L
.48185 .26937 L
.48253 .26939 L
.48376 .26937 L
.48445 .26931 L
.48517 .26922 L
.48647 .26898 L
.48787 .26861 L
.4894 .26808 L
.49215 .26682 L
.49472 .26531 L
.50468 .25705 L
.54352 .2122 L
.56329 .19288 L
.57372 .18462 L
.58482 .17721 L
.59566 .17121 L
.60547 .16669 L
.6246 .15982 L
.6439 .15481 L
.66474 .15077 L
.70582 .14503 L
.74538 .14102 L
.78342 .13815 L
.82392 .13594 L
Mistroke
.8629 .13434 L
.90433 .13299 L
.94425 .13189 L
.97619 .13113 L
Mfstroke
.316 1 0 r
.02381 .01472 m
.03279 .09401 L
.03793 .13055 L
.04262 .15651 L
.045 .16689 L
.04758 .17605 L
.0503 .18344 L
.05153 .18605 L
.05288 .18844 L
.05404 .19011 L
.0553 .19153 L
.05662 .19264 L
.05785 .19334 L
.05908 .19372 L
.06025 .19383 L
.0613 .19373 L
.06244 .19342 L
.06316 .19312 L
.06382 .19279 L
.0653 .19184 L
.06799 .18949 L
.07302 .18344 L
.08429 .16595 L
.10458 .13432 L
.1234 .11196 L
.13409 .10252 L
.14407 .09554 L
.15452 .08983 L
.16442 .0857 L
.17331 .08287 L
.17829 .08159 L
.18298 .08058 L
.18788 .07971 L
.19238 .07906 L
.19737 .0785 L
.19999 .07827 L
.20275 .07808 L
.20526 .07795 L
.20667 .0779 L
.20795 .07786 L
.20914 .07783 L
.21043 .07781 L
.21166 .0778 L
.21278 .07781 L
.21409 .07782 L
.21532 .07785 L
.21603 .07786 L
.21667 .07789 L
.21811 .07794 L
.2195 .07801 L
Mistroke
.22101 .0781 L
.22376 .07832 L
.22632 .07858 L
.22909 .07894 L
.2341 .07979 L
.23898 .08094 L
.24347 .08236 L
.24834 .08441 L
.25368 .08746 L
.25926 .09181 L
.26446 .09709 L
.27493 .11001 L
.28009 .11586 L
.28235 .11803 L
.28485 .12006 L
.28693 .12146 L
.28917 .12265 L
.2904 .12317 L
.29153 .12357 L
.2926 .12387 L
.29375 .12412 L
.29492 .1243 L
.296 .1244 L
.29729 .12444 L
.29846 .12441 L
.29969 .12431 L
.30038 .12422 L
.30101 .12413 L
.30342 .12362 L
.30587 .12289 L
.30811 .12208 L
.31314 .11981 L
.32222 .11479 L
.34287 .10263 L
.36193 .09347 L
.37271 .08953 L
.38268 .08665 L
.3923 .08449 L
.40133 .08295 L
.41123 .08172 L
.42192 .08077 L
.46303 .07794 L
.48353 .07642 L
.50262 .07519 L
.52102 .07429 L
.53132 .0739 L
.54069 .07362 L
.55 .07339 L
.55986 .0732 L
.57067 .07305 L
Mistroke
.57588 .07299 L
.58064 .07295 L
.58515 .07291 L
.59006 .07288 L
.59276 .07287 L
.59526 .07286 L
.5978 .07285 L
.60019 .07284 L
.60243 .07284 L
.6036 .07283 L
.60484 .07283 L
.60589 .07283 L
.60704 .07283 L
.60808 .07283 L
.60906 .07283 L
.61028 .07283 L
.61144 .07283 L
.61248 .07283 L
.61361 .07283 L
.61485 .07283 L
.61615 .07283 L
.6185 .07284 L
.62088 .07284 L
.62339 .07285 L
.62788 .07286 L
.63799 .07291 L
.64672 .07296 L
.65627 .07302 L
.69685 .07339 L
.73592 .07378 L
.77743 .07419 L
.81744 .07458 L
.85592 .07497 L
.89686 .07538 L
.93628 .07577 L
.97419 .07614 L
.97619 .07616 L
Mfstroke
.292 1 0 r
.02381 .01472 m
.03279 .094 L
.03793 .1305 L
.04262 .15635 L
.045 .16662 L
.04758 .17562 L
.04899 .17965 L
.0503 .18281 L
.05164 .18549 L
.05288 .18756 L
.05404 .18909 L
.05509 .1902 L
.05626 .19112 L
.05752 .19176 L
.05873 .19206 L
.06005 .19207 L
.06129 .1918 L
.06244 .19132 L
.06311 .19095 L
.06382 .19049 L
.06509 .1895 L
.06795 .18661 L
.07314 .17958 L
.08284 .16329 L
.10458 .12701 L
.11406 .11413 L
.12422 .10265 L
.14255 .08732 L
.15272 .08128 L
.16379 .07627 L
.17424 .07277 L
.18391 .07039 L
.18855 .06951 L
.19354 .06872 L
.19786 .06817 L
.20258 .0677 L
.20529 .06749 L
.20781 .06733 L
.21048 .06721 L
.21197 .06716 L
.21263 .06714 L
.21332 .06712 L
.21459 .0671 L
.21576 .06709 L
.21701 .06708 L
.21773 .06709 L
.21839 .06709 L
.2196 .06711 L
.2207 .06713 L
.22197 .06717 L
Mistroke
.22318 .06721 L
.22578 .06734 L
.22822 .06751 L
.23279 .06797 L
.23535 .06831 L
.23771 .06868 L
.24302 .06978 L
.2473 .07099 L
.25198 .07274 L
.25687 .07518 L
.26142 .07813 L
.27048 .08594 L
.2801 .09501 L
.28511 .09876 L
.28797 .10039 L
.29064 .10158 L
.29184 .10199 L
.29309 .10236 L
.29418 .10262 L
.29533 .10285 L
.29659 .10302 L
.29775 .10313 L
.29846 .10317 L
.29913 .10318 L
.30038 .10318 L
.30162 .10311 L
.30232 .10306 L
.30297 .10299 L
.30429 .10281 L
.3057 .10257 L
.30827 .102 L
.3106 .10135 L
.32167 .09712 L
.3418 .0878 L
.36247 .07948 L
.37156 .0766 L
.38161 .07399 L
.39054 .07214 L
.40017 .07059 L
.41035 .06939 L
.41991 .06858 L
.42946 .068 L
.43992 .06749 L
.46102 .06652 L
.50154 .06426 L
.52026 .06334 L
.54056 .06257 L
.55165 .06226 L
.56188 .06202 L
.57228 .06184 L
Mistroke
.58202 .0617 L
.59105 .0616 L
.60076 .06152 L
.61154 .06145 L
.62139 .0614 L
.62617 .06138 L
.63125 .06137 L
.64039 .06135 L
.64599 .06134 L
.65127 .06133 L
.656 .06133 L
.65867 .06132 L
.66112 .06132 L
.66358 .06132 L
.66583 .06132 L
.66707 .06132 L
.66772 .06132 L
.66842 .06132 L
.66969 .06132 L
.67087 .06132 L
.67194 .06132 L
.6731 .06132 L
.67419 .06132 L
.67519 .06132 L
.6763 .06132 L
.67752 .06132 L
.67996 .06132 L
.68268 .06132 L
.68514 .06132 L
.69067 .06133 L
.70063 .06134 L
.71062 .06135 L
.71983 .06136 L
.74063 .0614 L
.78005 .06148 L
.81796 .06158 L
.85832 .0617 L
.89717 .06182 L
.93846 .06195 L
.97619 .06207 L
Mfstroke
.269 1 0 r
.02381 .01472 m
.02846 .0569 L
.03068 .07343 L
.03279 .0855 L
.03398 .09062 L
.03527 .09477 L
.03645 .09736 L
.03754 .09889 L
.03871 .09973 L
.04 .09988 L
.04065 .0997 L
.04135 .09934 L
.04262 .09837 L
.04393 .09699 L
.04516 .09546 L
.04793 .09147 L
.05297 .08341 L
.06244 .06891 L
.07295 .05577 L
.08284 .04624 L
.09424 .03807 L
.10458 .03265 L
.11434 .02884 L
.12466 .02585 L
.13346 .02393 L
.14313 .02234 L
.15334 .02109 L
.16264 .02024 L
.17338 .01952 L
.18355 .01903 L
.19321 .01868 L
.20346 .01842 L
.21222 .01825 L
.22188 .01812 L
.2268 .01807 L
.23198 .01803 L
.2364 .018 L
.24123 .01797 L
.24397 .01796 L
.24646 .01796 L
.24783 .01795 L
.24933 .01795 L
.25062 .01795 L
.25204 .01795 L
.25335 .01794 L
.25458 .01794 L
.25587 .01794 L
.2566 .01794 L
.25727 .01794 L
.25845 .01794 L
Mistroke
.25974 .01794 L
.26096 .01795 L
.26209 .01795 L
.26474 .01795 L
.26718 .01796 L
.27268 .01797 L
.27744 .01798 L
.27874 .01798 L
.28013 .01798 L
.28134 .01798 L
.28265 .01798 L
.28392 .01798 L
.28509 .01798 L
.28621 .01798 L
.28739 .01798 L
.28845 .01798 L
.28945 .01798 L
.29054 .01798 L
.29171 .01798 L
.29414 .01798 L
.2967 .01797 L
.30127 .01796 L
.31084 .01793 L
.32105 .01789 L
.33943 .01782 L
.3497 .01778 L
.36082 .01775 L
.37131 .01773 L
.38098 .01772 L
.38567 .01771 L
.3907 .01771 L
.39505 .0177 L
.39978 .0177 L
.40266 .0177 L
.40532 .0177 L
.40787 .0177 L
.40917 .0177 L
.41058 .0177 L
.41184 .0177 L
.41299 .0177 L
.4141 .0177 L
.41526 .0177 L
.41654 .0177 L
.41773 .0177 L
.41904 .0177 L
.41977 .0177 L
.42044 .0177 L
.42162 .0177 L
.42274 .0177 L
.42527 .0177 L
Mistroke
.42774 .0177 L
.4304 .0177 L
.4396 .0177 L
.45038 .0177 L
.46038 .01771 L
.46528 .01771 L
.46802 .01771 L
.4705 .01771 L
.47192 .01771 L
.47323 .01771 L
.47392 .01771 L
.47467 .01771 L
.47545 .01771 L
.47618 .01771 L
.47688 .01771 L
.47753 .01771 L
.47877 .01771 L
.47946 .01771 L
.48009 .01771 L
.48153 .01771 L
.48393 .01771 L
.48617 .01771 L
.49128 .01771 L
.49626 .01771 L
.50163 .0177 L
.54279 .01768 L
.56333 .01767 L
.58243 .01767 L
.60087 .01766 L
.62056 .01766 L
.64192 .01766 L
.66208 .01765 L
.70057 .01765 L
.7415 .01765 L
.78093 .01765 L
.81883 .01764 L
.85919 .01764 L
.89804 .01764 L
.93933 .01764 L
.97619 .01764 L
Mfstroke
.245 1 0 r
.02381 .01472 m
.03279 .09448 L
.04262 .16396 L
.04758 .1915 L
.05288 .21538 L
.05789 .23278 L
.06244 .2445 L
.06507 .24958 L
.06785 .25374 L
.07022 .25636 L
.07157 .25748 L
.07283 .25831 L
.07353 .25868 L
.07428 .25901 L
.075 .25926 L
.07567 .25943 L
.07692 .25962 L
.07763 .25965 L
.07826 .25963 L
.07901 .25955 L
.07971 .25943 L
.08047 .25924 L
.08127 .25898 L
.08262 .25842 L
.0841 .25763 L
.08678 .25577 L
.08922 .25367 L
.09469 .24779 L
.10458 .23467 L
.12528 .20531 L
.14443 .18283 L
.16301 .16738 L
.1724 .16186 L
.17744 .15947 L
.18275 .15738 L
.18757 .15583 L
.19285 .15452 L
.19517 .15407 L
.19764 .15367 L
.19998 .15337 L
.2021 .15317 L
.2034 .15308 L
.20411 .15304 L
.20478 .153 L
.20596 .15296 L
.20725 .15295 L
.20797 .15295 L
.20866 .15295 L
.20994 .15299 L
.21066 .15302 L
Mistroke
.21132 .15305 L
.21283 .15316 L
.21416 .15328 L
.2154 .15342 L
.21774 .15377 L
.22025 .15425 L
.22296 .15491 L
.22789 .15653 L
.23249 .15862 L
.23753 .1617 L
.24294 .16621 L
.2486 .17276 L
.25397 .18127 L
.25878 .19135 L
.26401 .20514 L
.27337 .23475 L
.27828 .25005 L
.28344 .26392 L
.28619 .27002 L
.2892 .27552 L
.29194 .27944 L
.29449 .28217 L
.29584 .28327 L
.29711 .28409 L
.29826 .28465 L
.2995 .28508 L
.30014 .28524 L
.30085 .28535 L
.30159 .28541 L
.30228 .28541 L
.30352 .28529 L
.30421 .28515 L
.30485 .28499 L
.306 .28458 L
.30728 .284 L
.30986 .2824 L
.31451 .27833 L
.31993 .27207 L
.32503 .2652 L
.34417 .237 L
.35398 .22383 L
.36432 .21216 L
.37315 .2043 L
.37779 .20103 L
.38282 .19818 L
.38556 .19695 L
.3881 .19603 L
.39052 .19536 L
.39174 .1951 L
.39242 .19498 L
Mistroke
.39308 .19488 L
.39429 .19473 L
.3954 .19466 L
.39659 .19463 L
.3979 .19467 L
.39903 .19477 L
.40024 .19494 L
.40138 .19516 L
.40241 .19542 L
.40511 .19635 L
.40759 .19756 L
.41032 .19932 L
.41319 .20167 L
.41804 .20688 L
.42335 .21443 L
.43357 .23376 L
.44287 .25474 L
.45374 .2789 L
.45852 .28827 L
.46379 .29724 L
.46825 .30354 L
.47306 .30892 L
.47571 .31124 L
.47813 .31298 L
.48045 .31429 L
.48289 .31531 L
.4842 .31571 L
.48538 .31598 L
.48603 .3161 L
.48675 .3162 L
.48803 .31631 L
.48924 .31633 L
.49052 .31627 L
.49161 .31615 L
.49281 .31595 L
.49423 .31562 L
.49552 .31524 L
.49842 .31413 L
.50366 .31127 L
.50845 .30786 L
.51354 .30358 L
.5227 .29472 L
.54344 .2729 L
.56347 .25402 L
.57399 .24579 L
.58509 .23845 L
.59508 .23296 L
.60602 .22799 L
.62523 .22137 L
.6448 .21644 L
Mistroke
.66573 .21219 L
.70716 .20481 L
.74708 .19839 L
.78548 .19325 L
.82634 .18895 L
.86567 .18559 L
.9035 .18277 L
.94377 .1801 L
.97619 .17817 L
Mfstroke
.221 1 0 r
.02381 .01472 m
.03279 .09449 L
.04262 .16413 L
.04758 .1919 L
.05288 .21618 L
.05789 .23409 L
.06244 .24641 L
.06507 .25189 L
.06785 .25651 L
.07022 .25955 L
.07283 .26199 L
.0743 .26298 L
.07564 .26365 L
.07637 .26394 L
.07718 .26418 L
.07794 .26434 L
.07865 .26444 L
.07936 .26449 L
.08004 .26449 L
.08129 .26437 L
.08199 .26425 L
.08264 .26409 L
.0841 .26362 L
.08529 .26311 L
.08656 .26245 L
.08885 .26099 L
.09406 .25659 L
.10458 .2447 L
.12439 .2193 L
.13484 .20709 L
.14594 .19595 L
.15578 .18781 L
.16664 .18071 L
.17651 .17589 L
.18579 .17271 L
.19048 .17157 L
.19317 .17106 L
.19562 .17069 L
.19821 .17039 L
.19963 .17027 L
.20098 .17018 L
.20223 .17012 L
.20337 .17009 L
.20463 .17008 L
.20527 .17008 L
.20597 .17009 L
.2072 .17013 L
.20838 .17019 L
.20943 .17026 L
.21058 .17036 L
Mistroke
.21315 .17066 L
.21553 .17105 L
.21986 .17204 L
.22228 .17276 L
.22447 .17354 L
.22936 .17572 L
.23452 .17883 L
.23893 .18233 L
.24376 .1873 L
.24897 .1944 L
.25454 .20462 L
.2598 .21727 L
.26459 .23133 L
.27387 .2621 L
.27895 .27791 L
.28372 .29035 L
.28885 .30043 L
.29158 .30427 L
.29298 .30585 L
.29451 .30725 L
.29574 .30815 L
.29705 .3089 L
.29778 .30921 L
.29844 .30945 L
.29972 .30975 L
.3009 .30985 L
.30218 .30979 L
.30338 .30957 L
.30449 .30924 L
.30575 .30872 L
.30694 .30809 L
.30918 .30657 L
.31421 .30181 L
.32329 .28986 L
.34394 .25749 L
.35358 .24362 L
.36383 .23108 L
.37258 .22245 L
.38224 .2153 L
.38715 .21268 L
.38983 .21154 L
.39232 .21068 L
.39445 .2101 L
.39555 .20985 L
.39673 .20964 L
.39803 .20945 L
.39926 .20933 L
.40046 .20926 L
.40157 .20925 L
.40276 .20928 L
Mistroke
.40405 .20937 L
.40527 .20952 L
.40638 .2097 L
.40768 .20998 L
.4091 .21035 L
.41169 .21125 L
.41438 .21248 L
.41725 .21413 L
.42241 .21801 L
.42778 .22327 L
.43271 .22918 L
.44384 .24554 L
.46402 .2781 L
.47311 .29023 L
.47812 .29565 L
.48285 .29987 L
.48553 .30186 L
.48845 .3037 L
.49087 .30498 L
.49355 .30613 L
.49606 .30697 L
.49735 .30731 L
.49873 .30761 L
.50002 .30784 L
.5012 .308 L
.50233 .30811 L
.50352 .30818 L
.50476 .30821 L
.50546 .30821 L
.5061 .3082 L
.50728 .30814 L
.50853 .30804 L
.50965 .30792 L
.5107 .30778 L
.51308 .30735 L
.51565 .30676 L
.518 .3061 L
.52328 .30427 L
.54165 .29567 L
.5623 .28541 L
.57234 .28117 L
.58143 .27799 L
.59099 .27534 L
.59997 .27347 L
.60491 .27268 L
.60946 .27209 L
.6144 .27157 L
.6197 .27114 L
.62481 .27083 L
.62947 .27061 L
Mistroke
.63415 .27045 L
.63857 .27034 L
.64861 .27013 L
.65411 .27001 L
.65926 .26989 L
.66876 .26958 L
.6738 .26937 L
.67922 .26908 L
.69766 .26772 L
.70776 .26673 L
.71878 .26549 L
.73887 .26296 L
.7795 .25764 L
.81862 .25298 L
.86019 .24841 L
.90024 .24415 L
.93878 .24016 L
.97619 .2365 L
Mfstroke
.198 1 0 r
.02381 .01472 m
.02846 .05774 L
.03279 .09296 L
.03523 .10956 L
.03754 .12245 L
.03881 .12828 L
.0402 .13351 L
.04145 .13726 L
.04262 .13996 L
.04376 .14189 L
.045 .14321 L
.0457 .14365 L
.04637 .14387 L
.04762 .14381 L
.04894 .14316 L
.05016 .14211 L
.0515 .14054 L
.05293 .13848 L
.06244 .11972 L
.07287 .0981 L
.08414 .07855 L
.09479 .06423 L
.10458 .05412 L
.11422 .04648 L
.1248 .04015 L
.13585 .03529 L
.14616 .03195 L
.15661 .02946 L
.16651 .02771 L
.1754 .02653 L
.18507 .02556 L
.19447 .02486 L
.20484 .0243 L
.21006 .02409 L
.21568 .02391 L
.22095 .02377 L
.22585 .02367 L
.23048 .0236 L
.23307 .02357 L
.23542 .02355 L
.23668 .02354 L
.23801 .02353 L
.2387 .02353 L
.23947 .02353 L
.24017 .02352 L
.24081 .02352 L
.24208 .02352 L
.24277 .02352 L
.24344 .02352 L
.24461 .02352 L
Mistroke
.24589 .02352 L
.24658 .02353 L
.24733 .02353 L
.24868 .02354 L
.2512 .02356 L
.25414 .02359 L
.25684 .02362 L
.26178 .02371 L
.26699 .02383 L
.2765 .02406 L
.27923 .02412 L
.28182 .02416 L
.28417 .0242 L
.28667 .02423 L
.28772 .02424 L
.28884 .02425 L
.29008 .02426 L
.29124 .02426 L
.29232 .02426 L
.29344 .02426 L
.29441 .02426 L
.29546 .02426 L
.29672 .02426 L
.29786 .02425 L
.29918 .02424 L
.30042 .02423 L
.30502 .02418 L
.30966 .02412 L
.31476 .02403 L
.32507 .02382 L
.34353 .02345 L
.36302 .02315 L
.37395 .02303 L
.38393 .02294 L
.38872 .02291 L
.39382 .02288 L
.39823 .02286 L
.40299 .02285 L
.40807 .02283 L
.41285 .02282 L
.41561 .02282 L
.41712 .02282 L
.41853 .02282 L
.42102 .02281 L
.42233 .02281 L
.42306 .02281 L
.42374 .02281 L
.42497 .02281 L
.42562 .02281 L
.42632 .02281 L
Mistroke
.42706 .02281 L
.42775 .02281 L
.42906 .02281 L
.43028 .02281 L
.43141 .02281 L
.43265 .02281 L
.43397 .02281 L
.43979 .02282 L
.44506 .02282 L
.45017 .02283 L
.45556 .02283 L
.45778 .02283 L
.46016 .02283 L
.46152 .02283 L
.46277 .02283 L
.46402 .02283 L
.46521 .02283 L
.46631 .02283 L
.46753 .02283 L
.4688 .02283 L
.47 .02283 L
.47111 .02283 L
.47213 .02283 L
.47443 .02283 L
.47677 .02283 L
.47932 .02283 L
.48447 .02282 L
.48969 .02281 L
.49526 .0228 L
.50529 .02278 L
.52522 .02273 L
.54681 .02268 L
.56763 .02264 L
.58681 .02261 L
.60559 .02259 L
.62623 .02258 L
.66659 .02256 L
.70544 .02254 L
.7252 .02253 L
.74673 .02253 L
.78652 .02252 L
.80624 .02252 L
.82723 .02251 L
.86889 .02251 L
.90903 .02251 L
.94765 .0225 L
.97619 .0225 L
Mfstroke
.174 1 0 r
.02381 .01472 m
.02499 .02568 L
.02605 .03421 L
.02729 .04147 L
.02846 .04577 L
.02954 .04802 L
.03053 .0491 L
.03163 .04957 L
.03279 .04955 L
.03395 .04921 L
.0352 .04861 L
.03746 .04721 L
.04262 .04351 L
.0521 .03707 L
.06244 .03147 L
.07373 .02694 L
.08445 .02381 L
.09489 .02158 L
.10458 .02006 L
.11515 .01883 L
.1251 .01799 L
.13404 .01742 L
.14371 .01696 L
.15321 .01662 L
.16365 .01634 L
.17454 .01614 L
.18471 .016 L
.19516 .0159 L
.20506 .01583 L
.21395 .01578 L
.22362 .01574 L
.23302 .01572 L
.23837 .01571 L
.2434 .0157 L
.24867 .01569 L
.25351 .01569 L
.25604 .01569 L
.25881 .01568 L
.26171 .01568 L
.2644 .01568 L
.2735 .01568 L
.27848 .01568 L
.28314 .01568 L
.28556 .01568 L
.28817 .01568 L
.29371 .01568 L
.30345 .01567 L
.32479 .01566 L
.34495 .01564 L
.35508 .01564 L
Mistroke
.36612 .01564 L
.37117 .01563 L
.37655 .01563 L
.38622 .01563 L
.3916 .01563 L
.39653 .01563 L
.39934 .01563 L
.40196 .01563 L
.40468 .01563 L
.40612 .01563 L
.40767 .01563 L
.40904 .01563 L
.4103 .01563 L
.4115 .01563 L
.41278 .01563 L
.41392 .01563 L
.41499 .01563 L
.41616 .01563 L
.41742 .01563 L
.41869 .01563 L
.42008 .01563 L
.42287 .01563 L
.42545 .01563 L
.42786 .01563 L
.44663 .01563 L
.45651 .01563 L
.46191 .01563 L
.46695 .01563 L
.46951 .01563 L
.47226 .01563 L
.47382 .01563 L
.47531 .01563 L
.47664 .01563 L
.47739 .01563 L
.47809 .01563 L
.47931 .01563 L
.48045 .01563 L
.4817 .01563 L
.48241 .01563 L
.48306 .01563 L
.48429 .01563 L
.48563 .01563 L
.48834 .01563 L
.49098 .01563 L
.49339 .01563 L
.49878 .01563 L
.5085 .01563 L
.54845 .01563 L
.56675 .01563 L
.58689 .01563 L
Mistroke
.60674 .01562 L
.62777 .01562 L
.66808 .01562 L
.70687 .01562 L
.74812 .01562 L
.78785 .01562 L
.82606 .01562 L
.86673 .01562 L
.90587 .01562 L
.94748 .01562 L
.97619 .01562 L
Mfstroke
.15 1 0 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .0213 L
.02954 .02124 L
.03053 .02115 L
.03279 .02089 L
.04262 .01956 L
.05285 .01839 L
.06244 .01754 L
.07218 .01689 L
.0829 .01636 L
.09334 .01599 L
.10458 .01569 L
.11468 .0155 L
.12571 .01535 L
.13613 .01525 L
.1458 .01518 L
.15637 .01512 L
.16633 .01508 L
.17526 .01506 L
.18493 .01504 L
.19444 .01502 L
.20487 .01501 L
.21013 .015 L
.21577 .015 L
.22594 .01499 L
.23122 .01499 L
.23611 .01499 L
.24137 .01499 L
.24718 .01499 L
.25221 .01499 L
.25693 .01499 L
.26192 .01499 L
.2673 .01498 L
.30844 .01498 L
.32896 .01498 L
.33897 .01498 L
.34806 .01498 L
.3569 .01498 L
.36649 .01498 L
.37175 .01498 L
.37661 .01498 L
.38161 .01498 L
.38617 .01498 L
.39084 .01498 L
.39325 .01498 L
.39586 .01498 L
.39828 .01498 L
Mistroke
.40052 .01498 L
.40266 .01498 L
.40376 .01498 L
.40493 .01498 L
.4056 .01498 L
.40633 .01498 L
.40762 .01498 L
.40834 .01498 L
.40912 .01498 L
.40985 .01498 L
.41051 .01498 L
.41181 .01498 L
.41254 .01498 L
.41321 .01498 L
.41445 .01498 L
.41577 .01498 L
.41817 .01498 L
.42043 .01498 L
.42557 .01498 L
.43543 .01498 L
.4458 .01498 L
.4555 .01498 L
.46431 .01498 L
.46924 .01498 L
.4715 .01498 L
.47388 .01498 L
.4751 .01498 L
.47644 .01498 L
.47767 .01498 L
.47879 .01498 L
.48011 .01498 L
.48084 .01498 L
.48153 .01498 L
.48276 .01498 L
.48345 .01498 L
.48409 .01498 L
.48514 .01498 L
.48628 .01498 L
.48735 .01498 L
.48833 .01498 L
.4906 .01498 L
.493 .01498 L
.49752 .01498 L
.50247 .01498 L
.51273 .01498 L
.52206 .01498 L
.543 .01498 L
.56378 .01498 L
.58295 .01498 L
.60161 .01498 L
Mistroke
.62139 .01498 L
.65924 .01498 L
.69955 .01498 L
.73834 .01498 L
.75807 .01498 L
.77959 .01498 L
.81931 .01498 L
.85998 .01498 L
.89913 .01498 L
.94073 .01498 L
.97619 .01498 L
Mfstroke
.126 1 0 r
.02381 .01472 m
.03279 .09437 L
.04262 .16185 L
.04758 .18688 L
.0503 .19805 L
.05288 .20699 L
.05528 .21395 L
.05789 .22011 L
.06008 .22424 L
.06244 .22769 L
.06381 .22925 L
.06506 .23042 L
.06633 .23136 L
.06751 .23203 L
.06817 .23232 L
.06887 .23257 L
.06965 .23277 L
.07036 .23289 L
.07103 .23295 L
.07176 .23295 L
.07308 .23282 L
.07378 .23268 L
.07444 .2325 L
.07593 .23195 L
.07739 .23123 L
.07895 .23029 L
.08435 .22582 L
.09493 .21372 L
.10458 .20118 L
.12528 .17601 L
.13438 .16685 L
.14443 .1583 L
.15337 .15206 L
.16301 .14666 L
.17319 .14234 L
.18275 .13946 L
.18771 .13839 L
.19233 .13764 L
.19498 .13732 L
.19739 .1371 L
.19872 .137 L
.20017 .13692 L
.20083 .13689 L
.20154 .13687 L
.2028 .13684 L
.2041 .13683 L
.2053 .13683 L
.20596 .13685 L
.20668 .13686 L
.20799 .13691 L
Mistroke
.20921 .13698 L
.21051 .13707 L
.21284 .13729 L
.21583 .13768 L
.21864 .13818 L
.22389 .13944 L
.22856 .14102 L
.23368 .14335 L
.23903 .14664 L
.24401 .15076 L
.24869 .15586 L
.25294 .16186 L
.25785 .17079 L
.2625 .18143 L
.27129 .20605 L
.28075 .23167 L
.2834 .23736 L
.28618 .24239 L
.28875 .24614 L
.29114 .24885 L
.29339 .25072 L
.29465 .25149 L
.2958 .25203 L
.29705 .25245 L
.29776 .25261 L
.29841 .2527 L
.29961 .25277 L
.30088 .25268 L
.30211 .25244 L
.30323 .25211 L
.30453 .2516 L
.30576 .25098 L
.31032 .2478 L
.31529 .24301 L
.32069 .23674 L
.34171 .20899 L
.36107 .18649 L
.37136 .17702 L
.38246 .16884 L
.39301 .16288 L
.40269 .15881 L
.41195 .15595 L
.4217 .15371 L
.45977 .14752 L
.47936 .14511 L
.49033 .1441 L
.5003 .14339 L
.50961 .14286 L
.51946 .14242 L
.53028 .14204 L
Mistroke
.54025 .14178 L
.54508 .14168 L
.54967 .1416 L
.5522 .14157 L
.55496 .14153 L
.5575 .14151 L
.5598 .14149 L
.56094 .14149 L
.56217 .14148 L
.56333 .14148 L
.5644 .14148 L
.56553 .14147 L
.56678 .14147 L
.56808 .14148 L
.5693 .14148 L
.57044 .14148 L
.57152 .14149 L
.57355 .1415 L
.57573 .14152 L
.57811 .14155 L
.58296 .14163 L
.58752 .14173 L
.59251 .14187 L
.5979 .14205 L
.60886 .14254 L
.61891 .14313 L
.63785 .14455 L
.65855 .14647 L
.69913 .15063 L
.7382 .15446 L
.77972 .15824 L
.81972 .16185 L
.85821 .16535 L
.89914 .16903 L
.93857 .17248 L
.97619 .17572 L
Mfstroke
.103 1 0 r
.02381 .01472 m
.03279 .09438 L
.04262 .16189 L
.04758 .18676 L
.0503 .19771 L
.05288 .2063 L
.05528 .2128 L
.05789 .2183 L
.05904 .22023 L
.06026 .22196 L
.0613 .2232 L
.06244 .22429 L
.06314 .22483 L
.06378 .22525 L
.06505 .22585 L
.0662 .22615 L
.06743 .22623 L
.06813 .22617 L
.06888 .22602 L
.06959 .2258 L
.07025 .22554 L
.07149 .22489 L
.0728 .224 L
.07519 .22186 L
.07742 .21937 L
.0825 .21228 L
.10458 .17264 L
.12322 .14252 L
.14349 .11884 L
.15452 .10966 L
.16473 .1031 L
.17448 .0983 L
.17989 .09617 L
.18485 .09453 L
.19422 .09214 L
.19914 .09124 L
.20164 .09087 L
.20432 .09053 L
.20669 .09029 L
.20884 .09012 L
.20988 .09005 L
.21101 .08998 L
.21206 .08994 L
.21305 .0899 L
.2142 .08987 L
.21546 .08985 L
.2167 .08985 L
.21739 .08985 L
.21802 .08986 L
.21914 .08988 L
Mistroke
.22037 .08993 L
.22153 .08998 L
.2226 .09004 L
.22525 .09025 L
.22769 .09052 L
.23037 .09091 L
.23319 .09142 L
.23795 .09259 L
.24316 .0944 L
.24782 .09662 L
.2528 .09986 L
.2575 .10398 L
.26178 .10882 L
.27184 .12431 L
.27735 .13394 L
.28252 .1422 L
.28691 .14791 L
.28917 .15026 L
.29163 .15236 L
.29419 .154 L
.29558 .15468 L
.29688 .15517 L
.2981 .15552 L
.2992 .15574 L
.30048 .1559 L
.30168 .15594 L
.30283 .1559 L
.3039 .15579 L
.30508 .15559 L
.30634 .15529 L
.30892 .15444 L
.31127 .1534 L
.31581 .15084 L
.32011 .14787 L
.34006 .13126 L
.35826 .11696 L
.36862 .11029 L
.37836 .1051 L
.38866 .10073 L
.39811 .09762 L
.40821 .09513 L
.41352 .09413 L
.41911 .09325 L
.42864 .0921 L
.43883 .09119 L
.45718 .08984 L
.49865 .08613 L
.51943 .08429 L
.5386 .08294 L
.55726 .08199 L
Mistroke
.56667 .08162 L
.57703 .0813 L
.58699 .08105 L
.59646 .08087 L
.60737 .0807 L
.61734 .08058 L
.62694 .08049 L
.63716 .08041 L
.65555 .08031 L
.66585 .08027 L
.67698 .08023 L
.68749 .08021 L
.69716 .08019 L
.70186 .08018 L
.7069 .08018 L
.71126 .08017 L
.716 .08017 L
.71888 .08017 L
.72155 .08017 L
.7241 .08016 L
.72539 .08016 L
.72608 .08016 L
.72681 .08016 L
.72809 .08016 L
.72926 .08016 L
.73052 .08016 L
.73123 .08016 L
.73189 .08016 L
.7331 .08016 L
.7342 .08016 L
.73547 .08016 L
.73666 .08016 L
.73906 .08017 L
.7413 .08017 L
.74639 .08017 L
.75136 .08017 L
.75669 .08018 L
.77515 .0802 L
.79634 .08023 L
.81645 .08027 L
.85471 .08037 L
.89543 .08048 L
.93463 .08059 L
.97619 .08071 L
Mfstroke
.079 1 0 r
.02381 .01472 m
.03279 .09418 L
.03793 .13124 L
.04262 .15761 L
.04517 .16859 L
.04758 .17667 L
.04881 .17994 L
.05012 .18278 L
.05156 .18517 L
.05225 .18606 L
.05288 .18673 L
.05401 .1876 L
.05523 .18808 L
.05636 .18814 L
.05743 .18787 L
.05868 .18719 L
.05983 .18625 L
.0611 .18491 L
.06244 .18315 L
.06791 .17349 L
.07382 .16041 L
.08454 .13546 L
.0941 .11531 L
.10458 .09681 L
.1142 .08316 L
.12452 .07163 L
.13541 .06231 L
.14558 .05572 L
.15576 .05072 L
.16682 .04668 L
.17727 .04388 L
.18694 .04197 L
.19657 .04059 L
.20561 .03966 L
.21078 .03927 L
.21552 .03899 L
.22073 .03876 L
.22335 .03868 L
.22484 .03865 L
.22621 .03862 L
.22744 .0386 L
.22875 .03858 L
.23006 .03857 L
.2308 .03857 L
.2315 .03857 L
.23275 .03857 L
.2339 .03858 L
.23454 .03858 L
.23523 .03859 L
.23649 .03861 L
Mistroke
.23772 .03863 L
.23883 .03866 L
.24133 .03873 L
.24364 .03882 L
.24582 .03893 L
.25107 .03929 L
.25589 .03975 L
.26119 .04043 L
.26677 .04133 L
.27627 .04308 L
.2815 .04394 L
.28407 .0443 L
.28645 .04457 L
.28868 .04478 L
.29105 .04494 L
.29228 .045 L
.29343 .04505 L
.29469 .04509 L
.2954 .0451 L
.29605 .04511 L
.29711 .04512 L
.29809 .04511 L
.29917 .0451 L
.30031 .04508 L
.30152 .04504 L
.30266 .045 L
.3048 .0449 L
.30944 .04458 L
.31454 .04412 L
.32485 .043 L
.34331 .0409 L
.3628 .03912 L
.37373 .03839 L
.38371 .03787 L
.3936 .03749 L
.40277 .03723 L
.40755 .03713 L
.41283 .03705 L
.41548 .03701 L
.41834 .03698 L
.42084 .03696 L
.42352 .03694 L
.42611 .03692 L
.42847 .03691 L
.43084 .0369 L
.43307 .03689 L
.43434 .03689 L
.43568 .03689 L
.43684 .03689 L
.43809 .03689 L
Mistroke
.43943 .03688 L
.44068 .03688 L
.44145 .03688 L
.44217 .03688 L
.44287 .03688 L
.44354 .03688 L
.44417 .03688 L
.44486 .03688 L
.44607 .03688 L
.44675 .03688 L
.44747 .03688 L
.44877 .03688 L
.44996 .03688 L
.45108 .03688 L
.45231 .03688 L
.45362 .03688 L
.45436 .03688 L
.45504 .03688 L
.45658 .03688 L
.45794 .03688 L
.45938 .03688 L
.46187 .03687 L
.46463 .03687 L
.46698 .03686 L
.46955 .03685 L
.47473 .03682 L
.47953 .03679 L
.48399 .03676 L
.50485 .03653 L
.54391 .03605 L
.55417 .03594 L
.56528 .03585 L
.57488 .03578 L
.58543 .03572 L
.60532 .03564 L
.6162 .0356 L
.62637 .03557 L
.66522 .03549 L
.70651 .03543 L
.72716 .0354 L
.74629 .03538 L
.78456 .03535 L
.80514 .03534 L
.82376 .03533 L
.8639 .03532 L
.90252 .03531 L
.9436 .0353 L
.97619 .03529 L
Mfstroke
.055 1 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02132 L
.03163 .02122 L
.03279 .02108 L
.04262 .01979 L
.05217 .01868 L
.06244 .01776 L
.0728 .01706 L
.0825 .01656 L
.09403 .01613 L
.10458 .01585 L
.11442 .01565 L
.12357 .01552 L
.1336 .01541 L
.14429 .01532 L
.15457 .01526 L
.1657 .01521 L
.17621 .01518 L
.18587 .01516 L
.19561 .01514 L
.2047 .01513 L
.21467 .01512 L
.22026 .01512 L
.22536 .01511 L
.23016 .01511 L
.23527 .01511 L
.23963 .01511 L
.24444 .01511 L
.24695 .01511 L
.2496 .01511 L
.25249 .01511 L
.25378 .0151 L
.25515 .0151 L
.25645 .0151 L
.25764 .0151 L
.25883 .0151 L
.25995 .0151 L
.26126 .0151 L
.26247 .0151 L
.2631 .0151 L
.2638 .0151 L
.26452 .0151 L
.2652 .0151 L
.27018 .0151 L
.27281 .0151 L
Mistroke
.27425 .0151 L
.27561 .0151 L
.2769 .0151 L
.27763 .0151 L
.2783 .0151 L
.27949 .0151 L
.28074 .0151 L
.28191 .0151 L
.283 .0151 L
.28421 .0151 L
.28549 .0151 L
.28788 .0151 L
.29048 .0151 L
.29519 .0151 L
.30403 .0151 L
.32345 .0151 L
.33376 .0151 L
.34486 .0151 L
.35545 .0151 L
.36515 .01509 L
.37443 .01509 L
.37954 .01509 L
.38418 .01509 L
.39375 .01509 L
.39901 .01509 L
.40396 .01509 L
.41279 .01509 L
.42234 .01509 L
.46331 .01509 L
.48371 .01509 L
.50277 .01509 L
.52107 .01509 L
.54071 .01509 L
.55086 .01509 L
.56192 .01509 L
.57148 .01509 L
.58204 .01509 L
.60179 .01509 L
.61261 .01509 L
.62279 .01509 L
.66144 .01509 L
.68146 .01509 L
.69153 .01509 L
.70255 .01509 L
.70782 .01509 L
.71281 .01509 L
.71734 .01509 L
.72213 .01509 L
.72462 .01509 L
.72736 .01509 L
Mistroke
.72985 .01509 L
.73218 .01509 L
.73359 .01509 L
.73492 .01509 L
.73612 .01509 L
.73743 .01509 L
.73817 .01509 L
.73885 .01509 L
.73963 .01509 L
.74036 .01509 L
.74167 .01509 L
.7424 .01509 L
.74308 .01509 L
.74554 .01509 L
.74778 .01509 L
.75037 .01509 L
.75282 .01509 L
.76192 .01509 L
.77182 .01509 L
.78258 .01509 L
.82339 .01509 L
.86267 .01509 L
.90044 .01509 L
.94067 .01509 L
.97619 .01509 L
Mfstroke
.032 1 0 r
.02381 .01472 m
.02846 .05763 L
.03279 .09213 L
.03523 .10807 L
.03754 .12028 L
.03881 .12576 L
.0402 .13068 L
.04145 .13421 L
.04262 .13677 L
.04376 .13863 L
.045 .13995 L
.0457 .14042 L
.04637 .14069 L
.04762 .14077 L
.04894 .14032 L
.05016 .13949 L
.05086 .13886 L
.0515 .1382 L
.05293 .13645 L
.05783 .12851 L
.06244 .11966 L
.07312 .09902 L
.08439 .08035 L
.09483 .06669 L
.10458 .05675 L
.11345 .04967 L
.12296 .04374 L
.13351 .03875 L
.14313 .03533 L
.15304 .03266 L
.16222 .03079 L
.17228 .02925 L
.18298 .02804 L
.19235 .02728 L
.19727 .02696 L
.20245 .02668 L
.207 .02647 L
.21198 .02629 L
.21618 .02616 L
.22073 .02605 L
.22348 .02599 L
.22601 .02595 L
.22839 .02592 L
.22965 .02591 L
.231 .02589 L
.23223 .02588 L
.23334 .02588 L
.23447 .02587 L
.23554 .02587 L
.23673 .02587 L
Mistroke
.23783 .02587 L
.23905 .02587 L
.24034 .02587 L
.24103 .02587 L
.24176 .02588 L
.24306 .02589 L
.24446 .0259 L
.246 .02591 L
.24876 .02595 L
.25133 .026 L
.25614 .02611 L
.26129 .02628 L
.27092 .02669 L
.27619 .02693 L
.28114 .02712 L
.28392 .02721 L
.28647 .02727 L
.2893 .02733 L
.29078 .02735 L
.2916 .02736 L
.29234 .02736 L
.29359 .02737 L
.29427 .02737 L
.29491 .02737 L
.29605 .02738 L
.29729 .02737 L
.29795 .02737 L
.29866 .02737 L
.30011 .02736 L
.30145 .02734 L
.3027 .02733 L
.30787 .02724 L
.31276 .02712 L
.32195 .02686 L
.3426 .02622 L
.35224 .02596 L
.36248 .02573 L
.37208 .02556 L
.3809 .02544 L
.39025 .02535 L
.39516 .02531 L
.39767 .0253 L
.40034 .02528 L
.40271 .02527 L
.40486 .02526 L
.40702 .02526 L
.40906 .02526 L
.41022 .02525 L
.41145 .02525 L
.41249 .02525 L
Mistroke
.41364 .02525 L
.41488 .02525 L
.41558 .02525 L
.41621 .02525 L
.41744 .02525 L
.41861 .02525 L
.41986 .02526 L
.42121 .02526 L
.42365 .02526 L
.42821 .02528 L
.43354 .0253 L
.43843 .02533 L
.45683 .02545 L
.46153 .02548 L
.46657 .0255 L
.46902 .02551 L
.47133 .02552 L
.47341 .02552 L
.47567 .02553 L
.47694 .02553 L
.47814 .02553 L
.47946 .02553 L
.4802 .02553 L
.48087 .02553 L
.48216 .02553 L
.48289 .02553 L
.48357 .02553 L
.48494 .02553 L
.4864 .02552 L
.48908 .02552 L
.49161 .02551 L
.49633 .0255 L
.50607 .02545 L
.51636 .02538 L
.53482 .02524 L
.57273 .02499 L
.59219 .0249 L
.61309 .02482 L
.63428 .02477 L
.65438 .02473 L
.67424 .02471 L
.69265 .02469 L
.71323 .02467 L
.73185 .02466 L
.75115 .02465 L
.77199 .02464 L
.79198 .02464 L
.81306 .02463 L
.85111 .02463 L
.87067 .02462 L
Mistroke
.89161 .02462 L
.93304 .02462 L
.97296 .02462 L
.97619 .02462 L
Mfstroke
.008 1 0 r
.02381 .01472 m
.03279 .09422 L
.04262 .15999 L
.04758 .18335 L
.0503 .19343 L
.05288 .20126 L
.05528 .20714 L
.05789 .2121 L
.06026 .21542 L
.06244 .21759 L
.06371 .21847 L
.06487 .21907 L
.0655 .21931 L
.0662 .21951 L
.06747 .2197 L
.06865 .21969 L
.06991 .2195 L
.0711 .21916 L
.07218 .21873 L
.07356 .21801 L
.07483 .2172 L
.0777 .21491 L
.0829 .20949 L
.10458 .17958 L
.125 .15345 L
.13497 .14322 L
.14407 .13542 L
.15285 .1292 L
.16239 .12375 L
.17248 .11933 L
.17741 .11762 L
.18204 .11626 L
.18694 .11507 L
.19144 .1142 L
.19643 .11348 L
.19905 .11319 L
.2005 .11307 L
.20181 .11297 L
.20302 .1129 L
.20433 .11283 L
.20504 .11281 L
.20571 .11279 L
.20701 .11276 L
.20813 .11275 L
.20936 .11275 L
.21064 .11278 L
.21185 .11281 L
.21252 .11284 L
.21326 .11288 L
.21461 .11296 L
Mistroke
.21714 .11317 L
.22009 .11352 L
.22282 .11395 L
.22791 .11505 L
.23078 .11587 L
.23342 .11677 L
.23827 .11886 L
.24338 .12185 L
.24798 .12545 L
.25227 .12983 L
.25697 .1361 L
.262 .14486 L
.27163 .16692 L
.28185 .19058 L
.28718 .19956 L
.29022 .20326 L
.2916 .2046 L
.29306 .20579 L
.2943 .20661 L
.29566 .20733 L
.2969 .20782 L
.29805 .20815 L
.29875 .20828 L
.29941 .20837 L
.30064 .20843 L
.30134 .20841 L
.30198 .20836 L
.30268 .20826 L
.30342 .20812 L
.30469 .20778 L
.3059 .20735 L
.30816 .2063 L
.31059 .20485 L
.31324 .20294 L
.32243 .19444 L
.34331 .17134 L
.36268 .1523 L
.37296 .1442 L
.38406 .13712 L
.39461 .13189 L
.40429 .12825 L
.41355 .12563 L
.4233 .12354 L
.46137 .11754 L
.4826 .11433 L
.5019 .1118 L
.51152 .11076 L
.52196 .1098 L
.54092 .10848 L
.55036 .108 L
Mistroke
.56077 .10759 L
.566 .10743 L
.57163 .10728 L
.57691 .10717 L
.5818 .10709 L
.5867 .10703 L
.58921 .107 L
.59192 .10698 L
.59347 .10697 L
.5949 .10696 L
.59624 .10695 L
.59771 .10695 L
.59903 .10695 L
.60026 .10694 L
.60156 .10694 L
.60229 .10694 L
.60295 .10694 L
.6042 .10694 L
.60483 .10694 L
.60552 .10694 L
.60675 .10695 L
.6079 .10695 L
.61048 .10696 L
.61327 .10698 L
.61837 .10702 L
.62305 .10707 L
.63286 .1072 L
.64198 .10737 L
.66269 .10785 L
.70176 .10897 L
.74327 .11024 L
.78328 .11145 L
.82176 .11265 L
.8627 .11396 L
.90212 .11522 L
.94003 .11641 L
.97619 .11754 L
Mfstroke
0 1 .016 r
.02381 .01472 m
.03279 .09417 L
.03793 .13138 L
.04262 .1584 L
.045 .16937 L
.04758 .17911 L
.04899 .1835 L
.0503 .18696 L
.05164 .18991 L
.05288 .19216 L
.05404 .19382 L
.05509 .195 L
.05626 .19594 L
.05752 .19655 L
.05873 .19677 L
.06005 .19661 L
.06129 .19613 L
.06244 .19541 L
.06382 .19424 L
.06509 .1929 L
.06795 .18905 L
.07314 .17999 L
.08284 .15964 L
.10458 .11658 L
.1234 .09014 L
.13409 .0794 L
.14407 .07161 L
.15452 .06533 L
.16442 .06079 L
.17331 .05767 L
.18298 .05508 L
.19238 .05323 L
.19773 .05243 L
.20275 .05181 L
.20802 .05131 L
.21286 .05096 L
.2154 .05082 L
.21817 .05071 L
.21957 .05066 L
.22106 .05062 L
.22179 .05061 L
.22248 .0506 L
.22376 .05058 L
.22491 .05057 L
.22615 .05057 L
.22732 .05058 L
.22839 .05059 L
.22964 .05061 L
.231 .05064 L
.23229 .05068 L
Mistroke
.23348 .05073 L
.2361 .05086 L
.23846 .05101 L
.2412 .05124 L
.24377 .0515 L
.24839 .05213 L
.25264 .0529 L
.2573 .05401 L
.26222 .05553 L
.27245 .05973 L
.27748 .06198 L
.28213 .06384 L
.28634 .06521 L
.28849 .06576 L
.29081 .06623 L
.29202 .06643 L
.29313 .06658 L
.29425 .06671 L
.2953 .0668 L
.29645 .06688 L
.29771 .06694 L
.29894 .06696 L
.30025 .06695 L
.30157 .06691 L
.30278 .06685 L
.30411 .06675 L
.30552 .06663 L
.30789 .06635 L
.3105 .06597 L
.3198 .06414 L
.34072 .05906 L
.35157 .05663 L
.36184 .05465 L
.37185 .05306 L
.38112 .05187 L
.39014 .05095 L
.39973 .05021 L
.40936 .04968 L
.41484 .04946 L
.41999 .04929 L
.42468 .04918 L
.42981 .04908 L
.43516 .049 L
.44015 .04894 L
.45865 .04876 L
.46915 .04861 L
.47908 .04843 L
.49766 .04798 L
.53609 .047 L
.55595 .04663 L
Mistroke
.56596 .04648 L
.57698 .04635 L
.59641 .04618 L
.60731 .04611 L
.61729 .04605 L
.63629 .04597 L
.65702 .04591 L
.67835 .04585 L
.69768 .04581 L
.71808 .04577 L
.73683 .04575 L
.75609 .04572 L
.77692 .04571 L
.79576 .04569 L
.81643 .04568 L
.83595 .04568 L
.85687 .04567 L
.86705 .04567 L
.87813 .04567 L
.88769 .04567 L
.89825 .04567 L
.90846 .04566 L
.91804 .04566 L
.92332 .04566 L
.92816 .04566 L
.93069 .04566 L
.93347 .04566 L
.93487 .04566 L
.93636 .04566 L
.93777 .04566 L
.93905 .04566 L
.94016 .04566 L
.9412 .04566 L
.94234 .04566 L
.94356 .04566 L
.94484 .04566 L
.94605 .04566 L
.94714 .04566 L
.94833 .04566 L
.95048 .04566 L
.95277 .04566 L
.95688 .04566 L
.9621 .04566 L
.96702 .04566 L
.97619 .04566 L
Mfstroke
0 1 .04 r
.02381 .01472 m
.03279 .09448 L
.04262 .16391 L
.04758 .19153 L
.05288 .21577 L
.05785 .2338 L
.06244 .24676 L
.06788 .25804 L
.07075 .2624 L
.07379 .26596 L
.07642 .26826 L
.07889 .2698 L
.0803 .27044 L
.08159 .27088 L
.08231 .27107 L
.08309 .27123 L
.08382 .27134 L
.08451 .27141 L
.08577 .27146 L
.08648 .27144 L
.08713 .27139 L
.08833 .27124 L
.0896 .27099 L
.09074 .2707 L
.0918 .27037 L
.09422 .26942 L
.09922 .26676 L
.10458 .26311 L
.12439 .24653 L
.13484 .23786 L
.14594 .2297 L
.15578 .22365 L
.16664 .21839 L
.17139 .21658 L
.17651 .21496 L
.18135 .21375 L
.18579 .21292 L
.18827 .21257 L
.19053 .21233 L
.19178 .21222 L
.19313 .21214 L
.19441 .21208 L
.19559 .21205 L
.19668 .21203 L
.1977 .21204 L
.19882 .21206 L
.20002 .21211 L
.20128 .21218 L
.20247 .21227 L
.20471 .2125 L
Mistroke
.2072 .21286 L
.20985 .21336 L
.21461 .21459 L
.21753 .21558 L
.22028 .21669 L
.22541 .2193 L
.23008 .22238 L
.2352 .22673 L
.24054 .23265 L
.24553 .23982 L
.25446 .25806 L
.25946 .2719 L
.26401 .2866 L
.27329 .31898 L
.27837 .33521 L
.28314 .34798 L
.28827 .35848 L
.291 .36259 L
.2924 .36432 L
.29393 .3659 L
.29516 .36695 L
.29647 .36786 L
.2972 .36827 L
.29786 .36859 L
.29914 .36906 L
.30032 .36933 L
.3016 .36944 L
.3028 .36939 L
.30391 .3692 L
.30517 .36885 L
.30636 .36838 L
.3086 .36715 L
.31101 .36538 L
.31363 .36297 L
.32271 .3517 L
.34337 .31877 L
.36273 .29032 L
.37375 .2776 L
.38412 .26833 L
.38891 .26494 L
.39396 .26197 L
.39832 .25989 L
.40299 .25816 L
.40562 .25739 L
.40802 .25683 L
.41043 .25638 L
.41271 .25606 L
.414 .25593 L
.41536 .25582 L
.41653 .25575 L
Mistroke
.41781 .2557 L
.41853 .25569 L
.41919 .25569 L
.41995 .25569 L
.42067 .25571 L
.42195 .25575 L
.42268 .25579 L
.42335 .25584 L
.42464 .25595 L
.426 .25609 L
.42843 .25643 L
.43105 .25692 L
.43393 .2576 L
.43908 .2592 L
.44389 .26117 L
.45287 .26605 L
.4625 .27277 L
.48233 .289 L
.49278 .29721 L
.50388 .30472 L
.51373 .31008 L
.52459 .31461 L
.53447 .31767 L
.54375 .31988 L
.56224 .32346 L
.57271 .32558 L
.58245 .32791 L
.60251 .33429 L
.62361 .34333 L
.66268 .36262 L
.68261 .37153 L
.7042 .37957 L
.7442 .39047 L
.78514 .39852 L
.82456 .4049 L
.86247 .40995 L
.90283 .41413 L
.94167 .41723 L
.97619 .41951 L
Mfstroke
0 1 .063 r
.02381 .01472 m
.03279 .09419 L
.03793 .13135 L
.04262 .15802 L
.04517 .16929 L
.04758 .17774 L
.05012 .18434 L
.05156 .18704 L
.05288 .18891 L
.05402 .19006 L
.05509 .19078 L
.05626 .19118 L
.05752 .19119 L
.05884 .19077 L
.06009 .19001 L
.06122 .18905 L
.06244 .18773 L
.0653 .18373 L
.06799 .17904 L
.07302 .16872 L
.08429 .14325 L
.09416 .12243 L
.10458 .10377 L
.11415 .0898 L
.12466 .07762 L
.13421 .06897 L
.14313 .0626 L
.15358 .05682 L
.16348 .05268 L
.17237 .04983 L
.18204 .04748 L
.19144 .04579 L
.20181 .04447 L
.20703 .04399 L
.21265 .04359 L
.21523 .04345 L
.21796 .04333 L
.22028 .04325 L
.2216 .04321 L
.22282 .04318 L
.22403 .04315 L
.22536 .04313 L
.22605 .04313 L
.22669 .04312 L
.22737 .04312 L
.22811 .04311 L
.22875 .04311 L
.22944 .04311 L
.23071 .04312 L
.23195 .04313 L
Mistroke
.2331 .04315 L
.23432 .04317 L
.23547 .0432 L
.23762 .04327 L
.23993 .04338 L
.24243 .04352 L
.24774 .04393 L
.25042 .04421 L
.25335 .04459 L
.25854 .04542 L
.26338 .04643 L
.27244 .04875 L
.28206 .05115 L
.28447 .05162 L
.28707 .05204 L
.28856 .05223 L
.28992 .05239 L
.29131 .05252 L
.2926 .05261 L
.2937 .05267 L
.29487 .05272 L
.29617 .05276 L
.29735 .05277 L
.29858 .05277 L
.29928 .05276 L
.29992 .05274 L
.3011 .05271 L
.30234 .05265 L
.30487 .0525 L
.30759 .05227 L
.31248 .05173 L
.32362 .05015 L
.34376 .04709 L
.35391 .04577 L
.36497 .0446 L
.37541 .04374 L
.38007 .04343 L
.38508 .04315 L
.3901 .04292 L
.3947 .04275 L
.39909 .04262 L
.40152 .04257 L
.40373 .04253 L
.40619 .0425 L
.40754 .04248 L
.40882 .04247 L
.41 .04247 L
.41109 .04246 L
.41229 .04246 L
.41356 .04246 L
Mistroke
.41483 .04247 L
.41555 .04247 L
.4162 .04247 L
.41747 .04248 L
.41868 .0425 L
.42138 .04253 L
.42432 .04259 L
.42964 .04272 L
.43465 .04289 L
.44401 .04329 L
.45421 .04377 L
.45978 .04402 L
.46498 .04421 L
.46961 .04434 L
.47198 .0444 L
.47457 .04445 L
.47603 .04447 L
.47739 .04448 L
.47869 .0445 L
.47935 .0445 L
.48007 .04451 L
.48129 .04451 L
.48245 .04451 L
.48312 .04451 L
.48382 .04451 L
.48508 .04451 L
.48624 .0445 L
.48729 .04449 L
.48965 .04447 L
.49184 .04444 L
.4939 .0444 L
.49854 .0443 L
.50356 .04416 L
.54449 .0425 L
.56487 .04175 L
.58392 .04119 L
.6022 .04078 L
.62182 .04046 L
.64301 .04021 L
.66312 .04004 L
.68298 .03991 L
.70139 .03983 L
.72023 .03975 L
.74059 .03969 L
.76205 .03964 L
.78224 .0396 L
.80184 .03957 L
.82332 .03954 L
.86288 .03951 L
.90337 .03948 L
Mistroke
.94235 .03946 L
.97619 .03945 L
Mfstroke
0 1 .087 r
.02381 .01472 m
.03279 .09447 L
.04262 .16333 L
.04758 .18977 L
.0503 .20179 L
.05288 .21148 L
.05528 .21905 L
.05789 .22571 L
.06026 .2304 L
.06244 .23362 L
.06371 .23501 L
.06487 .236 L
.0655 .23644 L
.0662 .23682 L
.06747 .23728 L
.06865 .23746 L
.06991 .23738 L
.0711 .23707 L
.07218 .23661 L
.07356 .23577 L
.07483 .23477 L
.0777 .23181 L
.0829 .22443 L
.10458 .18196 L
.125 .14529 L
.13497 .13126 L
.14407 .1207 L
.15285 .11234 L
.16239 .10504 L
.17248 .09906 L
.18204 .09478 L
.19144 .0917 L
.19679 .09038 L
.20181 .08941 L
.20438 .08901 L
.20709 .08866 L
.20943 .08841 L
.21192 .08821 L
.21334 .08812 L
.21462 .08805 L
.21591 .088 L
.21713 .08797 L
.21782 .08796 L
.21855 .08796 L
.21986 .08796 L
.22059 .08797 L
.22127 .08798 L
.22202 .088 L
.22282 .08803 L
.22416 .0881 L
Mistroke
.22537 .08817 L
.22808 .08841 L
.23059 .08871 L
.23295 .08907 L
.23826 .09022 L
.24125 .0911 L
.244 .09208 L
.24866 .09423 L
.25378 .09746 L
.25912 .10212 L
.2641 .10791 L
.27316 .12176 L
.28277 .13724 L
.28779 .14354 L
.29064 .14629 L
.29332 .14828 L
.29451 .14898 L
.29577 .1496 L
.29685 .15004 L
.29801 .15041 L
.29926 .1507 L
.30042 .15088 L
.30113 .15094 L
.3018 .15097 L
.30306 .15094 L
.30429 .15083 L
.30499 .15072 L
.30564 .1506 L
.30696 .15028 L
.30838 .14984 L
.31094 .14882 L
.31328 .14766 L
.32434 .14005 L
.34447 .12315 L
.35449 .11538 L
.36514 .10823 L
.37501 .10274 L
.38428 .09856 L
.39304 .09542 L
.40248 .09279 L
.40759 .09167 L
.41296 .09068 L
.418 .08992 L
.42258 .08934 L
.43211 .08843 L
.4423 .08773 L
.46066 .08667 L
.50061 .08358 L
.5189 .08207 L
.53904 .08067 L
Mistroke
.55889 .07966 L
.56976 .07924 L
.57993 .07893 L
.59032 .07868 L
.60019 .07849 L
.61872 .07822 L
.62832 .07812 L
.63854 .07803 L
.65693 .0779 L
.67836 .07779 L
.69854 .07772 L
.70831 .07769 L
.71863 .07767 L
.7283 .07765 L
.73711 .07763 L
.74659 .07762 L
.75182 .07762 L
.75676 .07761 L
.76132 .07761 L
.76555 .07761 L
.76775 .07761 L
.77018 .07761 L
.7714 .07761 L
.77272 .07761 L
.77396 .07761 L
.7751 .07761 L
.77638 .07761 L
.77758 .07761 L
.77867 .07761 L
.77984 .07761 L
.78112 .07761 L
.78177 .07761 L
.78248 .07761 L
.78491 .07761 L
.78718 .07761 L
.78963 .07761 L
.79404 .07761 L
.79959 .07761 L
.80486 .07761 L
.81474 .07762 L
.8346 .07764 L
.85301 .07766 L
.89221 .0777 L
.93386 .07776 L
.974 .07782 L
.97619 .07782 L
Mfstroke
0 1 .111 r
.02381 .01472 m
.02499 .02577 L
.02605 .03475 L
.02729 .04308 L
.02846 .04868 L
.02954 .05205 L
.03053 .05394 L
.03163 .05505 L
.03279 .05547 L
.03395 .05538 L
.0352 .05492 L
.03638 .05426 L
.03746 .05353 L
.04262 .04939 L
.0529 .04122 L
.06244 .0351 L
.07277 .03003 L
.08405 .02598 L
.09398 .02336 L
.10458 .02131 L
.11487 .01986 L
.12599 .01873 L
.1365 .01795 L
.14616 .01743 L
.1559 .01704 L
.16499 .01677 L
.17496 .01655 L
.18565 .01637 L
.19582 .01625 L
.20119 .0162 L
.20689 .01616 L
.21186 .01613 L
.21734 .0161 L
.22701 .01606 L
.23193 .01605 L
.2371 .01603 L
.24152 .01602 L
.24636 .01602 L
.24909 .01601 L
.25158 .01601 L
.25445 .01601 L
.25577 .01601 L
.25716 .01601 L
.25836 .01601 L
.25967 .01601 L
.26087 .01601 L
.26199 .01601 L
.2633 .01601 L
.26451 .01601 L
.26517 .01601 L
Mistroke
.26589 .01601 L
.26721 .01601 L
.26786 .01601 L
.26855 .01601 L
.26978 .01601 L
.27254 .01601 L
.2738 .01601 L
.27514 .01601 L
.27641 .01601 L
.27756 .01601 L
.27866 .01601 L
.27985 .01601 L
.28098 .01601 L
.28203 .01601 L
.28316 .01601 L
.2844 .01601 L
.28571 .01601 L
.28693 .01601 L
.2895 .01601 L
.2922 .016 L
.29703 .016 L
.30791 .01599 L
.32792 .01597 L
.34607 .01596 L
.35551 .01595 L
.36572 .01594 L
.37651 .01594 L
.38177 .01594 L
.38669 .01594 L
.39617 .01593 L
.4012 .01593 L
.4066 .01593 L
.42766 .01593 L
.46898 .01593 L
.5088 .01592 L
.52699 .01592 L
.5471 .01592 L
.56685 .01592 L
.5778 .01592 L
.58785 .01592 L
.60717 .01592 L
.62802 .01592 L
.64692 .01592 L
.66761 .01592 L
.68719 .01592 L
.69816 .01592 L
.70814 .01592 L
.7181 .01592 L
.7273 .01592 L
.7321 .01592 L
Mistroke
.73739 .01592 L
.74005 .01592 L
.74291 .01592 L
.74563 .01592 L
.74809 .01592 L
.75063 .01592 L
.75202 .01592 L
.75333 .01592 L
.75455 .01592 L
.75567 .01592 L
.7569 .01592 L
.7582 .01592 L
.75951 .01592 L
.76025 .01592 L
.76092 .01592 L
.76223 .01592 L
.76346 .01592 L
.76623 .01592 L
.76924 .01592 L
.7743 .01592 L
.77968 .01592 L
.78933 .01592 L
.8271 .01592 L
.86732 .01592 L
.90603 .01592 L
.94719 .01592 L
.97619 .01592 L
Mfstroke
0 1 .134 r
.02381 .01472 m
.03279 .0945 L
.04262 .16469 L
.05288 .21973 L
.06244 .25632 L
.06792 .27173 L
.0731 .28302 L
.07775 .29074 L
.0828 .29682 L
.08542 .29914 L
.0883 .3011 L
.08975 .30187 L
.09131 .30254 L
.09278 .30304 L
.09413 .30339 L
.09477 .30352 L
.09545 .30363 L
.09669 .30378 L
.09744 .30383 L
.09816 .30385 L
.09879 .30385 L
.09949 .30383 L
.10078 .30374 L
.10143 .30366 L
.10214 .30356 L
.10458 .30307 L
.10588 .30273 L
.10709 .30235 L
.10982 .30136 L
.11478 .29908 L
.12409 .29369 L
.145 .28008 L
.16367 .26999 L
.16878 .26786 L
.17429 .26594 L
.17946 .26449 L
.18198 .26392 L
.18427 .26348 L
.18649 .26312 L
.1889 .26281 L
.19022 .26267 L
.19144 .26258 L
.19261 .2625 L
.19384 .26245 L
.19508 .26242 L
.19578 .26241 L
.19642 .26241 L
.19765 .26243 L
.19883 .26247 L
.19949 .26251 L
Mistroke
.20019 .26255 L
.20145 .26265 L
.20295 .26281 L
.20431 .26299 L
.20703 .26345 L
.20954 .264 L
.21518 .26573 L
.22016 .2679 L
.22541 .27095 L
.23038 .27471 L
.23491 .27904 L
.24014 .28539 L
.24509 .29305 L
.25388 .31183 L
.26343 .34062 L
.27279 .37313 L
.28286 .40357 L
.28863 .41646 L
.29115 .42093 L
.29391 .42501 L
.29635 .42793 L
.29896 .43037 L
.3004 .43142 L
.30171 .43221 L
.30293 .4328 L
.30358 .43306 L
.30427 .43329 L
.30554 .43361 L
.30673 .4338 L
.30743 .43385 L
.30809 .43386 L
.30933 .4338 L
.31049 .43364 L
.31156 .43341 L
.31273 .43306 L
.31399 .4326 L
.31656 .43134 L
.31898 .42983 L
.32451 .42538 L
.34359 .404 L
.35251 .3935 L
.36204 .38359 L
.36752 .3789 L
.3725 .37548 L
.3749 .37417 L
.37751 .37302 L
.37871 .3726 L
.37997 .37222 L
.38105 .37197 L
.38224 .37176 L
Mistroke
.38288 .37168 L
.38358 .37161 L
.38484 .37157 L
.38608 .37162 L
.38722 .37175 L
.38792 .37187 L
.38858 .37202 L
.38982 .37237 L
.39114 .37287 L
.39258 .37355 L
.39503 .3751 L
.39762 .37729 L
.40226 .38274 L
.40746 .39132 L
.41232 .40158 L
.42335 .43054 L
.442 .48067 L
.45254 .50288 L
.46228 .51838 L
.46718 .52442 L
.47259 .52982 L
.47823 .53417 L
.48082 .53575 L
.48353 .53715 L
.48595 .53818 L
.48859 .53909 L
.49099 .53974 L
.49322 .54019 L
.49458 .5404 L
.49587 .54055 L
.49702 .54065 L
.49827 .54072 L
.49892 .54074 L
.49963 .54075 L
.50038 .54075 L
.50107 .54074 L
.50232 .54069 L
.50302 .54065 L
.50366 .5406 L
.50495 .54048 L
.50617 .54033 L
.50845 .53999 L
.51354 .5389 L
.51794 .53765 L
.5227 .53604 L
.54344 .52725 L
.56304 .51875 L
.57341 .51489 L
.58452 .51145 L
.59524 .50878 L
Mistroke
.60499 .50683 L
.62408 .50387 L
.64483 .50107 L
.66399 .4981 L
.70239 .49011 L
.74173 .48019 L
.77956 .47091 L
.81983 .46213 L
.85859 .45445 L
.8998 .44665 L
.9395 .43943 L
.97619 .4331 L
Mfstroke
0 1 .158 r
.02381 .01472 m
.03279 .09449 L
.04262 .16411 L
.04758 .192 L
.05288 .2167 L
.05785 .23533 L
.06244 .24898 L
.06788 .26121 L
.07075 .26611 L
.07379 .27028 L
.07642 .27311 L
.07889 .27515 L
.08159 .27679 L
.08312 .27746 L
.08451 .27792 L
.08574 .27822 L
.08706 .27842 L
.0883 .27852 L
.08943 .27853 L
.09012 .2785 L
.09076 .27845 L
.09145 .27837 L
.09219 .27826 L
.09343 .27802 L
.0948 .27768 L
.09724 .27687 L
.09986 .27577 L
.10458 .27327 L
.12439 .25908 L
.14594 .24364 L
.15598 .23785 L
.16664 .23299 L
.17574 .22996 L
.18092 .22872 L
.18344 .22825 L
.18579 .22788 L
.18806 .2276 L
.19048 .22738 L
.19115 .22733 L
.19187 .22729 L
.19317 .22723 L
.19444 .2272 L
.19562 .22719 L
.19685 .2272 L
.19801 .22723 L
.19928 .22729 L
.19999 .22733 L
.20065 .22738 L
.20195 .2275 L
.20338 .22765 L
Mistroke
.20597 .22803 L
.20841 .22849 L
.21062 .22901 L
.21557 .23052 L
.22016 .23241 L
.22447 .2347 L
.22914 .23783 L
.23426 .24222 L
.23961 .24818 L
.24459 .25534 L
.25352 .27342 L
.25852 .2871 L
.26308 .30167 L
.27236 .3342 L
.2822 .36431 L
.28734 .37572 L
.29026 .3807 L
.293 .38435 L
.29551 .38687 L
.2978 .38851 L
.29901 .38912 L
.30032 .38961 L
.30099 .38978 L
.3017 .38991 L
.30297 .39002 L
.30421 .38997 L
.30492 .38988 L
.30557 .38975 L
.30627 .38957 L
.3069 .38936 L
.30832 .38879 L
.31085 .38736 L
.31324 .38557 L
.31857 .38032 L
.32436 .37306 L
.34452 .3422 L
.36389 .31394 L
.37417 .30164 L
.38527 .29098 L
.39041 .287 L
.39582 .28344 L
.40083 .28071 L
.4055 .27862 L
.41025 .27691 L
.41457 .27568 L
.41938 .2746 L
.42182 .27417 L
.42451 .27376 L
.42684 .27347 L
.42935 .27322 L
Mistroke
.43073 .2731 L
.43199 .27302 L
.43328 .27295 L
.43447 .2729 L
.43557 .27287 L
.43673 .27284 L
.43802 .27284 L
.43919 .27285 L
.4403 .27287 L
.4415 .27292 L
.44263 .27297 L
.44367 .27303 L
.44616 .27324 L
.44849 .2735 L
.45378 .27434 L
.45893 .27548 L
.46446 .27704 L
.48428 .28457 L
.50584 .29323 L
.51588 .29657 L
.52655 .29949 L
.5457 .3034 L
.56541 .30679 L
.58347 .31056 L
.60284 .31622 L
.6237 .32446 L
.66334 .34382 L
.70147 .36174 L
.74205 .37717 L
.78112 .38958 L
.82263 .40152 L
.86264 .41197 L
.90112 .42093 L
.94206 .42937 L
.97619 .43575 L
Mfstroke
0 1 .182 r
.02381 .01472 m
.02846 .0572 L
.03068 .07461 L
.03279 .08831 L
.03398 .09468 L
.03527 .1004 L
.03635 .1042 L
.03754 .10743 L
.03882 .10988 L
.03952 .1108 L
.04018 .11142 L
.04135 .11201 L
.04262 .11201 L
.04393 .11143 L
.04516 .11047 L
.0465 .10905 L
.04793 .10722 L
.05297 .09927 L
.06244 .08305 L
.07382 .06621 L
.08454 .05393 L
.09417 .0455 L
.10458 .03858 L
.11408 .03383 L
.12452 .02991 L
.13541 .02692 L
.14558 .02487 L
.15603 .02333 L
.16594 .02225 L
.17482 .02152 L
.18449 .02092 L
.19389 .02049 L
.20427 .02015 L
.20948 .02001 L
.2151 .01989 L
.22037 .0198 L
.22527 .01974 L
.2299 .01969 L
.23484 .01964 L
.23767 .01963 L
.24033 .01961 L
.24272 .0196 L
.24407 .0196 L
.24531 .0196 L
.24653 .0196 L
.24784 .01959 L
.24907 .01959 L
.25019 .01959 L
.25151 .01959 L
.25226 .0196 L
Mistroke
.25295 .0196 L
.25421 .0196 L
.25556 .0196 L
.2585 .01961 L
.26126 .01963 L
.26641 .01966 L
.2762 .01973 L
.28113 .01976 L
.28393 .01977 L
.28517 .01977 L
.28653 .01978 L
.28778 .01978 L
.28893 .01978 L
.29003 .01978 L
.2912 .01978 L
.29225 .01978 L
.29323 .01978 L
.2943 .01978 L
.29546 .01978 L
.29662 .01978 L
.29789 .01977 L
.30045 .01976 L
.30502 .01974 L
.31532 .01967 L
.32467 .0196 L
.34563 .01944 L
.36485 .01933 L
.37569 .01929 L
.3805 .01928 L
.38566 .01926 L
.39075 .01925 L
.39538 .01924 L
.4001 .01923 L
.40447 .01923 L
.40954 .01922 L
.41222 .01922 L
.41359 .01922 L
.41507 .01922 L
.41635 .01922 L
.41753 .01922 L
.41873 .01922 L
.41984 .01922 L
.42107 .01922 L
.42172 .01922 L
.42241 .01922 L
.42314 .01922 L
.42383 .01922 L
.42512 .01922 L
.42627 .01922 L
.4275 .01922 L
Mistroke
.42867 .01922 L
.42974 .01922 L
.43482 .01922 L
.4401 .01922 L
.44511 .01923 L
.45478 .01923 L
.459 .01923 L
.46121 .01923 L
.46355 .01923 L
.46478 .01923 L
.46613 .01923 L
.46737 .01923 L
.4685 .01923 L
.46966 .01923 L
.4709 .01923 L
.47206 .01923 L
.47315 .01923 L
.47438 .01923 L
.47569 .01923 L
.47681 .01923 L
.47805 .01923 L
.4808 .01923 L
.48337 .01923 L
.48799 .01923 L
.49223 .01923 L
.50177 .01922 L
.54141 .01918 L
.56139 .01916 L
.57954 .01915 L
.59916 .01914 L
.60995 .01914 L
.62012 .01913 L
.65861 .01913 L
.69954 .01912 L
.73897 .01911 L
.77687 .01911 L
.79634 .01911 L
.81723 .01911 L
.85853 .0191 L
.89831 .0191 L
.93658 .0191 L
.97619 .0191 L
Mfstroke
0 1 .206 r
.02381 .01472 m
.03279 .0945 L
.04262 .16461 L
.04758 .19322 L
.05288 .21911 L
.05785 .23918 L
.06244 .25433 L
.06788 .26842 L
.07069 .27417 L
.07379 .2794 L
.07629 .28285 L
.07899 .28582 L
.08048 .28715 L
.08184 .28818 L
.08313 .28901 L
.08451 .28974 L
.08585 .2903 L
.08706 .29068 L
.08828 .29096 L
.08943 .29112 L
.09008 .29118 L
.09077 .2912 L
.09201 .29117 L
.09269 .29111 L
.09334 .29103 L
.09404 .29092 L
.0948 .29077 L
.09606 .29045 L
.09743 .29001 L
.09991 .28898 L
.10458 .2864 L
.11398 .27931 L
.12435 .26996 L
.14536 .25114 L
.15479 .24399 L
.16471 .23773 L
.16991 .235 L
.17559 .23248 L
.18038 .23073 L
.18557 .22922 L
.18831 .2286 L
.19085 .22812 L
.19327 .22776 L
.19451 .22762 L
.19584 .22749 L
.19704 .2274 L
.19814 .22733 L
.19924 .22729 L
.20029 .22727 L
.2015 .22727 L
Mistroke
.20263 .22729 L
.20386 .22734 L
.20518 .22743 L
.20659 .22756 L
.2079 .22771 L
.21084 .22818 L
.21343 .22874 L
.21617 .2295 L
.22092 .23124 L
.22613 .23389 L
.23138 .2375 L
.23636 .24201 L
.24082 .24719 L
.24567 .25437 L
.25095 .26448 L
.25655 .27842 L
.2666 .31164 L
.27622 .34691 L
.28146 .36388 L
.28634 .37704 L
.29051 .38605 L
.29497 .39332 L
.29752 .39641 L
.29992 .39865 L
.30207 .40014 L
.30329 .40077 L
.30441 .40121 L
.30553 .40154 L
.30673 .40177 L
.30786 .40186 L
.3089 .40185 L
.31011 .40172 L
.31143 .40145 L
.31267 .40108 L
.31383 .40063 L
.31612 .39948 L
.31866 .39783 L
.32379 .39349 L
.34466 .36857 L
.35407 .35707 L
.36398 .34686 L
.36917 .34273 L
.37192 .34097 L
.37486 .33946 L
.37625 .33889 L
.37756 .33845 L
.37874 .33813 L
.38002 .33788 L
.38124 .33774 L
.38252 .33769 L
Mistroke
.38362 .33773 L
.38483 .33788 L
.38612 .33816 L
.38732 .33854 L
.38863 .33909 L
.39003 .33985 L
.39263 .34174 L
.39498 .34406 L
.39727 .34693 L
.39976 .35078 L
.40426 .35981 L
.40955 .37379 L
.41513 .39168 L
.42514 .42675 L
.43463 .45769 L
.44479 .48468 L
.44972 .4952 L
.45439 .50362 L
.46313 .51564 L
.46773 .52011 L
.47279 .52371 L
.47534 .52501 L
.47668 .52556 L
.47809 .52606 L
.47933 .52641 L
.48068 .52672 L
.48191 .52693 L
.48306 .52706 L
.48421 .52713 L
.48546 .52715 L
.48664 .52711 L
.48772 .52703 L
.48871 .52691 L
.48979 .52673 L
.49197 .52624 L
.49434 .52551 L
.49688 .52451 L
.50148 .52218 L
.51162 .51494 L
.52267 .50457 L
.54278 .48225 L
.56415 .4583 L
.58349 .43931 L
.6227 .41066 L
.66283 .38982 L
.70146 .37236 L
.74253 .35577 L
.78209 .34283 L
.82014 .33327 L
.86063 .32532 L
Mistroke
.89961 .319 L
.94105 .31325 L
.97619 .30903 L
Mfstroke
0 1 .229 r
.02381 .01472 m
.03279 .0945 L
.04262 .16463 L
.04758 .19329 L
.05288 .21931 L
.06244 .25517 L
.06788 .26992 L
.07379 .28192 L
.07649 .28617 L
.07936 .28991 L
.08184 .29255 L
.08451 .29483 L
.08708 .29652 L
.08944 .29766 L
.09057 .29809 L
.09181 .29846 L
.09297 .29874 L
.09406 .29892 L
.09472 .29901 L
.09543 .29908 L
.09673 .29913 L
.09799 .29911 L
.09915 .29903 L
.10041 .29888 L
.10112 .29877 L
.10179 .29865 L
.10458 .29797 L
.10718 .29711 L
.10959 .29616 L
.11503 .29354 L
.12493 .28773 L
.14349 .27605 L
.15247 .27099 L
.16215 .26638 L
.1677 .2642 L
.17278 .26253 L
.1776 .26124 L
.18025 .26067 L
.18275 .26021 L
.18522 .25984 L
.18652 .25968 L
.18789 .25953 L
.18905 .25943 L
.19032 .25934 L
.19148 .25928 L
.19256 .25924 L
.19374 .25922 L
.19486 .25922 L
.19586 .25924 L
.19695 .25927 L
Mistroke
.19814 .25933 L
.19941 .25942 L
.20168 .25965 L
.20308 .25984 L
.20437 .26004 L
.20728 .2606 L
.21254 .26204 L
.21733 .26388 L
.22238 .26645 L
.22735 .26975 L
.23188 .27353 L
.23711 .27905 L
.24206 .28571 L
.25085 .30208 L
.25582 .31447 L
.2604 .32801 L
.27017 .3609 L
.2753 .3778 L
.2807 .39346 L
.28544 .40474 L
.28795 .40966 L
.29063 .41409 L
.2931 .41744 L
.29534 .41987 L
.2976 .42176 L
.29972 .42304 L
.30085 .42354 L
.30191 .42389 L
.30307 .42414 L
.30431 .42428 L
.30562 .42428 L
.30685 .42413 L
.30796 .4239 L
.30917 .42353 L
.31021 .42313 L
.31136 .42259 L
.31369 .42122 L
.31787 .41791 L
.328 .40656 L
.33752 .39341 L
.35598 .3674 L
.36644 .35488 L
.37154 .34974 L
.37618 .34572 L
.38082 .34238 L
.38585 .3396 L
.38862 .33848 L
.38983 .33808 L
.39117 .33772 L
.39243 .33744 L
Mistroke
.39361 .33725 L
.39486 .33711 L
.39556 .33707 L
.3962 .33705 L
.39749 .33707 L
.39822 .33711 L
.39888 .33718 L
.40016 .33737 L
.40137 .33762 L
.40278 .33802 L
.40408 .33848 L
.40701 .33987 L
.40939 .34137 L
.41201 .34341 L
.41729 .34882 L
.42253 .35591 L
.4275 .36417 L
.43681 .38301 L
.45773 .43118 L
.46739 .4509 L
.47766 .46809 L
.48642 .4795 L
.49608 .48881 L
.501 .49237 L
.50618 .49538 L
.51061 .4974 L
.51544 .49912 L
.52067 .50049 L
.5236 .50106 L
.52625 .50148 L
.52873 .5018 L
.53142 .50207 L
.53396 .50227 L
.5363 .50241 L
.53875 .50252 L
.54098 .5026 L
.54356 .50266 L
.54601 .5027 L
.55035 .50275 L
.55508 .50281 L
.55781 .50285 L
.56027 .50291 L
.56312 .50299 L
.5658 .50309 L
.57057 .50334 L
.57573 .50372 L
.58066 .5042 L
.58527 .50474 L
.59572 .50632 L
.6168 .5105 L
Mistroke
.63549 .51444 L
.65578 .51799 L
.66685 .51942 L
.67172 .51992 L
.67708 .52038 L
.68179 .52071 L
.68685 .521 L
.68965 .52112 L
.6922 .52122 L
.69483 .5213 L
.69722 .52136 L
.69967 .52141 L
.70198 .52144 L
.70325 .52145 L
.70442 .52146 L
.7057 .52146 L
.70635 .52146 L
.70706 .52146 L
.70825 .52146 L
.70934 .52146 L
.71059 .52145 L
.71178 .52145 L
.71389 .52142 L
.71619 .52139 L
.72141 .52129 L
.72695 .52114 L
.73691 .5208 L
.77465 .51899 L
.81484 .51672 L
.85352 .51415 L
.89464 .51085 L
.93426 .50725 L
.97235 .50363 L
.97619 .50327 L
Mfstroke
0 1 .253 r
.02381 .01472 m
.03279 .09403 L
.03793 .13036 L
.04262 .15528 L
.04517 .16515 L
.04758 .17204 L
.0489 .17483 L
.05012 .17682 L
.05081 .1777 L
.05146 .17837 L
.05214 .17892 L
.05288 .17934 L
.05412 .17967 L
.05529 .17957 L
.05634 .17917 L
.05749 .17842 L
.05873 .17728 L
.06006 .17574 L
.06244 .17224 L
.08414 .12559 L
.09479 .10463 L
.10458 .08879 L
.1141 .07641 L
.12455 .06574 L
.13506 .05755 L
.14616 .05106 L
.15637 .0466 L
.16567 .04351 L
.17641 .04084 L
.18659 .03899 L
.19624 .03772 L
.20111 .03722 L
.2065 .03677 L
.21107 .03647 L
.216 .0362 L
.21826 .03611 L
.22065 .03602 L
.2227 .03595 L
.22492 .0359 L
.22625 .03587 L
.22749 .03585 L
.22867 .03584 L
.22992 .03582 L
.23103 .03582 L
.23208 .03581 L
.23323 .03581 L
.23446 .03582 L
.23577 .03583 L
.23651 .03583 L
.23719 .03584 L
Mistroke
.23845 .03586 L
.23979 .03589 L
.24234 .03595 L
.24466 .03603 L
.24921 .03625 L
.25177 .03641 L
.25412 .03659 L
.26302 .03753 L
.27291 .03898 L
.27834 .03982 L
.28349 .0405 L
.28581 .04074 L
.28827 .04096 L
.28956 .04106 L
.29097 .04114 L
.29228 .04121 L
.29347 .04126 L
.29457 .04129 L
.29573 .04132 L
.29689 .04134 L
.29816 .04134 L
.29927 .04134 L
.30044 .04133 L
.30156 .04131 L
.30256 .04128 L
.30494 .0412 L
.30746 .04108 L
.31196 .0408 L
.32214 .03996 L
.34059 .03819 L
.36043 .03656 L
.36909 .03601 L
.37853 .03552 L
.38853 .03511 L
.39801 .03483 L
.40327 .0347 L
.40887 .0346 L
.41364 .03453 L
.41892 .03447 L
.42383 .03443 L
.42629 .03442 L
.429 .03441 L
.43131 .0344 L
.43378 .03439 L
.43612 .03438 L
.43824 .03438 L
.44092 .03437 L
.44338 .03437 L
.44896 .03437 L
.45384 .03436 L
Mistroke
.45658 .03436 L
.45909 .03435 L
.46146 .03435 L
.46405 .03434 L
.46877 .03433 L
.47347 .03431 L
.47783 .03428 L
.48782 .03421 L
.49846 .03411 L
.51845 .03389 L
.54006 .03366 L
.56095 .03349 L
.57088 .03343 L
.58015 .03338 L
.59899 .0333 L
.60897 .03327 L
.61966 .03324 L
.63948 .0332 L
.66104 .03317 L
.7009 .03311 L
.7203 .0331 L
.74171 .03308 L
.78099 .03305 L
.80035 .03305 L
.82121 .03304 L
.86237 .03303 L
.90202 .03302 L
.92046 .03302 L
.94015 .03302 L
.97619 .03301 L
Mfstroke
0 1 .277 r
.02381 .01472 m
.02605 .03536 L
.02729 .04513 L
.02846 .05288 L
.02954 .0587 L
.03072 .0635 L
.0318 .06664 L
.03279 .06866 L
.03396 .07015 L
.03506 .07087 L
.03626 .07108 L
.03756 .07082 L
.03821 .07054 L
.03891 .07015 L
.0402 .06926 L
.04262 .06716 L
.06244 .04754 L
.07302 .03966 L
.08429 .03338 L
.09493 .02902 L
.10458 .02607 L
.1146 .02377 L
.12383 .02217 L
.13395 .02086 L
.14465 .01984 L
.15412 .01918 L
.16428 .01865 L
.17387 .01828 L
.18262 .01803 L
.19253 .01781 L
.2017 .01766 L
.21177 .01755 L
.21685 .0175 L
.22246 .01746 L
.22738 .01743 L
.23256 .01741 L
.23698 .0174 L
.23948 .01739 L
.24181 .01739 L
.24311 .01738 L
.24453 .01738 L
.24577 .01738 L
.24709 .01738 L
.24828 .01738 L
.24959 .01738 L
.25078 .01738 L
.25189 .01738 L
.25256 .01738 L
.25329 .01738 L
.25461 .01738 L
Mistroke
.25589 .01738 L
.25709 .01738 L
.25979 .01738 L
.26267 .01739 L
.27298 .01741 L
.2784 .01743 L
.28113 .01743 L
.28269 .01743 L
.28412 .01743 L
.28547 .01744 L
.28675 .01744 L
.28745 .01744 L
.2881 .01744 L
.28881 .01744 L
.28956 .01744 L
.29081 .01744 L
.29198 .01744 L
.29326 .01744 L
.29398 .01744 L
.29464 .01744 L
.29689 .01743 L
.29935 .01743 L
.3043 .01742 L
.3146 .01739 L
.32395 .01736 L
.34491 .0173 L
.36414 .01726 L
.37497 .01724 L
.37978 .01724 L
.38495 .01723 L
.39003 .01723 L
.39467 .01722 L
.39938 .01722 L
.40375 .01722 L
.40883 .01722 L
.41435 .01722 L
.41922 .01722 L
.42175 .01722 L
.4244 .01722 L
.42673 .01721 L
.42928 .01721 L
.43163 .01721 L
.43376 .01721 L
.43628 .01721 L
.43767 .01721 L
.43898 .01721 L
.4402 .01721 L
.44132 .01721 L
.44255 .01721 L
.44385 .01721 L
Mistroke
.44498 .01721 L
.44601 .01721 L
.44721 .01721 L
.44834 .01721 L
.44938 .01721 L
.45035 .01721 L
.45255 .01721 L
.45369 .01721 L
.45493 .01721 L
.45611 .01721 L
.45718 .01721 L
.45844 .01721 L
.45908 .01721 L
.45977 .01721 L
.46099 .01721 L
.46212 .01721 L
.46338 .01721 L
.46473 .01721 L
.46587 .01721 L
.46713 .01721 L
.46995 .01721 L
.47258 .01721 L
.47735 .01721 L
.48003 .01721 L
.48249 .01721 L
.49153 .01721 L
.50105 .01721 L
.53918 .01719 L
.56045 .01719 L
.57976 .01718 L
.59986 .01718 L
.61882 .01717 L
.63885 .01717 L
.65731 .01717 L
.67609 .01717 L
.69673 .01717 L
.7162 .01717 L
.73709 .01716 L
.74723 .01716 L
.75828 .01716 L
.76884 .01716 L
.77839 .01716 L
.79812 .01716 L
.80893 .01716 L
.81911 .01716 L
.82891 .01716 L
.83924 .01716 L
.85773 .01716 L
.86724 .01716 L
.87742 .01716 L
Mistroke
.88703 .01716 L
.89577 .01716 L
.9006 .01716 L
.90572 .01716 L
.9101 .01716 L
.91491 .01716 L
.91761 .01716 L
.92008 .01716 L
.92144 .01716 L
.92293 .01716 L
.92433 .01716 L
.92564 .01716 L
.92695 .01716 L
.92819 .01716 L
.9293 .01716 L
.9305 .01716 L
.93182 .01716 L
.93248 .01716 L
.93321 .01716 L
.93449 .01716 L
.93569 .01716 L
.93829 .01716 L
.94069 .01716 L
.94614 .01716 L
.95094 .01716 L
.95603 .01716 L
.97459 .01716 L
.97619 .01716 L
Mfstroke
0 1 .3 r
.02381 .01472 m
.03279 .09448 L
.04262 .16371 L
.04758 .19086 L
.05288 .21402 L
.05789 .23043 L
.06244 .24102 L
.06507 .24537 L
.0665 .24725 L
.06785 .2487 L
.06908 .24978 L
.07022 .25057 L
.07148 .25123 L
.07217 .25149 L
.07283 .25168 L
.07354 .25183 L
.07418 .2519 L
.07493 .25192 L
.07563 .25188 L
.07687 .25167 L
.07757 .25148 L
.07822 .25125 L
.07958 .25063 L
.08108 .24975 L
.0841 .24739 L
.08922 .24194 L
.09469 .23464 L
.10458 .21945 L
.12439 .18881 L
.13484 .17495 L
.14594 .16259 L
.15578 .15369 L
.16664 .14593 L
.17651 .14058 L
.18579 .1369 L
.19048 .13549 L
.19562 .13429 L
.19821 .13381 L
.20098 .1334 L
.20359 .1331 L
.20597 .13291 L
.20712 .13284 L
.20835 .13279 L
.20939 .13276 L
.21054 .13275 L
.21177 .13276 L
.21246 .13277 L
.21309 .13279 L
.21432 .13284 L
.21549 .13291 L
Mistroke
.21657 .133 L
.21772 .13311 L
.21979 .13336 L
.22225 .13375 L
.22447 .1342 L
.22936 .13555 L
.23183 .13643 L
.23452 .13759 L
.2393 .14021 L
.24376 .14346 L
.24902 .14864 L
.25382 .15505 L
.25936 .16506 L
.26459 .17749 L
.27338 .20329 L
.28285 .23028 L
.28549 .23642 L
.28827 .24197 L
.29084 .24623 L
.29324 .24944 L
.29549 .2518 L
.29789 .25363 L
.29926 .25438 L
.30056 .2549 L
.30172 .2552 L
.30297 .25538 L
.30421 .25541 L
.30536 .2553 L
.30663 .25505 L
.30734 .25485 L
.30799 .25463 L
.31071 .25337 L
.31329 .2517 L
.31784 .24786 L
.32279 .24269 L
.34381 .21647 L
.35399 .20462 L
.36356 .19526 L
.36876 .19107 L
.37354 .18788 L
.37884 .18512 L
.38162 .18405 L
.38303 .18361 L
.38456 .18323 L
.38589 .18297 L
.38712 .1828 L
.3883 .1827 L
.38955 .18267 L
.39066 .18271 L
.39171 .1828 L
Mistroke
.39285 .18298 L
.39409 .18326 L
.39539 .18365 L
.39682 .18422 L
.39941 .18564 L
.40193 .18758 L
.40428 .18993 L
.40894 .19646 L
.41316 .20483 L
.41804 .21759 L
.42263 .23244 L
.44103 .30382 L
.44607 .32175 L
.45146 .3385 L
.45613 .35056 L
.4612 .36094 L
.46399 .36539 L
.46657 .36874 L
.46903 .37124 L
.47029 .37226 L
.47164 .37317 L
.47286 .37382 L
.47398 .37427 L
.47505 .37459 L
.47617 .3748 L
.4774 .37489 L
.47855 .37483 L
.47981 .37463 L
.48052 .37445 L
.48116 .37425 L
.48247 .37371 L
.48387 .37299 L
.48636 .37128 L
.48905 .36889 L
.492 .36567 L
.50223 .35057 L
.54259 .27062 L
.56118 .23934 L
.58143 .21312 L
.60262 .19337 L
.62273 .18015 L
.64245 .17086 L
.66345 .16367 L
.68491 .15816 L
.7051 .15411 L
.74372 .14834 L
.76372 .14611 L
.7848 .1442 L
.82284 .14162 L
.84241 .14061 L
Mistroke
.86334 .1397 L
.90477 .13825 L
.94469 .13715 L
.97619 .13643 L
Mfstroke
0 1 .324 r
.02381 .01472 m
.03279 .0945 L
.04262 .16465 L
.05288 .21953 L
.06244 .25594 L
.06792 .27131 L
.0731 .28266 L
.07775 .29051 L
.0828 .29686 L
.08542 .29936 L
.0883 .30156 L
.09131 .30328 L
.09275 .30392 L
.09413 .30443 L
.09538 .3048 L
.09676 .30512 L
.098 .30534 L
.09916 .30548 L
.09987 .30554 L
.10054 .30558 L
.10178 .3056 L
.10248 .30559 L
.10313 .30556 L
.10383 .30551 L
.10458 .30544 L
.1058 .30529 L
.10713 .30508 L
.10954 .30457 L
.11406 .30323 L
.12422 .299 L
.14255 .28978 L
.15275 .285 L
.16233 .28122 L
.17231 .27822 L
.17762 .27708 L
.1806 .27659 L
.18333 .27624 L
.18461 .27611 L
.18582 .276 L
.18691 .27592 L
.18807 .27586 L
.18934 .27581 L
.1905 .27578 L
.19176 .27577 L
.19247 .27578 L
.19314 .27579 L
.19432 .27583 L
.19543 .27588 L
.19644 .27594 L
.19753 .27603 L
Mistroke
.19998 .2763 L
.20226 .27664 L
.20497 .27715 L
.20752 .27776 L
.21228 .27923 L
.21741 .28138 L
.22296 .28446 L
.22789 .28799 L
.23249 .29211 L
.23753 .29775 L
.24294 .30542 L
.2486 .31576 L
.25397 .3281 L
.26401 .35788 L
.2728 .3869 L
.28227 .41357 L
.28769 .42484 L
.29006 .42876 L
.29266 .43232 L
.29495 .43488 L
.2974 .437 L
.29876 .43791 L
.29999 .43858 L
.30123 .43912 L
.3024 .43949 L
.30354 .43974 L
.3048 .43988 L
.30612 .43989 L
.30735 .43977 L
.3085 .43956 L
.30955 .43928 L
.31076 .43886 L
.31191 .43837 L
.31447 .43697 L
.31684 .43534 L
.32221 .43061 L
.34323 .40432 L
.36346 .37832 L
.37337 .36812 L
.37771 .36442 L
.38246 .36098 L
.38704 .35832 L
.3913 .35648 L
.39365 .35574 L
.3958 .35525 L
.39698 .35505 L
.39827 .3549 L
.39949 .35483 L
.40061 .35481 L
.40173 .35486 L
Mistroke
.40294 .35496 L
.40409 .35512 L
.40513 .35532 L
.40635 .35562 L
.40768 .35603 L
.41011 .35699 L
.41264 .35831 L
.41533 .36007 L
.42018 .36423 L
.42555 .37032 L
.43048 .37727 L
.44161 .39695 L
.46178 .43804 L
.48062 .47031 L
.49131 .48373 L
.50129 .49313 L
.5063 .49686 L
.51175 .50025 L
.52166 .50496 L
.5313 .5082 L
.54022 .51043 L
.56049 .51448 L
.57951 .51873 L
.61728 .53009 L
.63577 .53581 L
.65598 .54115 L
.67604 .54515 L
.68697 .5468 L
.69714 .54806 L
.70768 .54911 L
.71762 .54993 L
.73621 .5511 L
.75624 .55206 L
.7747 .55279 L
.79507 .55348 L
.81412 .55402 L
.8324 .55443 L
.84258 .55461 L
.85203 .55474 L
.86217 .55485 L
.86752 .5549 L
.87322 .55493 L
.87583 .55495 L
.87865 .55496 L
.88114 .55497 L
.88377 .55498 L
.88615 .55498 L
.88749 .55498 L
.88875 .55498 L
.88991 .55499 L
Mistroke
.89096 .55499 L
.89217 .55499 L
.89332 .55499 L
.89447 .55499 L
.8957 .55499 L
.89687 .55499 L
.89793 .55499 L
.89918 .55498 L
.90054 .55498 L
.90301 .55498 L
.90559 .55497 L
.90834 .55496 L
.91329 .55495 L
.92295 .5549 L
.93172 .55484 L
.97178 .55449 L
.97619 .55445 L
Mfstroke
0 1 .348 r
.02381 .01472 m
.03279 .0945 L
.04262 .16449 L
.04758 .19293 L
.05288 .21855 L
.06244 .25336 L
.06788 .26738 L
.07075 .2733 L
.07379 .27856 L
.07644 .28238 L
.07936 .28581 L
.08205 .28831 L
.08451 .29009 L
.08573 .29081 L
.08707 .29148 L
.08834 .29201 L
.0895 .2924 L
.09085 .29276 L
.09159 .29291 L
.09229 .29303 L
.09353 .29317 L
.09423 .29321 L
.09487 .29323 L
.09603 .29322 L
.09712 .29315 L
.09831 .29302 L
.09959 .29282 L
.10093 .29254 L
.1022 .29222 L
.10458 .29148 L
.10917 .28961 L
.11423 .28703 L
.12449 .28082 L
.14291 .26906 L
.15233 .26374 L
.16226 .25905 L
.16745 .25703 L
.17314 .25518 L
.1783 .25386 L
.18311 .25293 L
.18574 .25256 L
.18816 .2523 L
.18943 .2522 L
.19082 .25211 L
.19152 .25208 L
.19227 .25205 L
.19299 .25203 L
.19364 .25202 L
.1949 .25202 L
.19607 .25204 L
Mistroke
.19736 .25209 L
.19808 .25213 L
.19873 .25217 L
.19993 .25226 L
.20122 .25239 L
.20357 .25269 L
.20582 .25308 L
.20828 .2536 L
.21326 .25503 L
.21786 .25685 L
.22216 .25902 L
.22718 .26227 L
.23264 .26685 L
.23779 .27243 L
.24255 .27896 L
.25156 .29615 L
.25611 .30775 L
.26112 .32286 L
.27136 .35803 L
.27694 .37635 L
.28213 .39101 L
.28695 .40199 L
.29133 .40958 L
.29383 .41291 L
.29619 .41539 L
.29868 .41735 L
.30008 .41817 L
.30137 .41874 L
.30254 .41912 L
.30361 .41935 L
.30484 .41949 L
.30601 .4195 L
.30709 .4194 L
.30809 .41923 L
.30918 .41894 L
.31035 .41854 L
.31276 .4174 L
.31503 .41597 L
.3202 .41162 L
.32978 .40053 L
.34011 .38605 L
.35974 .35745 L
.37012 .34381 L
.38122 .33129 L
.39196 .32153 L
.40172 .31472 L
.41154 .30967 L
.42081 .30614 L
.43052 .30324 L
.4408 .30075 L
Mistroke
.44958 .29908 L
.45457 .29837 L
.45925 .29788 L
.46182 .29768 L
.46422 .29754 L
.46559 .29748 L
.46684 .29743 L
.46753 .29742 L
.46828 .2974 L
.46899 .29739 L
.46964 .29738 L
.47082 .29738 L
.47193 .29738 L
.47314 .2974 L
.47444 .29743 L
.4758 .29747 L
.47709 .29751 L
.47951 .29763 L
.48412 .29794 L
.48839 .2983 L
.49804 .29932 L
.53733 .30359 L
.55703 .30542 L
.5751 .30757 L
.58453 .30909 L
.59446 .31107 L
.61532 .31669 L
.63508 .32372 L
.65345 .33134 L
.69251 .34855 L
.73403 .36543 L
.77403 .38003 L
.81252 .39336 L
.85346 .407 L
.89288 .41932 L
.93079 .43029 L
.97115 .44108 L
.97619 .44237 L
Mfstroke
0 1 .372 r
.02381 .01472 m
.03279 .09405 L
.03793 .13068 L
.04262 .15661 L
.04517 .16748 L
.04758 .17565 L
.05012 .18209 L
.05156 .18478 L
.05288 .1867 L
.05402 .18794 L
.05509 .18877 L
.05626 .18934 L
.05752 .18957 L
.05884 .18942 L
.06009 .18895 L
.06122 .18828 L
.06244 .18729 L
.0653 .18413 L
.06799 .18026 L
.07302 .17145 L
.08429 .14871 L
.09416 .12938 L
.10458 .11157 L
.11415 .09796 L
.12466 .08589 L
.13414 .07725 L
.14313 .07071 L
.15334 .0649 L
.16264 .06082 L
.17266 .05745 L
.18355 .05477 L
.19295 .05311 L
.19831 .0524 L
.20333 .05186 L
.2086 .05143 L
.21344 .05114 L
.21597 .05103 L
.21743 .05098 L
.21875 .05094 L
.22015 .05091 L
.22092 .0509 L
.22164 .05089 L
.22294 .05088 L
.22366 .05088 L
.22434 .05088 L
.22559 .05088 L
.22678 .05089 L
.22785 .05091 L
.22901 .05094 L
.23027 .05097 L
Mistroke
.23162 .05102 L
.23403 .05113 L
.23648 .05127 L
.23879 .05145 L
.2431 .05188 L
.24562 .0522 L
.24827 .05262 L
.25302 .05356 L
.25813 .05492 L
.26374 .05691 L
.27463 .06199 L
.27998 .06451 L
.28493 .06646 L
.28941 .06777 L
.29168 .06825 L
.29417 .06864 L
.29547 .06878 L
.29667 .06888 L
.29798 .06895 L
.29864 .06898 L
.29936 .06899 L
.30057 .069 L
.30188 .06897 L
.3031 .06892 L
.30422 .06885 L
.30538 .06876 L
.30665 .06864 L
.30923 .06833 L
.31385 .06759 L
.32427 .06538 L
.34318 .06089 L
.36266 .05709 L
.36827 .05625 L
.37359 .05556 L
.37833 .05505 L
.38357 .05459 L
.38596 .05442 L
.38854 .05426 L
.39077 .05415 L
.39321 .05406 L
.39455 .05402 L
.39581 .054 L
.3965 .05399 L
.39713 .05398 L
.39786 .05398 L
.39855 .05397 L
.39977 .05398 L
.4009 .05399 L
.40214 .05401 L
.40345 .05405 L
Mistroke
.40459 .05409 L
.40564 .05413 L
.40798 .05427 L
.41015 .05443 L
.41222 .05462 L
.41683 .0552 L
.42187 .05607 L
.42719 .05727 L
.43219 .05862 L
.44155 .06154 L
.45176 .06475 L
.45733 .06626 L
.46253 .06739 L
.46716 .06815 L
.46975 .06846 L
.47211 .06868 L
.47346 .06877 L
.4747 .06884 L
.47606 .0689 L
.47675 .06892 L
.47751 .06893 L
.47878 .06895 L
.4795 .06895 L
.48015 .06894 L
.48136 .06892 L
.48263 .06888 L
.48378 .06884 L
.48484 .06878 L
.4872 .06863 L
.49145 .06824 L
.49642 .06763 L
.5011 .06693 L
.53959 .05975 L
.55909 .05662 L
.58053 .05399 L
.6009 .0522 L
.61995 .051 L
.64025 .05009 L
.65879 .04949 L
.67783 .04903 L
.69858 .04865 L
.7183 .04837 L
.73929 .04814 L
.75932 .04796 L
.78095 .04781 L
.82109 .0476 L
.84108 .04753 L
.86216 .04747 L
.90021 .04738 L
.9407 .04732 L
Mistroke
.97619 .04727 L
Mfstroke
0 1 .395 r
.02381 .01472 m
.03279 .09449 L
.04262 .16418 L
.04758 .19218 L
.05288 .21704 L
.05785 .23586 L
.06244 .24968 L
.06788 .26207 L
.07075 .26704 L
.07379 .27124 L
.07642 .27408 L
.07889 .27611 L
.08028 .277 L
.08159 .2777 L
.08312 .27832 L
.08383 .27855 L
.08451 .27874 L
.08577 .27899 L
.08692 .27912 L
.08815 .27917 L
.08884 .27916 L
.08948 .27912 L
.09055 .279 L
.09173 .27879 L
.09296 .2785 L
.0941 .27816 L
.09675 .27715 L
.09916 .27598 L
.10458 .27266 L
.12528 .25546 L
.14443 .23954 L
.16301 .22772 L
.1724 .22347 L
.17774 .2216 L
.18275 .22021 L
.18745 .21923 L
.19011 .21881 L
.19259 .21852 L
.19393 .21841 L
.19521 .21832 L
.19635 .21826 L
.19759 .21822 L
.19823 .21821 L
.19894 .21821 L
.19968 .21821 L
.20037 .21822 L
.20161 .21827 L
.2023 .2183 L
.20294 .21834 L
.20408 .21842 L
Mistroke
.20529 .21854 L
.20748 .21882 L
.21008 .21926 L
.21243 .21978 L
.21707 .22114 L
.22144 .22288 L
.22611 .22533 L
.23123 .22884 L
.23658 .23367 L
.24156 .23955 L
.24623 .24661 L
.25049 .25467 L
.26005 .27972 L
.27011 .3149 L
.27562 .33455 L
.28078 .35101 L
.28554 .3636 L
.2899 .37264 L
.29221 .37644 L
.29473 .37982 L
.29727 .38243 L
.29866 .38353 L
.29994 .38436 L
.3012 .38498 L
.30235 .38541 L
.30361 .38572 L
.30425 .38582 L
.30495 .38588 L
.30613 .38587 L
.3074 .38572 L
.30859 .38545 L
.30968 .3851 L
.31185 .38411 L
.31421 .38264 L
.31851 .37903 L
.3235 .3736 L
.3288 .36671 L
.33832 .35252 L
.35799 .3214 L
.37604 .2963 L
.39537 .2764 L
.40552 .26904 L
.41621 .26321 L
.43593 .2554 L
.45429 .24926 L
.473 .2439 L
.48286 .24166 L
.4933 .23975 L
.50439 .23819 L
.51462 .2371 L
Mistroke
.52421 .23633 L
.52963 .23597 L
.53477 .23569 L
.53962 .23547 L
.54491 .23529 L
.54724 .23522 L
.54973 .23516 L
.55205 .23512 L
.55419 .23508 L
.55551 .23507 L
.5569 .23506 L
.55763 .23505 L
.5583 .23505 L
.55904 .23505 L
.55983 .23504 L
.56052 .23504 L
.56126 .23505 L
.56196 .23505 L
.56261 .23505 L
.56384 .23506 L
.56515 .23507 L
.56632 .23508 L
.56758 .2351 L
.56987 .23515 L
.57259 .23521 L
.57508 .23529 L
.57982 .23548 L
.58489 .23575 L
.59401 .23642 L
.60487 .23752 L
.61472 .23882 L
.63392 .2421 L
.65472 .2466 L
.69566 .25684 L
.73508 .26675 L
.77299 .27593 L
.81335 .28571 L
.85219 .29526 L
.89349 .30529 L
.93327 .31465 L
.97154 .32332 L
.97619 .32436 L
Mfstroke
0 1 .419 r
.02381 .01472 m
.03279 .09447 L
.04262 .16359 L
.04758 .19066 L
.05288 .21384 L
.05789 .23046 L
.06244 .24145 L
.06507 .24612 L
.06785 .24987 L
.07022 .25216 L
.07157 .25312 L
.07283 .25379 L
.07353 .25408 L
.07428 .25432 L
.075 .25449 L
.07567 .2546 L
.07692 .25466 L
.07763 .25462 L
.07826 .25454 L
.07901 .2544 L
.07971 .25422 L
.08127 .25365 L
.08265 .25298 L
.0841 .25211 L
.08915 .24795 L
.09387 .24284 L
.10458 .22862 L
.12322 .20212 L
.14349 .17794 L
.15452 .16786 L
.16473 .16046 L
.17448 .15499 L
.17989 .1526 L
.18485 .15077 L
.18932 .14943 L
.19422 .14828 L
.1966 .14784 L
.19914 .14745 L
.20055 .14727 L
.20182 .14714 L
.20304 .14703 L
.20432 .14694 L
.20544 .14688 L
.20667 .14683 L
.20779 .14681 L
.20883 .1468 L
.21006 .14682 L
.21119 .14685 L
.21249 .14692 L
.21372 .147 L
Mistroke
.21593 .14722 L
.21797 .14749 L
.22021 .14787 L
.2226 .14839 L
.22522 .14908 L
.22797 .14999 L
.23291 .1521 L
.23823 .15525 L
.24405 .16008 L
.2491 .16585 L
.2545 .17426 L
.25959 .18488 L
.26423 .19706 L
.2743 .22914 L
.27981 .24654 L
.28497 .26049 L
.28936 .26983 L
.29162 .27364 L
.29409 .27704 L
.29664 .27972 L
.29804 .28083 L
.29933 .28166 L
.30055 .28225 L
.30165 .28264 L
.30293 .28293 L
.30413 .28304 L
.30528 .28301 L
.30635 .28286 L
.30753 .28258 L
.3088 .28213 L
.31012 .28152 L
.31137 .28082 L
.31373 .27917 L
.31796 .27531 L
.32256 .27003 L
.34251 .24052 L
.36188 .21155 L
.37216 .1985 L
.38326 .18679 L
.39381 .17796 L
.40349 .17169 L
.41275 .16712 L
.4225 .16349 L
.44221 .15832 L
.46057 .15417 L
.49959 .14518 L
.52091 .14124 L
.53069 .13982 L
.54105 .13856 L
.55057 .13762 L
Mistroke
.56104 .13679 L
.57057 .1362 L
.57949 .13577 L
.58446 .13558 L
.58988 .1354 L
.59466 .13527 L
.59975 .13516 L
.60479 .13507 L
.60936 .13501 L
.61157 .13498 L
.61395 .13496 L
.61622 .13494 L
.61828 .13493 L
.62065 .13492 L
.62196 .13491 L
.6232 .13491 L
.62434 .1349 L
.6254 .1349 L
.62656 .1349 L
.62779 .1349 L
.62903 .1349 L
.62972 .1349 L
.63035 .1349 L
.63152 .1349 L
.63276 .13491 L
.63411 .13491 L
.63537 .13492 L
.63823 .13493 L
.64357 .13496 L
.64842 .135 L
.6593 .13512 L
.6785 .13541 L
.6993 .1358 L
.74024 .13667 L
.77966 .13757 L
.81757 .13849 L
.85793 .1395 L
.89678 .14047 L
.93807 .14148 L
.97619 .14239 L
Mfstroke
0 1 .443 r
.02381 .01472 m
.02605 .03534 L
.02729 .04503 L
.02846 .05261 L
.02954 .05817 L
.03072 .06261 L
.0318 .06537 L
.03279 .06703 L
.03396 .06813 L
.03506 .06851 L
.03626 .06842 L
.03756 .06789 L
.03821 .0675 L
.03891 .06701 L
.0402 .06597 L
.04262 .06368 L
.06244 .04445 L
.07302 .03705 L
.08429 .0312 L
.09493 .02718 L
.10458 .02447 L
.1146 .02237 L
.12383 .02093 L
.13395 .01974 L
.14465 .01882 L
.15412 .01822 L
.16428 .01775 L
.17387 .01742 L
.18262 .01719 L
.19253 .017 L
.2017 .01687 L
.21177 .01676 L
.21685 .01672 L
.22246 .01668 L
.22738 .01665 L
.23256 .01663 L
.23703 .01662 L
.24181 .0166 L
.24451 .0166 L
.24697 .01659 L
.24947 .01659 L
.25177 .01659 L
.25305 .01658 L
.25446 .01658 L
.25588 .01658 L
.25666 .01658 L
.25738 .01658 L
.25869 .01658 L
.25942 .01658 L
.26011 .01658 L
Mistroke
.26133 .01658 L
.26202 .01658 L
.26267 .01658 L
.26396 .01658 L
.26532 .01658 L
.26776 .01658 L
.27326 .01659 L
.27575 .01659 L
.27842 .01659 L
.27971 .01659 L
.28094 .01659 L
.28204 .01659 L
.28323 .01659 L
.28429 .01659 L
.28547 .01659 L
.2867 .01659 L
.28785 .01659 L
.28892 .01659 L
.2899 .01659 L
.29211 .01659 L
.29438 .01659 L
.29686 .01658 L
.30185 .01658 L
.31215 .01656 L
.3215 .01655 L
.34246 .01651 L
.35181 .0165 L
.36168 .01649 L
.37252 .01648 L
.37774 .01647 L
.3825 .01647 L
.39196 .01647 L
.39717 .01646 L
.40211 .01646 L
.40432 .01646 L
.40666 .01646 L
.40869 .01646 L
.41088 .01646 L
.4121 .01646 L
.41322 .01646 L
.41436 .01646 L
.41542 .01646 L
.41659 .01646 L
.41786 .01646 L
.41911 .01646 L
.4198 .01646 L
.42044 .01646 L
.42162 .01646 L
.42274 .01646 L
.42396 .01646 L
Mistroke
.42527 .01646 L
.42795 .01646 L
.4304 .01646 L
.4396 .01646 L
.45038 .01647 L
.45563 .01647 L
.46038 .01647 L
.46266 .01647 L
.46512 .01647 L
.46725 .01647 L
.46958 .01647 L
.47087 .01647 L
.47207 .01647 L
.47333 .01647 L
.47404 .01647 L
.47469 .01647 L
.47584 .01647 L
.4771 .01647 L
.47829 .01647 L
.47938 .01647 L
.48057 .01647 L
.48185 .01647 L
.48416 .01647 L
.48692 .01647 L
.48944 .01647 L
.49464 .01647 L
.50011 .01647 L
.51987 .01646 L
.53824 .01646 L
.55699 .01645 L
.57731 .01645 L
.58842 .01645 L
.59867 .01645 L
.61882 .01645 L
.6376 .01644 L
.65825 .01644 L
.69861 .01644 L
.73745 .01644 L
.75721 .01644 L
.77875 .01644 L
.81853 .01644 L
.85925 .01644 L
.89845 .01644 L
.9401 .01644 L
.97619 .01644 L
Mfstroke
0 1 .466 r
.02381 .01472 m
.03279 .0945 L
.04262 .16463 L
.04758 .19329 L
.05288 .21927 L
.06244 .25491 L
.06788 .26937 L
.07075 .27547 L
.07379 .28088 L
.07644 .28477 L
.07936 .28822 L
.08202 .29064 L
.08451 .29236 L
.08574 .29302 L
.0871 .2936 L
.08837 .29403 L
.08956 .29433 L
.09073 .29453 L
.09179 .29463 L
.09302 .29466 L
.09418 .29461 L
.09544 .29447 L
.09608 .29436 L
.09678 .29422 L
.09917 .29357 L
.10197 .29248 L
.10458 .29119 L
.11503 .28408 L
.12493 .2757 L
.14349 .25963 L
.15314 .25226 L
.1634 .24565 L
.17215 .24115 L
.18182 .23748 L
.18673 .23616 L
.18942 .23559 L
.19191 .23517 L
.19405 .23488 L
.19514 .23477 L
.19633 .23466 L
.19763 .23458 L
.19886 .23452 L
.20006 .2345 L
.20116 .23449 L
.20237 .23451 L
.20366 .23457 L
.20488 .23464 L
.20599 .23474 L
.20729 .23488 L
.20871 .23507 L
Mistroke
.2113 .23553 L
.21399 .23616 L
.21686 .23701 L
.22202 .23908 L
.2274 .24208 L
.23233 .24576 L
.23775 .25109 L
.24347 .25862 L
.24846 .26725 L
.2531 .27747 L
.26366 .30955 L
.27272 .34337 L
.28233 .37617 L
.28734 .38974 L
.29287 .40135 L
.2953 .40534 L
.2979 .40891 L
.30035 .4116 L
.30262 .41358 L
.3052 .41524 L
.30657 .41587 L
.30803 .41638 L
.30877 .41658 L
.30957 .41674 L
.31032 .41684 L
.31102 .41691 L
.31233 .41693 L
.313 .4169 L
.31372 .41683 L
.31441 .41674 L
.31505 .41662 L
.31626 .41634 L
.31756 .41594 L
.31898 .4154 L
.3239 .41281 L
.32896 .4092 L
.33435 .40465 L
.34403 .39562 L
.35338 .38719 L
.3583 .38335 L
.36348 .38002 L
.36567 .37889 L
.36802 .3779 L
.36938 .37745 L
.3706 .37712 L
.37184 .37686 L
.373 .37669 L
.37406 .37661 L
.37519 .3766 L
.37614 .37666 L
Mistroke
.3772 .37679 L
.37833 .37702 L
.37955 .37737 L
.3807 .37781 L
.38175 .37831 L
.38425 .3799 L
.38652 .38188 L
.38914 .38485 L
.3916 .38839 L
.396 .39668 L
.40075 .40862 L
.42148 .47885 L
.4318 .50874 L
.44143 .52983 L
.45148 .54541 L
.4568 .55132 L
.45956 .55382 L
.4625 .55607 L
.46502 .55769 L
.46779 .55915 L
.47031 .5602 L
.47268 .56095 L
.47404 .56129 L
.47546 .56156 L
.47668 .56174 L
.47737 .56182 L
.47801 .56187 L
.47876 .56192 L
.47947 .56195 L
.48079 .56195 L
.48153 .56193 L
.48221 .56189 L
.48296 .56183 L
.48375 .56175 L
.485 .56158 L
.48614 .56139 L
.48871 .5608 L
.49109 .56009 L
.49334 .55926 L
.49838 .55692 L
.50388 .55366 L
.51424 .54574 L
.52361 .5369 L
.5446 .51319 L
.58474 .46349 L
.62336 .42255 L
.66444 .38993 L
.70399 .36587 L
.74204 .34785 L
.76324 .33986 L
Mistroke
.78253 .33377 L
.82152 .32435 L
.86143 .31755 L
.89983 .31267 L
.94069 .30863 L
.97619 .30584 L
Mfstroke
0 1 .49 r
.02381 .01472 m
.03279 .09451 L
.04262 .16478 L
.05288 .22045 L
.06244 .25863 L
.06792 .27547 L
.0731 .28845 L
.07781 .29802 L
.0828 .30609 L
.08823 .31273 L
.09324 .31713 L
.09603 .31895 L
.09864 .32028 L
.1015 .32137 L
.10311 .32182 L
.10458 .32215 L
.10587 .32236 L
.10708 .32251 L
.10817 .3226 L
.10934 .32265 L
.11063 .32266 L
.11128 .32264 L
.11199 .32261 L
.11325 .32252 L
.11442 .3224 L
.11673 .32207 L
.11884 .32167 L
.12357 .32046 L
.13421 .3167 L
.14429 .31255 L
.16251 .30561 L
.1675 .30409 L
.17288 .30271 L
.17796 .30169 L
.18037 .3013 L
.18262 .301 L
.18484 .30077 L
.18598 .30068 L
.18722 .30059 L
.18792 .30055 L
.18857 .30052 L
.18986 .30048 L
.19102 .30046 L
.19225 .30047 L
.19345 .30049 L
.19475 .30054 L
.19597 .3006 L
.19708 .30069 L
.19838 .30081 L
.19981 .30097 L
Mistroke
.20239 .30135 L
.20516 .30189 L
.20767 .30249 L
.21329 .30432 L
.2185 .30664 L
.2234 .30949 L
.22807 .31291 L
.23319 .31763 L
.23853 .32387 L
.24352 .33121 L
.25245 .34906 L
.262 .37566 L
.27163 .40677 L
.28185 .43604 L
.28718 .44782 L
.29001 .45298 L
.29306 .45769 L
.29585 .46126 L
.29841 .46394 L
.30083 .46598 L
.30342 .46766 L
.30472 .46831 L
.30594 .46882 L
.30714 .46923 L
.30823 .46951 L
.30928 .46972 L
.31038 .46986 L
.31149 .46993 L
.31271 .46994 L
.31339 .4699 L
.31404 .46985 L
.31524 .4697 L
.31654 .46946 L
.31796 .46911 L
.32051 .46827 L
.32286 .46728 L
.33278 .46147 L
.34331 .45371 L
.35267 .44684 L
.35758 .44363 L
.36276 .44078 L
.36731 .43886 L
.36856 .43845 L
.36989 .43807 L
.37104 .4378 L
.37229 .43756 L
.37351 .43739 L
.37464 .4373 L
.37572 .43726 L
.37687 .43728 L
Mistroke
.37789 .43736 L
.37885 .43748 L
.3799 .43767 L
.38103 .43794 L
.38236 .43836 L
.38357 .43884 L
.38628 .44026 L
.38879 .44204 L
.39115 .44416 L
.39645 .45061 L
.40218 .46028 L
.42228 .50667 L
.4326 .52852 L
.44223 .54474 L
.45228 .55733 L
.4576 .56238 L
.4633 .5667 L
.46859 .56978 L
.47348 .57193 L
.47885 .5736 L
.48156 .57419 L
.48302 .57445 L
.48456 .57467 L
.4858 .57482 L
.48716 .57495 L
.4884 .57504 L
.48955 .57509 L
.49026 .57512 L
.49092 .57513 L
.49216 .57514 L
.49285 .57514 L
.49349 .57513 L
.49419 .57511 L
.49494 .57508 L
.49609 .57502 L
.49734 .57493 L
.49958 .57473 L
.50225 .5744 L
.50468 .57403 L
.51456 .57195 L
.52372 .56939 L
.54446 .56258 L
.58366 .55086 L
.60513 .54619 L
.62532 .5425 L
.66394 .53522 L
.70502 .5254 L
.74458 .51482 L
.78262 .50529 L
.82312 .49655 L
Mistroke
.8621 .48922 L
.90353 .48213 L
.94345 .47582 L
.97619 .47102 L
Mfstroke
0 1 .514 r
.02381 .01472 m
.03279 .0945 L
.04262 .16467 L
.05288 .21967 L
.06244 .25634 L
.06792 .27193 L
.0731 .28352 L
.07775 .29162 L
.0828 .29826 L
.08542 .30091 L
.0883 .30329 L
.09131 .3052 L
.09275 .30593 L
.09413 .30652 L
.09538 .30698 L
.09676 .30739 L
.09802 .30769 L
.09916 .3079 L
.09982 .308 L
.10052 .30808 L
.10127 .30815 L
.10197 .30819 L
.10263 .30822 L
.10333 .30823 L
.10458 .3082 L
.1058 .30813 L
.10649 .30807 L
.10713 .308 L
.10954 .30763 L
.11173 .30717 L
.11406 .30656 L
.12422 .30287 L
.14255 .29445 L
.15192 .29035 L
.16202 .28658 L
.16667 .28515 L
.17156 .28388 L
.17606 .28294 L
.1803 .28227 L
.1827 .28199 L
.18397 .28187 L
.1853 .28176 L
.18643 .28169 L
.18767 .28163 L
.18879 .2816 L
.18985 .28158 L
.19116 .28158 L
.19242 .2816 L
.19354 .28164 L
.19476 .2817 L
Mistroke
.19609 .2818 L
.1975 .28192 L
.20004 .28223 L
.20243 .28262 L
.20501 .28315 L
.20968 .28442 L
.21423 .28607 L
.21841 .28802 L
.22312 .29076 L
.22817 .29447 L
.23727 .30376 L
.24283 .31164 L
.2481 .32111 L
.25795 .34529 L
.27621 .40294 L
.28121 .41637 L
.28659 .42802 L
.28907 .43234 L
.29168 .43616 L
.29412 .43909 L
.29633 .44121 L
.29871 .44294 L
.30001 .44367 L
.30124 .4442 L
.30238 .44458 L
.30343 .44483 L
.30458 .44499 L
.3058 .44504 L
.30703 .44498 L
.30835 .44479 L
.30959 .44449 L
.31073 .44412 L
.31351 .44286 L
.31615 .44125 L
.32137 .43699 L
.32621 .43205 L
.33717 .41855 L
.35739 .39149 L
.36731 .37955 L
.3764 .37018 L
.38524 .36284 L
.38973 .35984 L
.39454 .35723 L
.39708 .35611 L
.39938 .35524 L
.40173 .35452 L
.40389 .35398 L
.40509 .35374 L
.40641 .35352 L
.40774 .35336 L
Mistroke
.40847 .35328 L
.40915 .35323 L
.4104 .35317 L
.41154 .35315 L
.41286 .35317 L
.41412 .35324 L
.41536 .35335 L
.41671 .35352 L
.41798 .35373 L
.41915 .35396 L
.42137 .35451 L
.42371 .35526 L
.42859 .35736 L
.43394 .36056 L
.44345 .36865 L
.45233 .37869 L
.47098 .40403 L
.49126 .42993 L
.5023 .44103 L
.51252 .44914 L
.52228 .45518 L
.53264 .46014 L
.57041 .47287 L
.61063 .48941 L
.64934 .50804 L
.669 .5162 L
.6905 .52345 L
.73015 .53294 L
.74977 .53641 L
.77073 .53962 L
.81224 .545 L
.85225 .54919 L
.89073 .55236 L
.93167 .55503 L
.97109 .55713 L
.97619 .55738 L
Mfstroke
0 1 .538 r
.02381 .01472 m
.02499 .02009 L
.02605 .02112 L
.02729 .02148 L
.02846 .02156 L
.02954 .02154 L
.03053 .02147 L
.03163 .02137 L
.03279 .02124 L
.04262 .01993 L
.05217 .0188 L
.06244 .01784 L
.0728 .01711 L
.0825 .01659 L
.09403 .01614 L
.10458 .01585 L
.11442 .01564 L
.12357 .0155 L
.1336 .01538 L
.14429 .01529 L
.15457 .01523 L
.1657 .01518 L
.17621 .01515 L
.18587 .01512 L
.19561 .01511 L
.2047 .01509 L
.21467 .01509 L
.22026 .01508 L
.22536 .01508 L
.23016 .01508 L
.23527 .01507 L
.23969 .01507 L
.24444 .01507 L
.24953 .01507 L
.25431 .01507 L
.25708 .01507 L
.25999 .01507 L
.26248 .01507 L
.2652 .01507 L
.27045 .01507 L
.27613 .01507 L
.27874 .01507 L
.2815 .01507 L
.28386 .01507 L
.28645 .01507 L
.29126 .01507 L
.29643 .01507 L
.30576 .01507 L
.32445 .01506 L
.34481 .01506 L
Mistroke
.3558 .01506 L
.36598 .01506 L
.37572 .01506 L
.38116 .01506 L
.38609 .01506 L
.39098 .01506 L
.39365 .01506 L
.39614 .01506 L
.40054 .01506 L
.40287 .01506 L
.40537 .01506 L
.40677 .01506 L
.40806 .01506 L
.40873 .01506 L
.40947 .01506 L
.41025 .01506 L
.41097 .01506 L
.41162 .01506 L
.41231 .01506 L
.41353 .01506 L
.41484 .01506 L
.41558 .01506 L
.41628 .01506 L
.41879 .01506 L
.42108 .01506 L
.4262 .01506 L
.43621 .01506 L
.44543 .01506 L
.45619 .01506 L
.46144 .01506 L
.46624 .01506 L
.46847 .01506 L
.47089 .01506 L
.47299 .01506 L
.47531 .01506 L
.47657 .01506 L
.47776 .01506 L
.47901 .01506 L
.47972 .01506 L
.48036 .01506 L
.48145 .01506 L
.48264 .01506 L
.48388 .01506 L
.48504 .01506 L
.48633 .01506 L
.48773 .01506 L
.49027 .01506 L
.49274 .01506 L
.49502 .01506 L
.5002 .01506 L
Mistroke
.50569 .01506 L
.54355 .01506 L
.5646 .01506 L
.58386 .01506 L
.60375 .01506 L
.62265 .01506 L
.66086 .01506 L
.70153 .01506 L
.74068 .01506 L
.76067 .01506 L
.78228 .01506 L
.82237 .01506 L
.86339 .01506 L
.9029 .01506 L
.94089 .01506 L
.97619 .01506 L
Mfstroke
0 1 .561 r
.02381 .01472 m
.03279 .09451 L
.04262 .16478 L
.05288 .22047 L
.06244 .25874 L
.06792 .27569 L
.0731 .28882 L
.07781 .29858 L
.0828 .30691 L
.08823 .31389 L
.09324 .31866 L
.09603 .3207 L
.09864 .32225 L
.1015 .3236 L
.10312 .32421 L
.10458 .32467 L
.10712 .32528 L
.10851 .32552 L
.10982 .3257 L
.11104 .32581 L
.11216 .32588 L
.11339 .32591 L
.11468 .32591 L
.116 .32586 L
.11673 .32582 L
.1174 .32577 L
.11871 .32564 L
.11994 .3255 L
.12271 .32507 L
.12571 .32447 L
.13615 .32165 L
.1458 .31856 L
.15479 .31574 L
.16447 .31312 L
.17001 .31191 L
.17509 .31105 L
.17761 .31071 L
.17995 .31046 L
.1824 .31026 L
.18369 .31018 L
.1844 .31014 L
.18507 .31012 L
.1863 .31008 L
.18696 .31007 L
.18766 .31006 L
.18839 .31006 L
.18909 .31007 L
.1904 .3101 L
.19162 .31014 L
.19275 .3102 L
Mistroke
.19399 .31029 L
.19531 .3104 L
.19832 .31076 L
.20114 .31123 L
.20642 .31244 L
.21146 .31408 L
.2161 .31606 L
.2212 .31883 L
.22657 .32257 L
.23607 .33181 L
.2414 .33893 L
.24625 .347 L
.25567 .36793 L
.26459 .3938 L
.27427 .42345 L
.27957 .43774 L
.28454 .44901 L
.28912 .45736 L
.29331 .46328 L
.29796 .46802 L
.30041 .46977 L
.30297 .47112 L
.30421 .47159 L
.30487 .4718 L
.30556 .47199 L
.30682 .47224 L
.30799 .47239 L
.30911 .47245 L
.31016 .47243 L
.31131 .47234 L
.31254 .47217 L
.31386 .47189 L
.31528 .47149 L
.31788 .47052 L
.32276 .46795 L
.3323 .46084 L
.34113 .45288 L
.35086 .4438 L
.36136 .43492 L
.36619 .43149 L
.37127 .4285 L
.37562 .42656 L
.37808 .42576 L
.37919 .42547 L
.38037 .42522 L
.38159 .42502 L
.38272 .42489 L
.38394 .42482 L
.38463 .42481 L
.38528 .42482 L
Mistroke
.38645 .42489 L
.38751 .42502 L
.38874 .42524 L
.38992 .42553 L
.39207 .42627 L
.39407 .4272 L
.39626 .42852 L
.3986 .43027 L
.40386 .43564 L
.40882 .44249 L
.41809 .45933 L
.43648 .4995 L
.44692 .52041 L
.45666 .5366 L
.46629 .54921 L
.47661 .55925 L
.48227 .56342 L
.48763 .56662 L
.49241 .56892 L
.49768 .57093 L
.50267 .5724 L
.50734 .57344 L
.51228 .57425 L
.51506 .57459 L
.51761 .57484 L
.51968 .57501 L
.52189 .57515 L
.52432 .57527 L
.52658 .57535 L
.52781 .57538 L
.52913 .57541 L
.53038 .57542 L
.53153 .57544 L
.53257 .57544 L
.53372 .57545 L
.53491 .57545 L
.53603 .57544 L
.53728 .57543 L
.53798 .57543 L
.53862 .57542 L
.54102 .57539 L
.54645 .57531 L
.5512 .57523 L
.5537 .57519 L
.55633 .57516 L
.55871 .57513 L
.56006 .57512 L
.56131 .57512 L
.56247 .57511 L
.56352 .57511 L
Mistroke
.56474 .57511 L
.56589 .57511 L
.56698 .57511 L
.56813 .57512 L
.56911 .57513 L
.5702 .57514 L
.57261 .57517 L
.57487 .57521 L
.57983 .57533 L
.58525 .57552 L
.59511 .57597 L
.61363 .57703 L
.6246 .57766 L
.63494 .57817 L
.64422 .57851 L
.64945 .57865 L
.65178 .5787 L
.65427 .57874 L
.65672 .57878 L
.65895 .5788 L
.66003 .57881 L
.6612 .57881 L
.66231 .57882 L
.66333 .57882 L
.66451 .57882 L
.66563 .57882 L
.66684 .57881 L
.66816 .57881 L
.66946 .5788 L
.67083 .57879 L
.67329 .57876 L
.67569 .57872 L
.67826 .57867 L
.68288 .57856 L
.69338 .57821 L
.70362 .57777 L
.71472 .57719 L
.73487 .57597 L
.77578 .57328 L
.81517 .57065 L
.85304 .56797 L
.89337 .56482 L
.93218 .56155 L
.97345 .55795 L
.97619 .55771 L
Mfstroke
0 1 .585 r
.02381 .01472 m
.03279 .09449 L
.04262 .16427 L
.04758 .19239 L
.05288 .21742 L
.05785 .23639 L
.06244 .25031 L
.06788 .26272 L
.07075 .26763 L
.07379 .27172 L
.07642 .27441 L
.07889 .27627 L
.0803 .27706 L
.08159 .27763 L
.08231 .27788 L
.08309 .2781 L
.08382 .27826 L
.08451 .27837 L
.08577 .27848 L
.08648 .27849 L
.08713 .27846 L
.08833 .27834 L
.0896 .2781 L
.09074 .27781 L
.0918 .27746 L
.09422 .27644 L
.09922 .27344 L
.10458 .2692 L
.12439 .2492 L
.14594 .22812 L
.15598 .22018 L
.16664 .21338 L
.17574 .20894 L
.18092 .20697 L
.18579 .20549 L
.19048 .20441 L
.19314 .20395 L
.19562 .20362 L
.19697 .20348 L
.19824 .20337 L
.19938 .2033 L
.20062 .20325 L
.20127 .20323 L
.20197 .20322 L
.20271 .20321 L
.2034 .20322 L
.20464 .20325 L
.20533 .20328 L
.20597 .20331 L
.20711 .20339 L
Mistroke
.20833 .2035 L
.21051 .20377 L
.21311 .20421 L
.21546 .20473 L
.2201 .20612 L
.22447 .20792 L
.22914 .21048 L
.23426 .21419 L
.23961 .21936 L
.24459 .22574 L
.24926 .23347 L
.25352 .24235 L
.26308 .26976 L
.27314 .3064 L
.27865 .32581 L
.28381 .34154 L
.28857 .35322 L
.29293 .36134 L
.29529 .36472 L
.29777 .36751 L
.30025 .36958 L
.30166 .37043 L
.30297 .37103 L
.30423 .37142 L
.30538 .37165 L
.30665 .37174 L
.30728 .37173 L
.30798 .37167 L
.30916 .37147 L
.31043 .37112 L
.31162 .37067 L
.31271 .37015 L
.31488 .36885 L
.31724 .36706 L
.32154 .36291 L
.33183 .34942 L
.34136 .33419 L
.36158 .30012 L
.38059 .27252 L
.39873 .25333 L
.40894 .24566 L
.41831 .24026 L
.43721 .23221 L
.4579 .22467 L
.47913 .21727 L
.49843 .21154 L
.50805 .20918 L
.51849 .20703 L
.53744 .20409 L
.54689 .20304 L
Mistroke
.55729 .20216 L
.56253 .20183 L
.56816 .20154 L
.57347 .20133 L
.57602 .20126 L
.57833 .2012 L
.58079 .20115 L
.5831 .20112 L
.58437 .2011 L
.58554 .2011 L
.58683 .20109 L
.58747 .20109 L
.58818 .20108 L
.58938 .20108 L
.59047 .20109 L
.59172 .20109 L
.59291 .2011 L
.59401 .20111 L
.59503 .20112 L
.59733 .20115 L
.59979 .2012 L
.60211 .20125 L
.60738 .20141 L
.61252 .20161 L
.61806 .20188 L
.63811 .20324 L
.65922 .2052 L
.69735 .20944 L
.73793 .21413 L
.77699 .21858 L
.81851 .22336 L
.85851 .22802 L
.897 .23244 L
.93794 .23698 L
.97619 .24103 L
Mfstroke
0 1 .609 r
.02381 .01472 m
.03279 .0945 L
.04262 .16436 L
.04758 .19247 L
.05288 .2173 L
.05789 .23586 L
.06244 .24877 L
.06507 .25455 L
.06785 .25945 L
.07022 .26266 L
.07283 .26524 L
.0743 .26626 L
.07564 .26695 L
.07637 .26723 L
.07718 .26746 L
.07794 .26761 L
.07865 .26768 L
.07936 .2677 L
.08004 .26766 L
.08129 .26746 L
.08199 .26728 L
.08264 .26707 L
.0841 .26645 L
.08656 .26497 L
.08885 .26317 L
.09406 .25777 L
.10458 .24323 L
.12322 .214 L
.14349 .18649 L
.15452 .17486 L
.16473 .16626 L
.17448 .15986 L
.17989 .15702 L
.18485 .15484 L
.18932 .1532 L
.19422 .15176 L
.19914 .15068 L
.20182 .15024 L
.20302 .15008 L
.20432 .14994 L
.20556 .14982 L
.2067 .14973 L
.20779 .14967 L
.20895 .14962 L
.20999 .14959 L
.21095 .14959 L
.21202 .14959 L
.21316 .14963 L
.21437 .14968 L
.21569 .14977 L
Mistroke
.21694 .14989 L
.21809 .15002 L
.22028 .15033 L
.2226 .15078 L
.22522 .15141 L
.22797 .15225 L
.23291 .15427 L
.23823 .15733 L
.24405 .16207 L
.2491 .16778 L
.2545 .17612 L
.25959 .18671 L
.26423 .19893 L
.2743 .23162 L
.27981 .24978 L
.28497 .26468 L
.28936 .27492 L
.29409 .28313 L
.29664 .28633 L
.29804 .28772 L
.29933 .28879 L
.30053 .2896 L
.30162 .29018 L
.30284 .29067 L
.30413 .291 L
.30528 .29113 L
.30653 .29112 L
.30784 .29094 L
.30907 .29062 L
.31022 .29019 L
.31126 .2897 L
.31362 .28825 L
.31614 .28622 L
.31889 .28352 L
.32389 .27748 L
.34251 .24789 L
.36188 .21623 L
.37216 .20195 L
.38326 .18919 L
.39381 .17961 L
.40349 .17283 L
.41275 .16792 L
.4225 .16409 L
.43203 .1613 L
.44221 .15895 L
.46057 .15515 L
.50204 .14583 L
.52282 .1418 L
.53194 .14035 L
.54199 .13899 L
Mistroke
.56065 .13707 L
.57086 .13631 L
.58042 .13574 L
.59081 .13527 L
.60069 .13493 L
.60955 .1347 L
.61921 .13452 L
.62453 .13444 L
.62954 .13438 L
.6341 .13434 L
.6389 .1343 L
.64415 .13427 L
.64898 .13425 L
.65167 .13424 L
.65418 .13424 L
.65562 .13423 L
.65693 .13423 L
.65766 .13423 L
.65845 .13423 L
.65919 .13423 L
.65988 .13423 L
.66106 .13423 L
.6623 .13423 L
.66336 .13423 L
.66452 .13423 L
.66577 .13423 L
.66711 .13423 L
.66952 .13424 L
.67195 .13424 L
.67426 .13425 L
.67856 .13426 L
.68845 .1343 L
.69917 .13436 L
.71906 .1345 L
.74011 .13468 L
.77801 .13508 L
.81837 .13557 L
.85722 .13607 L
.89851 .13661 L
.93829 .13712 L
.97619 .13759 L
Mfstroke
0 1 .632 r
.02381 .01472 m
.02846 .05762 L
.03279 .09194 L
.03523 .10758 L
.03754 .11931 L
.03881 .12445 L
.0402 .12892 L
.04146 .13203 L
.04262 .13414 L
.04376 .13555 L
.04498 .13639 L
.04614 .13663 L
.0472 .13643 L
.04843 .13576 L
.04913 .13519 L
.04978 .13457 L
.05224 .13144 L
.05718 .1229 L
.06244 .11244 L
.07287 .09228 L
.08414 .07414 L
.09479 .06086 L
.10458 .05147 L
.11422 .04437 L
.1248 .03848 L
.13585 .03396 L
.14616 .03085 L
.15661 .02853 L
.16651 .0269 L
.1754 .02579 L
.18507 .02488 L
.19447 .02423 L
.20484 .02371 L
.21006 .02351 L
.21568 .02333 L
.22095 .02321 L
.22585 .02311 L
.23048 .02304 L
.23307 .02302 L
.23542 .023 L
.23668 .02299 L
.23801 .02298 L
.23947 .02297 L
.24011 .02297 L
.24081 .02297 L
.24206 .02297 L
.24323 .02297 L
.24394 .02297 L
.24462 .02297 L
.24589 .02297 L
Mistroke
.24658 .02297 L
.24722 .02297 L
.24843 .02298 L
.24973 .02298 L
.25113 .02299 L
.25366 .02302 L
.25599 .02304 L
.26134 .02313 L
.26699 .02324 L
.2765 .02345 L
.28172 .02356 L
.28429 .0236 L
.28667 .02362 L
.2889 .02365 L
.29003 .02365 L
.29127 .02366 L
.29252 .02366 L
.29321 .02367 L
.29385 .02367 L
.29503 .02367 L
.29627 .02367 L
.29732 .02366 L
.29844 .02366 L
.29949 .02365 L
.30045 .02365 L
.3028 .02363 L
.30502 .02361 L
.30966 .02355 L
.31476 .02347 L
.32507 .02328 L
.34353 .02293 L
.36302 .02265 L
.37395 .02253 L
.38393 .02245 L
.38872 .02242 L
.39382 .02239 L
.39823 .02237 L
.40299 .02235 L
.40807 .02234 L
.41285 .02233 L
.41561 .02232 L
.41853 .02232 L
.42102 .02232 L
.42243 .02232 L
.42374 .02232 L
.42501 .02232 L
.42565 .02231 L
.42636 .02231 L
.42761 .02231 L
.42878 .02231 L
Mistroke
.42948 .02231 L
.43016 .02231 L
.43141 .02231 L
.43212 .02232 L
.43277 .02232 L
.43425 .02232 L
.43677 .02232 L
.43905 .02232 L
.44417 .02232 L
.45321 .02233 L
.45776 .02233 L
.46034 .02233 L
.46275 .02233 L
.46405 .02233 L
.46529 .02233 L
.46639 .02233 L
.4676 .02233 L
.4689 .02233 L
.46957 .02233 L
.47029 .02233 L
.47158 .02233 L
.47279 .02233 L
.47392 .02233 L
.4751 .02233 L
.47723 .02233 L
.47951 .02233 L
.48201 .02233 L
.48723 .02232 L
.49281 .02231 L
.50284 .02229 L
.54436 .0222 L
.56517 .02216 L
.58436 .02213 L
.60306 .02211 L
.62285 .0221 L
.64243 .02209 L
.66075 .02208 L
.6996 .02206 L
.71936 .02206 L
.74089 .02205 L
.78067 .02204 L
.8004 .02204 L
.82139 .02204 L
.86305 .02203 L
.90318 .02203 L
.94181 .02203 L
.97619 .02203 L
Mfstroke
0 1 .656 r
.02381 .01472 m
.03279 .0945 L
.04262 .16427 L
.04758 .19216 L
.05288 .21644 L
.05789 .23408 L
.06244 .24578 L
.06507 .25071 L
.0665 .25288 L
.06785 .25457 L
.06908 .25586 L
.07022 .25682 L
.07148 .25764 L
.07217 .25799 L
.07283 .25825 L
.07354 .25846 L
.07418 .25859 L
.07493 .25866 L
.07563 .25866 L
.07687 .2585 L
.07757 .25832 L
.07822 .25811 L
.07958 .25749 L
.08108 .25657 L
.0841 .25402 L
.08922 .24797 L
.09469 .2397 L
.10458 .2223 L
.12439 .18703 L
.13484 .17112 L
.14594 .15698 L
.15578 .14681 L
.16664 .13794 L
.17651 .13179 L
.18579 .12747 L
.19048 .12577 L
.19562 .12427 L
.19821 .12365 L
.20098 .12309 L
.20337 .12268 L
.20597 .12232 L
.20723 .12218 L
.20856 .12206 L
.2098 .12196 L
.21096 .12189 L
.21204 .12184 L
.2132 .12181 L
.21449 .12179 L
.21566 .1218 L
.21679 .12182 L
Mistroke
.21783 .12186 L
.21897 .12192 L
.22018 .12201 L
.22243 .12224 L
.22447 .12252 L
.22681 .12293 L
.22936 .1235 L
.23186 .12419 L
.23452 .12509 L
.2393 .1272 L
.24376 .12987 L
.24936 .13451 L
.25466 .14068 L
.25942 .14815 L
.26459 .1587 L
.27395 .18319 L
.28402 .20954 L
.28683 .21547 L
.28978 .22076 L
.29252 .22473 L
.29507 .2276 L
.29746 .2296 L
.2988 .23043 L
.30002 .23101 L
.30067 .23126 L
.30135 .23147 L
.30211 .23164 L
.3028 .23175 L
.30405 .23182 L
.30476 .2318 L
.30543 .23173 L
.30669 .2315 L
.30786 .23116 L
.30915 .23066 L
.31052 .22999 L
.31281 .22856 L
.31534 .22659 L
.32439 .21701 L
.34475 .18929 L
.36569 .16327 L
.37487 .15422 L
.38492 .14608 L
.39466 .13985 L
.40374 .13537 L
.41332 .13182 L
.42357 .1291 L
.4338 .12716 L
.44489 .12554 L
.46504 .12284 L
.50592 .11659 L
Mistroke
.52626 .11387 L
.54529 .11194 L
.56354 .11063 L
.57378 .11009 L
.58315 .1097 L
.593 .10939 L
.60215 .10916 L
.61218 .10897 L
.61775 .10889 L
.62288 .10883 L
.62779 .10878 L
.63317 .10874 L
.63859 .10871 L
.6443 .10868 L
.64934 .10866 L
.65217 .10866 L
.65474 .10865 L
.65714 .10865 L
.65849 .10865 L
.65974 .10865 L
.66084 .10865 L
.66204 .10865 L
.6633 .10865 L
.66448 .10865 L
.66566 .10865 L
.66692 .10865 L
.6681 .10865 L
.66918 .10865 L
.67183 .10865 L
.67432 .10866 L
.67929 .10867 L
.68468 .10868 L
.69431 .10871 L
.70319 .10875 L
.74261 .10898 L
.78052 .10927 L
.82088 .10962 L
.85972 .10997 L
.90102 .11035 L
.9408 .11069 L
.97619 .11098 L
Mfstroke
0 1 .68 r
.02381 .01472 m
.02499 .02009 L
.02605 .02113 L
.02729 .02149 L
.02846 .02158 L
.02954 .02157 L
.03053 .02151 L
.03163 .02141 L
.03279 .02129 L
.04262 .02004 L
.05217 .01894 L
.06244 .018 L
.0728 .01728 L
.0825 .01677 L
.09403 .01632 L
.10458 .01603 L
.11442 .01582 L
.12357 .01568 L
.1336 .01556 L
.14429 .01546 L
.15457 .0154 L
.1657 .01535 L
.17621 .01531 L
.18587 .01529 L
.19561 .01527 L
.2047 .01526 L
.21467 .01525 L
.22026 .01524 L
.22536 .01524 L
.23016 .01524 L
.23527 .01524 L
.23963 .01524 L
.24211 .01524 L
.24444 .01524 L
.24698 .01524 L
.24826 .01524 L
.24899 .01524 L
.24965 .01524 L
.25085 .01523 L
.25213 .01523 L
.25332 .01523 L
.25443 .01523 L
.25574 .01523 L
.2564 .01524 L
.25712 .01524 L
.2596 .01524 L
.261 .01524 L
.2625 .01524 L
.2652 .01524 L
.27533 .01524 L
Mistroke
.27811 .01524 L
.27963 .01524 L
.28106 .01524 L
.28241 .01524 L
.28311 .01524 L
.28385 .01524 L
.28517 .01524 L
.28638 .01524 L
.28763 .01524 L
.28877 .01524 L
.29009 .01524 L
.29134 .01524 L
.29249 .01524 L
.29356 .01524 L
.29597 .01524 L
.29839 .01524 L
.30107 .01524 L
.30648 .01524 L
.32749 .01523 L
.34674 .01523 L
.36562 .01522 L
.37511 .01522 L
.38044 .01522 L
.38547 .01522 L
.39042 .01522 L
.39578 .01522 L
.40512 .01522 L
.41043 .01522 L
.41604 .01522 L
.42609 .01522 L
.46403 .01522 L
.50442 .01522 L
.5433 .01522 L
.56308 .01522 L
.58462 .01522 L
.6053 .01522 L
.62444 .01522 L
.64308 .01522 L
.66367 .01522 L
.683 .01522 L
.69295 .01522 L
.70384 .01522 L
.71352 .01522 L
.72386 .01522 L
.73478 .01522 L
.74495 .01522 L
.75518 .01522 L
.76095 .01522 L
.76627 .01522 L
.77093 .01522 L
Mistroke
.77605 .01522 L
.77863 .01522 L
.7814 .01522 L
.78402 .01522 L
.78642 .01522 L
.78771 .01522 L
.78892 .01522 L
.79001 .01522 L
.79119 .01522 L
.79248 .01522 L
.79312 .01522 L
.79384 .01522 L
.7951 .01522 L
.79627 .01522 L
.79746 .01522 L
.79858 .01522 L
.80069 .01522 L
.80295 .01522 L
.80542 .01522 L
.81619 .01522 L
.82614 .01522 L
.86543 .01522 L
.9032 .01522 L
.94342 .01522 L
.97619 .01522 L
Mfstroke
0 1 .704 r
.02381 .01472 m
.03279 .09437 L
.04262 .16168 L
.04758 .1862 L
.0503 .19684 L
.05288 .20506 L
.05528 .21115 L
.05655 .21378 L
.05789 .21614 L
.05902 .2178 L
.06026 .2193 L
.06139 .22037 L
.06244 .22113 L
.0631 .22149 L
.06379 .22179 L
.06504 .22208 L
.06581 .22213 L
.06653 .22208 L
.06718 .22197 L
.06788 .22177 L
.06919 .2212 L
.06985 .22082 L
.07057 .22034 L
.07305 .2182 L
.07547 .21546 L
.07806 .21196 L
.08274 .2045 L
.10458 .16362 L
.12439 .1321 L
.13558 .11853 L
.14594 .10853 L
.15591 .10092 L
.16526 .0953 L
.17502 .09078 L
.18016 .08888 L
.18579 .08713 L
.19562 .08482 L
.20098 .08394 L
.20355 .0836 L
.20597 .08334 L
.20822 .08313 L
.21066 .08296 L
.21173 .0829 L
.21287 .08285 L
.21394 .08281 L
.21492 .08278 L
.21605 .08276 L
.21727 .08275 L
.2184 .08275 L
.21947 .08277 L
Mistroke
.22071 .08279 L
.22186 .08283 L
.22313 .08289 L
.22447 .08297 L
.22709 .08318 L
.22985 .08349 L
.2322 .08382 L
.23479 .08427 L
.23757 .08487 L
.24055 .08567 L
.24593 .08758 L
.24853 .08878 L
.25135 .09033 L
.25649 .09396 L
.26149 .09874 L
.26611 .10439 L
.27588 .11919 L
.28101 .12695 L
.2864 .13379 L
.29115 .13821 L
.29383 .14 L
.29512 .14067 L
.29633 .1412 L
.29744 .1416 L
.29864 .14194 L
.29973 .14217 L
.30073 .14232 L
.30182 .14242 L
.30301 .14245 L
.30426 .1424 L
.30543 .14228 L
.30664 .14209 L
.30777 .14185 L
.31032 .14112 L
.31257 .14028 L
.31496 .13922 L
.32366 .13424 L
.34323 .12082 L
.35281 .11471 L
.3629 .10921 L
.37151 .10542 L
.37646 .10365 L
.38095 .10233 L
.38578 .10123 L
.38844 .10077 L
.38966 .10061 L
.39095 .10045 L
.39206 .10035 L
.39328 .10026 L
.39439 .1002 L
Mistroke
.39542 .10017 L
.39664 .10016 L
.39776 .10018 L
.39905 .10024 L
.40027 .10034 L
.40158 .10048 L
.40277 .10065 L
.40544 .10118 L
.40791 .10188 L
.41024 .10274 L
.41296 .10402 L
.41547 .10549 L
.42112 .10997 L
.42582 .11506 L
.43086 .12197 L
.43996 .13776 L
.4507 .15885 L
.46063 .17591 L
.46557 .18227 L
.46809 .18485 L
.47081 .18709 L
.47223 .18804 L
.47353 .18877 L
.47485 .18938 L
.47607 .18984 L
.47743 .19021 L
.47814 .19036 L
.4789 .19047 L
.47971 .19054 L
.48046 .19057 L
.48114 .19057 L
.48188 .19053 L
.48313 .19038 L
.48431 .19015 L
.48559 .1898 L
.48697 .18932 L
.48978 .18802 L
.49236 .1865 L
.50201 .1785 L
.52265 .15581 L
.54179 .13555 L
.56033 .11983 L
.58005 .1075 L
.59037 .10258 L
.60152 .09824 L
.61115 .09516 L
.62171 .09238 L
.6417 .08845 L
.65261 .08685 L
.66278 .08561 L
Mistroke
.68319 .08369 L
.70176 .0824 L
.7209 .08137 L
.74168 .08051 L
.76151 .07986 L
.78253 .07932 L
.80206 .07893 L
.82036 .07865 L
.85912 .07821 L
.88024 .07804 L
.90033 .0779 L
.91881 .0778 L
.93851 .07771 L
.97619 .07758 L
Mfstroke
0 1 .727 r
.02381 .01472 m
.03279 .09451 L
.04262 .16477 L
.05288 .22038 L
.06244 .25839 L
.06792 .27506 L
.0731 .28782 L
.07781 .29716 L
.0828 .30494 L
.08539 .3082 L
.08823 .31123 L
.09324 .31528 L
.09606 .3169 L
.09762 .31761 L
.0991 .31818 L
.10047 .31861 L
.10196 .31898 L
.10332 .31924 L
.10458 .31942 L
.10587 .31953 L
.10651 .31956 L
.10722 .31958 L
.10848 .31957 L
.10966 .31952 L
.11037 .31947 L
.11104 .3194 L
.11231 .31925 L
.11367 .31903 L
.11515 .31874 L
.12032 .31735 L
.1251 .31565 L
.14371 .30719 L
.15346 .3027 L
.16396 .29848 L
.16879 .29686 L
.17388 .29541 L
.17865 .29433 L
.18298 .29357 L
.1853 .29327 L
.18749 .29305 L
.1887 .29296 L
.18981 .29289 L
.19103 .29283 L
.19232 .2928 L
.19335 .29279 L
.19445 .2928 L
.1955 .29282 L
.19645 .29286 L
.19757 .29292 L
.19879 .29301 L
Mistroke
.201 .29324 L
.20361 .29362 L
.20596 .29406 L
.21124 .29546 L
.21613 .29729 L
.22073 .29956 L
.2254 .30249 L
.23052 .30658 L
.23586 .31205 L
.24084 .31853 L
.24977 .3345 L
.25477 .34646 L
.25933 .35934 L
.26939 .39222 L
.28007 .42543 L
.28918 .44653 L
.29437 .45501 L
.29669 .45802 L
.29923 .46077 L
.3015 .46279 L
.30393 .46451 L
.30527 .46528 L
.30649 .46587 L
.30773 .46637 L
.30888 .46675 L
.30994 .46703 L
.31106 .46725 L
.31219 .4674 L
.31342 .46749 L
.31449 .46751 L
.31564 .46747 L
.31672 .46737 L
.31771 .46724 L
.31894 .46702 L
.32025 .46672 L
.3226 .46604 L
.32792 .46389 L
.33761 .45861 L
.34696 .45299 L
.35188 .45026 L
.35706 .44777 L
.3616 .44608 L
.36285 .44572 L
.36418 .44539 L
.36533 .44515 L
.36658 .44495 L
.36781 .4448 L
.36894 .44473 L
.37002 .4447 L
.37116 .44474 L
Mistroke
.37219 .44482 L
.37314 .44494 L
.3742 .44513 L
.37533 .4454 L
.37666 .44582 L
.37787 .44629 L
.38057 .44768 L
.38308 .44943 L
.38544 .45151 L
.39074 .45794 L
.39648 .4678 L
.40694 .49244 L
.41657 .51712 L
.42567 .53734 L
.43541 .55423 L
.441 .56179 L
.4461 .56748 L
.45094 .5719 L
.45608 .57568 L
.4608 .5784 L
.466 .58065 L
.46828 .58142 L
.47074 .5821 L
.47304 .58261 L
.47518 .58299 L
.4777 .58332 L
.47903 .58344 L
.48046 .58354 L
.48118 .58357 L
.48196 .5836 L
.48269 .58361 L
.48337 .58362 L
.48465 .58362 L
.4853 .5836 L
.48601 .58358 L
.48731 .58352 L
.48849 .58345 L
.49115 .58321 L
.49361 .58291 L
.49594 .58256 L
.50557 .58053 L
.5158 .57763 L
.53421 .57144 L
.57586 .5582 L
.616 .54893 L
.65462 .54048 L
.6957 .52984 L
.73526 .51892 L
.7733 .50952 L
.8138 .50141 L
Mistroke
.85278 .49512 L
.89421 .48946 L
.93413 .48475 L
.97253 .48083 L
.97619 .48049 L
Mfstroke
0 1 .751 r
.02381 .01472 m
.03279 .09451 L
.04262 .16479 L
.05288 .22055 L
.06244 .25904 L
.06792 .27619 L
.0731 .28957 L
.07781 .29958 L
.0828 .3082 L
.08823 .31551 L
.09324 .32058 L
.09864 .32449 L
.10171 .3261 L
.10458 .32723 L
.10715 .32799 L
.10954 .32848 L
.11092 .32868 L
.11216 .32881 L
.11286 .32886 L
.1136 .32891 L
.11431 .32894 L
.11496 .32895 L
.11614 .32895 L
.11725 .32892 L
.11846 .32886 L
.11976 .32875 L
.12112 .32861 L
.12241 .32844 L
.12483 .32806 L
.12944 .32709 L
.1337 .326 L
.14335 .32312 L
.1531 .3201 L
.1636 .3172 L
.16844 .3161 L
.17352 .31515 L
.17787 .31454 L
.18033 .31427 L
.18262 .31408 L
.18385 .31401 L
.18498 .31395 L
.18622 .31391 L
.18754 .31388 L
.18868 .31388 L
.18975 .31389 L
.19092 .31392 L
.19218 .31397 L
.1933 .31403 L
.19451 .31412 L
.19672 .31434 L
Mistroke
.19887 .31462 L
.20087 .31494 L
.20583 .31603 L
.21031 .31739 L
.21549 .31948 L
.22037 .32202 L
.23016 .32927 L
.23509 .3343 L
.24049 .34121 L
.25005 .35813 L
.25897 .38046 L
.27765 .43641 L
.28276 .44899 L
.28819 .45981 L
.29282 .46694 L
.29793 .47265 L
.30069 .47487 L
.30322 .4764 L
.30455 .47703 L
.306 .47758 L
.30673 .47781 L
.30751 .47802 L
.30824 .47818 L
.30892 .4783 L
.30956 .47839 L
.31025 .47846 L
.31094 .47851 L
.31169 .47853 L
.31235 .47852 L
.31305 .47849 L
.31431 .47838 L
.31563 .47819 L
.31688 .47793 L
.31921 .47729 L
.32164 .47641 L
.32422 .47527 L
.32885 .47278 L
.33935 .46584 L
.34892 .45904 L
.35901 .45268 L
.36318 .45058 L
.36763 .44882 L
.37019 .44808 L
.3714 .44781 L
.37252 .44761 L
.37364 .44745 L
.37485 .44734 L
.37593 .44729 L
.37706 .4473 L
.37826 .44737 L
Mistroke
.37935 .4475 L
.38061 .44772 L
.38181 .44801 L
.38394 .44872 L
.38626 .4498 L
.3888 .45139 L
.39151 .4536 L
.39639 .45898 L
.40202 .4676 L
.40732 .47787 L
.41723 .5003 L
.43563 .53887 L
.44607 .5549 L
.45581 .56597 L
.46544 .57378 L
.47084 .577 L
.47576 .57933 L
.48094 .58122 L
.48368 .58202 L
.48658 .58273 L
.48911 .58324 L
.49191 .58369 L
.49445 .58401 L
.49683 .58425 L
.49801 .58434 L
.49926 .58442 L
.50035 .58448 L
.50153 .58453 L
.50225 .58456 L
.50292 .58458 L
.50422 .5846 L
.50541 .58461 L
.50667 .58462 L
.5079 .58461 L
.50922 .58458 L
.51047 .58455 L
.5116 .58451 L
.51439 .5844 L
.51703 .58425 L
.52588 .58359 L
.53554 .58272 L
.5457 .58183 L
.55526 .58113 L
.56056 .58082 L
.56628 .58057 L
.56881 .58048 L
.57148 .5804 L
.57377 .58034 L
.57625 .5803 L
.57758 .58028 L
Mistroke
.57881 .58026 L
.57997 .58025 L
.58123 .58024 L
.58237 .58023 L
.58343 .58023 L
.58456 .58022 L
.58577 .58022 L
.58707 .58022 L
.58781 .58022 L
.58849 .58023 L
.58974 .58023 L
.59108 .58024 L
.59363 .58026 L
.59595 .58028 L
.6143 .58054 L
.61917 .5806 L
.62183 .58062 L
.62432 .58064 L
.62644 .58065 L
.62763 .58066 L
.62871 .58066 L
.6299 .58066 L
.63119 .58066 L
.63241 .58066 L
.63354 .58066 L
.63473 .58065 L
.63601 .58064 L
.63833 .58063 L
.64109 .5806 L
.64363 .58056 L
.64885 .58046 L
.65435 .58031 L
.66389 .57996 L
.67408 .57946 L
.69245 .57829 L
.73393 .575 L
.7739 .57188 L
.81236 .56919 L
.85326 .56646 L
.89265 .56381 L
.93053 .56125 L
.97086 .55858 L
.97619 .55824 L
Mfstroke
0 1 .775 r
.02381 .01472 m
.03279 .09451 L
.04262 .16477 L
.05288 .22042 L
.06244 .25857 L
.06792 .27542 L
.0731 .28843 L
.07781 .29807 L
.0828 .30626 L
.08823 .31309 L
.09324 .31771 L
.09603 .31967 L
.09864 .32115 L
.1015 .32242 L
.10312 .32298 L
.10458 .3234 L
.1058 .32369 L
.10712 .32395 L
.10851 .32416 L
.10982 .3243 L
.11105 .32438 L
.11235 .32442 L
.11346 .32442 L
.11468 .32439 L
.11542 .32435 L
.11612 .3243 L
.11744 .32419 L
.11885 .32402 L
.12039 .3238 L
.12571 .32272 L
.13077 .32138 L
.13615 .31973 L
.1458 .31652 L
.15517 .31349 L
.16528 .31071 L
.16992 .30968 L
.17481 .30882 L
.17899 .30826 L
.18135 .30803 L
.18355 .30787 L
.18483 .30781 L
.18547 .30778 L
.18618 .30776 L
.18743 .30773 L
.1886 .30773 L
.18931 .30773 L
.18998 .30775 L
.19124 .30778 L
.19195 .30781 L
.1926 .30785 L
Mistroke
.19408 .30794 L
.19538 .30806 L
.1966 .30818 L
.19889 .30848 L
.20135 .30889 L
.20401 .30945 L
.20873 .31074 L
.2137 .31257 L
.21795 .31458 L
.2226 .31731 L
.22786 .32119 L
.23283 .32579 L
.24215 .33766 L
.24736 .3467 L
.25218 .35694 L
.26308 .38689 L
.27285 .41726 L
.27798 .43176 L
.28337 .44476 L
.28812 .45398 L
.29062 .45799 L
.2933 .46162 L
.29577 .46439 L
.29801 .46644 L
.3001 .46798 L
.3024 .46927 L
.30362 .46979 L
.30476 .47019 L
.30597 .4705 L
.30726 .47073 L
.30846 .47085 L
.3096 .47088 L
.31062 .47084 L
.31174 .47072 L
.31295 .47052 L
.31428 .47021 L
.31568 .4698 L
.31699 .46932 L
.32185 .46693 L
.32645 .46391 L
.33068 .46065 L
.3402 .45223 L
.35011 .44301 L
.3607 .43396 L
.36584 .43024 L
.3707 .4273 L
.37506 .42525 L
.37752 .42438 L
.37871 .42404 L
.37979 .42378 L
Mistroke
.38084 .42357 L
.38198 .4234 L
.38319 .42329 L
.38433 .42324 L
.3854 .42325 L
.38654 .42333 L
.38762 .42347 L
.38859 .42365 L
.38984 .42396 L
.39099 .42432 L
.39358 .42546 L
.39586 .42684 L
.39828 .42871 L
.40311 .43384 L
.40762 .44037 L
.41787 .46089 L
.43652 .50576 L
.44635 .52637 L
.45679 .5439 L
.46784 .5577 L
.47311 .56277 L
.47805 .56676 L
.48762 .57267 L
.4927 .57499 L
.49818 .57697 L
.50281 .5783 L
.50776 .57942 L
.51318 .58036 L
.51823 .58102 L
.52392 .58158 L
.52929 .58199 L
.53934 .58258 L
.57782 .58521 L
.59732 .58712 L
.61876 .58912 L
.62858 .58987 L
.63913 .59052 L
.64424 .59078 L
.64909 .59098 L
.65378 .59114 L
.65818 .59127 L
.66323 .59138 L
.6678 .59146 L
.67037 .59149 L
.67273 .59151 L
.67532 .59153 L
.67662 .59153 L
.6773 .59154 L
.67804 .59154 L
.67928 .59154 L
Mistroke
.68045 .59154 L
.68159 .59154 L
.68265 .59154 L
.68378 .59154 L
.68504 .59154 L
.68634 .59154 L
.68757 .59153 L
.6898 .59152 L
.69185 .5915 L
.69645 .59147 L
.70629 .59135 L
.71542 .59122 L
.73614 .59088 L
.77526 .5903 L
.81683 .58976 L
.85689 .58914 L
.89542 .58841 L
.93642 .58757 L
.97589 .58674 L
.97619 .58673 L
Mfstroke
0 1 .798 r
.02381 .01472 m
.03279 .0945 L
.04262 .16472 L
.05288 .21996 L
.06244 .25713 L
.06792 .27312 L
.0731 .28514 L
.07775 .29365 L
.0828 .30075 L
.0883 .30627 L
.09107 .3083 L
.09413 .31 L
.09673 .31107 L
.09819 .31152 L
.09952 .31186 L
.10076 .31209 L
.10142 .31219 L
.10212 .31228 L
.10339 .3124 L
.10458 .31245 L
.10582 .31246 L
.10653 .31244 L
.10718 .3124 L
.10788 .31235 L
.10851 .3123 L
.10994 .31213 L
.11115 .31194 L
.11247 .3117 L
.11487 .31115 L
.12064 .3094 L
.12599 .30737 L
.14616 .29847 L
.15514 .29477 L
.16483 .29143 L
.17037 .2899 L
.17545 .28878 L
.18031 .28798 L
.18276 .28769 L
.18415 .28756 L
.18543 .28746 L
.18666 .28738 L
.18796 .28732 L
.18927 .28728 L
.19002 .28727 L
.19071 .28727 L
.19197 .28728 L
.19312 .28731 L
.19375 .28733 L
.19444 .28737 L
.1957 .28745 L
Mistroke
.19693 .28755 L
.19805 .28766 L
.20055 .28798 L
.20286 .28837 L
.20504 .28882 L
.21029 .29027 L
.21511 .29211 L
.2204 .29476 L
.22599 .29842 L
.23096 .30259 L
.23549 .3073 L
.24037 .31357 L
.24567 .32213 L
.25509 .343 L
.26401 .36951 L
.27424 .40248 L
.28383 .42793 L
.28864 .43734 L
.29383 .44476 L
.29663 .44765 L
.29816 .44891 L
.29958 .44988 L
.3009 .45062 L
.3021 .45116 L
.30343 .45162 L
.30416 .45181 L
.30485 .45195 L
.30601 .4521 L
.30725 .45215 L
.30842 .45209 L
.30949 .45195 L
.31075 .4517 L
.31211 .4513 L
.31459 .45029 L
.31719 .44886 L
.31995 .44698 L
.3249 .44277 L
.34337 .42142 L
.36304 .39643 L
.38108 .37723 L
.39049 .36971 L
.39528 .36665 L
.40041 .36399 L
.40311 .36284 L
.40556 .36195 L
.40806 .36119 L
.41036 .36061 L
.41305 .3601 L
.41446 .3599 L
.41596 .35973 L
Mistroke
.41726 .35962 L
.41848 .35956 L
.41918 .35954 L
.41982 .35953 L
.42056 .35953 L
.42126 .35954 L
.4225 .35959 L
.4232 .35963 L
.42385 .35968 L
.42504 .35979 L
.42629 .35994 L
.42846 .3603 L
.43085 .36082 L
.4334 .36153 L
.43614 .36246 L
.44108 .36461 L
.4507 .37042 L
.45947 .37727 L
.48018 .3959 L
.49933 .41133 L
.51793 .42219 L
.52732 .42623 L
.53768 .42991 L
.55867 .43625 L
.57791 .44259 L
.61661 .46042 L
.65626 .48198 L
.69439 .49942 L
.73497 .51307 L
.77403 .52326 L
.81555 .53236 L
.85555 .53974 L
.89404 .54564 L
.93498 .55087 L
.9744 .55512 L
.97619 .5553 L
Mfstroke
0 1 .822 r
.02381 .01472 m
.03279 .0945 L
.04262 .16471 L
.05288 .2199 L
.06244 .2569 L
.06792 .2727 L
.0731 .28448 L
.07775 .29272 L
.0828 .29947 L
.08542 .30215 L
.0883 .30454 L
.09131 .30644 L
.09275 .30716 L
.09413 .30774 L
.09538 .30817 L
.09676 .30856 L
.098 .30882 L
.09916 .30901 L
.09987 .30909 L
.10054 .30915 L
.10178 .30921 L
.10248 .30921 L
.10313 .3092 L
.10383 .30918 L
.10458 .30912 L
.1058 .309 L
.10713 .30881 L
.10954 .30833 L
.11189 .30771 L
.11406 .30702 L
.12422 .3027 L
.14255 .29301 L
.1523 .28809 L
.1628 .28358 L
.16764 .28186 L
.17272 .28033 L
.17749 .27917 L
.18182 .27836 L
.18414 .27803 L
.18633 .27778 L
.18746 .27767 L
.18865 .27759 L
.18995 .27751 L
.19116 .27746 L
.19219 .27744 L
.1933 .27743 L
.19434 .27744 L
.1953 .27747 L
.19641 .27751 L
.19763 .27759 L
Mistroke
.19878 .27768 L
.19985 .27778 L
.20243 .27811 L
.20486 .27852 L
.2094 .2796 L
.21429 .28123 L
.21957 .28362 L
.2245 .28655 L
.2291 .29001 L
.23414 .29478 L
.23955 .3013 L
.24522 .31013 L
.25058 .32083 L
.26062 .34793 L
.27888 .40688 L
.28388 .41975 L
.28927 .4307 L
.29175 .4347 L
.29435 .43822 L
.29679 .44088 L
.29901 .44279 L
.30138 .44433 L
.30268 .44496 L
.30391 .44542 L
.30505 .44573 L
.3061 .44593 L
.30726 .44604 L
.30847 .44606 L
.3097 .44596 L
.31102 .44574 L
.31227 .44543 L
.3134 .44506 L
.31618 .44382 L
.31882 .44225 L
.32404 .43817 L
.32888 .43345 L
.33984 .42047 L
.36007 .39336 L
.37907 .37011 L
.38791 .36123 L
.39722 .35353 L
.40743 .34707 L
.41679 .34274 L
.42632 .33949 L
.43156 .33807 L
.43651 .33695 L
.44112 .3361 L
.44355 .33573 L
.44612 .3354 L
.44829 .33518 L
Mistroke
.45067 .33498 L
.45172 .33492 L
.45284 .33486 L
.4539 .33481 L
.45487 .33478 L
.45616 .33476 L
.45737 .33475 L
.45846 .33475 L
.45964 .33477 L
.46093 .33481 L
.46158 .33484 L
.46229 .33487 L
.46472 .33502 L
.46701 .33521 L
.46945 .33546 L
.47387 .33604 L
.48471 .33797 L
.4946 .34009 L
.53446 .34784 L
.5527 .35064 L
.56307 .35237 L
.57281 .35427 L
.5926 .35942 L
.60272 .36287 L
.61361 .36722 L
.65477 .38808 L
.69442 .40965 L
.73255 .42794 L
.77313 .44484 L
.81219 .4596 L
.85371 .47387 L
.89371 .48601 L
.9322 .49622 L
.97314 .50569 L
.97619 .50634 L
Mfstroke
0 1 .846 r
.02381 .01472 m
.03279 .09446 L
.04262 .16297 L
.04758 .18876 L
.0503 .20022 L
.05288 .20924 L
.05528 .21604 L
.05789 .22171 L
.05904 .22367 L
.06026 .22538 L
.0613 .22657 L
.06244 .22757 L
.06314 .22803 L
.06378 .22837 L
.06505 .22878 L
.0662 .22886 L
.06743 .22866 L
.06813 .22843 L
.06888 .22808 L
.07025 .2272 L
.07157 .22607 L
.0728 .2248 L
.07751 .2182 L
.0825 .20906 L
.10458 .16094 L
.11478 .14103 L
.12444 .125 L
.14255 .10225 L
.1519 .09371 L
.16206 .08642 L
.17292 .08052 L
.18298 .07649 L
.18761 .07501 L
.1926 .07367 L
.20164 .0718 L
.20688 .07103 L
.20973 .07071 L
.21239 .07046 L
.21466 .07028 L
.21709 .07014 L
.21848 .07009 L
.21979 .07004 L
.22097 .07002 L
.22224 .07 L
.22347 .07 L
.2246 .07001 L
.2259 .07003 L
.22713 .07006 L
.22827 .07011 L
.22932 .07016 L
Mistroke
.23171 .07031 L
.23435 .07055 L
.23675 .07084 L
.23955 .07126 L
.24212 .07173 L
.24733 .07304 L
.25007 .07393 L
.25296 .07507 L
.25783 .07751 L
.26316 .08108 L
.27405 .09116 L
.2794 .09657 L
.28435 .10098 L
.28883 .10412 L
.2911 .10533 L
.29359 .10635 L
.2949 .10677 L
.29609 .10707 L
.2974 .10733 L
.29806 .10742 L
.29878 .10751 L
.3 .1076 L
.3013 .10763 L
.30252 .10759 L
.30364 .1075 L
.3048 .10737 L
.30607 .10716 L
.30865 .10659 L
.31104 .10589 L
.31327 .10512 L
.32369 .10036 L
.3426 .0902 L
.36121 .08155 L
.37173 .07774 L
.38147 .07493 L
.39176 .07263 L
.39739 .07162 L
.40269 .07083 L
.41225 .06973 L
.41732 .0693 L
.4228 .06892 L
.43236 .06845 L
.43778 .06826 L
.44282 .06812 L
.45366 .06785 L
.46391 .06757 L
.48434 .0668 L
.50292 .06587 L
.52122 .06492 L
.54136 .06403 L
Mistroke
.56121 .06338 L
.57207 .0631 L
.58224 .0629 L
.59263 .06273 L
.60251 .0626 L
.62104 .06242 L
.64086 .06228 L
.65925 .06218 L
.67806 .06211 L
.6984 .06204 L
.71983 .06198 L
.72945 .06196 L
.74 .06195 L
.75995 .06192 L
.77085 .06191 L
.78102 .0619 L
.78604 .0619 L
.79149 .0619 L
.79629 .0619 L
.80139 .06189 L
.80598 .06189 L
.81103 .06189 L
.81564 .06189 L
.81995 .06189 L
.82239 .06189 L
.82465 .06189 L
.82596 .06189 L
.82714 .06189 L
.8278 .06189 L
.82851 .06189 L
.82979 .06189 L
.83104 .06189 L
.83175 .06189 L
.83241 .06189 L
.83311 .06189 L
.83375 .06189 L
.83518 .06189 L
.8364 .06189 L
.83773 .06189 L
.84015 .06189 L
.8448 .06189 L
.84976 .06189 L
.85866 .06189 L
.86898 .0619 L
.88013 .0619 L
.90031 .0619 L
.94139 .06192 L
.97619 .06193 L
Mfstroke
0 1 .87 r
.02381 .01472 m
.02846 .0578 L
.03279 .0939 L
.03793 .12977 L
.04262 .15398 L
.04498 .1628 L
.04622 .16652 L
.04754 .16978 L
.04869 .17207 L
.04996 .17401 L
.05112 .17527 L
.0522 .17604 L
.05352 .17647 L
.05478 .17641 L
.0559 .176 L
.05713 .1752 L
.05783 .1746 L
.05847 .17397 L
.05989 .17229 L
.06244 .16846 L
.08269 .12529 L
.09333 .10426 L
.10458 .0862 L
.11453 .07363 L
.12545 .06295 L
.13538 .05552 L
.14465 .05016 L
.1551 .04554 L
.165 .04225 L
.17389 .03999 L
.18355 .03813 L
.19295 .03679 L
.20333 .03573 L
.20854 .03534 L
.21416 .03501 L
.21675 .03488 L
.21947 .03477 L
.22181 .03469 L
.22434 .03462 L
.22691 .03457 L
.22809 .03455 L
.22934 .03453 L
.23046 .03452 L
.2317 .03451 L
.23283 .0345 L
.23388 .0345 L
.2352 .0345 L
.23645 .03451 L
.23757 .03452 L
.2388 .03453 L
Mistroke
.24012 .03455 L
.24154 .03458 L
.24408 .03465 L
.24647 .03473 L
.24904 .03485 L
.25372 .03512 L
.25827 .03548 L
.26245 .0359 L
.27233 .03716 L
.27776 .03791 L
.28291 .03852 L
.28769 .03895 L
.2904 .03913 L
.29168 .03919 L
.29289 .03924 L
.29399 .03927 L
.29499 .0393 L
.29611 .03932 L
.2973 .03933 L
.29839 .03933 L
.29959 .03933 L
.30083 .03931 L
.30199 .03929 L
.30323 .03926 L
.30437 .03923 L
.30695 .03912 L
.31163 .03887 L
.32038 .03822 L
.34001 .03652 L
.34985 .03573 L
.36041 .035 L
.36953 .03447 L
.37946 .03402 L
.38965 .03366 L
.39433 .03354 L
.3993 .03342 L
.40377 .03333 L
.4087 .03326 L
.41286 .0332 L
.4174 .03316 L
.42231 .03312 L
.42499 .03311 L
.42748 .0331 L
.42978 .03309 L
.43195 .03308 L
.43445 .03308 L
.43673 .03307 L
.43793 .03307 L
.43925 .03307 L
.44063 .03307 L
Mistroke
.44193 .03307 L
.44314 .03307 L
.44424 .03307 L
.44551 .03307 L
.44673 .03307 L
.44802 .03307 L
.44924 .03307 L
.44991 .03307 L
.45064 .03307 L
.45191 .03307 L
.45266 .03307 L
.45344 .03307 L
.45411 .03307 L
.45485 .03307 L
.45626 .03307 L
.45757 .03307 L
.45884 .03306 L
.46018 .03306 L
.46259 .03306 L
.46518 .03306 L
.46804 .03305 L
.47315 .03303 L
.47794 .03301 L
.48688 .03296 L
.4965 .03288 L
.53766 .03249 L
.5582 .03233 L
.56822 .03226 L
.57731 .03222 L
.59575 .03214 L
.60588 .03211 L
.61544 .03209 L
.65392 .03202 L
.67381 .03199 L
.69486 .03197 L
.73277 .03193 L
.75223 .03192 L
.77313 .0319 L
.79289 .0319 L
.81442 .03189 L
.8542 .03188 L
.89492 .03187 L
.93412 .03186 L
.97578 .03186 L
.97619 .03186 L
Mfstroke
0 1 .893 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02123 L
.03053 .02114 L
.03279 .02087 L
.04262 .01953 L
.05285 .01836 L
.06244 .01751 L
.07218 .01686 L
.0829 .01633 L
.09334 .01595 L
.10458 .01566 L
.11468 .01547 L
.12571 .01532 L
.13613 .01522 L
.1458 .01515 L
.15637 .0151 L
.16633 .01506 L
.17526 .01503 L
.18493 .01501 L
.19444 .015 L
.20487 .01498 L
.21577 .01497 L
.22594 .01497 L
.23094 .01497 L
.23639 .01496 L
.24119 .01496 L
.24629 .01496 L
.25087 .01496 L
.25593 .01496 L
.26053 .01496 L
.26485 .01496 L
.30353 .01496 L
.32318 .01495 L
.33357 .01495 L
.34467 .01495 L
.35543 .01495 L
.3652 .01495 L
.36991 .01495 L
.37502 .01495 L
.3843 .01495 L
.38919 .01495 L
.39376 .01495 L
.39638 .01495 L
.39878 .01495 L
.4001 .01495 L
.40155 .01495 L
Mistroke
.40281 .01495 L
.40417 .01495 L
.40492 .01495 L
.4056 .01495 L
.40624 .01495 L
.40695 .01495 L
.40817 .01495 L
.40946 .01495 L
.4102 .01495 L
.41087 .01495 L
.41164 .01495 L
.41238 .01495 L
.41368 .01495 L
.41509 .01495 L
.41765 .01495 L
.42035 .01495 L
.42522 .01495 L
.43461 .01495 L
.44473 .01495 L
.45421 .01495 L
.46302 .01495 L
.46766 .01495 L
.47004 .01495 L
.47261 .01495 L
.47409 .01495 L
.47544 .01495 L
.47671 .01495 L
.47811 .01495 L
.47936 .01495 L
.48054 .01495 L
.48177 .01495 L
.48247 .01495 L
.4831 .01495 L
.4844 .01495 L
.48506 .01495 L
.48579 .01495 L
.48708 .01495 L
.48829 .01495 L
.491 .01495 L
.49394 .01495 L
.49929 .01495 L
.50421 .01495 L
.52311 .01495 L
.5438 .01495 L
.56503 .01495 L
.58433 .01495 L
.60439 .01495 L
.62334 .01495 L
.66178 .01495 L
.70266 .01495 L
Mistroke
.74204 .01495 L
.77989 .01495 L
.8202 .01495 L
.85899 .01495 L
.90023 .01495 L
.93996 .01495 L
.97619 .01495 L
Mfstroke
0 1 .917 r
.02381 .01472 m
.02846 .05722 L
.03068 .07471 L
.03279 .0886 L
.03398 .09518 L
.03527 .10119 L
.03635 .10531 L
.03754 .10895 L
.03882 .1119 L
.03952 .11311 L
.04018 .11402 L
.04135 .11511 L
.04262 .11564 L
.04393 .1156 L
.04516 .1151 L
.04586 .11464 L
.0465 .11414 L
.04793 .11275 L
.05297 .10591 L
.06244 .09045 L
.07287 .0747 L
.08414 .06095 L
.09479 .05099 L
.10458 .04397 L
.11432 .03862 L
.1234 .03478 L
.13338 .03155 L
.14407 .02898 L
.15424 .02717 L
.16531 .02573 L
.17576 .02474 L
.18543 .02407 L
.19506 .02357 L
.20409 .02324 L
.20926 .02309 L
.21401 .02298 L
.21921 .02288 L
.22203 .02284 L
.22469 .0228 L
.22709 .02278 L
.2297 .02276 L
.23206 .02274 L
.23424 .02273 L
.23546 .02273 L
.2366 .02272 L
.23785 .02272 L
.23855 .02272 L
.23919 .02272 L
.24048 .02272 L
.24121 .02272 L
Mistroke
.24188 .02272 L
.24312 .02273 L
.24444 .02273 L
.24682 .02275 L
.2494 .02277 L
.25184 .02279 L
.25408 .02282 L
.25832 .02289 L
.2628 .02299 L
.27303 .02325 L
.27806 .02338 L
.28271 .02348 L
.28692 .02354 L
.28905 .02357 L
.29019 .02358 L
.29139 .02359 L
.29262 .0236 L
.29374 .0236 L
.29494 .0236 L
.29626 .02361 L
.29741 .0236 L
.29863 .0236 L
.29978 .0236 L
.30083 .02359 L
.30334 .02358 L
.30566 .02356 L
.31089 .02349 L
.32038 .02334 L
.3413 .02296 L
.3601 .02267 L
.37078 .02255 L
.38076 .02247 L
.38575 .02243 L
.39119 .0224 L
.39633 .02238 L
.39878 .02237 L
.40109 .02237 L
.40331 .02236 L
.40536 .02236 L
.40646 .02236 L
.40763 .02236 L
.4088 .02236 L
.41008 .02236 L
.41133 .02236 L
.41247 .02236 L
.41378 .02236 L
.41503 .02236 L
.41618 .02236 L
.41724 .02236 L
.41964 .02236 L
Mistroke
.42207 .02237 L
.4243 .02238 L
.42931 .02239 L
.43838 .02244 L
.44908 .0225 L
.45901 .02256 L
.46374 .02259 L
.4682 .0226 L
.47068 .02261 L
.47335 .02262 L
.47577 .02262 L
.47801 .02263 L
.47921 .02263 L
.48049 .02263 L
.48171 .02263 L
.48281 .02263 L
.48411 .02263 L
.48484 .02263 L
.48552 .02263 L
.48677 .02263 L
.48809 .02263 L
.4907 .02262 L
.49315 .02262 L
.49873 .0226 L
.50344 .02258 L
.50858 .02256 L
.51893 .02251 L
.53744 .0224 L
.55871 .02229 L
.57802 .0222 L
.59812 .02213 L
.61709 .02208 L
.63712 .02205 L
.65557 .02202 L
.67435 .022 L
.695 .02199 L
.71446 .02197 L
.73536 .02196 L
.75655 .02196 L
.77665 .02195 L
.79651 .02195 L
.81492 .02194 L
.83377 .02194 L
.85412 .02194 L
.87559 .02194 L
.89577 .02194 L
.91537 .02193 L
.93685 .02193 L
.97619 .02193 L
Mfstroke
0 1 .941 r
.02381 .01472 m
.03279 .09447 L
.04262 .16361 L
.04758 .19068 L
.05288 .21379 L
.05789 .23025 L
.06244 .24101 L
.06507 .24551 L
.0665 .24748 L
.06785 .24904 L
.07022 .25112 L
.07148 .2519 L
.07213 .25222 L
.07283 .2525 L
.07358 .25273 L
.07427 .25289 L
.0751 .25299 L
.07585 .25302 L
.07656 .25299 L
.07733 .2529 L
.07805 .25275 L
.07872 .25257 L
.07997 .25211 L
.08134 .25145 L
.0841 .24963 L
.08922 .24488 L
.09469 .23829 L
.10458 .22424 L
.12439 .19509 L
.13484 .18164 L
.14594 .16953 L
.15578 .16074 L
.16664 .15305 L
.17651 .14773 L
.18579 .14407 L
.19048 .14268 L
.19562 .1415 L
.19821 .14104 L
.20098 .14065 L
.20232 .1405 L
.20359 .14038 L
.20472 .14029 L
.20597 .14021 L
.20713 .14015 L
.20821 .14012 L
.20936 .1401 L
.21059 .14011 L
.21173 .14013 L
.21281 .14017 L
.21379 .14022 L
Mistroke
.21485 .14029 L
.21727 .14052 L
.21862 .1407 L
.21984 .14088 L
.22447 .14183 L
.22681 .14247 L
.22936 .14332 L
.23452 .14557 L
.2393 .14842 L
.24376 .15196 L
.24902 .1576 L
.25382 .16458 L
.25936 .17547 L
.26459 .189 L
.27338 .21708 L
.28285 .24678 L
.28827 .26002 L
.29064 .26467 L
.29324 .2689 L
.29553 .27194 L
.29798 .27446 L
.29934 .27554 L
.30057 .27635 L
.30181 .27699 L
.30297 .27744 L
.30412 .27775 L
.30538 .27794 L
.3067 .27799 L
.30793 .27789 L
.30908 .27768 L
.31013 .2774 L
.31134 .27697 L
.31249 .27647 L
.31505 .27504 L
.31742 .27337 L
.32279 .26863 L
.34381 .24412 L
.35278 .23386 L
.36245 .22445 L
.36799 .22017 L
.37041 .2186 L
.37307 .21712 L
.37541 .21604 L
.37792 .21516 L
.37931 .2148 L
.38057 .21455 L
.38184 .21439 L
.38304 .21433 L
.38419 .21435 L
.38543 .21447 L
Mistroke
.38659 .21467 L
.38766 .21495 L
.38891 .21539 L
.39027 .21603 L
.39275 .21763 L
.3941 .21879 L
.39533 .22002 L
.39808 .22351 L
.40063 .22777 L
.40303 .23283 L
.40765 .24574 L
.41189 .26145 L
.42148 .30684 L
.43134 .35662 L
.44191 .40219 L
.44704 .41999 L
.45189 .43411 L
.45621 .44445 L
.46098 .45348 L
.46557 .45989 L
.46808 .46248 L
.47044 .46433 L
.47151 .46499 L
.47264 .46557 L
.47361 .46597 L
.47465 .4663 L
.47577 .46654 L
.47682 .46666 L
.47806 .46667 L
.47919 .46656 L
.48042 .46631 L
.48173 .4659 L
.48285 .46544 L
.48407 .4648 L
.48681 .46294 L
.48937 .46067 L
.494 .4553 L
.49898 .44792 L
.50912 .42855 L
.52017 .40285 L
.54027 .3517 L
.56165 .30123 L
.58099 .26382 L
.60119 .23382 L
.62019 .21298 L
.64032 .19695 L
.65881 .1862 L
.67769 .17796 L
.69837 .17109 L
.71794 .16605 L
Mistroke
.73887 .1618 L
.76017 .15842 L
.7803 .15591 L
.81871 .15251 L
.83853 .15126 L
.85956 .1502 L
.89738 .14876 L
.93766 .14766 L
.97619 .14689 L
Mfstroke
0 1 .964 r
.02381 .01472 m
.03279 .09451 L
.04262 .16473 L
.05288 .22007 L
.06244 .25746 L
.06792 .27362 L
.0731 .28581 L
.07775 .29449 L
.0828 .30176 L
.0883 .30745 L
.09107 .30955 L
.09413 .31134 L
.09673 .31246 L
.09819 .31295 L
.09952 .3133 L
.10076 .31356 L
.10142 .31368 L
.10212 .31378 L
.10339 .31391 L
.10458 .31398 L
.10582 .314 L
.10653 .31399 L
.10718 .31396 L
.10788 .31392 L
.10851 .31387 L
.10994 .31371 L
.11115 .31353 L
.11247 .3133 L
.11487 .31276 L
.12064 .31102 L
.12599 .30897 L
.14616 .29987 L
.15514 .29606 L
.16483 .29259 L
.17037 .29099 L
.17545 .28981 L
.18031 .28895 L
.18276 .28863 L
.18415 .28848 L
.18543 .28837 L
.18664 .28828 L
.18796 .2882 L
.18865 .28817 L
.1893 .28815 L
.18998 .28814 L
.19071 .28812 L
.19135 .28812 L
.19205 .28812 L
.19332 .28815 L
.19456 .28819 L
Mistroke
.1957 .28826 L
.19693 .28835 L
.19808 .28845 L
.20022 .2887 L
.20254 .28906 L
.20504 .28955 L
.21035 .29098 L
.21303 .29192 L
.21596 .29313 L
.22077 .29559 L
.22599 .29901 L
.23125 .30342 L
.23622 .3087 L
.24554 .32243 L
.25082 .33309 L
.25642 .3471 L
.26647 .37816 L
.27586 .40817 L
.28079 .42176 L
.28598 .43356 L
.29054 .44167 L
.29295 .4451 L
.29552 .44811 L
.2979 .45032 L
.30006 .45187 L
.3011 .45248 L
.30222 .45302 L
.30327 .45344 L
.30427 .45375 L
.30551 .45402 L
.30664 .45417 L
.30785 .45423 L
.30854 .45422 L
.30917 .45417 L
.31023 .45404 L
.3114 .45381 L
.31261 .45348 L
.31376 .45309 L
.31637 .45192 L
.31877 .45053 L
.32418 .44648 L
.33444 .43622 L
.34524 .42352 L
.36518 .4005 L
.37388 .39224 L
.37846 .38858 L
.38332 .38534 L
.38581 .38396 L
.38855 .38268 L
.39105 .38175 L
Mistroke
.39339 .3811 L
.39462 .38084 L
.39578 .38066 L
.39683 .38055 L
.39797 .38048 L
.39921 .38048 L
.40053 .38057 L
.40177 .38072 L
.4029 .38094 L
.40422 .38127 L
.4056 .38172 L
.40809 .38282 L
.41076 .38442 L
.41369 .38669 L
.41894 .39222 L
.42384 .39908 L
.43431 .41861 L
.44421 .44094 L
.46277 .48184 L
.47244 .49926 L
.4827 .5141 L
.49146 .52397 L
.50112 .53229 L
.51123 .53868 L
.52048 .54299 L
.53065 .54657 L
.54135 .54957 L
.57947 .55909 L
.62005 .56983 L
.6388 .57392 L
.65912 .5773 L
.67024 .57871 L
.68048 .57979 L
.70064 .5814 L
.71942 .5825 L
.74006 .58349 L
.78042 .58512 L
.81926 .58646 L
.86056 .58753 L
.90034 .58826 L
.93861 .58878 L
.97619 .58918 L
Mfstroke
0 1 .988 r
.02381 .01472 m
.03279 .09445 L
.04262 .16279 L
.04758 .18826 L
.0503 .19942 L
.05288 .20807 L
.05528 .21445 L
.05655 .21718 L
.05789 .21959 L
.05902 .22125 L
.06026 .2227 L
.06139 .22369 L
.06244 .22434 L
.0631 .2246 L
.06379 .22478 L
.06504 .22484 L
.06581 .22471 L
.06653 .22449 L
.06718 .2242 L
.06788 .2238 L
.06919 .22282 L
.07057 .22148 L
.07305 .21838 L
.07767 .21067 L
.08274 .20024 L
.10458 .1507 L
.12409 .11559 L
.13503 .1011 L
.145 .09069 L
.15492 .08259 L
.16409 .07673 L
.17416 .07177 L
.18485 .06788 L
.19422 .06541 L
.19949 .06436 L
.20432 .06357 L
.20857 .06302 L
.21322 .06256 L
.21557 .06238 L
.21808 .06223 L
.2193 .06217 L
.22045 .06213 L
.22157 .06209 L
.2226 .06207 L
.22375 .06205 L
.22499 .06204 L
.22614 .06204 L
.22723 .06205 L
.22849 .06207 L
.22967 .0621 L
Mistroke
.23095 .06214 L
.23232 .06221 L
.2351 .06238 L
.23772 .06262 L
.24007 .06288 L
.24261 .06324 L
.24729 .06411 L
.25223 .0654 L
.25645 .06688 L
.26107 .06897 L
.27195 .07594 L
.27731 .07992 L
.28225 .08334 L
.28674 .08589 L
.28903 .08693 L
.2915 .08782 L
.29279 .0882 L
.29396 .08849 L
.29516 .08873 L
.29628 .08891 L
.2975 .08905 L
.29815 .0891 L
.29884 .08915 L
.29957 .08918 L
.30026 .08919 L
.30154 .08917 L
.30271 .08911 L
.3038 .08901 L
.30499 .08888 L
.30628 .08869 L
.30889 .08819 L
.31128 .0876 L
.32025 .08466 L
.3405 .07639 L
.35052 .07258 L
.36118 .06911 L
.37104 .06648 L
.38032 .06449 L
.38907 .06301 L
.39851 .06179 L
.40362 .06127 L
.40899 .06083 L
.41403 .06049 L
.41861 .06024 L
.42318 .06005 L
.42814 .05988 L
.43338 .05975 L
.43833 .05966 L
.44788 .05953 L
.45669 .05942 L
Mistroke
.46637 .05927 L
.47543 .05907 L
.48537 .05879 L
.49606 .05841 L
.51579 .05765 L
.53731 .05687 L
.55791 .05629 L
.57703 .05591 L
.58761 .05575 L
.59757 .05563 L
.61618 .05546 L
.63628 .05533 L
.65475 .05524 L
.67519 .05515 L
.69426 .05509 L
.71378 .05503 L
.73225 .05499 L
.75262 .05496 L
.77118 .05493 L
.79111 .05491 L
.80953 .0549 L
.82821 .05489 L
.84882 .05488 L
.86818 .05487 L
.88904 .05486 L
.9091 .05486 L
.91918 .05486 L
.9302 .05486 L
.9403 .05486 L
.94983 .05486 L
.9551 .05486 L
.96081 .05486 L
.96565 .05486 L
.97078 .05486 L
.97619 .05486 L
Mfstroke
0 .988 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03479 L
.02721 .04278 L
.02846 .04917 L
.02961 .05313 L
.03068 .05545 L
.0317 .05676 L
.03279 .05748 L
.03395 .05769 L
.0352 .05749 L
.03638 .05703 L
.03746 .05644 L
.04262 .05263 L
.06244 .03791 L
.07277 .03245 L
.08405 .02802 L
.09469 .02495 L
.10458 .02283 L
.11515 .02116 L
.1251 .02 L
.13404 .01921 L
.14371 .01857 L
.15321 .01809 L
.16365 .0177 L
.17454 .01741 L
.18471 .01722 L
.19516 .01707 L
.20506 .01697 L
.21395 .01691 L
.21894 .01688 L
.22362 .01686 L
.22852 .01684 L
.23302 .01683 L
.23801 .01681 L
.24064 .01681 L
.24208 .01681 L
.2434 .01681 L
.2446 .01681 L
.24591 .0168 L
.24663 .0168 L
.24729 .0168 L
.24859 .0168 L
.24971 .0168 L
.25094 .0168 L
.25223 .0168 L
.25343 .0168 L
.25411 .0168 L
.25485 .0168 L
.25619 .01681 L
Mistroke
.25872 .01681 L
.26167 .01681 L
.2644 .01681 L
.275 .01683 L
.27753 .01684 L
.28019 .01684 L
.28266 .01684 L
.28387 .01685 L
.28497 .01685 L
.28595 .01685 L
.28703 .01685 L
.28816 .01685 L
.28924 .01685 L
.29042 .01685 L
.29167 .01685 L
.29274 .01685 L
.29392 .01685 L
.29517 .01685 L
.29632 .01685 L
.29891 .01685 L
.30119 .01684 L
.30359 .01684 L
.31316 .01682 L
.32337 .0168 L
.34175 .01676 L
.35201 .01674 L
.36313 .01673 L
.37363 .01672 L
.3833 .01671 L
.38798 .0167 L
.39302 .0167 L
.39736 .0167 L
.4021 .0167 L
.40764 .0167 L
.4129 .01669 L
.41538 .01669 L
.41801 .01669 L
.42275 .01669 L
.42513 .01669 L
.42763 .01669 L
.42977 .01669 L
.43098 .01669 L
.43211 .01669 L
.43342 .01669 L
.43466 .01669 L
.43577 .01669 L
.43698 .01669 L
.4383 .01669 L
.43896 .01669 L
.4397 .01669 L
Mistroke
.4422 .01669 L
.44457 .01669 L
.44674 .01669 L
.45163 .01669 L
.46047 .01669 L
.46293 .01669 L
.46524 .01669 L
.46652 .01669 L
.46791 .01669 L
.46917 .01669 L
.47032 .01669 L
.47142 .01669 L
.47245 .01669 L
.47357 .01669 L
.47477 .01669 L
.47603 .01669 L
.47723 .01669 L
.4783 .01669 L
.47947 .01669 L
.48195 .01669 L
.48469 .01669 L
.49024 .01669 L
.49538 .01669 L
.5002 .01669 L
.5204 .01669 L
.53891 .01668 L
.55945 .01667 L
.57855 .01667 L
.59699 .01667 L
.61668 .01666 L
.63804 .01666 L
.6582 .01666 L
.67822 .01666 L
.69668 .01666 L
.71546 .01666 L
.7361 .01666 L
.75557 .01666 L
.77646 .01666 L
.78661 .01665 L
.79765 .01665 L
.80821 .01665 L
.81776 .01665 L
.83749 .01665 L
.84831 .01665 L
.85848 .01665 L
.86828 .01665 L
.87861 .01665 L
.88829 .01665 L
.8971 .01665 L
.90661 .01665 L
Mistroke
.91185 .01665 L
.91679 .01665 L
.92137 .01665 L
.92559 .01665 L
.9278 .01665 L
.93023 .01665 L
.93145 .01665 L
.93277 .01665 L
.93401 .01665 L
.93515 .01665 L
.93643 .01665 L
.93764 .01665 L
.93873 .01665 L
.93991 .01665 L
.94119 .01665 L
.94184 .01665 L
.94255 .01665 L
.94498 .01665 L
.94726 .01665 L
.94971 .01665 L
.95412 .01665 L
.95969 .01665 L
.96496 .01665 L
.97484 .01665 L
.97619 .01665 L
Mfstroke
0 .964 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16466 L
.05288 .21951 L
.06244 .25562 L
.06792 .2706 L
.0731 .28136 L
.07775 .2885 L
.08038 .29158 L
.0828 .29387 L
.0854 .29576 L
.08783 .29706 L
.08923 .2976 L
.0905 .29799 L
.09121 .29815 L
.09197 .29829 L
.0927 .2984 L
.09337 .29846 L
.09408 .2985 L
.09484 .29851 L
.09556 .29849 L
.09622 .29845 L
.09747 .29831 L
.0981 .29821 L
.0988 .29807 L
.10024 .29772 L
.10179 .29725 L
.10458 .29614 L
.10986 .29334 L
.11475 .2901 L
.12582 .28143 L
.14594 .26491 L
.16461 .25251 L
.16972 .24988 L
.17523 .24746 L
.1804 .24559 L
.18521 .24421 L
.18983 .24322 L
.19242 .24281 L
.19478 .24253 L
.19612 .24242 L
.19736 .24234 L
.19801 .24231 L
.19872 .24228 L
.19947 .24226 L
.20016 .24226 L
.20144 .24226 L
.20261 .2423 L
.20326 .24233 L
.20397 .24237 L
Mistroke
.20525 .24247 L
.20668 .24261 L
.20803 .24279 L
.21055 .24322 L
.21326 .24383 L
.2162 .24469 L
.22149 .24678 L
.22635 .24943 L
.23106 .25281 L
.23611 .2575 L
.24087 .26322 L
.24521 .2698 L
.2503 .27959 L
.25583 .29331 L
.26589 .32655 L
.27524 .3616 L
.28531 .39379 L
.29108 .40752 L
.2936 .41238 L
.29636 .41691 L
.30141 .42322 L
.30416 .42567 L
.30672 .42736 L
.30919 .42852 L
.31058 .42898 L
.31185 .42928 L
.31298 .42947 L
.31421 .42958 L
.31549 .4296 L
.31669 .42954 L
.31787 .42941 L
.31898 .42923 L
.31997 .42901 L
.32106 .42873 L
.32574 .42699 L
.33085 .42434 L
.33628 .42096 L
.34604 .41436 L
.35539 .40864 L
.35796 .40737 L
.36066 .40623 L
.36296 .40544 L
.36426 .40509 L
.36549 .40482 L
.36664 .40462 L
.36788 .40448 L
.36901 .40441 L
.37006 .40442 L
.37119 .40448 L
.37243 .40465 L
Mistroke
.37373 .40492 L
.37495 .40527 L
.37717 .40619 L
.37919 .40736 L
.38153 .40915 L
.38376 .41133 L
.38879 .41818 L
.39335 .42698 L
.39862 .44024 L
.40358 .4552 L
.42197 .51214 L
.43174 .53492 L
.43708 .54479 L
.44206 .55249 L
.45088 .56296 L
.45554 .56704 L
.46054 .57042 L
.46311 .57179 L
.46583 .57298 L
.46819 .5738 L
.47073 .57449 L
.47214 .57479 L
.47344 .57501 L
.47468 .57517 L
.47599 .57529 L
.47668 .57534 L
.47743 .57537 L
.47813 .57539 L
.47876 .57539 L
.47951 .57538 L
.48032 .57535 L
.48109 .57531 L
.4818 .57526 L
.48296 .57515 L
.4842 .57499 L
.48645 .5746 L
.48913 .57399 L
.49158 .57328 L
.49688 .57129 L
.50192 .56887 L
.51154 .5629 L
.52178 .55476 L
.54019 .53603 L
.58184 .4795 L
.62198 .42393 L
.6606 .38362 L
.6806 .36774 L
.70168 .35379 L
.73972 .33431 L
.75929 .32668 L
Mistroke
.78022 .32004 L
.80008 .31497 L
.82165 .31059 L
.86157 .3047 L
.8814 .30253 L
.90242 .3006 L
.94025 .29788 L
.97619 .29599 L
Mfstroke
0 .941 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16451 L
.04758 .19291 L
.05288 .21833 L
.05785 .23764 L
.06244 .25178 L
.06788 .26424 L
.07075 .26906 L
.07379 .27296 L
.07505 .27423 L
.07642 .27539 L
.0776 .27621 L
.07889 .27694 L
.07967 .27728 L
.08039 .27755 L
.08108 .27776 L
.08182 .27792 L
.08255 .27803 L
.08323 .27809 L
.08451 .27808 L
.08567 .27795 L
.08695 .27768 L
.08759 .2775 L
.08828 .27726 L
.08953 .27675 L
.09195 .27544 L
.09415 .27394 L
.09951 .26924 L
.10458 .26376 L
.14291 .216 L
.16268 .19803 L
.17267 .19155 L
.17804 .18876 L
.18369 .18635 L
.18851 .1847 L
.19106 .18398 L
.19378 .18332 L
.1963 .18282 L
.19858 .18246 L
.19968 .18231 L
.20087 .18218 L
.20192 .18208 L
.20304 .18199 L
.20434 .18192 L
.20555 .18188 L
.20629 .18187 L
.20699 .18186 L
.20831 .18188 L
.20898 .1819 L
Mistroke
.20969 .18193 L
.21098 .18201 L
.21177 .18208 L
.21251 .18215 L
.21389 .18231 L
.2164 .1827 L
.2187 .18318 L
.22123 .18384 L
.22389 .18471 L
.22887 .18685 L
.2334 .18951 L
.23863 .19362 L
.24357 .19883 L
.24814 .20515 L
.25237 .21261 L
.257 .22301 L
.26192 .23683 L
.27154 .27049 L
.28165 .30603 L
.28583 .31806 L
.29029 .32848 L
.29285 .33328 L
.29518 .33687 L
.29739 .33963 L
.29972 .34187 L
.30091 .34275 L
.30222 .34353 L
.3034 .34406 L
.30451 .34442 L
.30582 .34467 L
.30701 .34474 L
.30767 .34471 L
.30839 .34464 L
.3097 .34437 L
.31082 .34402 L
.31207 .34349 L
.31458 .34203 L
.31692 .34024 L
.31911 .33821 L
.32915 .32546 L
.33998 .30767 L
.3596 .27308 L
.36998 .25646 L
.38108 .24116 L
.39182 .2291 L
.40159 .22045 L
.4114 .21377 L
.42068 .20898 L
.44067 .20168 L
.45911 .19612 L
Mistroke
.47944 .19003 L
.49848 .18474 L
.51789 .18033 L
.53634 .17723 L
.54603 .176 L
.5566 .17495 L
.56621 .17423 L
.57513 .17375 L
.58021 .17354 L
.58288 .17345 L
.58571 .17337 L
.58818 .17332 L
.59089 .17326 L
.59336 .17323 L
.59567 .1732 L
.59682 .17319 L
.59808 .17319 L
.59927 .17318 L
.60037 .17318 L
.60135 .17318 L
.60244 .17318 L
.60358 .17318 L
.60465 .17318 L
.60583 .17319 L
.60707 .1732 L
.60928 .17322 L
.61167 .17325 L
.61428 .17329 L
.61957 .1734 L
.62456 .17353 L
.6339 .17384 L
.65486 .17482 L
.69334 .17719 L
.73428 .17993 L
.77371 .18256 L
.81161 .18511 L
.85197 .18783 L
.89082 .19039 L
.93211 .19295 L
.97189 .19526 L
.97619 .19549 L
Mfstroke
0 .917 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16472 L
.05288 .21995 L
.06244 .25704 L
.06792 .27289 L
.0731 .28467 L
.07775 .29288 L
.0828 .29952 L
.08542 .30212 L
.0883 .30439 L
.08975 .30531 L
.09131 .30614 L
.09265 .30674 L
.09413 .30727 L
.09558 .30766 L
.09628 .30781 L
.09692 .30793 L
.09821 .30809 L
.09892 .30815 L
.09959 .30818 L
.10083 .30819 L
.10198 .30813 L
.10325 .308 L
.10388 .30791 L
.10458 .3078 L
.10709 .30723 L
.10982 .30639 L
.11478 .30432 L
.12409 .29914 L
.145 .28535 L
.16478 .27416 L
.17476 .27011 L
.18045 .26839 L
.18321 .26771 L
.18579 .26718 L
.18825 .26677 L
.19048 .26647 L
.19167 .26634 L
.19296 .26623 L
.19367 .26618 L
.19433 .26614 L
.19562 .26608 L
.19685 .26605 L
.19801 .26605 L
.19928 .26607 L
.19999 .2661 L
.20065 .26613 L
.20195 .26621 L
.20338 .26634 L
Mistroke
.20472 .26649 L
.20597 .26666 L
.20839 .26709 L
.21067 .2676 L
.21493 .26887 L
.21952 .27073 L
.22447 .27341 L
.22941 .2769 L
.234 .28105 L
.23905 .28685 L
.24445 .29487 L
.25012 .30585 L
.25548 .31915 L
.26553 .35152 L
.27432 .38309 L
.28379 .41254 L
.28921 .42558 L
.29417 .43488 L
.29892 .44153 L
.3013 .4441 L
.30391 .44637 L
.30652 .44811 L
.30888 .44927 L
.31019 .44975 L
.31161 .45015 L
.31226 .4503 L
.31295 .45043 L
.31418 .45059 L
.31532 .45067 L
.31653 .45068 L
.31768 .45063 L
.31873 .45054 L
.31996 .45036 L
.32129 .45011 L
.32372 .44948 L
.32624 .44864 L
.32901 .44752 L
.33464 .4448 L
.34475 .43923 L
.35415 .43452 L
.35889 .43274 L
.36018 .43236 L
.36157 .43201 L
.36287 .43174 L
.36407 .43154 L
.36475 .43146 L
.36547 .43139 L
.3662 .43134 L
.367 .43131 L
.36768 .43131 L
Mistroke
.36842 .43133 L
.36912 .43138 L
.36976 .43144 L
.37103 .43163 L
.37175 .43178 L
.37242 .43194 L
.37494 .4328 L
.37624 .4334 L
.37747 .43408 L
.37977 .43565 L
.38224 .43782 L
.38492 .44078 L
.38984 .44806 L
.39443 .45716 L
.40487 .4847 L
.41569 .51546 L
.42594 .53955 L
.4357 .55679 L
.44121 .56429 L
.44631 .56997 L
.45531 .57742 L
.45985 .58008 L
.46225 .58123 L
.46487 .58228 L
.46725 .58308 L
.46979 .58377 L
.47247 .58432 L
.47497 .58469 L
.47617 .58481 L
.47747 .58492 L
.47869 .58498 L
.47982 .58502 L
.48084 .58503 L
.48196 .58502 L
.48313 .58498 L
.48423 .58493 L
.48552 .58484 L
.48693 .58471 L
.48949 .58439 L
.49198 .58399 L
.49429 .58354 L
.50509 .58062 L
.5157 .57673 L
.52567 .57245 L
.54429 .56358 L
.58292 .54464 L
.62399 .526 L
.66355 .50866 L
.70159 .49181 L
.74209 .47523 L
Mistroke
.78107 .46249 L
.8225 .45272 L
.86242 .44604 L
.90082 .44127 L
.94168 .43748 L
.97619 .43514 L
Mfstroke
0 .893 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16453 L
.04758 .19302 L
.05288 .21871 L
.05785 .23855 L
.06244 .25348 L
.06788 .26727 L
.07069 .27288 L
.07379 .27795 L
.07629 .28128 L
.07899 .28412 L
.08048 .28539 L
.08184 .28636 L
.08313 .28714 L
.08451 .28781 L
.08585 .28832 L
.08706 .28867 L
.08828 .2889 L
.08943 .28903 L
.09008 .28906 L
.09077 .28907 L
.09201 .289 L
.09269 .28892 L
.09334 .28883 L
.0948 .28852 L
.09607 .28817 L
.09727 .28776 L
.09952 .28682 L
.10458 .28398 L
.11423 .27659 L
.12449 .26733 L
.14291 .25079 L
.15228 .24349 L
.16238 .23688 L
.17192 .23195 L
.18066 .22861 L
.1854 .22728 L
.188 .22669 L
.19046 .22623 L
.19276 .22589 L
.19396 .22575 L
.19524 .22562 L
.19632 .22553 L
.1975 .22546 L
.19858 .22541 L
.19958 .22538 L
.20086 .22538 L
.20159 .22538 L
.20226 .2254 L
Mistroke
.20349 .22545 L
.2048 .22553 L
.20609 .22564 L
.2073 .22578 L
.20956 .2261 L
.21225 .22662 L
.21472 .22724 L
.22028 .22915 L
.225 .23142 L
.23005 .23466 L
.23481 .23864 L
.23915 .24325 L
.24424 .25016 L
.24977 .26003 L
.255 .27214 L
.25982 .28603 L
.2696 .32031 L
.28012 .35702 L
.28496 .3707 L
.29005 .38207 L
.29439 .38923 L
.29686 .39227 L
.29914 .39447 L
.30151 .39612 L
.30285 .39679 L
.30408 .39725 L
.30516 .39752 L
.30634 .3977 L
.30758 .39774 L
.30873 .39765 L
.30986 .39746 L
.31093 .39718 L
.31188 .39685 L
.31293 .39641 L
.31527 .39514 L
.31743 .39363 L
.32193 .3896 L
.32689 .38398 L
.33695 .36994 L
.35789 .33632 L
.37712 .30816 L
.39594 .28755 L
.40541 .28015 L
.41577 .27406 L
.42603 .26961 L
.43536 .26644 L
.44625 .26348 L
.4563 .26133 L
.4656 .25982 L
.4703 .25922 L
Mistroke
.47546 .25869 L
.48063 .25827 L
.48349 .25809 L
.4862 .25794 L
.48871 .25783 L
.49145 .25772 L
.49395 .25764 L
.49625 .25759 L
.49881 .25754 L
.50012 .25752 L
.50157 .2575 L
.50275 .25748 L
.50401 .25747 L
.50534 .25746 L
.50658 .25746 L
.50778 .25745 L
.50909 .25745 L
.51033 .25745 L
.51147 .25745 L
.5125 .25745 L
.51364 .25746 L
.51482 .25746 L
.51594 .25747 L
.5185 .25749 L
.52121 .25752 L
.52604 .25759 L
.53123 .25768 L
.53692 .25782 L
.54221 .25799 L
.5472 .25819 L
.55654 .25871 L
.56177 .25909 L
.5666 .25951 L
.5775 .26075 L
.5872 .26224 L
.59627 .26399 L
.61692 .26933 L
.65576 .28351 L
.69706 .30071 L
.73684 .31623 L
.77511 .32999 L
.81582 .34394 L
.85502 .3566 L
.89668 .36883 L
.93682 .37924 L
.97544 .38807 L
.97619 .38823 L
Mfstroke
0 .87 1 r
.02381 .01472 m
.02846 .05765 L
.03279 .09252 L
.03754 .12235 L
.0402 .13456 L
.04262 .1428 L
.04385 .14599 L
.04516 .14868 L
.04627 .15044 L
.0475 .15184 L
.04882 .15279 L
.04957 .15308 L
.05024 .15321 L
.05156 .15312 L
.05281 .15265 L
.05397 .15193 L
.0552 .15089 L
.05742 .14843 L
.06244 .1409 L
.08414 .10184 L
.09479 .08591 L
.10458 .07403 L
.1141 .06479 L
.12455 .05686 L
.13506 .05076 L
.14616 .04592 L
.15637 .04259 L
.16567 .04029 L
.17641 .0383 L
.18659 .03692 L
.19624 .03599 L
.20111 .03563 L
.2065 .0353 L
.21107 .03509 L
.21347 .03499 L
.216 .03491 L
.21822 .03485 L
.22065 .03479 L
.22286 .03475 L
.22384 .03474 L
.22492 .03473 L
.22619 .03472 L
.22689 .03471 L
.22754 .03471 L
.22871 .03471 L
.22997 .03471 L
.23067 .03471 L
.23143 .03471 L
.23216 .03472 L
.23283 .03472 L
Mistroke
.23409 .03474 L
.23544 .03476 L
.23812 .03481 L
.24065 .03488 L
.24292 .03496 L
.24537 .03507 L
.25009 .03534 L
.25506 .03573 L
.25931 .03617 L
.26396 .03678 L
.27485 .03853 L
.2802 .03939 L
.28515 .04005 L
.28963 .04049 L
.2919 .04065 L
.29439 .04078 L
.2957 .04083 L
.29689 .04086 L
.2982 .04089 L
.29886 .04089 L
.29958 .0409 L
.3008 .0409 L
.3021 .04089 L
.30332 .04087 L
.30444 .04085 L
.3056 .04081 L
.30687 .04077 L
.30945 .04066 L
.31407 .0404 L
.32449 .0396 L
.3434 .03795 L
.36288 .03652 L
.37382 .03594 L
.37865 .03573 L
.38379 .03555 L
.38849 .03542 L
.39099 .03537 L
.39369 .03532 L
.39489 .0353 L
.39615 .03529 L
.39732 .03528 L
.39841 .03527 L
.39944 .03526 L
.40053 .03526 L
.40175 .03526 L
.40285 .03526 L
.40414 .03527 L
.4048 .03527 L
.40551 .03527 L
.40678 .03529 L
Mistroke
.40797 .0353 L
.41065 .03535 L
.41352 .03542 L
.41622 .03551 L
.41879 .03561 L
.4236 .03585 L
.42864 .03619 L
.4332 .03655 L
.44342 .03753 L
.45237 .03844 L
.46182 .03927 L
.4666 .03959 L
.46914 .03973 L
.47185 .03986 L
.47435 .03995 L
.47662 .04001 L
.47772 .04003 L
.47891 .04005 L
.48004 .04007 L
.48108 .04008 L
.48227 .04008 L
.48356 .04008 L
.48477 .04008 L
.48588 .04007 L
.48711 .04006 L
.48846 .04004 L
.49118 .03999 L
.49387 .03991 L
.49673 .03982 L
.5019 .0396 L
.52326 .03837 L
.54342 .0371 L
.56175 .03611 L
.58191 .03525 L
.6018 .03463 L
.62285 .03415 L
.64231 .03384 L
.6632 .0336 L
.68439 .03342 L
.7045 .03329 L
.74277 .03312 L
.76249 .03305 L
.78348 .033 L
.80495 .03295 L
.82514 .03292 L
.86376 .03288 L
.88375 .03286 L
.90484 .03285 L
.92321 .03284 L
.94288 .03283 L
Mistroke
.97619 .03282 L
Mfstroke
0 .846 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16456 L
.04758 .19307 L
.05288 .21871 L
.05785 .23838 L
.06244 .25299 L
.06788 .26617 L
.07075 .27144 L
.07379 .27585 L
.07642 .27877 L
.07889 .28079 L
.0803 .28166 L
.08159 .28227 L
.08231 .28254 L
.08309 .28278 L
.08382 .28296 L
.08451 .28308 L
.08577 .28319 L
.08648 .2832 L
.08713 .28317 L
.08833 .28303 L
.0896 .28277 L
.09074 .28243 L
.0918 .28204 L
.09422 .28089 L
.09922 .27751 L
.10458 .27273 L
.12439 .25012 L
.14594 .22627 L
.15598 .21728 L
.16664 .20954 L
.17574 .20442 L
.18054 .20227 L
.18579 .20034 L
.1907 .19894 L
.19321 .19838 L
.19588 .1979 L
.19839 .19755 L
.20067 .19732 L
.20177 .19725 L
.20297 .19719 L
.20409 .19716 L
.20513 .19714 L
.20633 .19716 L
.20763 .1972 L
.20884 .19727 L
.20996 .19736 L
.21126 .19749 L
.21268 .19767 L
Mistroke
.21526 .19811 L
.21796 .19873 L
.22083 .19957 L
.22599 .20164 L
.23136 .20467 L
.2363 .20845 L
.24172 .21402 L
.24744 .22203 L
.25242 .23135 L
.25707 .24248 L
.26762 .27675 L
.27668 .31048 L
.2863 .34045 L
.29131 .35172 L
.29417 .35668 L
.29684 .36037 L
.29929 .36296 L
.30153 .36471 L
.30271 .3654 L
.304 .36597 L
.30464 .3662 L
.30534 .36638 L
.30658 .3666 L
.30728 .36665 L
.30802 .36665 L
.30934 .36653 L
.31008 .36639 L
.31076 .36622 L
.31233 .36567 L
.31369 .36503 L
.31494 .36431 L
.31774 .36228 L
.32294 .35719 L
.32786 .35103 L
.348 .31844 L
.36619 .2874 L
.37656 .27178 L
.3863 .25917 L
.39659 .24822 L
.40605 .24027 L
.41615 .23372 L
.42704 .22832 L
.46664 .21352 L
.48658 .20679 L
.50471 .20172 L
.5243 .19764 L
.53507 .19598 L
.54524 .19477 L
.55495 .19388 L
.56026 .19351 L
Mistroke
.56523 .19322 L
.56982 .193 L
.57401 .19285 L
.57867 .19272 L
.58124 .19267 L
.58368 .19264 L
.58492 .19262 L
.58558 .19262 L
.58627 .19261 L
.58754 .19261 L
.58871 .1926 L
.58983 .1926 L
.59089 .1926 L
.59204 .19261 L
.59327 .19262 L
.59459 .19263 L
.59602 .19264 L
.59862 .19268 L
.60115 .19273 L
.6035 .19279 L
.61242 .1931 L
.61692 .1933 L
.62189 .19356 L
.64125 .19492 L
.66211 .19685 L
.70327 .20136 L
.74292 .20583 L
.78104 .21004 L
.82162 .2145 L
.86069 .21874 L
.90221 .22304 L
.94221 .22688 L
.97619 .22989 L
Mfstroke
0 .822 1 r
.02381 .01472 m
.02499 .02009 L
.02605 .02113 L
.02729 .0215 L
.02846 .02158 L
.02954 .02157 L
.03053 .02151 L
.03163 .02141 L
.03279 .02129 L
.04262 .02005 L
.05217 .01895 L
.06244 .01802 L
.0728 .01731 L
.0825 .0168 L
.09403 .01635 L
.10458 .01606 L
.11442 .01585 L
.12357 .01571 L
.1336 .01559 L
.14429 .0155 L
.15457 .01543 L
.1657 .01538 L
.17621 .01535 L
.18587 .01532 L
.19561 .01531 L
.2047 .01529 L
.21467 .01529 L
.22026 .01528 L
.22536 .01528 L
.23016 .01528 L
.23527 .01527 L
.23963 .01527 L
.24211 .01527 L
.24444 .01527 L
.24566 .01527 L
.24698 .01527 L
.24765 .01527 L
.24837 .01527 L
.24965 .01527 L
.25094 .01527 L
.25216 .01527 L
.25325 .01527 L
.25443 .01527 L
.25573 .01527 L
.25716 .01527 L
.26004 .01527 L
.2652 .01527 L
.27518 .01528 L
.27756 .01528 L
.28009 .01528 L
Mistroke
.28244 .01528 L
.28465 .01528 L
.28597 .01528 L
.28666 .01528 L
.28739 .01528 L
.28869 .01528 L
.28987 .01528 L
.29055 .01528 L
.29128 .01528 L
.29259 .01528 L
.29339 .01528 L
.29415 .01528 L
.29557 .01528 L
.29805 .01528 L
.30035 .01528 L
.30554 .01528 L
.3152 .01527 L
.32425 .01527 L
.34486 .01527 L
.35472 .01526 L
.36508 .01526 L
.37393 .01526 L
.3836 .01526 L
.3889 .01526 L
.3939 .01526 L
.40325 .01526 L
.40849 .01526 L
.41332 .01526 L
.41857 .01526 L
.42421 .01526 L
.4293 .01526 L
.43393 .01526 L
.43865 .01526 L
.44302 .01526 L
.44809 .01526 L
.45362 .01526 L
.45845 .01526 L
.46367 .01526 L
.46611 .01526 L
.46868 .01526 L
.47328 .01526 L
.47759 .01526 L
.48231 .01526 L
.48746 .01526 L
.49297 .01526 L
.5029 .01526 L
.54437 .01525 L
.56515 .01525 L
.58432 .01525 L
.60298 .01525 L
Mistroke
.62275 .01525 L
.6423 .01525 L
.66061 .01525 L
.68087 .01525 L
.6994 .01525 L
.7184 .01525 L
.72927 .01525 L
.73913 .01525 L
.75882 .01525 L
.76962 .01525 L
.77979 .01525 L
.78957 .01525 L
.79989 .01525 L
.81836 .01525 L
.82785 .01525 L
.83802 .01525 L
.84761 .01525 L
.85636 .01525 L
.86117 .01525 L
.86628 .01525 L
.8707 .01525 L
.87546 .01525 L
.87811 .01525 L
.88055 .01525 L
.88303 .01525 L
.88533 .01525 L
.88656 .01525 L
.88786 .01525 L
.88861 .01525 L
.88932 .01525 L
.89064 .01525 L
.89131 .01525 L
.89203 .01525 L
.89332 .01525 L
.89403 .01525 L
.8947 .01525 L
.89543 .01525 L
.89622 .01525 L
.89756 .01525 L
.89877 .01525 L
.90148 .01525 L
.904 .01525 L
.90636 .01525 L
.91168 .01525 L
.91741 .01525 L
.92789 .01525 L
.93752 .01525 L
.97619 .01525 L
Mfstroke
0 .798 1 r
.02381 .01472 m
.03279 .09451 L
.04262 .16473 L
.05288 .22004 L
.06244 .25732 L
.06792 .27334 L
.0731 .28536 L
.07775 .29384 L
.0828 .30084 L
.08542 .30366 L
.0883 .30619 L
.09131 .30824 L
.09275 .30903 L
.09413 .30966 L
.09538 .31015 L
.09676 .3106 L
.09802 .31092 L
.09916 .31115 L
.09982 .31125 L
.10052 .31134 L
.10127 .31142 L
.10197 .31146 L
.10263 .31149 L
.10333 .3115 L
.10458 .31147 L
.1058 .31139 L
.10649 .31132 L
.10713 .31124 L
.10954 .31084 L
.11173 .31033 L
.11406 .30966 L
.12422 .30555 L
.14255 .29605 L
.15215 .29124 L
.16225 .28688 L
.17087 .28393 L
.17576 .28263 L
.1803 .28168 L
.18282 .28127 L
.1852 .28095 L
.18734 .28074 L
.18854 .28064 L
.18966 .28058 L
.19085 .28052 L
.19197 .28049 L
.19319 .28048 L
.19451 .28049 L
.19517 .28051 L
.19589 .28053 L
.1972 .2806 L
Mistroke
.19847 .28069 L
.19965 .2808 L
.20238 .28114 L
.20495 .28158 L
.20975 .28273 L
.21244 .28358 L
.21492 .28451 L
.22051 .28716 L
.22522 .29008 L
.23027 .29406 L
.23937 .30411 L
.24493 .31269 L
.25019 .32303 L
.26005 .34915 L
.2783 .40808 L
.2833 .42121 L
.28869 .4325 L
.29117 .43667 L
.29377 .44037 L
.29621 .4432 L
.29843 .44527 L
.3008 .44698 L
.30211 .4477 L
.30334 .44825 L
.30448 .44865 L
.30552 .44891 L
.30668 .44911 L
.3079 .44921 L
.30913 .4492 L
.31044 .44906 L
.31169 .44883 L
.31282 .44853 L
.31416 .44808 L
.3156 .44747 L
.31824 .44606 L
.32353 .44221 L
.32915 .43691 L
.33926 .42526 L
.35893 .39959 L
.37698 .37805 L
.3862 .36913 L
.3963 .36152 L
.40156 .35854 L
.40645 .35639 L
.40911 .35547 L
.41162 .35477 L
.41301 .35445 L
.41452 .35415 L
.41589 .35393 L
.41715 .35377 L
Mistroke
.41836 .35365 L
.4195 .35357 L
.42071 .35352 L
.42203 .35351 L
.42318 .35354 L
.4244 .3536 L
.42555 .3537 L
.4266 .35382 L
.42794 .35401 L
.42917 .35423 L
.43196 .35488 L
.43441 .35562 L
.437 .35659 L
.44219 .3591 L
.44703 .36209 L
.45804 .37093 L
.49697 .40869 L
.50715 .41654 L
.51822 .42356 L
.53835 .43319 L
.57915 .45005 L
.61843 .47269 L
.65621 .49648 L
.69643 .51658 L
.73514 .53026 L
.7763 .54117 L
.81594 .54959 L
.85407 .55612 L
.89465 .56158 L
.93371 .56572 L
.97523 .56921 L
.97619 .56929 L
Mfstroke
0 .775 1 r
.02381 .01472 m
.02846 .05681 L
.03068 .07318 L
.03279 .0851 L
.03398 .09017 L
.03527 .09434 L
.03645 .09702 L
.03754 .09866 L
.03871 .09968 L
.04 .10004 L
.04065 .09997 L
.04135 .09975 L
.04262 .09899 L
.04393 .09783 L
.04516 .0965 L
.04793 .09288 L
.05297 .0853 L
.06244 .07117 L
.07295 .05803 L
.08284 .04835 L
.09424 .03996 L
.10458 .03434 L
.11434 .03037 L
.12466 .02723 L
.13346 .02521 L
.14313 .02352 L
.15334 .02219 L
.16264 .02128 L
.17338 .02051 L
.18355 .01998 L
.19321 .01961 L
.20346 .01933 L
.21222 .01915 L
.22188 .01901 L
.2268 .01896 L
.23198 .01892 L
.2364 .01889 L
.2389 .01888 L
.24123 .01887 L
.24254 .01887 L
.24395 .01886 L
.24528 .01886 L
.24651 .01886 L
.24762 .01886 L
.24885 .01886 L
.25012 .01886 L
.25131 .01886 L
.25198 .01886 L
.25271 .01886 L
.25403 .01886 L
Mistroke
.25532 .01886 L
.25651 .01886 L
.25921 .01887 L
.26209 .01888 L
.2724 .01894 L
.27782 .01897 L
.28078 .01898 L
.28354 .01899 L
.28596 .019 L
.28732 .019 L
.28856 .019 L
.28926 .019 L
.28991 .019 L
.29063 .01901 L
.29138 .01901 L
.29266 .01901 L
.29338 .01901 L
.29406 .01901 L
.29524 .019 L
.29649 .019 L
.29755 .019 L
.29871 .019 L
.30131 .01899 L
.30372 .01898 L
.31427 .01893 L
.32422 .01887 L
.34282 .01876 L
.35257 .0187 L
.36287 .01866 L
.37253 .01863 L
.38134 .0186 L
.3908 .01858 L
.39601 .01857 L
.40095 .01857 L
.40551 .01856 L
.40973 .01856 L
.41192 .01856 L
.41435 .01856 L
.41558 .01856 L
.41689 .01856 L
.41812 .01856 L
.41928 .01856 L
.42053 .01856 L
.42167 .01856 L
.42289 .01856 L
.42359 .01856 L
.42423 .01856 L
.42529 .01856 L
.42646 .01856 L
.42769 .01856 L
Mistroke
.42883 .01856 L
.43018 .01856 L
.43147 .01856 L
.43387 .01856 L
.43929 .01856 L
.4495 .01856 L
.45511 .01856 L
.45786 .01857 L
.46038 .01857 L
.46282 .01857 L
.46405 .01857 L
.46538 .01857 L
.46608 .01857 L
.46671 .01857 L
.46796 .01857 L
.46865 .01857 L
.46941 .01857 L
.47012 .01857 L
.47078 .01857 L
.4719 .01857 L
.47296 .01857 L
.47411 .01857 L
.47535 .01857 L
.47789 .01857 L
.48021 .01857 L
.48449 .01856 L
.48917 .01856 L
.4986 .01856 L
.53918 .01852 L
.55793 .01851 L
.57824 .0185 L
.58936 .0185 L
.59961 .01849 L
.61976 .01849 L
.63854 .01848 L
.65918 .01848 L
.69954 .01847 L
.73839 .01847 L
.75958 .01847 L
.77968 .01847 L
.81795 .01846 L
.85867 .01846 L
.89787 .01846 L
.93952 .01846 L
.97619 .01846 L
Mfstroke
0 .751 1 r
.02381 .01472 m
.02499 .02559 L
.02605 .03364 L
.02729 .03983 L
.02846 .04296 L
.02954 .04431 L
.03053 .04479 L
.03163 .04481 L
.03279 .0445 L
.03395 .044 L
.0352 .04332 L
.03746 .04193 L
.04262 .03858 L
.0521 .03306 L
.06244 .02837 L
.07373 .02462 L
.08445 .02204 L
.09489 .02022 L
.10458 .01897 L
.11515 .01797 L
.1251 .01729 L
.13404 .01683 L
.14371 .01645 L
.15321 .01618 L
.16365 .01596 L
.17454 .01579 L
.18471 .01568 L
.19516 .0156 L
.20506 .01554 L
.21395 .0155 L
.22362 .01547 L
.23302 .01545 L
.23837 .01544 L
.2434 .01544 L
.24832 .01543 L
.25351 .01543 L
.25919 .01542 L
.2644 .01542 L
.2694 .01542 L
.27395 .01542 L
.28414 .01542 L
.29359 .01541 L
.30251 .01541 L
.32083 .0154 L
.33124 .0154 L
.34098 .01539 L
.35136 .01539 L
.36085 .01539 L
.371 .01539 L
.37628 .01539 L
Mistroke
.3819 .01539 L
.38708 .01538 L
.39177 .01538 L
.39648 .01538 L
.40092 .01538 L
.40345 .01538 L
.40612 .01538 L
.40839 .01538 L
.40968 .01538 L
.41089 .01538 L
.41156 .01538 L
.41229 .01538 L
.41298 .01538 L
.41361 .01538 L
.41481 .01538 L
.41609 .01538 L
.41675 .01538 L
.41746 .01538 L
.41874 .01538 L
.41948 .01538 L
.42026 .01538 L
.42166 .01538 L
.42424 .01538 L
.42668 .01538 L
.43123 .01538 L
.44144 .01538 L
.4502 .01538 L
.45982 .01538 L
.46486 .01539 L
.46727 .01539 L
.46957 .01539 L
.47081 .01539 L
.47217 .01539 L
.4734 .01539 L
.47454 .01539 L
.47577 .01539 L
.47647 .01539 L
.47712 .01539 L
.47845 .01539 L
.47919 .01539 L
.47987 .01539 L
.48095 .01539 L
.48209 .01539 L
.48416 .01539 L
.48662 .01539 L
.48886 .01539 L
.49373 .01538 L
.49834 .01538 L
.50804 .01538 L
.51833 .01538 L
Mistroke
.53677 .01538 L
.55654 .01538 L
.57463 .01538 L
.59405 .01538 L
.61493 .01538 L
.63393 .01538 L
.65466 .01538 L
.69533 .01538 L
.73448 .01538 L
.75447 .01538 L
.77608 .01538 L
.81617 .01538 L
.85719 .01538 L
.8967 .01538 L
.93469 .01538 L
.97513 .01538 L
.97619 .01538 L
Mfstroke
0 .727 1 r
.02381 .01472 m
.02846 .0578 L
.03279 .09397 L
.03793 .13006 L
.04262 .1545 L
.04498 .16342 L
.04622 .16719 L
.04754 .17048 L
.04869 .17279 L
.04996 .17473 L
.05112 .17599 L
.0522 .17675 L
.05352 .17717 L
.05478 .17709 L
.0559 .17665 L
.05713 .17581 L
.05847 .17454 L
.05989 .1728 L
.06244 .16889 L
.08414 .12212 L
.09479 .10152 L
.10458 .08601 L
.1141 .07392 L
.12455 .06354 L
.13506 .05558 L
.14616 .04927 L
.15637 .04494 L
.16567 .04195 L
.17641 .03936 L
.18659 .03757 L
.19624 .03634 L
.20111 .03586 L
.2065 .03542 L
.21107 .03511 L
.216 .03485 L
.22065 .03467 L
.22284 .0346 L
.22492 .03454 L
.22611 .03452 L
.2274 .03449 L
.22847 .03448 L
.22966 .03446 L
.23094 .03445 L
.23164 .03445 L
.23229 .03444 L
.23346 .03444 L
.23472 .03444 L
.23589 .03444 L
.23716 .03445 L
.23837 .03447 L
Mistroke
.23948 .03448 L
.24159 .03452 L
.24384 .03458 L
.24653 .03467 L
.24944 .0348 L
.2547 .03513 L
.25983 .03556 L
.26454 .03607 L
.27365 .03725 L
.27866 .0379 L
.2834 .03843 L
.28609 .03868 L
.289 .03888 L
.29029 .03896 L
.29165 .03902 L
.29293 .03907 L
.2941 .0391 L
.29528 .03913 L
.29655 .03914 L
.29767 .03915 L
.29885 .03915 L
.30014 .03913 L
.30135 .03911 L
.30267 .03908 L
.30408 .03904 L
.30668 .03894 L
.30943 .0388 L
.31435 .03849 L
.32547 .0376 L
.34563 .03591 L
.35509 .03523 L
.36524 .0346 L
.37476 .03413 L
.38357 .03379 L
.39373 .03348 L
.39909 .03336 L
.40478 .03326 L
.40938 .03319 L
.41434 .03313 L
.41718 .03311 L
.41978 .03309 L
.42246 .03307 L
.4249 .03306 L
.42717 .03305 L
.42963 .03304 L
.43223 .03303 L
.43469 .03302 L
.43699 .03302 L
.43942 .03302 L
.44151 .03302 L
Mistroke
.4438 .03301 L
.44895 .03301 L
.45179 .03301 L
.45448 .03301 L
.45698 .03301 L
.45971 .033 L
.46219 .033 L
.46449 .03299 L
.46957 .03297 L
.47507 .03295 L
.48503 .03289 L
.50364 .03273 L
.5232 .03254 L
.54466 .03235 L
.5651 .03221 L
.58417 .03212 L
.59463 .03208 L
.60454 .03205 L
.6231 .03201 L
.64302 .03198 L
.66145 .03195 L
.68172 .03193 L
.70073 .03191 L
.7385 .03188 L
.7587 .03187 L
.77721 .03187 L
.79615 .03186 L
.81686 .03185 L
.83812 .03185 L
.85744 .03185 L
.8965 .03184 L
.9157 .03184 L
.9365 .03184 L
.97619 .03184 L
Mfstroke
0 .704 1 r
.02381 .01472 m
.02846 .05779 L
.03279 .09379 L
.03793 .129 L
.04037 .14201 L
.04262 .15167 L
.04498 .15932 L
.04622 .16233 L
.04754 .16479 L
.04869 .16633 L
.04976 .16731 L
.05093 .1679 L
.0522 .168 L
.05351 .1676 L
.05425 .16716 L
.05494 .16662 L
.0562 .16536 L
.05755 .16366 L
.06244 .15519 L
.08414 .10781 L
.09479 .08871 L
.10458 .07468 L
.11429 .06373 L
.12455 .05478 L
.13486 .04797 L
.14616 .04241 L
.15637 .03871 L
.16567 .03615 L
.17641 .03395 L
.18659 .03243 L
.19624 .03138 L
.20153 .03093 L
.2065 .03058 L
.21525 .03012 L
.2199 .02994 L
.22233 .02986 L
.22492 .02979 L
.22751 .02973 L
.22987 .02969 L
.23101 .02967 L
.23225 .02966 L
.2334 .02965 L
.23449 .02964 L
.23575 .02964 L
.23641 .02963 L
.23713 .02963 L
.23788 .02963 L
.2386 .02963 L
.23924 .02963 L
.23993 .02964 L
Mistroke
.2412 .02964 L
.2419 .02965 L
.24254 .02966 L
.24496 .02969 L
.24628 .02971 L
.24768 .02974 L
.25018 .0298 L
.25288 .02988 L
.25583 .03 L
.26112 .03026 L
.26606 .03057 L
.27653 .03133 L
.28169 .03166 L
.28395 .03178 L
.28645 .03189 L
.28868 .03197 L
.29077 .03202 L
.29192 .03204 L
.29297 .03206 L
.29413 .03207 L
.29535 .03208 L
.29651 .03208 L
.29774 .03208 L
.29891 .03207 L
.29997 .03206 L
.30122 .03204 L
.30257 .03202 L
.30502 .03196 L
.30992 .0318 L
.31451 .03161 L
.32493 .0311 L
.34599 .03003 L
.35642 .02959 L
.36631 .02925 L
.37513 .029 L
.38486 .02879 L
.3945 .02864 L
.39978 .02857 L
.40475 .02852 L
.40937 .02849 L
.41361 .02846 L
.41826 .02844 L
.4206 .02844 L
.42316 .02843 L
.42569 .02843 L
.42712 .02842 L
.42844 .02842 L
.42959 .02842 L
.43086 .02842 L
.43149 .02842 L
Mistroke
.43218 .02842 L
.43342 .02842 L
.43461 .02842 L
.43592 .02842 L
.43715 .02842 L
.43829 .02842 L
.44275 .02843 L
.44793 .02843 L
.45353 .02844 L
.45611 .02844 L
.45751 .02844 L
.45882 .02844 L
.45994 .02844 L
.46114 .02844 L
.46183 .02844 L
.46248 .02844 L
.46369 .02844 L
.46487 .02844 L
.46617 .02844 L
.46682 .02844 L
.46753 .02844 L
.4688 .02844 L
.47127 .02844 L
.47353 .02844 L
.47602 .02843 L
.47874 .02843 L
.48423 .02841 L
.49387 .02837 L
.50284 .02833 L
.5419 .02809 L
.56327 .02799 L
.57306 .02796 L
.58342 .02792 L
.60345 .02788 L
.62191 .02785 L
.6415 .02782 L
.65982 .0278 L
.69866 .02777 L
.71842 .02776 L
.73996 .02774 L
.77974 .02773 L
.79946 .02772 L
.82045 .02771 L
.86211 .02771 L
.90225 .0277 L
.94087 .02769 L
.97619 .02769 L
Mfstroke
0 .68 1 r
.02381 .01472 m
.03279 .09449 L
.04262 .16428 L
.04758 .19242 L
.05288 .21748 L
.05785 .2365 L
.06244 .25047 L
.06788 .26294 L
.07075 .26788 L
.07379 .272 L
.07642 .27471 L
.07889 .27658 L
.0803 .27738 L
.08159 .27794 L
.08231 .27819 L
.08309 .2784 L
.08382 .27856 L
.08451 .27867 L
.08577 .27877 L
.08648 .27877 L
.08713 .27874 L
.08833 .27861 L
.0896 .27836 L
.09074 .27805 L
.0918 .27769 L
.09422 .27662 L
.09922 .27351 L
.10458 .26911 L
.12439 .24831 L
.14594 .22621 L
.15598 .21784 L
.16664 .2106 L
.17574 .20582 L
.18054 .20382 L
.18579 .20203 L
.1907 .20075 L
.19338 .20022 L
.19588 .19982 L
.19708 .19966 L
.19822 .19953 L
.19926 .19944 L
.20035 .19936 L
.20155 .19929 L
.20265 .19925 L
.20383 .19923 L
.20513 .19923 L
.2058 .19925 L
.20653 .19927 L
.20785 .19934 L
.20913 .19944 L
Mistroke
.21033 .19956 L
.21303 .19994 L
.21591 .20051 L
.21863 .20121 L
.2212 .20204 L
.22599 .20406 L
.23066 .20673 L
.23578 .21062 L
.24112 .21609 L
.24611 .22289 L
.25078 .2312 L
.25503 .24081 L
.26459 .27043 L
.27465 .30921 L
.28016 .32941 L
.28533 .34575 L
.29009 .35802 L
.29444 .3668 L
.29928 .3739 L
.30182 .37657 L
.30319 .37773 L
.30449 .37866 L
.30565 .37935 L
.3069 .37996 L
.30804 .38039 L
.30909 .38069 L
.31023 .38091 L
.31148 .38104 L
.31278 .38105 L
.314 .38095 L
.31514 .38077 L
.31623 .38052 L
.31826 .37987 L
.32045 .37891 L
.32283 .37761 L
.33324 .3696 L
.34287 .36046 L
.35184 .35203 L
.35655 .34807 L
.36151 .3445 L
.36416 .34293 L
.36705 .34152 L
.36832 .34103 L
.36968 .34058 L
.37096 .34025 L
.37213 .34003 L
.37341 .33988 L
.37459 .33984 L
.37589 .3399 L
.37654 .33998 L
Mistroke
.37726 .3401 L
.37847 .34039 L
.37976 .34084 L
.38099 .3414 L
.38211 .34204 L
.38461 .34392 L
.38688 .34624 L
.3895 .34972 L
.39196 .3539 L
.39635 .36372 L
.40111 .37796 L
.42183 .46112 L
.43216 .49596 L
.44179 .52053 L
.45183 .53875 L
.45716 .54573 L
.46286 .55139 L
.46542 .55337 L
.46815 .55512 L
.4705 .55634 L
.47304 .55737 L
.47446 .55782 L
.47576 .55816 L
.477 .55842 L
.47831 .55862 L
.479 .5587 L
.47974 .55877 L
.48044 .55881 L
.48108 .55883 L
.48183 .55883 L
.48264 .55881 L
.48341 .55877 L
.48411 .55871 L
.48527 .55857 L
.48652 .55837 L
.48877 .55787 L
.49145 .55705 L
.49389 .55609 L
.4992 .55335 L
.50424 .54998 L
.51386 .54163 L
.5241 .53029 L
.5425 .50474 L
.58416 .43487 L
.60508 .40148 L
.6243 .37503 L
.66292 .33458 L
.6818 .31967 L
.70248 .30598 L
.72368 .29433 L
Mistroke
.74298 .28554 L
.78196 .27232 L
.80109 .26766 L
.82187 .26365 L
.84131 .26067 L
.86273 .25804 L
.90207 .25446 L
.92147 .25313 L
.94234 .25195 L
.97619 .25049 L
Mfstroke
0 .656 1 r
.02381 .01472 m
.02605 .03538 L
.02729 .04518 L
.02846 .05304 L
.02954 .05903 L
.03072 .06409 L
.0318 .06751 L
.03279 .06981 L
.03396 .07165 L
.03506 .07268 L
.03626 .0732 L
.03756 .07323 L
.03821 .07309 L
.03891 .07283 L
.0402 .07215 L
.04262 .07034 L
.06244 .05096 L
.07302 .04272 L
.08429 .03604 L
.09493 .03134 L
.10458 .02813 L
.1146 .02561 L
.12383 .02385 L
.13395 .02239 L
.14465 .02126 L
.15412 .02051 L
.16428 .01991 L
.17387 .01949 L
.18262 .01921 L
.19253 .01896 L
.2017 .0188 L
.21177 .01867 L
.21685 .01862 L
.22246 .01858 L
.22738 .01855 L
.23006 .01853 L
.23256 .01853 L
.23487 .01852 L
.23698 .01851 L
.2381 .01851 L
.23931 .01851 L
.2406 .01851 L
.24181 .01851 L
.24311 .01851 L
.24432 .01851 L
.24502 .01851 L
.24565 .01851 L
.24638 .01851 L
.24708 .01851 L
.24847 .01851 L
Mistroke
.24975 .01851 L
.25266 .01852 L
.2552 .01853 L
.25751 .01854 L
.26267 .01856 L
.27284 .01863 L
.2784 .01867 L
.28111 .01868 L
.28357 .0187 L
.2857 .01871 L
.288 .01871 L
.28927 .01872 L
.29044 .01872 L
.29155 .01872 L
.29274 .01872 L
.29393 .01872 L
.29521 .01872 L
.29641 .01872 L
.29752 .01872 L
.29874 .01872 L
.29944 .01872 L
.30009 .01872 L
.30279 .01871 L
.30521 .01871 L
.30782 .0187 L
.31258 .01868 L
.32146 .01863 L
.34139 .01852 L
.3613 .01843 L
.37134 .0184 L
.37699 .01838 L
.38236 .01837 L
.38724 .01836 L
.39255 .01835 L
.39738 .01834 L
.40184 .01834 L
.40433 .01834 L
.40666 .01834 L
.4079 .01834 L
.40922 .01833 L
.4099 .01833 L
.41066 .01833 L
.41198 .01833 L
.4127 .01833 L
.41339 .01833 L
.41467 .01833 L
.41539 .01833 L
.41606 .01833 L
.41678 .01833 L
.41756 .01833 L
Mistroke
.41883 .01833 L
.42003 .01834 L
.42275 .01834 L
.42533 .01834 L
.42772 .01834 L
.43314 .01835 L
.44301 .01836 L
.45192 .01837 L
.46154 .01839 L
.46705 .01839 L
.46947 .0184 L
.47212 .0184 L
.47446 .0184 L
.47697 .0184 L
.47835 .0184 L
.47961 .0184 L
.48088 .0184 L
.48208 .0184 L
.48315 .0184 L
.48433 .0184 L
.48556 .0184 L
.48671 .0184 L
.48779 .0184 L
.48878 .0184 L
.491 .0184 L
.49325 .0184 L
.49572 .0184 L
.50069 .01839 L
.51098 .01838 L
.52032 .01837 L
.54127 .01834 L
.56209 .01831 L
.58128 .01828 L
.59997 .01827 L
.61976 .01825 L
.63935 .01824 L
.65767 .01824 L
.67797 .01823 L
.69651 .01823 L
.71716 .01822 L
.73629 .01822 L
.75601 .01822 L
.77456 .01822 L
.79514 .01821 L
.81376 .01821 L
.83389 .01821 L
.85238 .01821 L
.87126 .01821 L
.89194 .01821 L
.91151 .01821 L
Mistroke
.93244 .01821 L
.95374 .01821 L
.97387 .01821 L
.97619 .01821 L
Mfstroke
0 .632 1 r
.02381 .01472 m
.03279 .09451 L
.04262 .16478 L
.05288 .2205 L
.06244 .25883 L
.06792 .27582 L
.0731 .28897 L
.07781 .29873 L
.0828 .30702 L
.08823 .31391 L
.09324 .31854 L
.09603 .32048 L
.09864 .32193 L
.1015 .32314 L
.10311 .32366 L
.10458 .32404 L
.10587 .3243 L
.10708 .32449 L
.10817 .32462 L
.10934 .32472 L
.11063 .32477 L
.11128 .32477 L
.11199 .32476 L
.11325 .32471 L
.11442 .32463 L
.11561 .32451 L
.11673 .32436 L
.11884 .32401 L
.12357 .3229 L
.12872 .3213 L
.13349 .31956 L
.14429 .3152 L
.15403 .31127 L
.16454 .30757 L
.16937 .30615 L
.17446 .3049 L
.1788 .30405 L
.18108 .30369 L
.18355 .30336 L
.18488 .30322 L
.1861 .30311 L
.18725 .30303 L
.18851 .30296 L
.18964 .30291 L
.1907 .30288 L
.19181 .30287 L
.19301 .30287 L
.19431 .3029 L
.19504 .30293 L
.19572 .30296 L
Mistroke
.19696 .30304 L
.19829 .30315 L
.20082 .30344 L
.20311 .3038 L
.20762 .30477 L
.21015 .30549 L
.21249 .30628 L
.22131 .3104 L
.22602 .31351 L
.23107 .31771 L
.24017 .32825 L
.24573 .33717 L
.25099 .34784 L
.26085 .37432 L
.2791 .43182 L
.2841 .44454 L
.28949 .45571 L
.29457 .46386 L
.29698 .46695 L
.29923 .4694 L
.30384 .47326 L
.30628 .47472 L
.30889 .47587 L
.3102 .47631 L
.31163 .47668 L
.31228 .47682 L
.31297 .47694 L
.31421 .47711 L
.3154 .4772 L
.31651 .47724 L
.31773 .47722 L
.31904 .47715 L
.31972 .47708 L
.32044 .477 L
.32174 .47681 L
.32468 .4762 L
.32722 .47552 L
.33003 .47462 L
.34006 .47075 L
.34947 .46716 L
.3542 .46573 L
.35689 .46512 L
.35808 .4649 L
.35938 .4647 L
.36012 .46461 L
.3608 .46454 L
.36144 .46448 L
.36214 .46444 L
.36335 .4644 L
.36464 .46441 L
Mistroke
.36537 .46445 L
.36604 .4645 L
.36681 .46458 L
.36754 .46467 L
.36884 .4649 L
.37026 .46524 L
.37276 .46607 L
.37543 .46732 L
.37795 .46889 L
.38023 .47067 L
.38511 .47575 L
.39027 .48319 L
.39949 .50181 L
.40955 .52606 L
.42032 .54933 L
.4306 .56622 L
.43997 .57737 L
.44448 .58151 L
.44939 .58523 L
.45368 .58789 L
.45831 .59019 L
.46316 .59206 L
.46772 .59337 L
.47036 .59395 L
.47314 .59443 L
.47551 .59475 L
.4781 .595 L
.47952 .59511 L
.48086 .59518 L
.48206 .59523 L
.48336 .59526 L
.48404 .59527 L
.48479 .59528 L
.48556 .59528 L
.48629 .59527 L
.48759 .59525 L
.48832 .59523 L
.48899 .59521 L
.49147 .5951 L
.49288 .59502 L
.49418 .59493 L
.49911 .59451 L
.50972 .59326 L
.51969 .59191 L
.53831 .58967 L
.54811 .58883 L
.55304 .58852 L
.55845 .58826 L
.56307 .5881 L
.56566 .58803 L
Mistroke
.56802 .58799 L
.57022 .58795 L
.57146 .58794 L
.5726 .58793 L
.5736 .58792 L
.57471 .58792 L
.57586 .58791 L
.57694 .58791 L
.57818 .58791 L
.57888 .58791 L
.57951 .58791 L
.58074 .58791 L
.5819 .58792 L
.58325 .58793 L
.5845 .58793 L
.58731 .58796 L
.59717 .58807 L
.60183 .58812 L
.60618 .58815 L
.60837 .58817 L
.60949 .58818 L
.61072 .58818 L
.61141 .58818 L
.61205 .58819 L
.61332 .58819 L
.61447 .58819 L
.6157 .58819 L
.61683 .58819 L
.61808 .58818 L
.61937 .58818 L
.62058 .58817 L
.62275 .58815 L
.62506 .58813 L
.62778 .58809 L
.63035 .58804 L
.63516 .58793 L
.63972 .58779 L
.64393 .58764 L
.65343 .5872 L
.67219 .58599 L
.69283 .58429 L
.73315 .58064 L
.77196 .57763 L
.81323 .57523 L
.85298 .57347 L
.89121 .57211 L
.9319 .57098 L
.97107 .5702 L
.97619 .57011 L
Mfstroke
0 .609 1 r
.02381 .01472 m
.03279 .09451 L
.04262 .16479 L
.05288 .22057 L
.06244 .2591 L
.06792 .27631 L
.0731 .28975 L
.0828 .30855 L
.08823 .31597 L
.09324 .32115 L
.09875 .32525 L
.10152 .32676 L
.10458 .32804 L
.10706 .32882 L
.10838 .32915 L
.10978 .32943 L
.11112 .32964 L
.11234 .32978 L
.11356 .32989 L
.11472 .32995 L
.11584 .32997 L
.11704 .32997 L
.11805 .32994 L
.11917 .32988 L
.12037 .32979 L
.12166 .32966 L
.12399 .32935 L
.12668 .32888 L
.1296 .32827 L
.13491 .32694 L
.14487 .324 L
.1542 .32117 L
.16425 .31848 L
.17001 .31723 L
.17529 .31633 L
.1779 .31599 L
.18034 .31573 L
.18287 .31552 L
.18422 .31544 L
.1849 .31541 L
.18565 .31538 L
.18693 .31535 L
.18763 .31534 L
.18829 .31534 L
.18947 .31534 L
.19073 .31537 L
.19143 .3154 L
.1922 .31543 L
.1936 .31551 L
.19497 .31562 L
Mistroke
.19623 .31574 L
.19877 .31606 L
.20107 .31643 L
.20622 .31758 L
.21085 .31903 L
.21585 .32109 L
.22058 .32359 L
.22492 .32643 L
.22963 .33023 L
.23468 .33527 L
.24378 .34771 L
.24934 .35805 L
.2546 .37013 L
.26446 .3983 L
.27325 .42547 L
.28271 .45046 L
.28813 .46142 L
.2931 .46915 L
.29785 .47459 L
.30023 .47665 L
.30284 .47843 L
.30418 .47917 L
.30544 .47976 L
.30659 .4802 L
.30781 .48059 L
.30913 .48092 L
.31035 .48113 L
.31167 .48127 L
.31241 .48132 L
.31311 .48134 L
.31434 .48131 L
.31551 .48123 L
.31657 .4811 L
.31771 .48092 L
.32028 .48033 L
.32265 .47959 L
.32749 .47763 L
.33284 .47493 L
.34367 .46866 L
.35308 .4634 L
.35821 .461 L
.36299 .45924 L
.3655 .45855 L
.36679 .45827 L
.36818 .45802 L
.36898 .45791 L
.36971 .45783 L
.37042 .45777 L
.37116 .45773 L
.37245 .4577 L
Mistroke
.37318 .45772 L
.37387 .45776 L
.37515 .45788 L
.37638 .45807 L
.37748 .45831 L
.37867 .45863 L
.38135 .45965 L
.38384 .46098 L
.38649 .46284 L
.38893 .46499 L
.39442 .4716 L
.39926 .47953 L
.40438 .48992 L
.42299 .53341 L
.43248 .55187 L
.44265 .56711 L
.45224 .57764 L
.46098 .58455 L
.4658 .58746 L
.47091 .58996 L
.47532 .59169 L
.48008 .59317 L
.48518 .59439 L
.48996 .59523 L
.49273 .59561 L
.49564 .59593 L
.49832 .59617 L
.50085 .59635 L
.50325 .59648 L
.50586 .59658 L
.50822 .59665 L
.5104 .5967 L
.51162 .59672 L
.51276 .59673 L
.51402 .59674 L
.51472 .59675 L
.51536 .59675 L
.51665 .59676 L
.51738 .59676 L
.51805 .59676 L
.51929 .59676 L
.52061 .59675 L
.52185 .59675 L
.523 .59675 L
.52558 .59674 L
.52781 .59673 L
.52899 .59672 L
.53025 .59672 L
.5314 .59672 L
.53245 .59671 L
Mistroke
.5335 .59671 L
.5345 .59671 L
.53561 .59672 L
.53665 .59672 L
.53778 .59672 L
.53898 .59673 L
.54018 .59674 L
.54149 .59675 L
.54389 .59678 L
.54622 .59682 L
.54838 .59687 L
.55328 .597 L
.5585 .59718 L
.5681 .59763 L
.5768 .59812 L
.59766 .59941 L
.60681 .59992 L
.61685 .6004 L
.62153 .60058 L
.62654 .60075 L
.63088 .60087 L
.63559 .60098 L
.63835 .60103 L
.64091 .60106 L
.6433 .60109 L
.64595 .60112 L
.64708 .60113 L
.64831 .60113 L
.64947 .60114 L
.65053 .60114 L
.65166 .60114 L
.6529 .60115 L
.65419 .60115 L
.65539 .60114 L
.65667 .60114 L
.65731 .60114 L
.65802 .60114 L
.66044 .60112 L
.6618 .60112 L
.66326 .6011 L
.66591 .60108 L
.6711 .60102 L
.67584 .60095 L
.69443 .60058 L
.73417 .59972 L
.77241 .59912 L
.79211 .5989 L
.81309 .59869 L
.85471 .59827 L
.89482 .59784 L
Mistroke
.93341 .59746 L
.97445 .59711 L
.97619 .59709 L
Mfstroke
0 .585 1 r
.02381 .01472 m
.03279 .09446 L
.04262 .16319 L
.04758 .18956 L
.05288 .21136 L
.05546 .21958 L
.05789 .22597 L
.06024 .23093 L
.06244 .23453 L
.06487 .2374 L
.06616 .23848 L
.06754 .23932 L
.06824 .23961 L
.06899 .23985 L
.0697 .24 L
.07037 .24006 L
.07162 .24 L
.07232 .23988 L
.07295 .23971 L
.0742 .23922 L
.07535 .2386 L
.07794 .23666 L
.08023 .2344 L
.08265 .23154 L
.10458 .19464 L
.12444 .16145 L
.14255 .13851 L
.15257 .12895 L
.16206 .12172 L
.17208 .11577 L
.1777 .1131 L
.18298 .111 L
.19238 .10812 L
.19737 .10701 L
.19994 .10655 L
.20275 .10612 L
.20552 .10579 L
.20809 .10556 L
.20951 .10546 L
.21081 .1054 L
.21152 .10537 L
.2123 .10534 L
.21303 .10532 L
.21371 .10531 L
.21491 .10531 L
.21603 .10531 L
.21727 .10534 L
.21796 .10537 L
.21859 .10539 L
.21986 .10546 L
Mistroke
.22124 .10556 L
.22376 .10581 L
.22632 .10615 L
.22909 .10664 L
.23153 .10718 L
.2341 .10787 L
.23898 .10959 L
.24347 .11174 L
.24865 .11514 L
.25348 .11948 L
.25878 .12597 L
.26446 .13532 L
.27409 .15606 L
.28431 .17748 L
.28964 .1854 L
.29267 .18861 L
.29406 .18975 L
.29551 .19075 L
.29676 .19144 L
.29812 .19202 L
.29935 .1924 L
.3005 .19264 L
.3012 .19272 L
.30186 .19277 L
.3031 .19276 L
.30379 .1927 L
.30443 .19262 L
.30513 .19249 L
.30587 .19232 L
.30714 .19195 L
.30835 .1915 L
.31061 .19042 L
.3157 .18709 L
.32488 .17884 L
.34577 .15666 L
.36396 .13951 L
.37433 .13165 L
.38406 .1256 L
.39356 .12088 L
.40381 .11696 L
.41476 .11393 L
.42481 .11193 L
.44371 .10927 L
.46441 .1067 L
.48563 .10393 L
.50493 .10159 L
.52499 .09965 L
.54395 .09832 L
.55365 .09782 L
.56394 .09741 L
Mistroke
.57272 .09714 L
.58238 .09692 L
.58758 .09683 L
.59253 .09676 L
.59696 .09672 L
.6018 .09668 L
.60456 .09666 L
.60705 .09665 L
.60843 .09665 L
.60916 .09665 L
.60993 .09665 L
.6106 .09665 L
.61134 .09665 L
.61264 .09664 L
.61395 .09664 L
.61515 .09665 L
.61581 .09665 L
.61653 .09665 L
.61784 .09665 L
.61906 .09665 L
.62036 .09666 L
.62269 .09666 L
.62758 .09669 L
.63207 .09672 L
.64217 .09682 L
.65108 .09693 L
.66046 .09707 L
.69859 .09778 L
.73917 .09862 L
.77823 .09943 L
.81975 .10029 L
.85975 .1011 L
.89824 .10184 L
.93918 .10256 L
.97619 .10314 L
Mfstroke
0 .561 1 r
.02381 .01472 m
.03279 .09421 L
.03793 .13172 L
.04262 .15963 L
.04758 .18233 L
.0503 .19182 L
.05288 .19892 L
.05527 .20395 L
.05747 .20737 L
.05862 .20871 L
.05988 .20986 L
.06121 .21071 L
.06244 .2112 L
.0631 .21135 L
.06379 .21142 L
.06504 .21136 L
.06581 .21119 L
.06653 .21096 L
.06718 .21068 L
.06788 .21032 L
.07057 .20836 L
.07305 .20585 L
.07776 .19964 L
.08274 .19169 L
.10458 .15281 L
.12444 .12365 L
.14255 .10491 L
.15257 .09734 L
.16206 .0917 L
.17208 .08709 L
.18298 .08341 L
.19238 .08116 L
.19773 .08022 L
.20275 .07955 L
.20532 .07928 L
.20802 .07906 L
.21033 .07891 L
.21163 .07884 L
.21286 .07879 L
.21355 .07877 L
.21429 .07875 L
.21559 .07872 L
.21633 .07872 L
.21711 .07871 L
.21777 .07871 L
.21851 .07872 L
.21981 .07874 L
.22055 .07876 L
.22122 .07878 L
.22252 .07883 L
Mistroke
.22376 .07889 L
.22636 .07907 L
.2288 .0793 L
.23337 .07991 L
.23593 .08037 L
.23829 .08089 L
.2436 .0824 L
.24787 .08407 L
.25256 .08653 L
.25745 .09 L
.262 .09429 L
.28068 .12042 L
.28579 .12688 L
.28859 .12976 L
.29122 .13197 L
.29364 .13359 L
.29586 .13473 L
.29703 .1352 L
.29832 .13562 L
.29961 .13595 L
.30031 .13608 L
.30096 .13619 L
.30166 .13627 L
.3023 .13632 L
.303 .13636 L
.30374 .13637 L
.30499 .13632 L
.3057 .13627 L
.30636 .1362 L
.3076 .13601 L
.30872 .13579 L
.31126 .13512 L
.31396 .13419 L
.3169 .13295 L
.32224 .13026 L
.34238 .11813 L
.36213 .1077 L
.3721 .10395 L
.37484 .10315 L
.37779 .10241 L
.38037 .10187 L
.38179 .10162 L
.38313 .10142 L
.38437 .10126 L
.38572 .10113 L
.38694 .10104 L
.38807 .10098 L
.38914 .10096 L
.39031 .10096 L
.39154 .10101 L
Mistroke
.39268 .10109 L
.39333 .10115 L
.39403 .10123 L
.39532 .10143 L
.39656 .10167 L
.39772 .10195 L
.40035 .1028 L
.40314 .10408 L
.40588 .10578 L
.40884 .10824 L
.41164 .11126 L
.41421 .11471 L
.41908 .12331 L
.42423 .1355 L
.44411 .20162 L
.45279 .22832 L
.45737 .23954 L
.46223 .24888 L
.4647 .25257 L
.46744 .25581 L
.46863 .25696 L
.46992 .25801 L
.47113 .25883 L
.47225 .25944 L
.47341 .25993 L
.47467 .2603 L
.4759 .26051 L
.47721 .26056 L
.47843 .26046 L
.47959 .26024 L
.48063 .25994 L
.48175 .25951 L
.48427 .25816 L
.48704 .25612 L
.49264 .25046 L
.50267 .23662 L
.52377 .20145 L
.54303 .1715 L
.56296 .14689 L
.58187 .12965 L
.5915 .12283 L
.60173 .11677 L
.62014 .1084 L
.63046 .10481 L
.64161 .10161 L
.66179 .09713 L
.68179 .09383 L
.70287 .09114 L
.74091 .08762 L
.76048 .08632 L
Mistroke
.78141 .08521 L
.80271 .08434 L
.82284 .08371 L
.86124 .08285 L
.88107 .08253 L
.9021 .08225 L
.92032 .08206 L
.93992 .08188 L
.97619 .08164 L
Mfstroke
0 .538 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16472 L
.05288 .22001 L
.06244 .25721 L
.06792 .27314 L
.0731 .28501 L
.07775 .29329 L
.0828 .30001 L
.08542 .30265 L
.0883 .30496 L
.08975 .30589 L
.09131 .30674 L
.09265 .30736 L
.09413 .3079 L
.09558 .30831 L
.09628 .30847 L
.09692 .30859 L
.09821 .30876 L
.09892 .30883 L
.09959 .30886 L
.10083 .30888 L
.10198 .30883 L
.10325 .30871 L
.10388 .30862 L
.10458 .30851 L
.10709 .30796 L
.10982 .30713 L
.11478 .30508 L
.12409 .29992 L
.145 .28613 L
.16478 .27494 L
.17476 .27089 L
.18045 .26917 L
.18321 .26849 L
.18579 .26797 L
.18825 .26755 L
.19048 .26725 L
.19167 .26713 L
.19296 .26702 L
.19367 .26697 L
.19433 .26693 L
.19562 .26687 L
.19685 .26684 L
.19801 .26684 L
.19928 .26686 L
.19999 .26689 L
.20065 .26692 L
.20195 .267 L
.20338 .26713 L
Mistroke
.20472 .26728 L
.20597 .26746 L
.20839 .26789 L
.21067 .2684 L
.21493 .26967 L
.21952 .27153 L
.22447 .27422 L
.22941 .27771 L
.234 .28187 L
.23905 .28768 L
.24445 .2957 L
.25012 .30669 L
.25548 .31998 L
.26553 .35231 L
.27432 .38382 L
.28379 .4132 L
.28921 .4262 L
.29417 .43546 L
.29892 .44207 L
.3013 .44461 L
.30391 .44686 L
.30652 .44857 L
.30888 .4497 L
.31019 .45017 L
.31088 .45037 L
.31161 .45056 L
.31225 .45069 L
.31295 .45081 L
.31418 .45096 L
.31543 .45102 L
.31656 .45102 L
.31787 .45093 L
.31911 .45078 L
.32026 .45058 L
.32132 .45036 L
.32372 .44969 L
.32856 .44783 L
.33391 .44517 L
.34475 .43893 L
.35415 .43389 L
.35889 .43194 L
.36157 .43109 L
.36277 .43079 L
.36407 .43052 L
.3648 .4304 L
.36548 .4303 L
.36612 .43023 L
.36682 .43017 L
.36804 .43011 L
.36932 .43013 L
Mistroke
.37005 .43018 L
.37072 .43024 L
.37149 .43035 L
.37222 .43048 L
.37352 .43079 L
.37494 .43125 L
.37745 .43238 L
.38011 .4341 L
.38263 .43625 L
.38492 .4387 L
.3898 .44568 L
.39495 .45586 L
.40418 .48044 L
.41423 .51012 L
.425 .5372 L
.43528 .55659 L
.44466 .56933 L
.44917 .57404 L
.45408 .57825 L
.45837 .58125 L
.46299 .58382 L
.46785 .58589 L
.4724 .58731 L
.47504 .58792 L
.47782 .58842 L
.48019 .58873 L
.48153 .58887 L
.48278 .58897 L
.4841 .58905 L
.48484 .58908 L
.48552 .58911 L
.48678 .58914 L
.48741 .58914 L
.48811 .58914 L
.48931 .58913 L
.49061 .5891 L
.49183 .58905 L
.49295 .58899 L
.49561 .5888 L
.49851 .58852 L
.5038 .58784 L
.51415 .58609 L
.52352 .58425 L
.54451 .58024 L
.56381 .57745 L
.57468 .57631 L
.58465 .57548 L
.60513 .57411 L
.62421 .57275 L
.64259 .57097 L
Mistroke
.66226 .56839 L
.70369 .56101 L
.74361 .55318 L
.78201 .54678 L
.82286 .54173 L
.8622 .5382 L
.90002 .53565 L
.92105 .53455 L
.9403 .53372 L
.97619 .53262 L
Mfstroke
0 .514 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16448 L
.04758 .19294 L
.05288 .21861 L
.06244 .25352 L
.06788 .26757 L
.07075 .27346 L
.07379 .27868 L
.07644 .28242 L
.07936 .28574 L
.08202 .28807 L
.08451 .28973 L
.08574 .29037 L
.0871 .29094 L
.08837 .29136 L
.08956 .29165 L
.09073 .29186 L
.09179 .29197 L
.09302 .29201 L
.09418 .29198 L
.09544 .29187 L
.09608 .29178 L
.09678 .29166 L
.09917 .29108 L
.10052 .29065 L
.10197 .29011 L
.10458 .28894 L
.11475 .28271 L
.12582 .27423 L
.14594 .25871 L
.15614 .25204 L
.16572 .2469 L
.1757 .24283 L
.181 .24123 L
.18377 .24056 L
.18672 .23996 L
.18932 .23954 L
.19168 .23925 L
.19282 .23914 L
.19405 .23904 L
.19522 .23898 L
.19629 .23893 L
.19755 .23891 L
.19872 .2389 L
.2 .23893 L
.20072 .23895 L
.20138 .23898 L
.2027 .23907 L
.20414 .2392 L
Mistroke
.20676 .23953 L
.20955 .24003 L
.21207 .24061 L
.21478 .2414 L
.21771 .24244 L
.22294 .24485 L
.22786 .24788 L
.23279 .25182 L
.23739 .25651 L
.24244 .26306 L
.24784 .27217 L
.25351 .28464 L
.25887 .29958 L
.26892 .33413 L
.2786 .36763 L
.2839 .38274 L
.28887 .39399 L
.29309 .4012 L
.29546 .40432 L
.29764 .4066 L
.29989 .40842 L
.30116 .40921 L
.30235 .40979 L
.3036 .41026 L
.30474 .41055 L
.30606 .41073 L
.3073 .41076 L
.30846 .41067 L
.3097 .41045 L
.31087 .41013 L
.31194 .40974 L
.31456 .40845 L
.31705 .40681 L
.32198 .40249 L
.32735 .3965 L
.34582 .37017 L
.36518 .34122 L
.37547 .32771 L
.38657 .31546 L
.39712 .30635 L
.40174 .30316 L
.4068 .30019 L
.41605 .29607 L
.4211 .29443 L
.4258 .29325 L
.42825 .29276 L
.43084 .29234 L
.43219 .29216 L
.43368 .29199 L
.43506 .29186 L
Mistroke
.43631 .29177 L
.43758 .2917 L
.43878 .29166 L
.44005 .29164 L
.44077 .29164 L
.44143 .29165 L
.44265 .29168 L
.44376 .29174 L
.44503 .29182 L
.44623 .29193 L
.4485 .29221 L
.45089 .2926 L
.45516 .29355 L
.45977 .29493 L
.46482 .29686 L
.48434 .30733 L
.50526 .32035 L
.54664 .34081 L
.56735 .34979 L
.58651 .35974 L
.62486 .38753 L
.66414 .42177 L
.70191 .45086 L
.74214 .47464 L
.78084 .49241 L
.822 .50756 L
.86165 .51905 L
.89978 .52756 L
.94036 .53442 L
.97619 .53905 L
Mfstroke
0 .49 1 r
.02381 .01472 m
.03279 .09447 L
.04262 .16368 L
.04758 .19086 L
.05288 .21415 L
.05789 .23086 L
.06244 .24188 L
.06507 .24655 L
.06785 .25027 L
.07022 .25252 L
.07157 .25344 L
.07283 .25409 L
.07353 .25436 L
.07428 .25458 L
.075 .25473 L
.07567 .25481 L
.07692 .25483 L
.07763 .25477 L
.07826 .25467 L
.07901 .2545 L
.07971 .2543 L
.08127 .25367 L
.08265 .25294 L
.0841 .25201 L
.08915 .24765 L
.09387 .24235 L
.10458 .22775 L
.12322 .20084 L
.14349 .17653 L
.15452 .16644 L
.16473 .15905 L
.17448 .1536 L
.17989 .15122 L
.18485 .14941 L
.18932 .14807 L
.19422 .14693 L
.1966 .14649 L
.19914 .1461 L
.20055 .14593 L
.20182 .14579 L
.20304 .14569 L
.20432 .14559 L
.20544 .14553 L
.20667 .14549 L
.20779 .14546 L
.20883 .14546 L
.21006 .14547 L
.21119 .14551 L
.21249 .14557 L
.21372 .14565 L
Mistroke
.21593 .14587 L
.21797 .14613 L
.22021 .14651 L
.2226 .14702 L
.22522 .14771 L
.22797 .14861 L
.23291 .1507 L
.23823 .15382 L
.24405 .1586 L
.2491 .16433 L
.2545 .17267 L
.25959 .18321 L
.26423 .19529 L
.2743 .22697 L
.27981 .24401 L
.28497 .2575 L
.28936 .2664 L
.29183 .27027 L
.29409 .2731 L
.29643 .27534 L
.29775 .2763 L
.29898 .277 L
.30029 .27755 L
.30147 .27788 L
.30213 .278 L
.30284 .27808 L
.30413 .27808 L
.30529 .27795 L
.30652 .27767 L
.30769 .27727 L
.30876 .27682 L
.31137 .27532 L
.31384 .27345 L
.31876 .26868 L
.32411 .26227 L
.34251 .23585 L
.36188 .20898 L
.37216 .197 L
.38326 .18626 L
.39381 .17817 L
.40349 .17242 L
.41275 .16821 L
.4225 .16483 L
.44221 .15973 L
.46057 .15557 L
.47929 .15164 L
.49959 .1482 L
.51068 .14677 L
.52091 .14572 L
.53069 .14494 L
Mistroke
.54105 .14431 L
.55047 .14391 L
.55576 .14375 L
.55827 .14369 L
.5606 .14364 L
.56296 .1436 L
.56509 .14357 L
.56746 .14355 L
.56876 .14354 L
.56999 .14353 L
.57107 .14353 L
.57222 .14352 L
.5732 .14352 L
.57427 .14352 L
.57543 .14353 L
.57667 .14353 L
.57784 .14354 L
.57891 .14355 L
.5812 .14357 L
.58372 .14361 L
.58883 .14371 L
.59356 .14384 L
.59801 .14398 L
.608 .14442 L
.61877 .14505 L
.63883 .14662 L
.65993 .14872 L
.69806 .15311 L
.73864 .15785 L
.77771 .1622 L
.81922 .1667 L
.85923 .17089 L
.89771 .17466 L
.93865 .17828 L
.97619 .18121 L
Mfstroke
0 .466 1 r
.02381 .01472 m
.03279 .09443 L
.04262 .16214 L
.04758 .18678 L
.0503 .19734 L
.05288 .20535 L
.05528 .21112 L
.05655 .21351 L
.05789 .21558 L
.05902 .21696 L
.06026 .21811 L
.06139 .21883 L
.06244 .21924 L
.0631 .21937 L
.06379 .21941 L
.06504 .21924 L
.06581 .21898 L
.06653 .21864 L
.06788 .21775 L
.06917 .21663 L
.07036 .21537 L
.07305 .21186 L
.08274 .19388 L
.10458 .1468 L
.1234 .11479 L
.13409 .10126 L
.14407 .09127 L
.15452 .0831 L
.16442 .07714 L
.17331 .07301 L
.18298 .06958 L
.19238 .06712 L
.19773 .06606 L
.20275 .06525 L
.20802 .0646 L
.21286 .06417 L
.2154 .06401 L
.21817 .06387 L
.21957 .06383 L
.22034 .06381 L
.22106 .06379 L
.22174 .06378 L
.22248 .06377 L
.22376 .06377 L
.22499 .06377 L
.22612 .06379 L
.22741 .06382 L
.22865 .06386 L
.22978 .06391 L
.23084 .06396 L
Mistroke
.23322 .06411 L
.23587 .06434 L
.23827 .06461 L
.24106 .06501 L
.24363 .06545 L
.24885 .06666 L
.25159 .06748 L
.25448 .06852 L
.25934 .07073 L
.26468 .0739 L
.27556 .08233 L
.28092 .08652 L
.28586 .08974 L
.29035 .09188 L
.29261 .09264 L
.29383 .09297 L
.29511 .09325 L
.29641 .09347 L
.2976 .09362 L
.29889 .09372 L
.29962 .09375 L
.30029 .09376 L
.30153 .09374 L
.30264 .09369 L
.30394 .09358 L
.30515 .09343 L
.30741 .09306 L
.30989 .09251 L
.31489 .09106 L
.32386 .08767 L
.34411 .07907 L
.3636 .0721 L
.37453 .06914 L
.38451 .067 L
.3944 .06537 L
.40357 .06424 L
.41363 .06335 L
.41871 .06302 L
.42432 .06273 L
.4344 .06236 L
.44364 .06211 L
.46449 .06157 L
.48339 .0609 L
.50408 .06 L
.52531 .05911 L
.54461 .05846 L
.55423 .05821 L
.56467 .05798 L
.58362 .05767 L
.59307 .05756 L
Mistroke
.60348 .05746 L
.61434 .05738 L
.62451 .05732 L
.6349 .05728 L
.64477 .05724 L
.6633 .05719 L
.6729 .05718 L
.68312 .05716 L
.69277 .05715 L
.70151 .05715 L
.7064 .05714 L
.71155 .05714 L
.71595 .05714 L
.71845 .05714 L
.72078 .05714 L
.72207 .05714 L
.72275 .05714 L
.72348 .05714 L
.72411 .05714 L
.72481 .05714 L
.72604 .05714 L
.72723 .05714 L
.72851 .05714 L
.72972 .05714 L
.73083 .05714 L
.73213 .05714 L
.73334 .05714 L
.73608 .05714 L
.73875 .05714 L
.7416 .05714 L
.74694 .05714 L
.75185 .05714 L
.76296 .05715 L
.78312 .05717 L
.82254 .05721 L
.86045 .05726 L
.90081 .05731 L
.93965 .05736 L
.97619 .0574 L
Mfstroke
0 .443 1 r
.02381 .01472 m
.02499 .02002 L
.02605 .02096 L
.02729 .02125 L
.02846 .02129 L
.02954 .02123 L
.03053 .02114 L
.03279 .02087 L
.04262 .01953 L
.05285 .01835 L
.06244 .0175 L
.07218 .01685 L
.0829 .01632 L
.09334 .01595 L
.10458 .01566 L
.11468 .01547 L
.12571 .01532 L
.13613 .01521 L
.1458 .01515 L
.15637 .01509 L
.16633 .01505 L
.17526 .01503 L
.18493 .01501 L
.19444 .01499 L
.20487 .01498 L
.21577 .01497 L
.22594 .01496 L
.23094 .01496 L
.23639 .01496 L
.24119 .01496 L
.24629 .01496 L
.25087 .01496 L
.25593 .01495 L
.26485 .01495 L
.26976 .01495 L
.27494 .01495 L
.28419 .01495 L
.30505 .01495 L
.32502 .01495 L
.34316 .01495 L
.35324 .01495 L
.36277 .01495 L
.37282 .01495 L
.37849 .01495 L
.38372 .01495 L
.38839 .01495 L
.39341 .01495 L
.39584 .01495 L
.39815 .01495 L
.40042 .01495 L
Mistroke
.40248 .01495 L
.40367 .01495 L
.40496 .01495 L
.40567 .01495 L
.40632 .01495 L
.40761 .01495 L
.40871 .01495 L
.40992 .01495 L
.41118 .01495 L
.41236 .01495 L
.41303 .01495 L
.41375 .01495 L
.41508 .01495 L
.41756 .01495 L
.42045 .01495 L
.42312 .01495 L
.43277 .01495 L
.44182 .01495 L
.45187 .01495 L
.45735 .01495 L
.46244 .01495 L
.46712 .01495 L
.46951 .01495 L
.4721 .01495 L
.47359 .01495 L
.47495 .01495 L
.47626 .01495 L
.47692 .01495 L
.47764 .01495 L
.47888 .01495 L
.48003 .01495 L
.48074 .01495 L
.48141 .01495 L
.48266 .01495 L
.48372 .01495 L
.48489 .01495 L
.48612 .01495 L
.48727 .01495 L
.48932 .01495 L
.49153 .01495 L
.49656 .01495 L
.50118 .01495 L
.51097 .01495 L
.52008 .01495 L
.54077 .01495 L
.55948 .01495 L
.57978 .01495 L
.60111 .01495 L
.62125 .01495 L
.66214 .01495 L
Mistroke
.70151 .01495 L
.73936 .01495 L
.77967 .01495 L
.81846 .01495 L
.85971 .01495 L
.89943 .01495 L
.93765 .01495 L
.97619 .01495 L
Mfstroke
0 .419 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16471 L
.05288 .21991 L
.06244 .2569 L
.06792 .27265 L
.0731 .28435 L
.07775 .29246 L
.0828 .299 L
.08542 .30156 L
.0883 .30377 L
.08975 .30467 L
.09131 .30548 L
.09265 .30606 L
.09413 .30656 L
.09558 .30694 L
.09628 .30708 L
.09692 .30719 L
.09821 .30735 L
.09892 .3074 L
.09959 .30742 L
.10083 .30742 L
.10198 .30735 L
.10325 .30722 L
.10388 .30712 L
.10458 .30701 L
.10709 .30644 L
.10982 .30559 L
.11478 .30354 L
.12409 .29846 L
.145 .28504 L
.16478 .27429 L
.17476 .27045 L
.18045 .26884 L
.18321 .26822 L
.18579 .26774 L
.18825 .26736 L
.19048 .26711 L
.19176 .26699 L
.19296 .26691 L
.19424 .26684 L
.19496 .26682 L
.19562 .2668 L
.19685 .26679 L
.19801 .26681 L
.19928 .26685 L
.19999 .26689 L
.20065 .26693 L
.20195 .26703 L
.20338 .26718 L
Mistroke
.20597 .26754 L
.20841 .268 L
.21062 .26853 L
.21557 .2701 L
.22016 .27209 L
.22447 .27451 L
.22914 .27784 L
.23426 .28252 L
.23961 .28883 L
.24459 .29638 L
.25352 .31519 L
.25852 .3292 L
.26308 .34397 L
.27314 .37946 L
.27865 .39757 L
.28381 .4122 L
.28857 .42328 L
.29293 .43132 L
.29777 .43797 L
.3003 .44056 L
.30297 .44266 L
.30422 .44343 L
.30539 .44405 L
.30645 .44451 L
.30757 .44491 L
.3088 .44524 L
.30993 .44546 L
.31115 .44559 L
.31184 .44562 L
.31248 .44563 L
.31363 .44558 L
.31471 .44546 L
.31568 .4453 L
.31674 .44506 L
.31912 .44434 L
.32132 .44345 L
.32593 .44097 L
.33103 .43751 L
.34136 .42914 L
.35076 .42124 L
.36068 .41406 L
.36587 .41125 L
.36881 .41007 L
.37022 .40962 L
.37155 .40928 L
.37276 .40904 L
.37408 .40886 L
.37527 .40878 L
.37637 .40877 L
.37756 .40884 L
Mistroke
.37887 .40902 L
.37953 .40915 L
.38024 .40932 L
.38153 .40973 L
.38286 .41028 L
.38407 .41089 L
.38677 .41272 L
.38928 .41502 L
.39164 .41777 L
.39694 .42625 L
.40268 .43925 L
.42277 .50066 L
.43309 .5279 L
.44272 .54756 L
.45277 .56275 L
.45809 .56895 L
.46379 .57439 L
.47398 .58155 L
.47973 .5844 L
.48505 .58642 L
.48969 .58777 L
.49481 .58889 L
.49738 .58933 L
.50016 .58973 L
.50258 .59001 L
.50518 .59026 L
.50778 .59046 L
.51014 .5906 L
.51251 .59071 L
.51476 .59079 L
.51603 .59083 L
.51737 .59086 L
.51978 .5909 L
.52112 .59092 L
.52238 .59093 L
.52375 .59094 L
.52523 .59095 L
.53054 .59097 L
.53194 .59097 L
.53345 .59097 L
.53487 .59097 L
.53618 .59098 L
.53742 .59098 L
.53878 .59099 L
.54019 .591 L
.54151 .59101 L
.54384 .59103 L
.54634 .59106 L
.54906 .59111 L
.55164 .59117 L
Mistroke
.55648 .59131 L
.56177 .59151 L
.56753 .59177 L
.58763 .59296 L
.60707 .59413 L
.61239 .59439 L
.61813 .59463 L
.6235 .59482 L
.62849 .59495 L
.63113 .595 L
.63352 .59504 L
.63618 .59507 L
.63764 .59509 L
.63901 .5951 L
.64023 .5951 L
.64152 .59511 L
.64262 .59511 L
.64382 .59511 L
.64512 .59511 L
.64585 .5951 L
.64651 .5951 L
.6478 .59509 L
.64903 .59508 L
.65129 .59506 L
.6537 .59503 L
.65803 .59495 L
.66268 .59485 L
.66782 .5947 L
.68716 .59395 L
.70802 .59295 L
.74914 .59106 L
.78875 .58976 L
.82685 .58886 L
.8674 .58807 L
.90643 .58744 L
.92634 .58717 L
.94792 .58694 L
.97619 .5867 L
Mfstroke
0 .395 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02133 L
.03163 .02122 L
.03279 .02108 L
.04262 .01979 L
.05217 .01869 L
.06244 .01777 L
.0728 .01708 L
.0825 .01659 L
.09403 .01616 L
.10458 .01588 L
.11442 .01568 L
.12357 .01555 L
.1336 .01544 L
.14429 .01535 L
.15457 .01529 L
.1657 .01524 L
.17621 .01521 L
.18587 .01519 L
.19561 .01517 L
.2047 .01516 L
.21467 .01515 L
.22026 .01515 L
.22536 .01514 L
.23016 .01514 L
.23527 .01514 L
.23963 .01514 L
.24444 .01514 L
.24713 .01514 L
.2496 .01514 L
.251 .01514 L
.2523 .01514 L
.25366 .01514 L
.25438 .01514 L
.25515 .01514 L
.25645 .01514 L
.25718 .01514 L
.25786 .01514 L
.2591 .01514 L
.26042 .01514 L
.2616 .01514 L
.2627 .01514 L
.2652 .01514 L
.27018 .01514 L
.27561 .01514 L
Mistroke
.27809 .01514 L
.27946 .01514 L
.28074 .01514 L
.28194 .01514 L
.28323 .01514 L
.28441 .01514 L
.28549 .01514 L
.28657 .01514 L
.28772 .01514 L
.2888 .01514 L
.28979 .01514 L
.29096 .01514 L
.29222 .01514 L
.29451 .01514 L
.29691 .01514 L
.29946 .01514 L
.30403 .01514 L
.34183 .01513 L
.36122 .01513 L
.37211 .01513 L
.38209 .01513 L
.38684 .01512 L
.39191 .01512 L
.40105 .01512 L
.40664 .01512 L
.41191 .01512 L
.42176 .01512 L
.46028 .01512 L
.50125 .01512 L
.54071 .01512 L
.56054 .01512 L
.57865 .01512 L
.59813 .01512 L
.61904 .01512 L
.6381 .01512 L
.65885 .01512 L
.6786 .01512 L
.6996 .01512 L
.70896 .01512 L
.71905 .01512 L
.73732 .01512 L
.74687 .01512 L
.75734 .01512 L
.76261 .01512 L
.76826 .01512 L
.77843 .01512 L
.78375 .01512 L
.78865 .01512 L
.79404 .01512 L
.79676 .01512 L
Mistroke
.79975 .01512 L
.80109 .01512 L
.80237 .01512 L
.80353 .01512 L
.80476 .01512 L
.80546 .01512 L
.8061 .01512 L
.80734 .01512 L
.80804 .01512 L
.80879 .01512 L
.8095 .01512 L
.81015 .01512 L
.81132 .01512 L
.81241 .01512 L
.81361 .01512 L
.81489 .01512 L
.81751 .01512 L
.81989 .01512 L
.82471 .01512 L
.82982 .01512 L
.83899 .01512 L
.85976 .01512 L
.89753 .01512 L
.93775 .01512 L
.97619 .01512 L
Mfstroke
0 .372 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03479 L
.02721 .04278 L
.02846 .04916 L
.02961 .0531 L
.03068 .05539 L
.0317 .05668 L
.03279 .05737 L
.03395 .05756 L
.0352 .05733 L
.03638 .05684 L
.03746 .05624 L
.04262 .05237 L
.06244 .03761 L
.07277 .03217 L
.08405 .02776 L
.09469 .02471 L
.10458 .02262 L
.11515 .02097 L
.1251 .01982 L
.13404 .01904 L
.14371 .01841 L
.15321 .01794 L
.16365 .01756 L
.17454 .01727 L
.18471 .01708 L
.19516 .01694 L
.20506 .01684 L
.21395 .01677 L
.21894 .01675 L
.22362 .01672 L
.22852 .01671 L
.23302 .01669 L
.23801 .01668 L
.24064 .01668 L
.2434 .01667 L
.24591 .01667 L
.24731 .01667 L
.24859 .01667 L
.24979 .01667 L
.25108 .01667 L
.2523 .01667 L
.25343 .01667 L
.25474 .01667 L
.25597 .01667 L
.25731 .01667 L
.25876 .01667 L
.26171 .01667 L
.2644 .01668 L
Mistroke
.27362 .01669 L
.27867 .0167 L
.28115 .0167 L
.28343 .0167 L
.28472 .0167 L
.28614 .01671 L
.28757 .01671 L
.28835 .01671 L
.28907 .01671 L
.29037 .01671 L
.29154 .01671 L
.29219 .01671 L
.2929 .01671 L
.29419 .01671 L
.29538 .01671 L
.2967 .01671 L
.29937 .0167 L
.30185 .0167 L
.30416 .0167 L
.31402 .01668 L
.32439 .01666 L
.3429 .01663 L
.35247 .01661 L
.36268 .0166 L
.37225 .01659 L
.38106 .01658 L
.39133 .01657 L
.39674 .01657 L
.40245 .01657 L
.40485 .01657 L
.40742 .01657 L
.40964 .01657 L
.41206 .01657 L
.41353 .01657 L
.41489 .01657 L
.41617 .01657 L
.41758 .01657 L
.41884 .01657 L
.42002 .01657 L
.42127 .01657 L
.42197 .01657 L
.42261 .01657 L
.42389 .01657 L
.42509 .01657 L
.42617 .01657 L
.42734 .01657 L
.42997 .01657 L
.4324 .01657 L
.43683 .01657 L
.44151 .01657 L
Mistroke
.45149 .01657 L
.45698 .01657 L
.46221 .01657 L
.46709 .01657 L
.46985 .01657 L
.47117 .01657 L
.47242 .01657 L
.47356 .01657 L
.47479 .01657 L
.47591 .01657 L
.47694 .01657 L
.47806 .01657 L
.47928 .01657 L
.48056 .01657 L
.48176 .01657 L
.48289 .01657 L
.48413 .01657 L
.48638 .01657 L
.48857 .01657 L
.49059 .01657 L
.49519 .01657 L
.50006 .01657 L
.51955 .01657 L
.53783 .01656 L
.57654 .01655 L
.59659 .01654 L
.6177 .01654 L
.63746 .01654 L
.65583 .01654 L
.6763 .01654 L
.69489 .01654 L
.71571 .01653 L
.73489 .01653 L
.75359 .01653 L
.77338 .01653 L
.79297 .01653 L
.81129 .01653 L
.83159 .01653 L
.85013 .01653 L
.86917 .01653 L
.88006 .01653 L
.88991 .01653 L
.90964 .01653 L
.92046 .01653 L
.93063 .01653 L
.94043 .01653 L
.94536 .01653 L
.95076 .01653 L
.95539 .01653 L
.95793 .01653 L
Mistroke
.96033 .01653 L
.96257 .01653 L
.965 .01653 L
.96608 .01653 L
.96721 .01653 L
.96828 .01653 L
.96925 .01653 L
.97014 .01653 L
.97098 .01653 L
.97187 .01653 L
.97283 .01653 L
.97368 .01653 L
.97457 .01653 L
.97542 .01653 L
.97619 .01653 L
Mfstroke
0 .348 1 r
.02381 .01472 m
.03279 .09451 L
.04262 .16475 L
.05288 .22024 L
.06244 .25799 L
.06792 .27445 L
.0731 .28698 L
.07781 .2961 L
.0828 .30365 L
.08539 .30679 L
.08823 .30969 L
.09324 .31354 L
.09606 .31506 L
.09762 .31573 L
.0991 .31625 L
.10047 .31664 L
.10196 .31698 L
.10262 .3171 L
.10332 .31721 L
.10458 .31735 L
.10582 .31744 L
.10653 .31746 L
.10718 .31747 L
.10788 .31746 L
.10851 .31744 L
.10924 .3174 L
.10994 .31735 L
.11116 .31723 L
.1123 .31707 L
.11487 .31661 L
.11743 .316 L
.12026 .31517 L
.12599 .31313 L
.14616 .30422 L
.15559 .3002 L
.16551 .29662 L
.17071 .2951 L
.17639 .29376 L
.17889 .29329 L
.18156 .29287 L
.18408 .29256 L
.18637 .29234 L
.18756 .29226 L
.18867 .29219 L
.1899 .29215 L
.19121 .29212 L
.19187 .29211 L
.19259 .29211 L
.1939 .29214 L
.19517 .29218 L
Mistroke
.19635 .29225 L
.19755 .29234 L
.19869 .29244 L
.2008 .2927 L
.20309 .29305 L
.20555 .29354 L
.21082 .29497 L
.21348 .29591 L
.21639 .29713 L
.22116 .29959 L
.22635 .30303 L
.2316 .3075 L
.23658 .31284 L
.2459 .32678 L
.25117 .3376 L
.25677 .35181 L
.26682 .38318 L
.27622 .41332 L
.28115 .42697 L
.28633 .43891 L
.2909 .44722 L
.29331 .45079 L
.29588 .45398 L
.29826 .45638 L
.30042 .45814 L
.30258 .45951 L
.30463 .46047 L
.30578 .46088 L
.30703 .4612 L
.3082 .46141 L
.30927 .46153 L
.31053 .46156 L
.31123 .46154 L
.31189 .4615 L
.31309 .46135 L
.31437 .4611 L
.31559 .46079 L
.3169 .46037 L
.31927 .45941 L
.32468 .45638 L
.33431 .4489 L
.34314 .44079 L
.35305 .43157 L
.36365 .42286 L
.36879 .41947 L
.37131 .41808 L
.37364 .41697 L
.37572 .41615 L
.37801 .41544 L
.37919 .41516 L
Mistroke
.3803 .41495 L
.38148 .4148 L
.38274 .4147 L
.38396 .41469 L
.38527 .41477 L
.3865 .41493 L
.38761 .41516 L
.38893 .41553 L
.39035 .41606 L
.39294 .41738 L
.39539 .41912 L
.39798 .42152 L
.40263 .42736 L
.40711 .43505 L
.4113 .44398 L
.42081 .46893 L
.43946 .51945 L
.45 .54177 L
.45974 .55759 L
.47005 .56998 L
.47525 .57481 L
.481 .57921 L
.48599 .58236 L
.49138 .58515 L
.49643 .58728 L
.50112 .58891 L
.5107 .5914 L
.51577 .59238 L
.52118 .59324 L
.54228 .59563 L
.5838 .59956 L
.60462 .60131 L
.61376 .60193 L
.6238 .60247 L
.62846 .60267 L
.63346 .60286 L
.63779 .60299 L
.6425 .60311 L
.64526 .60316 L
.64781 .6032 L
.65045 .60324 L
.65284 .60327 L
.6552 .60329 L
.65742 .6033 L
.65864 .60331 L
.65976 .60331 L
.66099 .60332 L
.66229 .60332 L
.66352 .60332 L
.66421 .60332 L
Mistroke
.66485 .60332 L
.66602 .60332 L
.66727 .60331 L
.66838 .60331 L
.66943 .60331 L
.6718 .6033 L
.67436 .60328 L
.6767 .60326 L
.68198 .60322 L
.70033 .60299 L
.72091 .6027 L
.74003 .60249 L
.75851 .60234 L
.76884 .60228 L
.77821 .60223 L
.81826 .60208 L
.8568 .60192 L
.89779 .6017 L
.93727 .6015 L
.97523 .60134 L
.97619 .60134 L
Mfstroke
0 .324 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16447 L
.04758 .19292 L
.05288 .21858 L
.06244 .25348 L
.06788 .26755 L
.07075 .27347 L
.07379 .27871 L
.07644 .2825 L
.07936 .28587 L
.08202 .28826 L
.08451 .28997 L
.08574 .29065 L
.0871 .29126 L
.08829 .29169 L
.08956 .29205 L
.09081 .29231 L
.09195 .29245 L
.0931 .29253 L
.09418 .29254 L
.09544 .29247 L
.09608 .29241 L
.09678 .29231 L
.09802 .29209 L
.09917 .29183 L
.10178 .29104 L
.10458 .28993 L
.10986 .2872 L
.11475 .28415 L
.12582 .27617 L
.14594 .26145 L
.15492 .25582 L
.16461 .25076 L
.17015 .24839 L
.17523 .24657 L
.18005 .24517 L
.1827 .24454 L
.18521 .24404 L
.18767 .24363 L
.18897 .24345 L
.19034 .24329 L
.1915 .24317 L
.19277 .24307 L
.19393 .243 L
.19501 .24295 L
.19619 .24292 L
.19731 .24291 L
.19831 .24292 L
.19941 .24295 L
Mistroke
.20059 .24301 L
.20186 .24309 L
.20305 .2432 L
.20413 .24331 L
.2068 .2437 L
.20926 .24417 L
.21195 .24482 L
.2148 .24569 L
.21958 .24757 L
.22483 .25036 L
.23009 .25407 L
.23506 .25861 L
.23953 .26378 L
.24438 .27085 L
.24966 .2807 L
.25526 .29413 L
.26531 .326 L
.27493 .3601 L
.28017 .37666 L
.28504 .38953 L
.28922 .39834 L
.29368 .40543 L
.29622 .40842 L
.29862 .41057 L
.30078 .41197 L
.30199 .41254 L
.30311 .41294 L
.30423 .41322 L
.30543 .41339 L
.30657 .41343 L
.3076 .41337 L
.30881 .41319 L
.31013 .41285 L
.31138 .4124 L
.31253 .41189 L
.31483 .4106 L
.31736 .40878 L
.3225 .40403 L
.33326 .39072 L
.34337 .37605 L
.36182 .34927 L
.37228 .33608 L
.38202 .32589 L
.39169 .31812 L
.39711 .31491 L
.40204 .31274 L
.40474 .31187 L
.40724 .31126 L
.40854 .31103 L
.40998 .31083 L
Mistroke
.4107 .31076 L
.41148 .3107 L
.41221 .31066 L
.41288 .31064 L
.41419 .31064 L
.4154 .3107 L
.41609 .31076 L
.41672 .31083 L
.41814 .31103 L
.41937 .31126 L
.42071 .31158 L
.42313 .31234 L
.4255 .31332 L
.42805 .31463 L
.43264 .31775 L
.43811 .32279 L
.44308 .32867 L
.4539 .3453 L
.46415 .36451 L
.48239 .40009 L
.49276 .41808 L
.5025 .43249 L
.52229 .45459 L
.53241 .46298 L
.5433 .47068 L
.58446 .49683 L
.62411 .5234 L
.64409 .53508 L
.66224 .54377 L
.68186 .55112 L
.70282 .55701 L
.72202 .56112 L
.74282 .56465 L
.78376 .56996 L
.82318 .57373 L
.86109 .57636 L
.88055 .57739 L
.90145 .57831 L
.94274 .57969 L
.97619 .58049 L
Mfstroke
0 .3 1 r
.02381 .01472 m
.03279 .09449 L
.04262 .1643 L
.04758 .19247 L
.05288 .21759 L
.05785 .23668 L
.06244 .25071 L
.06788 .26325 L
.07075 .26821 L
.07379 .27234 L
.07642 .27505 L
.07889 .2769 L
.0803 .27769 L
.08159 .27824 L
.08231 .27848 L
.08309 .27868 L
.08382 .27883 L
.08451 .27893 L
.08577 .27901 L
.08648 .27901 L
.08713 .27896 L
.08833 .27881 L
.0896 .27853 L
.09074 .27819 L
.0918 .27781 L
.09422 .27668 L
.09922 .27343 L
.10458 .26887 L
.12439 .24743 L
.14594 .2248 L
.15598 .21624 L
.16664 .20886 L
.17574 .20397 L
.18054 .20192 L
.18579 .2001 L
.1907 .19878 L
.19338 .19822 L
.19588 .1978 L
.19822 .1975 L
.19933 .19739 L
.20035 .1973 L
.20153 .19723 L
.20281 .19717 L
.20394 .19715 L
.20513 .19715 L
.20643 .19717 L
.20761 .19722 L
.20826 .19726 L
.20897 .19731 L
.21026 .19743 L
Mistroke
.21276 .19775 L
.21506 .19816 L
.21784 .19881 L
.22036 .19955 L
.22599 .20181 L
.23088 .20457 L
.23604 .20849 L
.24045 .21288 L
.24527 .21911 L
.25048 .228 L
.25606 .24072 L
.26611 .27312 L
.27574 .31039 L
.28596 .3446 L
.29129 .35776 L
.29412 .3633 L
.29717 .36818 L
.29996 .3717 L
.30251 .37417 L
.30495 .37589 L
.30618 .37654 L
.30752 .37709 L
.30882 .37747 L
.30955 .37762 L
.31022 .37772 L
.31146 .37781 L
.31277 .37777 L
.31394 .37764 L
.31504 .37743 L
.31624 .3771 L
.31753 .37665 L
.32039 .37532 L
.32311 .37368 L
.3282 .36978 L
.34742 .35037 L
.35706 .34091 L
.36234 .33659 L
.36493 .33479 L
.3673 .33337 L
.36931 .33236 L
.37151 .33148 L
.37266 .33112 L
.37372 .33086 L
.37485 .33065 L
.37605 .33052 L
.3773 .33049 L
.378 .33052 L
.37865 .33058 L
.37985 .33078 L
.38111 .33113 L
Mistroke
.38224 .33155 L
.3833 .33206 L
.38572 .33364 L
.38696 .33471 L
.38829 .33605 L
.39069 .33906 L
.39353 .34372 L
.39611 .34907 L
.40119 .36305 L
.40598 .38022 L
.42451 .45861 L
.43428 .49258 L
.4446 .51966 L
.45341 .53634 L
.45841 .54352 L
.46308 .5489 L
.46809 .5534 L
.47073 .55527 L
.47354 .55692 L
.47599 .55808 L
.47869 .55908 L
.47987 .55943 L
.48114 .55975 L
.48234 .55999 L
.48345 .56017 L
.48454 .56031 L
.4857 .56041 L
.48699 .56047 L
.48817 .56047 L
.48939 .56044 L
.49008 .56039 L
.49072 .56034 L
.49189 .56022 L
.49313 .56004 L
.49532 .55962 L
.49736 .55912 L
.50201 .55758 L
.50699 .55538 L
.51242 .55241 L
.52231 .54571 L
.54085 .52992 L
.58157 .4903 L
.62077 .45662 L
.66242 .42641 L
.70256 .39933 L
.74119 .37643 L
.76079 .36682 L
.78226 .35804 L
.82182 .34615 L
.84138 .34186 L
Mistroke
.86232 .33812 L
.88218 .33519 L
.90375 .33256 L
.92312 .33061 L
.94367 .32892 L
.97619 .32696 L
Mfstroke
0 .277 1 r
.02381 .01472 m
.02846 .05748 L
.03279 .09073 L
.03527 .10535 L
.03754 .11529 L
.03879 .1194 L
.03945 .12118 L
.04015 .12278 L
.04143 .12501 L
.04262 .12632 L
.04384 .12701 L
.04496 .12711 L
.04626 .12671 L
.04749 .12589 L
.04862 .12481 L
.04967 .12359 L
.05205 .12022 L
.06244 .10141 L
.07382 .08151 L
.08454 .06635 L
.09417 .05571 L
.10458 .04686 L
.11449 .04049 L
.12496 .03542 L
.1339 .03215 L
.14371 .0294 L
.15391 .02727 L
.16322 .02581 L
.17396 .02456 L
.18413 .0237 L
.19379 .0231 L
.20404 .02264 L
.2128 .02236 L
.21778 .02224 L
.22246 .02215 L
.22716 .02208 L
.23229 .02202 L
.23489 .02199 L
.23631 .02198 L
.23766 .02198 L
.23891 .02197 L
.24027 .02197 L
.24151 .02196 L
.24265 .02196 L
.24371 .02196 L
.24486 .02196 L
.24594 .02196 L
.24693 .02196 L
.24808 .02196 L
.24934 .02197 L
Mistroke
.25163 .02198 L
.25403 .022 L
.25657 .02202 L
.26115 .02208 L
.27089 .02223 L
.27621 .02233 L
.28116 .0224 L
.28398 .02244 L
.28654 .02246 L
.288 .02247 L
.28939 .02248 L
.29009 .02248 L
.29085 .02248 L
.29167 .02249 L
.29243 .02249 L
.29366 .02249 L
.29497 .02249 L
.29622 .02249 L
.29736 .02248 L
.29862 .02248 L
.3 .02247 L
.30279 .02245 L
.30806 .0224 L
.31285 .02234 L
.32358 .02219 L
.3429 .0219 L
.36213 .02167 L
.37296 .02157 L
.38294 .02151 L
.38763 .02148 L
.39266 .02146 L
.39701 .02144 L
.40174 .02143 L
.40728 .02142 L
.40983 .02141 L
.41254 .02141 L
.41497 .02141 L
.41766 .0214 L
.41883 .0214 L
.4201 .0214 L
.42128 .0214 L
.42239 .0214 L
.42365 .0214 L
.42478 .0214 L
.42601 .0214 L
.4267 .0214 L
.42734 .0214 L
.42841 .0214 L
.42958 .0214 L
.4308 .0214 L
Mistroke
.43195 .0214 L
.43458 .0214 L
.43699 .0214 L
.44241 .0214 L
.44771 .02141 L
.45335 .02141 L
.45609 .02141 L
.45867 .02141 L
.4598 .02141 L
.46099 .02141 L
.4623 .02141 L
.4635 .02141 L
.46468 .02141 L
.46576 .02141 L
.46701 .02141 L
.46819 .02141 L
.46928 .02141 L
.47028 .02141 L
.47256 .02141 L
.47485 .02141 L
.47738 .02141 L
.4825 .0214 L
.48765 .0214 L
.49319 .02139 L
.50323 .02138 L
.52289 .02134 L
.54439 .0213 L
.56493 .02126 L
.58403 .02124 L
.59457 .02124 L
.60451 .02123 L
.6231 .02122 L
.66158 .0212 L
.70252 .02119 L
.7229 .02119 L
.74195 .02118 L
.77985 .02118 L
.80016 .02118 L
.8187 .02117 L
.85848 .02117 L
.89674 .02117 L
.93746 .02117 L
.97619 .02117 L
Mfstroke
0 .253 1 r
.02381 .01472 m
.03279 .09442 L
.04262 .16306 L
.04758 .18975 L
.05288 .21255 L
.05789 .22893 L
.06244 .23985 L
.06507 .24457 L
.06785 .24842 L
.07022 .25085 L
.07157 .25191 L
.07283 .25269 L
.07353 .25304 L
.07428 .25336 L
.07495 .25359 L
.07567 .25379 L
.07637 .25392 L
.07701 .254 L
.07826 .25405 L
.07901 .254 L
.07971 .25392 L
.08047 .25378 L
.08127 .25357 L
.08262 .25312 L
.0841 .25246 L
.08678 .2509 L
.08922 .24911 L
.09469 .24405 L
.10458 .23264 L
.12528 .20666 L
.14443 .18641 L
.16301 .17234 L
.1724 .16731 L
.17744 .16515 L
.18275 .16326 L
.18757 .16189 L
.19012 .16129 L
.19285 .16075 L
.19536 .16035 L
.19764 .16005 L
.19874 .15993 L
.19994 .15983 L
.20098 .15975 L
.2021 .15968 L
.2034 .15963 L
.20461 .1596 L
.20535 .15959 L
.20605 .1596 L
.20737 .15962 L
.20804 .15964 L
Mistroke
.20876 .15967 L
.21004 .15974 L
.21157 .15987 L
.21295 .16001 L
.21543 .16035 L
.21811 .16084 L
.22296 .16209 L
.22534 .16289 L
.22789 .16391 L
.23249 .1662 L
.23796 .16989 L
.24294 .17444 L
.24813 .18079 L
.25377 .19021 L
.25909 .20215 L
.26401 .21605 L
.27379 .24884 L
.27891 .26559 L
.28431 .28054 L
.28905 .29065 L
.29174 .295 L
.29424 .29815 L
.29542 .29935 L
.29654 .30032 L
.29756 .30106 L
.29864 .3017 L
.29981 .30224 L
.30089 .3026 L
.30205 .30283 L
.30333 .30292 L
.30454 .30285 L
.30586 .3026 L
.30711 .30222 L
.30826 .30174 L
.31044 .30054 L
.31276 .29887 L
.31757 .2943 L
.32287 .28793 L
.34113 .26093 L
.36208 .23066 L
.37126 .21954 L
.38131 .20924 L
.3904 .20162 L
.40013 .19518 L
.4104 .19009 L
.41996 .18658 L
.43019 .18369 L
.44128 .18116 L
.45087 .17934 L
.45596 .17852 L
Mistroke
.46143 .17776 L
.46678 .17715 L
.47168 .17671 L
.47403 .17655 L
.4766 .17639 L
.47901 .17628 L
.48128 .17619 L
.48261 .17615 L
.48405 .17612 L
.48536 .17609 L
.48656 .17608 L
.48787 .17607 L
.48861 .17606 L
.4893 .17606 L
.49003 .17606 L
.49069 .17607 L
.49146 .17607 L
.49219 .17608 L
.49341 .17609 L
.49471 .17611 L
.49704 .17616 L
.49955 .17623 L
.50231 .17632 L
.51242 .1768 L
.52167 .17736 L
.54254 .17888 L
.56147 .18063 L
.57233 .1819 L
.58218 .18331 L
.60181 .18702 L
.62276 .19253 L
.66276 .20691 L
.70125 .22265 L
.74219 .23849 L
.78161 .25253 L
.81952 .26529 L
.85988 .27785 L
.89872 .2885 L
.94002 .29805 L
.97619 .30497 L
Mfstroke
0 .229 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03477 L
.02729 .04318 L
.02846 .04892 L
.02954 .05246 L
.03053 .05452 L
.03163 .0558 L
.03279 .05637 L
.03395 .0564 L
.0352 .05604 L
.03638 .05545 L
.03746 .05477 L
.04262 .0507 L
.0529 .04241 L
.06244 .03609 L
.07277 .03082 L
.08405 .02659 L
.09398 .02385 L
.10458 .0217 L
.11487 .02017 L
.12599 .01897 L
.1365 .01816 L
.14616 .01761 L
.1559 .01719 L
.16499 .01691 L
.17496 .01667 L
.18565 .01648 L
.19582 .01636 L
.20119 .01631 L
.20689 .01626 L
.21186 .01623 L
.21734 .01619 L
.22701 .01615 L
.23193 .01614 L
.2371 .01612 L
.24152 .01611 L
.24636 .01611 L
.24909 .0161 L
.25158 .0161 L
.25296 .0161 L
.25445 .0161 L
.25574 .0161 L
.25716 .0161 L
.25847 .0161 L
.2597 .0161 L
.261 .0161 L
.26173 .0161 L
.26239 .0161 L
.26358 .0161 L
Mistroke
.26487 .0161 L
.26608 .0161 L
.26721 .0161 L
.27231 .0161 L
.27498 .0161 L
.27645 .0161 L
.27781 .0161 L
.27901 .0161 L
.28029 .0161 L
.28102 .0161 L
.28171 .0161 L
.283 .0161 L
.28419 .0161 L
.28529 .0161 L
.2865 .0161 L
.28778 .0161 L
.28998 .0161 L
.29235 .0161 L
.29663 .01609 L
.30173 .01609 L
.3064 .01609 L
.32696 .01606 L
.34607 .01604 L
.35557 .01604 L
.36453 .01603 L
.37486 .01602 L
.38423 .01602 L
.38888 .01602 L
.39398 .01602 L
.39931 .01602 L
.40186 .01602 L
.40429 .01602 L
.40652 .01602 L
.40894 .01602 L
.41115 .01602 L
.41319 .01602 L
.41433 .01602 L
.41539 .01602 L
.41656 .01602 L
.41783 .01602 L
.41908 .01602 L
.42039 .01602 L
.42152 .01602 L
.42275 .01602 L
.42407 .01602 L
.42528 .01602 L
.42803 .01602 L
.43301 .01602 L
.44234 .01602 L
.44755 .01602 L
Mistroke
.45315 .01602 L
.45835 .01602 L
.46091 .01602 L
.46328 .01602 L
.46555 .01602 L
.46681 .01602 L
.46796 .01602 L
.46922 .01602 L
.46994 .01602 L
.47059 .01602 L
.4718 .01602 L
.47307 .01602 L
.47413 .01602 L
.47528 .01602 L
.47734 .01602 L
.47979 .01602 L
.48202 .01602 L
.4871 .01602 L
.49262 .01602 L
.50265 .01602 L
.54345 .01601 L
.56372 .01601 L
.58274 .01601 L
.60092 .01601 L
.62051 .016 L
.64056 .016 L
.66167 .016 L
.6998 .016 L
.72106 .016 L
.74038 .016 L
.77944 .016 L
.79864 .016 L
.81945 .016 L
.86038 .016 L
.89981 .016 L
.93771 .016 L
.97619 .016 L
Mfstroke
0 .206 1 r
.02381 .01472 m
.03279 .09448 L
.04262 .16382 L
.04758 .19112 L
.05288 .21454 L
.05789 .23126 L
.06244 .24216 L
.06507 .24668 L
.0665 .24865 L
.06785 .25018 L
.06908 .25133 L
.07022 .25218 L
.07148 .25289 L
.07217 .25319 L
.07283 .25341 L
.07354 .25358 L
.07418 .25368 L
.07493 .25373 L
.07563 .25371 L
.07687 .25353 L
.07757 .25335 L
.07822 .25314 L
.07958 .25255 L
.08108 .25168 L
.0841 .24932 L
.08922 .24378 L
.09469 .23629 L
.10458 .22057 L
.12439 .18866 L
.13484 .17418 L
.14594 .16126 L
.15578 .15193 L
.16664 .14379 L
.17651 .13815 L
.18579 .13423 L
.19048 .13272 L
.19562 .1314 L
.19821 .13087 L
.20098 .1304 L
.20359 .13005 L
.20597 .12981 L
.20712 .12972 L
.20835 .12965 L
.20939 .1296 L
.21054 .12956 L
.21177 .12955 L
.21246 .12955 L
.21309 .12955 L
.21432 .12958 L
.21549 .12963 L
Mistroke
.21657 .12969 L
.21772 .12977 L
.21979 .12998 L
.22225 .13032 L
.22447 .13072 L
.22936 .13194 L
.23183 .13276 L
.23452 .13384 L
.2393 .13631 L
.24376 .13939 L
.24902 .14433 L
.25382 .15049 L
.25936 .1602 L
.26459 .17241 L
.27338 .19842 L
.28285 .22681 L
.28827 .23975 L
.29064 .24433 L
.29324 .24853 L
.29553 .25155 L
.29798 .25408 L
.29934 .25517 L
.30057 .25599 L
.30181 .25664 L
.30297 .2571 L
.30412 .25743 L
.30538 .25764 L
.3067 .25769 L
.30793 .25761 L
.30908 .25741 L
.31013 .25714 L
.31134 .25672 L
.31249 .25623 L
.31505 .25481 L
.31742 .25314 L
.32279 .24836 L
.34381 .22302 L
.35354 .21117 L
.36404 .20006 L
.36886 .19578 L
.37395 .19193 L
.37871 .18903 L
.38304 .18708 L
.38415 .18669 L
.38536 .18633 L
.3864 .18607 L
.38755 .18584 L
.38877 .18567 L
.39005 .18557 L
.39125 .18555 L
Mistroke
.39237 .18561 L
.39349 .18575 L
.39455 .18596 L
.39551 .18621 L
.39655 .18655 L
.39768 .18703 L
.39888 .18764 L
.40105 .18908 L
.40361 .1914 L
.40637 .19477 L
.40899 .19892 L
.41139 .20366 L
.41595 .21541 L
.42076 .23199 L
.44064 .32904 L
.44932 .37016 L
.45875 .40659 L
.46396 .42253 L
.46878 .43461 L
.47339 .44385 L
.47828 .45128 L
.48075 .45414 L
.48341 .45657 L
.48463 .45747 L
.48592 .45827 L
.48713 .45889 L
.48822 .45934 L
.48954 .45975 L
.49026 .45991 L
.49094 .46002 L
.49215 .46013 L
.49347 .4601 L
.49416 .46004 L
.49491 .45992 L
.49571 .45975 L
.49645 .45955 L
.49777 .45909 L
.4992 .45845 L
.50175 .45695 L
.50446 .45486 L
.50934 .44996 L
.52039 .43419 L
.54049 .3952 L
.56052 .35352 L
.58215 .31444 L
.60307 .28549 L
.62229 .26577 L
.64116 .25095 L
.66185 .23792 L
.70234 .21751 L
Mistroke
.74132 .20244 L
.76262 .19613 L
.78276 .19135 L
.80103 .18789 L
.82116 .18487 L
.84099 .18252 L
.86201 .18054 L
.88304 .17895 L
.90229 .17775 L
.92082 .1768 L
.94105 .17595 L
.97619 .17488 L
Mfstroke
0 .182 1 r
.02381 .01472 m
.03279 .09449 L
.04262 .16434 L
.04758 .1925 L
.05288 .21754 L
.05785 .23641 L
.06244 .25007 L
.06788 .26194 L
.07075 .26644 L
.07221 .26832 L
.07379 .27002 L
.07516 .27126 L
.07642 .27219 L
.0777 .27296 L
.07889 .2735 L
.07961 .27377 L
.08027 .27396 L
.08099 .27412 L
.08177 .27423 L
.08245 .27429 L
.08318 .2743 L
.08387 .27426 L
.08451 .27419 L
.08567 .27398 L
.08691 .27364 L
.08809 .2732 L
.08916 .27272 L
.09178 .27122 L
.09427 .26942 L
.10458 .2591 L
.14291 .21213 L
.16268 .1947 L
.17267 .18843 L
.17804 .18575 L
.18369 .18342 L
.18851 .18183 L
.19106 .18114 L
.19378 .18051 L
.1963 .18004 L
.19858 .17969 L
.19968 .17956 L
.20087 .17943 L
.20192 .17934 L
.20304 .17926 L
.20434 .1792 L
.20555 .17916 L
.20629 .17915 L
.20699 .17915 L
.20831 .17918 L
.20898 .1792 L
Mistroke
.20969 .17923 L
.21098 .17932 L
.21251 .17946 L
.21389 .17962 L
.21637 .18002 L
.21904 .18058 L
.22389 .18203 L
.22628 .18296 L
.22883 .18415 L
.23342 .18683 L
.23889 .19115 L
.24387 .19647 L
.24906 .20391 L
.2547 .21489 L
.26003 .22868 L
.26495 .24449 L
.27472 .28085 L
.27985 .29926 L
.28524 .31599 L
.28999 .3278 L
.2925 .33285 L
.29517 .33733 L
.29765 .34065 L
.29989 .34301 L
.30097 .34394 L
.30214 .34479 L
.30325 .34546 L
.30427 .34595 L
.30541 .34637 L
.30663 .34668 L
.30776 .34684 L
.30883 .34687 L
.31007 .34679 L
.31122 .34659 L
.31249 .34625 L
.31383 .34575 L
.31631 .34449 L
.31864 .34294 L
.32395 .33831 L
.34207 .31595 L
.36052 .29281 L
.36558 .28771 L
.37099 .28321 L
.37361 .28145 L
.37609 .28007 L
.37831 .27911 L
.37957 .27868 L
.38073 .27837 L
.38188 .27814 L
.38312 .278 L
Mistroke
.38428 .27796 L
.38535 .27802 L
.3866 .2782 L
.38731 .27836 L
.38796 .27854 L
.38917 .27899 L
.39045 .27962 L
.39178 .28046 L
.39323 .28159 L
.39585 .28433 L
.3984 .28793 L
.40074 .29217 L
.40563 .30431 L
.411 .32303 L
.42183 .3728 L
.4327 .42404 L
.44299 .46437 L
.45223 .4923 L
.45701 .50387 L
.46228 .51458 L
.47209 .52948 L
.47746 .53523 L
.4825 .5393 L
.48479 .54077 L
.4872 .54207 L
.48928 .543 L
.49151 .54382 L
.49391 .54451 L
.49614 .54497 L
.49751 .54517 L
.4988 .54531 L
.49995 .5454 L
.50121 .54545 L
.50244 .54545 L
.50357 .54542 L
.50487 .54535 L
.5061 .54524 L
.50724 .54511 L
.50829 .54496 L
.51068 .54454 L
.51573 .54328 L
.5211 .54148 L
.54215 .5318 L
.56217 .52196 L
.5727 .51752 L
.5838 .51358 L
.60472 .50803 L
.62394 .504 L
.66198 .4945 L
.68155 .48775 L
Mistroke
.70248 .47941 L
.74391 .46234 L
.78383 .44881 L
.82223 .43943 L
.86309 .43225 L
.90242 .42708 L
.92064 .42517 L
.94025 .42343 L
.97619 .42107 L
Mfstroke
0 .158 1 r
.02381 .01472 m
.03279 .09449 L
.04262 .16437 L
.04758 .19265 L
.05288 .21796 L
.05785 .23733 L
.06244 .25173 L
.06788 .26484 L
.07075 .27018 L
.07379 .27476 L
.07624 .27772 L
.07889 .28021 L
.0804 .28133 L
.08179 .28218 L
.0831 .28284 L
.08451 .28338 L
.0852 .28359 L
.08585 .28376 L
.08706 .28398 L
.0882 .28411 L
.08943 .28414 L
.09008 .28412 L
.09079 .28407 L
.09153 .28398 L
.09222 .28387 L
.09347 .28361 L
.0948 .28325 L
.09743 .28228 L
.09991 .28108 L
.10458 .27827 L
.14291 .24568 L
.16268 .23232 L
.17267 .22756 L
.17835 .22549 L
.18369 .22397 L
.18839 .22297 L
.19105 .22256 L
.19352 .22227 L
.19487 .22215 L
.19615 .22207 L
.19729 .22201 L
.19853 .22198 L
.19917 .22197 L
.19988 .22197 L
.20062 .22198 L
.20131 .22199 L
.20255 .22204 L
.20324 .22208 L
.20387 .22212 L
.20502 .22222 L
Mistroke
.20623 .22234 L
.20842 .22264 L
.21101 .22311 L
.21337 .22366 L
.21801 .2251 L
.22238 .22694 L
.22705 .22951 L
.23217 .23322 L
.23751 .23831 L
.2425 .24452 L
.24717 .25198 L
.25142 .26049 L
.26098 .2867 L
.27104 .32252 L
.27655 .34202 L
.28172 .3581 L
.28648 .37023 L
.29083 .37883 L
.29319 .38247 L
.29567 .38555 L
.29816 .38788 L
.29957 .38888 L
.30088 .38961 L
.30213 .39014 L
.30329 .39048 L
.30455 .39069 L
.30519 .39074 L
.30589 .39075 L
.30707 .39066 L
.30833 .39043 L
.30953 .39008 L
.31061 .38966 L
.31279 .38856 L
.31515 .38697 L
.31945 .3832 L
.32974 .37079 L
.33926 .35698 L
.35949 .32773 L
.3694 .31578 L
.37374 .31132 L
.3785 .30707 L
.38276 .30386 L
.38733 .30113 L
.38985 .29996 L
.39215 .29912 L
.39326 .2988 L
.39446 .29851 L
.39559 .2983 L
.39664 .29816 L
.39776 .29807 L
Mistroke
.39898 .29805 L
.40012 .2981 L
.40116 .29822 L
.40238 .29842 L
.40308 .29858 L
.40372 .29876 L
.40614 .29965 L
.40746 .3003 L
.4087 .30102 L
.41102 .30269 L
.41351 .30497 L
.41621 .30804 L
.42114 .31542 L
.42573 .32455 L
.43617 .35312 L
.45724 .42643 L
.4677 .45923 L
.4776 .48483 L
.48643 .50307 L
.49617 .51876 L
.50583 .53053 L
.51609 .53983 L
.5256 .54633 L
.53451 .55116 L
.57322 .56619 L
.59288 .57254 L
.61438 .5784 L
.62432 .5806 L
.63492 .58255 L
.64486 .58402 L
.65403 .58509 L
.66428 .586 L
.66957 .58636 L
.67539 .5867 L
.68518 .58712 L
.69054 .58729 L
.69554 .58741 L
.70053 .58751 L
.70596 .5876 L
.71109 .58766 L
.71585 .5877 L
.72056 .58773 L
.72483 .58776 L
.73439 .5878 L
.77453 .58792 L
.79296 .58797 L
.79801 .58798 L
.80341 .58799 L
.80603 .58799 L
.80851 .588 L
Mistroke
.81073 .588 L
.81198 .588 L
.81315 .588 L
.81431 .588 L
.81555 .588 L
.81626 .588 L
.81693 .588 L
.81819 .588 L
.81884 .588 L
.81952 .588 L
.82075 .588 L
.8215 .588 L
.82221 .588 L
.82354 .588 L
.82594 .588 L
.82815 .58799 L
.83314 .58799 L
.83803 .58797 L
.84339 .58796 L
.85422 .58791 L
.87373 .58779 L
.89464 .58763 L
.93599 .58727 L
.97582 .5869 L
.97619 .5869 L
Mfstroke
0 .134 1 r
.02381 .01472 m
.02846 .05778 L
.03279 .09367 L
.03754 .12612 L
.0402 .14027 L
.04262 .15035 L
.04385 .15444 L
.04516 .15802 L
.04629 .16049 L
.0475 .16255 L
.04881 .16409 L
.05003 .16496 L
.05077 .16523 L
.05148 .16532 L
.05212 .16527 L
.05281 .16508 L
.05408 .16441 L
.05523 .16346 L
.05656 .16202 L
.05781 .16038 L
.06244 .15247 L
.08439 .10652 L
.09401 .08983 L
.10458 .07511 L
.11427 .06453 L
.12333 .05676 L
.13288 .05034 L
.14313 .04508 L
.1533 .04115 L
.16437 .03798 L
.17482 .03579 L
.18449 .0343 L
.19412 .03321 L
.20316 .03246 L
.20833 .03214 L
.21307 .0319 L
.21828 .03169 L
.2211 .0316 L
.22376 .03154 L
.22616 .03149 L
.22742 .03147 L
.22876 .03145 L
.22988 .03144 L
.23112 .03143 L
.23225 .03142 L
.2333 .03142 L
.23462 .03142 L
.23587 .03142 L
.23699 .03142 L
.23822 .03143 L
Mistroke
.23891 .03144 L
.23955 .03144 L
.24096 .03146 L
.2435 .03151 L
.24587 .03157 L
.24805 .03163 L
.25296 .03184 L
.2573 .03208 L
.26187 .03241 L
.27209 .03335 L
.27712 .03384 L
.28177 .03424 L
.28598 .03452 L
.28811 .03463 L
.29045 .03472 L
.29168 .03476 L
.2928 .03479 L
.29403 .03481 L
.29532 .03483 L
.29646 .03483 L
.29751 .03483 L
.29866 .03483 L
.29989 .03482 L
.30121 .0348 L
.30242 .03478 L
.30517 .03471 L
.30758 .03463 L
.31014 .03452 L
.31944 .03403 L
.34037 .03273 L
.35055 .03216 L
.3602 .03168 L
.37831 .03101 L
.38764 .03076 L
.39779 .03057 L
.40305 .03049 L
.40865 .03043 L
.41342 .03038 L
.4187 .03035 L
.4236 .03032 L
.42628 .03031 L
.42877 .0303 L
.43319 .03029 L
.43802 .03028 L
.44874 .03027 L
.45401 .03026 L
.45887 .03025 L
.46363 .03024 L
.46867 .03022 L
.4793 .03016 L
Mistroke
.49788 .03003 L
.53574 .02975 L
.55516 .02964 L
.56607 .02959 L
.57604 .02956 L
.59504 .02951 L
.6058 .02949 L
.61577 .02947 L
.63631 .02945 L
.65492 .02943 L
.67418 .02942 L
.69501 .02941 L
.71496 .0294 L
.72513 .0294 L
.73603 .02939 L
.74632 .02939 L
.75569 .02939 L
.76458 .02939 L
.77402 .02939 L
.78395 .02939 L
.79312 .02939 L
.79822 .02939 L
.803 .02939 L
.80824 .02939 L
.81119 .02939 L
.81389 .02939 L
.81638 .02939 L
.81864 .02939 L
.81989 .02939 L
.82055 .02939 L
.82124 .02939 L
.82252 .02939 L
.8237 .02939 L
.82479 .02939 L
.82595 .02939 L
.82705 .02939 L
.82805 .02939 L
.82922 .02939 L
.8305 .02939 L
.83283 .02939 L
.83556 .02939 L
.83803 .02939 L
.84357 .02939 L
.85353 .02939 L
.87283 .02939 L
.89367 .02939 L
.93475 .02939 L
.97431 .02939 L
.97619 .02939 L
Mfstroke
0 .111 1 r
.02381 .01472 m
.02846 .05737 L
.03279 .08998 L
.03527 .10405 L
.03754 .11353 L
.03879 .11746 L
.04015 .12071 L
.04143 .1229 L
.04262 .12424 L
.04376 .12498 L
.04498 .12526 L
.04614 .12508 L
.0472 .12461 L
.04843 .12374 L
.04978 .12246 L
.05224 .11944 L
.06244 .10276 L
.08284 .07149 L
.09424 .05887 L
.10458 .05014 L
.11463 .04365 L
.12551 .03836 L
.13578 .03464 L
.14523 .03204 L
.15496 .03001 L
.16405 .02857 L
.17402 .02738 L
.18471 .02644 L
.19489 .0258 L
.20063 .02552 L
.20595 .02532 L
.21098 .02516 L
.21571 .02503 L
.22064 .02493 L
.22345 .02489 L
.22607 .02486 L
.22834 .02483 L
.23077 .02481 L
.23215 .02481 L
.23346 .0248 L
.23463 .0248 L
.23591 .02479 L
.23715 .02479 L
.23786 .02479 L
.23852 .0248 L
.23922 .0248 L
.23986 .0248 L
.24129 .02481 L
.24251 .02481 L
.24384 .02482 L
Mistroke
.24626 .02485 L
.2487 .02488 L
.25091 .02492 L
.25586 .02502 L
.26045 .02516 L
.26476 .02532 L
.27366 .0257 L
.27855 .02591 L
.28318 .02608 L
.2858 .02616 L
.28864 .02623 L
.2899 .02625 L
.29123 .02627 L
.29248 .02629 L
.29362 .0263 L
.29478 .02631 L
.29601 .02632 L
.29711 .02632 L
.29826 .02633 L
.29952 .02633 L
.3007 .02632 L
.30199 .02632 L
.30271 .02631 L
.30336 .02631 L
.30593 .02628 L
.3083 .02625 L
.31365 .02615 L
.32334 .02592 L
.34442 .02535 L
.36322 .02494 L
.3739 .02476 L
.38387 .02465 L
.38887 .0246 L
.39151 .02458 L
.39431 .02457 L
.39675 .02456 L
.39805 .02455 L
.39945 .02455 L
.40072 .02455 L
.4019 .02455 L
.40302 .02454 L
.4042 .02454 L
.40536 .02455 L
.40642 .02455 L
.40764 .02455 L
.40879 .02455 L
.41084 .02456 L
.41306 .02457 L
.4155 .02459 L
.4181 .02461 L
Mistroke
.42275 .02466 L
.42767 .02472 L
.43217 .0248 L
.4423 .025 L
.45116 .02519 L
.46061 .02538 L
.46578 .02546 L
.47046 .02551 L
.47272 .02554 L
.47517 .02556 L
.47748 .02557 L
.47961 .02558 L
.48081 .02559 L
.48209 .02559 L
.48331 .02559 L
.48441 .02559 L
.48571 .02559 L
.48644 .02559 L
.48712 .02559 L
.48837 .02559 L
.48969 .02559 L
.49095 .02559 L
.4923 .02558 L
.49475 .02557 L
.49766 .02555 L
.50033 .02553 L
.51015 .02544 L
.51927 .02533 L
.53998 .02505 L
.55873 .02481 L
.57904 .02459 L
.60041 .02442 L
.62056 .02431 L
.64045 .02422 L
.6615 .02416 L
.68109 .02411 L
.69941 .02408 L
.73825 .02402 L
.75944 .024 L
.77955 .02398 L
.79963 .02396 L
.81781 .02395 L
.83754 .02394 L
.85853 .02394 L
.87945 .02393 L
.89867 .02393 L
.93729 .02392 L
.95585 .02392 L
.97619 .02392 L
Mfstroke
0 .087 1 r
.02381 .01472 m
.02846 .0578 L
.03279 .09394 L
.03793 .12998 L
.04262 .1545 L
.04498 .16355 L
.04622 .16742 L
.04754 .17085 L
.04869 .1733 L
.04996 .17543 L
.05112 .17687 L
.0522 .17782 L
.05352 .17849 L
.05478 .17866 L
.0559 .17845 L
.05713 .17788 L
.05783 .17741 L
.05847 .17689 L
.05989 .17546 L
.06244 .17209 L
.06787 .16251 L
.07287 .15217 L
.08414 .12813 L
.09471 .10803 L
.10458 .09246 L
.11443 .07991 L
.1234 .07075 L
.13338 .06273 L
.14407 .05614 L
.15398 .05151 L
.16315 .04822 L
.17322 .04548 L
.18391 .04334 L
.19328 .04199 L
.19855 .0414 L
.20338 .04096 L
.208 .04062 L
.21229 .04037 L
.21677 .04016 L
.21913 .04008 L
.22166 .04002 L
.2229 .03999 L
.22425 .03997 L
.22493 .03996 L
.22567 .03995 L
.2263 .03994 L
.22699 .03994 L
.22831 .03993 L
.22956 .03994 L
.23078 .03994 L
Mistroke
.23191 .03995 L
.2326 .03996 L
.23336 .03997 L
.23473 .03999 L
.23728 .04006 L
.23874 .04011 L
.24027 .04017 L
.24301 .04031 L
.24798 .04065 L
.25262 .0411 L
.25771 .04176 L
.26316 .04269 L
.27279 .0448 L
.27807 .04598 L
.28301 .04693 L
.28579 .04737 L
.28834 .04768 L
.29117 .04795 L
.29266 .04805 L
.29348 .0481 L
.29422 .04813 L
.29546 .04818 L
.29614 .04819 L
.29678 .0482 L
.29793 .04822 L
.29917 .04821 L
.29982 .04821 L
.30054 .0482 L
.30128 .04818 L
.30198 .04816 L
.30323 .04811 L
.30457 .04805 L
.30724 .04789 L
.3097 .0477 L
.31528 .04716 L
.32544 .04596 L
.34447 .04356 L
.36311 .04161 L
.37373 .04076 L
.38371 .04013 L
.39352 .03965 L
.39888 .03944 L
.40386 .03928 L
.41269 .03906 L
.41737 .03898 L
.42236 .0389 L
.43259 .03879 L
.44368 .0387 L
.45327 .03861 L
.46383 .03851 L
Mistroke
.48368 .03823 L
.50471 .0379 L
.52577 .0376 L
.54502 .03739 L
.55453 .03731 L
.56491 .03724 L
.57465 .03719 L
.58381 .03715 L
.59414 .03711 L
.6035 .03709 L
.61358 .03707 L
.61926 .03706 L
.62448 .03706 L
.62918 .03705 L
.63422 .03705 L
.63667 .03705 L
.63898 .03705 L
.64104 .03705 L
.64332 .03705 L
.64581 .03705 L
.64718 .03705 L
.64846 .03705 L
.64966 .03705 L
.65075 .03705 L
.65195 .03705 L
.65322 .03705 L
.65451 .03705 L
.65523 .03705 L
.65588 .03705 L
.65716 .03705 L
.65836 .03705 L
.66106 .03705 L
.66399 .03705 L
.66888 .03705 L
.67346 .03705 L
.68388 .03706 L
.70492 .03707 L
.74377 .03711 L
.78506 .03715 L
.82485 .03719 L
.86311 .03723 L
.90383 .03727 L
.94303 .0373 L
.97619 .03733 L
Mfstroke
0 .063 1 r
.02381 .01472 m
.03279 .0945 L
.04262 .16464 L
.04758 .19331 L
.05288 .21934 L
.06244 .2551 L
.06788 .26967 L
.07075 .27584 L
.07379 .28134 L
.07644 .28531 L
.07936 .28886 L
.08202 .29139 L
.08451 .29321 L
.08574 .29392 L
.0871 .29457 L
.08829 .29503 L
.08956 .29541 L
.09081 .29569 L
.09195 .29584 L
.0931 .29593 L
.09418 .29593 L
.09544 .29586 L
.09608 .29579 L
.09678 .29569 L
.09802 .29546 L
.09917 .29517 L
.10178 .29432 L
.10458 .29312 L
.10986 .29019 L
.11475 .28689 L
.12582 .27825 L
.14594 .26225 L
.15492 .25609 L
.16461 .25052 L
.17015 .24789 L
.17523 .24585 L
.18005 .24426 L
.1827 .24352 L
.18521 .24293 L
.18767 .24244 L
.19034 .24201 L
.19152 .24185 L
.19277 .24171 L
.19394 .2416 L
.19501 .24152 L
.19609 .24146 L
.19725 .24142 L
.19833 .2414 L
.19935 .24139 L
.20054 .24141 L
Mistroke
.20164 .24146 L
.20285 .24153 L
.20413 .24163 L
.20553 .24178 L
.20682 .24194 L
.20973 .24244 L
.21229 .24303 L
.21499 .2438 L
.21969 .24557 L
.22483 .2482 L
.23009 .2518 L
.23506 .25625 L
.23953 .26133 L
.24438 .26832 L
.24966 .27811 L
.25526 .29152 L
.26531 .32365 L
.27493 .35849 L
.28017 .37562 L
.28504 .3891 L
.28957 .39918 L
.29368 .40624 L
.29587 .4092 L
.29824 .4118 L
.29955 .41297 L
.30075 .41389 L
.30189 .41463 L
.30311 .41528 L
.30432 .41578 L
.30543 .41612 L
.30655 .41635 L
.3076 .41647 L
.30883 .4165 L
.30996 .41641 L
.31121 .4162 L
.31184 .41605 L
.31253 .41585 L
.315 .41489 L
.31767 .41341 L
.3225 .40977 L
.33338 .39826 L
.34337 .38565 L
.35327 .37303 L
.36387 .36096 L
.36901 .35604 L
.37387 .35215 L
.37823 .34939 L
.38069 .34819 L
.38187 .34771 L
.38296 .34733 L
Mistroke
.38401 .34702 L
.38515 .34676 L
.38636 .34655 L
.3875 .34643 L
.38857 .34639 L
.38971 .34643 L
.39078 .34655 L
.39176 .34673 L
.39301 .34705 L
.39416 .34746 L
.39542 .34803 L
.39675 .34877 L
.39899 .35039 L
.40145 .35274 L
.404 .35587 L
.40634 .35939 L
.41158 .36977 L
.41644 .38249 L
.42103 .39694 L
.43927 .46326 L
.44965 .49682 L
.45938 .52219 L
.46891 .54143 L
.47917 .5569 L
.48452 .56316 L
.49014 .56865 L
.50019 .57616 L
.50974 .58121 L
.51994 .58503 L
.52957 .58766 L
.53831 .58953 L
.55913 .59301 L
.57832 .59568 L
.5982 .598 L
.60792 .5989 L
.6168 .59957 L
.62586 .60011 L
.6309 .60034 L
.63558 .60051 L
.64065 .60066 L
.64355 .60072 L
.64617 .60077 L
.64868 .60081 L
.65104 .60083 L
.65234 .60084 L
.65353 .60085 L
.65484 .60086 L
.6555 .60086 L
.65623 .60086 L
.65754 .60086 L
Mistroke
.65875 .60086 L
.65938 .60086 L
.66008 .60086 L
.66081 .60086 L
.66149 .60086 L
.66274 .60085 L
.66389 .60085 L
.66647 .60083 L
.66875 .60081 L
.67124 .60078 L
.67579 .60071 L
.68664 .6005 L
.69672 .60027 L
.73584 .5993 L
.7558 .5989 L
.77741 .59857 L
.81746 .59809 L
.85845 .59763 L
.89793 .59719 L
.93589 .59683 L
.97619 .59653 L
Mfstroke
0 .04 1 r
.02381 .01472 m
.03279 .09441 L
.04262 .1628 L
.04758 .18916 L
.05288 .21143 L
.05789 .2272 L
.06244 .23752 L
.06507 .24188 L
.06785 .24538 L
.07022 .24752 L
.07157 .24841 L
.07283 .24906 L
.07353 .24933 L
.07428 .24957 L
.075 .24974 L
.07567 .24985 L
.07692 .24994 L
.07763 .24993 L
.07826 .24987 L
.07901 .24976 L
.07971 .24962 L
.08047 .24942 L
.08127 .24916 L
.0841 .24785 L
.08654 .24632 L
.08915 .24431 L
.09387 .23992 L
.10458 .22768 L
.12439 .2034 L
.13484 .192 L
.14594 .18166 L
.15578 .17413 L
.16664 .16757 L
.17651 .16312 L
.18579 .16017 L
.19048 .15911 L
.19317 .15864 L
.19562 .15829 L
.19821 .15801 L
.19963 .15789 L
.20098 .15781 L
.20223 .15775 L
.20337 .15772 L
.20463 .15771 L
.20527 .15771 L
.20597 .15771 L
.2072 .15775 L
.20838 .1578 L
.20943 .15786 L
.21058 .15795 L
Mistroke
.21315 .15822 L
.21553 .15857 L
.21986 .15947 L
.22228 .16014 L
.22447 .16084 L
.22936 .16285 L
.23452 .16573 L
.23893 .16896 L
.24376 .17359 L
.24897 .18025 L
.25454 .18994 L
.2598 .20211 L
.26459 .21587 L
.27465 .24933 L
.28016 .26645 L
.28533 .27958 L
.28972 .28794 L
.29218 .29146 L
.29444 .29395 L
.29678 .29581 L
.29811 .29656 L
.29934 .29706 L
.30065 .29741 L
.30183 .29755 L
.30249 .29756 L
.3032 .29753 L
.30449 .29733 L
.30564 .29702 L
.30688 .29655 L
.30912 .29536 L
.31178 .29345 L
.3142 .29129 L
.32447 .27895 L
.34287 .25149 L
.36354 .22325 L
.37264 .21322 L
.38268 .20407 L
.39225 .19723 L
.40125 .19238 L
.41074 .18874 L
.41608 .18727 L
.42098 .18624 L
.42571 .18549 L
.42836 .18518 L
.43077 .18496 L
.43302 .18481 L
.43428 .18475 L
.43545 .18471 L
.43648 .18469 L
.4376 .18468 L
Mistroke
.43878 .18468 L
.43988 .1847 L
.44116 .18475 L
.44188 .18478 L
.44255 .18482 L
.44388 .1849 L
.44509 .18501 L
.4474 .18525 L
.44985 .18559 L
.45537 .18667 L
.46057 .18808 L
.47035 .1917 L
.48067 .19666 L
.49914 .20704 L
.53714 .22658 L
.5583 .23591 L
.57758 .24537 L
.59758 .25778 L
.61651 .27259 L
.65486 .30889 L
.69566 .34622 L
.73495 .37436 L
.77272 .39532 L
.81294 .41322 L
.85165 .4268 L
.89281 .43754 L
.91335 .44166 L
.93245 .44487 L
.97058 .44977 L
.97619 .45034 L
Mfstroke
0 .016 1 r
.02381 .01472 m
.03279 .09439 L
.04262 .16224 L
.04758 .18767 L
.0503 .19907 L
.05288 .2082 L
.05528 .21531 L
.05789 .22155 L
.06026 .22598 L
.06244 .22907 L
.06371 .23045 L
.06487 .23146 L
.0655 .23192 L
.0662 .23235 L
.06747 .23293 L
.06865 .23325 L
.06991 .23337 L
.0711 .23328 L
.07218 .23305 L
.07285 .23283 L
.07356 .23254 L
.07483 .23189 L
.0777 .22983 L
.08018 .22748 L
.0829 .2244 L
.10458 .19102 L
.12572 .15961 L
.145 .13849 L
.15457 .13071 L
.16498 .12405 L
.17482 .11926 L
.18391 .11597 L
.18855 .11469 L
.19354 .11357 L
.19825 .11277 L
.20034 .11249 L
.20258 .11225 L
.20388 .11213 L
.20506 .11204 L
.20626 .11196 L
.20737 .1119 L
.20866 .11185 L
.20935 .11183 L
.21007 .11182 L
.21128 .11181 L
.21197 .11181 L
.21261 .11181 L
.21327 .11183 L
.21398 .11184 L
.21527 .11189 L
Mistroke
.21654 .11196 L
.21771 .11204 L
.22036 .11229 L
.22318 .11266 L
.22579 .11311 L
.22855 .11371 L
.23349 .11513 L
.23881 .1173 L
.24182 .11889 L
.24463 .12067 L
.24973 .1248 L
.25438 .12986 L
.25974 .13768 L
.26481 .1473 L
.2736 .16777 L
.28307 .18859 L
.28571 .1931 L
.28849 .19703 L
.29086 .1997 L
.29222 .20095 L
.29346 .20191 L
.29463 .20267 L
.2959 .20334 L
.2966 .20363 L
.29724 .20386 L
.2985 .2042 L
.29959 .20437 L
.30078 .20444 L
.30203 .20438 L
.3032 .20422 L
.30442 .20393 L
.30576 .2035 L
.30819 .20242 L
.31056 .20103 L
.31275 .19951 L
.32301 .19013 L
.34403 .16716 L
.36426 .14806 L
.37417 .14071 L
.38326 .13517 L
.39192 .13088 L
.40141 .1272 L
.41094 .1244 L
.42098 .12221 L
.44057 .11903 L
.46151 .11598 L
.4814 .11335 L
.49188 .11222 L
.50298 .11126 L
.51287 .11061 L
Mistroke
.51811 .11033 L
.52375 .11008 L
.52893 .10989 L
.53365 .10975 L
.53852 .10963 L
.54293 .10954 L
.5477 .10948 L
.55032 .10945 L
.55278 .10943 L
.55389 .10942 L
.55507 .10942 L
.55609 .10941 L
.55717 .10941 L
.55835 .1094 L
.55944 .1094 L
.56074 .1094 L
.56193 .1094 L
.56321 .10941 L
.56386 .10941 L
.56458 .10941 L
.56703 .10942 L
.5684 .10943 L
.56989 .10945 L
.57257 .10947 L
.57783 .10954 L
.58265 .10963 L
.59247 .10988 L
.60159 .11019 L
.61161 .11062 L
.6223 .11119 L
.66382 .11428 L
.70382 .11795 L
.7423 .1214 L
.78324 .12479 L
.82267 .12786 L
.86057 .13061 L
.90093 .13323 L
.93978 .13539 L
.97619 .13709 L
Mfstroke
.008 0 1 r
.02381 .01472 m
.03279 .09393 L
.03793 .13006 L
.04262 .15503 L
.04517 .1652 L
.04758 .1726 L
.04881 .17559 L
.05012 .17819 L
.05156 .1804 L
.05225 .18124 L
.05288 .18188 L
.05401 .18274 L
.05523 .18328 L
.05636 .18346 L
.05743 .18335 L
.05868 .18292 L
.05983 .18226 L
.0611 .18127 L
.06244 .17993 L
.06791 .17231 L
.07382 .1616 L
.08454 .14039 L
.0941 .1226 L
.10458 .10578 L
.1142 .09307 L
.12452 .0821 L
.13541 .07309 L
.14558 .06661 L
.15576 .06164 L
.16682 .05759 L
.17727 .05479 L
.18694 .05289 L
.19158 .05218 L
.19657 .05155 L
.20089 .0511 L
.20561 .0507 L
.21084 .05038 L
.2137 .05025 L
.21507 .0502 L
.21636 .05016 L
.21755 .05013 L
.21885 .0501 L
.22003 .05009 L
.22112 .05007 L
.2223 .05007 L
.22359 .05007 L
.22424 .05007 L
.22495 .05008 L
.22621 .05009 L
.2269 .0501 L
Mistroke
.22755 .05012 L
.22876 .05015 L
.23147 .05024 L
.23381 .05035 L
.23634 .05051 L
.23914 .05073 L
.2421 .05102 L
.24739 .05173 L
.25235 .05266 L
.25697 .05381 L
.26205 .05544 L
.26749 .05762 L
.27769 .06221 L
.28306 .06427 L
.28601 .06516 L
.28877 .06581 L
.29116 .06624 L
.29251 .06642 L
.29374 .06656 L
.29502 .06666 L
.29575 .06671 L
.29642 .06674 L
.29713 .06676 L
.29778 .06677 L
.29853 .06678 L
.29923 .06678 L
.30041 .06675 L
.30165 .0667 L
.30271 .06664 L
.30387 .06655 L
.30647 .06629 L
.3089 .06598 L
.31933 .06408 L
.32923 .06187 L
.34778 .05777 L
.35741 .05593 L
.36766 .05427 L
.37726 .05299 L
.38607 .05204 L
.39543 .05125 L
.40552 .05061 L
.41442 .05021 L
.42379 .0499 L
.46187 .04898 L
.48309 .04841 L
.5024 .04794 L
.51202 .04774 L
.52246 .04756 L
.53225 .04743 L
.54141 .04732 L
Mistroke
.55086 .04724 L
.55629 .04721 L
.56126 .04718 L
.56611 .04716 L
.5714 .04714 L
.5743 .04713 L
.57699 .04712 L
.57956 .04712 L
.58099 .04712 L
.5823 .04712 L
.5835 .04712 L
.58462 .04712 L
.58586 .04712 L
.58718 .04712 L
.58784 .04712 L
.58856 .04712 L
.58987 .04712 L
.59115 .04712 L
.59233 .04712 L
.59446 .04712 L
.59681 .04712 L
.60156 .04713 L
.60673 .04715 L
.6123 .04717 L
.62238 .04721 L
.64244 .04734 L
.66354 .04752 L
.70167 .04787 L
.74225 .04825 L
.78132 .04857 L
.82283 .04888 L
.86284 .04914 L
.90132 .04937 L
.94226 .04957 L
.97619 .04971 L
Mfstroke
.032 0 1 r
.02381 .01472 m
.02846 .05719 L
.03068 .07455 L
.03279 .08814 L
.03398 .09443 L
.03527 .10003 L
.03645 .10403 L
.03754 .10685 L
.03871 .10903 L
.04 .11051 L
.04065 .11093 L
.04135 .11117 L
.04262 .11111 L
.04393 .1105 L
.04516 .10952 L
.0465 .10811 L
.04793 .1063 L
.05297 .09848 L
.06244 .08259 L
.07382 .06608 L
.08454 .054 L
.09417 .04569 L
.10458 .03886 L
.11408 .03415 L
.12452 .03027 L
.13541 .0273 L
.14558 .02527 L
.15603 .02373 L
.16594 .02265 L
.17482 .02192 L
.18449 .02133 L
.19389 .0209 L
.20427 .02055 L
.20948 .02042 L
.2151 .02031 L
.22037 .02022 L
.22527 .02015 L
.2299 .0201 L
.23484 .02007 L
.23767 .02005 L
.23905 .02004 L
.24033 .02004 L
.24147 .02003 L
.24272 .02003 L
.24398 .02003 L
.24467 .02003 L
.24531 .02003 L
.24662 .02003 L
.24736 .02003 L
.24804 .02003 L
Mistroke
.24929 .02003 L
.25 .02003 L
.25063 .02003 L
.25183 .02003 L
.25313 .02004 L
.25549 .02005 L
.25826 .02006 L
.26118 .02008 L
.26641 .02012 L
.27592 .02021 L
.27842 .02024 L
.28114 .02026 L
.2835 .02027 L
.28484 .02028 L
.28609 .02028 L
.28736 .02029 L
.28851 .02029 L
.28975 .0203 L
.2904 .0203 L
.29108 .0203 L
.29222 .0203 L
.29329 .0203 L
.29445 .0203 L
.29569 .0203 L
.29683 .02029 L
.29805 .02029 L
.30028 .02028 L
.30444 .02026 L
.30934 .02023 L
.31393 .02019 L
.32435 .0201 L
.34541 .01992 L
.35584 .01984 L
.36574 .01978 L
.37455 .01974 L
.38428 .0197 L
.39392 .01967 L
.39921 .01966 L
.40417 .01966 L
.40879 .01965 L
.41303 .01965 L
.41525 .01964 L
.41768 .01964 L
.41891 .01964 L
.42022 .01964 L
.42144 .01964 L
.42258 .01964 L
.42381 .01964 L
.42452 .01964 L
.42516 .01964 L
Mistroke
.42648 .01964 L
.42721 .01964 L
.4279 .01964 L
.42912 .01964 L
.43025 .01964 L
.43149 .01964 L
.43281 .01964 L
.43581 .01964 L
.43863 .01964 L
.4439 .01964 L
.44861 .01964 L
.45118 .01965 L
.45358 .01965 L
.45484 .01965 L
.45618 .01965 L
.45695 .01965 L
.45767 .01965 L
.45833 .01965 L
.45903 .01965 L
.4603 .01965 L
.46094 .01965 L
.46164 .01965 L
.46288 .01965 L
.46405 .01965 L
.46523 .01965 L
.46648 .01964 L
.46875 .01964 L
.47144 .01964 L
.47389 .01964 L
.47922 .01964 L
.48425 .01964 L
.50275 .01962 L
.54124 .01957 L
.56113 .01955 L
.57128 .01954 L
.58218 .01954 L
.60177 .01953 L
.62009 .01952 L
.64128 .01952 L
.66138 .01951 L
.69965 .01951 L
.72102 .01951 L
.74037 .0195 L
.77957 .0195 L
.79887 .0195 L
.81971 .0195 L
.86078 .0195 L
.90034 .0195 L
.93839 .0195 L
.97619 .0195 L
Mistroke
Mfstroke
.055 0 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02142 L
.02954 .02138 L
.03053 .0213 L
.03279 .02105 L
.04262 .01973 L
.05285 .01854 L
.06244 .01768 L
.07218 .01701 L
.0829 .01646 L
.09334 .01607 L
.10458 .01576 L
.11468 .01557 L
.12571 .01541 L
.13613 .0153 L
.1458 .01523 L
.15637 .01517 L
.16633 .01513 L
.17526 .0151 L
.18493 .01508 L
.19444 .01506 L
.20487 .01505 L
.21013 .01505 L
.21577 .01504 L
.22594 .01503 L
.23122 .01503 L
.23611 .01503 L
.24137 .01503 L
.24718 .01503 L
.25221 .01503 L
.25693 .01503 L
.25954 .01503 L
.26192 .01503 L
.2673 .01503 L
.27722 .01502 L
.28268 .01502 L
.28782 .01502 L
.29783 .01502 L
.30692 .01502 L
.32543 .01502 L
.34503 .01502 L
.35456 .01502 L
.36504 .01502 L
.37458 .01502 L
.3835 .01502 L
.38848 .01502 L
.39111 .01502 L
Mistroke
.3939 .01502 L
.39659 .01502 L
.39903 .01502 L
.40151 .01502 L
.40378 .01502 L
.40602 .01502 L
.40714 .01502 L
.40838 .01502 L
.40962 .01502 L
.41031 .01502 L
.41094 .01502 L
.41217 .01502 L
.41334 .01502 L
.41442 .01502 L
.41557 .01502 L
.41656 .01502 L
.41764 .01502 L
.42006 .01502 L
.42232 .01502 L
.42703 .01502 L
.43218 .01502 L
.44254 .01502 L
.45207 .01502 L
.46106 .01502 L
.46601 .01502 L
.46879 .01502 L
.47012 .01502 L
.47136 .01502 L
.47249 .01502 L
.47353 .01502 L
.47467 .01502 L
.47591 .01502 L
.47709 .01502 L
.47837 .01502 L
.47959 .01502 L
.48071 .01502 L
.48191 .01502 L
.4832 .01502 L
.48554 .01502 L
.48832 .01502 L
.49087 .01502 L
.49613 .01502 L
.50167 .01502 L
.53975 .01502 L
.56098 .01502 L
.58028 .01502 L
.60034 .01502 L
.61929 .01502 L
.65773 .01501 L
.69861 .01501 L
Mistroke
.73798 .01501 L
.77584 .01501 L
.79526 .01501 L
.81615 .01501 L
.85739 .01501 L
.89712 .01501 L
.93533 .01501 L
.976 .01501 L
.97619 .01501 L
Mfstroke
.079 0 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03475 L
.02729 .04309 L
.02846 .04869 L
.02954 .05206 L
.03053 .05397 L
.03163 .05508 L
.03279 .05551 L
.03395 .05543 L
.0352 .05498 L
.03638 .05432 L
.03746 .0536 L
.04262 .04948 L
.0529 .04133 L
.06244 .03521 L
.07277 .03014 L
.08405 .02608 L
.09398 .02346 L
.10458 .02141 L
.11487 .01995 L
.12599 .01881 L
.1365 .01803 L
.14616 .01751 L
.1559 .01712 L
.16499 .01684 L
.17496 .01662 L
.18565 .01644 L
.19582 .01632 L
.20119 .01627 L
.20689 .01623 L
.21186 .0162 L
.21734 .01617 L
.22701 .01613 L
.23193 .01611 L
.2371 .0161 L
.24152 .01609 L
.24636 .01609 L
.24909 .01608 L
.25158 .01608 L
.25296 .01608 L
.25445 .01608 L
.25574 .01608 L
.25716 .01608 L
.25847 .01608 L
.2597 .01608 L
.261 .01608 L
.26173 .01608 L
.26239 .01608 L
.26358 .01608 L
Mistroke
.26487 .01608 L
.26608 .01608 L
.26721 .01608 L
.27231 .01608 L
.27498 .01608 L
.27781 .01608 L
.27901 .01608 L
.28029 .01608 L
.28102 .01608 L
.28169 .01608 L
.283 .01608 L
.28418 .01608 L
.28546 .01608 L
.28666 .01608 L
.28778 .01608 L
.28884 .01608 L
.28999 .01608 L
.29207 .01608 L
.29455 .01608 L
.29681 .01608 L
.3064 .01607 L
.32696 .01605 L
.34607 .01603 L
.36453 .01602 L
.37486 .01601 L
.38423 .01601 L
.3891 .016 L
.39424 .016 L
.40346 .016 L
.40858 .016 L
.41337 .016 L
.42427 .016 L
.46314 .016 L
.50447 .01599 L
.54428 .01599 L
.56248 .01599 L
.58258 .01599 L
.60233 .01599 L
.62333 .01598 L
.64266 .01598 L
.6635 .01598 L
.68352 .01598 L
.70461 .01598 L
.72433 .01598 L
.74269 .01598 L
.75319 .01598 L
.76312 .01598 L
.77203 .01598 L
.7817 .01598 L
.79115 .01598 L
Mistroke
.79652 .01598 L
.80155 .01598 L
.80675 .01598 L
.81169 .01598 L
.81441 .01598 L
.81738 .01598 L
.82259 .01598 L
.82514 .01598 L
.82649 .01598 L
.82791 .01598 L
.82915 .01598 L
.83051 .01598 L
.83176 .01598 L
.83291 .01598 L
.83413 .01598 L
.83528 .01598 L
.83631 .01598 L
.83743 .01598 L
.83865 .01598 L
.83995 .01598 L
.84227 .01598 L
.84475 .01598 L
.84742 .01598 L
.85225 .01598 L
.85799 .01598 L
.86325 .01598 L
.88219 .01598 L
.9029 .01598 L
.94348 .01598 L
.97619 .01598 L
Mfstroke
.103 0 1 r
.02381 .01472 m
.03279 .09441 L
.04262 .16285 L
.04758 .18924 L
.05288 .2115 L
.05789 .22718 L
.06244 .23733 L
.06507 .24157 L
.0665 .24344 L
.06785 .24491 L
.07022 .24689 L
.07148 .24764 L
.07283 .24823 L
.07358 .24847 L
.07427 .24863 L
.07504 .24875 L
.07585 .24881 L
.07662 .2488 L
.07735 .24874 L
.07801 .24865 L
.07872 .2485 L
.07937 .24833 L
.08008 .2481 L
.08152 .2475 L
.0841 .24606 L
.08922 .24201 L
.09469 .23636 L
.10458 .22424 L
.12439 .19899 L
.13484 .18731 L
.14594 .17678 L
.15578 .16916 L
.16664 .16254 L
.17651 .15804 L
.18579 .15506 L
.19048 .15398 L
.19317 .15349 L
.19562 .15313 L
.19821 .15283 L
.19963 .1527 L
.20098 .15261 L
.20223 .15254 L
.20337 .1525 L
.20463 .15248 L
.20527 .15247 L
.20597 .15248 L
.2072 .1525 L
.20838 .15254 L
.20943 .15259 L
.21058 .15267 L
Mistroke
.21182 .15277 L
.21315 .15291 L
.21553 .15323 L
.21795 .15366 L
.22022 .15415 L
.22447 .15536 L
.22914 .15716 L
.23426 .15983 L
.23961 .16363 L
.24459 .1684 L
.24926 .17431 L
.25352 .18125 L
.25843 .19153 L
.26308 .2037 L
.27187 .23144 L
.28133 .26016 L
.28398 .26663 L
.28676 .27245 L
.28933 .27689 L
.29172 .28019 L
.29397 .28258 L
.29513 .28354 L
.29637 .28439 L
.29709 .28479 L
.29775 .2851 L
.29904 .28555 L
.30022 .2858 L
.30146 .28589 L
.30269 .28582 L
.30381 .28562 L
.30511 .28523 L
.30634 .28473 L
.30852 .28352 L
.3109 .28178 L
.31628 .27652 L
.32127 .27042 L
.34229 .23978 L
.36252 .2132 L
.37243 .20301 L
.38153 .19548 L
.39036 .18981 L
.39486 .18755 L
.39967 .18558 L
.40451 .18407 L
.40667 .18354 L
.40901 .18307 L
.41045 .18284 L
.41177 .18266 L
.41301 .18252 L
.41367 .18246 L
Mistroke
.41437 .1824 L
.41559 .18233 L
.41674 .18228 L
.41805 .18227 L
.41925 .18229 L
.42053 .18234 L
.42175 .18242 L
.42284 .18252 L
.42402 .18266 L
.42666 .18309 L
.4291 .18364 L
.43355 .18505 L
.43579 .18598 L
.43824 .18719 L
.44342 .19037 L
.44897 .19483 L
.45897 .20568 L
.48023 .23776 L
.50035 .27034 L
.5387 .31641 L
.57951 .35528 L
.61879 .40087 L
.65656 .44173 L
.67592 .45739 L
.69679 .47004 L
.71684 .47889 L
.73795 .48574 L
.7577 .49065 L
.77607 .49434 L
.79482 .49743 L
.81514 .50016 L
.8365 .50237 L
.8461 .50316 L
.85666 .50389 L
.86625 .50444 L
.87655 .50491 L
.88742 .5053 L
.8927 .50545 L
.8976 .50556 L
.90292 .50567 L
.90774 .50574 L
.91309 .50581 L
.91603 .50584 L
.91879 .50586 L
.92124 .50587 L
.92258 .50588 L
.92383 .50588 L
.92498 .50589 L
.92603 .50589 L
.9272 .50589 L
Mistroke
.92845 .50589 L
.9291 .50589 L
.92979 .50589 L
.93103 .50589 L
.93171 .50589 L
.93235 .50589 L
.93306 .50589 L
.93382 .50589 L
.93518 .50589 L
.93647 .50588 L
.93889 .50587 L
.94142 .50586 L
.9438 .50584 L
.94825 .50581 L
.95823 .5057 L
.96686 .50557 L
.97619 .5054 L
Mfstroke
.126 0 1 r
.02381 .01472 m
.03279 .0942 L
.03793 .13164 L
.04262 .15942 L
.04758 .18196 L
.0503 .19139 L
.05288 .19847 L
.05527 .20353 L
.05747 .20702 L
.05862 .20842 L
.05988 .20966 L
.06121 .21061 L
.06244 .21122 L
.0631 .21144 L
.06379 .21159 L
.06504 .21167 L
.06581 .2116 L
.06653 .21147 L
.06718 .21129 L
.06788 .21103 L
.06919 .21039 L
.07057 .2095 L
.07305 .20744 L
.07767 .20228 L
.08274 .19524 L
.10458 .16046 L
.11544 .14486 L
.12572 .13225 L
.13574 .12207 L
.145 .11436 L
.15386 .10838 L
.16364 .10313 L
.17347 .09911 L
.17856 .09746 L
.18391 .096 L
.18873 .09493 L
.19401 .094 L
.1988 .09337 L
.20094 .09315 L
.20326 .09295 L
.20467 .09285 L
.20598 .09278 L
.2072 .09272 L
.20785 .0927 L
.20854 .09267 L
.20975 .09264 L
.21087 .09263 L
.21216 .09262 L
.21334 .09263 L
.21401 .09264 L
Mistroke
.21472 .09266 L
.21599 .0927 L
.21677 .09273 L
.2175 .09277 L
.21887 .09285 L
.22139 .09305 L
.22412 .09334 L
.2265 .09367 L
.22905 .0941 L
.23365 .09511 L
.23911 .09681 L
.24409 .09895 L
.24928 .10202 L
.25492 .10665 L
.26025 .11265 L
.26517 .11978 L
.27418 .13549 L
.2789 .14352 L
.28387 .15053 L
.28653 .15346 L
.28943 .15596 L
.2907 .15683 L
.29206 .15759 L
.29334 .15817 L
.29451 .15859 L
.29581 .15892 L
.29649 .15905 L
.29721 .15914 L
.29842 .15922 L
.2991 .15922 L
.29974 .15919 L
.30094 .15907 L
.30203 .15888 L
.30329 .15858 L
.30449 .15822 L
.30685 .1573 L
.30907 .15622 L
.31413 .15314 L
.32437 .14526 L
.34279 .1301 L
.3526 .12292 L
.36294 .11646 L
.37263 .11148 L
.38144 .10783 L
.39097 .10474 L
.39586 .10348 L
.40116 .10232 L
.40607 .10144 L
.4106 .10077 L
.41952 .09978 L
Mistroke
.42418 .0994 L
.4292 .09908 L
.43162 .09895 L
.43393 .09885 L
.4362 .09877 L
.43826 .09871 L
.43945 .09868 L
.44074 .09866 L
.44144 .09865 L
.4421 .09864 L
.44338 .09863 L
.44448 .09862 L
.44569 .09862 L
.44695 .09863 L
.44812 .09864 L
.44879 .09865 L
.44952 .09866 L
.45084 .09869 L
.45332 .09876 L
.45621 .09888 L
.45889 .09903 L
.46353 .09936 L
.46853 .09983 L
.47757 .10096 L
.49818 .10451 L
.53934 .11218 L
.55988 .11571 L
.57898 .11935 L
.61711 .12966 L
.63758 .1372 L
.65617 .14483 L
.69617 .16117 L
.73466 .1741 L
.7756 .18464 L
.81502 .19258 L
.85293 .19839 L
.87239 .20064 L
.89329 .20253 L
.90343 .20326 L
.91448 .20393 L
.92503 .20445 L
.93459 .20483 L
.94475 .20514 L
.95431 .20537 L
.95957 .20546 L
.96441 .20552 L
.96971 .20558 L
.97238 .2056 L
.9753 .20561 L
.97619 .20562 L
Mistroke
Mfstroke
.15 0 1 r
.02381 .01472 m
.03279 .09448 L
.04262 .16404 L
.04758 .19173 L
.05288 .21594 L
.05789 .23383 L
.06244 .24615 L
.06507 .25164 L
.06785 .25627 L
.07022 .25932 L
.07283 .26177 L
.0743 .26276 L
.07564 .26343 L
.07637 .26371 L
.07718 .26395 L
.07794 .26411 L
.07865 .26421 L
.07936 .26425 L
.08004 .26424 L
.08129 .26411 L
.08199 .26397 L
.08264 .26381 L
.0841 .26331 L
.08529 .26277 L
.08656 .26209 L
.08885 .26056 L
.09406 .25596 L
.10458 .24349 L
.12439 .21664 L
.13484 .20365 L
.14594 .19173 L
.15578 .18297 L
.16664 .17526 L
.17651 .16995 L
.18579 .16635 L
.19048 .16502 L
.19562 .16393 L
.19821 .16353 L
.19963 .16335 L
.20098 .16321 L
.20223 .1631 L
.20289 .16305 L
.20359 .16301 L
.20483 .16295 L
.20597 .16292 L
.20712 .16291 L
.20816 .16292 L
.20937 .16295 L
.21052 .163 L
.21158 .16307 L
Mistroke
.21256 .16315 L
.21478 .16339 L
.21724 .16377 L
.21948 .16421 L
.22186 .1648 L
.22447 .16559 L
.22936 .16753 L
.23452 .17038 L
.2393 .17392 L
.24376 .17826 L
.24902 .18509 L
.25382 .19339 L
.25936 .20609 L
.26459 .22141 L
.27338 .25193 L
.28285 .28284 L
.28827 .29628 L
.29064 .30092 L
.29324 .30511 L
.2957 .30825 L
.29798 .31046 L
.29925 .3114 L
.3004 .31209 L
.30103 .3124 L
.30172 .31268 L
.30297 .31306 L
.30421 .31327 L
.30536 .31333 L
.30663 .31323 L
.30734 .31311 L
.30799 .31296 L
.30929 .31255 L
.31071 .31193 L
.31329 .31041 L
.31568 .30859 L
.31822 .30627 L
.32279 .30129 L
.34381 .27209 L
.35339 .25888 L
.36348 .24678 L
.37209 .23852 L
.37698 .23487 L
.38153 .23225 L
.38404 .23116 L
.38528 .23073 L
.38642 .23039 L
.38743 .23015 L
.38855 .22994 L
.38967 .2298 L
.39087 .22973 L
Mistroke
.39216 .22974 L
.39335 .22985 L
.39401 .22995 L
.39472 .23009 L
.39602 .23045 L
.39723 .2309 L
.39853 .23151 L
.40085 .23299 L
.40356 .2354 L
.40648 .23898 L
.40925 .24342 L
.41179 .24853 L
.41661 .26122 L
.4217 .27902 L
.44157 .3733 L
.45969 .44886 L
.46972 .4787 L
.47921 .49968 L
.48924 .51543 L
.4949 .52195 L
.50013 .52672 L
.50477 .53008 L
.50977 .53293 L
.51449 .535 L
.51881 .53648 L
.52361 .53773 L
.52885 .53874 L
.53433 .53952 L
.53942 .54008 L
.55817 .54188 L
.56874 .54322 L
.57848 .54477 L
.59985 .54882 L
.61026 .55077 L
.62 .55236 L
.62906 .55354 L
.63414 .55406 L
.63878 .55444 L
.64124 .5546 L
.64385 .55474 L
.64535 .55481 L
.64672 .55486 L
.6481 .5549 L
.64937 .55494 L
.65059 .55496 L
.65186 .55498 L
.65315 .55499 L
.65388 .555 L
.65455 .555 L
.65579 .55499 L
Mistroke
.65691 .55499 L
.6582 .55497 L
.65943 .55495 L
.66057 .55492 L
.66181 .55489 L
.66404 .55482 L
.66911 .55457 L
.67448 .55422 L
.67939 .55381 L
.69783 .5517 L
.73752 .54579 L
.7757 .54055 L
.81634 .53623 L
.85545 .53278 L
.89702 .52954 L
.93708 .52692 L
.97562 .52499 L
.97619 .52496 L
Mfstroke
.174 0 1 r
.02381 .01472 m
.02846 .0569 L
.03068 .07345 L
.03279 .08558 L
.03398 .09076 L
.03527 .09499 L
.03645 .09769 L
.03754 .09931 L
.03871 .10028 L
.04 .10055 L
.04065 .10044 L
.04135 .10015 L
.04262 .09929 L
.04393 .09802 L
.04516 .09659 L
.04793 .09276 L
.05297 .0849 L
.06244 .07054 L
.07295 .05735 L
.08284 .04772 L
.09424 .03941 L
.10458 .03388 L
.11434 .02998 L
.12466 .0269 L
.13346 .02492 L
.14313 .02327 L
.15334 .02198 L
.16264 .0211 L
.17338 .02035 L
.18355 .01983 L
.19321 .01947 L
.20346 .0192 L
.21222 .01903 L
.22188 .01889 L
.2268 .01884 L
.23198 .0188 L
.2364 .01877 L
.2389 .01876 L
.24123 .01875 L
.24254 .01875 L
.24395 .01875 L
.24528 .01874 L
.24651 .01874 L
.24762 .01874 L
.24885 .01874 L
.25012 .01874 L
.25131 .01874 L
.25198 .01874 L
.25271 .01874 L
.25403 .01874 L
Mistroke
.25532 .01874 L
.25651 .01875 L
.25921 .01875 L
.26209 .01876 L
.2724 .01882 L
.27782 .01884 L
.28078 .01886 L
.28354 .01887 L
.28596 .01887 L
.28732 .01888 L
.28856 .01888 L
.28926 .01888 L
.28991 .01888 L
.29063 .01888 L
.29138 .01888 L
.29266 .01888 L
.29338 .01888 L
.29406 .01888 L
.29524 .01888 L
.29649 .01888 L
.29755 .01888 L
.29871 .01887 L
.30131 .01887 L
.30372 .01886 L
.31427 .01881 L
.32422 .01875 L
.34282 .01864 L
.35257 .0186 L
.36287 .01856 L
.37253 .01852 L
.38134 .0185 L
.3908 .01848 L
.39601 .01848 L
.40095 .01847 L
.40551 .01847 L
.40973 .01847 L
.41192 .01847 L
.41435 .01846 L
.41558 .01846 L
.41689 .01846 L
.41814 .01846 L
.41928 .01846 L
.42055 .01846 L
.42175 .01846 L
.42284 .01846 L
.42401 .01846 L
.42528 .01846 L
.42593 .01846 L
.42664 .01846 L
.42906 .01846 L
Mistroke
.43133 .01847 L
.43377 .01847 L
.43818 .01847 L
.45887 .01848 L
.46377 .01848 L
.46898 .01848 L
.47053 .01848 L
.47199 .01848 L
.4734 .01848 L
.47471 .01848 L
.47595 .01848 L
.47726 .01848 L
.47858 .01848 L
.47932 .01849 L
.48002 .01849 L
.48127 .01848 L
.48197 .01848 L
.48263 .01848 L
.48382 .01848 L
.48509 .01848 L
.48729 .01848 L
.48972 .01848 L
.49508 .01848 L
.50011 .01848 L
.50996 .01847 L
.52031 .01846 L
.53882 .01845 L
.57695 .01841 L
.59657 .0184 L
.61753 .01839 L
.63889 .01839 L
.65905 .01838 L
.67908 .01838 L
.69753 .01838 L
.71791 .01837 L
.73696 .01837 L
.75641 .01837 L
.77486 .01837 L
.79517 .01837 L
.81371 .01837 L
.83357 .01837 L
.85197 .01837 L
.87255 .01837 L
.89118 .01837 L
.91047 .01837 L
.92134 .01837 L
.93131 .01837 L
.94043 .01837 L
.95019 .01837 L
.9558 .01837 L
Mistroke
.9609 .01837 L
.96602 .01837 L
.97087 .01837 L
.97364 .01837 L
.97619 .01837 L
Mfstroke
.198 0 1 r
.02381 .01472 m
.02846 .05777 L
.03279 .09339 L
.03754 .12466 L
.0402 .13754 L
.04262 .14608 L
.04385 .14928 L
.04516 .15186 L
.04627 .15343 L
.0475 .15454 L
.04882 .15507 L
.04957 .1551 L
.05024 .15496 L
.05156 .15432 L
.05281 .15328 L
.05397 .15202 L
.0552 .15039 L
.05742 .14687 L
.06244 .13716 L
.07287 .11501 L
.08414 .09352 L
.09388 .07845 L
.10458 .06545 L
.11511 .0557 L
.12624 .04799 L
.13654 .04267 L
.14616 .03892 L
.15661 .03585 L
.16651 .0337 L
.1754 .03223 L
.18507 .03104 L
.19447 .03018 L
.20484 .02951 L
.21006 .02926 L
.21568 .02905 L
.21827 .02897 L
.22099 .0289 L
.22332 .02885 L
.22585 .02881 L
.22719 .02879 L
.22842 .02878 L
.22958 .02876 L
.23085 .02875 L
.23199 .02875 L
.23306 .02874 L
.23419 .02874 L
.2354 .02874 L
.23671 .02874 L
.23744 .02874 L
.23813 .02875 L
Mistroke
.23939 .02875 L
.24073 .02877 L
.24328 .0288 L
.24559 .02884 L
.24796 .02889 L
.25014 .02895 L
.25506 .02913 L
.25939 .02933 L
.26396 .02959 L
.27346 .03023 L
.27869 .03056 L
.28126 .0307 L
.28364 .03081 L
.28583 .03089 L
.28824 .03096 L
.28949 .03099 L
.29067 .03101 L
.29191 .03103 L
.2926 .03103 L
.29324 .03104 L
.2943 .03104 L
.29528 .03104 L
.29635 .03104 L
.2975 .03104 L
.29871 .03103 L
.29985 .03101 L
.30199 .03098 L
.30439 .03093 L
.30663 .03087 L
.31173 .0307 L
.32204 .03028 L
.3405 .02948 L
.35094 .02908 L
.36083 .02876 L
.36964 .02852 L
.37938 .02831 L
.38902 .02815 L
.39395 .02808 L
.39926 .02802 L
.40422 .02798 L
.40876 .02794 L
.41343 .02792 L
.41768 .0279 L
.42241 .02788 L
.42746 .02787 L
.43658 .02785 L
.44734 .02782 L
.45727 .02779 L
.46657 .02776 L
.47643 .02771 L
Mistroke
.49722 .02759 L
.51699 .02747 L
.53507 .02739 L
.5545 .02733 L
.56521 .0273 L
.57538 .02728 L
.58498 .02727 L
.5952 .02726 L
.60485 .02725 L
.61359 .02724 L
.61847 .02724 L
.62363 .02724 L
.62803 .02724 L
.63286 .02724 L
.63558 .02724 L
.63806 .02724 L
.63943 .02724 L
.64015 .02724 L
.64092 .02724 L
.64159 .02724 L
.64233 .02724 L
.64363 .02724 L
.64493 .02724 L
.64612 .02724 L
.64744 .02724 L
.64809 .02724 L
.64881 .02724 L
.65134 .02724 L
.65368 .02724 L
.65874 .02724 L
.66421 .02724 L
.67415 .02724 L
.69275 .02725 L
.73368 .02726 L
.77311 .02728 L
.81101 .0273 L
.85137 .02731 L
.89022 .02732 L
.93151 .02734 L
.9713 .02734 L
.97619 .02735 L
Mfstroke
.221 0 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02107 L
.04262 .01977 L
.05217 .01867 L
.06244 .01774 L
.0728 .01704 L
.0825 .01655 L
.09403 .01612 L
.10458 .01584 L
.11442 .01565 L
.12357 .01551 L
.1336 .0154 L
.14429 .01531 L
.15457 .01525 L
.1657 .01521 L
.17621 .01517 L
.18587 .01515 L
.19561 .01514 L
.2047 .01512 L
.21467 .01512 L
.22026 .01511 L
.22536 .01511 L
.23016 .01511 L
.23527 .0151 L
.23963 .0151 L
.24444 .0151 L
.24695 .0151 L
.2496 .0151 L
.25249 .0151 L
.25378 .0151 L
.25515 .0151 L
.25645 .0151 L
.25764 .0151 L
.25883 .0151 L
.25995 .0151 L
.26126 .0151 L
.26247 .0151 L
.2631 .0151 L
.2638 .0151 L
.26452 .0151 L
.2652 .0151 L
.27018 .0151 L
.27281 .0151 L
Mistroke
.27561 .0151 L
.277 .0151 L
.2783 .0151 L
.27947 .0151 L
.28074 .0151 L
.28194 .0151 L
.28321 .0151 L
.2843 .0151 L
.28549 .0151 L
.28674 .0151 L
.28792 .0151 L
.29012 .0151 L
.2925 .0151 L
.29508 .0151 L
.29973 .0151 L
.30403 .0151 L
.32432 .0151 L
.34335 .01509 L
.36155 .01509 L
.37178 .01509 L
.38115 .01509 L
.3859 .01509 L
.39098 .01509 L
.40011 .01509 L
.4057 .01509 L
.41097 .01509 L
.42083 .01509 L
.45934 .01509 L
.47887 .01509 L
.50031 .01509 L
.52094 .01509 L
.53977 .01509 L
.55926 .01509 L
.56999 .01509 L
.58016 .01509 L
.60005 .01509 L
.61846 .01509 L
.6371 .01509 L
.65769 .01509 L
.67702 .01509 L
.68697 .01509 L
.69786 .01509 L
.70823 .01509 L
.71788 .01509 L
.72312 .01509 L
.72807 .01509 L
.73378 .01509 L
.73646 .01509 L
.73897 .01509 L
.74138 .01509 L
Mistroke
.74359 .01509 L
.74604 .01509 L
.74739 .01509 L
.74868 .01509 L
.74991 .01509 L
.75123 .01509 L
.75247 .01509 L
.7536 .01509 L
.75429 .01509 L
.75492 .01509 L
.75562 .01509 L
.75636 .01509 L
.7576 .01509 L
.75896 .01509 L
.76137 .01509 L
.76357 .01509 L
.7685 .01509 L
.77308 .01509 L
.77741 .01509 L
.79733 .01509 L
.81576 .01509 L
.85504 .01509 L
.89281 .01509 L
.93304 .01509 L
.97174 .01509 L
.97619 .01509 L
Mfstroke
.245 0 1 r
.02381 .01472 m
.02846 .05767 L
.03279 .09281 L
.03754 .12395 L
.04018 .1375 L
.04262 .14758 L
.04518 .15576 L
.0465 .15908 L
.04795 .16207 L
.04913 .16402 L
.0504 .16565 L
.0511 .16637 L
.05174 .16692 L
.053 .16769 L
.0542 .1681 L
.05531 .16821 L
.05654 .16806 L
.05784 .16761 L
.05908 .16694 L
.06026 .16612 L
.06244 .16413 L
.06757 .1578 L
.07299 .14955 L
.08269 .13352 L
.09325 .11687 L
.10458 .1015 L
.11485 .09008 L
.12422 .08161 L
.13311 .07508 L
.14255 .06951 L
.15246 .06493 L
.16164 .06163 L
.1715 .05892 L
.17681 .05775 L
.1824 .05673 L
.18722 .05599 L
.19249 .05531 L
.19734 .05482 L
.20174 .05446 L
.20697 .05414 L
.20984 .05402 L
.21115 .05397 L
.21255 .05393 L
.21374 .05391 L
.21506 .05388 L
.21625 .05387 L
.21737 .05386 L
.21869 .05386 L
.21989 .05386 L
.22056 .05386 L
Mistroke
.22128 .05387 L
.2226 .05389 L
.22394 .05392 L
.22516 .05396 L
.22793 .05406 L
.23037 .05419 L
.23294 .05436 L
.23741 .05477 L
.24231 .05539 L
.24756 .05633 L
.25317 .05773 L
.25847 .05955 L
.2633 .06171 L
.27336 .06739 L
.27887 .07052 L
.28403 .07293 L
.28617 .07372 L
.28842 .0744 L
.29089 .07497 L
.29315 .07534 L
.29435 .07548 L
.29564 .07559 L
.29685 .07566 L
.29795 .07568 L
.29925 .07568 L
.29998 .07566 L
.30065 .07563 L
.30189 .07556 L
.3032 .07545 L
.30558 .07518 L
.30776 .07485 L
.31265 .07391 L
.32148 .0717 L
.34158 .06608 L
.3516 .06354 L
.36225 .06122 L
.37212 .05943 L
.38139 .05807 L
.39014 .05705 L
.39959 .0562 L
.40469 .05584 L
.41007 .05552 L
.41969 .05509 L
.42922 .05476 L
.4394 .05449 L
.45776 .05407 L
.46799 .05391 L
.47376 .05384 L
.47651 .05381 L
.47908 .05379 L
Mistroke
.48152 .05377 L
.48374 .05376 L
.48621 .05375 L
.48757 .05375 L
.48887 .05375 L
.49011 .05375 L
.49081 .05374 L
.49144 .05374 L
.49266 .05374 L
.49382 .05375 L
.49448 .05375 L
.49518 .05375 L
.49642 .05375 L
.49776 .05375 L
.49923 .05376 L
.50174 .05377 L
.50448 .05378 L
.50944 .05381 L
.51875 .05388 L
.53967 .0541 L
.55946 .05437 L
.58048 .05475 L
.59996 .05524 L
.61825 .05585 L
.65695 .05755 L
.69811 .05957 L
.73776 .06128 L
.77589 .06267 L
.81647 .06394 L
.85553 .06498 L
.89705 .06587 L
.93705 .06651 L
.97554 .06695 L
.97619 .06696 L
Mfstroke
.269 0 1 r
.02381 .01472 m
.02846 .05679 L
.03068 .07308 L
.03279 .08482 L
.03398 .08975 L
.03527 .09372 L
.03645 .09621 L
.03754 .09767 L
.03871 .0985 L
.04 .09867 L
.04065 .09852 L
.04135 .09821 L
.04262 .09732 L
.04393 .09605 L
.04516 .09464 L
.04793 .0909 L
.05297 .08326 L
.06244 .06932 L
.07295 .05652 L
.08284 .04715 L
.09424 .03905 L
.10458 .03366 L
.11434 .02985 L
.12466 .02685 L
.13346 .02491 L
.14313 .0233 L
.15334 .02204 L
.16264 .02118 L
.17338 .02045 L
.18355 .01994 L
.19321 .01959 L
.20346 .01932 L
.21222 .01916 L
.22188 .01903 L
.2268 .01898 L
.23198 .01894 L
.2364 .01892 L
.2389 .01891 L
.24123 .0189 L
.24254 .0189 L
.24395 .01889 L
.2446 .01889 L
.24528 .01889 L
.24651 .01889 L
.2477 .01889 L
.2488 .01889 L
.25001 .01889 L
.25131 .01889 L
.25203 .01889 L
.2527 .01889 L
Mistroke
.2542 .0189 L
.25694 .01891 L
.25944 .01891 L
.26209 .01893 L
.2724 .01899 L
.27782 .01902 L
.28078 .01903 L
.28354 .01904 L
.28596 .01905 L
.28732 .01905 L
.28856 .01905 L
.28926 .01905 L
.28991 .01905 L
.29063 .01905 L
.29138 .01905 L
.29266 .01905 L
.29338 .01905 L
.29406 .01905 L
.29524 .01905 L
.29649 .01905 L
.29871 .01904 L
.30111 .01904 L
.30372 .01903 L
.31402 .01898 L
.32337 .01892 L
.34434 .0188 L
.36356 .01871 L
.37439 .01867 L
.38437 .01865 L
.38906 .01864 L
.39409 .01863 L
.39844 .01863 L
.40317 .01862 L
.40605 .01862 L
.40871 .01862 L
.41121 .01861 L
.41397 .01861 L
.41627 .01861 L
.41875 .01861 L
.42136 .01861 L
.42265 .01861 L
.42382 .01861 L
.42622 .01861 L
.42753 .01861 L
.42877 .01861 L
.42992 .01861 L
.43098 .01861 L
.43215 .01861 L
.43338 .01861 L
.43462 .01861 L
Mistroke
.43532 .01861 L
.43595 .01861 L
.43719 .01861 L
.43836 .01861 L
.43963 .01861 L
.44033 .01861 L
.44098 .01861 L
.44176 .01861 L
.44246 .01861 L
.44313 .01861 L
.44384 .01861 L
.44516 .01861 L
.44639 .01861 L
.4471 .01861 L
.44774 .01861 L
.44919 .01861 L
.45057 .01861 L
.45208 .01861 L
.45483 .01861 L
.45737 .01861 L
.46008 .01861 L
.46493 .01861 L
.46983 .0186 L
.47431 .0186 L
.48442 .01859 L
.5027 .01858 L
.52324 .01856 L
.54235 .01855 L
.56079 .01854 L
.5711 .01853 L
.58048 .01853 L
.59967 .01853 L
.6105 .01852 L
.62048 .01852 L
.63925 .01852 L
.6599 .01852 L
.67936 .01852 L
.70026 .01852 L
.7104 .01852 L
.72145 .01852 L
.732 .01852 L
.74156 .01852 L
.75172 .01852 L
.76128 .01852 L
.76654 .01851 L
.77138 .01851 L
.77668 .01851 L
.77935 .01851 L
.78227 .01851 L
.7848 .01851 L
Mistroke
.78613 .01851 L
.78754 .01851 L
.78877 .01851 L
.79013 .01851 L
.79136 .01851 L
.79252 .01851 L
.79372 .01851 L
.79486 .01851 L
.79589 .01851 L
.79701 .01851 L
.79822 .01851 L
.79951 .01851 L
.80073 .01851 L
.80184 .01851 L
.80453 .01851 L
.80701 .01851 L
.81261 .01851 L
.82277 .01851 L
.84159 .01852 L
.86225 .01852 L
.90266 .01852 L
.94155 .01852 L
.97619 .01852 L
Mfstroke
.292 0 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04313 L
.02846 .04879 L
.02954 .05223 L
.03053 .05419 L
.03163 .05536 L
.03279 .05584 L
.03395 .05579 L
.0352 .05536 L
.03638 .05471 L
.03746 .054 L
.04262 .04986 L
.0529 .04161 L
.06244 .03539 L
.07277 .03024 L
.08405 .02612 L
.09398 .02346 L
.10458 .02137 L
.11487 .01989 L
.12599 .01874 L
.1365 .01795 L
.14616 .01742 L
.1559 .01702 L
.16499 .01674 L
.17496 .01652 L
.18565 .01634 L
.19582 .01622 L
.20119 .01617 L
.20689 .01613 L
.21186 .01609 L
.21734 .01606 L
.22701 .01602 L
.23193 .01601 L
.2371 .01599 L
.24158 .01599 L
.24636 .01598 L
.24906 .01597 L
.25152 .01597 L
.25402 .01597 L
.25632 .01597 L
.25901 .01597 L
.26042 .01597 L
.26192 .01597 L
.26322 .01597 L
.26444 .01597 L
.26514 .01597 L
.26578 .01597 L
.26651 .01597 L
Mistroke
.26721 .01596 L
.26846 .01596 L
.26917 .01596 L
.26981 .01596 L
.271 .01597 L
.27226 .01597 L
.27339 .01597 L
.27446 .01597 L
.2757 .01597 L
.27683 .01597 L
.27804 .01597 L
.27935 .01597 L
.28058 .01597 L
.28171 .01596 L
.28294 .01596 L
.2843 .01596 L
.28706 .01596 L
.28945 .01596 L
.29163 .01596 L
.29656 .01596 L
.30546 .01595 L
.32603 .01593 L
.34514 .01592 L
.35464 .01591 L
.3636 .01591 L
.37392 .0159 L
.3833 .0159 L
.38794 .0159 L
.39304 .0159 L
.39837 .01589 L
.40093 .01589 L
.40335 .01589 L
.40558 .01589 L
.40801 .01589 L
.41021 .01589 L
.41226 .01589 L
.41339 .01589 L
.41446 .01589 L
.41563 .01589 L
.41689 .01589 L
.41814 .01589 L
.41946 .01589 L
.42058 .01589 L
.42181 .01589 L
.42313 .01589 L
.42434 .01589 L
.42709 .01589 L
.43207 .01589 L
.4414 .01589 L
.44665 .01589 L
Mistroke
.45157 .0159 L
.45425 .0159 L
.4567 .0159 L
.458 .0159 L
.45942 .0159 L
.4602 .0159 L
.46092 .0159 L
.46161 .0159 L
.46234 .0159 L
.46359 .0159 L
.46429 .0159 L
.46495 .0159 L
.46565 .0159 L
.46628 .0159 L
.46701 .0159 L
.46771 .0159 L
.46893 .0159 L
.47007 .0159 L
.47264 .0159 L
.47521 .0159 L
.47804 .01589 L
.48377 .01589 L
.49418 .01589 L
.50395 .01589 L
.54265 .01589 L
.56271 .01589 L
.57291 .01589 L
.58381 .01588 L
.60357 .01588 L
.62194 .01588 L
.66346 .01588 L
.70346 .01588 L
.74195 .01588 L
.76184 .01588 L
.78289 .01588 L
.82079 .01588 L
.86115 .01588 L
.9 .01588 L
.94129 .01588 L
.97619 .01588 L
Mfstroke
.316 0 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02107 L
.04262 .01977 L
.05217 .01866 L
.06244 .01773 L
.0728 .01702 L
.0825 .01652 L
.09403 .01609 L
.10458 .01581 L
.11442 .01561 L
.12357 .01548 L
.1336 .01536 L
.14429 .01528 L
.15457 .01522 L
.1657 .01517 L
.17621 .01514 L
.18587 .01511 L
.19561 .0151 L
.2047 .01509 L
.21467 .01508 L
.22026 .01507 L
.22536 .01507 L
.23016 .01507 L
.23527 .01507 L
.23969 .01506 L
.24444 .01506 L
.24953 .01506 L
.25431 .01506 L
.25708 .01506 L
.25999 .01506 L
.26248 .01506 L
.2639 .01506 L
.2652 .01506 L
.26774 .01506 L
.27049 .01506 L
.27286 .01506 L
.27548 .01506 L
.27766 .01506 L
.28001 .01506 L
.28249 .01506 L
.28481 .01506 L
.29043 .01506 L
.29576 .01506 L
Mistroke
.30576 .01506 L
.32584 .01506 L
.34401 .01505 L
.35417 .01505 L
.36372 .01505 L
.37381 .01505 L
.37949 .01505 L
.38471 .01505 L
.38942 .01505 L
.39447 .01505 L
.39692 .01505 L
.39923 .01505 L
.4013 .01505 L
.40357 .01505 L
.40607 .01505 L
.40744 .01505 L
.40872 .01505 L
.40992 .01505 L
.41101 .01505 L
.41222 .01505 L
.41348 .01505 L
.41477 .01505 L
.41549 .01505 L
.41615 .01505 L
.41863 .01505 L
.42002 .01505 L
.42152 .01505 L
.42425 .01505 L
.44377 .01505 L
.45412 .01505 L
.4571 .01505 L
.45992 .01505 L
.46249 .01505 L
.4639 .01505 L
.46522 .01505 L
.46647 .01505 L
.46763 .01505 L
.46891 .01505 L
.46958 .01505 L
.47029 .01505 L
.47145 .01505 L
.47253 .01505 L
.47372 .01505 L
.47498 .01505 L
.4757 .01505 L
.47636 .01505 L
.47785 .01505 L
.48055 .01505 L
.48301 .01505 L
.48561 .01505 L
Mistroke
.49469 .01505 L
.50467 .01505 L
.54498 .01505 L
.56353 .01505 L
.58377 .01505 L
.59474 .01505 L
.60492 .01505 L
.62502 .01505 L
.66417 .01505 L
.70577 .01505 L
.72665 .01505 L
.74585 .01505 L
.78443 .01505 L
.82393 .01505 L
.86192 .01505 L
.90237 .01505 L
.9413 .01505 L
.97619 .01505 L
Mfstroke
.34 0 1 r
.02381 .01472 m
.03279 .09448 L
.04262 .16372 L
.04758 .19089 L
.05288 .21413 L
.05789 .23069 L
.06244 .24151 L
.06507 .24604 L
.0665 .24803 L
.06785 .2496 L
.07022 .25169 L
.07148 .25248 L
.07213 .2528 L
.07283 .25308 L
.07358 .25332 L
.07427 .25347 L
.0751 .25358 L
.07585 .25361 L
.07656 .25358 L
.07733 .25349 L
.07805 .25335 L
.07872 .25317 L
.07997 .25272 L
.08134 .25206 L
.0841 .25026 L
.08922 .24555 L
.09469 .23906 L
.10458 .22524 L
.12439 .1968 L
.13484 .18377 L
.14594 .17209 L
.15578 .16366 L
.16664 .15632 L
.17651 .1513 L
.18579 .1479 L
.19048 .14663 L
.19562 .14559 L
.19821 .14519 L
.19963 .14501 L
.20098 .14487 L
.20223 .14476 L
.20359 .14466 L
.20483 .14459 L
.20597 .14455 L
.20703 .14453 L
.20818 .14452 L
.20926 .14453 L
.21025 .14455 L
.2114 .1446 L
.21266 .14468 L
Mistroke
.21385 .14477 L
.21496 .14487 L
.21738 .14518 L
.21957 .14554 L
.22191 .14602 L
.22447 .14667 L
.22936 .14832 L
.23452 .15075 L
.2393 .1538 L
.24376 .15754 L
.24902 .16346 L
.25382 .17069 L
.25936 .18183 L
.26459 .19539 L
.27338 .22266 L
.28285 .25 L
.28549 .25602 L
.28827 .26137 L
.29084 .2654 L
.29324 .26834 L
.29549 .27041 L
.29675 .27129 L
.29789 .27192 L
.29915 .27243 L
.29985 .27264 L
.30051 .27278 L
.30171 .27292 L
.30297 .2729 L
.30421 .27273 L
.30533 .27245 L
.30663 .27199 L
.30785 .27141 L
.31004 .27011 L
.31242 .2683 L
.3178 .26301 L
.32279 .25701 L
.34381 .22774 L
.35354 .21506 L
.36404 .20329 L
.37311 .19505 L
.37825 .19124 L
.38304 .18827 L
.38767 .18598 L
.39004 .18502 L
.39262 .18417 L
.39403 .18379 L
.39534 .18349 L
.39656 .18326 L
.39721 .18316 L
.39791 .18307 L
Mistroke
.39911 .18294 L
.40024 .18288 L
.40153 .18286 L
.40271 .1829 L
.40382 .18298 L
.40501 .18313 L
.40613 .18333 L
.40714 .18356 L
.40963 .18433 L
.41197 .18535 L
.41417 .1866 L
.41619 .18803 L
.42076 .19237 L
.42322 .19544 L
.42547 .19874 L
.43051 .20816 L
.43518 .21959 L
.4396 .23293 L
.46027 .31753 L
.4785 .3903 L
.48888 .42195 L
.49862 .44486 L
.50814 .46178 L
.51841 .47525 L
.52937 .48574 L
.53942 .49311 L
.57906 .51598 L
.59905 .52687 L
.61719 .53548 L
.62661 .53915 L
.63682 .54242 L
.64243 .54389 L
.6476 .54504 L
.65251 .54596 L
.65777 .54677 L
.66284 .54738 L
.66748 .54781 L
.66971 .54797 L
.67213 .54811 L
.67441 .54822 L
.67655 .5483 L
.67786 .54834 L
.67928 .54837 L
.68056 .5484 L
.68174 .54841 L
.68303 .54842 L
.68375 .54842 L
.68443 .54842 L
.68515 .54842 L
.6858 .54841 L
Mistroke
.68655 .54841 L
.68727 .5484 L
.68847 .54838 L
.68974 .54836 L
.69203 .5483 L
.69449 .54822 L
.6972 .54811 L
.70733 .54754 L
.7166 .54685 L
.73747 .54499 L
.77717 .54139 L
.81535 .53833 L
.85598 .53516 L
.8951 .53203 L
.93667 .52885 L
.97619 .52618 L
Mfstroke
.364 0 1 r
.02381 .01472 m
.03279 .09434 L
.04262 .16171 L
.04758 .18668 L
.0503 .19779 L
.05288 .20663 L
.05528 .21345 L
.05789 .21938 L
.06026 .22353 L
.06244 .22638 L
.06371 .22762 L
.06487 .22851 L
.0655 .2289 L
.0662 .22926 L
.06747 .22971 L
.06865 .22992 L
.06991 .22992 L
.0711 .22974 L
.07218 .22942 L
.07285 .22915 L
.07356 .22882 L
.07483 .22808 L
.0777 .22586 L
.0829 .22021 L
.10458 .187 L
.12444 .15807 L
.14255 .13831 L
.15257 .13012 L
.16206 .12396 L
.17208 .11894 L
.1777 .11671 L
.18298 .11498 L
.18788 .11366 L
.19238 .11268 L
.19737 .11185 L
.19999 .11152 L
.20275 .11125 L
.20526 .11107 L
.20667 .111 L
.20795 .11095 L
.20914 .11093 L
.21043 .11091 L
.21166 .11092 L
.21278 .11094 L
.21409 .11098 L
.21532 .11104 L
.21667 .11112 L
.21811 .11124 L
.22106 .11156 L
.22376 .11195 L
Mistroke
.22854 .11293 L
.23121 .11365 L
.23363 .11443 L
.23834 .11634 L
.24278 .11874 L
.24798 .1225 L
.25275 .12719 L
.25799 .1341 L
.26352 .14377 L
.27375 .16666 L
.27877 .17787 L
.28342 .18663 L
.28764 .19269 L
.28976 .19501 L
.29211 .19698 L
.29333 .19777 L
.29445 .19836 L
.29568 .19886 L
.29698 .19923 L
.29811 .19942 L
.29916 .19949 L
.30031 .19946 L
.30154 .19931 L
.30286 .19902 L
.30408 .19864 L
.30682 .19743 L
.30924 .196 L
.31179 .19418 L
.32109 .18567 L
.34202 .16328 L
.3522 .15346 L
.36186 .14548 L
.37126 .13908 L
.37996 .13435 L
.38929 .13051 L
.39421 .12899 L
.39673 .12834 L
.39944 .12775 L
.40212 .12726 L
.40457 .1269 L
.40691 .12664 L
.40809 .12654 L
.40938 .12645 L
.41012 .12641 L
.41082 .12638 L
.41212 .12635 L
.41286 .12634 L
.41353 .12634 L
.41427 .12635 L
.41506 .12636 L
Mistroke
.41636 .12641 L
.41758 .12649 L
.41891 .12659 L
.42035 .12675 L
.42289 .12711 L
.4256 .12764 L
.42815 .12829 L
.43047 .12901 L
.43615 .13141 L
.4415 .13458 L
.44653 .13849 L
.45116 .14294 L
.4616 .15607 L
.48203 .19074 L
.5011 .2239 L
.51944 .24931 L
.53909 .26971 L
.58048 .30911 L
.62034 .35704 L
.63857 .37764 L
.64895 .38768 L
.65869 .39575 L
.66902 .40284 L
.67848 .40805 L
.68859 .41239 L
.69386 .41419 L
.69949 .41582 L
.70463 .41705 L
.70931 .41799 L
.71843 .41938 L
.72354 .41995 L
.72908 .42042 L
.73432 .42074 L
.73683 .42086 L
.73914 .42095 L
.74138 .42103 L
.74382 .42109 L
.74639 .42115 L
.74768 .42117 L
.74884 .42118 L
.74994 .42119 L
.75112 .4212 L
.75237 .42121 L
.75355 .42121 L
.75466 .42122 L
.75582 .42122 L
.75682 .42121 L
.75791 .42121 L
.75858 .4212 L
.7593 .4212 L
Mistroke
.76062 .42119 L
.76308 .42116 L
.76595 .42112 L
.7686 .42107 L
.77856 .42082 L
.78822 .42049 L
.79728 .4201 L
.8179 .41897 L
.83814 .41749 L
.85666 .4158 L
.89635 .41131 L
.93453 .40637 L
.97517 .40103 L
.97619 .4009 L
Mfstroke
.387 0 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03477 L
.02729 .04318 L
.02846 .04891 L
.02954 .05244 L
.03053 .0545 L
.03163 .05576 L
.03279 .05633 L
.03395 .05635 L
.0352 .05598 L
.03638 .05538 L
.03746 .05469 L
.04262 .05062 L
.0529 .04233 L
.06244 .03603 L
.07277 .03079 L
.08405 .02657 L
.09398 .02385 L
.10458 .02171 L
.11487 .02019 L
.12599 .019 L
.1365 .01819 L
.14616 .01764 L
.1559 .01723 L
.16499 .01694 L
.17496 .01671 L
.18565 .01652 L
.19582 .0164 L
.20119 .01635 L
.20689 .0163 L
.21186 .01627 L
.21734 .01624 L
.22701 .01619 L
.23193 .01618 L
.2371 .01617 L
.24152 .01616 L
.24636 .01615 L
.24909 .01615 L
.25158 .01614 L
.25296 .01614 L
.25445 .01614 L
.25574 .01614 L
.25716 .01614 L
.25847 .01614 L
.2597 .01614 L
.261 .01614 L
.26173 .01614 L
.26239 .01614 L
.26358 .01614 L
Mistroke
.26487 .01614 L
.26608 .01614 L
.26721 .01614 L
.27231 .01614 L
.27498 .01614 L
.27781 .01614 L
.27901 .01614 L
.28029 .01614 L
.28102 .01614 L
.28169 .01614 L
.283 .01615 L
.28418 .01615 L
.28546 .01615 L
.28666 .01614 L
.28778 .01614 L
.28884 .01614 L
.28999 .01614 L
.29207 .01614 L
.29455 .01614 L
.29681 .01614 L
.3064 .01613 L
.32696 .01611 L
.34607 .01609 L
.35557 .01608 L
.36453 .01607 L
.37486 .01607 L
.38423 .01606 L
.39398 .01606 L
.39889 .01606 L
.40429 .01606 L
.41383 .01606 L
.42275 .01606 L
.46163 .01605 L
.50296 .01605 L
.52363 .01605 L
.54277 .01605 L
.56251 .01604 L
.58107 .01604 L
.59971 .01604 L
.6203 .01604 L
.64046 .01604 L
.65896 .01604 L
.67786 .01604 L
.69855 .01604 L
.71813 .01604 L
.7291 .01604 L
.73908 .01604 L
.74904 .01604 L
.75824 .01604 L
.76833 .01604 L
Mistroke
.77342 .01604 L
.77903 .01604 L
.78423 .01604 L
.78679 .01604 L
.78917 .01604 L
.7915 .01604 L
.79361 .01604 L
.79595 .01604 L
.79724 .01604 L
.79845 .01604 L
.79966 .01604 L
.80035 .01604 L
.80099 .01604 L
.80229 .01604 L
.80302 .01604 L
.80368 .01604 L
.80486 .01604 L
.80615 .01604 L
.80736 .01604 L
.80848 .01604 L
.81099 .01604 L
.81375 .01604 L
.81933 .01604 L
.82944 .01604 L
.8387 .01604 L
.85956 .01604 L
.8992 .01604 L
.93733 .01604 L
.97619 .01604 L
Mfstroke
.411 0 1 r
.02381 .01472 m
.03279 .09447 L
.04262 .16362 L
.04758 .19057 L
.05288 .21326 L
.05546 .22198 L
.05789 .22887 L
.06024 .23432 L
.06244 .23838 L
.06487 .24173 L
.06616 .24305 L
.06754 .24414 L
.06824 .24455 L
.06899 .24492 L
.0697 .24517 L
.07037 .24534 L
.07162 .24546 L
.07232 .24543 L
.07295 .24534 L
.0742 .245 L
.07535 .2445 L
.07661 .24377 L
.07794 .24279 L
.08265 .23792 L
.08806 .23019 L
.0931 .22164 L
.10458 .20021 L
.12322 .16732 L
.14349 .14016 L
.15452 .12939 L
.16473 .12161 L
.17448 .11589 L
.17989 .11335 L
.18485 .11138 L
.19422 .10853 L
.19914 .10745 L
.20164 .10701 L
.20432 .10662 L
.20669 .10634 L
.20884 .10614 L
.20988 .10607 L
.21101 .106 L
.21207 .10594 L
.21305 .10591 L
.21419 .10588 L
.21526 .10587 L
.21643 .10587 L
.21769 .10589 L
.21901 .10594 L
.22026 .106 L
Mistroke
.22138 .10607 L
.2226 .10617 L
.22516 .10645 L
.22793 .10687 L
.23054 .10738 L
.23294 .10796 L
.2375 .10939 L
.24231 .11149 L
.24749 .11463 L
.25232 .11866 L
.25762 .12475 L
.2633 .13369 L
.27293 .15449 L
.28315 .17791 L
.28848 .1874 L
.29151 .19155 L
.29436 .19455 L
.29562 .19563 L
.29696 .19658 L
.29811 .19726 L
.29934 .19784 L
.30004 .19811 L
.30067 .19831 L
.30191 .19861 L
.3026 .19872 L
.30335 .19879 L
.30406 .19882 L
.30471 .19881 L
.30592 .1987 L
.30702 .19851 L
.30828 .19818 L
.30949 .19777 L
.31163 .19683 L
.31395 .19553 L
.31922 .19166 L
.3241 .18725 L
.34461 .16563 L
.35434 .15597 L
.36484 .14706 L
.37475 .14039 L
.37946 .13788 L
.38384 .13595 L
.38808 .13448 L
.39045 .13385 L
.39261 .1334 L
.39376 .13321 L
.39498 .13304 L
.39561 .13298 L
.39631 .13292 L
.39755 .13285 L
Mistroke
.39871 .13283 L
.39995 .13286 L
.40113 .13294 L
.40221 .13306 L
.4034 .13324 L
.40467 .1335 L
.40695 .13416 L
.40835 .13468 L
.40967 .13528 L
.41213 .13666 L
.41666 .14026 L
.41921 .143 L
.42156 .14603 L
.42627 .1538 L
.43131 .16485 L
.4404 .19187 L
.46107 .26774 L
.47125 .29846 L
.477 .31157 L
.48232 .3207 L
.48456 .32368 L
.48696 .32632 L
.48961 .32857 L
.49208 .33007 L
.49334 .33062 L
.49472 .33106 L
.49541 .33121 L
.49616 .33133 L
.49686 .3314 L
.49749 .33143 L
.49872 .3314 L
.49941 .33132 L
.50004 .33122 L
.50121 .33095 L
.50245 .33055 L
.50366 .33006 L
.50498 .3294 L
.50739 .32791 L
.5119 .32417 L
.52204 .31225 L
.54036 .28424 L
.56173 .25156 L
.58107 .22778 L
.59079 .21835 L
.60128 .20992 L
.62028 .19837 L
.64027 .1897 L
.66135 .18248 L
.6994 .17111 L
.73989 .16067 L
Mistroke
.77887 .15321 L
.80017 .15026 L
.82031 .14806 L
.85871 .14501 L
.87854 .14384 L
.89956 .1428 L
.93738 .14137 L
.95608 .14084 L
.97619 .14038 L
Mfstroke
.435 0 1 r
.02381 .01472 m
.02846 .05752 L
.03279 .09151 L
.03523 .10714 L
.03754 .11928 L
.0402 .13007 L
.04135 .13372 L
.04262 .13707 L
.04377 .13954 L
.04502 .14163 L
.04633 .14324 L
.04756 .14425 L
.04878 .14482 L
.04994 .145 L
.05099 .1449 L
.05212 .14454 L
.05282 .1442 L
.05348 .1438 L
.05471 .14288 L
.05748 .14011 L
.06244 .13345 L
.08439 .0989 L
.09401 .08614 L
.10458 .07466 L
.11363 .06677 L
.12333 .06 L
.13357 .05442 L
.14313 .0504 L
.1533 .04711 L
.16437 .04444 L
.17482 .0426 L
.18449 .04135 L
.18912 .04089 L
.19412 .04047 L
.19843 .04016 L
.20316 .0399 L
.20839 .03967 L
.21125 .03958 L
.2139 .03951 L
.21519 .03948 L
.2164 .03946 L
.2175 .03944 L
.21867 .03943 L
.21994 .03942 L
.22111 .03941 L
.22237 .03941 L
.22309 .03941 L
.22376 .03941 L
.22501 .03942 L
.22571 .03942 L
Mistroke
.22634 .03943 L
.22758 .03944 L
.22874 .03946 L
.23135 .03951 L
.23417 .0396 L
.23667 .0397 L
.23931 .03982 L
.24405 .04013 L
.24862 .04053 L
.25289 .04103 L
.25757 .04173 L
.26258 .04268 L
.27221 .04495 L
.27749 .0462 L
.28243 .04718 L
.28521 .04761 L
.28776 .04793 L
.29059 .04818 L
.29208 .04827 L
.2929 .04831 L
.29364 .04834 L
.29488 .04838 L
.29556 .04839 L
.2962 .0484 L
.29735 .0484 L
.29859 .04839 L
.29924 .04838 L
.29996 .04836 L
.3014 .04832 L
.30274 .04826 L
.304 .04819 L
.30916 .0478 L
.31406 .04731 L
.32324 .04621 L
.34389 .04361 L
.35353 .04256 L
.36378 .04161 L
.37338 .04088 L
.38219 .04035 L
.39154 .03992 L
.39636 .03974 L
.40164 .03957 L
.41053 .03936 L
.41539 .03928 L
.41991 .03921 L
.43041 .03908 L
.44034 .03899 L
.44925 .03892 L
.45425 .03889 L
.45669 .03888 L
Mistroke
.45892 .03887 L
.4611 .03886 L
.46347 .03885 L
.46478 .03885 L
.46599 .03885 L
.46714 .03884 L
.46837 .03884 L
.46907 .03884 L
.46972 .03884 L
.47043 .03884 L
.47118 .03884 L
.47244 .03884 L
.47316 .03885 L
.47383 .03885 L
.47622 .03885 L
.47755 .03886 L
.47877 .03886 L
.48395 .03888 L
.48958 .03892 L
.49981 .03901 L
.54061 .0395 L
.56088 .03975 L
.5799 .04002 L
.61767 .04074 L
.65637 .04175 L
.69753 .04283 L
.71808 .04328 L
.73718 .04364 L
.77531 .04418 L
.81437 .04459 L
.83573 .04476 L
.85589 .04488 L
.87592 .04498 L
.89438 .04505 L
.90408 .04507 L
.91315 .04509 L
.92311 .04511 L
.9287 .04512 L
.9338 .04512 L
.93859 .04512 L
.94126 .04513 L
.94368 .04513 L
.94595 .04513 L
.94723 .04513 L
.9484 .04513 L
.94943 .04513 L
.95056 .04513 L
.95174 .04513 L
.95284 .04513 L
.95413 .04513 L
Mistroke
.95486 .04513 L
.95553 .04513 L
.95677 .04513 L
.95808 .04513 L
.96035 .04513 L
.96286 .04513 L
.96552 .04513 L
.96839 .04512 L
.97358 .04512 L
.97619 .04512 L
Mfstroke
.458 0 1 r
.02381 .01472 m
.03279 .09421 L
.03793 .1315 L
.04262 .15861 L
.045 .16961 L
.04758 .17935 L
.04899 .18373 L
.0503 .18718 L
.05164 .1901 L
.05288 .19233 L
.05404 .19396 L
.05509 .19512 L
.05626 .19603 L
.05752 .1966 L
.05873 .19677 L
.06005 .19657 L
.06129 .19605 L
.06244 .19529 L
.06382 .19407 L
.06509 .19269 L
.06795 .18876 L
.07314 .17957 L
.08284 .15909 L
.10458 .11604 L
.1234 .08971 L
.13409 .07903 L
.14407 .07128 L
.15452 .06504 L
.16442 .06053 L
.17331 .05743 L
.18298 .05486 L
.19238 .05302 L
.19773 .05222 L
.20275 .05161 L
.20802 .05111 L
.21286 .05077 L
.2154 .05063 L
.21817 .05051 L
.21957 .05047 L
.22106 .05043 L
.22179 .05041 L
.22248 .0504 L
.22376 .05039 L
.22491 .05038 L
.22615 .05038 L
.22732 .05038 L
.22839 .05039 L
.22964 .05042 L
.231 .05045 L
.23229 .05049 L
Mistroke
.23348 .05053 L
.2361 .05066 L
.23846 .05082 L
.2412 .05104 L
.24377 .05131 L
.24839 .05194 L
.25264 .05272 L
.2573 .05386 L
.26222 .05544 L
.27245 .0599 L
.27748 .06236 L
.28213 .06446 L
.28626 .06602 L
.29081 .06731 L
.29318 .06778 L
.29539 .06811 L
.29661 .06824 L
.29773 .06834 L
.29896 .06841 L
.30025 .06845 L
.30148 .06846 L
.30259 .06845 L
.30388 .06841 L
.30509 .06834 L
.30622 .06826 L
.30725 .06817 L
.30959 .06791 L
.31455 .06716 L
.3198 .06614 L
.34072 .06122 L
.35091 .05894 L
.36056 .05708 L
.36996 .05558 L
.37866 .0545 L
.3831 .05407 L
.38799 .05368 L
.39036 .05353 L
.39292 .0534 L
.39432 .05334 L
.39561 .05329 L
.39684 .05326 L
.39815 .05323 L
.39947 .05321 L
.40067 .0532 L
.40187 .0532 L
.40301 .05321 L
.40365 .05321 L
.40434 .05322 L
.40556 .05325 L
.40688 .05329 L
Mistroke
.40833 .05335 L
.411 .05351 L
.41387 .05374 L
.41658 .05403 L
.41906 .05436 L
.42383 .05518 L
.42891 .05637 L
.43806 .05932 L
.45878 .06839 L
.46908 .07232 L
.4719 .07317 L
.47488 .07393 L
.47745 .07447 L
.48021 .07495 L
.48282 .07529 L
.48519 .07551 L
.48633 .07558 L
.48757 .07565 L
.48875 .07569 L
.48983 .07571 L
.49109 .07571 L
.49227 .0757 L
.49356 .07566 L
.49429 .07563 L
.49495 .0756 L
.4976 .07543 L
.49893 .07532 L
.50039 .07517 L
.50568 .0745 L
.51067 .07368 L
.52001 .07183 L
.54097 .06712 L
.5593 .06331 L
.57945 .05996 L
.59934 .05755 L
.61022 .05655 L
.62039 .05578 L
.6407 .0546 L
.65924 .0538 L
.69902 .05252 L
.73728 .05158 L
.75866 .05117 L
.778 .05087 L
.8172 .05041 L
.8365 .05026 L
.85734 .05012 L
.87694 .05002 L
.89842 .04993 L
.91753 .04986 L
.93798 .0498 L
Mistroke
.97619 .04971 L
Mfstroke
.482 0 1 r
.02381 .01472 m
.02846 .05768 L
.03279 .09298 L
.03793 .12702 L
.04262 .14968 L
.04498 .15813 L
.04754 .16519 L
.04872 .16774 L
.04996 .17 L
.05113 .17173 L
.0522 .17299 L
.05341 .17409 L
.05471 .17489 L
.05592 .17531 L
.05707 .17545 L
.05772 .17542 L
.05841 .17531 L
.05964 .17492 L
.0604 .17457 L
.06111 .17416 L
.06244 .17323 L
.06489 .17101 L
.06757 .16793 L
.07299 .16034 L
.08269 .14463 L
.10458 .11149 L
.12409 .09031 L
.13503 .08176 L
.145 .07568 L
.15492 .07096 L
.16409 .06758 L
.17416 .06475 L
.17973 .06353 L
.18485 .06258 L
.19422 .06127 L
.19914 .06077 L
.20164 .06057 L
.20432 .06039 L
.20669 .06025 L
.20884 .06015 L
.21101 .06008 L
.21198 .06005 L
.21305 .06003 L
.21421 .06001 L
.21543 .05999 L
.21657 .05999 L
.21763 .05999 L
.21888 .06 L
.22003 .06001 L
.22135 .06004 L
Mistroke
.2226 .06007 L
.2252 .06017 L
.22764 .0603 L
.22984 .06045 L
.23221 .06065 L
.23481 .06092 L
.23754 .06127 L
.24245 .06208 L
.24699 .06309 L
.25122 .06434 L
.25587 .06611 L
.26085 .06859 L
.27048 .07505 L
.28069 .08222 L
.28326 .08364 L
.28603 .0849 L
.28761 .08549 L
.28906 .08595 L
.29053 .08634 L
.2919 .08663 L
.29307 .08682 L
.29432 .08697 L
.29503 .08704 L
.2957 .08708 L
.29695 .08713 L
.2976 .08714 L
.29828 .08713 L
.2995 .08708 L
.30081 .08699 L
.30156 .08692 L
.30226 .08684 L
.30473 .08647 L
.30742 .08593 L
.31232 .08467 L
.32151 .08166 L
.34216 .0743 L
.36191 .06859 L
.37188 .06642 L
.38291 .06457 L
.39298 .06333 L
.40223 .06253 L
.40708 .06222 L
.41238 .06196 L
.41506 .06186 L
.41792 .06177 L
.42037 .0617 L
.42308 .06165 L
.42566 .06161 L
.42707 .06159 L
.4284 .06158 L
Mistroke
.42963 .06157 L
.43076 .06157 L
.43206 .06157 L
.4333 .06157 L
.434 .06157 L
.43464 .06157 L
.43537 .06158 L
.43605 .06158 L
.43728 .0616 L
.43861 .06161 L
.44162 .06167 L
.4444 .06174 L
.44907 .06191 L
.4542 .06217 L
.45955 .06253 L
.46454 .06294 L
.48491 .06528 L
.50347 .06784 L
.54334 .07265 L
.58169 .07691 L
.60147 .07981 L
.62249 .08361 L
.66026 .09135 L
.68125 .09528 L
.70048 .09827 L
.71934 .10058 L
.73919 .10244 L
.75894 .10383 L
.77732 .10484 L
.79779 .10571 L
.81638 .10631 L
.82637 .10656 L
.83558 .10674 L
.84569 .1069 L
.85078 .10695 L
.85638 .10701 L
.85888 .10702 L
.8616 .10704 L
.864 .10705 L
.86656 .10706 L
.86786 .10707 L
.86909 .10707 L
.87019 .10707 L
.87138 .10707 L
.87251 .10707 L
.87371 .10707 L
.87473 .10707 L
.87585 .10707 L
.87652 .10707 L
.87725 .10707 L
Mistroke
.87858 .10707 L
.87988 .10707 L
.88107 .10706 L
.88379 .10706 L
.88666 .10704 L
.89146 .10702 L
.89674 .10698 L
.90687 .10687 L
.91614 .10676 L
.93702 .10641 L
.97619 .10556 L
Mfstroke
.506 0 1 r
.02381 .01472 m
.03279 .0943 L
.04262 .161 L
.04758 .18509 L
.0503 .19549 L
.05288 .2035 L
.05528 .20939 L
.05655 .21192 L
.05789 .21417 L
.05902 .21574 L
.06026 .21713 L
.06139 .21811 L
.06244 .21878 L
.0631 .21908 L
.06379 .21932 L
.06504 .21951 L
.06581 .21949 L
.06653 .21938 L
.06718 .21921 L
.06788 .21895 L
.06919 .21826 L
.07057 .21728 L
.07305 .21493 L
.07767 .20885 L
.08274 .20042 L
.10458 .1584 L
.12409 .12702 L
.13503 .11368 L
.145 .10396 L
.15426 .09677 L
.16409 .09074 L
.17487 .08574 L
.18485 .08236 L
.19422 .08009 L
.19949 .07916 L
.20432 .07851 L
.20857 .07809 L
.21098 .07791 L
.21322 .07779 L
.21445 .07774 L
.2156 .07771 L
.21664 .07768 L
.21776 .07767 L
.21898 .07767 L
.22028 .07768 L
.22138 .0777 L
.2226 .07773 L
.22389 .07778 L
.22509 .07784 L
.22781 .07804 L
Mistroke
.23021 .07827 L
.23276 .07859 L
.23764 .07943 L
.24205 .08051 L
.24722 .08228 L
.25014 .08356 L
.25281 .08498 L
.25774 .08829 L
.26294 .09295 L
.27317 .10549 L
.2782 .11225 L
.28284 .11789 L
.28706 .12207 L
.28921 .12378 L
.29153 .12529 L
.29384 .12646 L
.29602 .12724 L
.29728 .12757 L
.29796 .12771 L
.2986 .12781 L
.29973 .12795 L
.30096 .12802 L
.30219 .12801 L
.30288 .12797 L
.30352 .12792 L
.30469 .12778 L
.30592 .12756 L
.30807 .12705 L
.31042 .12631 L
.31564 .1241 L
.32051 .12154 L
.34144 .10867 L
.36005 .09865 L
.37057 .09435 L
.38032 .09137 L
.3852 .09025 L
.3906 .08933 L
.39331 .089 L
.39484 .08886 L
.39624 .08875 L
.39747 .08868 L
.39816 .08865 L
.39881 .08863 L
.40013 .08861 L
.40086 .08862 L
.40153 .08862 L
.40278 .08866 L
.40342 .08869 L
.40411 .08873 L
.40534 .08883 L
Mistroke
.40649 .08895 L
.40909 .08932 L
.41054 .0896 L
.41187 .08991 L
.41427 .09058 L
.41688 .09152 L
.42165 .09384 L
.4242 .09546 L
.42696 .09755 L
.43197 .10226 L
.44133 .11449 L
.46231 .15247 L
.47263 .17 L
.48226 .18228 L
.48711 .18668 L
.4896 .18847 L
.49231 .19006 L
.49527 .1914 L
.49663 .19188 L
.49808 .1923 L
.49938 .1926 L
.50007 .19273 L
.50081 .19285 L
.50211 .19301 L
.50333 .1931 L
.50459 .19314 L
.50573 .19313 L
.50705 .19305 L
.5083 .19294 L
.50945 .19278 L
.51051 .19261 L
.51291 .1921 L
.51534 .19144 L
.518 .19057 L
.52339 .18841 L
.54449 .17749 L
.55532 .17187 L
.56559 .16719 L
.57559 .16345 L
.58485 .16074 L
.59386 .15878 L
.60344 .1573 L
.60892 .15668 L
.61408 .15621 L
.6237 .15553 L
.64213 .15442 L
.65258 .15363 L
.66232 .15267 L
.68231 .14997 L
.7034 .14628 L
Mistroke
.74238 .13896 L
.76224 .13568 L
.78381 .13269 L
.82373 .12856 L
.84355 .12701 L
.86458 .12561 L
.9024 .12355 L
.94268 .12188 L
.97619 .12086 L
Mfstroke
.53 0 1 r
.02381 .01472 m
.02605 .03539 L
.02729 .04524 L
.02846 .05319 L
.02954 .05933 L
.03072 .06462 L
.0318 .0683 L
.03279 .07087 L
.03396 .07302 L
.03506 .07434 L
.03626 .07516 L
.03756 .07548 L
.03821 .07547 L
.03891 .07534 L
.0402 .07488 L
.04145 .07419 L
.04262 .07339 L
.06244 .05448 L
.07295 .04604 L
.08284 .03977 L
.09424 .03428 L
.10458 .03057 L
.11434 .02793 L
.12466 .02582 L
.13346 .02445 L
.14313 .0233 L
.15334 .02239 L
.16264 .02177 L
.17338 .02124 L
.18355 .02087 L
.19321 .02062 L
.1985 .02052 L
.20346 .02043 L
.21222 .02032 L
.21687 .02028 L
.21929 .02026 L
.22188 .02024 L
.22448 .02023 L
.22684 .02022 L
.22922 .02021 L
.23028 .02021 L
.23146 .02021 L
.23273 .0202 L
.23342 .0202 L
.23407 .0202 L
.23523 .0202 L
.23648 .0202 L
.23718 .0202 L
.23794 .0202 L
.23866 .0202 L
Mistroke
.23932 .0202 L
.24058 .02021 L
.24192 .02021 L
.24467 .02022 L
.24763 .02023 L
.25043 .02025 L
.253 .02027 L
.25788 .02032 L
.26302 .02039 L
.27253 .02054 L
.27776 .02062 L
.28033 .02065 L
.2827 .02067 L
.28489 .02069 L
.2873 .02071 L
.28847 .02072 L
.28973 .02072 L
.29106 .02073 L
.2923 .02073 L
.29337 .02073 L
.29453 .02074 L
.29574 .02074 L
.29687 .02073 L
.29793 .02073 L
.29889 .02073 L
.30105 .02072 L
.30337 .02071 L
.30591 .0207 L
.31106 .02066 L
.32027 .02057 L
.34108 .02036 L
.36057 .02019 L
.3715 .02012 L
.38147 .02007 L
.39137 .02004 L
.40054 .02001 L
.40531 .02 L
.41059 .02 L
.42129 .01998 L
.46146 .01995 L
.47991 .01993 L
.49037 .01992 L
.49547 .01992 L
.50011 .01992 L
.50475 .01992 L
.50979 .01992 L
.51255 .01992 L
.51511 .01992 L
.51754 .01991 L
.5189 .01991 L
Mistroke
.52013 .01991 L
.52132 .01991 L
.52263 .01991 L
.52334 .01991 L
.52401 .01991 L
.52531 .01991 L
.52655 .01991 L
.52766 .01991 L
.52895 .01991 L
.53017 .01991 L
.53081 .01991 L
.53151 .01991 L
.53294 .01991 L
.53548 .01991 L
.53845 .01991 L
.54122 .01992 L
.54623 .01992 L
.55168 .01992 L
.56159 .01992 L
.57123 .01992 L
.58015 .01993 L
.59883 .01994 L
.61944 .01995 L
.65966 .01999 L
.69837 .02003 L
.73953 .02006 L
.77917 .02009 L
.8173 .0201 L
.83857 .02011 L
.85788 .02011 L
.87821 .02012 L
.89694 .02012 L
.91614 .02012 L
.92625 .02012 L
.93695 .02013 L
.94639 .02013 L
.95654 .02013 L
.96145 .02013 L
.96611 .02013 L
.97485 .02013 L
.97619 .02013 L
Mfstroke
.553 0 1 r
.02381 .01472 m
.02846 .05724 L
.03279 .08891 L
.03527 .10197 L
.03754 .11037 L
.03879 .11367 L
.03945 .11506 L
.04015 .11629 L
.04143 .11793 L
.04262 .11882 L
.04384 .1192 L
.04496 .11914 L
.04626 .11865 L
.04749 .11784 L
.04862 .11686 L
.04967 .11577 L
.05205 .11283 L
.06244 .09674 L
.07382 .0795 L
.08454 .06614 L
.09417 .05663 L
.10458 .04863 L
.11449 .0428 L
.12496 .03813 L
.1339 .03509 L
.14371 .03252 L
.15391 .03051 L
.16322 .02914 L
.17396 .02795 L
.18413 .02714 L
.19379 .02658 L
.19866 .02637 L
.20404 .02617 L
.20862 .02603 L
.21354 .02591 L
.2182 .02582 L
.22246 .02577 L
.22495 .02574 L
.2272 .02573 L
.22845 .02572 L
.22911 .02572 L
.22981 .02571 L
.23109 .02571 L
.23227 .02571 L
.23335 .02571 L
.23451 .02571 L
.23561 .02571 L
.23661 .02572 L
.23778 .02572 L
.23906 .02573 L
Mistroke
.24139 .02575 L
.24412 .02579 L
.24659 .02583 L
.25213 .02595 L
.25726 .02611 L
.26209 .0263 L
.27098 .02674 L
.27587 .02699 L
.2805 .02719 L
.28312 .02728 L
.28597 .02736 L
.28723 .02739 L
.28856 .02742 L
.28981 .02744 L
.29095 .02746 L
.2921 .02747 L
.29334 .02748 L
.29443 .02748 L
.29558 .02748 L
.29685 .02748 L
.29802 .02748 L
.29931 .02747 L
.30004 .02746 L
.30069 .02746 L
.30326 .02743 L
.30563 .02739 L
.31097 .02727 L
.32067 .02701 L
.34175 .02636 L
.36055 .02588 L
.37122 .02568 L
.3812 .02553 L
.39164 .02541 L
.39677 .02536 L
.40153 .02532 L
.41041 .02527 L
.4151 .02525 L
.42008 .02524 L
.4578 .02514 L
.47874 .02506 L
.49797 .02499 L
.51679 .02494 L
.52626 .02493 L
.53662 .02491 L
.5419 .0249 L
.54688 .0249 L
.55141 .0249 L
.55621 .02489 L
.5587 .02489 L
.56143 .02489 L
Mistroke
.56395 .02489 L
.56625 .02489 L
.56764 .02489 L
.56896 .02489 L
.57036 .02489 L
.57115 .02489 L
.57188 .02489 L
.57257 .02489 L
.57322 .02489 L
.57443 .02489 L
.57574 .02489 L
.57647 .02489 L
.57715 .02489 L
.57841 .02489 L
.57961 .02489 L
.58186 .02489 L
.58427 .02489 L
.5869 .02489 L
.59162 .02489 L
.59599 .02489 L
.60601 .0249 L
.61666 .02491 L
.63614 .02494 L
.65443 .02496 L
.69314 .02503 L
.7343 .0251 L
.77394 .02515 L
.81207 .02519 L
.85265 .02522 L
.89171 .02525 L
.91164 .02526 L
.93323 .02527 L
.97323 .02529 L
.97619 .02529 L
Mfstroke
.577 0 1 r
.02381 .01472 m
.02846 .05737 L
.03279 .08999 L
.03527 .10405 L
.03754 .1135 L
.03879 .11738 L
.03945 .11906 L
.04015 .12058 L
.04143 .1227 L
.04262 .12396 L
.04384 .12465 L
.04496 .12481 L
.04626 .1245 L
.04749 .12379 L
.04862 .12285 L
.04967 .12176 L
.05205 .11872 L
.06244 .10133 L
.07382 .08247 L
.08454 .06791 L
.09417 .0576 L
.10458 .04896 L
.11449 .0427 L
.12496 .03771 L
.1339 .03446 L
.14371 .03174 L
.15391 .02961 L
.16322 .02816 L
.17396 .02691 L
.18413 .02606 L
.19379 .02547 L
.19908 .02522 L
.20404 .02502 L
.2128 .02476 L
.21745 .02465 L
.21987 .02461 L
.22246 .02457 L
.22506 .02453 L
.22742 .02451 L
.22979 .02449 L
.23086 .02448 L
.23203 .02448 L
.2333 .02447 L
.234 .02447 L
.23465 .02447 L
.23581 .02447 L
.23706 .02447 L
.23776 .02447 L
.23852 .02447 L
.23924 .02447 L
Mistroke
.2399 .02447 L
.24116 .02448 L
.2425 .02449 L
.24525 .02451 L
.24679 .02452 L
.24821 .02454 L
.25358 .02463 L
.25846 .02475 L
.2636 .02491 L
.27311 .02524 L
.27833 .02542 L
.28091 .02549 L
.28328 .02555 L
.28547 .02559 L
.28788 .02562 L
.28914 .02564 L
.29031 .02565 L
.29155 .02566 L
.29225 .02566 L
.29288 .02566 L
.29394 .02566 L
.29492 .02566 L
.296 .02566 L
.29715 .02566 L
.29835 .02565 L
.2995 .02564 L
.30163 .02562 L
.30403 .02559 L
.30627 .02556 L
.31137 .02547 L
.32168 .02523 L
.34015 .02479 L
.35058 .02457 L
.36047 .02439 L
.36929 .02426 L
.37902 .02414 L
.38866 .02405 L
.39359 .02402 L
.39891 .02399 L
.40386 .02396 L
.4084 .02394 L
.41307 .02393 L
.41732 .02392 L
.42205 .02391 L
.42711 .0239 L
.43622 .02389 L
.44698 .02388 L
.45691 .02386 L
.46621 .02383 L
.47607 .0238 L
Mistroke
.49686 .02373 L
.51663 .02367 L
.53472 .02363 L
.54468 .02361 L
.55414 .0236 L
.56413 .02359 L
.56974 .02358 L
.57502 .02358 L
.57999 .02358 L
.58535 .02357 L
.58981 .02357 L
.59471 .02357 L
.60003 .02357 L
.60293 .02357 L
.60564 .02357 L
.60694 .02357 L
.60818 .02357 L
.6093 .02357 L
.61049 .02357 L
.61178 .02357 L
.61298 .02357 L
.61427 .02357 L
.615 .02357 L
.61569 .02357 L
.61687 .02357 L
.61812 .02357 L
.61931 .02357 L
.62039 .02357 L
.62303 .02357 L
.62553 .02357 L
.6305 .02357 L
.63589 .02357 L
.64552 .02357 L
.6544 .02358 L
.69382 .02359 L
.73173 .02361 L
.77209 .02363 L
.81093 .02364 L
.85223 .02365 L
.89201 .02366 L
.93027 .02367 L
.97099 .02368 L
.97619 .02368 L
Mfstroke
.601 0 1 r
.02381 .01472 m
.02846 .05705 L
.03068 .07403 L
.03279 .08692 L
.03398 .09267 L
.03527 .09761 L
.03645 .10097 L
.03754 .10319 L
.03871 .10475 L
.04 .1056 L
.04065 .10573 L
.04135 .10569 L
.04262 .1052 L
.04393 .10423 L
.04516 .10299 L
.04793 .09941 L
.05297 .09153 L
.06244 .0764 L
.07295 .06218 L
.08284 .05168 L
.09424 .04256 L
.10458 .03646 L
.11434 .03215 L
.12466 .02874 L
.13346 .02655 L
.14313 .02471 L
.15334 .02327 L
.16264 .02229 L
.17338 .02146 L
.18355 .02089 L
.19321 .02049 L
.20346 .02019 L
.21222 .02 L
.2172 .01992 L
.22188 .01986 L
.22658 .0198 L
.23172 .01976 L
.23431 .01975 L
.23708 .01973 L
.23842 .01973 L
.23969 .01972 L
.24082 .01972 L
.24207 .01972 L
.24323 .01972 L
.24431 .01972 L
.24546 .01972 L
.24669 .01972 L
.24783 .01972 L
.24891 .01972 L
.24989 .01972 L
Mistroke
.25095 .01972 L
.25337 .01973 L
.25594 .01974 L
.26057 .01977 L
.27088 .01985 L
.2763 .01989 L
.27926 .01991 L
.28202 .01993 L
.28445 .01994 L
.2858 .01994 L
.28704 .01995 L
.2877 .01995 L
.2884 .01995 L
.28916 .01995 L
.28987 .01995 L
.29114 .01995 L
.29186 .01995 L
.29254 .01995 L
.29373 .01995 L
.29497 .01995 L
.29603 .01994 L
.2972 .01994 L
.29979 .01993 L
.30221 .01992 L
.31276 .01985 L
.3227 .01978 L
.3413 .01963 L
.35105 .01957 L
.36136 .01951 L
.37101 .01947 L
.37982 .01944 L
.38928 .01941 L
.3945 .0194 L
.39944 .0194 L
.40369 .01939 L
.40821 .01939 L
.41057 .01938 L
.41317 .01938 L
.41776 .01938 L
.4201 .01938 L
.42267 .01938 L
.42535 .01938 L
.42784 .01938 L
.43231 .01938 L
.43708 .01938 L
.43978 .01938 L
.4427 .01937 L
.44546 .01937 L
.448 .01937 L
.45282 .01937 L
Mistroke
.45793 .01937 L
.46285 .01937 L
.46735 .01936 L
.47748 .01935 L
.49579 .01933 L
.51639 .01931 L
.53552 .01929 L
.55402 .01928 L
.56436 .01928 L
.57373 .01927 L
.58376 .01927 L
.59299 .01927 L
.60312 .01927 L
.61382 .01927 L
.6233 .01926 L
.63347 .01926 L
.6384 .01926 L
.64306 .01926 L
.65181 .01926 L
.6564 .01926 L
.66147 .01926 L
.66402 .01926 L
.66536 .01926 L
.66676 .01926 L
.668 .01926 L
.66936 .01926 L
.67059 .01926 L
.67173 .01926 L
.67288 .01926 L
.67413 .01926 L
.67531 .01926 L
.6764 .01926 L
.67738 .01926 L
.67846 .01926 L
.67959 .01926 L
.68064 .01926 L
.68304 .01926 L
.68523 .01926 L
.69016 .01926 L
.69494 .01926 L
.70004 .01926 L
.70919 .01926 L
.72994 .01926 L
.77159 .01926 L
.81173 .01927 L
.85035 .01927 L
.89143 .01927 L
.91191 .01927 L
.93099 .01927 L
.96903 .01927 L
Mistroke
.97619 .01927 L
Mfstroke
.625 0 1 r
.02381 .01472 m
.03279 .09422 L
.03793 .13162 L
.04262 .15904 L
.04758 .18047 L
.0503 .18889 L
.05156 .19197 L
.05288 .19472 L
.05402 .19667 L
.05527 .19839 L
.0564 .1996 L
.05747 .20044 L
.05872 .20108 L
.05987 .20135 L
.06119 .20132 L
.06244 .20097 L
.0631 .20068 L
.06381 .20028 L
.0651 .19935 L
.0675 .19698 L
.07031 .19335 L
.07289 .18938 L
.08259 .17139 L
.10458 .13007 L
.1234 .10384 L
.13409 .09295 L
.14407 .08497 L
.15452 .07849 L
.16442 .0738 L
.17331 .07057 L
.18298 .06791 L
.19238 .06606 L
.19773 .06528 L
.20275 .06471 L
.20532 .06448 L
.20802 .06428 L
.21033 .06414 L
.21286 .06402 L
.21429 .06397 L
.21559 .06394 L
.21631 .06393 L
.21709 .06391 L
.21783 .06391 L
.21851 .0639 L
.21972 .0639 L
.22041 .0639 L
.22106 .06391 L
.22236 .06393 L
.22309 .06395 L
.22376 .06397 L
Mistroke
.22505 .06401 L
.22627 .06406 L
.22854 .06418 L
.23099 .06436 L
.23363 .06461 L
.2384 .06522 L
.24278 .06601 L
.2476 .06718 L
.25287 .06895 L
.25838 .07149 L
.26352 .07459 L
.27258 .0815 L
.27754 .08538 L
.28219 .08851 L
.28481 .08994 L
.28721 .09102 L
.28987 .09193 L
.29127 .09229 L
.29274 .09259 L
.2939 .09277 L
.29515 .0929 L
.29633 .09298 L
.29739 .09301 L
.29865 .09299 L
.29936 .09296 L
.30001 .09292 L
.30121 .09282 L
.30248 .09266 L
.30501 .09223 L
.30772 .09162 L
.31262 .09021 L
.32376 .08609 L
.34389 .07824 L
.35405 .07486 L
.36511 .07182 L
.37555 .06957 L
.38522 .06801 L
.38984 .06743 L
.39483 .06691 L
.39954 .06653 L
.40386 .06627 L
.40634 .06616 L
.40865 .06608 L
.40998 .06604 L
.41118 .06602 L
.41185 .066 L
.41257 .06599 L
.41389 .06598 L
.41516 .06598 L
.41588 .06598 L
Mistroke
.41656 .06598 L
.41727 .06599 L
.41792 .066 L
.41867 .06601 L
.41939 .06602 L
.42064 .06605 L
.42181 .06608 L
.42446 .06619 L
.4271 .06633 L
.42954 .0665 L
.43503 .06704 L
.43988 .0677 L
.44499 .06861 L
.45387 .07075 L
.46361 .07389 L
.48477 .08245 L
.50405 .08985 L
.51363 .09279 L
.52405 .09539 L
.54298 .09896 L
.56238 .10211 L
.58378 .1063 L
.62307 .11719 L
.64406 .12325 L
.65324 .12552 L
.66329 .12761 L
.67306 .1292 L
.68215 .13028 L
.68718 .13072 L
.69175 .13102 L
.69428 .13115 L
.69702 .13127 L
.69961 .13136 L
.702 .13141 L
.70325 .13144 L
.70444 .13146 L
.70551 .13147 L
.70668 .13148 L
.70794 .13148 L
.70865 .13148 L
.70928 .13148 L
.71053 .13148 L
.7117 .13147 L
.71281 .13146 L
.71397 .13144 L
.71606 .13141 L
.71831 .13136 L
.72077 .13129 L
.72594 .13112 L
.73146 .13088 L
Mistroke
.74142 .13035 L
.78285 .1276 L
.82277 .12492 L
.86117 .12242 L
.90203 .11981 L
.94136 .11747 L
.97619 .11565 L
Mfstroke
.648 0 1 r
.02381 .01472 m
.02499 .02568 L
.02605 .03417 L
.02729 .04131 L
.02846 .0454 L
.02954 .04744 L
.03053 .04834 L
.03163 .04866 L
.03279 .04852 L
.03395 .04808 L
.0352 .04741 L
.03746 .04594 L
.04262 .04221 L
.0521 .03592 L
.06244 .03052 L
.07373 .02618 L
.08445 .02321 L
.09489 .0211 L
.10458 .01966 L
.11515 .01851 L
.1251 .01771 L
.13404 .01718 L
.14371 .01675 L
.15321 .01643 L
.16365 .01617 L
.17454 .01598 L
.18471 .01585 L
.19516 .01576 L
.20506 .01569 L
.21395 .01565 L
.22362 .01561 L
.23302 .01559 L
.23837 .01558 L
.2434 .01557 L
.24867 .01557 L
.25351 .01556 L
.25881 .01556 L
.26148 .01556 L
.2644 .01556 L
.30496 .01554 L
.3237 .01553 L
.34401 .01552 L
.35512 .01552 L
.36536 .01551 L
.37514 .01551 L
.38056 .01551 L
.38551 .01551 L
.39002 .01551 L
.39494 .01551 L
.39764 .01551 L
Mistroke
.40014 .01551 L
.40269 .01551 L
.40508 .01551 L
.40732 .01551 L
.4085 .01551 L
.40974 .01551 L
.41078 .01551 L
.41193 .01551 L
.41298 .01551 L
.41395 .01551 L
.41518 .01551 L
.41634 .01551 L
.41738 .01551 L
.41851 .01551 L
.41974 .01551 L
.42105 .01551 L
.42339 .01551 L
.43301 .01551 L
.44313 .01551 L
.44731 .01551 L
.4496 .01551 L
.45176 .01551 L
.45299 .01551 L
.45433 .01551 L
.45554 .01551 L
.45665 .01551 L
.45771 .01551 L
.45886 .01551 L
.46007 .01551 L
.4612 .01551 L
.4624 .01551 L
.46371 .01551 L
.46494 .01551 L
.46609 .01551 L
.46825 .01551 L
.47055 .01551 L
.47532 .01551 L
.48058 .01551 L
.49134 .01551 L
.50145 .01551 L
.54011 .01551 L
.56012 .01551 L
.57019 .01551 L
.58122 .0155 L
.6008 .0155 L
.61177 .0155 L
.62174 .0155 L
.66169 .0155 L
.70013 .0155 L
.71998 .0155 L
Mistroke
.74101 .0155 L
.77887 .0155 L
.79829 .0155 L
.81918 .0155 L
.86042 .0155 L
.90015 .0155 L
.93836 .0155 L
.97619 .0155 L
Mfstroke
.672 0 1 r
.02381 .01472 m
.02846 .05717 L
.03068 .07445 L
.03279 .08782 L
.03398 .0939 L
.03527 .09922 L
.03645 .1029 L
.03754 .10538 L
.03871 .10718 L
.04 .10823 L
.04065 .10844 L
.04135 .10846 L
.04262 .10803 L
.04393 .10707 L
.04516 .10582 L
.04793 .10211 L
.05297 .09382 L
.06244 .07791 L
.07295 .06301 L
.08284 .05205 L
.09424 .04256 L
.10458 .03623 L
.11434 .03176 L
.12466 .02824 L
.13346 .02598 L
.14313 .02409 L
.15334 .02261 L
.16264 .0216 L
.17338 .02074 L
.18355 .02016 L
.19321 .01975 L
.20346 .01943 L
.21222 .01923 L
.22188 .01908 L
.2268 .01902 L
.23198 .01897 L
.2364 .01894 L
.23888 .01892 L
.24123 .01891 L
.24397 .0189 L
.24518 .0189 L
.24646 .0189 L
.24785 .01889 L
.24913 .01889 L
.24985 .01889 L
.25052 .01889 L
.25125 .01889 L
.25204 .01889 L
.25332 .01889 L
.25405 .01889 L
Mistroke
.25473 .01889 L
.25597 .01889 L
.25729 .0189 L
.25981 .0189 L
.26209 .01891 L
.27147 .01895 L
.2766 .01897 L
.28137 .01899 L
.28387 .019 L
.28528 .019 L
.28655 .019 L
.28728 .01901 L
.28795 .01901 L
.28869 .01901 L
.28947 .01901 L
.29078 .01901 L
.29153 .01901 L
.29223 .01901 L
.29345 .01901 L
.29474 .019 L
.29584 .019 L
.29703 .019 L
.29972 .01899 L
.30221 .01898 L
.31276 .01893 L
.3227 .01887 L
.3413 .01876 L
.35105 .01871 L
.36136 .01867 L
.37101 .01863 L
.37982 .01861 L
.38928 .01859 L
.3945 .01858 L
.39944 .01858 L
.40369 .01857 L
.40821 .01857 L
.41317 .01857 L
.41776 .01857 L
.42232 .01856 L
.42712 .01856 L
.43238 .01856 L
.43721 .01856 L
.44593 .01856 L
.45548 .01856 L
.46031 .01856 L
.46555 .01856 L
.4705 .01856 L
.47507 .01856 L
.48039 .01856 L
.48603 .01855 L
Mistroke
.49601 .01855 L
.51556 .01854 L
.53386 .01853 L
.55242 .01852 L
.57266 .01851 L
.59381 .0185 L
.6139 .01849 L
.63359 .01849 L
.65457 .01849 L
.67599 .01849 L
.69617 .01848 L
.71456 .01848 L
.73474 .01848 L
.75469 .01848 L
.77576 .01848 L
.79529 .01848 L
.80623 .01848 L
.81621 .01848 L
.8353 .01848 L
.84609 .01848 L
.85607 .01848 L
.86506 .01848 L
.87475 .01848 L
.88538 .01848 L
.89055 .01848 L
.89536 .01848 L
.90038 .01848 L
.90494 .01848 L
.91 .01848 L
.91279 .01848 L
.91541 .01848 L
.91797 .01848 L
.91926 .01848 L
.92068 .01848 L
.92189 .01848 L
.92319 .01848 L
.92442 .01848 L
.92554 .01848 L
.92622 .01848 L
.92694 .01848 L
.92824 .01848 L
.92903 .01848 L
.92978 .01848 L
.93117 .01848 L
.93374 .01848 L
.93652 .01848 L
.94129 .01848 L
.94573 .01848 L
.95583 .01848 L
.96566 .01848 L
Mistroke
.97619 .01848 L
Mfstroke
.696 0 1 r
.02381 .01472 m
.03279 .09427 L
.03793 .13197 L
.04262 .16007 L
.04758 .18267 L
.0503 .19185 L
.05288 .19841 L
.05404 .20071 L
.05527 .20272 L
.05633 .20412 L
.05747 .20528 L
.05869 .20615 L
.05984 .20663 L
.06053 .20677 L
.0612 .20681 L
.06244 .20661 L
.0631 .20638 L
.06381 .20603 L
.0651 .20517 L
.06635 .20406 L
.0675 .20282 L
.07289 .19483 L
.08259 .17514 L
.10458 .12918 L
.1234 .10012 L
.13409 .08814 L
.14407 .0794 L
.15452 .07231 L
.16442 .06718 L
.17331 .06364 L
.18298 .0607 L
.19238 .0586 L
.19773 .05769 L
.20275 .05699 L
.20802 .05643 L
.21286 .05604 L
.2154 .05589 L
.21817 .05577 L
.21957 .05572 L
.22034 .0557 L
.22106 .05568 L
.22174 .05567 L
.22248 .05566 L
.22376 .05564 L
.22499 .05564 L
.22612 .05564 L
.22741 .05566 L
.22865 .05568 L
.22978 .05571 L
.23084 .05574 L
Mistroke
.23322 .05585 L
.23587 .05601 L
.23827 .05621 L
.24106 .0565 L
.24363 .05683 L
.24885 .05772 L
.25159 .05834 L
.25448 .05911 L
.25934 .06077 L
.26468 .06313 L
.27556 .06939 L
.28092 .0725 L
.28586 .0749 L
.29035 .0765 L
.29261 .07708 L
.29511 .07755 L
.29641 .07772 L
.2976 .07784 L
.29892 .07792 L
.29957 .07795 L
.30029 .07796 L
.30151 .07796 L
.30281 .07792 L
.30404 .07785 L
.30515 .07775 L
.30759 .07747 L
.31017 .07706 L
.31478 .07609 L
.32521 .07321 L
.34411 .0674 L
.35358 .0648 L
.36373 .06243 L
.37324 .06063 L
.38205 .05934 L
.38688 .05879 L
.39221 .05829 L
.39757 .05793 L
.40051 .05778 L
.40183 .05773 L
.40327 .05769 L
.40454 .05766 L
.40573 .05764 L
.40698 .05762 L
.40768 .05762 L
.40831 .05762 L
.40946 .05762 L
.41069 .05763 L
.41186 .05765 L
.41294 .05767 L
.41419 .05771 L
Mistroke
.41536 .05775 L
.41801 .05789 L
.4206 .05807 L
.42338 .05833 L
.42863 .059 L
.4335 .05986 L
.43884 .06109 L
.44453 .06273 L
.46463 .07029 L
.47492 .07401 L
.48034 .07558 L
.48329 .0763 L
.48605 .07687 L
.48868 .07733 L
.49107 .07767 L
.49372 .07796 L
.49518 .07809 L
.49656 .07818 L
.49773 .07825 L
.49897 .0783 L
.50003 .07833 L
.50119 .07834 L
.50244 .07835 L
.50315 .07834 L
.50379 .07834 L
.50498 .07831 L
.50623 .07827 L
.50747 .07821 L
.5088 .07814 L
.51124 .07797 L
.51578 .07754 L
.52599 .07616 L
.54436 .07301 L
.56386 .06971 L
.5742 .06821 L
.5853 .06684 L
.59594 .06576 L
.60567 .06496 L
.61556 .0643 L
.62472 .06379 L
.64376 .06297 L
.6645 .06227 L
.7037 .06103 L
.74536 .05979 L
.76628 .05927 L
.78549 .05887 L
.82412 .05827 L
.84299 .05805 L
.86368 .05785 L
.90417 .05755 L
Mistroke
.94315 .05734 L
.97619 .05722 L
Mfstroke
.719 0 1 r
.02381 .01472 m
.03279 .09422 L
.03793 .13165 L
.04262 .15917 L
.04758 .18084 L
.0503 .18945 L
.05156 .19264 L
.05288 .1955 L
.05402 .19756 L
.05527 .19941 L
.0564 .20073 L
.05747 .20167 L
.05872 .20243 L
.05987 .20281 L
.06119 .20291 L
.06244 .20268 L
.0631 .20244 L
.06381 .2021 L
.0651 .20128 L
.06635 .20024 L
.0675 .19909 L
.07289 .19179 L
.08259 .17398 L
.10458 .13211 L
.1234 .10516 L
.13409 .09392 L
.14407 .08566 L
.15452 .07893 L
.16442 .07405 L
.17331 .07068 L
.18298 .06791 L
.19238 .06595 L
.19773 .06512 L
.20275 .06452 L
.20532 .06427 L
.20802 .06405 L
.21036 .06389 L
.21286 .06376 L
.21427 .0637 L
.21556 .06366 L
.21685 .06363 L
.21806 .06361 L
.21875 .0636 L
.21949 .0636 L
.2208 .0636 L
.22153 .0636 L
.22221 .06361 L
.22295 .06362 L
.22376 .06364 L
.22509 .06367 L
Mistroke
.2263 .06372 L
.22901 .06386 L
.23153 .06403 L
.23389 .06425 L
.2392 .06493 L
.24219 .06545 L
.24493 .06603 L
.2496 .0673 L
.25471 .0692 L
.26005 .07188 L
.26503 .07512 L
.2741 .08238 L
.27906 .08636 L
.28371 .08955 L
.28633 .091 L
.28872 .09208 L
.29139 .093 L
.29278 .09336 L
.29425 .09366 L
.29542 .09384 L
.29667 .09398 L
.29784 .09406 L
.29891 .09409 L
.30017 .09408 L
.30087 .09405 L
.30153 .09401 L
.30273 .0939 L
.304 .09375 L
.30652 .09333 L
.30924 .09272 L
.31414 .0913 L
.32528 .08717 L
.34541 .07921 L
.35557 .07576 L
.36662 .07268 L
.37707 .07044 L
.38172 .06965 L
.38674 .06893 L
.39175 .06837 L
.39394 .06817 L
.39635 .06799 L
.39847 .06785 L
.40075 .06775 L
.402 .0677 L
.40314 .06767 L
.40429 .06765 L
.40538 .06763 L
.40657 .06763 L
.40787 .06764 L
.40853 .06765 L
Mistroke
.40924 .06766 L
.41052 .0677 L
.41179 .06775 L
.41299 .06781 L
.41526 .06796 L
.41791 .06821 L
.42038 .06851 L
.42329 .06895 L
.42597 .06946 L
.43105 .07072 L
.43655 .07256 L
.44651 .07728 L
.45556 .08305 L
.46512 .0902 L
.47533 .09811 L
.485 .10494 L
.49441 .11035 L
.50311 .11408 L
.50765 .11555 L
.51247 .11678 L
.5173 .11773 L
.52009 .11815 L
.52264 .11848 L
.52783 .11897 L
.53056 .11915 L
.53343 .1193 L
.53594 .1194 L
.53827 .11947 L
.54356 .11959 L
.54861 .11967 L
.55127 .11972 L
.55409 .11978 L
.55655 .11983 L
.55926 .11992 L
.56403 .12011 L
.56866 .12036 L
.57364 .12073 L
.58262 .12165 L
.59276 .12308 L
.60381 .12504 L
.62392 .12908 L
.63409 .131 L
.64365 .13254 L
.64894 .13324 L
.65466 .13386 L
.65986 .13429 L
.66236 .13445 L
.66464 .13457 L
.66706 .13467 L
.66936 .13475 L
Mistroke
.67062 .13478 L
.67178 .1348 L
.67305 .13481 L
.6737 .13482 L
.67441 .13482 L
.67559 .13482 L
.67667 .13482 L
.67792 .13481 L
.67911 .13479 L
.6802 .13477 L
.68121 .13475 L
.68351 .13469 L
.68622 .13458 L
.68876 .13446 L
.69352 .13418 L
.7042 .13331 L
.72426 .13109 L
.74273 .12878 L
.78221 .1242 L
.82017 .12075 L
.86058 .11781 L
.89948 .11539 L
.94083 .11325 L
.97619 .11178 L
Mfstroke
.743 0 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01974 L
.05285 .01855 L
.06244 .01769 L
.07218 .01702 L
.0829 .01647 L
.09334 .01608 L
.10458 .01578 L
.11468 .01558 L
.12571 .01542 L
.13613 .01531 L
.1458 .01524 L
.15637 .01518 L
.16633 .01514 L
.17526 .01511 L
.18493 .01509 L
.19444 .01507 L
.20487 .01506 L
.21013 .01506 L
.21577 .01505 L
.22594 .01505 L
.23122 .01504 L
.23611 .01504 L
.24137 .01504 L
.24718 .01504 L
.25221 .01504 L
.25693 .01504 L
.25954 .01504 L
.26192 .01504 L
.2673 .01504 L
.27722 .01504 L
.28278 .01504 L
.28782 .01504 L
.29765 .01503 L
.30692 .01503 L
.32543 .01503 L
.34503 .01503 L
.35456 .01503 L
.36504 .01503 L
.37458 .01503 L
.3835 .01503 L
.38848 .01503 L
.39111 .01503 L
Mistroke
.3939 .01503 L
.39659 .01503 L
.39903 .01503 L
.40148 .01503 L
.40378 .01503 L
.40604 .01503 L
.40718 .01503 L
.40843 .01503 L
.40949 .01503 L
.41064 .01503 L
.41171 .01503 L
.41269 .01503 L
.41393 .01503 L
.41507 .01503 L
.41632 .01503 L
.41764 .01503 L
.41987 .01503 L
.42232 .01503 L
.44333 .01503 L
.44778 .01503 L
.45253 .01503 L
.45526 .01503 L
.45774 .01503 L
.45893 .01503 L
.46023 .01503 L
.46144 .01503 L
.46258 .01503 L
.46367 .01503 L
.46485 .01503 L
.46616 .01503 L
.46736 .01503 L
.4686 .01503 L
.4693 .01503 L
.46995 .01503 L
.47114 .01503 L
.47241 .01503 L
.47463 .01503 L
.47671 .01503 L
.48146 .01503 L
.48644 .01503 L
.49101 .01503 L
.50132 .01503 L
.52182 .01503 L
.54091 .01503 L
.56049 .01503 L
.57898 .01503 L
.59942 .01503 L
.618 .01503 L
.65643 .01503 L
.69732 .01503 L
Mistroke
.71765 .01503 L
.73669 .01503 L
.77454 .01503 L
.79481 .01503 L
.81334 .01503 L
.85306 .01503 L
.89128 .01503 L
.93194 .01503 L
.97109 .01503 L
.97619 .01503 L
Mfstroke
.767 0 1 r
.02381 .01472 m
.02846 .05776 L
.03279 .09324 L
.03754 .12383 L
.0389 .13054 L
.0402 .13595 L
.04135 .13997 L
.04262 .14356 L
.04386 .14623 L
.04502 .14802 L
.04624 .14921 L
.04756 .14977 L
.04878 .1497 L
.04994 .14917 L
.05099 .14835 L
.05212 .14715 L
.05471 .14345 L
.05748 .13846 L
.06244 .12809 L
.07287 .10569 L
.08414 .08489 L
.09479 .06945 L
.10458 .05847 L
.11422 .05013 L
.1248 .04319 L
.13585 .03784 L
.14616 .03416 L
.15661 .0314 L
.16651 .02947 L
.1754 .02815 L
.18507 .02708 L
.19447 .0263 L
.20484 .02568 L
.21006 .02545 L
.21568 .02524 L
.22099 .02509 L
.22585 .02499 L
.23059 .02491 L
.23325 .02488 L
.2345 .02487 L
.23566 .02486 L
.23673 .02486 L
.23791 .02485 L
.23909 .02485 L
.24035 .02485 L
.24145 .02484 L
.24264 .02485 L
.24375 .02485 L
.24478 .02485 L
.24605 .02486 L
Mistroke
.24741 .02487 L
.24986 .02489 L
.25276 .02493 L
.2554 .02498 L
.26059 .0251 L
.26548 .02524 L
.27527 .02558 L
.28061 .02575 L
.28322 .02582 L
.28559 .02588 L
.28764 .02591 L
.28985 .02594 L
.29107 .02596 L
.2922 .02597 L
.29327 .02597 L
.29441 .02598 L
.29556 .02598 L
.29679 .02598 L
.29795 .02598 L
.29901 .02597 L
.30019 .02596 L
.30148 .02595 L
.30408 .02592 L
.30663 .02589 L
.30938 .02584 L
.31438 .02573 L
.32373 .0255 L
.34469 .02496 L
.36461 .02456 L
.37464 .02442 L
.3803 .02435 L
.38566 .0243 L
.39054 .02426 L
.39585 .02423 L
.39819 .02422 L
.40068 .02421 L
.40301 .0242 L
.40515 .02419 L
.40761 .02419 L
.40891 .02419 L
.41027 .02419 L
.41146 .02418 L
.41257 .02418 L
.41378 .02418 L
.41508 .02418 L
.41582 .02418 L
.4165 .02418 L
.41725 .02418 L
.41804 .02418 L
.41937 .02419 L
Mistroke
.42083 .02419 L
.42353 .02419 L
.42606 .0242 L
.43102 .02422 L
.43645 .02425 L
.44632 .02432 L
.46485 .02445 L
.47017 .02449 L
.47518 .02451 L
.47967 .02453 L
.48221 .02453 L
.48454 .02454 L
.48575 .02454 L
.48705 .02454 L
.48828 .02454 L
.4894 .02454 L
.49071 .02454 L
.49146 .02454 L
.49214 .02454 L
.4934 .02454 L
.49404 .02454 L
.49474 .02454 L
.49741 .02453 L
.5003 .02453 L
.50551 .02451 L
.51509 .02447 L
.52557 .02441 L
.54667 .02429 L
.56794 .02417 L
.58725 .02408 L
.60735 .02401 L
.62632 .02396 L
.64635 .02393 L
.66481 .0239 L
.70423 .02386 L
.74214 .02383 L
.76323 .02382 L
.7825 .02381 L
.80266 .0238 L
.82134 .02379 L
.84038 .02379 L
.86112 .02378 L
.90032 .02378 L
.92179 .02378 L
.94198 .02377 L
.95981 .02377 L
.97619 .02377 L
Mfstroke
.791 0 1 r
.02381 .01472 m
.02846 .05767 L
.03279 .09288 L
.03754 .12418 L
.04018 .13779 L
.04262 .14787 L
.04518 .15594 L
.04652 .15921 L
.04795 .16199 L
.04919 .16385 L
.05035 .16516 L
.05163 .16615 L
.05234 .16652 L
.053 .16674 L
.0542 .16688 L
.05531 .16672 L
.05654 .16627 L
.05784 .16549 L
.05908 .1645 L
.06026 .16336 L
.06244 .16079 L
.08439 .12309 L
.09401 .1073 L
.10458 .09267 L
.12333 .07354 L
.13357 .06615 L
.14313 .06078 L
.15358 .05627 L
.16348 .05303 L
.17237 .05082 L
.18204 .049 L
.19144 .04771 L
.19679 .04716 L
.20181 .04674 L
.20709 .04641 L
.21192 .04619 L
.21446 .04611 L
.21591 .04608 L
.21723 .04605 L
.21863 .04603 L
.2194 .04602 L
.22013 .04601 L
.22142 .046 L
.22215 .046 L
.22282 .046 L
.22407 .04601 L
.22526 .04602 L
.22633 .04603 L
.22749 .04605 L
.22876 .04608 L
Mistroke
.2301 .04612 L
.23252 .04621 L
.23497 .04632 L
.23727 .04646 L
.24158 .04679 L
.24676 .04736 L
.25151 .04807 L
.25672 .04911 L
.26222 .05056 L
.27245 .054 L
.27748 .0557 L
.28213 .05703 L
.28634 .05793 L
.28847 .05825 L
.29081 .05852 L
.29204 .05862 L
.29316 .05869 L
.29439 .05874 L
.29568 .05877 L
.29681 .05877 L
.29786 .05876 L
.29902 .05873 L
.30025 .05867 L
.30157 .05859 L
.30278 .0585 L
.30552 .05825 L
.3105 .05761 L
.3198 .05607 L
.34072 .05221 L
.35953 .04936 L
.3702 .04815 L
.38018 .04727 L
.38518 .04692 L
.39061 .0466 L
.39541 .04636 L
.40051 .04615 L
.40508 .04601 L
.41014 .04588 L
.41474 .0458 L
.41906 .04574 L
.42148 .04572 L
.42374 .0457 L
.42504 .0457 L
.42622 .04569 L
.42687 .04569 L
.42758 .04569 L
.42887 .04569 L
.43011 .04569 L
.43082 .04569 L
.43148 .04569 L
Mistroke
.43218 .04569 L
.43282 .0457 L
.43425 .0457 L
.43547 .04571 L
.4368 .04572 L
.43921 .04575 L
.44165 .04578 L
.44386 .04582 L
.44881 .04593 L
.45339 .04607 L
.45771 .04623 L
.46748 .0467 L
.4778 .04734 L
.49628 .04865 L
.53427 .05097 L
.57472 .0528 L
.61365 .0551 L
.65503 .05804 L
.67574 .05925 L
.68485 .05968 L
.69489 .06007 L
.70385 .06035 L
.71349 .06058 L
.71881 .06069 L
.72368 .06076 L
.73324 .06088 L
.73799 .06092 L
.74306 .06096 L
.74784 .06098 L
.75218 .061 L
.75484 .061 L
.75729 .06101 L
.75858 .06101 L
.75999 .06101 L
.7607 .06101 L
.76146 .06101 L
.76218 .06101 L
.76283 .06101 L
.76412 .06101 L
.7653 .06101 L
.76661 .06101 L
.76733 .06101 L
.76799 .06101 L
.7692 .06101 L
.77051 .06101 L
.77289 .06101 L
.77527 .061 L
.77782 .061 L
.78243 .06098 L
.79288 .06095 L
Mistroke
.80392 .0609 L
.81396 .06084 L
.85388 .06053 L
.89228 .06013 L
.93314 .05965 L
.97247 .05918 L
.97619 .05913 L
Mfstroke
.814 0 1 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02107 L
.04262 .01977 L
.05217 .01867 L
.06244 .01774 L
.0728 .01704 L
.0825 .01655 L
.09403 .01612 L
.10458 .01584 L
.11442 .01564 L
.12357 .01551 L
.1336 .01539 L
.14429 .01531 L
.15457 .01525 L
.1657 .0152 L
.17621 .01517 L
.18587 .01514 L
.19561 .01513 L
.2047 .01512 L
.21467 .01511 L
.22026 .0151 L
.22536 .0151 L
.23016 .0151 L
.23527 .0151 L
.23969 .0151 L
.24444 .01509 L
.2471 .01509 L
.24953 .01509 L
.25201 .01509 L
.25431 .01509 L
.25685 .01509 L
.25819 .01509 L
.25962 .01509 L
.26034 .01509 L
.26112 .01509 L
.26186 .01509 L
.26254 .01509 L
.26384 .01509 L
.26449 .01509 L
.2652 .01509 L
.2665 .01509 L
.2677 .01509 L
.27042 .01509 L
Mistroke
.27301 .01509 L
.27537 .01509 L
.27648 .01509 L
.27768 .01509 L
.27882 .01509 L
.27986 .01509 L
.28097 .01509 L
.28219 .01509 L
.28346 .01509 L
.28465 .01509 L
.28595 .01509 L
.28736 .01509 L
.28993 .01509 L
.29243 .01509 L
.29474 .01509 L
.29998 .01509 L
.30554 .01509 L
.32528 .01509 L
.34335 .01509 L
.35261 .01508 L
.36273 .01508 L
.3729 .01508 L
.37841 .01508 L
.3836 .01508 L
.38855 .01508 L
.3939 .01508 L
.40325 .01508 L
.40856 .01508 L
.41416 .01508 L
.42421 .01508 L
.46215 .01508 L
.48327 .01508 L
.50255 .01508 L
.5225 .01508 L
.54142 .01508 L
.55106 .01508 L
.56131 .01508 L
.57091 .01508 L
.57972 .01508 L
.58907 .01508 L
.59917 .01508 L
.61744 .01508 L
.63634 .01508 L
.65703 .01508 L
.67662 .01508 L
.68751 .01508 L
.69756 .01508 L
.70778 .01508 L
.71317 .01508 L
.71592 .01508 L
Mistroke
.71888 .01508 L
.72147 .01508 L
.72383 .01508 L
.72497 .01508 L
.72621 .01508 L
.72737 .01508 L
.72847 .01508 L
.72914 .01508 L
.72986 .01508 L
.73112 .01508 L
.73183 .01508 L
.73259 .01508 L
.73324 .01508 L
.73394 .01508 L
.73521 .01508 L
.73592 .01508 L
.73657 .01508 L
.73783 .01508 L
.73902 .01508 L
.74139 .01508 L
.74362 .01508 L
.74869 .01508 L
.75363 .01508 L
.75895 .01508 L
.77737 .01508 L
.81853 .01508 L
.85818 .01508 L
.89631 .01508 L
.93689 .01508 L
.97595 .01508 L
.97619 .01508 L
Mfstroke
.838 0 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03475 L
.02729 .04309 L
.02846 .04869 L
.02954 .05206 L
.03053 .05396 L
.03163 .05507 L
.03279 .05549 L
.03395 .05541 L
.0352 .05494 L
.03638 .05428 L
.03746 .05356 L
.04262 .04942 L
.0529 .04124 L
.06244 .03511 L
.07277 .03004 L
.08405 .02598 L
.09398 .02336 L
.10458 .02131 L
.11487 .01986 L
.12599 .01873 L
.1365 .01796 L
.14616 .01744 L
.1559 .01705 L
.16499 .01677 L
.17496 .01655 L
.18565 .01638 L
.19582 .01626 L
.20119 .01621 L
.20689 .01617 L
.21186 .01614 L
.21734 .01611 L
.22701 .01607 L
.23193 .01606 L
.2371 .01604 L
.24152 .01603 L
.24636 .01603 L
.24909 .01602 L
.25158 .01602 L
.25296 .01602 L
.25445 .01602 L
.25574 .01602 L
.25716 .01602 L
.25847 .01602 L
.2597 .01602 L
.261 .01602 L
.26173 .01602 L
.26239 .01602 L
.26358 .01602 L
Mistroke
.26487 .01602 L
.26608 .01602 L
.26721 .01602 L
.26987 .01602 L
.27231 .01602 L
.27493 .01602 L
.27642 .01602 L
.27713 .01602 L
.27781 .01602 L
.27903 .01602 L
.28015 .01602 L
.28135 .01602 L
.28266 .01602 L
.28395 .01602 L
.2846 .01602 L
.28532 .01602 L
.28778 .01602 L
.29019 .01602 L
.2924 .01602 L
.29739 .01601 L
.3064 .01601 L
.32696 .01598 L
.34607 .01597 L
.35557 .01596 L
.36453 .01596 L
.37486 .01595 L
.38423 .01595 L
.38888 .01595 L
.39398 .01595 L
.39931 .01595 L
.40186 .01595 L
.40429 .01595 L
.40652 .01595 L
.40894 .01595 L
.41115 .01594 L
.41319 .01594 L
.41539 .01594 L
.41665 .01594 L
.41783 .01594 L
.41906 .01594 L
.4202 .01594 L
.42144 .01594 L
.42275 .01594 L
.42398 .01594 L
.42468 .01594 L
.42532 .01594 L
.42774 .01594 L
.43228 .01594 L
.43713 .01594 L
.4397 .01595 L
Mistroke
.44112 .01595 L
.44247 .01595 L
.44362 .01595 L
.44487 .01595 L
.44601 .01595 L
.44707 .01595 L
.44817 .01595 L
.44916 .01595 L
.4503 .01595 L
.45138 .01595 L
.45253 .01595 L
.45375 .01595 L
.45592 .01594 L
.45826 .01594 L
.46083 .01594 L
.46607 .01594 L
.47104 .01594 L
.48035 .01594 L
.50127 .01594 L
.5195 .01594 L
.53962 .01594 L
.55941 .01593 L
.57025 .01593 L
.58042 .01593 L
.59026 .01593 L
.60062 .01593 L
.61913 .01593 L
.62868 .01593 L
.63889 .01593 L
.65726 .01593 L
.66751 .01593 L
.67862 .01593 L
.68822 .01593 L
.69878 .01593 L
.70837 .01593 L
.71867 .01593 L
.72954 .01593 L
.73972 .01593 L
.74986 .01593 L
.75521 .01593 L
.76091 .01593 L
.76638 .01593 L
.77134 .01593 L
.78101 .01593 L
.78591 .01593 L
.79107 .01593 L
.80031 .01593 L
.81026 .01593 L
.82115 .01593 L
.84235 .01593 L
Mistroke
.86165 .01593 L
.88168 .01593 L
.90063 .01593 L
.93903 .01593 L
.97619 .01593 L
Mfstroke
.862 0 1 r
.02381 .01472 m
.02605 .0354 L
.02846 .05344 L
.02962 .06023 L
.03072 .06546 L
.0317 .06922 L
.03279 .07248 L
.03398 .07515 L
.03524 .0771 L
.03641 .07824 L
.0375 .07886 L
.03879 .07912 L
.03997 .07902 L
.04062 .07885 L
.04132 .07859 L
.04262 .07793 L
.04523 .07609 L
.04759 .07403 L
.0529 .06882 L
.06244 .05936 L
.07287 .05041 L
.08414 .04275 L
.09479 .03723 L
.10458 .03334 L
.11432 .03038 L
.1234 .02824 L
.13338 .02645 L
.14407 .02501 L
.15424 .024 L
.16531 .02319 L
.17576 .02264 L
.18543 .02227 L
.19506 .022 L
.20409 .02182 L
.20926 .02174 L
.21401 .02168 L
.21921 .02164 L
.22183 .02162 L
.22469 .0216 L
.22723 .02159 L
.22866 .02159 L
.22998 .02159 L
.23113 .02159 L
.2324 .02158 L
.23304 .02158 L
.23373 .02159 L
.23497 .02159 L
.23617 .02159 L
.23747 .02159 L
.2387 .02159 L
Mistroke
.23985 .0216 L
.24201 .02161 L
.24431 .02162 L
.24703 .02165 L
.24997 .02168 L
.2553 .02175 L
.26049 .02184 L
.26526 .02195 L
.27437 .02216 L
.27938 .02227 L
.28412 .02235 L
.2868 .02238 L
.28832 .02239 L
.28972 .0224 L
.2909 .02241 L
.29219 .02242 L
.29285 .02242 L
.29355 .02242 L
.29482 .02242 L
.29603 .02242 L
.29672 .02242 L
.29736 .02242 L
.29865 .02241 L
.29937 .02241 L
.30003 .02241 L
.30248 .02239 L
.3048 .02238 L
.30944 .02233 L
.31454 .02227 L
.32485 .02211 L
.34331 .02184 L
.3628 .0216 L
.37373 .02151 L
.38371 .02144 L
.3885 .02142 L
.3936 .02139 L
.40277 .02136 L
.40785 .02135 L
.41263 .02134 L
.41783 .02133 L
.42352 .02132 L
.43333 .02131 L
.43833 .02131 L
.44368 .02131 L
.44869 .0213 L
.45326 .0213 L
.45545 .0213 L
.45661 .0213 L
.45784 .0213 L
.45891 .0213 L
Mistroke
.46009 .0213 L
.46117 .0213 L
.46217 .0213 L
.46342 .0213 L
.46412 .0213 L
.46475 .0213 L
.46598 .0213 L
.46714 .0213 L
.4685 .0213 L
.46975 .0213 L
.47256 .0213 L
.47485 .0213 L
.47737 .0213 L
.48244 .02131 L
.49202 .02132 L
.50097 .02133 L
.53989 .02139 L
.58128 .02146 L
.62114 .02154 L
.65949 .02164 L
.67889 .02169 L
.70029 .02173 L
.72056 .02176 L
.73958 .02178 L
.75978 .0218 L
.77829 .02181 L
.79722 .02181 L
.80795 .02182 L
.81793 .02182 L
.82846 .02182 L
.83364 .02182 L
.8384 .02182 L
.84265 .02182 L
.84733 .02182 L
.84975 .02182 L
.85202 .02182 L
.85442 .02182 L
.85577 .02182 L
.857 .02182 L
.85829 .02182 L
.85951 .02182 L
.8606 .02182 L
.86178 .02182 L
.86307 .02182 L
.86372 .02182 L
.86444 .02182 L
.8657 .02182 L
.86688 .02182 L
.86919 .02182 L
.8713 .02182 L
Mistroke
.87603 .02182 L
.88114 .02182 L
.88669 .02182 L
.89678 .02182 L
.9166 .02182 L
.93763 .02181 L
.97545 .0218 L
.97619 .0218 L
Mfstroke
.885 0 1 r
.02381 .01472 m
.02499 .02569 L
.02605 .03426 L
.02729 .04169 L
.02846 .04626 L
.02954 .0488 L
.03053 .05013 L
.03163 .05085 L
.03279 .05105 L
.03395 .05088 L
.0352 .05042 L
.03638 .04983 L
.03746 .04919 L
.04262 .04565 L
.0529 .03865 L
.06244 .03334 L
.07277 .0289 L
.08405 .02533 L
.09398 .02301 L
.10458 .02118 L
.11487 .01988 L
.12599 .01886 L
.1365 .01817 L
.14616 .01769 L
.1559 .01734 L
.16499 .01709 L
.17496 .01689 L
.18565 .01673 L
.19582 .01662 L
.20119 .01658 L
.20689 .01654 L
.21186 .01651 L
.21734 .01649 L
.22701 .01645 L
.23193 .01644 L
.23461 .01644 L
.2371 .01643 L
.24152 .01643 L
.24386 .01642 L
.24507 .01642 L
.24636 .01642 L
.24703 .01642 L
.24776 .01642 L
.24905 .01642 L
.24978 .01642 L
.25057 .01642 L
.2513 .01642 L
.25198 .01642 L
.25328 .01642 L
.25402 .01642 L
Mistroke
.2547 .01642 L
.25595 .01642 L
.25728 .01642 L
.25997 .01643 L
.2625 .01643 L
.26721 .01643 L
.277 .01645 L
.27938 .01645 L
.28193 .01645 L
.28339 .01645 L
.28473 .01645 L
.28537 .01645 L
.28606 .01645 L
.28733 .01645 L
.28848 .01645 L
.28955 .01645 L
.29073 .01645 L
.29199 .01645 L
.29325 .01645 L
.29458 .01645 L
.29694 .01645 L
.30118 .01645 L
.30582 .01644 L
.32711 .01641 L
.34643 .01638 L
.35609 .01637 L
.36655 .01636 L
.37643 .01635 L
.38553 .01635 L
.39022 .01635 L
.39525 .01634 L
.39959 .01634 L
.40433 .01634 L
.40721 .01634 L
.40987 .01634 L
.41237 .01634 L
.41513 .01634 L
.4199 .01634 L
.42498 .01634 L
.43518 .01634 L
.44075 .01634 L
.44593 .01634 L
.45037 .01634 L
.45511 .01634 L
.46515 .01634 L
.50381 .01633 L
.51403 .01633 L
.52513 .01633 L
.53472 .01632 L
.54527 .01632 L
Mistroke
.55553 .01632 L
.56513 .01632 L
.57042 .01632 L
.57526 .01632 L
.58085 .01632 L
.58359 .01632 L
.58616 .01632 L
.58858 .01632 L
.59119 .01632 L
.59235 .01632 L
.59357 .01632 L
.59471 .01632 L
.59576 .01632 L
.59697 .01632 L
.59828 .01632 L
.59949 .01632 L
.60063 .01632 L
.60128 .01632 L
.60196 .01632 L
.60319 .01632 L
.60388 .01632 L
.60452 .01632 L
.60598 .01632 L
.60823 .01632 L
.6106 .01632 L
.61483 .01632 L
.61939 .01632 L
.62437 .01632 L
.644 .01632 L
.66495 .01632 L
.70647 .01632 L
.74647 .01633 L
.78496 .01633 L
.8259 .01633 L
.84627 .01633 L
.86532 .01633 L
.88477 .01633 L
.90323 .01633 L
.92353 .01633 L
.93251 .01633 L
.94207 .01633 L
.95137 .01633 L
.95978 .01633 L
.96824 .01633 L
.97619 .01633 L
Mfstroke
.909 0 1 r
.02381 .01472 m
.03279 .09418 L
.03793 .13142 L
.04262 .15852 L
.045 .16955 L
.04758 .17936 L
.04899 .1838 L
.0503 .1873 L
.05164 .19029 L
.05288 .19258 L
.05404 .19428 L
.05509 .19549 L
.05626 .19647 L
.05752 .19712 L
.05873 .19737 L
.06005 .19725 L
.06129 .1968 L
.06244 .1961 L
.06382 .19496 L
.06509 .19364 L
.06795 .18983 L
.07314 .18081 L
.08284 .16047 L
.10458 .11735 L
.1234 .09086 L
.13409 .08011 L
.14407 .07231 L
.15452 .06603 L
.16442 .06151 L
.17331 .05839 L
.18298 .05581 L
.19238 .05397 L
.19773 .05318 L
.20275 .05257 L
.20802 .05208 L
.21286 .05174 L
.2154 .05161 L
.21817 .0515 L
.21957 .05146 L
.22034 .05144 L
.22106 .05142 L
.22174 .05141 L
.22248 .0514 L
.22376 .05139 L
.22499 .05138 L
.22612 .05139 L
.22741 .0514 L
.22865 .05142 L
.22978 .05144 L
.23084 .05147 L
Mistroke
.23322 .05156 L
.23587 .0517 L
.23827 .05186 L
.24106 .0521 L
.24363 .05238 L
.24885 .05314 L
.25159 .05365 L
.25448 .0543 L
.25934 .05567 L
.26468 .0576 L
.27556 .06253 L
.28092 .06486 L
.28327 .06574 L
.28586 .06658 L
.28802 .06717 L
.29035 .06767 L
.29163 .06789 L
.29281 .06806 L
.29392 .06819 L
.29511 .0683 L
.29632 .06838 L
.29745 .06843 L
.29814 .06844 L
.29879 .06845 L
.3 .06844 L
.30129 .0684 L
.30248 .06833 L
.30378 .06824 L
.30515 .06811 L
.30978 .06748 L
.31475 .06656 L
.32372 .0645 L
.34411 .05947 L
.35427 .05731 L
.36533 .05535 L
.37577 .05391 L
.38042 .05339 L
.38544 .05291 L
.39045 .05251 L
.39505 .05221 L
.39945 .05199 L
.40408 .05182 L
.40654 .05175 L
.40792 .05173 L
.40917 .05171 L
.41034 .05169 L
.41161 .05168 L
.41281 .05168 L
.41391 .05168 L
.4152 .05168 L
Mistroke
.4164 .05169 L
.41772 .05171 L
.41914 .05173 L
.42062 .05177 L
.42203 .05181 L
.42468 .0519 L
.42727 .05203 L
.42971 .05217 L
.43427 .05251 L
.43919 .05299 L
.4445 .05365 L
.46289 .05682 L
.48245 .06057 L
.48781 .06143 L
.49355 .06222 L
.49894 .06282 L
.50391 .06325 L
.509 .06358 L
.51168 .0637 L
.51453 .06381 L
.51572 .06384 L
.517 .06387 L
.5181 .06389 L
.51931 .06391 L
.52065 .06393 L
.52138 .06393 L
.52206 .06394 L
.52328 .06394 L
.52458 .06394 L
.52585 .06394 L
.52702 .06393 L
.5283 .06392 L
.52966 .0639 L
.53195 .06386 L
.53445 .06381 L
.54342 .06355 L
.56452 .0628 L
.57451 .06249 L
.57938 .06238 L
.58378 .06229 L
.5884 .06222 L
.59094 .06219 L
.59332 .06217 L
.59459 .06216 L
.59592 .06215 L
.59708 .06215 L
.59832 .06214 L
.59901 .06214 L
.59965 .06214 L
.60089 .06213 L
Mistroke
.60159 .06213 L
.60234 .06213 L
.60305 .06213 L
.60371 .06213 L
.6048 .06214 L
.60597 .06214 L
.60707 .06214 L
.60808 .06215 L
.61055 .06216 L
.61289 .06217 L
.61754 .06221 L
.62262 .06227 L
.63359 .0624 L
.64393 .06251 L
.64844 .06256 L
.65321 .06259 L
.65571 .06261 L
.65703 .06261 L
.65844 .06262 L
.65975 .06262 L
.66093 .06262 L
.66213 .06263 L
.66326 .06263 L
.66441 .06263 L
.6655 .06263 L
.66669 .06263 L
.66797 .06262 L
.66925 .06262 L
.67059 .06262 L
.67299 .0626 L
.67521 .06259 L
.67729 .06258 L
.68199 .06253 L
.68715 .06247 L
.69184 .06239 L
.70237 .06219 L
.74234 .06114 L
.7808 .06013 L
.8217 .0593 L
.8611 .05871 L
.89897 .05826 L
.9393 .05787 L
.97619 .05759 L
Mfstroke
.933 0 1 r
.02381 .01472 m
.02499 .02577 L
.02605 .03477 L
.02729 .04318 L
.02846 .04892 L
.02954 .05246 L
.03053 .05452 L
.03163 .05581 L
.03279 .05638 L
.03395 .05641 L
.0352 .05605 L
.03638 .05546 L
.03746 .05478 L
.04262 .05073 L
.0529 .04244 L
.06244 .03612 L
.07277 .03086 L
.08405 .02662 L
.09398 .02388 L
.10458 .02173 L
.11487 .0202 L
.12599 .019 L
.1365 .01819 L
.14616 .01763 L
.1559 .01722 L
.16499 .01693 L
.17496 .01669 L
.18565 .01651 L
.19582 .01638 L
.20119 .01633 L
.20689 .01628 L
.21186 .01625 L
.21734 .01622 L
.22701 .01618 L
.23193 .01616 L
.2371 .01615 L
.24152 .01614 L
.24636 .01613 L
.24909 .01613 L
.25158 .01612 L
.25296 .01612 L
.25445 .01612 L
.25574 .01612 L
.25716 .01612 L
.25847 .01612 L
.2597 .01612 L
.261 .01612 L
.26173 .01612 L
.26239 .01612 L
.26358 .01612 L
Mistroke
.26487 .01612 L
.26608 .01612 L
.26721 .01612 L
.27231 .01612 L
.27498 .01612 L
.27645 .01612 L
.27781 .01612 L
.27911 .01612 L
.28029 .01612 L
.2816 .01612 L
.28232 .01612 L
.283 .01612 L
.28419 .01612 L
.28529 .01612 L
.2865 .01612 L
.28778 .01612 L
.28893 .01612 L
.28998 .01612 L
.29235 .01612 L
.29663 .01612 L
.30139 .01611 L
.3064 .01611 L
.3264 .01609 L
.34456 .01607 L
.35399 .01606 L
.36421 .01605 L
.375 .01605 L
.38026 .01604 L
.38517 .01604 L
.39466 .01604 L
.39969 .01604 L
.40508 .01604 L
.41609 .01604 L
.42614 .01604 L
.46595 .01603 L
.50425 .01603 L
.52361 .01603 L
.545 .01602 L
.55473 .01602 L
.56523 .01602 L
.58423 .01602 L
.59379 .01602 L
.60425 .01602 L
.62534 .01602 L
.64493 .01602 L
.66587 .01602 L
.68719 .01602 L
.69697 .01602 L
.70734 .01602 L
.71685 .01602 L
Mistroke
.72733 .01602 L
.73685 .01602 L
.74577 .01602 L
.75074 .01602 L
.75336 .01602 L
.75616 .01602 L
.75885 .01602 L
.76128 .01602 L
.76373 .01602 L
.76483 .01602 L
.76603 .01602 L
.7672 .01602 L
.76829 .01602 L
.76944 .01602 L
.77067 .01602 L
.77182 .01602 L
.7729 .01602 L
.77388 .01602 L
.77494 .01602 L
.77609 .01602 L
.77736 .01602 L
.77994 .01602 L
.78456 .01602 L
.78949 .01602 L
.79467 .01602 L
.80392 .01602 L
.82479 .01602 L
.86291 .01602 L
.90349 .01602 L
.94256 .01602 L
.97619 .01602 L
Mfstroke
.957 0 1 r
.02381 .01472 m
.02846 .05719 L
.03068 .07453 L
.03279 .08807 L
.03398 .0943 L
.03527 .09982 L
.03645 .10372 L
.03754 .10642 L
.03871 .10846 L
.04 .10976 L
.04065 .11009 L
.04135 .11023 L
.04262 .11 L
.04393 .10922 L
.04516 .1081 L
.04793 .10459 L
.05297 .09642 L
.06244 .0803 L
.07295 .06499 L
.08284 .05365 L
.09424 .04379 L
.10458 .03721 L
.11434 .03255 L
.12466 .02887 L
.13346 .02651 L
.14313 .02453 L
.15334 .02298 L
.16264 .02192 L
.17338 .02102 L
.18355 .02041 L
.19321 .01998 L
.20346 .01964 L
.21222 .01944 L
.22188 .01927 L
.2268 .01921 L
.23198 .01916 L
.2364 .01913 L
.23888 .01911 L
.24123 .0191 L
.24397 .01909 L
.24518 .01909 L
.24646 .01909 L
.24712 .01908 L
.24785 .01908 L
.24913 .01908 L
.24986 .01908 L
.25063 .01908 L
.25137 .01908 L
.25204 .01908 L
.25332 .01908 L
Mistroke
.2545 .01908 L
.25581 .01908 L
.25719 .01909 L
.25976 .01909 L
.26209 .0191 L
.27147 .01915 L
.2766 .01917 L
.28137 .01919 L
.28387 .0192 L
.28528 .0192 L
.28655 .01921 L
.28723 .01921 L
.28795 .01921 L
.28874 .01921 L
.28947 .01921 L
.29078 .01921 L
.29153 .01921 L
.29223 .01921 L
.29345 .01921 L
.29474 .01921 L
.29584 .0192 L
.29703 .0192 L
.29972 .01919 L
.30221 .01918 L
.31276 .01913 L
.3227 .01906 L
.3413 .01894 L
.35105 .01889 L
.36136 .01884 L
.37101 .01881 L
.37982 .01878 L
.38928 .01876 L
.3945 .01875 L
.39944 .01875 L
.40821 .01874 L
.41317 .01874 L
.41776 .01873 L
.42737 .01873 L
.4364 .01873 L
.457 .01872 L
.46681 .01872 L
.47715 .01872 L
.48598 .01872 L
.49565 .01871 L
.53618 .01869 L
.55489 .01868 L
.57519 .01867 L
.59651 .01866 L
.61666 .01866 L
.63651 .01865 L
Mistroke
.65754 .01865 L
.6954 .01865 L
.71482 .01865 L
.73571 .01865 L
.75686 .01865 L
.77695 .01864 L
.79677 .01864 L
.81516 .01864 L
.82574 .01864 L
.8357 .01864 L
.85431 .01864 L
.86409 .01864 L
.87441 .01864 L
.88407 .01864 L
.89288 .01864 L
.90237 .01864 L
.90759 .01864 L
.91254 .01864 L
.91475 .01864 L
.9171 .01864 L
.91913 .01864 L
.92132 .01864 L
.92255 .01864 L
.92367 .01864 L
.92481 .01864 L
.92587 .01864 L
.92703 .01864 L
.92831 .01864 L
.92955 .01864 L
.93024 .01864 L
.93088 .01864 L
.93207 .01864 L
.93319 .01864 L
.93441 .01864 L
.93573 .01864 L
.93842 .01864 L
.94087 .01864 L
.94559 .01864 L
.95008 .01864 L
.96003 .01864 L
.97088 .01864 L
.97619 .01864 L
Mfstroke
.98 0 1 r
.02381 .01472 m
.02846 .05737 L
.03279 .09 L
.03527 .10412 L
.03754 .1137 L
.03879 .1177 L
.04015 .12104 L
.04143 .12333 L
.04262 .12477 L
.04376 .1256 L
.04498 .12599 L
.04614 .12592 L
.0472 .12554 L
.04843 .12477 L
.04978 .12359 L
.05224 .12076 L
.06244 .10459 L
.08284 .07361 L
.09424 .06097 L
.10458 .0522 L
.11463 .04567 L
.12551 .04034 L
.13578 .03658 L
.14523 .03396 L
.15496 .03191 L
.16405 .03045 L
.17402 .02925 L
.18471 .02831 L
.19489 .02768 L
.20063 .02741 L
.20595 .02721 L
.21098 .02706 L
.21571 .02695 L
.22064 .02686 L
.22325 .02683 L
.22473 .02681 L
.22607 .0268 L
.22722 .02679 L
.22847 .02678 L
.22979 .02678 L
.23103 .02678 L
.2322 .02677 L
.23343 .02678 L
.23449 .02678 L
.23564 .02678 L
.23634 .02679 L
.23701 .02679 L
.23825 .0268 L
.24105 .02682 L
.24347 .02686 L
Mistroke
.24611 .0269 L
.25142 .02704 L
.25438 .02713 L
.25706 .02723 L
.26721 .02773 L
.2766 .02825 L
.28132 .02846 L
.284 .02855 L
.2865 .02861 L
.28791 .02864 L
.28924 .02866 L
.29044 .02868 L
.29174 .02869 L
.29242 .02869 L
.29316 .0287 L
.29393 .0287 L
.29466 .0287 L
.29596 .02869 L
.29669 .02869 L
.29736 .02869 L
.29856 .02867 L
.29968 .02866 L
.30222 .02862 L
.30469 .02857 L
.30733 .02851 L
.32728 .02783 L
.34888 .0271 L
.35901 .02683 L
.36972 .0266 L
.37887 .02645 L
.38892 .02632 L
.39415 .02627 L
.39911 .02623 L
.4084 .02618 L
.4136 .02615 L
.41841 .02614 L
.42931 .02611 L
.43892 .02609 L
.44332 .02608 L
.44795 .02608 L
.45042 .02608 L
.45312 .02607 L
.4543 .02607 L
.45557 .02607 L
.45677 .02607 L
.45786 .02607 L
.45852 .02607 L
.45923 .02607 L
.46049 .02607 L
.46119 .02607 L
Mistroke
.46185 .02607 L
.46257 .02607 L
.46335 .02607 L
.46474 .02607 L
.46606 .02607 L
.46854 .02608 L
.47114 .02608 L
.47358 .02608 L
.47814 .02609 L
.48836 .02612 L
.50676 .02618 L
.54533 .02632 L
.58635 .02644 L
.62586 .02661 L
.66385 .02678 L
.68337 .02686 L
.70429 .02691 L
.71448 .02693 L
.71985 .02694 L
.72555 .02695 L
.73052 .02695 L
.736 .02696 L
.74062 .02696 L
.74567 .02697 L
.7506 .02697 L
.75328 .02697 L
.75578 .02697 L
.75812 .02697 L
.76025 .02697 L
.76143 .02697 L
.76271 .02697 L
.76392 .02697 L
.76504 .02697 L
.76624 .02697 L
.76753 .02697 L
.76875 .02697 L
.76986 .02697 L
.77117 .02697 L
.7719 .02697 L
.77259 .02697 L
.77517 .02697 L
.7779 .02697 L
.78037 .02697 L
.7859 .02697 L
.79596 .02696 L
.8052 .02696 L
.82604 .02695 L
.86559 .02693 L
.90364 .0269 L
.94414 .02686 L
Mistroke
.97619 .02683 L
Mfstroke
1 0 .996 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01955 L
.05285 .01837 L
.06244 .01753 L
.07218 .01688 L
.0829 .01635 L
.09334 .01597 L
.10458 .01568 L
.11468 .01549 L
.12571 .01534 L
.13613 .01524 L
.1458 .01517 L
.15637 .01511 L
.16633 .01508 L
.17526 .01505 L
.18493 .01503 L
.19444 .01502 L
.20487 .015 L
.21013 .015 L
.21577 .01499 L
.22594 .01499 L
.23122 .01499 L
.23611 .01498 L
.24137 .01498 L
.24718 .01498 L
.25221 .01498 L
.25693 .01498 L
.26192 .01498 L
.2673 .01498 L
.30844 .01498 L
.32896 .01497 L
.33897 .01497 L
.34806 .01497 L
.3569 .01497 L
.36649 .01497 L
.37175 .01497 L
.37661 .01497 L
.38161 .01497 L
.38617 .01497 L
.39084 .01497 L
.39325 .01497 L
.39586 .01497 L
.39828 .01497 L
Mistroke
.40052 .01497 L
.40266 .01497 L
.40376 .01497 L
.40493 .01497 L
.4056 .01497 L
.40633 .01497 L
.40762 .01497 L
.40834 .01497 L
.40912 .01497 L
.40985 .01497 L
.41051 .01497 L
.41181 .01497 L
.41254 .01497 L
.41321 .01497 L
.41445 .01497 L
.41577 .01497 L
.41817 .01497 L
.42043 .01497 L
.42557 .01497 L
.44409 .01497 L
.44916 .01497 L
.45195 .01497 L
.45457 .01497 L
.45702 .01497 L
.45841 .01497 L
.45968 .01497 L
.46075 .01497 L
.46193 .01497 L
.46316 .01497 L
.46431 .01497 L
.46556 .01497 L
.46626 .01497 L
.46691 .01497 L
.46811 .01497 L
.46938 .01497 L
.47157 .01497 L
.474 .01497 L
.47936 .01497 L
.48439 .01497 L
.49455 .01497 L
.50551 .01497 L
.52513 .01497 L
.54661 .01497 L
.55652 .01497 L
.56711 .01497 L
.5862 .01497 L
.59643 .01497 L
.60753 .01497 L
.62767 .01497 L
.66856 .01497 L
Mistroke
.70793 .01497 L
.74578 .01497 L
.76521 .01497 L
.78609 .01497 L
.82733 .01497 L
.86706 .01497 L
.90528 .01497 L
.94594 .01497 L
.97619 .01497 L
Mfstroke
1 0 .972 r
.02381 .01472 m
.02846 .05764 L
.03279 .09229 L
.03523 .10849 L
.03754 .12112 L
.03881 .12691 L
.0402 .13222 L
.04145 .13616 L
.04262 .13913 L
.04376 .14141 L
.045 .14319 L
.0457 .14392 L
.04637 .14444 L
.04762 .14496 L
.04894 .14497 L
.05016 .14452 L
.05086 .14409 L
.0515 .14361 L
.05293 .14223 L
.05528 .13921 L
.05783 .13519 L
.06244 .12676 L
.08293 .08909 L
.09325 .07439 L
.10458 .06185 L
.11481 .05323 L
.12579 .04625 L
.13614 .04132 L
.14558 .03792 L
.1555 .0352 L
.16467 .03329 L
.17473 .03171 L
.18543 .03049 L
.1948 .02972 L
.19972 .0294 L
.2049 .02912 L
.20945 .02893 L
.21444 .02875 L
.21896 .02863 L
.22318 .02854 L
.22581 .0285 L
.22823 .02847 L
.22949 .02846 L
.23089 .02845 L
.23159 .02845 L
.23234 .02845 L
.23305 .02845 L
.2337 .02845 L
.23497 .02845 L
.23614 .02845 L
Mistroke
.23743 .02845 L
.23815 .02846 L
.2388 .02846 L
.24 .02847 L
.24129 .02849 L
.24364 .02852 L
.24588 .02856 L
.24835 .02862 L
.25332 .02878 L
.25793 .02898 L
.26222 .02922 L
.27128 .02983 L
.2809 .03046 L
.28331 .03058 L
.28591 .03069 L
.2874 .03075 L
.28877 .03079 L
.29015 .03082 L
.29144 .03085 L
.29254 .03086 L
.29371 .03087 L
.29501 .03088 L
.29619 .03089 L
.29743 .03088 L
.29812 .03088 L
.29876 .03088 L
.29994 .03087 L
.30118 .03085 L
.30371 .0308 L
.30643 .03074 L
.31133 .03059 L
.32247 .03013 L
.3426 .02924 L
.35276 .02884 L
.36381 .02849 L
.37426 .02822 L
.38393 .02804 L
.38855 .02797 L
.39354 .02791 L
.39785 .02786 L
.40257 .02782 L
.4051 .02781 L
.4078 .02779 L
.41065 .02778 L
.41192 .02778 L
.41331 .02778 L
.41469 .02777 L
.41596 .02777 L
.41718 .02777 L
.41847 .02777 L
Mistroke
.41962 .02777 L
.4207 .02777 L
.42189 .02777 L
.42316 .02777 L
.42449 .02778 L
.4257 .02778 L
.42841 .02779 L
.43091 .0278 L
.43328 .02781 L
.43858 .02785 L
.44431 .02791 L
.45478 .02806 L
.46441 .02822 L
.48484 .02859 L
.49482 .02873 L
.50391 .02883 L
.50843 .02887 L
.51333 .0289 L
.51797 .02892 L
.52225 .02894 L
.52459 .02894 L
.52678 .02895 L
.52796 .02895 L
.52919 .02895 L
.53054 .02895 L
.53178 .02895 L
.533 .02895 L
.53429 .02895 L
.53551 .02895 L
.53662 .02895 L
.53792 .02895 L
.53866 .02895 L
.53934 .02895 L
.5419 .02895 L
.54435 .02895 L
.54658 .02894 L
.55161 .02894 L
.56068 .02892 L
.56575 .02892 L
.56843 .02891 L
.57128 .02891 L
.57401 .02891 L
.57649 .02891 L
.57769 .02891 L
.57898 .02891 L
.58021 .02891 L
.58133 .02891 L
.5826 .02891 L
.5838 .02891 L
.58488 .02891 L
Mistroke
.58605 .02891 L
.58732 .02891 L
.58867 .02891 L
.5911 .02891 L
.59543 .02892 L
.6002 .02892 L
.61088 .02895 L
.62089 .02897 L
.63942 .02903 L
.64921 .02905 L
.65965 .02907 L
.6626 .02908 L
.66539 .02908 L
.6681 .02909 L
.6706 .02909 L
.67297 .02909 L
.67419 .02909 L
.67549 .02909 L
.67679 .02909 L
.678 .02909 L
.67875 .02909 L
.67945 .02909 L
.68077 .02909 L
.68192 .02909 L
.68319 .02909 L
.68383 .02909 L
.68452 .02909 L
.68577 .02909 L
.68818 .02909 L
.69039 .02909 L
.69549 .02908 L
.70086 .02908 L
.7104 .02906 L
.72059 .02904 L
.73895 .02899 L
.78044 .02887 L
.82041 .02878 L
.85886 .02871 L
.89977 .02865 L
.93916 .0286 L
.97619 .02856 L
Mfstroke
1 0 .949 r
.02381 .01472 m
.02846 .05779 L
.03279 .09374 L
.03793 .12883 L
.04037 .14179 L
.04262 .15147 L
.04498 .15924 L
.04622 .16237 L
.04754 .16498 L
.04869 .1667 L
.04976 .16787 L
.05093 .16869 L
.0522 .16908 L
.05351 .169 L
.05425 .16876 L
.05494 .16841 L
.0562 .1675 L
.05755 .16618 L
.06012 .16284 L
.06244 .1591 L
.08269 .11841 L
.09333 .09951 L
.10458 .08341 L
.11453 .07226 L
.12545 .06279 L
.13538 .05623 L
.14465 .05148 L
.1551 .04741 L
.165 .04451 L
.17389 .04253 L
.18355 .04092 L
.19295 .03977 L
.19831 .03927 L
.20333 .03889 L
.2086 .03857 L
.21344 .03836 L
.21597 .03827 L
.21875 .03819 L
.22015 .03816 L
.22164 .03813 L
.22305 .03811 L
.22434 .0381 L
.22553 .03809 L
.22665 .03809 L
.22787 .03809 L
.22919 .03809 L
.22984 .03809 L
.23056 .0381 L
.23187 .03811 L
.23314 .03813 L
Mistroke
.23432 .03815 L
.23666 .03821 L
.23878 .03828 L
.24352 .03849 L
.24621 .03866 L
.24867 .03884 L
.25424 .03937 L
.25914 .03999 L
.26432 .04081 L
.27382 .04255 L
.27905 .04343 L
.28162 .04379 L
.284 .04407 L
.28619 .04429 L
.2886 .04446 L
.28985 .04453 L
.29102 .04458 L
.29226 .04462 L
.29296 .04464 L
.2936 .04465 L
.29465 .04466 L
.29564 .04466 L
.29671 .04465 L
.29786 .04463 L
.29907 .0446 L
.30021 .04457 L
.30234 .04447 L
.30474 .04433 L
.30699 .04418 L
.31209 .04375 L
.3224 .04269 L
.34086 .04072 L
.3513 .03976 L
.36119 .039 L
.37 .03844 L
.37974 .03796 L
.38938 .0376 L
.39466 .03745 L
.39962 .03734 L
.40394 .03726 L
.40848 .03719 L
.41346 .03713 L
.41803 .03709 L
.4206 .03707 L
.42303 .03706 L
.42523 .03705 L
.42756 .03704 L
.42877 .03704 L
.43011 .03704 L
.43132 .03704 L
Mistroke
.43245 .03704 L
.43313 .03703 L
.43378 .03703 L
.43501 .03704 L
.43632 .03704 L
.43706 .03704 L
.43775 .03704 L
.43891 .03704 L
.44015 .03704 L
.44241 .03705 L
.44462 .03706 L
.44664 .03708 L
.45125 .03712 L
.45611 .03717 L
.4656 .03732 L
.47576 .03753 L
.4941 .038 L
.51393 .03848 L
.53548 .03888 L
.57535 .03943 L
.61615 .04013 L
.63642 .04056 L
.65544 .04093 L
.67362 .04123 L
.68384 .04135 L
.69321 .04145 L
.69795 .04148 L
.70302 .04151 L
.7074 .04154 L
.71215 .04156 L
.71505 .04157 L
.71773 .04158 L
.72024 .04158 L
.723 .04159 L
.72419 .04159 L
.72547 .04159 L
.72658 .04159 L
.72779 .04159 L
.72849 .04159 L
.72914 .04159 L
.73043 .04159 L
.73161 .04159 L
.73285 .04159 L
.7341 .04159 L
.73481 .04159 L
.73547 .04159 L
.73681 .04159 L
.73823 .04159 L
.74082 .04159 L
.74317 .04158 L
Mistroke
.7489 .04157 L
.75432 .04156 L
.77451 .0415 L
.81291 .04135 L
.85376 .04118 L
.8931 .041 L
.93092 .04083 L
.9712 .04066 L
.97619 .04064 L
Mfstroke
1 0 .925 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01974 L
.05285 .01855 L
.06244 .01769 L
.07218 .01702 L
.0829 .01647 L
.09334 .01608 L
.10458 .01578 L
.11468 .01558 L
.12571 .01542 L
.13613 .01531 L
.1458 .01524 L
.15637 .01518 L
.16633 .01514 L
.17526 .01512 L
.18493 .01509 L
.19444 .01508 L
.20487 .01506 L
.21013 .01506 L
.21577 .01506 L
.22594 .01505 L
.23122 .01505 L
.23611 .01505 L
.24148 .01504 L
.24718 .01504 L
.25211 .01504 L
.25674 .01504 L
.25939 .01504 L
.26182 .01504 L
.26449 .01504 L
.2673 .01504 L
.27684 .01504 L
.27959 .01504 L
.28219 .01504 L
.28704 .01504 L
.29162 .01504 L
.29585 .01504 L
.30541 .01504 L
.32576 .01504 L
.33572 .01503 L
.34481 .01503 L
.35355 .01503 L
.36307 .01503 L
Mistroke
.37314 .01503 L
.3827 .01503 L
.38803 .01503 L
.39304 .01503 L
.39754 .01503 L
.40008 .01503 L
.40241 .01503 L
.40363 .01503 L
.40493 .01503 L
.40606 .01503 L
.40728 .01503 L
.40803 .01503 L
.40872 .01503 L
.40936 .01503 L
.41008 .01503 L
.41131 .01503 L
.41262 .01503 L
.4133 .01503 L
.41402 .01503 L
.4153 .01503 L
.41601 .01503 L
.41668 .01503 L
.41818 .01503 L
.4207 .01503 L
.42339 .01503 L
.43309 .01503 L
.44335 .01503 L
.44593 .01503 L
.4487 .01503 L
.45029 .01503 L
.45175 .01503 L
.45245 .01503 L
.45321 .01503 L
.45392 .01503 L
.45459 .01503 L
.45583 .01503 L
.45649 .01503 L
.4572 .01503 L
.4579 .01503 L
.45864 .01503 L
.45927 .01503 L
.45997 .01503 L
.46121 .01503 L
.46254 .01503 L
.46494 .01503 L
.46763 .01503 L
.47012 .01503 L
.47573 .01503 L
.48591 .01503 L
.50498 .01503 L
Mistroke
.52531 .01503 L
.54435 .01503 L
.56259 .01503 L
.57284 .01503 L
.5822 .01503 L
.6012 .01503 L
.62193 .01503 L
.6626 .01503 L
.70175 .01503 L
.72317 .01503 L
.74335 .01503 L
.78192 .01503 L
.80187 .01503 L
.82294 .01503 L
.86094 .01503 L
.90138 .01503 L
.94031 .01503 L
.97619 .01503 L
Mfstroke
1 0 .901 r
.02381 .01472 m
.02846 .05741 L
.03279 .09064 L
.03523 .1054 L
.03754 .11641 L
.03881 .12125 L
.0402 .12554 L
.04146 .1286 L
.04262 .13077 L
.04376 .13233 L
.04498 .13344 L
.04614 .13399 L
.0472 .13412 L
.04843 .13387 L
.04913 .13355 L
.04978 .13317 L
.05097 .13223 L
.05224 .13096 L
.05759 .12344 L
.06244 .11503 L
.08269 .08092 L
.09409 .06639 L
.10458 .05608 L
.11387 .049 L
.12406 .04299 L
.13471 .03828 L
.14465 .03498 L
.1551 .03238 L
.165 .03054 L
.17389 .02929 L
.18355 .02826 L
.19295 .02752 L
.20333 .02694 L
.20854 .02672 L
.21416 .02653 L
.21947 .0264 L
.22202 .02634 L
.22434 .0263 L
.22661 .02627 L
.22908 .02624 L
.23043 .02623 L
.23168 .02622 L
.23288 .02622 L
.23414 .02621 L
.23522 .02621 L
.23638 .02621 L
.23748 .02621 L
.23848 .02621 L
.23966 .02621 L
.24093 .02622 L
Mistroke
.24214 .02623 L
.24326 .02624 L
.24597 .02627 L
.24852 .02631 L
.25329 .02641 L
.25842 .02657 L
.26396 .02679 L
.2743 .0273 L
.27934 .02755 L
.28394 .02773 L
.28643 .0278 L
.28879 .02786 L
.29 .02788 L
.29129 .0279 L
.29196 .02791 L
.29269 .02792 L
.29399 .02793 L
.29469 .02793 L
.29542 .02794 L
.29673 .02794 L
.29746 .02794 L
.29814 .02794 L
.29889 .02793 L
.29968 .02793 L
.30112 .02792 L
.30248 .0279 L
.30502 .02786 L
.30966 .02777 L
.31476 .02763 L
.32507 .0273 L
.34353 .02668 L
.36302 .02616 L
.37395 .02595 L
.37879 .02587 L
.38393 .0258 L
.38863 .02575 L
.39382 .0257 L
.39855 .02567 L
.40299 .02564 L
.40552 .02563 L
.40691 .02563 L
.40819 .02563 L
.40939 .02562 L
.41047 .02562 L
.41168 .02562 L
.41297 .02562 L
.41364 .02562 L
.41435 .02562 L
.41563 .02562 L
.41633 .02562 L
Mistroke
.417 .02562 L
.41773 .02562 L
.41851 .02562 L
.41991 .02562 L
.42124 .02563 L
.42374 .02563 L
.42633 .02565 L
.42877 .02566 L
.43334 .02569 L
.43825 .02573 L
.44356 .02578 L
.46195 .02603 L
.47227 .02617 L
.48191 .02628 L
.48716 .02633 L
.49195 .02636 L
.49727 .02639 L
.5002 .0264 L
.50154 .0264 L
.50298 .02641 L
.50421 .02641 L
.50535 .02641 L
.50643 .02641 L
.50757 .02641 L
.50883 .02642 L
.50999 .02642 L
.51127 .02641 L
.51199 .02641 L
.51264 .02641 L
.51396 .02641 L
.51517 .02641 L
.51792 .02641 L
.52034 .0264 L
.5229 .02639 L
.53168 .02636 L
.54133 .02631 L
.56242 .0262 L
.58169 .02612 L
.59122 .02609 L
.60162 .02606 L
.61143 .02605 L
.62053 .02603 L
.63113 .02603 L
.64111 .02602 L
.65973 .02601 L
.66953 .026 L
.67986 .02599 L
.69835 .02596 L
.7364 .02589 L
.77689 .02583 L
Mistroke
.81588 .02578 L
.85731 .02574 L
.89723 .02571 L
.93563 .02569 L
.97619 .02567 L
Mfstroke
1 0 .877 r
.02381 .01472 m
.02499 .02012 L
.02605 .0212 L
.02729 .02161 L
.02846 .02172 L
.02954 .02173 L
.03053 .02168 L
.03163 .0216 L
.03279 .02148 L
.04262 .02027 L
.05217 .01916 L
.06244 .01821 L
.0728 .01748 L
.0825 .01696 L
.09403 .0165 L
.10458 .01619 L
.11442 .01598 L
.12357 .01583 L
.1336 .01571 L
.14429 .01561 L
.15457 .01554 L
.1657 .01549 L
.17621 .01545 L
.18587 .01543 L
.19561 .01541 L
.2047 .0154 L
.21467 .01539 L
.22026 .01539 L
.22536 .01538 L
.23016 .01538 L
.2328 .01538 L
.23527 .01538 L
.23737 .01538 L
.23963 .01538 L
.24085 .01538 L
.24214 .01538 L
.24324 .01538 L
.24444 .01538 L
.24512 .01538 L
.24584 .01538 L
.24653 .01538 L
.24717 .01538 L
.24837 .01538 L
.24964 .01538 L
.25101 .01538 L
.25229 .01538 L
.2552 .01538 L
.25772 .01538 L
.26002 .01538 L
.2652 .01538 L
Mistroke
.27442 .01539 L
.27707 .01539 L
.27957 .01539 L
.28183 .01539 L
.28423 .01539 L
.28551 .01539 L
.28619 .01539 L
.28692 .01539 L
.2882 .01539 L
.2894 .01539 L
.29012 .01539 L
.2909 .01539 L
.29164 .01539 L
.29232 .01539 L
.29362 .01539 L
.29427 .01539 L
.29499 .01539 L
.29747 .01539 L
.30014 .01539 L
.30496 .01539 L
.31456 .01539 L
.32504 .01538 L
.34616 .01537 L
.35627 .01537 L
.36581 .01537 L
.3768 .01537 L
.38155 .01537 L
.38677 .01537 L
.39652 .01536 L
.40184 .01536 L
.40682 .01536 L
.41148 .01536 L
.41573 .01536 L
.42529 .01536 L
.4651 .01536 L
.4833 .01536 L
.49366 .01536 L
.5034 .01536 L
.5129 .01536 L
.51824 .01536 L
.52315 .01536 L
.52803 .01536 L
.53337 .01536 L
.53607 .01536 L
.53895 .01536 L
.54167 .01536 L
.54295 .01536 L
.54415 .01536 L
.54526 .01536 L
.54645 .01536 L
Mistroke
.54713 .01536 L
.54778 .01536 L
.54899 .01536 L
.55026 .01536 L
.55144 .01536 L
.55273 .01536 L
.55346 .01536 L
.55411 .01536 L
.55639 .01536 L
.55885 .01536 L
.56331 .01536 L
.56858 .01536 L
.57414 .01536 L
.5841 .01536 L
.59359 .01536 L
.60375 .01536 L
.62209 .01536 L
.66347 .01536 L
.68418 .01536 L
.70334 .01536 L
.72312 .01536 L
.74169 .01536 L
.76036 .01536 L
.78097 .01536 L
.80117 .01536 L
.81968 .01536 L
.82884 .01536 L
.83862 .01536 L
.84935 .01536 L
.85932 .01536 L
.86466 .01536 L
.86958 .01536 L
.87215 .01536 L
.87497 .01536 L
.8764 .01536 L
.87792 .01536 L
.87866 .01536 L
.87937 .01536 L
.88068 .01536 L
.88196 .01536 L
.88311 .01536 L
.88375 .01536 L
.88444 .01536 L
.88569 .01536 L
.88687 .01536 L
.88811 .01536 L
.89033 .01536 L
.89293 .01536 L
.89535 .01536 L
.90084 .01536 L
Mistroke
.90587 .01536 L
.91133 .01536 L
.92125 .01536 L
.93982 .01536 L
.97619 .01536 L
Mfstroke
1 0 .854 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01975 L
.05285 .01857 L
.06244 .01771 L
.07218 .01705 L
.0829 .0165 L
.09334 .01611 L
.10458 .01581 L
.11468 .01561 L
.12571 .01546 L
.13613 .01535 L
.1458 .01528 L
.15637 .01522 L
.16633 .01518 L
.17526 .01515 L
.18493 .01513 L
.19444 .01512 L
.20487 .0151 L
.21013 .0151 L
.21577 .01509 L
.22594 .01509 L
.23122 .01508 L
.23611 .01508 L
.24148 .01508 L
.24422 .01508 L
.24718 .01508 L
.24975 .01508 L
.25211 .01508 L
.25437 .01508 L
.25674 .01508 L
.258 .01508 L
.25935 .01508 L
.26063 .01508 L
.26178 .01508 L
.26249 .01508 L
.26314 .01508 L
.26386 .01508 L
.26462 .01508 L
.2659 .01508 L
.26662 .01508 L
.2673 .01508 L
.27228 .01508 L
.27364 .01508 L
Mistroke
.27439 .01508 L
.27509 .01508 L
.27575 .01508 L
.27646 .01508 L
.27771 .01508 L
.2789 .01508 L
.28021 .01508 L
.28087 .01508 L
.28158 .01508 L
.28285 .01508 L
.28413 .01508 L
.28533 .01508 L
.28759 .01508 L
.2922 .01508 L
.29647 .01508 L
.30612 .01508 L
.32641 .01507 L
.34544 .01507 L
.35431 .01507 L
.36365 .01507 L
.37388 .01507 L
.38324 .01507 L
.38826 .01507 L
.39281 .01507 L
.39807 .01507 L
.40048 .01507 L
.40302 .01507 L
.40521 .01507 L
.40762 .01507 L
.40981 .01507 L
.41185 .01507 L
.41309 .01507 L
.41426 .01507 L
.41531 .01507 L
.41646 .01507 L
.4177 .01507 L
.41833 .01507 L
.41903 .01507 L
.42025 .01507 L
.4214 .01507 L
.42258 .01507 L
.42383 .01507 L
.42609 .01507 L
.43122 .01507 L
.43377 .01507 L
.43654 .01507 L
.43781 .01507 L
.43915 .01507 L
.44031 .01507 L
.44156 .01507 L
Mistroke
.44281 .01507 L
.44394 .01507 L
.44509 .01507 L
.44617 .01507 L
.44743 .01507 L
.4486 .01507 L
.44988 .01507 L
.45125 .01507 L
.45363 .01507 L
.45587 .01507 L
.46006 .01507 L
.46472 .01507 L
.46983 .01507 L
.48015 .01507 L
.49863 .01507 L
.51979 .01507 L
.53907 .01507 L
.54865 .01507 L
.55907 .01507 L
.56884 .01507 L
.578 .01507 L
.58741 .01507 L
.59779 .01507 L
.60791 .01507 L
.6188 .01507 L
.62839 .01507 L
.63886 .01507 L
.6498 .01507 L
.65996 .01507 L
.6705 .01507 L
.68044 .01507 L
.68936 .01507 L
.69439 .01507 L
.69903 .01507 L
.70371 .01507 L
.70629 .01507 L
.70873 .01507 L
.711 .01507 L
.71348 .01507 L
.71572 .01507 L
.71781 .01507 L
.71911 .01507 L
.72051 .01507 L
.72116 .01507 L
.72184 .01507 L
.72306 .01507 L
.72423 .01507 L
.72533 .01507 L
.72653 .01507 L
.72781 .01507 L
Mistroke
.72852 .01507 L
.72918 .01507 L
.73067 .01507 L
.73338 .01507 L
.73584 .01507 L
.73845 .01507 L
.74786 .01507 L
.75798 .01507 L
.77628 .01507 L
.78637 .01507 L
.7974 .01507 L
.80244 .01507 L
.80782 .01507 L
.81252 .01507 L
.81749 .01507 L
.82004 .01507 L
.82284 .01507 L
.82407 .01507 L
.82539 .01507 L
.82662 .01507 L
.82777 .01507 L
.82846 .01507 L
.8292 .01507 L
.82994 .01507 L
.83075 .01507 L
.83146 .01507 L
.83221 .01507 L
.83293 .01507 L
.83358 .01507 L
.83482 .01507 L
.83552 .01507 L
.83617 .01507 L
.83747 .01507 L
.83889 .01507 L
.84152 .01507 L
.844 .01507 L
.84864 .01507 L
.85406 .01507 L
.85906 .01507 L
.86875 .01507 L
.87781 .01507 L
.89845 .01507 L
.91873 .01507 L
.93726 .01507 L
.97619 .01507 L
Mfstroke
1 0 .83 r
.02381 .01472 m
.02846 .0578 L
.03279 .09385 L
.03793 .1293 L
.04037 .14249 L
.04262 .15234 L
.04498 .1602 L
.04622 .16332 L
.04754 .16588 L
.04869 .1675 L
.04976 .16854 L
.05093 .16919 L
.0522 .16935 L
.05351 .16899 L
.05425 .16856 L
.05494 .16804 L
.0562 .16679 L
.05755 .16509 L
.06244 .15657 L
.08414 .10866 L
.09479 .08939 L
.10458 .07526 L
.11429 .06424 L
.12455 .05526 L
.13486 .04843 L
.14616 .04285 L
.15637 .03914 L
.16567 .03659 L
.17641 .03439 L
.18659 .03287 L
.19624 .03183 L
.20153 .03138 L
.2065 .03104 L
.21525 .03057 L
.2199 .0304 L
.22233 .03032 L
.22492 .03025 L
.22751 .0302 L
.22987 .03016 L
.23101 .03015 L
.23225 .03014 L
.23341 .03013 L
.23449 .03012 L
.23574 .03012 L
.23691 .03011 L
.23819 .03012 L
.23891 .03012 L
.23957 .03012 L
.24089 .03013 L
.24164 .03014 L
Mistroke
.24233 .03015 L
.24496 .03019 L
.24628 .03021 L
.24772 .03025 L
.25032 .03032 L
.25518 .03051 L
.26085 .03081 L
.26606 .03117 L
.27517 .03191 L
.28018 .03229 L
.28492 .03258 L
.2876 .03271 L
.28902 .03276 L
.29052 .03281 L
.29178 .03284 L
.29317 .03287 L
.29443 .03289 L
.29562 .0329 L
.29684 .03291 L
.29813 .0329 L
.29922 .0329 L
.30042 .03289 L
.30172 .03287 L
.3031 .03284 L
.3056 .03278 L
.31094 .0326 L
.31586 .03238 L
.32698 .0318 L
.34715 .03075 L
.36595 .02999 L
.37662 .02968 L
.3866 .02947 L
.3916 .02939 L
.39704 .02932 L
.39952 .0293 L
.40217 .02928 L
.40446 .02926 L
.40693 .02925 L
.40808 .02924 L
.4093 .02924 L
.41042 .02923 L
.41147 .02923 L
.41246 .02923 L
.41351 .02923 L
.41468 .02923 L
.41574 .02923 L
.41699 .02923 L
.41814 .02923 L
.41941 .02923 L
.42075 .02923 L
Mistroke
.423 .02924 L
.42548 .02926 L
.42797 .02927 L
.43068 .0293 L
.43562 .02935 L
.4449 .02949 L
.46578 .0299 L
.47066 .02999 L
.47592 .03007 L
.48057 .03013 L
.48547 .03018 L
.48821 .0302 L
.48965 .03021 L
.49121 .03021 L
.49263 .03022 L
.49393 .03022 L
.49524 .03023 L
.49648 .03023 L
.49768 .03023 L
.49896 .03023 L
.50005 .03023 L
.50125 .03023 L
.50255 .03023 L
.50394 .03022 L
.50645 .03021 L
.50885 .0302 L
.51141 .03018 L
.51603 .03015 L
.52651 .03005 L
.54761 .02979 L
.56754 .02956 L
.58913 .02935 L
.59924 .02928 L
.60994 .02921 L
.62913 .02912 L
.64872 .02906 L
.66704 .02901 L
.70588 .02892 L
.74718 .02883 L
.76782 .0288 L
.78696 .02877 L
.82522 .02873 L
.8458 .02871 L
.86442 .0287 L
.90456 .02868 L
.94319 .02866 L
.97619 .02866 L
Mfstroke
1 0 .806 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02107 L
.04262 .01977 L
.05217 .01867 L
.06244 .01774 L
.0728 .01703 L
.0825 .01654 L
.09403 .01611 L
.10458 .01583 L
.11442 .01563 L
.12357 .01549 L
.1336 .01538 L
.14429 .0153 L
.15457 .01523 L
.1657 .01519 L
.17621 .01515 L
.18587 .01513 L
.19561 .01512 L
.2047 .01511 L
.21467 .0151 L
.22026 .01509 L
.22536 .01509 L
.23016 .01509 L
.23527 .01509 L
.23969 .01508 L
.24444 .01508 L
.2471 .01508 L
.24953 .01508 L
.25201 .01508 L
.25431 .01508 L
.25685 .01508 L
.25819 .01508 L
.25962 .01508 L
.26112 .01508 L
.26186 .01508 L
.26254 .01508 L
.26382 .01508 L
.26449 .01508 L
.2652 .01508 L
.26641 .01508 L
.26773 .01508 L
.26898 .01508 L
.27013 .01508 L
Mistroke
.27246 .01508 L
.27464 .01508 L
.27588 .01508 L
.27658 .01508 L
.27722 .01508 L
.27835 .01508 L
.27955 .01508 L
.28084 .01508 L
.28204 .01508 L
.28336 .01508 L
.28478 .01508 L
.28714 .01508 L
.2897 .01508 L
.29436 .01508 L
.2989 .01508 L
.30309 .01508 L
.32338 .01508 L
.34241 .01507 L
.36061 .01507 L
.37084 .01507 L
.38021 .01507 L
.38497 .01507 L
.39004 .01507 L
.39917 .01507 L
.40476 .01507 L
.41003 .01507 L
.41989 .01507 L
.45841 .01507 L
.47793 .01507 L
.49938 .01507 L
.50922 .01507 L
.51978 .01507 L
.52967 .01507 L
.53883 .01507 L
.54899 .01507 L
.56005 .01507 L
.5698 .01507 L
.58016 .01507 L
.58952 .01507 L
.59961 .01507 L
.60914 .01507 L
.61788 .01507 L
.63838 .01507 L
.65747 .01507 L
.67705 .01507 L
.68667 .01507 L
.69555 .01507 L
.70031 .01507 L
.70535 .01507 L
.70779 .01507 L
Mistroke
.71041 .01507 L
.71191 .01507 L
.71329 .01507 L
.71459 .01507 L
.71598 .01507 L
.71722 .01507 L
.71834 .01507 L
.71947 .01507 L
.72054 .01507 L
.72178 .01507 L
.72293 .01507 L
.72418 .01507 L
.72551 .01507 L
.72774 .01507 L
.72983 .01507 L
.73456 .01507 L
.73957 .01507 L
.74502 .01507 L
.75493 .01507 L
.77349 .01507 L
.81429 .01507 L
.85358 .01507 L
.89135 .01507 L
.93157 .01507 L
.97028 .01507 L
.97619 .01507 L
Mfstroke
1 0 .783 r
.02381 .01472 m
.02846 .05777 L
.03279 .09338 L
.03754 .1244 L
.0389 .13129 L
.0402 .13687 L
.04135 .14104 L
.04262 .14478 L
.04386 .14758 L
.04502 .14946 L
.04624 .15073 L
.04756 .15134 L
.04878 .15128 L
.04994 .15073 L
.05099 .14988 L
.05212 .14863 L
.05471 .14476 L
.05748 .13954 L
.06244 .12872 L
.07287 .10553 L
.08414 .08418 L
.09479 .06845 L
.10458 .05732 L
.11422 .0489 L
.1248 .04193 L
.13585 .03657 L
.14616 .0329 L
.15661 .03015 L
.16651 .02822 L
.1754 .02692 L
.18507 .02585 L
.19447 .02508 L
.20484 .02446 L
.21006 .02423 L
.21568 .02402 L
.22095 .02387 L
.22585 .02375 L
.23048 .02367 L
.23285 .02364 L
.23542 .02361 L
.23689 .0236 L
.23825 .02359 L
.23951 .02358 L
.24091 .02357 L
.24216 .02357 L
.24333 .02356 L
.24457 .02356 L
.24526 .02356 L
.24589 .02356 L
.24719 .02357 L
Mistroke
.24792 .02357 L
.24858 .02357 L
.24986 .02358 L
.25107 .02359 L
.25379 .02361 L
.25672 .02364 L
.26207 .02373 L
.26699 .02383 L
.2761 .02405 L
.28111 .02415 L
.28358 .02419 L
.28585 .02422 L
.28713 .02423 L
.28854 .02424 L
.28995 .02425 L
.29073 .02425 L
.29146 .02426 L
.29274 .02426 L
.29391 .02426 L
.2952 .02426 L
.29585 .02426 L
.29656 .02426 L
.29787 .02425 L
.29906 .02424 L
.30173 .02422 L
.3042 .02419 L
.30653 .02416 L
.31628 .02399 L
.32659 .02378 L
.34505 .02341 L
.35451 .02325 L
.36466 .02311 L
.37425 .02301 L
.38299 .02294 L
.38779 .02291 L
.39289 .02288 L
.40205 .02284 L
.40714 .02283 L
.41191 .02282 L
.41715 .02281 L
.4201 .0228 L
.4228 .0228 L
.42528 .0228 L
.42753 .0228 L
.42878 .0228 L
.43013 .0228 L
.43141 .0228 L
.43259 .0228 L
.43368 .0228 L
.4347 .0228 L
Mistroke
.43581 .0228 L
.43702 .0228 L
.43827 .0228 L
.43946 .0228 L
.44054 .0228 L
.4417 .0228 L
.44443 .0228 L
.4469 .0228 L
.45244 .0228 L
.4624 .02281 L
.46728 .02282 L
.46994 .02282 L
.47243 .02282 L
.47473 .02282 L
.47683 .02282 L
.47803 .02282 L
.47916 .02282 L
.48036 .02282 L
.48166 .02282 L
.48294 .02282 L
.48415 .02282 L
.48484 .02282 L
.48548 .02282 L
.4869 .02282 L
.4882 .02282 L
.48962 .02282 L
.49248 .02282 L
.49498 .02282 L
.49766 .02282 L
.50248 .02281 L
.51273 .02279 L
.52384 .02277 L
.544 .02273 L
.5635 .02269 L
.58494 .02265 L
.60531 .02263 L
.62436 .02261 L
.64466 .0226 L
.6632 .02259 L
.70299 .02257 L
.74125 .02256 L
.76262 .02256 L
.78197 .02255 L
.8024 .02255 L
.82117 .02255 L
.84047 .02255 L
.86131 .02255 L
.88179 .02254 L
.90087 .02254 L
.92079 .02254 L
Mistroke
.93891 .02254 L
.95807 .02254 L
.97619 .02254 L
Mfstroke
1 0 .759 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .0213 L
.02954 .02125 L
.03053 .02116 L
.03279 .0209 L
.04262 .01958 L
.05285 .01842 L
.06244 .01758 L
.07218 .01694 L
.0829 .01642 L
.09334 .01604 L
.10458 .01575 L
.11468 .01557 L
.12571 .01542 L
.13613 .01532 L
.1458 .01525 L
.15637 .01519 L
.16633 .01515 L
.17526 .01513 L
.18493 .01511 L
.19444 .01509 L
.20487 .01508 L
.21013 .01508 L
.21577 .01507 L
.22594 .01507 L
.23122 .01506 L
.23611 .01506 L
.24148 .01506 L
.24422 .01506 L
.24718 .01506 L
.24975 .01506 L
.25211 .01506 L
.25437 .01506 L
.25674 .01506 L
.258 .01506 L
.2587 .01506 L
.25935 .01506 L
.26063 .01506 L
.26178 .01506 L
.26245 .01506 L
.26316 .01506 L
.26443 .01506 L
.26514 .01506 L
.2658 .01506 L
.2673 .01506 L
.27228 .01506 L
.27491 .01506 L
Mistroke
.27566 .01506 L
.27638 .01506 L
.27702 .01506 L
.27771 .01506 L
.27899 .01506 L
.28017 .01506 L
.28144 .01506 L
.28216 .01506 L
.28283 .01506 L
.28403 .01506 L
.28513 .01506 L
.28759 .01506 L
.28996 .01506 L
.29215 .01506 L
.29711 .01506 L
.30612 .01506 L
.32641 .01505 L
.34544 .01505 L
.35431 .01505 L
.36365 .01505 L
.37388 .01505 L
.38324 .01505 L
.38826 .01505 L
.39281 .01505 L
.39807 .01505 L
.40302 .01505 L
.40526 .01505 L
.40762 .01505 L
.41185 .01505 L
.4142 .01505 L
.4164 .01505 L
.41882 .01505 L
.42005 .01505 L
.4214 .01505 L
.42396 .01505 L
.42536 .01505 L
.42668 .01505 L
.43156 .01505 L
.43434 .01505 L
.43688 .01505 L
.43967 .01505 L
.44262 .01505 L
.44502 .01505 L
.44759 .01505 L
.45222 .01505 L
.45773 .01505 L
.46273 .01505 L
.48189 .01505 L
.50268 .01505 L
.52214 .01505 L
Mistroke
.53321 .01505 L
.54357 .01505 L
.55348 .01505 L
.56254 .01505 L
.56754 .01505 L
.573 .01505 L
.58294 .01505 L
.58826 .01505 L
.59327 .01505 L
.59777 .01505 L
.60263 .01505 L
.60516 .01505 L
.60794 .01505 L
.60934 .01505 L
.61085 .01505 L
.61157 .01505 L
.61226 .01505 L
.61356 .01505 L
.61477 .01505 L
.61606 .01505 L
.61716 .01505 L
.61837 .01505 L
.61967 .01505 L
.6204 .01505 L
.62107 .01505 L
.62361 .01505 L
.62609 .01505 L
.62835 .01505 L
.63342 .01505 L
.64254 .01505 L
.6532 .01505 L
.66325 .01505 L
.70174 .01505 L
.72124 .01505 L
.74267 .01505 L
.76328 .01505 L
.7821 .01505 L
.80156 .01505 L
.81241 .01505 L
.82246 .01505 L
.83245 .01505 L
.8415 .01505 L
.85154 .01505 L
.85675 .01505 L
.86224 .01505 L
.86704 .01505 L
.86958 .01505 L
.8723 .01505 L
.8748 .01505 L
.87708 .01505 L
Mistroke
.87818 .01505 L
.87937 .01505 L
.8805 .01505 L
.88154 .01505 L
.88273 .01505 L
.88402 .01505 L
.88524 .01505 L
.88635 .01505 L
.88765 .01505 L
.88907 .01505 L
.89165 .01505 L
.89434 .01505 L
.89721 .01505 L
.90238 .01505 L
.90773 .01505 L
.91266 .01505 L
.92378 .01505 L
.94395 .01505 L
.97619 .01505 L
Mfstroke
1 0 .735 r
.02381 .01472 m
.02846 .05749 L
.03279 .09096 L
.03527 .10597 L
.03754 .1165 L
.03879 .12103 L
.04015 .12494 L
.04143 .12772 L
.04262 .12956 L
.04376 .13073 L
.04498 .13141 L
.04614 .13157 L
.0472 .13135 L
.04843 .13072 L
.04913 .13021 L
.04978 .12964 L
.05224 .12686 L
.05718 .11928 L
.06244 .10995 L
.07287 .09171 L
.08414 .07502 L
.09479 .06263 L
.10458 .05378 L
.11422 .04703 L
.1248 .04139 L
.13585 .03702 L
.14616 .034 L
.15661 .03174 L
.16651 .03014 L
.1754 .02906 L
.18507 .02818 L
.19447 .02755 L
.20484 .02706 L
.21006 .02688 L
.21568 .02673 L
.21827 .02667 L
.22099 .02662 L
.22332 .02659 L
.22585 .02656 L
.22719 .02655 L
.22842 .02654 L
.22958 .02653 L
.23085 .02652 L
.23199 .02652 L
.23306 .02652 L
.23419 .02652 L
.2354 .02652 L
.23671 .02652 L
.23744 .02652 L
.23813 .02653 L
Mistroke
.23939 .02654 L
.24073 .02655 L
.24328 .02657 L
.24559 .02661 L
.25014 .0267 L
.25506 .02685 L
.2597 .02702 L
.26396 .02722 L
.27307 .02771 L
.27808 .02797 L
.28282 .02816 L
.28551 .02825 L
.28692 .02828 L
.28842 .02831 L
.28969 .02834 L
.29107 .02835 L
.29234 .02837 L
.29352 .02837 L
.29475 .02838 L
.29603 .02838 L
.29713 .02837 L
.29833 .02837 L
.29963 .02836 L
.30101 .02834 L
.3035 .0283 L
.30885 .02819 L
.31377 .02805 L
.32489 .02768 L
.34505 .02699 L
.36385 .0265 L
.37453 .02629 L
.38451 .02615 L
.3895 .02609 L
.39494 .02605 L
.40008 .02601 L
.40483 .02598 L
.4091 .02597 L
.41154 .02596 L
.41382 .02596 L
.41499 .02595 L
.41622 .02595 L
.41727 .02595 L
.41842 .02595 L
.41966 .02595 L
.42036 .02595 L
.42099 .02595 L
.42222 .02595 L
.42338 .02595 L
.42453 .02595 L
.42577 .02595 L
Mistroke
.428 .02596 L
.43066 .02596 L
.43309 .02597 L
.43836 .02599 L
.44337 .02602 L
.45219 .02609 L
.46182 .02619 L
.48315 .02645 L
.50248 .02666 L
.51217 .02674 L
.52265 .02681 L
.53254 .02685 L
.54163 .02688 L
.56207 .02693 L
.58114 .02699 L
.59948 .02706 L
.61913 .02716 L
.63896 .02727 L
.64941 .02732 L
.66051 .02736 L
.67036 .02739 L
.67559 .02741 L
.68122 .02742 L
.68638 .02742 L
.68864 .02743 L
.6911 .02743 L
.69329 .02743 L
.69562 .02743 L
.69691 .02743 L
.69809 .02743 L
.69926 .02744 L
.70038 .02744 L
.70153 .02744 L
.70277 .02744 L
.70394 .02744 L
.70501 .02744 L
.70626 .02744 L
.70697 .02744 L
.70763 .02744 L
.71011 .02743 L
.71146 .02743 L
.71273 .02743 L
.7151 .02743 L
.72041 .02743 L
.72928 .02742 L
.73886 .0274 L
.77994 .02733 L
.8195 .02726 L
.85754 .02719 L
.89804 .02713 L
Mistroke
.93702 .02708 L
.97619 .02703 L
Mfstroke
1 0 .711 r
.02381 .01472 m
.02605 .03592 L
.02846 .05664 L
.03053 .07155 L
.03163 .07793 L
.03279 .08347 L
.03344 .08603 L
.03416 .0884 L
.03543 .09149 L
.03672 .0934 L
.03793 .09426 L
.03911 .09441 L
.04019 .09409 L
.04143 .0933 L
.04262 .09223 L
.04753 .08596 L
.0521 .0792 L
.06244 .06468 L
.07295 .05279 L
.08284 .04417 L
.09424 .03677 L
.10458 .03186 L
.11434 .0284 L
.12466 .02569 L
.13346 .02394 L
.14313 .02249 L
.15334 .02135 L
.16264 .02058 L
.17338 .01992 L
.18355 .01947 L
.19321 .01916 L
.20346 .01892 L
.21222 .01877 L
.22188 .01865 L
.2268 .01861 L
.23198 .01858 L
.2364 .01855 L
.2389 .01855 L
.24123 .01854 L
.24254 .01854 L
.24395 .01853 L
.2446 .01853 L
.24528 .01853 L
.24651 .01853 L
.2477 .01853 L
.2488 .01853 L
.25001 .01853 L
.25131 .01853 L
.25203 .01853 L
.2527 .01853 L
Mistroke
.2542 .01853 L
.25694 .01854 L
.25944 .01855 L
.26209 .01856 L
.2724 .01861 L
.27782 .01863 L
.28078 .01864 L
.28222 .01865 L
.28354 .01865 L
.2847 .01865 L
.28596 .01866 L
.28666 .01866 L
.2873 .01866 L
.28856 .01866 L
.28983 .01866 L
.29055 .01866 L
.29123 .01866 L
.29194 .01866 L
.29259 .01866 L
.29331 .01866 L
.29406 .01866 L
.29522 .01865 L
.29645 .01865 L
.29868 .01865 L
.30372 .01863 L
.30907 .01861 L
.31399 .01859 L
.32511 .01853 L
.34527 .01842 L
.36407 .01835 L
.37475 .01832 L
.38473 .0183 L
.38972 .0183 L
.39516 .01829 L
.39996 .01828 L
.40505 .01828 L
.40963 .01828 L
.41469 .01828 L
.41928 .01827 L
.4236 .01827 L
.42829 .01827 L
.43095 .01827 L
.43342 .01827 L
.43476 .01827 L
.43604 .01827 L
.43718 .01827 L
.43842 .01827 L
.43906 .01827 L
.43977 .01827 L
.44051 .01827 L
Mistroke
.4412 .01827 L
.44243 .01827 L
.44313 .01827 L
.44376 .01827 L
.4449 .01827 L
.44611 .01827 L
.4483 .01827 L
.45089 .01827 L
.45325 .01827 L
.45789 .01827 L
.46226 .01827 L
.47203 .01828 L
.48235 .01828 L
.50083 .01829 L
.51032 .01829 L
.51564 .01829 L
.52048 .01829 L
.525 .01829 L
.52754 .01829 L
.5299 .01829 L
.53196 .01829 L
.53313 .01829 L
.53423 .01829 L
.53538 .01829 L
.53644 .01829 L
.5376 .01829 L
.53882 .01829 L
.54006 .01829 L
.54075 .01829 L
.5414 .01829 L
.54258 .01829 L
.54383 .01829 L
.54838 .01829 L
.55365 .01829 L
.55858 .01829 L
.5628 .01829 L
.56401 .01829 L
.56517 .01829 L
.5663 .01829 L
.56733 .01829 L
.56849 .01829 L
.56972 .01829 L
.57086 .01829 L
.57193 .01829 L
.57319 .01829 L
.57434 .01829 L
.57561 .01829 L
.57695 .01829 L
.57951 .01829 L
.58193 .01829 L
Mistroke
.58646 .01829 L
.59134 .01829 L
.59664 .01829 L
.60618 .01829 L
.61499 .0183 L
.6353 .0183 L
.65433 .0183 L
.66367 .0183 L
.67255 .01831 L
.67744 .01831 L
.68279 .01831 L
.68514 .01831 L
.68764 .01831 L
.69001 .01831 L
.69215 .01831 L
.69335 .01831 L
.69448 .01831 L
.69571 .01831 L
.69703 .01831 L
.69769 .01831 L
.69841 .01831 L
.69972 .01831 L
.70099 .01831 L
.70217 .01831 L
.70327 .01831 L
.7043 .01831 L
.70664 .01831 L
.70893 .01831 L
.71139 .01831 L
.71668 .01831 L
.72225 .01831 L
.73221 .0183 L
.7703 .0183 L
.81085 .0183 L
.84989 .01829 L
.89137 .01829 L
.93134 .01828 L
.9698 .01828 L
.97619 .01828 L
Mfstroke
1 0 .688 r
.02381 .01472 m
.02846 .05721 L
.03068 .07466 L
.03279 .08847 L
.03398 .09496 L
.03527 .10086 L
.03635 .10487 L
.03754 .10836 L
.03882 .11114 L
.03952 .11226 L
.04018 .11307 L
.04135 .114 L
.04262 .11437 L
.04393 .11416 L
.04516 .11352 L
.04586 .113 L
.0465 .11244 L
.04793 .11093 L
.05297 .10383 L
.06244 .08831 L
.07287 .07279 L
.08414 .05936 L
.09479 .0497 L
.10458 .04294 L
.11432 .03779 L
.1234 .03411 L
.13338 .03103 L
.14407 .02858 L
.15424 .02686 L
.16531 .0255 L
.17576 .02457 L
.18543 .02394 L
.19506 .02348 L
.20409 .02317 L
.20926 .02303 L
.21401 .02293 L
.21921 .02284 L
.22203 .0228 L
.22469 .02277 L
.22709 .02275 L
.2297 .02273 L
.23084 .02272 L
.23206 .02272 L
.2332 .02271 L
.23424 .02271 L
.23545 .0227 L
.23675 .0227 L
.23795 .0227 L
.23909 .0227 L
.23974 .0227 L
Mistroke
.24042 .02271 L
.24165 .02271 L
.2424 .02271 L
.24311 .02271 L
.24444 .02272 L
.24668 .02274 L
.24904 .02276 L
.25327 .02281 L
.25782 .02288 L
.2628 .02298 L
.27285 .02322 L
.27779 .02333 L
.28235 .02341 L
.2849 .02345 L
.2862 .02346 L
.2876 .02347 L
.28833 .02348 L
.289 .02348 L
.29031 .02349 L
.29101 .02349 L
.29177 .02349 L
.29257 .02349 L
.29331 .02349 L
.29461 .02349 L
.29584 .02349 L
.29694 .02348 L
.29813 .02347 L
.30081 .02346 L
.30328 .02343 L
.30797 .02337 L
.313 .0233 L
.32208 .02314 L
.34273 .02278 L
.35289 .02263 L
.36395 .02249 L
.37439 .02239 L
.38406 .02233 L
.38869 .0223 L
.39367 .02228 L
.4027 .02225 L
.40793 .02223 L
.41344 .02222 L
.41815 .02221 L
.4233 .02221 L
.43356 .0222 L
.44288 .02219 L
.44805 .02219 L
.44946 .02219 L
.45096 .02219 L
.45226 .02219 L
Mistroke
.45365 .02219 L
.45496 .02219 L
.45615 .02219 L
.45735 .02219 L
.4585 .02219 L
.45982 .02219 L
.46104 .02219 L
.46175 .02219 L
.46239 .02219 L
.46383 .02219 L
.46615 .02219 L
.46871 .02219 L
.47386 .02219 L
.47863 .0222 L
.48309 .0222 L
.50391 .02223 L
.54284 .02228 L
.56267 .02229 L
.58422 .02232 L
.62409 .02237 L
.64349 .0224 L
.66489 .02243 L
.67465 .02244 L
.68516 .02246 L
.69508 .02246 L
.70418 .02247 L
.70892 .02247 L
.71399 .02247 L
.71877 .02248 L
.72311 .02248 L
.72578 .02248 L
.72823 .02248 L
.73092 .02248 L
.73228 .02248 L
.73304 .02248 L
.73377 .02248 L
.73508 .02248 L
.73627 .02248 L
.73756 .02248 L
.73829 .02248 L
.73896 .02248 L
.7402 .02248 L
.74132 .02248 L
.74261 .02248 L
.74382 .02248 L
.7485 .02248 L
.75115 .02248 L
.75362 .02248 L
.76395 .02247 L
.78244 .02247 L
Mistroke
.82142 .02246 L
.86286 .02244 L
.90277 .02243 L
.94118 .02241 L
.97619 .0224 L
Mfstroke
1 0 .664 r
.02381 .01472 m
.02499 .02578 L
.02605 .0348 L
.02721 .04282 L
.02846 .04929 L
.02961 .05334 L
.03068 .05575 L
.0317 .05716 L
.03279 .05796 L
.03395 .05826 L
.0352 .05813 L
.03638 .05772 L
.03746 .05718 L
.04262 .05347 L
.06244 .03871 L
.07277 .03317 L
.08405 .02865 L
.09469 .02553 L
.10458 .02337 L
.11515 .02166 L
.1251 .02047 L
.13404 .01967 L
.14371 .01901 L
.15321 .01852 L
.16365 .01813 L
.17454 .01783 L
.18471 .01763 L
.19516 .01748 L
.20506 .01738 L
.21395 .01732 L
.21897 .01729 L
.22362 .01727 L
.22825 .01725 L
.23069 .01725 L
.23325 .01724 L
.2355 .01724 L
.23796 .01723 L
.23905 .01723 L
.2402 .01723 L
.24121 .01723 L
.24229 .01723 L
.24295 .01723 L
.24367 .01723 L
.24495 .01723 L
.24567 .01723 L
.24644 .01723 L
.24717 .01723 L
.24784 .01723 L
.24912 .01723 L
.24985 .01723 L
Mistroke
.25053 .01723 L
.25308 .01723 L
.25557 .01724 L
.25783 .01724 L
.26289 .01725 L
.27227 .01728 L
.2774 .01729 L
.2799 .0173 L
.28217 .0173 L
.28467 .01731 L
.28605 .01731 L
.28735 .01731 L
.28804 .01731 L
.28877 .01731 L
.29007 .01731 L
.2908 .01731 L
.29148 .01731 L
.29223 .01731 L
.29303 .01731 L
.29424 .01731 L
.29493 .01731 L
.29557 .01731 L
.29824 .01731 L
.30054 .0173 L
.30301 .0173 L
.31328 .01728 L
.32439 .01724 L
.34456 .01719 L
.36447 .01715 L
.3745 .01713 L
.38016 .01712 L
.38553 .01712 L
.39041 .01711 L
.39572 .01711 L
.40013 .01711 L
.40501 .01711 L
.41027 .0171 L
.41587 .0171 L
.42592 .0171 L
.44687 .0171 L
.45604 .01709 L
.46609 .01709 L
.4708 .01709 L
.47584 .01709 L
.48019 .01709 L
.48491 .01709 L
.48769 .01709 L
.49025 .01709 L
.4927 .01709 L
.49394 .01709 L
Mistroke
.4953 .01709 L
.49653 .01709 L
.49765 .01709 L
.49895 .01709 L
.50018 .01709 L
.50131 .01709 L
.50236 .01709 L
.50352 .01709 L
.50475 .01709 L
.50599 .01709 L
.50735 .01709 L
.51011 .01709 L
.51504 .01709 L
.5208 .01709 L
.52617 .01709 L
.54635 .01709 L
.58528 .0171 L
.60653 .0171 L
.62666 .0171 L
.66501 .01711 L
.68441 .01711 L
.69471 .01712 L
.70581 .01712 L
.71638 .01712 L
.72608 .01712 L
.73534 .01712 L
.74509 .01712 L
.75465 .01712 L
.76 .01712 L
.76485 .01712 L
.76939 .01712 L
.77178 .01712 L
.7743 .01712 L
.77651 .01712 L
.77769 .01712 L
.77895 .01712 L
.7801 .01712 L
.78116 .01712 L
.78222 .01712 L
.78322 .01712 L
.78447 .01712 L
.78518 .01712 L
.78583 .01712 L
.78702 .01712 L
.78827 .01712 L
.7894 .01712 L
.79045 .01712 L
.79284 .01712 L
.79543 .01712 L
.79779 .01712 L
Mistroke
.80308 .01712 L
.81254 .01712 L
.82149 .01712 L
.84145 .01712 L
.85989 .01712 L
.89923 .01712 L
.93705 .01712 L
.97619 .01712 L
Mfstroke
1 0 .64 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04313 L
.02846 .0488 L
.02954 .05226 L
.03053 .05424 L
.03163 .05543 L
.03279 .05593 L
.03395 .0559 L
.0352 .05548 L
.03638 .05486 L
.03746 .05415 L
.04262 .05005 L
.0529 .04181 L
.06244 .03558 L
.07277 .03041 L
.08405 .02626 L
.09398 .02358 L
.10458 .02147 L
.11487 .01998 L
.12599 .01881 L
.1365 .01802 L
.14616 .01748 L
.1559 .01708 L
.16499 .01679 L
.17496 .01656 L
.18565 .01638 L
.19582 .01626 L
.20119 .01621 L
.20689 .01617 L
.21186 .01613 L
.21734 .0161 L
.22701 .01606 L
.23193 .01605 L
.2371 .01603 L
.24158 .01602 L
.24636 .01601 L
.24906 .01601 L
.25152 .01601 L
.25402 .01601 L
.25632 .01601 L
.25901 .016 L
.26042 .016 L
.26115 .016 L
.26192 .016 L
.26322 .016 L
.26444 .016 L
.26519 .016 L
.26589 .016 L
Mistroke
.26652 .016 L
.26721 .016 L
.26786 .016 L
.26855 .016 L
.26978 .016 L
.2711 .016 L
.27254 .016 L
.27497 .016 L
.2763 .016 L
.27756 .016 L
.27877 .016 L
.2801 .016 L
.2813 .016 L
.28241 .016 L
.28345 .016 L
.2846 .016 L
.2858 .016 L
.28693 .016 L
.2895 .016 L
.2922 .016 L
.29703 .016 L
.30223 .01599 L
.30791 .01599 L
.3292 .01597 L
.34852 .01595 L
.35819 .01594 L
.36865 .01594 L
.37853 .01593 L
.38762 .01593 L
.39231 .01593 L
.39734 .01593 L
.40642 .01593 L
.41197 .01593 L
.41722 .01593 L
.42708 .01593 L
.46537 .01592 L
.48474 .01592 L
.50612 .01592 L
.52635 .01592 L
.54536 .01592 L
.55517 .01591 L
.56552 .01591 L
.58401 .01591 L
.59354 .01591 L
.60373 .01591 L
.62209 .01591 L
.64341 .01591 L
.66356 .01591 L
.68185 .01591 L
.69225 .01591 L
Mistroke
.70199 .01591 L
.71236 .01591 L
.72184 .01591 L
.72669 .01591 L
.73198 .01591 L
.73757 .01591 L
.74288 .01591 L
.74543 .01591 L
.74678 .01591 L
.7482 .01591 L
.74944 .01591 L
.7508 .01591 L
.75205 .01591 L
.7532 .01591 L
.75442 .01591 L
.75557 .01591 L
.7566 .01591 L
.75772 .01591 L
.75894 .01591 L
.76024 .01591 L
.76134 .01591 L
.76256 .01591 L
.76528 .01591 L
.76777 .01591 L
.77339 .01591 L
.78354 .01591 L
.80248 .01591 L
.82319 .01591 L
.86377 .01591 L
.90283 .01591 L
.94435 .01591 L
.97619 .01591 L
Mfstroke
1 0 .617 r
.02381 .01472 m
.02846 .05704 L
.03068 .07394 L
.03279 .08666 L
.03398 .09226 L
.03527 .09699 L
.03645 .10013 L
.03754 .10213 L
.03871 .10344 L
.04 .10403 L
.04065 .10404 L
.04135 .10387 L
.04262 .10316 L
.04393 .10199 L
.04516 .1006 L
.04793 .09675 L
.05297 .0886 L
.06244 .07343 L
.07295 .05943 L
.08284 .04918 L
.09424 .04034 L
.10458 .03446 L
.11434 .03031 L
.12466 .02705 L
.13346 .02495 L
.14313 .0232 L
.15334 .02183 L
.16264 .0209 L
.17338 .02011 L
.18355 .01957 L
.19321 .01919 L
.20346 .01889 L
.21222 .01871 L
.22188 .01857 L
.2268 .01851 L
.23198 .01846 L
.2364 .01843 L
.24123 .01841 L
.24397 .0184 L
.24646 .01839 L
.24783 .01839 L
.24933 .01838 L
.25001 .01838 L
.25074 .01838 L
.25204 .01838 L
.25323 .01838 L
.25451 .01838 L
.25572 .01838 L
.25682 .01838 L
.25811 .01838 L
Mistroke
.25952 .01838 L
.26209 .01839 L
.26465 .01839 L
.26742 .0184 L
.27243 .01842 L
.2769 .01843 L
.27927 .01844 L
.2818 .01845 L
.28324 .01845 L
.28455 .01845 L
.28587 .01845 L
.28712 .01845 L
.2878 .01845 L
.28852 .01845 L
.28981 .01845 L
.29053 .01845 L
.2912 .01845 L
.29194 .01845 L
.29274 .01845 L
.29396 .01845 L
.29529 .01845 L
.29798 .01844 L
.30279 .01843 L
.30809 .01841 L
.31309 .01838 L
.32243 .01834 L
.3434 .01823 L
.35315 .01819 L
.36345 .01816 L
.37225 .01814 L
.38192 .01812 L
.38715 .01811 L
.39211 .01811 L
.4014 .0181 L
.4066 .01809 L
.41141 .01809 L
.42231 .01809 L
.46154 .01807 L
.49926 .01806 L
.52021 .01805 L
.53943 .01804 L
.55945 .01804 L
.57809 .01803 L
.59699 .01803 L
.60699 .01803 L
.61768 .01803 L
.639 .01803 L
.65914 .01803 L
.69758 .01802 L
.71743 .01802 L
Mistroke
.73847 .01802 L
.75801 .01802 L
.77632 .01802 L
.78671 .01802 L
.79658 .01802 L
.8063 .01802 L
.81511 .01802 L
.82471 .01802 L
.83493 .01802 L
.84441 .01802 L
.85332 .01802 L
.85799 .01802 L
.8631 .01802 L
.86568 .01802 L
.86844 .01802 L
.87082 .01802 L
.87342 .01802 L
.87467 .01802 L
.876 .01802 L
.87723 .01802 L
.87838 .01802 L
.87946 .01802 L
.88062 .01802 L
.88191 .01802 L
.88309 .01802 L
.88415 .01802 L
.88514 .01802 L
.88622 .01802 L
.88738 .01802 L
.88975 .01802 L
.8919 .01802 L
.89675 .01802 L
.90189 .01802 L
.91109 .01802 L
.921 .01802 L
.9319 .01802 L
.95136 .01802 L
.97226 .01802 L
.97619 .01802 L
Mfstroke
1 0 .593 r
.02381 .01472 m
.02846 .05776 L
.03279 .09332 L
.03754 .12422 L
.0389 .13109 L
.0402 .13665 L
.04135 .14084 L
.04262 .14461 L
.04386 .14746 L
.04502 .14942 L
.04624 .15078 L
.04756 .15151 L
.04878 .15157 L
.04994 .15115 L
.05099 .15041 L
.05212 .14928 L
.05471 .14568 L
.05748 .14072 L
.06244 .13025 L
.07287 .1074 L
.08414 .08607 L
.09479 .07023 L
.10458 .05896 L
.11422 .05041 L
.1248 .04329 L
.13585 .03781 L
.14616 .03405 L
.15661 .03122 L
.16651 .02924 L
.1754 .0279 L
.18507 .0268 L
.19447 .026 L
.20484 .02537 L
.21006 .02513 L
.21568 .02492 L
.22095 .02476 L
.22585 .02465 L
.23048 .02457 L
.23307 .02454 L
.23542 .02451 L
.23668 .0245 L
.23801 .0245 L
.2387 .02449 L
.23947 .02449 L
.24017 .02449 L
.24081 .02449 L
.24208 .02448 L
.24277 .02448 L
.24344 .02448 L
.24461 .02449 L
Mistroke
.24589 .02449 L
.24658 .02449 L
.24733 .0245 L
.24868 .02451 L
.2512 .02453 L
.25414 .02457 L
.25684 .02461 L
.26178 .02471 L
.26699 .02485 L
.2765 .02513 L
.28172 .02527 L
.28429 .02532 L
.28667 .02535 L
.2889 .02538 L
.29003 .02539 L
.29127 .0254 L
.29252 .0254 L
.29321 .0254 L
.29385 .0254 L
.29503 .0254 L
.29627 .0254 L
.29732 .0254 L
.29844 .02539 L
.30045 .02537 L
.30284 .02534 L
.30502 .02531 L
.31502 .02512 L
.32424 .02489 L
.34505 .02439 L
.36385 .02405 L
.37453 .02392 L
.38451 .02382 L
.3895 .02378 L
.39494 .02375 L
.39974 .02373 L
.40483 .02371 L
.40941 .02369 L
.41446 .02368 L
.41668 .02368 L
.41906 .02367 L
.42132 .02367 L
.42338 .02367 L
.42577 .02367 L
.42709 .02367 L
.42833 .02367 L
.42948 .02366 L
.43054 .02366 L
.4317 .02366 L
.43294 .02366 L
.43418 .02366 L
Mistroke
.43487 .02366 L
.43551 .02366 L
.43674 .02366 L
.43792 .02367 L
.43928 .02367 L
.44054 .02367 L
.4434 .02367 L
.44876 .02367 L
.45361 .02368 L
.46449 .0237 L
.47386 .02371 L
.47898 .02372 L
.48375 .02372 L
.48625 .02372 L
.48753 .02372 L
.48892 .02372 L
.48972 .02372 L
.49045 .02372 L
.49114 .02372 L
.49189 .02372 L
.49321 .02373 L
.49393 .02373 L
.4946 .02373 L
.49582 .02373 L
.49711 .02372 L
.4982 .02372 L
.4994 .02372 L
.50208 .02372 L
.50458 .02372 L
.50963 .02372 L
.51511 .02371 L
.52505 .02369 L
.54364 .02365 L
.56314 .02361 L
.58458 .02358 L
.5944 .02356 L
.60495 .02355 L
.624 .02354 L
.63414 .02353 L
.64519 .02352 L
.6653 .02352 L
.70602 .0235 L
.74522 .02348 L
.76525 .02348 L
.78687 .02347 L
.82701 .02346 L
.847 .02345 L
.86809 .02345 L
.90613 .02345 L
.94663 .02344 L
Mistroke
.97619 .02344 L
Mfstroke
1 0 .569 r
.02381 .01472 m
.02846 .05707 L
.03068 .07414 L
.03279 .08724 L
.03398 .09317 L
.03527 .09835 L
.03645 .10195 L
.03754 .1044 L
.03871 .10621 L
.04 .10731 L
.04065 .10756 L
.04135 .10764 L
.04262 .10733 L
.04393 .1065 L
.04516 .10538 L
.04793 .10194 L
.05297 .09406 L
.06244 .07857 L
.07295 .0638 L
.08284 .05284 L
.09424 .04329 L
.10458 .03689 L
.11434 .03236 L
.12466 .02878 L
.13346 .02647 L
.14313 .02454 L
.15334 .02302 L
.16264 .02199 L
.17338 .02111 L
.18355 .0205 L
.19321 .02008 L
.20346 .01976 L
.21222 .01955 L
.22188 .0194 L
.2268 .01934 L
.23198 .01929 L
.2364 .01926 L
.2389 .01924 L
.24123 .01923 L
.24254 .01923 L
.24395 .01922 L
.2452 .01922 L
.24651 .01922 L
.2477 .01922 L
.24901 .01921 L
.2502 .01921 L
.25131 .01921 L
.25198 .01921 L
.25271 .01921 L
.25403 .01922 L
Mistroke
.25532 .01922 L
.25651 .01922 L
.25921 .01923 L
.26209 .01924 L
.2724 .0193 L
.27782 .01933 L
.28078 .01935 L
.28354 .01936 L
.28596 .01936 L
.28732 .01937 L
.28856 .01937 L
.28926 .01937 L
.28991 .01937 L
.29063 .01937 L
.29138 .01937 L
.29266 .01937 L
.29338 .01937 L
.29406 .01937 L
.29524 .01937 L
.29649 .01937 L
.29871 .01936 L
.30111 .01935 L
.30372 .01934 L
.31402 .01928 L
.32337 .01921 L
.34434 .01907 L
.35368 .01902 L
.36356 .01897 L
.37439 .01893 L
.38437 .01891 L
.39383 .01889 L
.39914 .01888 L
.40398 .01887 L
.40849 .01887 L
.41339 .01887 L
.41802 .01886 L
.42231 .01886 L
.42693 .01886 L
.43192 .01886 L
.44095 .01886 L
.44618 .01886 L
.45169 .01886 L
.46154 .01886 L
.47107 .01885 L
.47641 .01885 L
.48126 .01885 L
.4907 .01885 L
.49962 .01885 L
.51961 .01884 L
.53805 .01883 L
Mistroke
.55839 .01882 L
.57742 .01881 L
.59567 .0188 L
.61528 .0188 L
.62539 .0188 L
.63643 .01879 L
.65652 .01879 L
.69719 .01879 L
.73634 .01878 L
.75633 .01878 L
.77794 .01878 L
.79706 .01878 L
.81803 .01878 L
.83798 .01878 L
.85905 .01878 L
.88021 .01878 L
.89949 .01878 L
.91814 .01878 L
.93842 .01878 L
.95804 .01878 L
.97619 .01878 L
Mfstroke
1 0 .545 r
.02381 .01472 m
.02605 .0354 L
.02729 .04532 L
.02846 .0534 L
.02954 .05972 L
.03072 .06526 L
.0318 .06919 L
.03279 .07197 L
.03396 .07437 L
.03506 .07587 L
.03626 .07685 L
.03756 .07728 L
.03821 .0773 L
.03891 .0772 L
.0402 .07674 L
.04145 .07603 L
.04262 .07519 L
.05221 .06543 L
.06244 .05473 L
.07382 .04501 L
.08454 .03801 L
.09417 .03323 L
.10458 .02931 L
.11408 .02662 L
.12452 .0244 L
.13541 .0227 L
.14558 .02154 L
.15603 .02066 L
.16594 .02004 L
.17482 .01963 L
.18449 .01929 L
.19389 .01904 L
.20427 .01885 L
.20948 .01878 L
.2151 .01871 L
.22037 .01866 L
.22527 .01862 L
.2299 .0186 L
.23227 .01859 L
.23484 .01858 L
.23631 .01857 L
.23767 .01857 L
.23893 .01857 L
.24033 .01856 L
.24158 .01856 L
.24275 .01856 L
.24399 .01856 L
.24468 .01856 L
.24531 .01856 L
.24662 .01856 L
Mistroke
.24734 .01856 L
.248 .01856 L
.24929 .01856 L
.25049 .01856 L
.25191 .01857 L
.25321 .01857 L
.25614 .01858 L
.26114 .0186 L
.26641 .01863 L
.27592 .01868 L
.27865 .0187 L
.28124 .01871 L
.28359 .01872 L
.28488 .01872 L
.28609 .01872 L
.28723 .01873 L
.28827 .01873 L
.28942 .01873 L
.29066 .01873 L
.29165 .01873 L
.29272 .01873 L
.29384 .01873 L
.29488 .01873 L
.29613 .01873 L
.29731 .01872 L
.29951 .01872 L
.30187 .01871 L
.30444 .01871 L
.31393 .01866 L
.32435 .01861 L
.34541 .01849 L
.35541 .01845 L
.36489 .01841 L
.37583 .01838 L
.38056 .01837 L
.3858 .01836 L
.39544 .01835 L
.40072 .01834 L
.40569 .01834 L
.4103 .01833 L
.41454 .01833 L
.4192 .01833 L
.42154 .01833 L
.4241 .01833 L
.42663 .01833 L
.42806 .01833 L
.42937 .01833 L
.43052 .01833 L
.43179 .01833 L
.43243 .01833 L
Mistroke
.43312 .01833 L
.43436 .01833 L
.43555 .01833 L
.43685 .01833 L
.43809 .01833 L
.43923 .01833 L
.44139 .01833 L
.44368 .01833 L
.4464 .01833 L
.44934 .01833 L
.45467 .01833 L
.46463 .01834 L
.48419 .01834 L
.48955 .01835 L
.49529 .01835 L
.49807 .01835 L
.50071 .01835 L
.50306 .01835 L
.50431 .01835 L
.50565 .01835 L
.50693 .01835 L
.50811 .01835 L
.50924 .01835 L
.51042 .01835 L
.51167 .01835 L
.51284 .01835 L
.51412 .01835 L
.51483 .01835 L
.51548 .01835 L
.51665 .01835 L
.51773 .01835 L
.52016 .01835 L
.52231 .01835 L
.52458 .01835 L
.53438 .01835 L
.54516 .01834 L
.56625 .01834 L
.57625 .01834 L
.58552 .01834 L
.59014 .01833 L
.59506 .01833 L
.59787 .01833 L
.60051 .01833 L
.60289 .01833 L
.60545 .01833 L
.60774 .01833 L
.60904 .01833 L
.61025 .01833 L
.61153 .01833 L
.61269 .01833 L
Mistroke
.61334 .01833 L
.61404 .01833 L
.61531 .01833 L
.61639 .01833 L
.61759 .01833 L
.62001 .01833 L
.62226 .01833 L
.62436 .01833 L
.64289 .01833 L
.65268 .01833 L
.65806 .01834 L
.66312 .01834 L
.66588 .01834 L
.66743 .01834 L
.66886 .01834 L
.67007 .01834 L
.67076 .01834 L
.6714 .01834 L
.67269 .01834 L
.67341 .01834 L
.67407 .01834 L
.67537 .01834 L
.67657 .01834 L
.67789 .01834 L
.6793 .01834 L
.68165 .01834 L
.68425 .01834 L
.68923 .01834 L
.6946 .01833 L
.70433 .01833 L
.7139 .01833 L
.72436 .01833 L
.74546 .01833 L
.78601 .01832 L
.82504 .01832 L
.86653 .01832 L
.9065 .01831 L
.94495 .01831 L
.97619 .01831 L
Mfstroke
1 0 .522 r
.02381 .01472 m
.02499 .02577 L
.02605 .03478 L
.02721 .04273 L
.02846 .04904 L
.02961 .05288 L
.03068 .05507 L
.0317 .05627 L
.03279 .05686 L
.03395 .05697 L
.0352 .05668 L
.03638 .05614 L
.03746 .05549 L
.04262 .05153 L
.0529 .04325 L
.06244 .03688 L
.07277 .03155 L
.08405 .02725 L
.09398 .02447 L
.10458 .02227 L
.11487 .02071 L
.12599 .01949 L
.1365 .01865 L
.14616 .01809 L
.1559 .01766 L
.16499 .01737 L
.17496 .01713 L
.18565 .01694 L
.19582 .01681 L
.20119 .01675 L
.20689 .01671 L
.21186 .01667 L
.21734 .01664 L
.22701 .0166 L
.23193 .01659 L
.2371 .01658 L
.24152 .01657 L
.24403 .01657 L
.24636 .01656 L
.24766 .01656 L
.24835 .01656 L
.24908 .01656 L
.24971 .01656 L
.25041 .01656 L
.25164 .01656 L
.25284 .01656 L
.25412 .01656 L
.25533 .01656 L
.25644 .01656 L
.25781 .01656 L
Mistroke
.25909 .01656 L
.26197 .01657 L
.26721 .01657 L
.27231 .01658 L
.27498 .01658 L
.27781 .01659 L
.28029 .01659 L
.2816 .01659 L
.283 .01659 L
.2843 .01659 L
.28547 .01659 L
.28666 .01659 L
.28778 .01659 L
.28885 .01659 L
.29003 .01659 L
.29126 .01659 L
.29241 .01659 L
.29448 .01659 L
.2967 .01659 L
.30176 .01658 L
.3064 .01658 L
.32696 .01654 L
.34607 .01651 L
.36453 .01649 L
.37486 .01648 L
.38423 .01647 L
.3891 .01647 L
.39424 .01647 L
.39869 .01647 L
.40346 .01646 L
.40858 .01646 L
.41337 .01646 L
.41907 .01646 L
.42427 .01646 L
.44494 .01646 L
.45403 .01646 L
.45887 .01646 L
.46408 .01646 L
.46651 .01646 L
.46907 .01646 L
.47144 .01646 L
.47365 .01646 L
.47572 .01646 L
.47794 .01646 L
.47921 .01646 L
.4804 .01646 L
.48148 .01646 L
.48264 .01646 L
.48387 .01646 L
.48501 .01646 L
Mistroke
.48627 .01646 L
.48698 .01646 L
.48763 .01646 L
.49033 .01646 L
.49291 .01646 L
.49744 .01646 L
.50238 .01646 L
.54304 .01646 L
.56185 .01646 L
.57245 .01646 L
.58219 .01646 L
.60362 .01646 L
.62379 .01646 L
.64423 .01647 L
.6633 .01647 L
.68164 .01647 L
.69192 .01647 L
.70129 .01647 L
.70611 .01647 L
.71122 .01647 L
.71558 .01647 L
.71806 .01647 L
.72039 .01647 L
.72161 .01647 L
.72293 .01647 L
.7236 .01647 L
.72432 .01647 L
.72561 .01647 L
.7269 .01647 L
.72811 .01647 L
.72921 .01647 L
.73039 .01647 L
.73169 .01647 L
.73311 .01647 L
.73599 .01647 L
.74116 .01647 L
.74638 .01647 L
.75133 .01647 L
.76062 .01647 L
.78152 .01647 L
.81978 .01647 L
.8605 .01647 L
.8997 .01647 L
.94136 .01646 L
.97619 .01646 L
Mfstroke
1 0 .498 r
.02381 .01472 m
.02605 .03539 L
.02729 .04528 L
.02846 .0533 L
.02954 .05953 L
.03072 .06495 L
.0318 .06875 L
.03279 .07143 L
.03396 .07371 L
.03506 .07511 L
.03626 .07601 L
.03756 .07638 L
.03821 .07638 L
.03891 .07627 L
.0402 .07579 L
.04145 .07508 L
.04262 .07425 L
.06244 .05431 L
.07295 .04543 L
.08284 .03888 L
.09424 .03316 L
.10458 .02931 L
.11434 .02658 L
.12466 .02441 L
.13346 .02301 L
.14313 .02183 L
.15334 .02091 L
.16264 .02028 L
.17338 .01974 L
.18355 .01937 L
.19321 .01911 L
.20346 .01891 L
.21222 .01879 L
.2172 .01873 L
.22188 .01869 L
.22658 .01866 L
.23172 .01863 L
.23431 .01862 L
.23708 .01862 L
.23842 .01861 L
.23969 .01861 L
.24082 .01861 L
.24207 .01861 L
.24323 .01861 L
.24431 .01861 L
.24546 .01861 L
.24669 .01861 L
.24783 .01861 L
.24891 .01861 L
.24989 .01861 L
Mistroke
.25095 .01861 L
.25337 .01862 L
.25594 .01862 L
.26057 .01864 L
.27031 .0187 L
.27563 .01873 L
.28059 .01875 L
.28318 .01876 L
.28596 .01877 L
.28755 .01878 L
.28832 .01878 L
.28904 .01878 L
.28968 .01878 L
.29039 .01878 L
.2911 .01878 L
.29185 .01878 L
.29251 .01878 L
.2932 .01878 L
.29443 .01878 L
.29511 .01878 L
.29575 .01878 L
.2972 .01878 L
.29962 .01877 L
.30221 .01876 L
.3074 .01874 L
.31303 .01872 L
.32324 .01866 L
.34232 .01855 L
.36224 .01846 L
.37227 .01843 L
.37793 .01842 L
.3833 .0184 L
.38817 .0184 L
.39348 .01839 L
.3979 .01838 L
.40278 .01838 L
.40804 .01837 L
.41364 .01837 L
.41882 .01837 L
.42369 .01837 L
.42837 .01837 L
.43103 .01837 L
.4335 .01836 L
.43612 .01836 L
.4385 .01836 L
.43982 .01836 L
.44051 .01836 L
.44125 .01836 L
.44189 .01836 L
.4426 .01836 L
Mistroke
.44385 .01836 L
.44508 .01836 L
.44625 .01836 L
.4473 .01836 L
.44845 .01836 L
.44969 .01836 L
.45102 .01836 L
.4534 .01836 L
.45809 .01837 L
.46234 .01837 L
.47171 .01837 L
.4816 .01837 L
.4841 .01837 L
.48678 .01837 L
.48831 .01837 L
.48971 .01837 L
.49114 .01837 L
.49245 .01837 L
.49364 .01837 L
.49491 .01837 L
.49618 .01837 L
.4969 .01837 L
.49758 .01837 L
.4988 .01837 L
.49991 .01837 L
.50114 .01837 L
.50243 .01837 L
.50501 .01837 L
.50744 .01837 L
.51198 .01837 L
.51688 .01837 L
.52219 .01837 L
.54056 .01836 L
.56006 .01835 L
.5704 .01835 L
.5815 .01835 L
.59214 .01835 L
.60187 .01834 L
.61164 .01834 L
.62092 .01834 L
.62597 .01834 L
.63054 .01834 L
.64078 .01834 L
.65918 .01834 L
.66858 .01834 L
.67848 .01834 L
.68935 .01834 L
.69932 .01834 L
.73737 .01834 L
.77786 .01833 L
Mistroke
.81684 .01833 L
.85828 .01833 L
.89819 .01832 L
.9366 .01832 L
.97619 .01832 L
Mfstroke
1 0 .474 r
.02381 .01472 m
.02605 .03538 L
.02729 .04523 L
.02846 .05316 L
.02954 .05925 L
.03072 .06446 L
.0318 .06804 L
.03279 .07048 L
.03396 .07248 L
.03506 .07363 L
.03626 .07428 L
.03756 .0744 L
.03821 .07429 L
.03891 .07407 L
.0402 .07343 L
.04145 .07259 L
.04262 .07166 L
.06244 .05174 L
.07295 .04323 L
.08284 .03702 L
.09424 .03163 L
.10458 .02803 L
.11434 .02547 L
.12466 .02346 L
.13346 .02215 L
.14313 .02107 L
.15334 .02021 L
.16264 .01963 L
.17338 .01913 L
.18355 .01878 L
.19321 .01855 L
.20346 .01836 L
.21222 .01825 L
.22188 .01816 L
.2268 .01813 L
.23198 .0181 L
.2364 .01809 L
.2389 .01808 L
.24123 .01807 L
.24254 .01807 L
.24322 .01807 L
.24395 .01807 L
.24458 .01807 L
.24528 .01807 L
.24651 .01807 L
.24771 .01807 L
.24899 .01807 L
.25021 .01807 L
.25131 .01807 L
.25269 .01807 L
Mistroke
.25396 .01807 L
.25684 .01808 L
.25938 .01809 L
.26209 .0181 L
.2724 .01814 L
.27782 .01816 L
.28078 .01817 L
.28354 .01818 L
.28596 .01818 L
.28732 .01818 L
.28856 .01818 L
.28926 .01819 L
.28991 .01819 L
.29063 .01819 L
.29138 .01819 L
.29266 .01819 L
.29338 .01819 L
.29406 .01819 L
.29524 .01818 L
.29649 .01818 L
.29871 .01818 L
.30111 .01817 L
.30372 .01817 L
.31402 .01813 L
.32337 .01809 L
.34434 .01799 L
.36356 .01793 L
.37439 .0179 L
.38437 .01789 L
.38906 .01788 L
.39409 .01787 L
.39844 .01787 L
.40317 .01787 L
.40871 .01786 L
.41397 .01786 L
.41909 .01786 L
.42382 .01786 L
.42845 .01786 L
.43344 .01786 L
.43814 .01786 L
.44247 .01786 L
.44494 .01786 L
.44725 .01786 L
.44979 .01786 L
.4512 .01786 L
.45249 .01786 L
.45315 .01786 L
.45385 .01786 L
.4551 .01786 L
.45579 .01786 L
Mistroke
.45644 .01786 L
.45716 .01786 L
.45793 .01786 L
.45858 .01786 L
.4593 .01786 L
.46061 .01786 L
.46306 .01786 L
.46838 .01786 L
.47099 .01786 L
.47339 .01786 L
.47452 .01786 L
.47557 .01786 L
.47668 .01786 L
.47788 .01786 L
.47911 .01786 L
.48023 .01786 L
.48152 .01786 L
.48275 .01786 L
.48395 .01786 L
.48528 .01786 L
.48797 .01786 L
.49046 .01786 L
.4928 .01786 L
.49806 .01786 L
.50372 .01785 L
.5133 .01785 L
.52378 .01785 L
.54488 .01785 L
.56615 .01784 L
.58546 .01784 L
.59511 .01783 L
.60556 .01783 L
.61543 .01783 L
.62453 .01783 L
.63423 .01783 L
.64331 .01783 L
.66395 .01783 L
.7028 .01783 L
.72399 .01783 L
.74409 .01783 L
.78236 .01782 L
.82308 .01782 L
.86228 .01782 L
.90393 .01782 L
.94407 .01782 L
.97619 .01782 L
Mfstroke
1 0 .451 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02133 L
.03163 .02122 L
.03279 .02109 L
.04262 .0198 L
.05217 .01871 L
.06244 .01779 L
.0728 .0171 L
.0825 .01661 L
.09403 .01618 L
.10458 .0159 L
.11442 .01571 L
.12357 .01557 L
.1336 .01546 L
.14429 .01538 L
.15457 .01532 L
.1657 .01527 L
.17621 .01524 L
.18587 .01522 L
.19561 .0152 L
.2047 .01519 L
.21467 .01518 L
.22026 .01518 L
.22536 .01517 L
.23016 .01517 L
.23527 .01517 L
.23963 .01517 L
.24198 .01517 L
.24444 .01517 L
.24573 .01517 L
.24713 .01517 L
.24842 .01517 L
.2496 .01517 L
.25099 .01517 L
.25175 .01517 L
.25247 .01517 L
.25376 .01517 L
.25448 .01517 L
.25515 .01517 L
.25635 .01517 L
.25748 .01517 L
.25871 .01517 L
.26003 .01517 L
.26274 .01517 L
.2652 .01517 L
Mistroke
.27442 .01517 L
.27707 .01517 L
.27837 .01517 L
.27957 .01517 L
.28063 .01517 L
.28181 .01517 L
.28298 .01517 L
.28423 .01517 L
.28495 .01517 L
.28563 .01517 L
.28692 .01517 L
.28763 .01517 L
.2883 .01517 L
.28902 .01517 L
.2898 .01517 L
.29227 .01517 L
.29367 .01517 L
.29499 .01517 L
.29979 .01517 L
.30496 .01517 L
.32465 .01516 L
.33506 .01516 L
.34616 .01516 L
.35694 .01516 L
.36672 .01516 L
.37656 .01516 L
.38583 .01516 L
.39048 .01516 L
.39558 .01516 L
.40091 .01516 L
.40589 .01516 L
.41054 .01516 L
.41479 .01516 L
.42435 .01515 L
.43359 .01515 L
.44341 .01515 L
.45419 .01515 L
.46416 .01515 L
.48383 .01515 L
.49245 .01515 L
.50188 .01515 L
.51129 .01515 L
.52121 .01515 L
.52642 .01515 L
.532 .01515 L
.53727 .01515 L
.54205 .01515 L
.54436 .01515 L
.54689 .01515 L
.54817 .01515 L
Mistroke
.54954 .01515 L
.55073 .01515 L
.55202 .01515 L
.5533 .01515 L
.55448 .01515 L
.55562 .01515 L
.55682 .01515 L
.55801 .01515 L
.55913 .01515 L
.56013 .01515 L
.56121 .01515 L
.56373 .01515 L
.56648 .01515 L
.56936 .01515 L
.57204 .01515 L
.582 .01515 L
.59247 .01515 L
.60237 .01515 L
.62093 .01515 L
.65928 .01515 L
.67868 .01515 L
.70008 .01515 L
.70984 .01515 L
.72035 .01515 L
.73028 .01515 L
.73937 .01515 L
.74412 .01515 L
.74918 .01515 L
.75356 .01515 L
.75831 .01515 L
.76121 .01515 L
.76389 .01515 L
.7664 .01515 L
.76916 .01515 L
.77035 .01515 L
.77163 .01515 L
.77274 .01515 L
.77395 .01515 L
.77465 .01515 L
.77531 .01515 L
.7766 .01515 L
.77777 .01515 L
.77901 .01515 L
.78026 .01515 L
.78097 .01515 L
.78163 .01515 L
.78297 .01515 L
.78439 .01515 L
.78698 .01515 L
.78934 .01515 L
Mistroke
.79506 .01515 L
.80048 .01515 L
.81016 .01515 L
.82067 .01515 L
.86152 .01515 L
.90086 .01515 L
.93868 .01515 L
.97619 .01515 L
Mfstroke
1 0 .427 r
.02381 .01472 m
.02846 .05721 L
.03068 .07466 L
.03279 .08845 L
.03398 .09492 L
.03527 .10077 L
.03635 .10471 L
.03754 .1081 L
.03882 .11075 L
.03952 .11179 L
.04018 .11251 L
.04135 .11329 L
.04262 .11347 L
.04393 .11306 L
.04516 .11225 L
.04586 .11162 L
.0465 .11097 L
.04793 .10926 L
.05297 .10157 L
.06244 .08539 L
.07287 .06959 L
.08414 .05613 L
.09479 .04655 L
.10458 .03989 L
.11432 .03486 L
.1234 .03128 L
.13338 .02829 L
.14407 .02593 L
.15424 .02427 L
.16531 .02296 L
.17576 .02207 L
.18543 .02146 L
.19506 .02101 L
.20409 .0207 L
.21401 .02046 L
.21958 .02036 L
.22469 .02028 L
.22943 .02023 L
.23204 .02021 L
.2345 .02019 L
.23679 .02017 L
.23928 .02016 L
.24037 .02015 L
.24154 .02015 L
.2426 .02015 L
.24362 .02014 L
.2449 .02014 L
.24607 .02014 L
.24734 .02014 L
.24805 .02014 L
Mistroke
.24871 .02014 L
.24992 .02014 L
.25102 .02014 L
.25228 .02015 L
.25348 .02015 L
.25619 .02016 L
.25869 .02017 L
.26432 .02021 L
.27343 .0203 L
.27844 .02034 L
.2809 .02036 L
.28318 .02037 L
.28587 .02038 L
.28728 .02039 L
.288 .02039 L
.28878 .02039 L
.29003 .0204 L
.29121 .0204 L
.29189 .0204 L
.2926 .0204 L
.29388 .0204 L
.29508 .02039 L
.29635 .02039 L
.29756 .02039 L
.29865 .02038 L
.30386 .02036 L
.30872 .02032 L
.31387 .02028 L
.32308 .02019 L
.34389 .02 L
.35335 .01993 L
.36351 .01986 L
.37309 .01981 L
.38183 .01978 L
.38663 .01977 L
.39173 .01975 L
.40089 .01974 L
.40598 .01973 L
.41075 .01972 L
.41599 .01972 L
.42165 .01972 L
.42659 .01971 L
.4312 .01971 L
.43626 .01971 L
.44166 .01971 L
.44439 .01971 L
.44734 .01971 L
.44995 .01971 L
.45271 .01971 L
.45519 .01971 L
Mistroke
.45793 .01971 L
.46275 .01971 L
.46752 .01971 L
.47003 .01971 L
.47271 .01971 L
.47529 .01971 L
.47762 .01971 L
.48218 .01971 L
.48488 .01971 L
.4878 .01971 L
.49309 .0197 L
.49828 .0197 L
.50306 .0197 L
.5219 .01969 L
.54257 .01968 L
.56373 .01967 L
.58301 .01966 L
.59259 .01966 L
.60301 .01966 L
.61284 .01965 L
.62194 .01965 L
.64062 .01965 L
.66123 .01965 L
.70145 .01965 L
.74016 .01964 L
.78132 .01964 L
.82096 .01963 L
.85909 .01963 L
.89967 .01963 L
.93874 .01963 L
.97619 .01963 L
Mfstroke
1 0 .403 r
.02381 .01472 m
.02499 .02577 L
.02605 .03478 L
.02721 .04273 L
.02846 .04902 L
.02961 .05283 L
.03068 .05499 L
.0317 .05616 L
.03279 .05673 L
.03395 .0568 L
.0352 .05647 L
.03638 .05591 L
.03746 .05524 L
.04262 .0512 L
.0529 .04285 L
.06244 .03646 L
.07277 .03114 L
.08405 .02686 L
.09398 .02409 L
.10458 .02192 L
.11487 .02037 L
.12599 .01916 L
.1365 .01834 L
.14616 .01778 L
.1559 .01736 L
.16499 .01707 L
.17496 .01683 L
.18565 .01665 L
.19582 .01652 L
.20119 .01647 L
.20689 .01642 L
.21186 .01639 L
.21734 .01635 L
.22701 .01631 L
.23193 .0163 L
.2371 .01628 L
.24152 .01628 L
.24636 .01627 L
.24909 .01627 L
.25158 .01627 L
.25296 .01626 L
.25368 .01626 L
.25445 .01626 L
.25512 .01626 L
.25586 .01626 L
.25716 .01626 L
.25847 .01626 L
.25967 .01626 L
.26033 .01626 L
.26105 .01626 L
Mistroke
.26235 .01626 L
.26358 .01626 L
.26488 .01626 L
.26721 .01627 L
.27223 .01627 L
.27497 .01627 L
.27753 .01627 L
.27898 .01627 L
.2803 .01627 L
.281 .01627 L
.28176 .01627 L
.28257 .01627 L
.28333 .01627 L
.28397 .01627 L
.28468 .01627 L
.28541 .01627 L
.2861 .01627 L
.28734 .01627 L
.28803 .01627 L
.28867 .01627 L
.2911 .01627 L
.29337 .01627 L
.2985 .01626 L
.30351 .01626 L
.30885 .01625 L
.3288 .01623 L
.3393 .01621 L
.3504 .0162 L
.36033 .01619 L
.37124 .01619 L
.38116 .01618 L
.39043 .01618 L
.39543 .01618 L
.40087 .01618 L
.406 .01617 L
.41076 .01617 L
.41975 .01617 L
.42931 .01617 L
.46703 .01617 L
.48798 .01617 L
.5072 .01617 L
.54585 .01617 L
.56475 .01616 L
.56993 .01616 L
.57547 .01616 L
.58031 .01616 L
.58544 .01616 L
.58798 .01616 L
.59076 .01616 L
.59333 .01616 L
Mistroke
.59567 .01616 L
.59843 .01616 L
.59995 .01616 L
.60065 .01616 L
.6014 .01616 L
.6021 .01616 L
.60273 .01616 L
.60397 .01616 L
.60466 .01616 L
.60541 .01616 L
.60612 .01616 L
.60677 .01616 L
.60793 .01616 L
.60918 .01616 L
.61036 .01616 L
.61144 .01616 L
.61407 .01616 L
.61656 .01616 L
.62152 .01616 L
.62691 .01616 L
.64631 .01616 L
.65661 .01616 L
.66202 .01616 L
.66771 .01616 L
.67276 .01616 L
.67544 .01616 L
.67829 .01616 L
.68092 .01616 L
.68331 .01616 L
.68446 .01616 L
.68571 .01616 L
.68689 .01616 L
.68798 .01616 L
.68908 .01616 L
.69025 .01616 L
.69137 .01616 L
.69238 .01616 L
.69357 .01616 L
.69486 .01616 L
.69609 .01616 L
.69722 .01616 L
.69971 .01616 L
.70196 .01616 L
.707 .01616 L
.7119 .01616 L
.71706 .01616 L
.7263 .01616 L
.74714 .01616 L
.78518 .01616 L
.82568 .01616 L
Mistroke
.86466 .01616 L
.90609 .01616 L
.94601 .01616 L
.97619 .01616 L
Mfstroke
1 0 .379 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01974 L
.05285 .01856 L
.06244 .0177 L
.07218 .01703 L
.0829 .01648 L
.09334 .01609 L
.10458 .01579 L
.11468 .01559 L
.12571 .01543 L
.13613 .01533 L
.1458 .01525 L
.15637 .01519 L
.16633 .01515 L
.17526 .01513 L
.18493 .0151 L
.19444 .01509 L
.20487 .01507 L
.21013 .01507 L
.21577 .01507 L
.22594 .01506 L
.23122 .01506 L
.23611 .01505 L
.24148 .01505 L
.24718 .01505 L
.24955 .01505 L
.25211 .01505 L
.25674 .01505 L
.25942 .01505 L
.26225 .01505 L
.26466 .01505 L
.26603 .01505 L
.2673 .01505 L
.27235 .01505 L
.27501 .01505 L
.27646 .01505 L
.27782 .01505 L
.28028 .01505 L
.28159 .01505 L
.28299 .01505 L
.28548 .01505 L
.28776 .01505 L
.29232 .01505 L
Mistroke
.29729 .01505 L
.30634 .01505 L
.3277 .01504 L
.34704 .01504 L
.35675 .01504 L
.36723 .01504 L
.37713 .01504 L
.38622 .01504 L
.39094 .01504 L
.39598 .01504 L
.40035 .01504 L
.40509 .01504 L
.41065 .01504 L
.41591 .01504 L
.42576 .01504 L
.44558 .01504 L
.45557 .01504 L
.4666 .01504 L
.48761 .01504 L
.49681 .01504 L
.50685 .01504 L
.52574 .01504 L
.53603 .01504 L
.54559 .01504 L
.55614 .01504 L
.56609 .01504 L
.57502 .01504 L
.58005 .01504 L
.58469 .01504 L
.58938 .01504 L
.59441 .01504 L
.60349 .01504 L
.60903 .01504 L
.61429 .01504 L
.62414 .01504 L
.66244 .01504 L
.6818 .01504 L
.68711 .01504 L
.69283 .01504 L
.69823 .01504 L
.70063 .01504 L
.70319 .01504 L
.70567 .01504 L
.70791 .01504 L
.709 .01504 L
.71018 .01504 L
.71129 .01504 L
.71231 .01504 L
.7135 .01504 L
.71462 .01504 L
Mistroke
.71584 .01504 L
.71716 .01504 L
.71854 .01504 L
.71984 .01504 L
.7223 .01504 L
.72471 .01504 L
.72729 .01504 L
.73192 .01504 L
.74243 .01504 L
.75272 .01504 L
.76385 .01504 L
.78403 .01504 L
.82505 .01504 L
.86456 .01504 L
.90255 .01504 L
.94299 .01504 L
.97619 .01504 L
Mfstroke
1 0 .356 r
.02381 .01472 m
.02499 .02568 L
.02605 .03417 L
.02729 .04131 L
.02846 .04542 L
.02954 .04747 L
.03053 .04839 L
.03163 .04872 L
.03279 .04859 L
.03395 .04817 L
.0352 .04751 L
.03746 .04605 L
.04262 .04235 L
.0521 .03607 L
.06244 .03068 L
.07373 .02634 L
.08445 .02335 L
.09489 .02124 L
.10458 .0198 L
.11515 .01864 L
.1251 .01784 L
.13404 .01731 L
.14371 .01687 L
.15321 .01656 L
.16365 .0163 L
.17454 .01611 L
.18471 .01598 L
.19516 .01588 L
.20506 .01581 L
.21395 .01577 L
.22362 .01574 L
.23302 .01571 L
.23837 .0157 L
.2434 .0157 L
.24867 .01569 L
.25351 .01569 L
.25604 .01569 L
.25881 .01568 L
.26021 .01568 L
.26171 .01568 L
.2644 .01568 L
.27408 .01568 L
.27643 .01568 L
.27775 .01568 L
.27895 .01568 L
.28172 .01568 L
.28432 .01568 L
.28707 .01568 L
.29008 .01568 L
.29555 .01568 L
Mistroke
.3059 .01567 L
.32688 .01566 L
.34588 .01565 L
.35604 .01564 L
.36559 .01564 L
.37568 .01563 L
.38132 .01563 L
.38658 .01563 L
.39611 .01563 L
.40116 .01563 L
.40656 .01563 L
.41223 .01563 L
.41759 .01563 L
.42764 .01563 L
.44759 .01563 L
.46602 .01563 L
.48631 .01563 L
.49624 .01563 L
.50534 .01563 L
.52354 .01563 L
.53309 .01563 L
.54314 .01563 L
.55271 .01563 L
.55806 .01563 L
.56292 .01563 L
.56746 .01563 L
.56985 .01563 L
.57238 .01563 L
.57459 .01563 L
.57702 .01563 L
.57809 .01563 L
.57923 .01563 L
.58031 .01563 L
.5813 .01563 L
.58248 .01563 L
.58358 .01563 L
.58479 .01563 L
.5861 .01563 L
.58739 .01563 L
.58804 .01563 L
.58876 .01563 L
.5912 .01563 L
.59349 .01563 L
.59594 .01563 L
.60036 .01563 L
.60595 .01563 L
.61123 .01563 L
.62111 .01563 L
.65955 .01563 L
.6698 .01563 L
Mistroke
.6794 .01563 L
.68941 .01563 L
.69472 .01563 L
.69749 .01563 L
.70043 .01563 L
.70319 .01563 L
.70568 .01563 L
.70688 .01563 L
.70819 .01563 L
.70942 .01563 L
.71055 .01563 L
.71119 .01563 L
.71187 .01563 L
.71311 .01563 L
.71386 .01563 L
.71458 .01563 L
.71522 .01563 L
.71592 .01563 L
.71734 .01563 L
.71886 .01563 L
.72158 .01563 L
.72651 .01563 L
.73114 .01563 L
.74168 .01563 L
.76188 .01563 L
.78039 .01563 L
.82003 .01563 L
.85816 .01563 L
.89874 .01563 L
.9378 .01562 L
.97619 .01562 L
Mfstroke
1 0 .332 r
.02381 .01472 m
.02499 .02568 L
.02605 .0342 L
.02729 .04143 L
.02846 .04569 L
.02954 .04789 L
.03053 .04893 L
.03163 .04936 L
.03279 .04932 L
.03395 .04896 L
.0352 .04835 L
.03746 .04694 L
.04262 .04324 L
.0521 .03685 L
.06244 .03131 L
.07373 .02683 L
.08445 .02373 L
.09489 .02153 L
.10458 .02003 L
.11515 .01882 L
.1251 .01798 L
.13404 .01742 L
.14371 .01696 L
.15321 .01663 L
.16365 .01636 L
.17454 .01616 L
.18471 .01602 L
.19516 .01592 L
.20506 .01585 L
.21395 .0158 L
.22362 .01576 L
.23302 .01574 L
.23837 .01573 L
.2434 .01572 L
.24867 .01571 L
.25351 .01571 L
.25604 .01571 L
.25881 .01571 L
.26021 .01571 L
.26171 .01571 L
.2644 .0157 L
.27408 .0157 L
.27663 .0157 L
.27803 .0157 L
.27937 .0157 L
.2806 .0157 L
.28195 .0157 L
.28432 .0157 L
.28709 .0157 L
.28966 .0157 L
Mistroke
.29555 .0157 L
.30056 .0157 L
.3059 .01569 L
.32512 .01568 L
.34588 .01567 L
.35706 .01566 L
.36734 .01566 L
.37716 .01565 L
.38258 .01565 L
.38752 .01565 L
.39702 .01565 L
.40225 .01565 L
.40719 .01565 L
.41599 .01565 L
.42554 .01565 L
.46638 .01565 L
.48667 .01564 L
.50569 .01564 L
.5239 .01564 L
.5435 .01564 L
.55309 .01564 L
.56358 .01564 L
.57452 .01564 L
.58469 .01564 L
.59524 .01564 L
.60519 .01564 L
.62379 .01564 L
.64384 .01564 L
.66231 .01564 L
.6827 .01564 L
.70176 .01564 L
.71116 .01564 L
.72006 .01564 L
.73033 .01564 L
.7397 .01564 L
.74428 .01564 L
.74934 .01564 L
.75188 .01564 L
.75462 .01564 L
.75588 .01564 L
.75721 .01564 L
.75845 .01564 L
.75958 .01564 L
.76072 .01564 L
.76178 .01564 L
.76291 .01564 L
.76414 .01564 L
.76521 .01564 L
.76634 .01564 L
.76731 .01564 L
Mistroke
.76837 .01564 L
.77077 .01564 L
.77334 .01564 L
.778 .01564 L
.78324 .01564 L
.78811 .01564 L
.79915 .01564 L
.81924 .01564 L
.85839 .01564 L
.89999 .01564 L
.94008 .01564 L
.97619 .01564 L
Mfstroke
1 0 .308 r
.02381 .01472 m
.02846 .05717 L
.03068 .07442 L
.03279 .08775 L
.03398 .0938 L
.03527 .09908 L
.03645 .10273 L
.03754 .10518 L
.03871 .10695 L
.04 .10798 L
.04065 .10818 L
.04135 .10819 L
.04262 .10776 L
.04393 .1068 L
.04516 .10555 L
.04793 .10185 L
.05297 .09361 L
.06244 .07777 L
.07295 .06292 L
.08284 .05199 L
.09424 .04251 L
.10458 .03619 L
.11434 .03173 L
.12466 .02821 L
.13346 .02594 L
.14313 .02406 L
.15334 .02257 L
.16264 .02156 L
.17338 .02071 L
.18355 .02012 L
.19321 .01971 L
.20346 .01939 L
.21222 .01919 L
.22188 .01903 L
.2268 .01898 L
.23198 .01893 L
.2364 .01889 L
.24123 .01887 L
.24397 .01886 L
.24646 .01885 L
.24783 .01885 L
.24856 .01885 L
.24933 .01885 L
.25 .01885 L
.25074 .01885 L
.25204 .01884 L
.25334 .01884 L
.25454 .01885 L
.2552 .01885 L
.25592 .01885 L
Mistroke
.25723 .01885 L
.25975 .01885 L
.26209 .01886 L
.27268 .01891 L
.27788 .01893 L
.28015 .01894 L
.28265 .01894 L
.28374 .01895 L
.2849 .01895 L
.286 .01895 L
.28701 .01895 L
.28814 .01895 L
.28937 .01895 L
.29053 .01895 L
.2916 .01895 L
.29275 .01895 L
.29383 .01895 L
.29502 .01895 L
.29629 .01894 L
.29889 .01894 L
.30127 .01893 L
.3111 .01888 L
.32023 .01883 L
.34095 .0187 L
.3515 .01865 L
.36144 .01861 L
.37037 .01858 L
.38004 .01855 L
.38953 .01854 L
.39492 .01853 L
.39996 .01852 L
.40517 .01852 L
.41012 .01852 L
.41581 .01851 L
.42101 .01851 L
.45931 .01849 L
.50006 .01848 L
.52029 .01847 L
.5393 .01846 L
.55766 .01846 L
.57701 .01845 L
.58664 .01845 L
.59717 .01845 L
.61567 .01845 L
.62593 .01845 L
.63526 .01845 L
.6562 .01845 L
.69615 .01844 L
.73458 .01844 L
.75404 .01844 L
Mistroke
.77547 .01844 L
.81484 .01844 L
.83426 .01844 L
.85515 .01844 L
.87487 .01844 L
.89639 .01844 L
.91723 .01844 L
.93612 .01844 L
.95552 .01844 L
.96617 .01844 L
.97619 .01844 L
Mfstroke
1 0 .285 r
.02381 .01472 m
.02499 .02568 L
.02605 .03424 L
.02729 .04161 L
.02846 .04607 L
.02954 .0485 L
.03053 .04974 L
.03163 .05036 L
.03279 .05048 L
.03395 .05024 L
.0352 .04973 L
.03746 .04844 L
.04262 .04484 L
.0521 .03836 L
.06244 .03262 L
.07373 .02792 L
.08445 .02465 L
.09489 .02232 L
.10458 .02071 L
.11515 .01941 L
.1251 .01852 L
.13404 .01791 L
.14371 .01742 L
.15321 .01705 L
.16365 .01676 L
.17454 .01654 L
.18471 .01639 L
.19516 .01628 L
.20506 .0162 L
.21395 .01615 L
.21894 .01613 L
.22362 .01611 L
.23302 .01609 L
.23801 .01608 L
.24058 .01607 L
.2434 .01607 L
.24598 .01606 L
.24873 .01606 L
.25026 .01606 L
.25165 .01606 L
.25306 .01606 L
.25435 .01606 L
.25556 .01606 L
.25684 .01606 L
.25812 .01606 L
.25884 .01606 L
.25952 .01606 L
.26075 .01606 L
.26188 .01606 L
.26317 .01606 L
Mistroke
.2644 .01606 L
.27402 .01606 L
.27678 .01606 L
.27939 .01606 L
.28052 .01606 L
.28172 .01606 L
.28304 .01606 L
.28425 .01606 L
.2854 .01606 L
.28644 .01606 L
.28765 .01606 L
.28879 .01606 L
.28985 .01606 L
.29082 .01606 L
.29303 .01606 L
.29525 .01606 L
.2977 .01606 L
.30265 .01606 L
.32366 .01603 L
.3429 .01601 L
.36179 .016 L
.37128 .01599 L
.37661 .01599 L
.38164 .01599 L
.38659 .01599 L
.39194 .01599 L
.40129 .01599 L
.4066 .01598 L
.41221 .01598 L
.42226 .01598 L
.4602 .01598 L
.48132 .01598 L
.50059 .01598 L
.52077 .01597 L
.53946 .01597 L
.55853 .01597 L
.56858 .01597 L
.57928 .01597 L
.58863 .01597 L
.59872 .01597 L
.60825 .01597 L
.617 .01597 L
.62678 .01597 L
.6359 .01597 L
.65659 .01597 L
.6956 .01597 L
.73707 .01597 L
.77702 .01597 L
.81545 .01597 L
.85634 .01597 L
Mistroke
.89571 .01597 L
.93356 .01597 L
.95299 .01597 L
.97387 .01597 L
.97619 .01597 L
Mfstroke
1 0 .261 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04313 L
.02846 .0488 L
.02954 .05225 L
.03053 .05423 L
.03163 .05542 L
.03279 .05591 L
.03395 .05588 L
.0352 .05546 L
.03638 .05483 L
.03746 .05413 L
.04262 .05002 L
.0529 .04178 L
.06244 .03555 L
.07277 .03039 L
.08405 .02624 L
.09398 .02357 L
.10458 .02147 L
.11487 .01998 L
.12599 .01881 L
.1365 .01802 L
.14616 .01748 L
.1559 .01708 L
.16499 .0168 L
.17496 .01657 L
.18565 .01639 L
.19582 .01626 L
.20119 .01621 L
.20689 .01617 L
.21186 .01614 L
.21734 .01611 L
.22701 .01607 L
.23193 .01605 L
.2371 .01604 L
.24158 .01603 L
.24636 .01602 L
.24906 .01602 L
.25152 .01601 L
.25402 .01601 L
.25632 .01601 L
.25901 .01601 L
.26042 .01601 L
.26115 .01601 L
.26192 .01601 L
.26322 .01601 L
.26444 .01601 L
.26519 .01601 L
.26589 .01601 L
Mistroke
.26652 .01601 L
.26721 .01601 L
.2721 .01601 L
.27466 .01601 L
.27606 .01601 L
.27737 .01601 L
.27852 .01601 L
.27975 .01601 L
.28045 .01601 L
.28111 .01601 L
.28235 .01601 L
.28349 .01601 L
.28454 .01601 L
.2857 .01601 L
.28693 .01601 L
.28963 .01601 L
.29216 .01601 L
.29794 .016 L
.30274 .016 L
.30791 .01599 L
.3276 .01597 L
.338 .01596 L
.3491 .01595 L
.35989 .01595 L
.36967 .01594 L
.37951 .01594 L
.38878 .01593 L
.39342 .01593 L
.39853 .01593 L
.4035 .01593 L
.40883 .01593 L
.41838 .01593 L
.4273 .01593 L
.44851 .01593 L
.46863 .01593 L
.50692 .01592 L
.52667 .01592 L
.53678 .01592 L
.54767 .01592 L
.55782 .01592 L
.56712 .01592 L
.57595 .01592 L
.58539 .01592 L
.59518 .01592 L
.60429 .01592 L
.62498 .01592 L
.63521 .01592 L
.64631 .01592 L
.66645 .01592 L
.68591 .01592 L
Mistroke
.70734 .01592 L
.71713 .01592 L
.72767 .01592 L
.73754 .01592 L
.74671 .01592 L
.75682 .01592 L
.76216 .01592 L
.76786 .01592 L
.77329 .01592 L
.7784 .01592 L
.78299 .01592 L
.78557 .01592 L
.78795 .01592 L
.78922 .01592 L
.79041 .01592 L
.7915 .01592 L
.79266 .01592 L
.79391 .01592 L
.79507 .01592 L
.79632 .01592 L
.79703 .01592 L
.7977 .01592 L
.79881 .01592 L
.79998 .01592 L
.80098 .01592 L
.80207 .01592 L
.80452 .01592 L
.80679 .01592 L
.81203 .01592 L
.81679 .01592 L
.82746 .01592 L
.84666 .01592 L
.86746 .01592 L
.9084 .01592 L
.94782 .01592 L
.97619 .01592 L
Mfstroke
1 0 .237 r
.02381 .01472 m
.02846 .05704 L
.03068 .07393 L
.03279 .08663 L
.03398 .09221 L
.03527 .0969 L
.03645 .1 L
.03754 .10196 L
.03871 .10323 L
.04 .10377 L
.04065 .10376 L
.04135 .10357 L
.04262 .10282 L
.04393 .10162 L
.04516 .1002 L
.04793 .09631 L
.05297 .08813 L
.06244 .073 L
.07295 .05907 L
.08284 .0489 L
.09424 .04013 L
.10458 .03431 L
.11434 .0302 L
.12466 .02697 L
.13346 .02489 L
.14313 .02316 L
.15334 .02181 L
.16264 .02088 L
.17338 .0201 L
.18355 .01956 L
.19321 .01919 L
.20346 .0189 L
.21222 .01872 L
.22188 .01857 L
.2268 .01852 L
.23198 .01847 L
.2364 .01844 L
.24123 .01842 L
.24397 .01841 L
.24646 .0184 L
.24783 .0184 L
.24933 .0184 L
.25001 .01839 L
.25074 .01839 L
.25204 .01839 L
.25323 .01839 L
.25451 .01839 L
.25572 .01839 L
.25682 .01839 L
.25811 .01839 L
Mistroke
.25952 .0184 L
.26209 .0184 L
.26742 .01842 L
.27243 .01843 L
.27699 .01845 L
.27948 .01845 L
.2818 .01846 L
.28311 .01846 L
.28431 .01846 L
.28494 .01846 L
.28564 .01846 L
.28637 .01846 L
.28706 .01846 L
.28827 .01846 L
.28957 .01846 L
.29067 .01846 L
.29189 .01846 L
.2933 .01846 L
.2946 .01846 L
.29751 .01845 L
.30008 .01844 L
.30279 .01843 L
.34095 .01825 L
.35106 .01821 L
.36059 .01818 L
.37159 .01815 L
.38156 .01813 L
.39131 .01811 L
.39622 .01811 L
.40161 .0181 L
.40622 .0181 L
.41116 .0181 L
.42008 .0181 L
.46141 .01808 L
.48208 .01807 L
.50122 .01806 L
.51978 .01805 L
.53952 .01805 L
.54887 .01805 L
.55896 .01805 L
.57723 .01804 L
.58679 .01804 L
.59725 .01804 L
.60817 .01804 L
.61834 .01804 L
.63877 .01804 L
.65736 .01804 L
.69731 .01804 L
.73574 .01804 L
.7552 .01804 L
Mistroke
.77663 .01804 L
.816 .01804 L
.83542 .01804 L
.8563 .01804 L
.87603 .01804 L
.89755 .01804 L
.91816 .01804 L
.93728 .01804 L
.94779 .01804 L
.95769 .01804 L
.96658 .01804 L
.97619 .01804 L
Mfstroke
1 0 .213 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01975 L
.05285 .01857 L
.06244 .01771 L
.07218 .01704 L
.0829 .0165 L
.09334 .01611 L
.10458 .01581 L
.11468 .01561 L
.12571 .01545 L
.13613 .01535 L
.1458 .01528 L
.15637 .01522 L
.16633 .01518 L
.17526 .01515 L
.18493 .01513 L
.19444 .01511 L
.20487 .0151 L
.21013 .0151 L
.21577 .01509 L
.22594 .01509 L
.23122 .01508 L
.23611 .01508 L
.24148 .01508 L
.24422 .01508 L
.24718 .01508 L
.24975 .01508 L
.25211 .01508 L
.25437 .01508 L
.25674 .01508 L
.258 .01508 L
.25935 .01508 L
.26063 .01508 L
.26178 .01508 L
.26249 .01508 L
.26314 .01508 L
.26386 .01508 L
.26462 .01508 L
.2659 .01508 L
.26662 .01508 L
.2673 .01508 L
.27228 .01508 L
.27364 .01508 L
Mistroke
.27439 .01508 L
.27509 .01508 L
.27575 .01508 L
.27646 .01508 L
.27771 .01508 L
.2789 .01508 L
.28021 .01508 L
.28087 .01508 L
.28158 .01508 L
.28285 .01508 L
.28413 .01508 L
.28533 .01508 L
.28759 .01508 L
.2922 .01508 L
.29647 .01508 L
.30612 .01508 L
.32641 .01507 L
.34544 .01507 L
.35431 .01507 L
.36365 .01507 L
.37388 .01507 L
.38324 .01507 L
.38826 .01507 L
.39281 .01507 L
.39772 .01507 L
.40302 .01507 L
.40795 .01507 L
.41248 .01507 L
.4214 .01507 L
.43047 .01507 L
.44021 .01507 L
.45088 .01507 L
.46086 .01507 L
.48065 .01507 L
.49109 .01507 L
.50219 .01507 L
.51201 .01507 L
.52286 .01507 L
.53273 .01507 L
.542 .01507 L
.54669 .01507 L
.55182 .01507 L
.55717 .01507 L
.55974 .01507 L
.56216 .01507 L
.5644 .01507 L
.56684 .01507 L
.56906 .01507 L
.5711 .01507 L
.57224 .01507 L
Mistroke
.57331 .01507 L
.57448 .01507 L
.57574 .01507 L
.57706 .01507 L
.57831 .01507 L
.57943 .01507 L
.58066 .01507 L
.58199 .01507 L
.58321 .01507 L
.58598 .01507 L
.58841 .01507 L
.59098 .01507 L
.60034 .01507 L
.61035 .01507 L
.62132 .01507 L
.66177 .01507 L
.68042 .01507 L
.69025 .01507 L
.70069 .01507 L
.70595 .01507 L
.71174 .01507 L
.71701 .01507 L
.72195 .01507 L
.72441 .01507 L
.727 .01507 L
.72922 .01507 L
.73164 .01507 L
.73301 .01507 L
.73425 .01507 L
.73494 .01507 L
.73569 .01507 L
.7364 .01507 L
.73705 .01507 L
.73821 .01507 L
.73949 .01507 L
.74013 .01507 L
.74083 .01507 L
.74208 .01507 L
.74341 .01507 L
.74463 .01507 L
.74734 .01507 L
.74985 .01507 L
.75222 .01507 L
.76327 .01507 L
.77293 .01507 L
.78337 .01507 L
.82445 .01507 L
.86401 .01507 L
.90205 .01507 L
.94255 .01507 L
Mistroke
.97619 .01507 L
Mfstroke
1 0 .19 r
.02381 .01472 m
.02499 .02015 L
.02605 .02128 L
.02729 .02173 L
.02846 .02188 L
.02954 .02191 L
.03053 .02188 L
.03163 .02181 L
.03279 .02171 L
.04262 .02054 L
.05217 .01941 L
.06244 .01843 L
.0728 .01765 L
.0825 .0171 L
.09403 .0166 L
.10458 .01627 L
.11442 .01604 L
.12357 .01588 L
.1336 .01575 L
.14429 .01564 L
.15457 .01557 L
.1657 .01551 L
.17621 .01547 L
.18587 .01544 L
.19561 .01542 L
.2047 .01541 L
.21467 .0154 L
.22026 .01539 L
.22536 .01539 L
.23016 .01539 L
.2328 .01539 L
.23527 .01539 L
.23755 .01538 L
.23963 .01538 L
.24195 .01538 L
.24316 .01538 L
.24444 .01538 L
.24574 .01538 L
.24693 .01538 L
.24758 .01538 L
.24829 .01538 L
.24958 .01538 L
.25079 .01538 L
.25207 .01538 L
.25316 .01538 L
.25436 .01538 L
.25706 .01538 L
.25996 .01538 L
.2652 .01539 L
.27533 .01539 L
Mistroke
.27811 .01539 L
.28106 .01539 L
.2825 .01539 L
.28385 .01539 L
.28507 .01539 L
.28638 .01539 L
.28764 .01539 L
.28881 .01539 L
.2901 .01539 L
.29082 .01539 L
.29148 .01539 L
.29216 .01539 L
.2928 .01539 L
.29424 .01539 L
.29551 .01539 L
.29685 .01539 L
.30143 .01539 L
.30648 .01539 L
.32749 .01538 L
.34674 .01537 L
.35652 .01537 L
.36562 .01537 L
.37511 .01537 L
.38547 .01537 L
.39054 .01536 L
.39603 .01536 L
.40086 .01536 L
.40597 .01536 L
.41059 .01536 L
.41566 .01536 L
.42457 .01536 L
.46496 .01536 L
.50384 .01536 L
.52363 .01536 L
.54517 .01536 L
.56584 .01536 L
.57571 .01536 L
.58498 .01536 L
.59395 .01536 L
.60362 .01536 L
.60885 .01536 L
.61436 .01536 L
.61907 .01536 L
.62422 .01536 L
.62949 .01536 L
.63447 .01536 L
.63895 .01536 L
.6438 .01536 L
.65377 .01536 L
.65906 .01536 L
Mistroke
.66475 .01536 L
.6701 .01536 L
.675 .01536 L
.6846 .01536 L
.69538 .01536 L
.70563 .01536 L
.74384 .01536 L
.78451 .01536 L
.82366 .01536 L
.86526 .01536 L
.90535 .01536 L
.94392 .01536 L
.97619 .01536 L
Mfstroke
1 0 .166 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01955 L
.05285 .01838 L
.06244 .01754 L
.07218 .01689 L
.0829 .01636 L
.09334 .01599 L
.10458 .0157 L
.11468 .01551 L
.12571 .01536 L
.13613 .01526 L
.1458 .01519 L
.15637 .01514 L
.16633 .0151 L
.17526 .01507 L
.18493 .01505 L
.19444 .01504 L
.20487 .01502 L
.21013 .01502 L
.21577 .01502 L
.22594 .01501 L
.23122 .01501 L
.23611 .01501 L
.24137 .015 L
.24718 .015 L
.25221 .015 L
.25693 .015 L
.25954 .015 L
.26192 .015 L
.2673 .015 L
.27722 .015 L
.28268 .015 L
.28782 .015 L
.29783 .015 L
.30692 .015 L
.32543 .015 L
.34503 .015 L
.35456 .01499 L
.36504 .01499 L
.37458 .01499 L
.3835 .01499 L
.38848 .01499 L
.3939 .01499 L
Mistroke
.39903 .01499 L
.40378 .01499 L
.4085 .01499 L
.41276 .01499 L
.42232 .01499 L
.43171 .01499 L
.43643 .01499 L
.44161 .01499 L
.45246 .01499 L
.46244 .01499 L
.48363 .01499 L
.50292 .01499 L
.51251 .01499 L
.52294 .01499 L
.53278 .01499 L
.54188 .01499 L
.55153 .01499 L
.56058 .01499 L
.56576 .01499 L
.57051 .01499 L
.57572 .01499 L
.5812 .01499 L
.58621 .01499 L
.59077 .01499 L
.59329 .01499 L
.59602 .01499 L
.5986 .01499 L
.59975 .01499 L
.60098 .01499 L
.60213 .01499 L
.60318 .01499 L
.60423 .01499 L
.60523 .01499 L
.6064 .01499 L
.60747 .01499 L
.60865 .01499 L
.60991 .01499 L
.61102 .01499 L
.61222 .01499 L
.6144 .01499 L
.61698 .01499 L
.61936 .01499 L
.62409 .01499 L
.62914 .01499 L
.63826 .01499 L
.65895 .01499 L
.67884 .01499 L
.69006 .01499 L
.69541 .01499 L
.70041 .01499 L
Mistroke
.70486 .01499 L
.70736 .01499 L
.70965 .01499 L
.71214 .01499 L
.71355 .01499 L
.71486 .01499 L
.71612 .01499 L
.71726 .01499 L
.71857 .01499 L
.71981 .01499 L
.721 .01499 L
.72231 .01499 L
.72368 .01499 L
.72496 .01499 L
.72724 .01499 L
.72969 .01499 L
.73527 .01499 L
.74036 .01499 L
.75029 .01499 L
.75946 .01499 L
.78023 .01499 L
.81951 .01499 L
.85729 .01499 L
.89751 .01499 L
.93622 .01499 L
.97619 .01499 L
Mfstroke
1 0 .142 r
.02381 .01472 m
.02499 .02577 L
.02605 .03476 L
.02729 .04314 L
.02846 .04881 L
.02954 .05228 L
.03053 .05427 L
.03163 .05547 L
.03279 .05598 L
.03395 .05596 L
.0352 .05556 L
.03638 .05494 L
.03746 .05424 L
.04262 .05016 L
.0529 .04193 L
.06244 .0357 L
.07277 .03052 L
.08405 .02636 L
.09398 .02367 L
.10458 .02156 L
.11487 .02006 L
.12599 .01889 L
.1365 .01809 L
.14616 .01755 L
.1559 .01714 L
.16499 .01686 L
.17496 .01663 L
.18565 .01645 L
.19582 .01632 L
.20119 .01627 L
.20689 .01623 L
.21186 .0162 L
.21734 .01617 L
.22701 .01612 L
.23193 .01611 L
.2371 .01609 L
.24152 .01609 L
.24636 .01608 L
.24909 .01608 L
.25158 .01607 L
.25296 .01607 L
.25445 .01607 L
.25574 .01607 L
.25716 .01607 L
.25847 .01607 L
.2597 .01607 L
.261 .01607 L
.26173 .01607 L
.26239 .01607 L
.26358 .01607 L
Mistroke
.26487 .01607 L
.26608 .01607 L
.26721 .01607 L
.26851 .01607 L
.26987 .01607 L
.27231 .01607 L
.27515 .01607 L
.27654 .01607 L
.27781 .01607 L
.27899 .01607 L
.2801 .01607 L
.28128 .01607 L
.28256 .01607 L
.28388 .01607 L
.28454 .01607 L
.28527 .01607 L
.28656 .01607 L
.28778 .01607 L
.29006 .01607 L
.29246 .01607 L
.29674 .01607 L
.30136 .01606 L
.3064 .01606 L
.32769 .01603 L
.34701 .01601 L
.35667 .01601 L
.36713 .016 L
.37701 .016 L
.38611 .01599 L
.3908 .01599 L
.39583 .01599 L
.40491 .01599 L
.41045 .01599 L
.41571 .01599 L
.42556 .01599 L
.46386 .01598 L
.48322 .01598 L
.50461 .01598 L
.51434 .01598 L
.52484 .01598 L
.54384 .01598 L
.5534 .01597 L
.56386 .01597 L
.57478 .01597 L
.58495 .01597 L
.59546 .01597 L
.60538 .01597 L
.61429 .01597 L
.62396 .01597 L
.66485 .01597 L
Mistroke
.68518 .01597 L
.70422 .01597 L
.72363 .01597 L
.74208 .01597 L
.75177 .01597 L
.76234 .01597 L
.77195 .01597 L
.78087 .01597 L
.78595 .01597 L
.79145 .01597 L
.79663 .01597 L
.8014 .01597 L
.80572 .01597 L
.81046 .01597 L
.81284 .01597 L
.81416 .01597 L
.8154 .01597 L
.81656 .01597 L
.81782 .01597 L
.81896 .01597 L
.82002 .01597 L
.8212 .01597 L
.82244 .01597 L
.8235 .01597 L
.82466 .01597 L
.82591 .01597 L
.82661 .01597 L
.82725 .01597 L
.82965 .01597 L
.83189 .01597 L
.83431 .01597 L
.8387 .01597 L
.84942 .01597 L
.8593 .01597 L
.87808 .01597 L
.89873 .01597 L
.91819 .01597 L
.93909 .01597 L
.97619 .01597 L
Mfstroke
1 0 .119 r
.02381 .01472 m
.02499 .02005 L
.02605 .02105 L
.02729 .02138 L
.02846 .02144 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02108 L
.04262 .01978 L
.05217 .01867 L
.06244 .01775 L
.0728 .01704 L
.0825 .01655 L
.09403 .01612 L
.10458 .01584 L
.11442 .01564 L
.12357 .01551 L
.1336 .01539 L
.14429 .01531 L
.15457 .01525 L
.1657 .0152 L
.17621 .01517 L
.18587 .01515 L
.19561 .01513 L
.2047 .01512 L
.21467 .01511 L
.22026 .01511 L
.22536 .0151 L
.23016 .0151 L
.23527 .0151 L
.23963 .0151 L
.24444 .0151 L
.24695 .0151 L
.2496 .0151 L
.25249 .0151 L
.25378 .0151 L
.25515 .0151 L
.25645 .0151 L
.25764 .0151 L
.25883 .0151 L
.25995 .0151 L
.26126 .0151 L
.26247 .0151 L
.2631 .0151 L
.2638 .0151 L
.26452 .0151 L
.2652 .0151 L
.26645 .0151 L
.26779 .0151 L
Mistroke
.27018 .0151 L
.27298 .0151 L
.27435 .0151 L
.27561 .0151 L
.27682 .0151 L
.2781 .0151 L
.27939 .0151 L
.28012 .0151 L
.2808 .0151 L
.28198 .0151 L
.28306 .0151 L
.28431 .0151 L
.28549 .0151 L
.28773 .0151 L
.29011 .0151 L
.29438 .0151 L
.30403 .01509 L
.32376 .01509 L
.34183 .01509 L
.35109 .01509 L
.36122 .01509 L
.37139 .01509 L
.37689 .01509 L
.38209 .01509 L
.38703 .01509 L
.39239 .01509 L
.39684 .01509 L
.40173 .01508 L
.40704 .01508 L
.41265 .01508 L
.4227 .01508 L
.4327 .01508 L
.44218 .01508 L
.45312 .01508 L
.46309 .01508 L
.48129 .01508 L
.49165 .01508 L
.50139 .01508 L
.52114 .01508 L
.53124 .01508 L
.54214 .01508 L
.55169 .01508 L
.56215 .01508 L
.57308 .01508 L
.58325 .01508 L
.58828 .01508 L
.59375 .01508 L
.59891 .01508 L
.60368 .01508 L
.60797 .01508 L
Mistroke
.61041 .01508 L
.6127 .01508 L
.61511 .01508 L
.61731 .01508 L
.61852 .01508 L
.61916 .01508 L
.61985 .01508 L
.6211 .01508 L
.62226 .01508 L
.6235 .01508 L
.62421 .01508 L
.62487 .01508 L
.62556 .01508 L
.6262 .01508 L
.62762 .01508 L
.62884 .01508 L
.63016 .01508 L
.63255 .01508 L
.63834 .01508 L
.64369 .01508 L
.65409 .01508 L
.66386 .01508 L
.67285 .01508 L
.67532 .01508 L
.67791 .01508 L
.68033 .01508 L
.68254 .01508 L
.68372 .01508 L
.68501 .01508 L
.68571 .01508 L
.68636 .01508 L
.68764 .01508 L
.68874 .01508 L
.68995 .01508 L
.69121 .01508 L
.69238 .01508 L
.69305 .01508 L
.69378 .01508 L
.6951 .01508 L
.69638 .01508 L
.69757 .01508 L
.70027 .01508 L
.70315 .01508 L
.70853 .01508 L
.71347 .01508 L
.72461 .01508 L
.7448 .01508 L
.78436 .01508 L
.8224 .01508 L
.8629 .01508 L
Mistroke
.90188 .01508 L
.94332 .01508 L
.97619 .01508 L
Mfstroke
1 0 .095 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .02129 L
.02954 .02124 L
.03053 .02115 L
.03279 .02088 L
.04262 .01955 L
.05285 .01838 L
.06244 .01754 L
.07218 .01689 L
.0829 .01636 L
.09334 .01598 L
.10458 .01569 L
.11468 .0155 L
.12571 .01535 L
.13613 .01525 L
.1458 .01518 L
.15637 .01513 L
.16633 .01509 L
.17526 .01506 L
.18493 .01504 L
.19444 .01503 L
.20487 .01501 L
.21013 .01501 L
.21577 .015 L
.22594 .015 L
.23122 .015 L
.23611 .01499 L
.24137 .01499 L
.24718 .01499 L
.25221 .01499 L
.25693 .01499 L
.26192 .01499 L
.26473 .01499 L
.2673 .01499 L
.27722 .01499 L
.28268 .01499 L
.28782 .01499 L
.29783 .01499 L
.30692 .01499 L
.32543 .01498 L
.34503 .01498 L
.35456 .01498 L
.36504 .01498 L
.37458 .01498 L
.3835 .01498 L
.38848 .01498 L
.3939 .01498 L
Mistroke
.39869 .01498 L
.40378 .01498 L
.40883 .01498 L
.4134 .01498 L
.42232 .01498 L
.43171 .01498 L
.44161 .01498 L
.45246 .01498 L
.46244 .01498 L
.48234 .01498 L
.50046 .01498 L
.50983 .01498 L
.52001 .01498 L
.53077 .01498 L
.54094 .01498 L
.55036 .01498 L
.56075 .01498 L
.56598 .01498 L
.5716 .01498 L
.57691 .01498 L
.58177 .01498 L
.58653 .01498 L
.5916 .01498 L
.59639 .01498 L
.60074 .01498 L
.6034 .01498 L
.60586 .01498 L
.6085 .01498 L
.6114 .01498 L
.61628 .01498 L
.62145 .01498 L
.66184 .01498 L
.68046 .01498 L
.68556 .01498 L
.69098 .01498 L
.6932 .01498 L
.69561 .01498 L
.69698 .01498 L
.69824 .01498 L
.69954 .01498 L
.70072 .01498 L
.70195 .01498 L
.70327 .01498 L
.7045 .01498 L
.70565 .01498 L
.7063 .01498 L
.707 .01498 L
.70824 .01498 L
.70893 .01498 L
.70958 .01498 L
Mistroke
.71105 .01498 L
.71379 .01498 L
.71629 .01498 L
.72193 .01498 L
.72687 .01498 L
.73225 .01498 L
.74205 .01498 L
.76174 .01498 L
.78271 .01498 L
.82432 .01498 L
.8644 .01498 L
.90297 .01498 L
.944 .01498 L
.97619 .01498 L
Mfstroke
1 0 .071 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01974 L
.05285 .01856 L
.06244 .0177 L
.07218 .01703 L
.0829 .01648 L
.09334 .01609 L
.10458 .01579 L
.11468 .01559 L
.12571 .01543 L
.13613 .01533 L
.1458 .01525 L
.15637 .01519 L
.16633 .01515 L
.17526 .01513 L
.18493 .0151 L
.19444 .01509 L
.20487 .01507 L
.21013 .01507 L
.21577 .01506 L
.22594 .01506 L
.23122 .01506 L
.23611 .01505 L
.24148 .01505 L
.24718 .01505 L
.24955 .01505 L
.25211 .01505 L
.25674 .01505 L
.25942 .01505 L
.26225 .01505 L
.26466 .01505 L
.26603 .01505 L
.2673 .01505 L
.27235 .01505 L
.27501 .01505 L
.27782 .01505 L
.28028 .01505 L
.28168 .01505 L
.28299 .01505 L
.28543 .01505 L
.28776 .01505 L
.29244 .01505 L
.29672 .01505 L
Mistroke
.30634 .01505 L
.32641 .01504 L
.34459 .01504 L
.35406 .01504 L
.3643 .01504 L
.37511 .01504 L
.38038 .01504 L
.38529 .01504 L
.39482 .01504 L
.39986 .01504 L
.40526 .01504 L
.41093 .01504 L
.4163 .01504 L
.42634 .01504 L
.43602 .01504 L
.44629 .01504 L
.46472 .01504 L
.48446 .01504 L
.50253 .01504 L
.52191 .01504 L
.53208 .01504 L
.54278 .01504 L
.55235 .01504 L
.55761 .01504 L
.56256 .01504 L
.56719 .01504 L
.5722 .01504 L
.58094 .01504 L
.58585 .01504 L
.59043 .01504 L
.59588 .01504 L
.60086 .01504 L
.61101 .01504 L
.61661 .01504 L
.62191 .01504 L
.66021 .01504 L
.67957 .01504 L
.6906 .01504 L
.69564 .01504 L
.70096 .01504 L
.70566 .01504 L
.70832 .01504 L
.7096 .01504 L
.7108 .01504 L
.7119 .01504 L
.71309 .01504 L
.71417 .01504 L
.71517 .01504 L
.71624 .01504 L
.71743 .01504 L
Mistroke
.71867 .01504 L
.71983 .01504 L
.72109 .01504 L
.7218 .01504 L
.72246 .01504 L
.72496 .01504 L
.72723 .01504 L
.72964 .01504 L
.73518 .01504 L
.74019 .01504 L
.75023 .01504 L
.75946 .01504 L
.78028 .01504 L
.81979 .01504 L
.85778 .01504 L
.89822 .01504 L
.93715 .01504 L
.97619 .01504 L
Mfstroke
1 0 .047 r
.02381 .01472 m
.02499 .02002 L
.02605 .02097 L
.02729 .02126 L
.02846 .0213 L
.02954 .02125 L
.03053 .02116 L
.03279 .0209 L
.04262 .01958 L
.05285 .01843 L
.06244 .01759 L
.07218 .01695 L
.0829 .01642 L
.09334 .01605 L
.10458 .01575 L
.11468 .01556 L
.12571 .01541 L
.13613 .01531 L
.1458 .01524 L
.15637 .01519 L
.16633 .01515 L
.17526 .01512 L
.18493 .0151 L
.19444 .01508 L
.20487 .01507 L
.21013 .01507 L
.21577 .01506 L
.22594 .01506 L
.23122 .01505 L
.23611 .01505 L
.24148 .01505 L
.24422 .01505 L
.24718 .01505 L
.24975 .01505 L
.25211 .01505 L
.25451 .01505 L
.25674 .01505 L
.2592 .01505 L
.2605 .01505 L
.26188 .01505 L
.26258 .01505 L
.26334 .01505 L
.26401 .01505 L
.26472 .01505 L
.26536 .01505 L
.26606 .01505 L
.2673 .01505 L
.26849 .01505 L
.26961 .01505 L
.2709 .01505 L
Mistroke
.27207 .01505 L
.27337 .01505 L
.27477 .01505 L
.27608 .01505 L
.27727 .01505 L
.27841 .01505 L
.27947 .01505 L
.28064 .01505 L
.28188 .01505 L
.28319 .01505 L
.28443 .01505 L
.28675 .01505 L
.28947 .01505 L
.29198 .01505 L
.29766 .01505 L
.30764 .01505 L
.32793 .01504 L
.34696 .01504 L
.35583 .01504 L
.36516 .01504 L
.37539 .01504 L
.38476 .01504 L
.38978 .01504 L
.39433 .01504 L
.39923 .01504 L
.40454 .01504 L
.40947 .01504 L
.414 .01504 L
.42292 .01504 L
.44172 .01504 L
.4524 .01504 L
.46238 .01504 L
.48099 .01504 L
.50125 .01504 L
.51227 .01504 L
.52247 .01504 L
.53284 .01504 L
.54258 .01504 L
.55155 .01504 L
.56122 .01504 L
.57196 .01504 L
.58181 .01504 L
.5916 .01504 L
.60071 .01504 L
.61071 .01504 L
.62141 .01504 L
.63163 .01504 L
.64273 .01504 L
.66287 .01504 L
.70376 .01504 L
Mistroke
.74313 .01504 L
.78098 .01504 L
.82129 .01504 L
.86008 .01504 L
.87981 .01504 L
.90133 .01504 L
.92056 .01504 L
.94106 .01504 L
.95055 .01504 L
.95949 .01504 L
.97619 .01504 L
Mfstroke
1 0 .024 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .0214 L
.03053 .02132 L
.03163 .02121 L
.03279 .02107 L
.04262 .01977 L
.05217 .01866 L
.06244 .01773 L
.0728 .01703 L
.0825 .01653 L
.09403 .0161 L
.10458 .01582 L
.11442 .01563 L
.12357 .01549 L
.1336 .01538 L
.14429 .01529 L
.15457 .01523 L
.1657 .01518 L
.17621 .01515 L
.18587 .01513 L
.19561 .01511 L
.2047 .0151 L
.21467 .01509 L
.22026 .01509 L
.22536 .01509 L
.23016 .01508 L
.23527 .01508 L
.23969 .01508 L
.24444 .01508 L
.2471 .01508 L
.24953 .01508 L
.25201 .01508 L
.25431 .01508 L
.25685 .01508 L
.2583 .01508 L
.25962 .01508 L
.26101 .01508 L
.26232 .01508 L
.2637 .01508 L
.26448 .01508 L
.2652 .01508 L
.26646 .01508 L
.26765 .01508 L
.26871 .01508 L
.26988 .01508 L
.27114 .01508 L
Mistroke
.27248 .01508 L
.2749 .01508 L
.27608 .01508 L
.27735 .01508 L
.27855 .01508 L
.27966 .01508 L
.28066 .01508 L
.28175 .01508 L
.2829 .01508 L
.28397 .01508 L
.28525 .01508 L
.28665 .01508 L
.28918 .01508 L
.29165 .01508 L
.29393 .01508 L
.30461 .01507 L
.3249 .01507 L
.34393 .01507 L
.3528 .01507 L
.36213 .01507 L
.37236 .01507 L
.38173 .01507 L
.3913 .01507 L
.39665 .01507 L
.40151 .01507 L
.40605 .01507 L
.41097 .01507 L
.41989 .01507 L
.46086 .01506 L
.48126 .01506 L
.50031 .01506 L
.51862 .01506 L
.52888 .01506 L
.53825 .01506 L
.54815 .01506 L
.55732 .01506 L
.56737 .01506 L
.57245 .01506 L
.57807 .01506 L
.58297 .01506 L
.58814 .01506 L
.59739 .01506 L
.60254 .01506 L
.60734 .01506 L
.61824 .01506 L
.65725 .01506 L
.67714 .01506 L
.68762 .01506 L
.69335 .01506 L
.69872 .01506 L
Mistroke
.70388 .01506 L
.70861 .01506 L
.71112 .01506 L
.71385 .01506 L
.71535 .01506 L
.71675 .01506 L
.71807 .01506 L
.71949 .01506 L
.7208 .01506 L
.722 .01506 L
.72315 .01506 L
.72436 .01506 L
.72545 .01506 L
.72647 .01506 L
.72758 .01506 L
.72878 .01506 L
.73005 .01506 L
.73143 .01506 L
.73395 .01506 L
.7364 .01506 L
.73867 .01506 L
.7483 .01506 L
.75735 .01506 L
.77795 .01506 L
.81666 .01506 L
.85782 .01506 L
.89746 .01506 L
.93559 .01506 L
.97617 .01506 L
.97619 .01506 L
Mfstroke
1 0 0 r
.02381 .01472 m
.02499 .02005 L
.02605 .02104 L
.02729 .02137 L
.02846 .02143 L
.02954 .02139 L
.03053 .02131 L
.03279 .02106 L
.04262 .01975 L
.05285 .01857 L
.06244 .01772 L
.07218 .01705 L
.0829 .01651 L
.09334 .01612 L
.10458 .01581 L
.11468 .01562 L
.12571 .01546 L
.13613 .01535 L
.1458 .01528 L
.15637 .01522 L
.16633 .01518 L
.17526 .01515 L
.18493 .01513 L
.19444 .01511 L
.20487 .0151 L
.21013 .0151 L
.21577 .01509 L
.22594 .01509 L
.23122 .01508 L
.23611 .01508 L
.24148 .01508 L
.24422 .01508 L
.24718 .01508 L
.24975 .01508 L
.25211 .01508 L
.25451 .01508 L
.25674 .01508 L
.2592 .01508 L
.2605 .01508 L
.26188 .01508 L
.26258 .01508 L
.26334 .01508 L
.26406 .01508 L
.26472 .01508 L
.26597 .01508 L
.2666 .01508 L
.2673 .01508 L
.26859 .01508 L
.26979 .01508 L
.27251 .01508 L
Mistroke
.27511 .01508 L
.27624 .01508 L
.27746 .01508 L
.27867 .01508 L
.27978 .01508 L
.28084 .01508 L
.28196 .01508 L
.28314 .01508 L
.28424 .01508 L
.28545 .01508 L
.28675 .01508 L
.28944 .01508 L
.29236 .01508 L
.29768 .01508 L
.30764 .01508 L
.32706 .01507 L
.33737 .01507 L
.34847 .01507 L
.35907 .01507 L
.36876 .01507 L
.37804 .01507 L
.38315 .01507 L
.38779 .01507 L
.39736 .01507 L
.40262 .01507 L
.40757 .01507 L
.4164 .01507 L
.42595 .01507 L
.43625 .01507 L
.44587 .01507 L
.4559 .01507 L
.46692 .01507 L
.48554 .01507 L
.5058 .01507 L
.51681 .01507 L
.52701 .01507 L
.53676 .01507 L
.54713 .01506 L
.55648 .01506 L
.56657 .01506 L
.5761 .01506 L
.58485 .01506 L
.59463 .01506 L
.60375 .01506 L
.61375 .01506 L
.62444 .01506 L
.6659 .01506 L
.68668 .01506 L
.69581 .01506 L
.70585 .01506 L
Mistroke
.71485 .01506 L
.72451 .01506 L
.72985 .01506 L
.73473 .01506 L
.73963 .01506 L
.74429 .01506 L
.74688 .01506 L
.74932 .01506 L
.75151 .01506 L
.75275 .01506 L
.75388 .01506 L
.75511 .01506 L
.75625 .01506 L
.75751 .01506 L
.75821 .01506 L
.75886 .01506 L
.76015 .01506 L
.76088 .01506 L
.76155 .01506 L
.76411 .01506 L
.7663 .01506 L
.76835 .01506 L
.77303 .01506 L
.7825 .01506 L
.8027 .01506 L
.82121 .01506 L
.86085 .01506 L
.89898 .01506 L
.93956 .01506 L
.97619 .01506 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 432.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400?l00000o`00003ooooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo
003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooo
oooo__ooool00?oooooooooooonnooooo`00XOooool00oo<c<coA4A4o`000003o`000003oc8b<_mV
IVKogMgM00Wooooo00?ogMgMoeEEEOl000000_l000000omEEEGogMgMooooo`0nooooo`Wo00001ooo
ool00ooMgMgoEEEEo`000002o`000003oeEEEOoMgMgooooo00Oooooo00?ogMgMoeEEEOl000000_l0
00000omEEEGogMgMooooo`0fooooo`Wo00001?ooool00oo<c<coA4A4o`000003o`000003oc8b<_mV
IVKogMgM00Wooooo00?ogMgMoeEEEOl000000_l000000omEEEGogMgMooooo`0dooooo`_o000000?o
gMgMooooooooool01?ooool00ooMgMgoEEEEo`000002o`000003oeEEEOoMgMgooooo00Oooooo00?o
gMgMoeEEEOl000000_l000000omEEEGogMgMooooo`0cooooo`_o000000KogMgMoooooooooooooooo
olc<c?m4A4@4o`000003oc8b<_mVIVKogMgM00Wooooo00?ogMgMoeEEEOl000000_l000000omEEEGo
gMgMooooo`0cooooo`03olc<c?m4A4Co000000?o000000?o<S8bogMgMoo<c<`02_ooool00ooMgMgo
EEEEo`000002o`000003oeEEEOoMgMgooooo00Oooooo00?ogMgMoeEEEOl000000_l000000omEEEGo
gMgMooooo`0Yooooo`00XOooool4o`000007ohN7Qoooooook^k^oiRHV?l0003oA4A4onk^kP06oooo
o`09olc<c?l0003o0000okZj^_oooooogMgMob4Q8Ol0003oc<c<03oooooo00?ogMgMofIVI_l00000
0_l000000onYZJWoooooooooo`06ooooo`09olc<c?l0003o0000okZj^_oooooogMgMob4Q8Ol0003o
c<c<00Kooooo00Woc<c<o`000?l0003o^[ZjoooooooMgMgo8B4Qo`000?o<c<`0=oooool00ooMgMgo
IVIVo`000002o`000003ojVYZOoooooooooo00Cooooo1?l000001on7QhOoooooonk^k_nHV9So0000
odA4A?o^k^h01_ooool02Oo<c<co0000o`000?nj^[[oooooomgMgOlQ8B7o0000olc<c00dooooo`03
olc<c?l0003o000000So000000?oEEEEooooooooool00oooool02Oo<c<co0000o`000?nj^[[ooooo
omgMgOlQ8B7o0000olc<c006ooooo`09olc<c?l0003o0000okZj^_oooooogMgMob4Q8Ol0003oc<c<
03?ooooo00?oc<c<o`000?l000002?l000001?mEEEGoooooooooooooool4o`000007ohN7Qooooooo
k^k^oiRHV?l0003oA4A4onk^kP06ooooo`09olc<c?l0003o0000okZj^_oooooogMgMob4Q8Ol0003o
c<c<03?ooooo0ol000002?lb<S;oc<c<ooooooo^k^koV9RHoa0@4?lb<S;ogMgM1oooool02Oo<c<co
0000o`000?nj^[[oooooomgMgOlQ8B7o0000olc<c006ooooo`09olc<c?l0003o0000okZj^_oooooo
gMgMob4Q8Ol0003oc<c<02Wooooo002Qooooo`04oc8b<_l0003oEEEEomgMg@Cooooo00Coc<c<o`00
0?l0003oc<c<1?ooool01?oMgMgo0000o`000?nj^[X3ooooo`04onk^k_l0003o0000onk^kT3ooooo
0ol00008ooooo`04omgMgOl0003o0000okZj^P?ooooo00Cok^k^o`000?l0003ok^k^1?ooool01?oM
gMgo0000o`000?nj^[X3ooooo`04onk^k_l0003o0000onk^kSSooooo0ol00007ooooo`04oc8b<_l0
003oEEEEomgMg@Cooooo00Coc<c<o`000?l0003oc<c<1?ooool01?oMgMgo0000o`000?nj^[X3oooo
o`04onk^k_l0003o0000onk^kSCooooo00?oV9RHo`000?l000002?l000001Oo^k^kooooooooooooo
oooogMgM00;o000000Go^[Zjooooooooooooooooonk^kP02o`000003onk^k_oooooooooo00;ooooo
00CogMgMo`000?l0003o^[Zj0oooool01?o^k^ko0000o`000?o^k^hcooooo`03oiRHV?l0003o0000
00So000000Ook^k^oooooooooooo<S8bo`000?mEEEGogMgM00Cooooo00Coc<c<o`000?l0003oc<c<
1?ooool01?oMgMgo0000o`000?nj^[X3ooooo`04onk^k_l0003o0000onk^kS;ooooo00?o8B4Qoa0@
4?nHV9P01Oooool01?o^k^ko0000o`000?o<c<`5ooooo`04omgMgOl0003o0000okZj^P?ooooo00Co
k^k^o`000?l0003ok^k^1?ooool01?oMgMgo0000o`000?nj^[X3ooooo`04onk^k_l0003o0000onk^
kRSooooo002Zooooo`04ohN7Qol0003o410@onk^kP?ooooo00?oEEEEo`000?lQ8B401Oooool00omE
EEGo0000oeEEE@10ooooo`?o00002?ooool00omEEEGo0000ob4Q8@05ooooo`03oeEEEOl0003oEEEE
00Cooooo00?oEEEEo`000?lQ8B401Oooool00omEEEGo0000oeEEE@0hooooo`?o00004?ooool01?n7
QhOo0000oa0@4?o^k^h3ooooo`03oeEEEOl0003o8B4Q00Gooooo00?oEEEEo`000?mEEED0=Oooool0
0omEEEGo<S8booooo`05ooooo`03omgMgOlQ8B7oMgMg00?ooooo00?oEEEEo`000?lQ8B401Oooool0
0omEEEGo0000oeEEE@04ooooo`03oeEEEOl0003o8B4Q00Gooooo00?oEEEEo`000?mEEED0=?ooool0
0omEEEGo<S8booooo`05ooooo`03omgMgOlQ8B7oMgMg00_ooooo00CoQhN7o`000?l@413ok^k^0ooo
ool00omEEEGo0000ob4Q8@05ooooo`03oeEEEOl0003oEEEE03_ooooo00CoV9RHo`000?l0003ok^k^
1?ooool00omEEEGo0000ob4Q8@05ooooo`03oeEEEOl0003oEEEE00Cooooo00?oEEEEo`000?lQ8B40
1Oooool00omEEEGo0000oeEEE@0Xooooo`00Z_ooool01?o^k^ko0000o`000?mgMgL2ooooo`04omgM
gOl0003o0000ogMgM`Gooooo00CoQhN7o`000?l0003ok^k^?oooool3o`0000Oooooo00CogMgMo`00
0?l0003oMgMg1Oooool01?n7QhOo0000o`000?o^k^h2ooooo`04omgMgOl0003o0000ogMgM`Gooooo
00CoQhN7o`000?l0003ok^k^=oooool3o`00013ooooo00Cok^k^o`000?l0003oMgMg0_ooool01?oM
gMgo0000o`000?mgMgL5ooooo`04ohN7Qol0003o0000onk^kSGooooo00?o<S8boeEEEOooool01Ooo
ool01OoMgMgoEEEEoooooooooooogMgM00;o000000?oMgMgooooooooool00oooool01?n7QhOo0000
o`000?o^k^h2ooooo`04omgMgOl0003o0000ogMgM`Gooooo00CoQhN7o`000?l0003ok^k^=?ooool0
0olb<S;oEEEEooooo`05ooooo`03omgMgOmEEEGooooo00[ooooo00Cok^k^o`000?l0003oMgMg0_oo
ool01?oMgMgo0000o`000?mgMgL5ooooo`04ohN7Qol0003o0000onk^kS[ooooo00Cok^k^o`000?l0
003oIVIV0oooool01?oMgMgo0000o`000?mgMgL5ooooo`04ohN7Qol0003o0000onk^kP;ooooo00Co
gMgMo`000?l0003oMgMg1Oooool01?n7QhOo0000o`000?o^k^hWooooo`00Zoooool2o`000004ob4Q
8OooooooooooohN7Q`;o000000?o^[Zjooooooooool00oooool01?nj^[[o0000o`000?nHV9Pooooo
o`?o00001oooool01?n7QhOo0000o`000?nj^[X5ooooo`04okZj^_l0003o0000oiRHV0;ooooo00Co
QhN7o`000?l0003o^[Zj1Oooool01?nj^[[o0000o`000?nHV9Pgooooo`?o00004Oooool2o`000004
ob4Q8OooooooooooohN7Q`;o000000?o^[Zjooooooooool00oooool01?nj^[[o0000o`000?nHV9Pe
ooooo`03onk^k_l0003oMgMg00Wooooo00CoQhN7o`000?l0003o^[Zj1Oooool01?nj^[[o0000o`00
0?nHV9P2ooooo`04ohN7Qol0003o0000okZj^PGooooo00Co^[Zjo`000?l0003oV9RH=?ooool00oo^
k^ko0000ogMgM`0Cooooo`;o000000Co8B4QooooooooooooQhN70_l000000onj^[[oooooooooo`03
ooooo`04okZj^_l0003o0000oiRHV3_ooooo0_l000001Ol@413oooooooooooooooooQhN700;o0000
00?o^[Zjooooooooool00oooool01?nj^[[o0000o`000?nHV9P2ooooo`04ohN7Qol0003o0000okZj
^PGooooo00Co^[Zjo`000?l0003oV9RH9oooool00:[ooooo00CogMgMo`000?l0003o00000_ooool0
1?m4A4Co0000o`000?o<c<`5ooooo`04omgMgOl0003o0000oeEEECoooooo0ol00007ooooo`04odA4
A?l0003o0000olc<c0Gooooo00CogMgMo`000?l0003oEEEE0_ooool01?m4A4Co0000o`000?o<c<`5
ooooo`04omgMgOl0003o0000oeEEECOooooo0ol0000@ooooo`04omgMgOl0003o0000o`0000;ooooo
00CoA4A4o`000?l0003oc<c<1Oooool01?oMgMgo0000o`000?mEEEDfooooo`03olc<c?l0003oV9RH
00Sooooo00CoA4A4o`000?l0003oc<c<1Oooool01?oMgMgo0000o`000?mEEED2ooooo`04odA4A?l0
003o0000olc<c0Gooooo00CogMgMo`000?l0003oEEEE=Oooool00oo<c<co0000oiRHV00Aooooo`04
omgMgOl0003o0000o`0000;ooooo00CoA4A4o`000?l0003oc<c<1Oooool01?oMgMgo0000o`000?mE
EEDjooooo`04omgMgOl0003o0000o`0000?ooooo00CoA4A4o`000?l0003oc<c<1Oooool01?oMgMgo
0000o`000?mEEED2ooooo`04odA4A?l0003o0000olc<c0Gooooo00CogMgMo`000?l0003oEEEE9ooo
ool00:[ooooo00CoMgMgo`000?l0003o00000_ooool00olQ8B7o0000o`000007ooooo`;o000000?o
<S8booooooooool0?Oooool3o`0000Oooooo00?o8B4Qo`000?l000001oooool2o`000004oc8b<_oo
ooooooooob4Q8@;o00001oooool2o`000003oc8b<_oooooooooo03Gooooo0ol0000@ooooo`04ogMg
Mol0003o0000o`0000;ooooo00?o8B4Qo`000?l000001oooool2o`000003oc8b<_oooooooooo03Go
oooo00?oQhN7o`000?o<c<`01oooool00olQ8B7o0000o`000007ooooo`;o000000Co<S8boooooooo
oooo8B4Q0_l00007ooooo`;o000000?o<S8booooooooool0=?ooool00on7QhOo0000olc<c00@oooo
o`04ogMgMol0003o0000o`0000;ooooo00?o8B4Qo`000?l000001oooool2o`000003oc8b<_oooooo
oooo03Sooooo00CoIVIVo`000?l0003o00000oooool00olQ8B7o0000o`000007ooooo`;o000000Co
<S8boooooooooooo8B4Q0_l00007ooooo`;o000000?o<S8booooooooool09Oooool00:Wooooo00Go
c<c<o`000?l0003o0000oc8b<P02ooooo`?o00001oooool3o`0003oooooo0ol00007ooooo`?o0000
1oooool3o`0000;ooooo0ol00007ooooo`?o0000=oooool3o`0000oooooo00Goc<c<o`000?l0003o
0000oc8b<P02ooooo`?o00001oooool3o`0003Sooooo00?oA4A4o`000?oMgMd01_ooool3o`0000Oo
oooo0ol00002ooooo`?o00001oooool3o`0003Oooooo00?oA4A4o`000?oMgMd03_ooool01Oo<c<co
0000o`000?l0003o<S8b00;ooooo0ol00007ooooo`?o0000>Oooool01OnHV9So0000o`000?l0003o
MgMg00?ooooo0ol00007ooooo`?o00000_ooool3o`0000Oooooo0ol0000Wooooo`00Z?ooool00on7
QhOo0000o`000002o`000003oiRHV?oooooooooo00?o00001oooool3o`0003oooooo0ol00007oooo
o`?o00001oooool3o`0000;ooooo0ol00007ooooo`?o0000=oooool3o`0000kooooo00?oQhN7o`00
0?l000000_l000000onHV9Soooooooooo`03o`0000Oooooo0ol0000hooooo`03onk^k_l0003o8B4Q
00Kooooo0ol00007ooooo`?o00000_ooool3o`0000Oooooo0ol0000gooooo`03onk^k_l0003o8B4Q
00gooooo00?oQhN7o`000?l000000_l000000onHV9Soooooooooo`03o`0000Oooooo0ol0000foooo
o`03omgMgOnYZJWo<S8b00?o000000?o8B4Qonk^k_ooool00_ooool3o`0000Oooooo0ol00002oooo
o`?o00001oooool3o`0002Oooooo002Tooooo`03omgMgOnYZJWoEEEE00Go000000Co<S8boooooooo
oooooooo0ol00007ooooo`?o0000?oooool3o`0000Oooooo0ol00007ooooo`?o00000_ooool3o`00
00Oooooo0ol0000gooooo`?o00002_ooool00ooMgMgoZJVYoeEEE@05o`000004oc8b<_oooooooooo
ooooo`?o00001oooool3o`0003Wooooo00?oIVIVo`000?mVIVH01Oooool3o`0000Oooooo0ol00002
ooooo`?o00001oooool3o`0003Sooooo00?oIVIVo`000?mVIVH02?ooool00ooMgMgoZJVYoeEEE@05
o`000004oc8b<_ooooooooooooooo`?o00001oooool3o`0003Cooooo00?oA4A4o`000?l000001?l0
00000omVIVKok^k^ooooo`03ooooo`?o00001oooool3o`0000;ooooo0ol00007ooooo`?o00009ooo
ool00:;ooooo00?oV9RHo`000?l000001_l000000om4A4Cok^k^ooooo`02ooooo`?o00001oooool3
o`0003oooooo0ol00007ooooo`?o00001oooool3o`0000;ooooo0ol00007ooooo`?o0000=oooool3
o`0000Sooooo00?oV9RHo`000?l000001_l000000om4A4Cok^k^ooooo`02ooooo`?o00001oooool3
o`0003Wooooo00Coc<c<o`000?l0003ogMgM1?ooool3o`0000Oooooo0ol00002ooooo`?o00001ooo
ool3o`0003Sooooo00Coc<c<o`000?l0003ogMgM1Oooool00onHV9So0000o`000006o`000003odA4
A?o^k^kooooo00;ooooo0ol00007ooooo`?o0000=_ooool01OnHV9So8B4Qo`000?l@413ogMgM00Ko
oooo0ol00007ooooo`?o00000_ooool3o`0000Oooooo0ol0000Wooooo`00X_ooool00onj^[[o0000
o`000004o`000003oa0@4?nHV9Sooooo00Cooooo00Co8B4Qo`000?l0003ok^k^1_ooool2o`000003
ob4Q8Ooooooooooo03gooooo0ol00007ooooo`04ob4Q8Ol0003o0000onk^kPKooooo0_l000001?lQ
8B7ooooooooooolQ8B42o`000003onk^k_oooooooooo00Cooooo0_l000000olQ8B7oooooooooo`0e
ooooo`?o00002?ooool00onj^[[o0000o`000004o`000003oa0@4?nHV9Sooooo00Cooooo00Co8B4Q
o`000?l0003ok^k^1_ooool2o`000003ob4Q8Ooooooooooo03Sooooo0_l000000omVIVKooooooooo
o`02ooooo`04ob4Q8Ol0003o0000onk^kPKooooo0_l000001?lQ8B7ooooooooooolQ8B42o`000003
onk^k_oooooooooo00Cooooo0_l000000olQ8B7oooooooooo`0gooooo`;o000000?oIVIVoooooooo
ool00oooool00onj^[[o0000o`000004o`000003oa0@4?nHV9Sooooo00Cooooo00Co8B4Qo`000?l0
003ok^k^1_ooool2o`000003ob4Q8Ooooooooooo03Kooooo00CoQhN7o`000?lQ8B7oc<c<1Oooool0
1?lQ8B7o0000o`000?o^k^h6ooooo`;o000000Co8B4Qoooooooooooo8B4Q0_l000000oo^k^kooooo
ooooo`04ooooo`;o000000?o8B4Qooooooooool09Oooool00:?ooooo0_l000001?lQ8B7oA4A4ohN7
Qoo<c<`7ooooo`04odA4A?l0003o0000okZj^PGooooo00Co^[Zjo`000?l0003oEEEE?oooool3o`00
00Oooooo00CoA4A4o`000?l0003o^[Zj1Oooool01?nj^[[o0000o`000?mEEED2ooooo`04odA4A?l0
003o0000okZj^PGooooo00Co^[Zjo`000?l0003oEEEE=oooool3o`0000Wooooo0_l000001?lQ8B7o
A4A4ohN7Qoo<c<`7ooooo`04odA4A?l0003o0000okZj^PGooooo00Co^[Zjo`000?l0003oEEEE<_oo
ool00omgMgOok^k^ooooo`05ooooo`;o000000?o410@ooooooooool00_ooool01?m4A4Co0000o`00
0?nj^[X5ooooo`04okZj^_l0003o0000oeEEE@;ooooo00CoA4A4o`000?l0003o^[Zj1Oooool01?nj
^[[o0000o`000?mEEEDaooooo`03ogMgMoo^k^kooooo00Gooooo0_l000000ol@413oooooooooo`04
ooooo`;o000000Co8B4QodA4A?n7QhOoc<c<1oooool01?m4A4Co0000o`000?nj^[X5ooooo`04okZj
^_l0003o0000oeEEECWooooo00CoQhN7o`000?l0003oc<c<1?ooool01?m4A4Co0000o`000?nj^[X5
ooooo`04okZj^_l0003o0000oeEEE@;ooooo00CoA4A4o`000?l0003o^[Zj1Oooool01?nj^[[o0000
o`000?mEEEDWooooo`00Xoooool2ogMgM`_ooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj^[[o
0000o`000?nHV9Poooooo`?o00001oooool01?n7QhOo0000o`000?nYZJT5ooooo`04okZj^_l0003o
0000oiRHV0;ooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj^[[o0000o`000?nHV9Pgooooo`?o
00002Oooool2ogMgM`_ooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj^[[o0000o`000?nHV9Pb
ooooo`03oc8b<_nHV9Sooooo00Cooooo00Coc<c<o`000?l0003o00001?ooool01?n7QhOo0000o`00
0?nYZJT5ooooo`04okZj^_l0003o0000oiRHV0;ooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj
^[[o0000o`000?nHV9Paooooo`03oc8b<_nHV9Sooooo00Cooooo00Coc<c<o`000?l0003o00001_oo
ool2ogMgM`_ooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj^[[o0000o`000?nHV9Piooooo`04
onk^k_l0003o0000odA4A0Cooooo00CoQhN7o`000?l0003oZJVY1Oooool01?nj^[[o0000o`000?nH
V9P2ooooo`04ohN7Qol0003o0000ojVYZ@Gooooo00Co^[Zjo`000?l0003oV9RH9oooool00:?ooooo
00?ogMgMoa0@4?ooool02_ooool01?oMgMgo0000o`000?mVIVH5ooooo`04ogMgMol0003o0000onk^
kSoooooo0ol00007ooooo`04omgMgOl0003o0000ofIVIPGooooo00CoMgMgo`000?l0003ok^k^0_oo
ool01?oMgMgo0000o`000?mVIVH5ooooo`04ogMgMol0003o0000onk^kSOooooo0ol00009ooooo`03
omgMgOl@413ooooo00[ooooo00CogMgMo`000?l0003oIVIV1Oooool01?mgMgOo0000o`000?o^k^hb
ooooo`03ogMgMol0003ok^k^00Cooooo00CoEEEEo`000?l0003o00001?ooool01?oMgMgo0000o`00
0?mVIVH5ooooo`04ogMgMol0003o0000onk^kP;ooooo00CogMgMo`000?l0003oIVIV1Oooool01?mg
MgOo0000o`000?o^k^haooooo`03ogMgMol0003ok^k^00Cooooo00CoEEEEo`000?l0003o00001_oo
ool00ooMgMgo410@ooooo`0:ooooo`04omgMgOl0003o0000ofIVIPGooooo00CoMgMgo`000?l0003o
k^k^<Oooool00om4A4Cok^k^ooooo`05ooooo`04onk^k_l0003o0000o`0000Cooooo00CogMgMo`00
0?l0003oIVIV1Oooool01?mgMgOo0000o`000?o^k^h2ooooo`04omgMgOl0003o0000ofIVIPGooooo
00CoMgMgo`000?l0003ok^k^9oooool00:Cooooo00?oA4A4oiRHV?ooool02_ooool00omEEEGo0000
ob4Q8@05ooooo`03ob4Q8Ol0003oEEEE03gooooo00?o8B4QohN7QomgMgL00ol00008ooooo`03oeEE
EOl0003o8B4Q00Gooooo00?o8B4Qo`000?mEEED01?ooool00omEEEGo0000ob4Q8@05ooooo`03ob4Q
8Ol0003oEEEE03Gooooo00?o8B4QohN7QomgMgL00ol0000:ooooo`03odA4A?nHV9Sooooo00[ooooo
00?oEEEEo`000?lQ8B401Oooool00olQ8B7o0000oeEEE@0cooooo`07omgMgOl0003o8B4QokZj^_oo
ooook^k^ofIVIP03o`000003oc8b<_oooooooooo00?ooooo00?oEEEEo`000?lQ8B401Oooool00olQ
8B7o0000oeEEE@04ooooo`03oeEEEOl0003o8B4Q00Gooooo00?o8B4Qo`000?mEEED0<_ooool01ooM
gMgo0000ob4Q8Onj^[[oooooonk^k_mVIVH00ol000000olb<S;oooooooooo`05ooooo`03odA4A?nH
V9Sooooo00[ooooo00?oEEEEo`000?lQ8B401Oooool00olQ8B7o0000oeEEE@0booooo`03oiRHV?lb
<S;ok^k^00Gooooo00CoQhN7o`000?l0003o00001Oooool00omEEEGo0000ob4Q8@05ooooo`03ob4Q
8Ol0003oEEEE00Cooooo00?oEEEEo`000?lQ8B401Oooool00olQ8B7o0000oeEEE@0Xooooo`00Y?oo
ool00onj^[[o0000o`000005o`000003oc8b<_oooooooooo00;ooooo00CogMgMo`000?l0003o^[Zj
0oooool01?nj^[[o0000o`000?o^k^hmooooo`03okZj^_lb<S;o000000?o00002?ooool01?oMgMgo
0000o`000?nj^[X3ooooo`04okZj^_l0003o0000onk^kPCooooo00CogMgMo`000?l0003o^[Zj0ooo
ool01?nj^[[o0000o`000?o^k^heooooo`03okZj^_lb<S;o000000?o00002_ooool00onj^[[o0000
o`000005o`000003oc8b<_oooooooooo00;ooooo00CogMgMo`000?l0003o^[Zj0oooool01?nj^[[o
0000o`000?o^k^hdooooo`03ofIVI_l0003o000000Ko000000?oZJVYooooooooool00oooool01?oM
gMgo0000o`000?nj^[X3ooooo`04okZj^_l0003o0000onk^kPCooooo00CogMgMo`000?l0003o^[Zj
0oooool01?nj^[[o0000o`000?o^k^hcooooo`03ofIVI_l0003o000000Ko000000?oZJVYoooooooo
ool01Oooool00onj^[[o0000o`000005o`000003oc8b<_oooooooooo00;ooooo00CogMgMo`000?l0
003o^[Zj0oooool01?nj^[[o0000o`000?o^k^hcooooo`03odA4A?lQ8B7oZJVY00;ooooo00?oc<c<
oeEEEOl000000_l000000omVIVKoooooooooo`03ooooo`04omgMgOl0003o0000okZj^P?ooooo00Co
^[Zjo`000?l0003ok^k^1?ooool01?oMgMgo0000o`000?nj^[X3ooooo`04okZj^_l0003o0000onk^
kRSooooo002Uooooo`03oa0@4?l0003o000000Go000000?ogMgMooooooooool00_ooool01_nj^[[o
0000o`000?nj^[[ooooookZj^P;o000000?oc<c<ooooooooool0?_ooool01?nj^[[o410@o`000?l0
0009ooooo`06okZj^_l0003o0000okZj^_oooooo^[Zj0_l000000oo<c<coooooooooo`04ooooo`06
okZj^_l0003o0000okZj^_oooooo^[Zj0_l000000oo<c<coooooooooo`0fooooo`04okZj^_l@413o
0000o`0000_ooooo00?o410@o`000?l000001Ol000000ooMgMgoooooooooo`02ooooo`06okZj^_l0
003o0000okZj^_oooooo^[Zj0_l000000oo<c<coooooooooo`0cooooo`03onk^k_lb<S;o000000Go
000000?oEEEEooooooooool01Oooool01_nj^[[o0000o`000?nj^[[ooooookZj^P;o000000?oc<c<
ooooooooool01?ooool01_nj^[[o0000o`000?nj^[[ooooookZj^P;o000000?oc<c<ooooooooool0
<_ooool00oo^k^ko<S8bo`000005o`000003oeEEEOoooooooooo00Oooooo00?o410@o`000?l00000
1Ol000000ooMgMgoooooooooo`02ooooo`06okZj^_l0003o0000okZj^_oooooo^[Zj0_l000000oo<
c<coooooooooo`0cooooo`03oeEEEOl0003o000000Go000000?o8B4Qonk^k_ooool01Oooool01_nj
^[[o0000o`000?nj^[[ooooookZj^P;o000000?oc<c<ooooooooool01?ooool01_nj^[[o0000o`00
0?nj^[[ooooookZj^P;o000000?oc<c<ooooooooool09oooool00:Gooooo00?oQhN7o`000?l00000
1Ol000000on7QhOoooooooooo`03ooooo`03omgMgOmEEEGo000000;o000000?oEEEEomgMgOooool0
@_ooool00onHV9So410@ooooo`09ooooo`03omgMgOmEEEGo000000;o000000?oEEEEomgMgOooool0
1oooool00ooMgMgoEEEEo`000002o`000003oeEEEOoMgMgooooo03[ooooo00?oV9RHoa0@4?ooool0
2_ooool00on7QhOo0000o`000005o`000003ohN7Qooooooooooo00?ooooo00?ogMgMoeEEEOl00000
0_l000000omEEEGogMgMooooo`0gooooo`06oiRHV?lQ8B7o0000o`000?lb<S;oZJVY2Oooool00ooM
gMgoEEEEo`000002o`000003oeEEEOoMgMgooooo00Oooooo00?ogMgMoeEEEOl000000_l000000omE
EEGogMgMooooo`0fooooo`06oiRHV?lQ8B7o0000o`000?lb<S;oZJVY2_ooool00on7QhOo0000o`00
0005o`000003ohN7Qooooooooooo00?ooooo00?ogMgMoeEEEOl000000_l000000omEEEGogMgMoooo
o`0fooooo`03okZj^_m4A4Co000000;o000000?o8B4QohN7Qoooool02?ooool00ooMgMgoEEEEo`00
0002o`000003oeEEEOoMgMgooooo00Oooooo00?ogMgMoeEEEOl000000_l000000omEEEGogMgMoooo
o`0Yooooo`00[?ooool00on7QhOo8B4Qooooo`2oooooo`03ohN7QolQ8B7ooooo0;Kooooo00?oQhN7
ob4Q8Oooool0T_ooool00:gooooo00?ogMgMooooooooool0_oooool00ooMgMgoooooooooo`2foooo
o`03omgMgOoooooooooo097ooooo001Cooooo`03o`000?oooooooooo0?oooooooooooomXooooo`00
Doooool00ol0003oooooooooo`3oooooooooooooJ?ooool005?ooooo00?o0000ooooooooool0oooo
ooooooooofSooooo001Cooooo`03o`000?oooooooooo0?oooooooooooomXooooo`00Doooool00ol0
003oooooooooo`3oooooooooooooJ?ooool005?ooooo00?o0000ooooooooool0ooooooooooooofSo
oooo001Cooooo`03o`000?oooooooooo0?oooooooooooomXooooo`00Doooool00ol0003ooooooooo
o`3oooooooooooooJ?ooool004Gooooo3_l000000ooo003o0000o`00000eo`0000Koof401_oo0?h5
ool03003ool01_oo003oo`000?ooo`00hooo000>o`0002gooooo001Cooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool01?ooool6ool032_oo`001_oo01koool09=ooo`0T>oooool005?o
oooo00?oo`00ooooooooool02ooooolAool000Ooo`0`3?ooool6ool0F`Koo`184_oo02@5ool0I`Ko
o`251Ooo0:TAool0NOooo`0l__oo03`kooooo`00Doooool00ooo003oooooooooo`05ooooo`Koo`00
1Ooo01hCooooo`Ko0<3o1_oo05@<ool090[oo`2Y3?oo07TMool0?4_oo`1>oooo06ecool0KC_ooooo
001Cooooo`03ool09?oo003oo`0000Goo`001_oo030Dooooo`Co0<3o1_oo05@6ool090Koo`1W1_oo
0:T5o`3oAPGoo`1i3?oo03`6ool0CQOoo`1]8?oL0?l6ohL0o`_oo`1]4On70?l2oooP0?oog03oN_oL
0?lkooooo`00Doooool00ooo02Coooooooooo`0Looooo`?o0<3o1?oo05@2ool0B0Coo`0T0_oo06L4
ool0Q@Ko0?ma2ooo07T5ool0?0Koo`1>00?oV@3oool0KOoo06d01?oo06d<om`0ogCoo`2`oooo09MJ
ool0Uc_ooooo001Cooooo`03ool09?oX0?oooooo01Sooooo1?l0`?l3ool0E0?oo`180ooo02@3ool0
I`03ool0QOoo0:Woo`2Y00Co0?ma0_l0odH4ool0N@Koo`1o1Ooo03`5ool0CP03om`0oooo06goo`1]
00Coo`1]00?ooi40ooooooooool00_ooool00ol0A_ooo`2`ool0/00:ool0/0Goo`38Kooo09Oool@0
o`ooa03oBon=0?lkooooo`00Doooool00ooo02Coo`0looooo`0Eooooo`?o0<3o00CoY@3oool0E?oo
05Coo`1D0_oo04P4ool09003ool0Iooo08Goo`2500?oo`2Y00?o0?maooooooooool00ol0odH3ool0
N@Coo`1o0_oo0;H4ool0?0Goo`1>1_oo06d<ool0/003oi<0oooo0<Soo`3800?oo`382ooo09LVool0
_0Coo`3V00?oS@3ool@0ooo40?l08_o40?l00on=0?ooo`2lool0_02[ool0_7Woo`3VD_oo0;`koooo
o`00Doooool00ooo02Coo`0looooo`0Booooo`?o0<3o00CoY@3oool0E?oo05Coo`1D0_oo04P3ool0
9005ool0Iooo08Goo`25ool0QOoo0:T00_l0og43ooooo`?o0?m60ooo07T3ool0O`?oo`2f0ooo03`4
ool0CP03o`P0oooo06goo`1]00;oo`1]00?ooi40oooooooo0;000ooo0;06o`16o`03oi<0oooo0<So
o`3800Coo`381Ooo09L;ool0_0KonP3o0_ook00Kool0n0?onP3o:_oo0;`2ooX0o`GoooP0I?oo0?PM
oc80oa3oo`3h5Olb0?miool0_5;oo`3D>oooool005?ooooo00?oo`0Tool0??ooool04?ooool2o`30
o`;oY@3o0_oo05@2ool0B0?oo`0T00Coo`1Wool0QOoo08Goo`2Y0_oolP02o`3oL@;ooooo0ol0odH3
ool0N@?oo`1o0ooo0;H3ool0?0?oo`1>0_l80?l3ool0K@?ooooo0ooo0;04o`16o`?oT`3o1?oo0<P6
ool0U`Goo`2l4_oo0?PMool0e0ooo`3h00?oon`0oooh0?oon0002?oon003ooo/01Koo`3h1Olb0?l0
0ol0]?ooo`3Dool0e03Fool0e1?oo`3hP?l08_lkooooo`00Doooool00ol0003oo`0Tooooo`0>oooo
o`;o0<3o00CoooooojD0oooo05Coo`1D0_oo04P2ool090;oo`1W00Goo`25ool0ZOoolP3ooo80oonY
0002o`3oL@04ooooool0odKo0?m6o`3oAP?oo`1i0ooo07l3ool0]P03om`0oooo03coo`0l00?oo`1>
00?oo`2Ao`P0oooo06d00_oo06d2ooooo`07oonS0?oo0;3oo`2`ool0/?l0A_ooooooo`3oX@04oi<0
o`03ool0b?oo0;coo`2l00Coo`2G00Goo`3Vo`So0?l8o`3o2?l0oonl0006ool0n0Ko<P3o00?ooooo
ool0e?oo0=@02Ooo0=@Mo`0Ro`koo`3D00?o<P3oool0n?oo0?P03?oo0?P4oc80o`?o0;Co5Ooo0=@D
o`0Roc3ooooo:oo4o`04o`3og_So0;[o>oooool005?ooooo00?o0000ool09?ooool03?ooool2o`30
o`04oooooonU0?ooo`1Dool0E0;oo`180_oo02@2ool0I`;oo`2Y00?ooo80ooo>0?l0og400_l0og43
o`3oAP?oo`1i0ooo07l00on70?ooo`2fool0]P02om`0o`;oo`0l0_oo04h2ool0T@?oo`1]0oooX`03
ool0/003ooooool0oj7o0?nQ00?oT`3o00CoS@3oool0_?oo0;coo`2l0ooo09L2ool0iP;ooooo1Ooo
0?P00olb0?ooooooooooo`04o`2do`Koo`3D2?l08_lKolCo00Kooooo2ol08_l2oooooaKoo`3D3_l0
8_l;ooooo`;om?l01?o4o`03o`3ogVKo0;[o;_l0od3:o`3Noc_ooooo001Cooooo`03o`000?oo02Co
oooo00[ooooo0_l0`?l2ooooo`;oo`1D0_oo04P2ool090;oo`1W0_oo0:T2ooo>00;o0?ma00Cooooo
o`3oA_l0odKoofd00_oo07T3ool0O`;oQ`3o0_oo0;H2om`0o`;oo`0l0_oo04h2ool0T@;oo`1]00?o
oi40oonS0?ooX`000ooo0;02ooooo`05o`3oXOnC0?ooT`3ooi<0oon=0?l00ooo0;`3ool0U`?ooooo
1?oo0?P2oc80o`?ooooo00?o0;Coool0e?oo0=@01?oo0=@5o`0Ro`Goa?l00ol0g_lSo`2jo`?oa?l0
1ooooolDo`0Ro`kooooo00Com?l0ol[o0?o:o`3ob_l00ol0omhAo`2joaWo0=ko<_l0od0Uoi?o02Co
0=kob_lDo`0kooooo`00Doooool00ol0003oo`0Tooooo`09ooooo`03o`30oooooooooooo00;oo`1D
0_oo04P01?oo7P3oo`0Tool0Iooo06L2ool0Z@04ooob0?oocP3o0?mao`3oL@;ooooo00Co0?m6oom]
0?oo07Woo`1i0_oo07l00ooo08_oQ`3oohL0o`02ool0]P04om`0oom40?ooo`0lool0?0;oo`1>00Ko
o`2Ao`P0oooo06goo`1]oonA0?ooX`03ool0/003o`16oooooooooooo00?oT`3o00Co01coool0_?oo
0;coo`2l0ooo09L3ooooo`?oo`3h0olb0?l00oooooooo`3Dool0e004ool0e0Go02;o00?o[?l0o`3N
ool0g_l01?l0g_l7o`2job3o0?m00ol0g_l9o`2jo`;oa?l05?ooool8olCo00?o0?oN2Ol0^_l2o`3o
@0go0=ko2OnCo`0_ool0lRCo5?l000?o0=koo`0Fool05_l0ool05_l2o`0Foc_ooooo001Cooooo`03
o`000?oo02Co0<3o00Oooooo0_l0`?l00oooooooo`1Kool0E002ool0B004on80oooo7P3oo`0Tool0
I`;oo`2Y00Cooo80ooo>0?oooooo0?ma0_ooool2o`3oAP07oom]0?oo07Woo`1oool0Oooo08_oQ`3o
ooooo`02ool0]P;oA03o0_oo03`2ool0CP;o203o0_oo06d01?ooT@3ooj<0ool0/?oo0;02o`16o`;o
oooo0_nC0?l01?l07?oonP3oool0_?oo0;`3ool0U`?ooooo0ooo0?P00olb0?oob_l0ol[o0004ool0
e0Go02;o00?o[?l0o`3Nool0g_l01?l0g_l6o`2jo`Co0?m00_nCo`0Nool0lPCoTol01_l0od05o`3N
ob7o0;[o2ol0g_l00on/o`3oo`3bool0lP0Cool0lPCo5?l01_ooR`09o`0FoacoK`3o<_oo0?9Qoon;
0=3ooooo001Cooooo`03o`000?oo03coo`0T00Kooooo00Oo0<3oooooooooooooo`1Kool0E?oo04So
hP3o00;ooah000?oo`0Tool0Iooo0:T00_oolP02ooooo`05o`3oLOoooooo0?m6o`3oA_ooK@000_oo
07T02?oo07ooo`2;ohL0ooooooooonH0ool0]_oL0?ooA03o0_oo03`2ool0CP06ool0TOl80?ooo`1]
ool0KOooT@3ooj<00_oo0;02o`16o`;ooooo0_nC0?l2ooX0o`;oo`2l0_oo09L3ooooo`?oo`3h0oo:
o`001?l0]?ooo`3Dool0e?o4o`03o`0Ro`;o[?l01?l0g_l6o`2jo`Cooooo2?oo0?8Nofl0o`[oo`3b
00Go[?l0ooo80?oob03oolP0o`3o@00;o`3No`?o0?oN4_l0g_l00onCo`3oo`3bool0lP0:ool0lP03
oaCo0?oooooooh/000Cooh/01_l05_lKofl0oaCooooo8?l0g_l5oooooaGoK`3o=Ooo0?:Jo`3o42Oo
o`3b>oooool005?ooooo00?o0000ool0??oo02@01?ooool2o`30o`07oooooonU0?ooo`1Kool0E?oo
04SohP3ooolN0002ool09003ool0Iooo0:Wooo8000?ooooo00?o0?maooooool0odH00_ooK@001_oo
07Woo`1oool0Oooo08_ooooooooV00;oo`2f0_m40?l01?oo03coo`1>ool0C_oo0942o`P0o`03ool0
KOooT@3ooi4000;oo`2`00Coooooo`16oooooooooooo0_nC0?l2ooX0o`;oo`2l0_oo09L2ooooo`?o
o`3h00?o<P3ool[o0?o:o`000_l0]?l2ool0e0?o02;o0_n/o`03o`3No`Co0;[o2_oo0?82ofl0o`So
01Ko6oooool00ol05_ooK`3oofl0o`03ofl0o`;ooh/00olDo`05ool0lP;oTol00on/o`06o`3o@0?o
0=ko1?l0od04ojco00KoTol01Ooo0?87oaCo0003oon;0?m_0?ooK`3o00ooK`3o3Oooool>o`3o43[o
oooo:Ol0oa0Kooooo`GoK`3oV_oo0?9Rooooo`00Doooool00ol0003oo`0lool09002ooooo`;o0<3o
0_ooool01onU0?ooo`1Dool0E?oo04SooooooolN0?oo02@00_oo06L00ooo0:Wooo80ooooo`02oooo
o`04o`3oLOl0odKo0?m6oom]00;oo`1i00Coo`1oool0Ron70?ooonH00_oo0;H01OoL0?ooA03oool0
??oo03coo`1>00;oo`2A00Co203oool0KOoo06gooi400_oo0;001?oooooo04Koo`16ooooool2oi<0
o`04ooX0oooo0;coo`2lool0_0;oo`2G0_ooool2ool0n006ol[o0?lb0?oo<P3oooooooo4o`3o0;Co
0_oo0=@2o`0Ro`Go0=ko0ol0^_l01?l0od3oo`3bool0l_oo0?85ofl0o`Go01Ko2_oooolLo`3o40Go
oooo1?m_0?l00ol05_oooh/0oon;0003oaCo00Goo`3b2onCo`0<ool0lPCo5?l000?ooh/0o`0Fool0
5_l01_m_0?l3o`0Fo`Wooooo4_l0oa0>oooooa[o0?l@4oooool=o`3o45_oooooAOm_0?nUooooo`00
Doooool00ol0003oo`0lool09003o`30o`04oooooonU0?ooY@3oool0E0;oo`1800CoooooomH0oooo
02Coo`1W0_oo0:T01_oolP3ooooooooooooooooo0?mao`3oAP;oofd000koo`1iool0Oooo07ooo`2;
ooooooooiP3oo`2fom`0ooooooooA03oool0??mko`3oo`1>ool0T@;o203o00Coo`1]ooooooooT@3o
o`2`0_ooool01Ol0A_oooooooi<0oonC0?oonP3o00;oo`2l00?oo`38ool0Uooo09L00_ooool2ool0
n0?o<P3o00?oa?l0ojco0?l0]?l00_oo0=@01_l08_oo0=koo`3Nool0g_ooolP0o`3ogP?o0;[o1?oo
0?82ofl0o`03oaCo0?l05_oo01Ko00;o01Ko1Oooool;o`3o40Wooooo0_o:0?lAooooo`Ko0?l@0ooo
ool5ofl0o`?o01Ko00?ooh/0oaCo0?lDo`002ooo0?84oaCo00Cooh/01Ol05_l6ofl0o`Kooooo3?l0
oa0Goooooa[obP3o2OoooolCo`3o44[oooooHol0o`AZofl0oc_ooooo001Cooooo`04o`000?oo03co
o`0Tool0F`;ooooo00Coo`1Kool0E?oo05Coo`180_ooool01_oF0?ooo`0Tool0Iooo0:Wooo80ooo>
00?ooooo00So0?mao`3oA_ooK@3o0:Ooool0NOoo07ooo`2;ohL0o`;oonH000Woo`2foooooom4o`3o
A03oool0??mko`3oo`1>ool0TOl80?l00_oo06d01?ooooooo`2`ool0/?ooool2o`16o`;oT`3o00?o
01coool0_?oo0;`00_oo0<P00ooo09Ooooooooooo`02ool0n0;o<P3o00Coa?l0ojco0?n/o`3o[?l0
0_oo0=@2o`3No`?oolP000?o0;[oofl0oooo0?800ooo0?801?oooooooh/0oon;0?lDo`03o`0Fo`Go
oooo1?l0oa0DolX0o`;ooooo4?o:0?l7ooooo`Co0?l@1?ooool6ofl0o`;o01Ko2OooR`000ooooooo
01Koo`0Fo`0:ofl0o`Kooooo1_l0oa0?oooooaCobP3o6_oooolEolX0oa3oooooH_l20?m5ooooofOo
0?mO>oooool005?ooooo00Co0000oooooooo02Coo`180ooo05@2ool0B0;ooooo00GoeP3oool09?oo
06Ooo`2Yooob0004ooooo`07o`3oLOoooooo0?m6o`2Woooo07Woo`1oool0R`02oooV000>om`0oooo
0;KoooooodCo0?m40?ooo`0log_o0?oo04kom03oo`P0oooo06goon00oooooooo0;02ooooo`08o`16
oonC0?ooT`3oo`0Loooj0?ooo`2lool0i_oo0<P2ool0U`03ooooooo:o`3oo`3h00;o<P3o00Coa?l0
ojco0?n/o`3ooooo0_oo0=@2o`3No`;oolP000?o0;[oofl0oom_0?l00_oo0?801Ol0od3ooooooon;
0?ooR`3o5?l000?o01Ko1Oooool00ol0oa3obP3oolX0o`04olX0obKooooo1_o:0?l5ooooo`Co0?l@
1_ooool>ofl0o`[ooooo1_l0oa09ooooo`cobP3o6Oooool?o`3o11_o0P3o4?o:0?mIooooo`Wo0?mO
S?l20?mKooooo`00Doooool00ol0003oooooool09004ool0B003on80oooooooooooo00;oo`0T00?o
o`1Wool0ZOoocP001?ooool02?l0og7oooooo`3oA_l0Yoooo`1iool0Oooo08_oonH00_oL0?l02ooo
0;KoooooodCo0?m40?ooo`0log_o0?oo04kom03oo`P0oooo06goon0000;oo`2`0_ooool02ol0A_oo
T`3oo`0Lool07?oonP3oool0_?oo0>Koo`38ool0Uooooooob_l000;oo`3h00Go<P3ooooooon/o`3o
[?l0ooooo`02ool0e0;o0=ko0_oob003ofl0o`;oo`3b00Cooooooon;0?ooR`3o5?l00ol05_l4oooo
o`03o`3o4?o:0?oobP3o00;obP3o3Oooool4o`80oaKoM@3o0_l20?l9ooooo`?obP3o1_ooool3o`3o
41Gooooo1_l0oa0:ooooo`GobP3o4oooool8o`3o11Wo0P3o:ooooolGolX0ob3ooooo8_l0oeljoooo
og_oM@3o>oooool005?ooooo00Co0000oooooooo03coo`0T1Oooool01Ooo02Coo`1Wool0Iooo0:Wo
olh000Cooooo01Oo0?maooooool0odKoofd0ool0NOoo07ooo`2;oooV0?oL0?ooooooool0]_oooooo
A?l0od@0oooo03coNol0ool0C_od0?oo203oool0KOooh03oo`2`o`3ojP02ooooo`03o`16oonC0?oo
01co00;onP3o00Coo`2lool0i_oo0<Soo`2G0_o:o`000ooo0?So<P3ooc80o`02ojco00;ooooo00Co
o`3Do`3Nool0g_ooolP00om_0?l00ol0^_ooo`3bool0lP03oon;0003oaCo0?l05_oo01Ko00?ooooo
0_l0oa03olX0o`cooooo0ol20?l3ogD0oacoj03o1Ome0?l6ooooo`?obP3o1_oooolEo`3o40[ooooo
1_o:0?lBooooo`?o0?l41?l20?lNonP0oa[ooooo:_mYo`0BolX0o`;oJOl03?l0oelXofWo03CoM@3o
5?meo`2Rooooo`00Doooool01?l0003oooooool0??oo02@2ooooo`04oolN0?oF0?ooo`0Tool0I`;o
o`2Y00?oolh0ooooooooool00_ooool02Ol0og7oooooo`3oA_ooK@3o0:Ooool0NOoo08_oonH0om`0
o`02ooooo`0<ool0]_m4o`3oA03oool0??mko`3oo`1>ool0TOl80?ooo`1]oooP0?oo0;3o0?oZ0_oo
ool01?l0A_ooT`3oo`0Loooj0?l2ool0_004ool0i_oo0<Soo`2Gol[o00;oo`3h00?o<P3oojco0?n/
o`000_ooool2ool0e005o`3Noooob03oK`3oofl0oonCo`000ooo0?82oon;0004ooooool05_oo01Ko
o`0Fo`?ooooo0_l0oa02olX0o`[ooooo1?l20?l7onP0oaKo?P3o1_ooool6onP0o`;oM@3o1_ooool3
olX0oacooooo1_o:0?l@ooooo`Co0P3o2ooX0?lEogD0o`Kooooo0oln0?l7onP0odKo?P3o0_ooool7
o`3oG`_obP3o0ooooolGogGo017oM@3o;_oooon1ofWo03_ooooo001Cooooo`04o`000?ooooooo`0l
onP0o`Coo`0T00Coo`1Wool0ZOoocP3oolh01?ooool02Ol0og7oooooo`3oA_ooK@3o0:Ooool0NOoo
07ooonH0om`0o`02ooooo`0<ool0]_m4o`3oA03oool0??mko`3oo`1>ool0TOod0?ooo`1]oooP0?oo
0;3o0?oZ0_ooool03_l0A_ooT`3oo`0Loooj0?ooo`2loc;o0?oo0>Koo`38ool0Uoo:o`3oo`3hoooo
oolb0?oo[?l00_ooool2ool0e005o`0Rool0g_ooTol0ofl0oonCo`000_oo0?800ol0od3ooh/0oooo
o`03o`0Fo`Cooooo00Co0?l@olX0ooo:0?oobP3o1_ooool4o`80o`;oM@3o1?oX0?l7och0o`;ooooo
1?meo`0Bok80o`?o?P3o00?oJOl0ooooooooool01?ooool3onP0o`03ogD0ool20?oooooo00Gooooo
0oo:0?lCooooo`KobP3o4?ooool4o`80o`Koj03o0ome0?l6o`3oG`Cooooo0_mYo`0Aoch0o`?oM@3o
0oln0?l3ofWo00Oooooo1OoX0?lmooooo`;o0?mO0_l0oo`Doch0o`cobP3o3_me0?o0o`3oo3_ooooo
001Cooooo`05o`000?ooooooo`0lool0NOoo08D00_oo06L2ool0Z@03ooo>0?oooooooooo00?ooooo
00Wo0?maooooool0odKoofd0o`2Woooo07Woo`1ooooV0?oL0?l00_ooool03?oo0;Kooooood@0oooo
03coNol0ool0C_oo097om03oo`P0oooo06goo`2`o`3ojP;ooooo00goS@3ooi<0ool07?oonP3oool0
_?lbo`3oo`3Vool0b?oo09Ooooooool0n?n/o`3o<P3o00?ooooo00Coo`3Do`0Rool08_ooTol00_m_
0?l01?ooooooo`3bo`3o@?l0od02ooooo`03o`0FoolDo`3ooooo00?ooooo0oo:0?l5ooooo`Co0P3o
0ome0?l3onP0o`;o?P3o0oooool3ogGo00Wo/P3o4_ooool6ok80o`Co?P3o0oooool2onP0o`03ogD0
ool20?oooooo00Kooooo0oo:0?l<ooooo`CobP3o4Oooool3o`80o`Koj03o1?me0?l6ooooo`KoJOl0
1Oln0?l?ok80o`?oMOl00_l0oel4ogD0o`kooooo1OoX0?lFooooobCo0?ol00CoMOl0oooooooooooo
oooo2ol0Mol=ogD0o`Ko07Oo3?o:0?lCoch0ofKo07Oo9onb0?lRonP0oc_ooooo001Cooooo`05o`00
0?ooooooo`0lool0NOooZ@000_oo0:T00ooolP3oolh0ooooo`04ooooo`09o`3oLOoooooo0?m6oom]
0?l0Yoooo`1iool0OoooiP3og03o00;ooooo00coo`2foooooom4o`3oo`0log_o0?oo04koo`2Aoo@0
ool80?ooo`1]ool0/?l0onX2ooooo`0=ohd0oonC0?oo01coooX0oooo0;co<_l0ool0i_l8o`3oo`2G
oooooooo0?So[?l0oc80o`03ooooo`06ool0e?l08_ooTol0oi?o0?m_0?oooooo0_oo0?800ol0od3o
oh/0ooooo`02o`0Fo`03oaCo0?oooooooooo00?obP3o1_ooool2o`80o`04oooooome0?ooM@3oogD0
o`?oj03o0_ooool5ogGo00Co/P3o8Oooool4ok80o`;o?P3o0oooool3onP0o`03o`80oooooooooooo
00Kooooo3?o:0?lAooooo`;o0P3o1OoX0?l4ogD0o`03o`3oGooooooooooo00?ooooo00?oJOl0och0
ooln0?l01?ln0?l:ok80o`oooooo1onb0?l2o`3oG`?oM@3o4?l0oo`6onP0oa3o0?ol1OoooolSo`1g
o`Kooooo1Ome0?lOoooooa[obP3o4Oln0?lEokko01[o/P3oA_oX0?lRolX0oc_ooooo001Cooooo`04
o`000?ooooooo`0lool0N@Wooooo01Oo0?maooooool0odKoofd0o`2Woooo07Woo`1ooooV0?oooooo
g03ooooooooo0;KoooooodCo0?m40?ooo`0lool0C_oo097om03oo`P0oooo06goon00ool0/002oooo
o`0=ohd0oonC0?oo01coooX0oooo0;co<_l0ool0i_l8o`3oo`38ool0Uooo0?So[?l0oc80o`03oooo
o`03ool0e?l08_ooTol000;oK`3o00Coooooool0l_l0od3o0?m00_ooool00ol05_oo5?l0ooooo`03
olX0o`03o`3o4?oooooooooo00Cooooo0_l20?l00ol0oeooM@3oogD0o`03onP0o`03oooooomeo`3o
MOl000;oMOl000?ooooook80oonb0?l00_nb0?l00oooooooN`3oog/0o`0Log/0o`[ooooo0_nb0?l0
0oln0?ooooooooooo`02ooooo`04o`3oGooX0?ooj03oogD0oaoooooo00?o0?l4o`80oooX0?l00ooX
0?l3ogD0o`03o`3oGooooooooooo00?ooooo0_mYo`05och0o`Ko/P3o3_oooolBo`3oo0Ko/P3o00?o
M@3oogGo0?ooool03oooool3o`1go`Goj03o4?l0Mol9ooooo`;oMOl01_l0oel00omeo`3ooooooooo
o`0?ooooo`KoM@3o3?ooool;okko02?oB_l01?nb0?lColX0obgoj03o@_o:0?mQooooo`00Doooool0
1Ol0003oooooool0Uooo03coo`1i00Oooooo02Ko0?maooooool0odKoofd0o`2Woooo07Woo`1ooooV
0?oooooog03ooooooooo0;KoooooodCo0?m40?ooo`0lool0C_oo097om03oo`P0oooo06goon00ool0
/?l0on[oooooohd0oonC0?oo01coojGo0?oo0;co<_l0ool0i_l8o`3oo`38ool0Uooo0?So[?l0oc80
o`?ooooo00Coo`3DoooooonCo`3oK`3o0_ooool01?oo0?;o0?m0oon;0?ooool2o`0Fo`03oaCo0?o:
0?oobP3o00;o0?l@1Oooool01?mYo`3o0P3oo`80ool0oel2ogD0o`;oj03o0_ooool2ogGo00;ooooo
0onb0?l00oooooooN`3oog/0o`02og/0o`?ooooo1onno`0Do`3oo0KoN`3o1_ooool00onb0?oo?P3o
och0o`04ooooo`03o`3oGooX0?ooj03o00;oM@3o6?ooool2o`80o`Coj03o0_me0?l00ol0oeoooooo
ooooo`03ooooo`CoJOl00_ln0?l6ok80o`[ooooo2?l0oo`Jog/0o`?o/P3o3Omk0?l2o`1go`Sooooo
2OoX0?l7ooooo`KoMOl01Ol0oel<od[o06?oj03o5Ol0omPGoch0ofWo0?oH>oooool005?ooooo00Go
0000oooooooo0;Koo`0lool0N@05ooooo`;o0?ma00_oooooo`3oA_ooK@3o0:Ooool0NOoo07ooonH0
oooooooL0?ooooooool0]P02ooooo`0Hod@0oooo03coNol0ool0C_od0?oo203oool0KOooh03oo`2`
o`3oj_ooooooS@3ooi<0ool07?ooYOl0ooX0oooo0;coo`3Vo`So0?oo0<Soo`2Gool0n?n/o`3o<P3o
0oooool01?oo0=Coooooofl0oom_0?l2ooooo`0:ool0l_l0omkooh/0ooooool05_oo5?l0ooooooo:
0?ooooooo`3o40Cooooo0_mYo`02o`80o`03och0oome0?ooj03o00;oj03o0_ooool2ogGo0004oooo
oonb0?oo/P3ook80o`CoN`3o0oooool4okko0003ooooool0ooco0?ol01Ko^03o0_l0Mol00ooooooo
0?olo`3oo003o`3oo0;oN`3o1Oooool2ok80o`;o?P3o1Oooool01?oX0?oo0?mOogD0oome0?l@oooo
o`Go0P3o0ooX0?l2ogD0o`03o`3oGooooooooooo00;ooooo1?mYo`03och0o`Co/P3o2oooool00ol0
oocoN`3oog/0o`0:og/0o`_o07Oo0oooool:okko00Gooooo0_nb0?l3o`3oG`GoMOl00oooool6og/0
o`Kooooo1om:o`0NonP0o`KoM@3o1ol0omPDooooo`ko/P3oH?oooolGoch0ohgooooo001Cooooo`05
o`000?ooooooooooool0??oo07T01?ooool02ol0og7oooooooooool0odKoofd0o`2Woooo07Woo`1o
oooV0?oooooog03o00;ooooo01[oo`2foooooom40?ooo`0lool0WOoo04koo`2Ao`P0oooo06goon00
ool0/?l0on[oooooohd0oonC0?oo01coojGo0?oj0?ooo`2lool0i_l8o`3oo`38ool0Uooo0?Soa?l0
oc80o`Cooooo00?oo`3Dofl0ooooool00_ooool01_oo0?;o0?oNoon;0?oooooo01KooaCo00;obP3o
00Coooooo`3o4?oooooooooo0omYo`02o`80o`04och0oooX0?ooj03oonP0o`?ooooo0_meo`03ok80
o`04og/0ooooooooooooooooo`Ko__l01onh0?l3o`1goa?ooooo1onh0?l00ooooooo0?olo`3oo002
og/0o`Gooooo0onb0?l00oln0?ooooooooooo`02ooooo`?oj03o0ome0?l2o`80o`Kooooo1Ol20?l0
0ol0o`CoooooonP0o`02onP0o`03ogD0ool0oeoo0?mO00;ooooo1OmYo`04och0o`?o/P3o2Oooool2
okko00GoN`3o00?o__l0ooooooooool01?ooool5o`1go`;ooooo4onO0?l3ooooo`Go__l00_ooool3
ok80o`?o0?mO0_ooool3ogGo00KoB_l02Omk0?lEo`3of0?ooooo1Onno`05ogD0oaGooooo3?nb0?n5
ooooodKo?P3oAoooool005?ooooo00Ko0000ooooooooooooo`0lool0NOl0og42ooooo`0;o`3oLOoo
oooo0?m6o`3oA_ooK@3o0:Ooool0NOoo07ooo`2;oooooooL0?l00_ooool03?oo0;Kooooood@0ool/
0?ooo`0lool0C_oo097om03oool0KOooh03oo`2`o`3ojP;ooooo00goT`3oo`0LoonUo`3onP3oool0
_?lbo`3oo`3Vool0b?oo09Ooo`3holCo0?oooooo<P3o00?ooooo00?oo`3Dofl0ooooool00_ooool0
1ooo0?;o0?oNoon;0?oooooo01Koooooooo:0?l00_ooool01_l0oa3oooooofWo0?mYo`3oooooo`80
o`;o?P3o00?oM@3oonP0ooooool00_ooool3ogGo00;o/P3o00?oN`3oooooooooool01?nno`02oooo
o`Co^03o1?l0MolGod[o00Oooooo0_nO0?l3okP0o`03ooooool0oocoN`3o00;o__l01Oooool2ok80
o`03och0oooooooooooo00?ooooo1_oX0?l5o`80o`Ooj03o00CoM@3ooooooooooooooooo1?mYo`02
ogGo00?o?P3o00Cooooook80oonb0?oo/P3o2?ooool3okko00?oN`3o1_ooool8oil0oa3o^03o0_oo
ool6od[o00KoW`3o1_l0omP00ome0?oo/P3ook80o`0Do`3of003o`3oGomk0?ooN`3o00OoN`3o2_oo
ool5okko00GoM@3o3_ooool<ok80omOooooo3?ln0?lkooooo`00Doooool01_l0003ooooooooooooo
03coo`1io`2Wo`;o0?ma00Soooooo`3oA_ooK@3oofd0o`2Woooo07Woo`1oool0R`;og03o0_ooool0
6ooo0;Kooooood@0ool/0?ooo`0loiT0oooo04kom03oool0KOooh03oo`2`o`3oj_ooX`3oooooohd0
oonC0?ooYOl0ooX0oooo0;co<_l0ool0i_oo0<Soo`2Gool0n?o4o`3ooooooc80o`03ooooo`03ool0
e?nCo`3oolP000;ooooo00Ooo`3bo`3og_ooooooooooo`0FoooooooobP3o00;ooooo00Co0?l@ofWo
0?mYo`3ooooo0oln0?l00ome0?ooj03oonP0o`02ooooo`;oMOl000?oN`3ook80oonb0?l00_ooool3
okko00?ooooo0onh0?l4o`1go`CoB_l00ooooolAonSo00?ooooo1om:o`03ooooo`;oW`3o0_nh0?l0
0oooooooN`3oog/0o`02okko00Gooooo0_nb0?l00omeo`3oooooooooo`04ooooo`;o0?mO1_oX0?l2
ogD0o`;o0?mO1?ooool3ofWo0003oooooomeo`3oMOl000?o?P3o1?nb0?l8ooooo`;o__l01?mk0?l4
ooooo`03o`1goonO0?ooW`3o00;oW`3o2?nh0?l7ooooo`03od[o0?l0omSo0?oH00Ko0?oH1_nh0?l6
o`3of0;ooooo1?nO0?l4ooooo`03ogD0oonb0?oo/P3o00?o__l03ol0oel8ooooo`;o__l02?mk0?l2
okko0003oooooome0?ooM@3o00;oM@3o3Oooool6ok80ok?ooooo??nho`0kooooo`00Doooool01_l0
003ooooooooooooo09Ooo`0lool0N@?o0?m600Ooofd0o`2Wool0Yoooo`1iool0Oooo08_og03o00Co
oooo01[oo`2foooooom40?ooo`0lool0WOoo04koo`2Ao`P0oooo06goo`2`o`3oj_ooX`3oooooohd0
oonC0?ooYOl0ooX0oooo0;coooooool0i_l8o`3oo`2Gool0n?o4o`3ooooooc80o`?ooooo00?oo`3D
oi?o0?oob0000_ooool01ooo0?;o0?oNoooooooooooo01Koooooooo:0?l00_ooool01_l0oa3oJOl0
ooooool20?oo?P3oo`3oG`;oM@3o00Coj03ooooooooooooooooo0_mk0?l2ok80o`;ooooo0_nno`03
ooooo`?o^03o0ol0Mol3od[o0003oooooooXo`3oj?l000Goj?l00onho`0Eo`3of0?ooooo0om:o`04
ooooo`03okP0oonO0?oooooo00;oN`3o00?o__l0ooooooooool01?ooool00onb0?oo?P3ooch0o`0A
ooooo`?oJOl00omeo`03och0o`?o/P3o2Oooool00onno`3oN`3oog/0o`02og/0o`03o`3oo?oooooo
oooo00;ooooo00?o07Oooil0oonO0?l01Onh0?l9ooooo`Oo0?oH3_oXo`03okP0o`Woj?l01?nO0?l3
onSo00?o/P3o0_oXo`0Eokko00Wooooo00?oM@3oog/0oomk0?l01_mk0?l6ooooo`Ko/P3oG?oooomM
okSo07Oooooo001Cooooo`06o`000?ooooooooooool0Uooo03coo`1i1?l0Yol2ool0N@03ool0Oooo
08_og03o00Cooooo01[oo`2foooooom40?ooo`0lool0WOoo04koo`2Aoo@0oooo06goo`2`o`3oj_oo
X`3oooooohd0oonC0?oo01coooX0oooo0;coooooool0i_l8o`3oo`38ool0Uoo4o`3ooooooc80o`?o
oooo00?oK`3oool0e?oob0000_ooool01ooo0?;o0?oNoooooooooooo01KooaCo0?o:0?l00_ooool0
0ol0oa3oooooo`80o`02och0o`04o`3oGome0?ooj03oonP0o`;ooooo0_mk0?l2ok80o`;ooooo0_nn
o`02ooooo`?o^03o0ol0Mol2od[o00Goj?l00_ooool3okSo00Go0?oH4?ooool5okSo00Go0?oH00?o
oooood[o0?m:o`000oooool2okP0o`;ooooo0_mk0?l00onno`3oooooooooo`03ooooo`?o/P3o00?o
JOl0ooooooooool02?ooool5ofWo00;oMOl000Cooooooch0ooln0?oo?P3o0onb0?l9ooooo`04okko
0?mk0?ooN`3oog/0o`;o0?ol0oooool3oil0o`Co^03o2Oooool5o`3of0?oj?l05Oooool2okP0o`_o
oooo0onO0?l3ooooo`?o/P3o00?oooooonSo0?oXo`004OoXo`04ooooo`GoM@3o2Oooool6ok80o`;o
N`3o00?ooooooe3o0?m@o`00Aom@o`0FokSo0=Cooooo001Cooooo`06o`000?ooooooooooool0Uooo
03coo`1o1?oo07T01?n70?ooo`1oool0RooL0?l4ooooo`0<ool0]_ooooooA03oob`0oooo03coV@3o
ool0C_od0?ooo`1]oooP0?oo0;3ooj<00_ooool03On=0?ooT`3oooX0oooo0;coooooool0i_l8o`3o
o`38ool0Uon/o`3ooooooc80ooook0000_ooool00om_0?ooo`3Dooo80002ooooo`07ool0l_l0omko
ooooooooool05_oo5?l0olX0o`02ooooo`08o`3o4?oooooo0P3ooch0oooooooo0?mOogD0oooX0?l2
ooooo`;oN`3o00Cooooook80oooooooooooo0_nno`02ooooo`;o^03o00CoB_l0o`1gool0Mooo0?ol
0_oXo`03ooooo`;o^?l01ol0omPKooooo`Co^?l00_l0omP00oooooooB_l0ooooo`03ooooo`04okP0
oonO0?ooooooo`3oo0;oN`3o1oooool2ok80o`;o?P3o1omYo`000omeo`3o?P3ooch0o`05och0o`?o
/P3o2_ooool3og/0o`;o0?ol0_ooool4oil0o`?o^03o1oooool2od[o00Co0?oH00?ooooookSo0?nh
o`006onho`000ooooooo^03ookP0o`0<ooooo`;oW`3o1?ooool3ok80o`;oM@3o3?ooool7ogD0o`Wo
D?l01Onb0?l8oe3o00OoN`3o0ooXo`08oooooaSo^?l08?oXo`1doe3o02oooooo3?oXo`0kooooo`00
Doooool3o`000003o`0Foooo03cog03o00Goo`1o00?oo`2;om`0ooooool01?ooool06_oo0;Kooooo
od@0oooo03coo`2Mool0C_oo097o203oool0KOoo0;3o0?oZoonS0?ooooooS@3ooi<0oonUo`3onP3o
ool0_?o:o`3oo`3Vo`So0?oo09Ooo`3holCo0?lb0?ooon`00oooool02ooo0=CoolP0oooooooooooo
o`3bo`2jool0omkoooooo`0FoolDo`3obP3o00;ooooo00Ko0?l@ooooooln0?oo?P3oooooool0oel2
onP0o`04oooooomk0?ooN`3oogGo00;o/P3o00?ooooookko0?nno`000_ooool2okP0o`;o0?ol00?o
07OoonSo0?oXo`000oooool3okSo00;o0?oH3Oooool;onko00kooooo00Co^?l0onSo0?l0omSo0?oH
0om:o`02ooooo`;o^03o0_ooool00ol0oocoN`3oooooo`07ooooo`;o/P3o2?ln0?l4ooooo`?o/P3o
2_ooool3og/0o`;o0?ol0_ooool3oil0o`04o`1goonh0?oo^03ookP0o`Gooooo00Coj?l0od[o0?m:
o`3oB_l00ol0omP5okSo01gooooo0onho`02okP0o`03okSo0?oooooooooo00Wooooo0onO0?l01?oo
ooooD?l0oe3o0?m@o`04ok80o`[oM@3o1Om@o`05ooooo`Ko/P3o5?ooool7og/0o`Co^?l0AOoooomW
onSo03_oD?l0>oooool005?ooooo00Oo0000ooooooooooooooooool0??oooooog03o00;oo`2;0_oo
ool00ooL0?ooooooooooo`03ooooo`0Jool0]_ooooooA03oob`0oooo03coo`1>ool0TOod0?ooo`1]
ool0/?l0on[ooj<0oooooon=0?ooT`3oo`0Loooj0?ooo`2lol[o0?oo0>Ko2?l0ool0b?oo09Ooa?l0
oc80ooook003ooooo`0>ofl0oooo0=Cooooooooooooo0?;o0;[oo`3og_oooooo01KooaCo0?o:0?oo
ooooofWo0?l0oa02och0o`;ooooo00?o0?mOonP0ooooool00_mk0?l00omeo`3ooooook80o`02oooo
o`03okko0?oooooooooo00;o^03o00CoB_l0o`3oo?l0Mooo07Oo0oooool3okSo0003ooooool0omSo
0?oH00Oooooo0oo^o`05oe3o00ooP@3o1?o^o`07ooooo`?o^?l00_l0omP00oooooooB_l0ooooo`02
ooooo`05okP0ool0Mooooooooooooomk0?l02Oooool<ok80o`[ooooo0omk0?l2o`3oo0;ooooo0onO
0?l01?l0Mooo^03ookP0oonh0?l4ooooo`;oj?l00om:o`03o`3of003okSo0?oooooooooo00cooooo
6oo^o`02okP0o`;o^?l02om@o`02oil0o`Kooooo5?nb0?lAooooo`_o^?l01Oooool:og/0o`[ok_l0
Q_l0oaIAo`3o]3_ooooo001Cooooo`06o`000?oooooooooooooooooo03coA03o0_ooool3om`0o`Go
oooo01[oo`2fooooooooooooA03oool0??nI0?ooo`1>oo@0ool80?ooo`1]ool0/?ooX`3oooooohd0
ool0A_ooT`3oooX0oooo0;coooooool0i_l8o`3oo`38ool0Uoo4o`3ooooooc80o`?ooooo013oK`3o
ool0e?oob03oooooool0l_l0^_oo0?oNooooool05_oo5?l0olX0ooooooooJOl0o`3o4?ln0?oo0P3o
0_ooool01?l0oeooj03ooooooomk0?l2ogGo00;o/P3o00Cooooookko0?nno`3ooooo0_nh0?l01?m:
o`3o0?olo`1gool0Mol2ooooo`?o^?l00_ooool2o`3of0?ooooo0_o^o`03oe3o00WoP@3o3ol0Sol5
oh40o`;ok_l01oooool2okSo00;o0?oH00KoB_l0oooooooooooooooookP0ool0Mol2ooooo`03og/0
ool0oocooooo01Wooooo0omk0?l2o`3oo0;ooooo0onO0?l01?l0Mooo^03ookP0oonh0?l4ooooo`?o
j?l00_m:o`03o`3of0Wooooo2Oo^o`0Booooo`_oD?l00_nh0?l2onko00[o^?l000?ooooooil0oonO
0?l07Oooool:okSo00;oQol06_l0oaH8og/0o`;o0?lF:On7o`07ooooob?o6_l0<ol0okB<ooooo`00
Doooool01_l0003oooooooooooooooooo`1>ool0?0[ooooo01[oo`2foooooom40?ooo`0lool0WOoo
04koo`2Ao`P0oooo06goo`2`o`3oj_ooX`3oooooohd0oonC0?oo01coooX0oooo0;coo`3Vo`So0?oo
ooooo`2Gool0n?oooooo<P3oooo/00;ooooo00OoK`3oool0e?oob03oooooool0l_l0^_oo0?oN00;o
oooo00Oo01KoolX0oomYo`3oJOl0o`3o4?ln0?oo0P3o00;ooooo00Oo0?mOogD0oooX0?ooN`3oogGo
0?oooooo/P3o00;ooooo00Ko__l0oooooonO0?oo^03ood[o0?oXo`02o`1go`04oooooonho`3o^?l0
okSo00?ooooo0_l0omP00oooooooD?l0oe3o0004oe3o00?oP@3o1Ol0SolEooooo`?o08oo0on10?l2
onko00Kooooo00Co^?l0ooooool0omSoB_l00oooool01onh0?oo07OoooooooooooooN`3oo`3oo?nn
o`005?ooool01Onno`3oN`3oog/0oomk0?oooooo00;o0?ol0_ooool2oil0o`04o`1goonh0?oo^03o
okP0o`Cooooo0ooXo`02od[o00?o0?oH2?ooool4onko00cooooo3om@o`0=ooooo`03okP0oooooooo
oooo00Kooooo0oo^o`03okSo00?oW`3o3Onho`0=ohOo00co0?lF00?ok_l0ooooooooool01OoooolJ
oa[o00CoN`3o;_lJo`0;ohOo01So0?nd2On7o`1Ooa[o01co08oo>oooool005?ooooo00Ko0000oooo
ooooooooooooool0Uooo03`9ooooo`0Jool0]_ooooooA03oob`0oooo03coV@3oool0C_od0?ooo`1]
ool0/?l0on[ooj<0oooooon=0?ooT`3oo`0Loooj0?ooo`2lol[o0?oo0>Ko2?l0ool0b?oo09Oooooo
oc80ooook002ooooo`0@ofl0oooo0=CoolP0oooooooo0?;oooooo`2jool0od3oooooo`0Fooo:0?oo
JOl0ooooool0oa3o?P3oo`80o`;ooooo00So0?mOogD0oooX0?ooooooogGo0?oooooo/P3oooooo`;o
__l000CoW`3ookP0oonh0?ooj?l00_l0Mol2ooooo`04okSo0?ooooooooooooooo`?o0?oH0om@o`00
1?o^o`3oooooooooool0Sol2oh40o`03o`2?oooooooooooo00Kooooo4Ol0ok@7ooooo`;o08oo1?n1
0?l5ooooo`04okSo0?oXo`3o0?oHod[o00?ooooo0_nh0?l01Ol0Moooooooog/0ool0ooco__l000oo
oooo0_nno`03og/0o`04ooooool0ooco0?olo`3oo0;ooooo0_nO0?l00ol0Mooo^03ookP0o`04oooo
o`?oj?l000?ooooood[o0?m:o`000_l0omP6ooooo`Gok_l02oooool5oe3o01gooooo0_nh0?l7oooo
o`SoQol00onO0?l00on7o`3o0?lFo`3o5P0Do`3o5P03oooooolJo`3o6_l0017o6_l07_ooool4og/0
ob[ooooo2ol0okA<ooooo`03ohOo0?l0Sooo08oo037o08oo7?n7o`0kooooo`00Doooool01_l0003o
ooooooooooooooooo`2Gool0?0Sooooo01Ooo`2fooooooooooooA03oool0??oo09goo`1>ool0TOl8
0?ooo`1]ool0/?l0on[oooooohd0ool0A_ooT`3oooX0oooo0;cob_l0ool0i_l8o`3oo`38ool0U`02
ooooo`06oc80ooooooooooooofl0ool0]?ooo`3D0_ooool02ooo0?;o0;[oo`3o@?oooooo01KoolX0
oomYo`3oooooo`3o4?ln0?oo0P3o00;ooooo00Wo0?mOog/0oooX0?ooooooogGo0?oooooo/P3ooooo
oonno`000_nO0?l01?nh0?ooB_l0onSo0?l0Mol2ooooo`;o^?l00_ooool2o`3of0?oD?l000Cok_l0
oooooooooooo08oo0on10?l6ooooo`Go0?nd3?n7o`05ooooo`Go0?nd1Oooool2o`2?o`03oooooon1
0?oooooo00Cooooo00Co^?l0onSo0?l0omSoB_l00oooool01?nO0?oo^03oo`1gooooool3og/0o`;o
__l02_ooool01?nno`3oN`3oog/0oomk0?l2ooooo`;o0?ol0_ooool3oil0o`03o`1goonh0?oo^03o
00?ooooo0ooXo`000ooooooo^?l0od[o0003o`3of0Gooooo0oo^o`0;ooooo`GoD?l07oooool5ohOo
0003okP0oon7o`3oQol000CoQol02ol0oaH3oil0o`Wooooo3?lJo`0eooooo`GoN`3o6Oooool<o`3o
]2kooooo:_l0Son:ooooo`00Doooool01_l0003oooooooooooooooooo`2Gool0?0Oooooo00coo`2f
ooooooooooooA03oob`0oooo03coo`1>ool0TOod0?ooo`1]ool0/?l0onX2ooooo`0Aohd0oonC0?oo
01coool0_?l0oj7oo`3Vo`So0?n/o`3oo`2Gool0n?oooooo<P3oooo/0?ooooooK`3oo`2doooo0=@0
0_ooool02ooo0?;o0;[oooooool0od3o01KoolX0oomYo`3oooooo`3o4?ln0?oo0P3o00;ooooo00[o
0?mOog/0oooX0?ooooooogGo0?oooooo/P3ooooooonno`3oW`3o0_nh0?l00ooXo`3oooooo`1go`02
ooooo`03okSo0?oooooooooo00;o0?oH0_m@o`02onko00;ooooo0on10?l5ooooo`04ohOo0?l0okCo
0?ndo`3o]0?oQol03_ooool9ohOo0004ooooool0okCo0?ndo`3o]0Cooooo0_l0Sol00on10?ook_l0
ooooo`03ooooo`04okSo0?oXo`3o0?oHod[o00?ooooo00KoW`3ookP0oonh0?oo07Ooooooool0oo`5
og/0o`?o__l01Omk0?l2ooooo`?o0?ol0_ooool2oil0o`04o`1goonh0?oo^03ookP0o`?ooooo0_oX
o`02ooooo`;oB_l00_l0omP5ooooo`?ok_l02_ooool4oe3o01Wooooo2on7o`000ooooooo0?lFo`3o
5P03o`3o5P;o^03o1?l0oaH:ooooo`Co6_l00onO0?l6oa[o04Kooooo1Omk0?l5ooooo`oo0?nd;_oo
ool<o`2?okCooooo001Cooooo`07o`000?ooooooooooooooool05_ooo`0lool0]P06ooooo`0Jool0
]_ooooooA03oob`0oooo03coV@3oool0C_od0?oo203oool0KOl0on[ooj<0oooooon=0?ooT`3oo`0L
oooj0?ooo`2looCo0?oo0>Ko2?l0ool0b?oo09Oooooooc80ooook002ooooo`0?ofl0oooo0=Cooooo
oooooooo0?;oooooo`2jool0od3oooooolX0oomYo`3oooooo`3o4?ln0?oo0P3o00;ooooo00co0?mO
og/0oooX0?ooooooogGo0?oooooo/P3ooooooonno`3oW`3ookP0oom:o`02ooooo`04o`1goooooooo
^?l0okSo00;ooooo00?o0?oHoe3o0?m@o`000_o^o`02ooooo`;oP@3o0_ooool4ohOo00?o0?nd2_oo
ool@o`3o5P?ooooo0_n7o`02ooooo`;o0?nd0oooool01?m@o`3o08oooh40ooo^o`04ooooo`04okSo
0?oXo`3o0?oHod[o00Gooooo00?o^03oo`1gooooool00_ooool2o`3oo0CoN`3o0oooool4o`3oo0;o
oooo0onO0?l3okP0o`?ooooo0ooXo`02ooooo`;oB_l00_l0omP5ooooo`;ok_l02_ooool3oe3o00Wo
oooo1On10?l6ooooo`OoQol03_l0oaH7ooooo`03okP0oooooooo6_l000_o6_l01oooool3oil0odko
oooo1_mk0?laooooo`_o08oo`?ooool005?ooooo00?o0000ooooooooool00_ooool00ooo03coo`2f
ooooo`04ooooo`0Gool0]_oooooooooood@0oon1o`3oo`0lool0C_oo097o203oool0KOoo0;3o0?oZ
oooooon=0?oo04Kooi<0oooj0?ooo`2lo`3oXOoo0>Ko2?l0ojco0?oo09L00_ooool01Olb0?oooooo
oooooom_0?ooo`3D00?ooooo00[oo`3bo`2jool0od3oooooolX0oolDo`3oooooo`3o4?ln0?oo0P3o
0_ooool01Ol0oeooN`3oonP0ooooooooMOl000;ooooo00Co/P3ookko0?nO0?oo^03o0oooool01Ol0
MooooooookSo0?ooooooD?l000;o0?oH0oo^o`001Ooooooo08oooh40oon10?oooooo00?oQol000Co
ooooo`3o]?l0okCo0?nd1oooool6o`3o5Pgo6_l00oooool5o`3o5P;oQol00_ooool3o`3o]0;ooooo
00?o08oooh40ooo^o`001?ooool01?nho`3oj?l0o`3of?m:o`05ooooo`03okP0oonO0?oo07Oo00Co
oooo1_l0oo`3ooooo`?oW`3o0onh0?l4ooooo`;oj?l00_ooool3od[o00;o0?oH1?ooool3onko00So
oooo1?m@o`04ooooo`SoP@3o1On7o`05oh40o`03ohOo0?l0oaKo0?lF00Go0?lF3?ooool:oa[o00;o
^03o5Oooool2oil0odSooooo1?l0ok@6ooooo`GoN`3o8Oooool;o`2?ol_ooooo001Cooooo`03o`00
0?oooooooooo00;ooooo00?oo`0lool0]_ooool01?ooool07_oo0;Kooooood@0ool/0?ooo`0loiT0
oooo04kom03oo`3o;_oo06go0?oZoooooon=0?oooooooi<0ool07?ooo`2lo`3oXOooooooo`3Vojco
0?oo0<Soo`2Goooooolb0?ooon`0oooooom_0?oo0;Coool0e0;ooooo00Koo`3bo`2joooooooo0?m0
olX0oolDo`02ooooo`09o`3o4?ln0?ooooooooooool0oeooooooonP0ooooooooMOl000;ooooo00Co
/P3ookko0?nO0?oo^03o0oooool00ol0Mooo^?l0okSo0002oe3o0004o`3of?o^o`3ok_l0ooooo`;o
08oo0_n10?l3ohOo0004ooooool0okCo0?ndo`3o]0Oooooo0ol0oaH6oa[o00gooooo1_lJo`02oooo
o`?o0?lF00GoQol0ooooooooooooooooo`3o]002ooooo`03o`2?oon10?ook_l000Cooooo0_nho`00
0ol0omSoB_l0ooooo`04ooooo`?o^03o00?o07Ooooooooooool01_ooool3oil0o`?o^03o1Oooool2
onSo00;ooooo0_m:o`000onho`3o0?oHo`3of004ooooo`;ok_l02?ooool3oe3o00Gooooo0on10?l4
ooooo`CoQol01Oooool5o`3o5PCoP@3o0_ooool>oa[o00cooooo00?o^03oooooooooool05?ooool3
oil0od7ooooo1?l0ok@?ooooo`KoN`3o3oooool<o`2?omKooooo001Cooooo`03o`000?oooooooooo
00;ooooo00?oo`0lod@0oooo0;H00_ooool2ool0]P0Moooooom40?oo;03oool0??mko`3oo`1>ool0
TOl80?ooo`1]ool0/?l0on[oooooohd0oonC0?oo01coooX0oooo0;coooooool0i_l8o`3oo`38ool0
Uooooooo<P3oooo/0?ooooooK`3oo`3Noooo0=@00_ooool02_oo0?;oooooo`2jool0od3obP3oofWo
0?lDo`3oooooo`3o4?ln0?l2ooooo`05o`3oGoooooooN`3oonP0oomeo`000_ooool01?nb0?oooooo
oil0oonh0?l3ooooo`07o`1gool0oocoD?l0oe3o0?oooooo0?oHonko0002ooooo`03o`2?oon10?oo
P@3o00;oQol000Coooooo`3o]?l0okCo0?nd1oooool3o`3o5P04oa[o0?oooooooooooooooa?o803o
1Oooool3oa[o00;ooooo00?o0?lFohOo0?n7o`000_ooool01_l0okCoooooooooool0SoooP@3oonko
00Gooooo00?o^?l0o`3of?m:o`001oooool3okP0o`CoW`3o1Onh0?l00ol0Moooooooooooo`03oooo
o`;oj?l00_ooool2od[o0003okSo0?l0omSo0?oH00Cooooo0_o^o`07ooooo`?oD?l01Oooool3oh40
o`Cooooo0on7o`05ooooo`Co0?lF1oooool2oa[o00;oP@3o6oooool00onh0?ooooooooooo`0Foooo
o`CoW`3o>?ooool5o`3o]1Wooooo1_mk0?l9o`2?on;ooooo001Cooooo`03o`000?oooooooooo00;o
oooo00?oo`0lod@0ooooool00_oo0;H2ooooo`0_od@0ool/0?ooPOl0ool0??nI0?ooo`1>oo@0oooo
06goo`2`o`3oj_ooooooS@3ooooooonC0?oonP3oool0_?l0oj7oo`3Vo`So0?n/o`3oo`2Gool0n?oo
oooo<P3ooooooom_0?oo0=koo`0Roooo0=Coooooool0l_oooooo0;[oo`3o@?oooooobP3ooaCo0?oo
oooo0?l@och0ool20?ooooooo`3oGoooooooN`3oonP0oomeo`000_ooool01?nb0?oooooooil0oonh
0?l3ooooo`03o`1gool0oocoD?l000;ooooo00Co0?oHonko0?oooooooooo0_n10?l00on7o`3ooooo
o`3o]002o`3o]0Oooooo0ol0oaH00olJo`3o803oob00o`04ob00oa?ooooo1OlP0?l3ooooo`?o6_l0
0_l0oaH2ohOo0006ooooool0okCo0?ndoooooon10?oooooo0_o^o`04ooooo`04okSo0?l0omSoB_l0
od[o00Sooooo1Onh0?l8ooooo`;oj?l000Oooooood[o0?m:o`3oB_l0okSo0?oooooo0?oH00Cooooo
0_o^o`07ooooo`;oD?l01Oooool3oh40o`Cooooo0on7o`04ooooo`Co0?lF1?ooool7oa[o00Cooooo
00?oP@3oooooooooool06Oooool00onh0?ooooooooooo`0Iooooo`KoW`3o;_ooool4o`3o]1kooooo
1_l0Sol6og/0onGooooo001Cooooo`03o`000?oooooooooo00;ooooo00?oo`1>ool0??m40?l00ooo
ool07Om40?oo;03ooooooooo03coV@3oool0C_oo097o203oool0KOooX`3o0?oZohd0ooooooooT`3o
o`0Loooj0?ooo`2loooooooo0>Ko2?l0ool0b?oo09Oooooooc80ooook03oK`3oo`3NoonCo`3oo`3D
00;ooooo00Koo`3bo`2joooooooo0?m0olX0oolDo`02ooooo`0>och0ool20?ooooooo`3oGooooooo
N`3oonP0ooooooooMOl0oooooonb0?oooooooil0oonh0?l3ooooo`03o`1gool0oocooooo00;ooooo
00?o0?oHooooooooool00_n10?l01?n7o`3oooooooooool0ok@8ooooo`;o0?lF00Co6_l0ob00oolP
0?oo803o7_ooool3ob00o`?ooooo0_lJo`000ol0oaKoooooohOo0002ooooo`03o`3o]?l0SoooP@3o
00;ooooo00?ok_l0ooooooooool00_ooool01?nho`3o0?oHoooooom:o`0Booooo`;oj?l000Cooooo
od[o0?m:o`3ooooo0_nho`02o`3of0?ooooo0_o^o`07ooooo`;oD?l01?ooool3oh40o`Cooooo0on7
o`04ooooo`?o0?lF1Oooool3oa[o00_ooooo00?oP@3oooooooooool06_ooool00onh0?oooooooooo
o`0Nooooo`GoW`3o4_ooooldo`2Eo`Go08oo2?l0UOl4ooooo`GoN`3oh?ooool005?ooooo00?o0000
ooooooooool00_ooool00ooo06goo`0lob`0o`04od@0o`0coooooooo03coNol0ool0C_oo097om03o
ool0KOoo0;3o0?oZoooooon=0?oo04Kooi<0oooj0?ooo`2lo`3oXOoo0>Ko2?l0olCo0?oo09Ooo`3h
oooooolb0?ooK`3oooooool0g_oo02;oool0e?ooooooo`3booooool0^_oo0?m0olX0oomYo`3o5?l0
ooooooln0?oo0P3oooooool0oeooooooog/0oooX0?ooooooogGo0?oooooo/P3ooooooonO0?oo^03o
00?ooooo00Ko07Ooo`3oo?ooooooooooonko0?l0omP2ooooo`03oh40ool0Sooooooo00;ooooo00?o
0?ndooooooooool01Oooool00olJo`3o0?lFob00o`02ob00obCooooo0_lP0?l3ooooo`04oa[o0?l0
oaKo0?lFohOo00;ooooo00?o0?ndo`2?oon10?l00_ooool00oo^o`3oooooooooo`02ooooo`03okSo
0?l0omSoj?l000;oB_l03_ooool2onSo00?oB_l000?ooooookSo0?nho`000_l0omP3ooooo`;ok_l0
2?ooool01?m@o`3oooooooooooooool3oh40o`Cooooo0on7o`04ooooo`?o0?lF1_ooool2oa[o00oo
oooo0_n10?l00ooooooo803oob00o`0>ob00o`[ooooo0_nh0?lQooooo`;o09Go1_nO0?l<o`2Eoa;o
oooo0_l0ok@Looooo`Co08oo3Oooool9o`2Eo`WoN`3o7Ol0UOnjooooo`00Doooool00ol0003ooooo
ooooo`02ooooo`03ool0n?oo04koo`0l00Co;03o02Koo`0log_o0?nI0?ooo`1>oo@0ool80?ooo`1]
o`3oj_ooooooS@3ooooooonC0?oonP3ool[o0?oo0;coooooool0i_n/o`3oo`38ool0Uooooooo<P3o
ooo/0?m_0?oo0=kooi?o0?oo0=Coooooool0l_oooooo0;[oo`3o@?o:0?oo01KooaCo0?oooooo?P3o
o`80o`;ooooo00[o0?mOog/0oome0?ooj03oogGo0?oooooo/P3ooooooonO0?oo^03o0oooool01ol0
Mooo0?olooooooooooook_l0o`3of?ooool00_n10?l4ooooo`03o`3o]?oooooooooo00Cooooo00Co
6_l0ob00oolP0?oo803o:Oooool03OlP0?oooooooooooooooooo6_l0ooooool0oaKoQol0ooooool0
okCoooooo`2?oon10?l00_ooool00oo^o`3oooooooooo`02ooooo`04okSo0?l0omSoj?l0ooooo`;o
B_l02Oooool3onSo00;oB_l00_ooool2okSo00;o0?oH1?ooool00oo^o`3oooooooooo`06ooooo`;o
D?l00_ooool2oh40o`Cooooo0on7o`05ooooo`;o0?lF1Oooool9o`3o]0Kooooo2?lP0?l00on10?oo
ooooooooo`0>ooooo`[o803o0_ooool00onh0?ooooooooooo`0Booooo`co09Go2?ooool6oil0oaGo
oooo0ol0ok@Jooooo`Co08oo8oooool8og/0oaGooooo;ol0UOn;ooooo`00Doooool00ol0003ooooo
ooooo`02ooooo`04okP0oooo04koo`2Aool0?0;ooooo01Coo`0log_o0?nI0?ooo`1>oo@0ool80?oo
o`1]ool0/?l0on[oS@3ooooooonC0?oo01coooX0oooo0;co0?nQool0i_l8o`3oo`38ool0U`;ooooo
00Go<P3oofl0ool0g_ooTol0ool0e002ooooo`0Eool0l_l0^_oo0?oNo`3o@?o:0?oooooooaCo0?ln
0?oo0?l@o`80oooooooo0?mOog/0oome0?ooj03ooooooomeo`3ooooook80oonO0?oo^03o00?ooooo
00Wo07Ooo`3oo?ooooooooooonko0?l0omSooooooh40ool0Sol00oooool2o`3o]0Gooooo0olP0?l]
ooooo`;o803o0_ooool00olJo`3oooooo`3o5P02ooooo`04o`3o]?oooooo08oooh40o`;ooooo00?o
k_l0ooooooooool00_ooool00onho`3o0?oHo`3of002onSo00;oB_l00oooool4onSo00?oB_l000Co
oooookSo0?nho`3o^?l00_l0omP4ooooo`;ok_l01oooool2oe3o00;ooooo0_n10?l3ooooo`?oQol0
1oooool00ol0oaKoooooo`2?o`0:o`2?o`[o803o2Oooool00on10?ooooooooooo`0Gooooo`?o803o
00?o^03oob00ooooool01_ooool;o`2Eoa[ooooo1OnO0?l>ooooo`;o0?nd6Oooool4o`2?oboooooo
1_mk0?lnooooobko09GoGOooool005?ooooo00?o0000ooooooooool00oooool00ooo06goo`1>ool0
?003ool0?00`oiT0oooo04kooooooo@0ool0obkoo`1]o`3oj_ooooooS@3ooooooonC0?oonP3oool0
_?l0oj7oo`3Vo`So0?o4o`3oo`2Gool0n?oooooo<P3oofl0oooooooo0=koo`0Roooo0=Coooooool0
l_oooooo0;[oo`3o@?o:0?oooooooaCo0?oooooo?P3oo`80oooooooo0?mOoooooomk0?ooj03ooooo
oomeo`3ooooook80oonO0?oo^03o0oooool02?m@o`3o07Ooo`3oo?ooooook_l0ooooool0omSoP@3o
1?ooool00ol0okCoooooooooo`02ooooo`?o803o00?o0?lFooooooooool0;oooool03?lP0?oooooo
oooooolJo`3o0?lFohOo0?oooooo0?ndooooool0SoooD?l0oh40o`;ooooo00?ok_l0ooooooooool0
0oooool01Onho`3o0?oHooooooooooooj?l000OoB_l000GooooookSo0?nho`3o^?l0ooooo`02o`3o
f0Cooooo0_o^o`07ooooo`;oD?l00oooool01?n10?ooooooooooooooool2ohOo00Kooooo1_l0Sol0
1?oooooo6_l0oa[o0?lJo`04ooooo`?o803o00Coooooo`2?ool0Sooo08oo0oooool3o`3o]0Wooooo
00?oP@3oooooooooool06_ooool00ol0UOoo^03oob00o`05ob00o`03o`2Eoooooooooooo02Sooooo
1?nO0?l8ooooo`;o0?nd6?ooool3o`2?ocWooooo5?mk0?mHooooob;o09Go>oooool005?ooooo00?o
0000ooooooooool00oooool00ooo09Ooo`1]ool0CP03oiT0o`0Iool0C_oooooom03oo`P0oooo06go
o`2`o`3oj_n=0?oooooooi<0oooj0?oob_l0ool0_?ooooooo`3Vo`So0?oo0<Soo`2Goooooolb0?oo
on`0ofl0ool0g_ooTol0ool0e002ooooo`09ool0l_l0^_oo0?m0olX0ool05_oooooooaCo0?ln0?oo
0P3o00;ooooo00Wo0?mOog/0oooX0?ooooooogGo0?oooooo/P3ood[o0?nh0?l00oooool02Om@o`3o
07Ooo`3oo?ooooook_l0ooooool0omSo08oooh40o`02ooooo`;o0?nd0oooool2ob00o`;o0?lF5ooo
ool=o`2Eoa3ooooo00co803ooooooooooooo6_l0o`3o5_n7o`3oooooo`3o]?oooooo08oooooooon1
0?l2ooooo`03onko0?oooooooooo00Cooooo0_l0omP00onho`3oooooooooo`02ooooo`Co^?l00ooo
ool00ol0omSoooooooooo`02ooooo`;ok_l01oooool2oe3o00?ooooo0_n10?l2ooooo`;oQol01_oo
ool2o`2?o`?o0?nd00Cooooooa[o0?lJo`3o6_l01?ooool3ob00o`Oooooo00?o08ooooooooooool0
0oooool00ol0okCoooooooooo`07ooooo`03oh40oooooooooooo01;ooooo1ol0UOl2ooooo`;o^03o
1?ooool6ob00obWooooo1?nO0?l01?oooooo0?ndo`3o]?l0ok@Gooooo`?o08ooD?oooolGog/0oeOo
oooo3?mk0?lkooooo`00Doooool3o`0000?ooooo03Goo`2Gool0KOoo04koo`2Aoooooooo04kooooo
oo@0ool80?ooo`1]ool0/?l0on[oooooohd0oonC0?oo01coooX0oooo0;co0?nQool0i_l8o`3oa?l0
ool0Uooo0?Sooooooc80oom_0?ooooooo`3Nool08_ooo`3Doooooooo0?;ooh/0o`2jooo:0?oo01Ko
oooooolDo`3o?P3oo`3o4?l20?ooooooo`3oGomk0?ooM@3oonP0ooooooooMOl0oooooonb0?ooW`3o
okP0o`02ooooo`09oe3o0?l0Mooo0?olooooooo^o`3oooooo`3of?l0SoooP@3o00;ooooo00?o0?nd
ooooooooool00_ooool00olP0?oo6_l0o`3o5P0Dooooo`03o`2EoomY0?ooJ@3o01?oJ@3o00?o09Go
ooooooooool02_ooool01olP0?oooooooooooolJo`3o0?lFohOo0?l0ok@00_ooool00ol0SoooP@3o
ooooo`02ooooo`03onko0?oooooooooo00Gooooo1?l0omP00onho`3oooooo`3of005o`3of0?ooooo
0_o^o`08ooooo`04oe3o0?ooooooooooooooo`;oP@3o0oooool00on7o`3oooooooooo`04ooooo`;o
08oo0_l0ok@2ooooo`;o6_l01?ooool3ob00o`_ooooo00?o08ooooooooooool00oooool00ol0okCo
ooooooooo`07ooooo`03oh40oooooooooooo00_ooooo1_l0UOl;ooooo`;o^03o2?ooool6ob00oago
oooo2?l2o`02o`3o]0CoW`3o5?l2o`03o`2?o`oo0_l0FooooomGog/0odOooooo001Cooooo`03o`00
0?oooooooooo00?ooooo00?oo`2GooX0oooo06d00ooo04h06?od0?oo203ooooooooo06gooj<0o`3o
j_n=0?oooooooi<0oooj0?oob_l0ool0_?ooooooo`3Vo`So0?oo0<Soo`2Goooooolb0?ooon`0ofl0
ool0g_ooTol0ool0e0;ooooo00Woo`3bo`2jool0od3obP3ooooooolDo`3o?P3oooooool20?l00_oo
ool02Omk0?ooM@3oonP0ooooooooMOl0oooooonb0?ooW`3ookP0o`02ooooo`09oe3o0?l0Mooo0?ol
ooooooo^o`3oooooo`3of?l0SoooP@3o00;ooooo00Co0?ndoooooooooooooooo0_lP0?l2o`3o5Q;o
oooo00Co09GoofT0oomY0?ooJ@3o5Oooool3ofT0o`_ooooo00Oo803ooooooooooooo6_l0o`3o5_oo
oooo0?nd00;ooooo00?o08oooh40ooooool00_ooool00oo^o`3oooooooooo`08ooooo`?o0?oH1_oo
ool2onko00Sooooo0_m@o`02ooooo`;oP@3o0oooool2ohOo00Gooooo0_l0Sol01?l0okCo0?lFoooo
ooooool2oa[o00Cooooo0_lP0?l?ooooo`03o`2?oooooooooooo00?ooooo00?o0?ndooooooooool0
1oooool00on10?ooooooooooo`04ooooo`Ko09Go4oooool2okP0o`cooooo1_lP0?l4oooooa?o0_l0
1oooool00ol0okCoooooooooo`04ooooo`CoW`3o0_ooool;o`3oY`?o08ooD_l0ojNiooooo`00Dooo
ool00ol0003oooooooooo`03ooooo`03ool0e?oo09Ooo`1]00?om03o02;o203ooooooooo06gooooo
o`3oj_n=0?oooooooi<0oooj0?oob_l0ool0_?l0oj7oo`3Vo`So0?o4o`3oo`2Gool0n?oooooo<P3o
ofl0ool0g_ooTol0o`0Roooo0=Coooooool0l_ooR`3o0;[oolX0ool05_oooooooch0oooooooo0P3o
0_ooool02Omk0?ooooooonP0ooooooooMOl0oooooonb0?oo__l0okP0o`02ooooo`03oe3o0?nho`3o
07Oo00;ooooo00Cok_l0o`3of?l0SoooP@3o0_ooool00ol0okCoooooooooo`02ob00o`03oa[o0?l0
oaKooooo013ooooo00Co09GoofT0oomY0?ooJ@3o0oooool6ofoo00CoG@3o00?oKol0ok;o0?ooool0
2oooool2ofT0o`03o`2Eoooooooooooo00Oooooo00_o803ooooooolJo`3o0?lFohOo0?oooooo0?nd
ooooool0SoooD?l0oh40o`03ooooo`;ok_l03oooool2onko00Sooooo0_m@o`03ooooo`04oh40oooo
ooooooooooooo`;oQol01Oooool2o`2?o`04o`3o]?l0oaKoooooooooo`;o6_l00oooool3ob00oa7o
oooo00?o08ooooooooooool01?ooool00ol0okCoooooooooo`05ooooo`03o`2Eoon10?oo09Go00Go
09Go6oooool2okP0o`Gooooo00?o0_l0o`04ool01?l02?l01?l6ob00ob?o00Co1?nO0?l:o`04ocgo
oooo5ol2o`1do`3oYdGooooo001Cooooo`03o`000?oooooooooo00?ooooo00Coo`3hool0Uooo0;3o
o`1]0_l80?l2ool0K@0_ooooool0on[oooooohd0ooooooooT`3oooX0ooodo`3oo`2lool0i_n/o`3o
2?l0ool0b?oo09Oooooooc80oom_0?ooooooo`3Nooooooooo`3Doooooooo0?;oooooo`2jooo:0?oo
01KooooooolDo`3o?P3oooooool20?ooooooog/0ooooooooM@3oonP0ooooooooMOl0od[o0?nb0?oo
W`3ookP0ooooooooD?l0okSo0?l0Mol00_ooool2ohOo0006o`2?oon10?ooooooooooool0okCooooo
0_lP0?l00ooooooo6_l0o`3o5P0@ooooo`03o`2EoomY0?ooJ@3o00GoKol02?mM0?l3o`04o`SoG@3o
00?o/_l0ooooooooool01Oooool2ofT0o`03o`2Eoooooooooooo00Kooooo00_o803ooooooolJo`3o
0?lFohOo0?oooooo0?ndooooool0SoooD?l0oh40o`04ooooo`03onko0?oooooooooo00Wooooo0oo^
o`09ooooo`04oe3o0?ooooooooooooooo`;oP@3o0_ooool2ohOo00Gooooo0_l0Sol2o`3o]004o`3o
5_oooooooooooa[o00?ooooo0_lP0?lEooooo`03o`2?oooooooooooo00;ooooo2Ol0UOl2ooooo`03
oh40oooooooooooo01Wooooo1ol01?l3okP0o`?o00Co4?ooool6ob00o`Go0?nW2_ooool00ol0okCo
ooooooooo`0?ooooo`?oW`3o0_ooool2o`2?o`?ooooo3ol01?m6ooooobko0_l0A?ooool;okP0oc_o
oooo001Cooooo`03o`000?oooooooooo00?ooooo00Co^03oool0Uooj0?ooo`2`0_oo06d08Ooo0;3o
0?oZo`3oj_ooooooS@3ooooooonC0?oonP3ool[o0?oo0;co0?nQool0i_l8o`3oa?l0ool0Uooo0?So
oooooc80oom_0?oo0=kooi?o0?l08_ooo`3Doooooooo0?;ooh/0o`2jooo:0?oo01Koooooooln0?oo
ooooo`80o`02ooooo`09og/0oome0?ooj03ooooooomeo`3oB_l0ok80oonO0?oo^03o00;ooooo00So
D?l0o`1gooooooooooooohOo0?oooooo08oooh40o`;ooooo00?o0?ndoooooolP0?l00_ooool00olJ
o`3o0?lFooooo`0<ooooo`;o09Go0omY0?l2ok;o00GoG@3o0ol01?l?o`;o0005o`04oomM0?ooG@3o
oed0oom_o`001_ooool00omY0?oo09Goooooo`06ooooo`07ob00oooooooooooooa[o0?l0oaKoQol0
o`3o]002ooooo`03o`2?oon10?oooooo00Cooooo00?ok_l0ooooooooool01_ooool2onko00[ooooo
0_m@o`03ooooo`05oh40oooooooooooooooooon7o`001_ooool01?l0Soooooooo`3o]?l0oaH2oooo
o`;o6_l00_ooool2ob00oaSooooo00Co08ooo`2Eool0UOoo09Go0oooool00ol0okCoooooooooo`06
ooooo`03oh40oooooooooooo013ooooo2?l01?l4o`;o00Kooooo0onh0?l8ooooo`Wo0?nW1Oooool6
ob00o`Oooooo0_l0ok@Eooooo`CoW`3o4_ooool@o`04ofCooooo6?l2o`0EoooooaOo^03oA_ooool0
05?ooooo00?o0000ooooooooool01?ooool00ooo09Ooo`2lohd0o`03o`3ojP0ToonS0?ooooooS@3o
oooooonC0?oonP3oojGo0?oo0;co0?nQool0i_oooooo2?l0oooooooo09Oooooooc80oom_0?oooooo
o`3Nooooooooo`3Doooooooo0?;ooh/0o`2jooo:0?oo01Koooooooln0?ooooooo`3o4?l20?oooooo
og/0oome0?ooj03o0_ooool01?meo`3o/P3ookko0?nh0?l2ooooo`0=oe3o0?l0Mooooooooooooon7
o`3oooooo`2?ooooooooP@3oooooool0okCoooooob00o`02ooooo`03oa[o0?l0oaKooooo00[ooooo
0_l0UOl3ofT0o`;ooooo0omM0?l3o`04oaGooooo0ol2o`03oed0o`Gooooo0_mY0?l00ol0UOoooooo
ooooo`04ooooo`0;ob00oooooooo6_l0o`3o5_n7o`3oooooo`3o]?oooooo08oooooooon10?l01Ooo
ool8onko00[ooooo0_m@o`03ooooo`;oP@3o0_ooool2ohOo00Gooooo0_l0Sol2o`3o]004o`3o5_oo
oooooooooa[o00;ooooo0_lP0?lGooooo`?o09Go00?oooooo`2?ooooool01Oooool00ol0okCooooo
ooooo`06ooooo`03oh40oooooooooooo00Kooooo2Ol01?l3o`;o01;ooooo0_nh0?l6o`3oYaCooooo
1_lP0?l00ol0okCoooooooooo`0Cooooo`;o08oo1?ooool4oil0oakooooo2?l01?mdooooo`?o0_l0
4_nh0?l2o`;o01Gooooo2onO0?lkooooo`00Doooool00ol0003oooooooooo`04ooooo`03ool0Uooo
0;coS@3o00Cooj<002;oS@3oooooooooooooT`3oooX0ooodo`3oo`2lo`3oXOoo0>Ko2?l0olCo0?oo
0<Soo`2Goooooom_0?ooooooo`3NoonCo`3o02;oool0e?ooooooo`3boon;0?l0^_oobP3oo`0Fooln
0?oo5?l0ooooool20?ooooooog/0ooooooooj03o0_ooool04omeo`3oB_l0ok80oonO0?oo^03ooooo
oom@o`3o^?l0o`1gooooooooQol0ooooool0Sooooooooh40oooooooo0?ndoooooolP0?l00_ooool0
0olJo`3o0?lFooooo`0:ooooo`04o`2Eoom_o`3oJ@3oooooo`CoG@3o0_l2o`0Looooo`?o0_l00omM
0?l4ooooo`03ofT0ool0UOoooooo00Gooooo00_o803ooooooolJo`3o0?lFohOo0?oooooo0?ndoooo
ool0Sooooooooh40o`0Dooooo`;oD?l01?ooool01On10?ooooooooooooooooooQol000Gooooo0_l0
Sol2o`3o]003o`3o5_oooooooooo00;o6_l000?oooooob00oolP0?l05_ooool3o`2Eo`Cooooo00?o
08ooooooooooool01?ooool00ol0okCoooooooooo`06ooooo`03oh40oooooooo00Co00Ko00Co1_l2
o`0Cooooo`Oo0?nW1Onh0?lIooooo`;o0?nd1OlP0?l?ooooo`;o08oo2_ooool4oil0ob;ooooo1ol0
1?mUooooo`_o^03o5?ooool4o`;o017oW`3o2ol2o`0kooooo`00Doooool00ol0003oooooooooo`04
ooooo`03ool0Uooo0;coT`3o00CoS@3o0_ooool06onC0?oonP3oooCo0?oo0;co0?nQool0i_oooooo
2?l0oooooooo09Oooooooc80oom_0?ooooooo`3Nooooooooo`3Doooooooo0?;ooh/0o`2jooo:0?oo
01Koooooooln0?ooooooo`80o`02ooooo`0Gog/0oome0?ooj03ooooooomeo`3oB_l0ok80oonO0?oo
^03ooooooom@o`3o^?l0o`1gooooooooQol0ooooool0Sooo0?oHoh40oooooooo0?ndoooooolP0?l0
0_ooool00olJo`3o0?lFooooo`08ooooo`03ofoo0?l0UOoo09Go00;oJ@3o0_mM0?l00ol01?oooooo
ooooo`0Rooooo`;o0_l000?o00Cooed0oomM0?l00oooool00omY0?oo09Goooooo`04ooooo`0;ob00
ooooooooooooo`3o5_ooooooQol0ooooool0okCoooooo`2?ooooool00_n10?lAooooo`03oe3o0?oo
oooooooo00;ooooo0_n10?l2ooooo`;oQol01?ooool2o`2?o`;o0?nd00Goooooo`3o5_oooooooooo
oa[o0002ooooo`03ob00oooooooooooo01?ooooo0ol0UOl8ooooo`03o`2?oooooooooooo00Cooooo
00Co0?ndok;o0?nbo`3o/_l01Ol01?l00on10?ooKol0o`;o0005o`;o017oKol02?l0ojL<ooooo`ko
^03o2_ooool00ol0okCoooooooooo`05ooooo`Go803o2?ooool2o`2?oa3ooooo0onO0?lVooooo`[o
00CoBOoooolBokP0oaSooooo2onO0?mGooooo`00Doooool00ol0003oooooooooo`04ooooo`04ool0
e?oo09OonP3ool[o00Cooooo023oooP0ooX0oonUo`3oooooool0_?oo0>Koooooo`So0?o4o`3oo`38
ool0UoooooooK`3oooooool0g_ooTol0o`0Roooo0=Coooooool0l_ooR`3obP3oo`3o@?l05_oo?P3o
oaCo0?oooooo0P3ooooooomk0?ooooooonP0o`;ooooo00koMOl0od[o0?nb0?oo^03ooooooom@o`3o
^?l0o`1gool0oocoQol0ooooool0Sooo0?oHoh40o`;ooooo00?o0?ndob00ooooool00_ooool00ol0
oaKoooooooooo`05ooooo`?oKol000Co09GooooooomY0?ooG@3o0_l01?lXooooo`04o`;o0?m_o`3o
00Cooed0o`;ooooo00?oJ@3oo`2Eooooool01Oooool01olP0?oooooooa[o0?l0oaKoooooohOo0?l0
ok@00_ooool01?l0Sooooooooe3o0?n10?l>ooooo`;oD?l01?ooool01On10?oooooooooooooooooo
Qol000Cooooo0_l0Sol2o`3o]0;ooooo00Go0?lFoooooooooooo6_l0ooooo`02ob00oa?ooooo0ol0
UOl6ooooo`Ko/_l000?o08oook;o0?m_o`000_m_o`05o`04o`;oKol00ol2o`000on10?oo0_l0oooo
o`03ooooo`_o/_l02?l0ojL7oooooa_oKol05Onh0?l2ooooo`Co803o0_ooool2o`2?oaGooooo0onO
0?l]ooooo`_o00Co;OoooolAokP0oaSooooo4_nO0?lLooooo`_oP@3o>oooool005?ooooo00?o0000
ooooooooool01?ooool01ooo0=Coo`2GooX0oonC0?oob_l0oooooooon0000_nC0?l0;_oj0?oooooo
ool0_?l0oj7oo`3Vooooool8o`3oooooool0Uooooooo<P3oofl0ool0g_ooTol0ooooool08_ooo`3D
ool0l_ooR`3o0;[oolX0ool05_oo?P3ooaCo0?oooooo0P3ooooooomk0?oo0?mOogD0oooX0?oooooo
ogGo0?m:o`3o/P3ookP0ooooooooD?l0oooooonho`3o07Oooooooon7o`3o08ooo`3of?n10?l2oooo
o`03o`3o]?lP0?oooooo00;ooooo00?o6_l0o`3o5_ooool01?ooool2ofoo0003ok;o0?l0UOoo09Go
00;oJ@3o0_l01?lCooooo`ko0?nW2_ooool2o`;o0006o`04oomM0?oooooooooooomY0?oo09Go1Ooo
ool02_lP0?oooooooooooolJo`3o0?lFoooooon7o`3o0?ndooooool0Sol2ooooo`03oe3o0?n10?oo
D?l000Sooooo1?m@o`04ooooo`;oP@3o0_ooool2ohOo00Cooooo00?o08ooooooool0ok@00oooool0
1_l0oaKooooooooooolJo`3oooooob00oa?ooooo0_l0UOl4ooooo`Go/_l000?oooooofoo0?m_o`00
0_m_o`06o`04o`04ooooool2o`3o0_l0o`3o]0?o0_l01?ooool00on10?ooooooooooo`06ooooo`Oo
0?nW0_ooool8ok;o02Oooooo00?o0?ndooooooooool01oooool4ofoo00Go^03o00?oKol0ob00oolP
0?l00_lP0?l=ofoo00_ooooo0onO0?leooooo`co00Co5_ooool;okP0oaSooooo4OnO0?lIoooooaGo
P@3oA_ooool005?ooooo00?o0000ooooooooool01?ooool0=_oX0?ooo`2Gool0_?oj0?ooT`3ool[o
0?nC0?oo01coooX0ooooooooo`2loiWo0?oo0>Koooooo`So0?o4o`3oo`38ool0UoooooooK`3ooooo
ool0g_ooooooo`0Roooo0=Coooooool0l_ooR`3obP3oo`3o@?l05_oo?P3ooaCo0?oooooo0P3ooooo
oomk0?ooooooonP0ooooooooMOl0oooooonb0?ooW`3ookP0oom@o`3ooooookSo0?l0Mooo0?olohOo
0?l0Sooo0?oHoh40o`;ooooo00?o0?ndob00ooooool00_ooool00olJo`3o0?lFooooo`04ooooo`06
ofoo0?nbo`3oooooo`2EoomM0?ooJ@3o0_l01?l@ooooo`Go0?nW3_ooool5o`3oY`Oooooo00?o0_l0
oed0ooooool00_ooool00omY0?oo09Goooooo`04ooooo`04ob00ooooooooooooo`3o5P;ooooo00Co
Qol0o`3o]?oooooo08oo0oooool00on10?ooD?l0oe3o0006oe3o00Gooooo0on10?l3ooooo`03ohOo
0?oooooooooo00;ooooo0_l0Sol01?oooooo0?ndooooooooool2o`3o5P03oooooolJo`3o6_l000;o
803o4_ooool2o`2Eo`?ooooo0onbo`06ofoo00Co00Co0_ooool00ol0Sooo0_l0o`;o0002o`;o00;o
oooo00?o0?ndooooooooool01Oooool00on10?ooooooooooo`06o`3oYa7ooooo2Onbo`0Mooooo`03
o`3o]?oooooooooo017ooooo1onh0?l00olP0?ooooooooooo`08ooooo`[oKol01?ooool4oil0ocgo
oooo3?l01?l:okP0oaSooooo2onO0?lCoooooaOoP@3oFoooool002Sooooo00?ogMgMoeEEEOl00000
0_l000000omEEEGogMgMooooo`05ooooo`03ogMgMol0003oMgMg00Cooooo2ol000000ooMgMgooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00Co^03oool0Uooo0;co04Ko1?oj0?l2ooooo`0[
ool0_?l0oj7oo`3Vo`So0?lbo`3oooooool0UoooooooK`3oooo/0?l0g_ooTol0ooooool08_ooo`3D
ool0l_ooR`3o0;[oolX0ool05_oo?P3ooaCo0?oooooo0P3ooooooomk0?ooooooogD0oooX0?oooooo
ogGo0?m:o`3o/P3ookP0ooooooooD?l0okSo0?oooooo07OoohOo0?oooooo08oooh40o`02ooooo`03
o`3o]?lP0?oooooo00;ooooo00?o6_l0o`3o5_ooool00oooool2ofoo00;ooooo00Co09GoofT0oomY
0?oo00Co3oooool3o`3oYaSooooo0ol0ojL5ooooo`03o`;o0?mM0?oooooo00;ooooo00?oJ@3oo`2E
ooooool00oooool02?lP0?oooooooooooolJo`3o0?lFoooooon7o`3o0?nd0_ooool01?l0Sooooooo
ooooooooool2oh40o`Wooooo0_n10?l4ooooo`;oQol00oooool2o`2?o`03ooooool0okCo0?nd00;o
oooo00Ko0?lFoooooooooooo6_l0oooooolP0?lBooooo`;o09Go0_ooool3ok;o00?oKol00oooool3
o`04o`;ooooo1?l2o`000ol0Soooooooooooo`05ooooo`04o`3o]?ooooooooooooooo`Co0?nW00?o
P@3oo`3oYoooool07oooool:ok;o01;ooooo00?o0?ndooooooooool04?ooool2o`2?o`Oooooo1_nh
0?l?ooooo`SoKol01_nO0?lkooooo`So^03o4Ol01?lAoil0o`cooooo4_n10?mbooooo`009oooool0
2Oo<c<co0000o`000?nj^[[oooooomgMgOlQ8B7o0000olc<c005ooooo`?o00001?ooool00oo<c<co
0000o`000008o`000003oeEEEOoooooooooo00Wooooo00?o0000ooooooooool01Oooool00ooo09Oo
o`3Vool0_003o`16o`;ooooo02_oo`2lo`3oXOoo0>Koooooo`So0?ooW@3oo`3hool0UoooooooK`3o
ooooool0g_ooooooo`0Roooo0=Coooooool0l_ooR`3obP3oo`3o@?l05_oo?P3ooaCo0?oooooo0P3o
og/0ool0oeooooooonP0ooooooooMOl0od[o0?nb0?oo^03ooooooom@o`3o^?l0ooooool0Mooo0?ol
onko0?l0SoooP@3o00;ooooo00?o0?ndob00ooooool00_ooool00olJo`3o0?lFooooo`03ooooo`06
ofoo0?nbo`3oooooooooool0UOooJ@3o0_l01?l=ooooo`?o0?nW7_ooool00ol0ojOoooooooooo`02
ooooo`03o`;o0?l01?ooG@3o00;ooooo00?oJ@3oo`2Eooooool01?ooool02?lP0?oooooooooooolJ
o`3o0?lFoooooon7o`3o0?nd0_ooool00ol0Soooooooooooo`02ooooo`WoP@3o1Oooool00on7o`3o
ooooooooo`02ooooo`04o`2?ooooooooooooo`3o]0?ooooo00Co0?lFoooooooooooo6_l00_lP0?lB
ooooo`03o`2Eoooooooo/_l000;o/_l00om_o`03oooooa7oG@3o0ol0ojL01?l0okCo0?nWo`3oYol0
ojL5ooooo`03oh40oooooooooooo02Sooooo4Onbo`000ol0okCo/_l0ok;o000;ok;o00Gooooo00?o
08ooooooooooool03?ooool00olP0?oo^03ookP0o`04okP0oa7ooooo1_m_o`06oil0obkooooo1onh
0?l7oooooa;oW`3o00?oooooo`04ool01?l03ol01?l;oh40ohCooooo000Vooooo`04omgMgOl0003o
0000okZj^P?ooooo00Cok^k^o`000?l0003ok^k^1?ooool00omgMgOo0000ogMgM`05ooooo`03oiRH
V?l0003o000000So000000?ok^k^ooooooooool02?ooool00ol0003oooooooooo`05ooooo`04ool0
Uom_0?ooo`3Vool0_0?ooooo02ooo`2loiWo0?oo0>Koooooo`So0?lbo`3oooooool0b?oo09OoK`3o
oc80ool0g_ooTol0ooo80?l08_ooo`3Dool0l_ooR`3o0;[oolX0ool05_oo?P3ooaCo0?oooooo0P3o
og/0ool0oeooooooogD0oooX0?ooooooogGo0?nb0?ooW`3ookP0oom@o`3ooooookSo0?l0Mooo0?ol
onko0?l0Sooo0?oHoh40oooooooo0?ndob00o`03ooooo`03oa[o0?l0oaKooooo00;ooooo0_m_o`02
ooooo`04o`;o0?l0UOooJ@3oo`04o`gooooo0_l0ojL>ooooo`Ko03Co3_ooool00ol0ojOooooooooo
o`02ooooo`03o`;o0?l01?ooG@3o00;ooooo00?oJ@3oo`2Eooooool01?ooool01olP0?oooooooa[o
0?l0oaKoooooohOo0?l0ok@00_ooool00ol0Soooooooooooo`0>ooooo`;oQol00oooool2o`2?o`03
ooooool0okCo0?nd00?ooooo00Go0?lFoooooooooooo6_l0ob00o`0Cooooo`04o`2Eoonbo`3o/_l0
ooooo`;oKol00_ooool4oed0o`;ooooo0ol2o`08ooooo`04o`2?ool0ojOo0?nWo`3oY`CoG@3o00?o
0?ndooooooooool01Oooool00on10?ooooooooooo`0hooooo`03o`3o]?oooooooooo00cooooo1?nb
o`000ol0Sooo/_l0ok;o000Aok;o00?o803o1_nh0?lCooooo`CoKol01OnO0?l00om_o`3ooooooooo
o`0Mooooo`Wo^03o00?ooooooil0oonO0?l02onO0?lHooooo`coP@3o2ol01?n4ooooo`009_ooool0
0omEEEGo0000ob4Q8@05ooooo`03oeEEEOl0003oEEEE00gooooo00?oEEEEoc8b<_ooool01Oooool0
0ooMgMgo8B4QogMgM`0:ooooo`03o`000?oooooooooo00Gooooo00?oo`2Gool0n?o4o`001?oo0;`0
;_nIo`3oo`3Voooooooooooo2?l0oonM0?oo0?Soo`2Goooooom_0?ooon`0o`3Noooooooo02;oool0
e?ooooooo`3bofWo0?o:0?oo0?m0och0oooooooo5?l0ooooool20?ooN`3oo`3oGoooooooj03ooooo
oomeo`3oB_l0ok80oonh0?ooD?l0oooooonho`3oooooo`1gool0oocoooooo`2?oon10?ooooooo`3o
]?lP0?l3ooooo`03oa[o0?l0oaKooooo00;ooooo00GoKol0ok;o0?ooooooooooo`;o0002oed0o`03
ofT0oooooooooooo00_ooooo00?o0?nWooooooooool01_ooool8o`0do`Gooooo00?oEol0o`0dool0
=?l01Ol0=?l8ooooo`;o0?nW0oooool00ol2o`3o00Cooed0o`02ooooo`03ofT0oooooooooooo00?o
oooo00So803ooooooooooooo6_l0o`3o5_ooooooQol0o`3o]0;ooooo0_l0Sol=ooooo`04ohOo0?oo
ooooooooooooo`;o08oo0_ooool00ol0okCoooooooooo`02ooooo`03o`3o5_oooooo6_l000;o803o
4_ooool00onbo`3o09Goooooo`03ofoo0005oooooomM0?ooG@3ooed0ool01?l00_ooool3o`;o00So
oooo0ol0ojL00ooooooo08ooooooo`05ooooo`?oG@3o1_ooool00on10?ooooooooooo`0fooooo`03
o`3o]?oooooooooo013ooooo00?o08ooooooooooool04_ooool3ok;o00?o803o0onbo`06okP0oaKo
oooo4?nO0?l4ooooo`?oW`3o2Onh0?l:oil0oaWooooo3?n10?lGooooo`_o00Co=?ooool:oeOo03_o
oooo000Uooooo`04omgMgOl0003o0000ogMgM`Gooooo00CoQhN7o`000?l0003ok^k^3Oooool00olb
<S;oEEEEooooo`05ooooo`03omgMgOmEEEGooooo00Wooooo00?o0000ooooooooool01Oooool0=?oo
09Ooo`3ho`3oXOoo0>KoVOl0ool0_?nIo`3oo`3Vo`3oXOoooooo2?l0oc;o0?oo0?Soo`38ool0Uom_
0?oo<P3oo`3NoonCo`3oolP0o`0Roooo0=Coo`3boon;0?o:0?oo0?m0o`0Fooln0?oo5?l0ooooool2
0?ooN`3oo`3oGoooooooM@3oonP0ooooooooB_l0ok80oonh0?ooD?l0oooooonho`3oooooo`1gool0
oocok_l0o`2?oon10?ooooooo`3o]?lP0?l4ooooo`03oa[o0?l0oaKooooo00;oKol00oooool01?l2
o`3oG@3oo`04oomY0?l<ooooo`;o0?nW1_ooool3o`0do`Gooooo2_l0od`6ooooo`?o03Co1oooool2
o`3oY`;ooooo00?o0_l0o`04oomM0?l00_ooool00omY0?ooooooooooo`03ooooo`05ob00oooooooo
6_l0ooooool0oaH00_ooool01Ol0okCoQol0oooooooooooo08oo00[ooooo0_n7o`001?oooooo08oo
o`2?ool0Sol3ooooo`04o`3o]?ooooooooooooooo`;o0?lF00?ooooooa[o0?lP0?l04_ooool00onb
o`3o09Goo`2Eo`02ofoo0004oooooomM0?ooG@3ooed0o`;o00Co00?oooooo`;o0?l2o`001OmY0?l4
ooooo`?o0?nW1?ooool00ol0Soooooooooooo`05ooooo`03o`3o]?ooooooG@3o00Gooooo00?oP@3o
ooooooooool0=Oooool00ol0okCoooooooooo`0@ooooo`03o`2?oooooooooooo01Wooooo0_lP0?l0
0ooooooo/_l0ok;o0004ok;o00Co^03o00?o/_l0ooooooooool06oooool3ofoo00?oW`3o1Onh0?l0
0om_o`3oooooooooo`0Pooooo`WoP@3o;_ooool<o`04obSoEol0AOooool002Gooooo00CoQhN7o`00
0?l0003o^[Zj1Oooool01?nj^[[o0000o`000?nHV9P=ooooo`03onk^k_l0003oMgMg017ooooo00?o
0000ooooooooool01Oooool01?oo09Ooo`3hofl0ool0oj43ool0iP0Qo`3oXOooooooa?l0o`So0?lb
o`3oo`3hool0Uom_0?oo<P3oooo/0?l0g_ooooooooo80?oo0=Coooooool0l_mYo`3obP3oo`3o@?ln
0?oooooooaCo0?l20?ooN`3oooooool0oeooooooonP0ooooooooMOl0od[o0?nb0?oo^03o00;ooooo
00[o^?l0ooooool0Moook_l0o`2?ool0omSoP@3oooooool0okCo803o0oooool01OlJo`3o0?lFoooo
oom_o`3o/_l000?ooooo00Co0_l0oed0ool01?ooJ@3o2oooool2o`3oY`Gooooo0ol0=?l3ooooo`Go
0?m<2_ooool6o`3oC0?ooooo0ol0=?l6ooooo`09o`3oYoooooooooooo`;o0?l01?ooG@3oooooool0
UOooJ@3o00Cooooo00Go803ooooooooooooo6_l0o`3o5P03ooooo`;o0?nd0_ooool3o`2?o`Kooooo
00CoQol0oooooooooooo08oo1?ooool2o`3o]0?ooooo00Go0?lFoooooooooooo6_l0ob00o`0Aoooo
o`;o/_l000Co09Goofoo0?oooooooooo0_mM0?l2ooooo`03o`04oomY0?ooJ@3o00?oJ@3o1Oooool4
ofT0o`Oooooo00?o08ooooooooooool01_ooool00ol0okCooooooed0o`05ooooo`03oh40oooooooo
oooo03?ooooo00?o0?ndooooooooool04?ooool00ol0Soooooooooooo`0>ooooo`ko0?nK0_lP0?l9
o`3oVbCo^03o7_l0oi/4ooooo`KoP@3o9_oooolHoeOo00Gooooo4Ol01?mLooooo`009Oooool01?m4
A4Co0000o`000?o<c<`5ooooo`04omgMgOl0003o0000oeEEE@kooooo00?oc<c<o`000?nHV9P04?oo
ool00ol0003oooooooooo`05ooooo`03ool0e?oo09Ooo`3h00Co0?nQ0_o4o`00:_l8o`3o<_l0ool0
n?oo0<Soo`2Gofl0oolb0?oo0=kooi?o0?oob03o02;oool0e?oo0?;oJOl0olX0ool0od3o01Kooch0
oolDo`3oooooo`80oomk0?oo0?mOoooooome0?ooj03ooooooom:o`3o/P3ookP0oom@o`3ooooookSo
0?oooooo07Ooo`3oo?oooooo08oooh40oooooooo0?ndob00o`?ooooo00Go6_l0o`3o5_ooooooKol0
ok;o0002ooooo`;o0_l000?oG@3oo`04oomY0?l02_ooool2o`3oY`Cooooo0ol0=?l3ooooo`?o0?m<
5Oooool3o`3oC0;ooooo00?oEol0o`0dooooool01?ooool01_l0ojOooooooooooooooooo0_l0oed0
o`;ooooo00?oJ@3oooooooooool00oooool01OlP0?oooooooa[o0?oooooo0?lF00?ooooo00?oQol0
o`3o]?n7o`000_ooool:o`2?o`?ooooo0_l0ok@4ooooo`05o`3o5_oooooooooooa[o0?lP0?l04Ooo
ool01Onbo`3o09Goo`2Eoom_o`3ooooo00;oG@3o0_ooool3ofT0o`03o`;o0?oooooooooo00Kooooo
0_l0ojL2ooooo`;oJ@3o1oooool00ol0Soooooooooooo`05ooooo`04o`3o]?oooooooooooed0o`Co
oooo00?oP@3oooooooooool0<_ooool00ol0okCoooooooooo`0;ooooo`Go0?nK00?o08ooo`3oVol0
oi/03ol0oi/@o`3oJ`?o803o<Ol0of/:ooooo`_oKol01_n10?m1o`3oVaWooooo5_l01?l00ooooooo
0?m<o`3oC008o`3oC3_ooooo000Uooooo`03ob4Q8Ol0003o000000Oooooo0_l000000olb<S;ooooo
ooooo`0=ooooo`03ohN7Qol0003oc<c<00oooooo1?l00004ooooo`06okP0oooo09Ooo`3hofl0ooo4
o`3o0?nQ0_o4o`007ol8o`3ooooooc;o0?oo0?Soo`2Gofl0oolb0?oo0=kooi?o0?ooooooolP0ool0
e?ooooooo`3bofWo0?o:0?oo0?m0och0oooooooo5?l0o`80oomk0?ooooooo`3oGoooooooj03ooooo
oomeo`3oB_l0ok80oonh0?l00_ooool02Onho`3o07Ooo`3oo?o^o`3o08ooo`3of?n10?oo0?ndob00
o`03ooooo`05oa[o0?oooooo0?lFofoo0?nbo`000_ooool01Ol2o`3ooooooed0ool01?ooJ@3o00Wo
oooo0_l0ojL4ooooo`;o03Co0oooool3o`3oC003oooooolPo`3o8?l001;o8?l01_ooool2o`3oC003
oooooomGo`3o03Co00Gooooo00Wo0?nWoooooooooooo0_l0ofoo0?mM0?ooooooo`2EoomY0?l01?oo
ool01_lP0?oooooooooooolJo`3oooooo`3o5PCooooo0_l0ok@5ohOo00Sooooo00?o0?ndoooooooo
ool00oooool00ol0oaKoooooooooo`02ob00oa3ooooo0_nbo`001Ol0UOooKol0ooooooooooooG@3o
00;ooooo0_mY0?l2o`;o00Oooooo0ol0ojL6ooooo`03ofT0oooooooooooo00Cooooo00?o08oooooo
ooooool01_ooool01?l0okCooooooooooomM0?l4ooooo`03oh40oooooooooooo033ooooo00?o0?nd
ooooooooool01?l0of/8o`3oV`Cooooo00?o08ooooooooooool08oooool2ob00oaOooooo1onbo`0A
ooooo`oo0?m[1_n10?lIo`3oJ`;oEol0;?ooool_o`3oV`_o00Co>oooool002Gooooo0ol00007oooo
o`?o00004?ooool00om4A4Co0000omgMg@0>ooooo`03o`000?oooooooooo00Kooooo00Coo`2Gol@0
oooo0?So2?l00_ooool06_l8o`3ooooooc;o0?oo0?Soo`38ool0Uooooooo<P3oo`3NooooooooolP0
o`0Roooo0=Coo`3bofWo0?o:0?oo0?m0och0oooooooo5?l0oooooomk0?ooooooo`3oGoooooooj03o
0_ooool00om:o`3o/P3ookP0o`02ooooo`09okSo0?n7o`3o07Ooo`3oo?l0Sooooooooh40oooooooo
803o00?ooooo00Go6_l0ooooool0oaKoKol0ok;o0002ooooo`05o`;o0?ooooooG@3oo`04oomY0?l0
2Oooool00ol0ojOoooooooooo`02ooooo`04oeOo0?l0=?ooooooooooo`?o0?m<1?lPo`0Dooooo`;o
8?l01_ooool01?l0odcoooooooooool0=?l5ooooo`05o`3oYoooooooooooo`;o0?mM0?l00_ooool0
0omY0?ooooooooooo`03ooooo`05ob00oooooooooooooa[o0?l0oaH01_ooool00ol0okCooooooooo
o`08ooooo`;o0?nd1Oooool01?l0oaKooooooa[o0?lP0?lAooooo`05ok;o0?l0UOoo09Goofoo0?oo
ool00_mM0?l2ooooo`03ofT0oooooooo0_l000Oooooo0_l0ojL:ooooo`03ofT0oooooooooooo00?o
oooo00?o08ooooooooooool01_ooool01?l0okCoooooooooooooool2oed0o`;ooooo00?oP@3ooooo
ooooool09oooool7o`3oJ`03o`3oVol0okCo0?nK00Ko0?nK2oooool00ol0Soooooooooooo`0Voooo
o`?o803o6oooool;ok;o00oooooo1_n10?l5ooooo`_oEol03oooool^o`3oJ`?o0?m<L_ooool002Go
oooo0ol00007ooooo`?o00004?ooool00oo^k^ko0000ob4Q8@0>ooooo`03o`000?oooooooooo00Ko
oooo00Coo`3Dool0Uooo0?SoK`3o0_l8o`00:OooU`3o<_l0oooooooo0?Soo`2Goooooolb0?oo0=ko
oi?o0?ooooooolP0ool0e?ooooooo`3bolX0ool0^_oo0?m0och0oooooooo5?l0o`80oomk0?oooooo
o`3oGoooooooj03ooooooom:o`3oj?l0ok80oonh0?oooooookSo0?oooooo07Ooo`3oo?o^o`3o08oo
oh40oooooooo803o00?ooooo00Go6_l0ooooool0oaKoKol0ok;o0002ooooo`05o`;o0?ooooooG@3o
o`2EoomY0?l02Oooool01Ol0ojOoooooooooooooooooEol000;o03Co00?oooooo`3oC?l0od`00_lP
o`07oooooa;o0?o`0_ooool3ob3o00Cooooo00Co0?m<oooooooooooo03Co1Oooool01ol0ojOooooo
ooooool2o`3oG@3ooooooomY0?l01_ooool01OlP0?oooooooa[o0?oooooo0?lF00Gooooo0ol0ok@6
ooooo`;o0?nd1Oooool2o`3o5P03oooooolJo`3o803o013ooooo0_nbo`001Ol0UOooKol0oooooooo
ooooG@3o00;ooooo0_mY0?l2o`;o00Oooooo00?o0?nWooooooooool02oooool2ofT0o`Cooooo00?o
08ooooooooooool01_ooool00ol0okCoooooooooo`02ooooo`04oed0oooooooooooooh40ob?ooooo
1Ol0of/2ooooo`Go0?nK00Co0?ndoooooooooooooooo3olPo`000ol0Sooo8?l0ob3o0007ob3o02?o
oooo0olP0?lSooooo`Wo/_l01_n10?l;oeOo00?o/_l07ooooolGo`3oC0oooooo5ol0of/SofT0oc_o
oooo000Uooooo`?o00001oooool3o`00017ooooo00?oIVIVo`000?mVIVH03Oooool00ol0003ooooo
ooooo`06ooooo`05ool0e?oo09Ooa03oool0n?m_0?l00_lbo`006?ooooooo`3hool0b?oo09Oooooo
oc80ool0g_ooooooooo80?l08_ooo`3Dool0l_mYo`3obP3oo`3o@?ln0?oooooooaCo0?ooooooN`3o
ooooool0oeooooooonP0o`;ooooo00?oB_l0ok80oonh0?l00_ooool02Onho`3oQol0o`1gool0ooco
08oooooooon10?oo803oo`3o]002ooooo`05oa[o0?ooooooooooo`3o5_nbo`000_ooool01_l2o`3o
oooooed0ool0UOoo00CoofT0o`Sooooo00?o0?nWooooooooool00_mGo`001Ol0=?ooooooo`3oC?l0
odco8?l000Oooooo0ol0oo0Booooo`Go0?o`0_lPo`03ooooo`04o`3oC?ooooooooooo`0do`Cooooo
00Go0?nWoooooooooooo0_l0oed0o`02ooooo`03ofT0oooooooooooo00?ooooo00Ko803ooooooooo
oooo6_l0ooooool0oaH6ooooo`Oo0?nd1_ooool01Ol0oaKooooooooooolJo`3o803o013ooooo00Go
/_l0ooooool0UOooKol0ooooo`02oed0o`;ooooo00?oJ@3oooooool2o`001oooool2o`3oYa3ooooo
00GoJ@3oooooooooooooooooo`2?o`08ooooo`03o`3o]?oooooooooo00?ooooo00?oG@3ooooooon1
0?l05oooool8ob3o00Co0?m[00?o8?l0o`3oVol0oi/01?l0oi/4ob3o0003o`3o]?lPo`3o8?l000;o
8?l03_ooool00ol0Soooooooooooo`08oooooa[o8?l03?ooool3ob00ob?ooooo00?oEol0oh40oon1
0?l00on10?l5oeOo00oooooo5?nbo`0;o`3oC1Cooooo5om_o`000oooooooJ@3oofT0o`0?ofT0oaSo
oooo2ol0of/kooooo`009Oooool3o`0000Oooooo0ol0000Aooooo`04olc<c?l0003o0000omgMg@co
oooo00?o0000ooooooooool01_ooool00ooo0=CobP3oool0U`05ool0n00Vofl0oooo09Oooooooc80
ool0g_ooTol0oooooooob03oo`3Doooooooo0?;obP3oo`2jooln0?oo01KooooooolDo`3oN`3oo`3o
4?oooooo0?mOoooooooX0?oooooood[o0?oooooo^03ooe3o0?oooooo^?l0ohOo0?l0Mooo0?oloooo
ool0SoooP@3oob00ool0ok@3ooooo`04oa[o0?oooooo0?lFok;o00;ooooo00Ko0_l0oooooomM0?oo
09Goo`04oomY0?l8ooooo`04o`3oYooooooooooooeOo00;o03Co0_l0od`7ooooo`?o0?o`1_ooool;
oeL0o`Wooooo00?o0?o`oooooolPo`000oooool01?l0odcoooooooooool0=?l4ooooo`07o`3oYooo
ooooooooo`;o0?mM0?ooooooofT0o`06ooooo`03ob00oooooooo6_l000;ooooo0_l0oaH?ooooo`;o
0?lF0_ooool00olJo`3o803oooooo`0?ooooo`06ok;o0?oooooo09Goofoo0?ooooooG@3o0_ooool2
ofT0o`;o0_l01oooool00ol0ojOoooooooooo`0@ooooo`05ofT0ooooooooooooooooool0Sol02Ooo
ool00ol0okCoooooooooo`02ooooo`04oed0oooooooooooooh40o`Wooooo3OlPo`04ooooo`;o0?m[
1ol0oi/4ooooocko07go2olPo`04ooooo`;o803o6?ooool4oeOo00KoP@3o8Oooool<o`3oC0?ooooo
5onbo`06oooooaOoJ@3o5_m_o`1Iooooo`009Oooool01?lQ8B7o0000o`000?o^k^h6ooooo`;o0000
00?o8B4Qooooooooool04?ooool2o`000003ofIVI_oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00onh0?ooo`3Dool0U`05ooooo`0>ol@0oooo09Oooooooc80oonCo`3oooooooo80?l08_oo
o`3Dool0l_ooR`3obP3oo`3o@?ln0?l2ooooo`0;oaCo0?mk0?ooooooo`3oGoooooooj03ooooooom:
o`3oMOl0ok80oonh0?l00_ooool02?nho`3o07Ooooooool0ooco08oooooooon10?oo803o0oooool0
1?lJo`3oooooo`3o5_nbo`02ooooo`06o`;o0?ooooooG@3oo`2Eool01?ooJ@3o2?ooool01Ol0ojOo
oooooooooolPo`3o03Co00;o0?m<1_ooool3o`3ol0?ooooo1omG0?l:o`1mo`OoE`3o0oooool3o`3o
l0?ooooo00?o0?m<ooooool0=?l01?ooool01Ol0ojOoooooooooool2o`3oG@3o00;ooooo00?oJ@3o
ooooooooool00oooool01?lP0?oooooooooooolJo`03ooooo`03o`3o5_oooooooooo00_ooooo00Co
0?lFoooooooooooooooo0_lP0?l@ooooo`04ok;o0?oooooo09Goofoo00;oG@3o0_ooool00omY0?oo
ooooo`;o0007ooooo`;o0?nW5?ooool01OmY0?oooooooooooooooooo08oo00Sooooo00?o0?ndoooo
ooooool00oooool01?mM0?oooooooooooon10?l3ooooo`Go8?l03Oooool00ol0of_o0?nKo`3oV`02
o`3oV`co07go1?ooool00ol0okCoooooooooo`0@ooooo`03o`2?oooooooooooo02Cooooo2?l0OOl3
ooooo`Ko8?l00_lP0?l2ob3o00kooooo1?mGo`06oh40oa_ooooo3?l0od`Qooooo`_oJ@3o;Onbo`0E
ofoo04Cooooo000Uooooo`04odA4A?l0003o0000okZj^PGooooo00Co^[Zjo`000?l0003oEEEE2_oo
ool00omgMgOok^k^ooooo`05ooooo`;o000000?o410@ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`04obH0oooo0=Coo`2Gol@0o`;ooooo0_o40?l01?oo09Oooooooc80oonCo`02ooooo`0D
ooo80?l08_ooo`3Dool0l_o:0?oo0;[ooch0ool05_oooooooaCo0?mk0?oo0?l@ooooool0oeoooooo
onP0ooooooooB_l0oooooonh0?l2ooooo`09okSo0?n7o`3o07Ooo`3oo?l0Sooooooooh40oolP0?oo
0?nd00;ooooo00Co6_l0oooooom_o`3o0?lF0_ooool01_l2o`3ooooooed0ool0UOoo00CoofT0o`So
oooo00?o0?nWooooooooool00_l0=?l00ol0odcoooooooooo`04ooooo`;o0?o`0oooool3oeL0o`Co
07go1ol0of/2ooooo`Oo0?m[0ol0OOl00oooooooE`3ooeL0o`04ooooo`07o`3ol?oooooooooooooo
ool0odcoooooo`0do`04ooooo`07o`3oYoooooooooooo`;o0?mM0?ooooooofT0o`06ooooo`03ob00
oooooooooooo00;o6_l00_ooool00ol0oaKoooooooooo`09ooooo`05o`3o5_oooooooooooa[o0?lP
0?l04?ooool2ok;o0004ooooool0UOoooooooed0o`;ooooo0_mY0?l00ooooooo0_l0ooooo`06oooo
o`03o`3oYooooooooooo01Cooooo00GoJ@3oooooooooooooooooo`2?o`09ooooo`03o`3o]?oooooo
oooo00?ooooo00?oG@3oob3o0?n10?l00olPo`0=ooooo`04o`3oJol0oi_o0?nKo`3oV`Ko07go3ooo
ool00ol0okCoooooooooo`0@ooooo`03o`2?oooooooooooo02gooooo1ol0OOl4ooooo`?o803o1olP
o`04oeOo00KoP@3o6?ooool9o`3oC27ooooo3?mY0?lcooooob?o0?o`>oooool002Gooooo00CoQhN7
o`000?l0003oZJVY1Oooool01?nj^[[o0000o`000?nHV9P:ooooo`03oc8b<_nHV9Sooooo00Cooooo
00Coc<c<o`000?l0003o00003?ooool00ol0003oooooooooo`07ooooo`03ool0e?o:0?ooo`2G00;o
a03o00Goo`38ool0Uooooooooooooc80o`02ooooo`08ooo80?l08_ooo`3Dool0l_o:0?oooooooch0
ool05_l2ooooo`0;og/0ool20?ooooooo`3oGoooooooj03ooooooom:o`3oMOl0ok80oonh0?l00_oo
ool02?n7o`3o07Ooonko0?l0ooco08oooh40oolP0?oo0?nd0oooool00olJo`3oooooo`3o5P02oooo
o`06o`;o0?ooooooG@3oo`2Eool01?ooJ@3o2?ooool01_l0ojOoooooob3o0?l0=?ooooooo`3oC0Go
oooo0_l0oo02ooooo`?oE`3o0_l0OOl3o`3oJ`Gooooo2ol0oi/3ooooo`;o0?m[0ol0OOl00omG0?oo
ooooooooo`02ooooo`07o`3ol?ooooooooooooooool0odcoooooo`0do`03ooooo`05o`3oYooooooo
ooooo`;o0?mM0?l00_ooool00omY0?ooooooooooo`04ooooo`05ob00oooooooooooooooooolJo`00
0_ooool2o`3o5PKooooo0ol0oaH2ooooo`;o803o4?ooool01_nbo`3oooooooooool0UOoooooooed0
o`;ooooo00CoJ@3ooooooooooooo0_l01oooool00ol0ojOoooooooooo`0Fooooo`04ofT0oooooooo
ooooo`2?o`Wooooo00?o0?ndob3o0?lPo`000olPo`001?ooooooG@3ooooooon10?l:ooooo`03o`3o
Jol0oi_o0?nK00Ko07go5?ooool00ol0okCoooooooooo`0Aooooo`03o`2?oooooooooooo03Cooooo
1ol0OOl2ob00o`?oEol01_n10?l4ob3o01Cooooo1_l0od`Qooooo`WoJ@3o5ooooolXo`3ol5kooooo
000Uooooo`04omgMgOl0003o0000ofIVIPGooooo00CoMgMgo`000?l0003ok^k^2_ooool00omgMgOo
0000onk^kP04ooooo`04oeEEEOl0003o0000o`0000cooooo00?o0000ooooooooool01oooool00ooX
0?ooo`3Doc80o`03ool0U`03ooooool0g_oo<P3o00?ooooo01CoolP0o`0Roooo0=Coo`3bolX0ool0
^_oo?P3oo`0Foooooooo5?l0og/0ool0oa3oooooo`3oGoooooooj03ooooooom:o`3o__l0okP0o`;o
oooo00Wo^?l0ohOo0?l0Mooo0?olo`2?ooooooooP@3oob00ool0ok@00_ooool03?lJo`3oooooofoo
0?l0oaKoooooo`;o0?ooooooG@3oo`2Eool01?ooooooofT0o`Oooooo00Ko0?nWoooooolPo`3o03Co
ooooool0od`4ooooo`;o0?o`0_ooool2oeL0o`?o07go0_l0of/3ooooo`Go0?nK2oooool5o`3oV`;o
oooo00Co0?m[o`1moomG0?ooE`3o0oooool01ol0oo3ooooooooooooooooo0?m<ooooool0=?l00ooo
ool01ol0ojOoooooooooool2o`3oG@3ooooooomY0?l01oooool01?lP0?oooooooooooolJo`04oooo
o`Ko0?lF0oooool00olJo`3o803oooooo`0@ooooo`06ok;o0?ooooooooooo`2EooooooooG@3o0_oo
ool01?mY0?ooooooooooool2o`07ooooo`03o`3oYooooooooooo01Sooooo00?oJ@3oooooool0Sol0
1?ooool5ob3o0003o`3o]?oooooooooo00Cooooo00?oG@3ooooooon10?l01_ooool2o`3oV`Go07go
6Oooool00ol0okCoooooooooo`0Aooooo`03o`2?oooooooooooo03Oooooo1?mGo`06oh40o`So07go
0_ooool:ob3o00Gooooo1Ol0od`Pooooo`OoJ@3o5?ooool<o`3ol8Kooooo000Vooooo`03oeEEEOl0
003o8B4Q00Gooooo00?o8B4Qo`000?mEEED02oooool01ooMgMgo0000ob4Q8Onj^[[oooooonk^k_mV
IVH00ol000000olb<S;oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Coj03oool0e?o:
0?oo<P3o0ol0g_l03?lb0?ooooooooooooooooooolP0o`0Roooo0=Coo`3bolX0oooooooo?P3oo`0F
o`;ooooo00_oN`3oo`80oooooooo0?mOoooooooX0?oooooood[o0?meo`3o/P3ookP0o`02ooooo`08
ohOo0?l0Moook_l0o`2?ooooooooP@3oob00ool0ok@3ooooo`0;oa[o0?m_o`3o0?lFooooool2o`3o
oooooed0oooooooo00CooooooomY0?l01oooool01_l0ojOo8?l0ob3o0?l0=?ooooooo`3oC0?ooooo
0_l0oo02ooooo`;oE`3o0_l0OOl3o`3oJ`;ooooo0ol0oi/@oaX0o`Gooooo0ol0oi/2o`3oJ`06o`1m
oomG0?ooooooooooool0oo3o8?l00oooool00ol0odco03Coooooo`02ooooo`08o`3oYooooooooooo
o`;o0?mM0?ooooooofT0ool0UOl7ooooo`03ob00oooooooooooo00;o6_l02Oooool00olJo`3o803o
ob00o`0Aooooo`06ok;o0?ooooooooooo`2EooooooooG@3o0_ooool01?mY0?ooooooo`;o0?l2o`07
ooooo`03o`3oYooooooooooo01Wooooo00CoJ@3oob3o0?lPo`3o08oo0olPo`06ooooo`03o`3o]?oo
oooooooo00Cooooo00?oG@3ooooooon10?l00ol0oi/4o`1moagooooo00?o0?ndooooooooool04Ooo
ool00ol0Soooooooooooo`0`ooooo`coP@3o1Oooool3ob00o`Kooooo2Ol0OOl2ooooo`Ko0?m<1_lP
o`0Jooooo`GoJ@3o3oooool<o`3ol9;ooooo000Vooooo`04omgMgOl0003o0000okZj^P?ooooo00Co
^[Zjo`000?l0003ok^k^3?ooool00omVIVKo0000o`000006o`000003ojVYZOoooooooooo00[ooooo
00?o0000ooooooooool01oooool00onh0?ooo`3DolX0o`04oc80o`0Hooo/0?ooooooooooooo80?oo
oooo02;oool0e?oo0?;obP3ooch0ool0od3o01Kooooooomk0?oo0P3oo`3o4?oooooo0?mOoooooooX
0?ooB_l0ogGo0?nno`3o^03o0_ooool02?nho`3oQol0o`1gool0ooco08oooooooon10?oo0?nd0ooo
ool00olJo`3oKol0o`3o5P02ooooo`06o`;o0?mM0?ooooooo`04ooooooooJ@3o1oooool01?l0ojOo
8?l0oeOo0?l0=?l2o`3oC0?ooooo00?o0?o`ooooooooool00_mG0?l01?l0OOoo0?m[o`3oJol0of/3
ooooo`Go6P3o0olno`0<ooooo`03ocko0?lJ0?oo6P3o00?o6P3o0oooool2o`3oV`03ooooool0OOoo
E`3o00;ooooo00?o0?o`ob3o0?ooool00_ooool00ol0odco03Coooooo`02ooooo`07o`3oYooooooo
ooooo`04oomM0?ooooooofT0o`08ooooo`04ob00ooooooooooooooooo`;o6_l01Oooool2oa[o0003
ob00oooooooooooo013ooooo00Ko/_l0oooooooooooo09GooooooomM0?l2ooooo`03ofT0oooooooo
0_l000Sooooo00?o0?nWooooooooool05_ooool5ob3o0003ofT0oooooooo08oo00Wooooo00?o0?nd
ooooooooool00_ooool01Ol0of_o0?nKo`3oVomM0?ooP@3o00?o07go8?ooool00ol0okCooooooooo
o`0Aooooo`03o`2?oooooooooooo02Wooooo2?n10?l00omGo`3oooooooooo`0Aooooo`;o803o2Ooo
ool4o`3oC0So07go1_ooool<ob3o00Wooooo1OmY0?l9ooooo`_o0?o`W_ooool002Oooooo00Ko^[Zj
o`000?l0003o^[Zjoooooonj^[X2o`000003olc<c?oooooooooo00_ooooo00?ok^k^oc8b<_l00000
1Ol000000omEEEGoooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00CoP@3oool0e?oo0?;o
JOl00_ook004ooooo`08ooo80?l08_ooo`3Dool0l_o:0?oooooooch0ool05_l2ooooo`0;og/0ool2
0?ooooooo`3oGoooooooj03ooooooom:o`3oMOl0oil0oonh0?l00_ooool02?n7o`3o07Ooonko0?l0
Sooooooooh40oolP0?oo0?nd0_ooool02olJo`3oKol0ok;o0?l0oaKoooooo`;o0?mM0?ooooooo`04
ooooooooJ@3o00Oooooo00Go0?nWoooooomGo`3o03Coo`3oC004ooooo`04o`3ol?ooooooE`3ooeL0
o`;o07go00Co0?m[oooooooooooooooo0olJ0?l01?oooooo?_l0ocko0?lno`0Fooooo`03oaX0ooln
o`3o?_l000;ooooo00Co0?nKooooool0of_oE`3o0_ooool01ol0oo3o8?l0oooooooooooo0?m<oooo
ool0=?l00_ooool02?l0ojOoooooooooool2o`3oG@3ooooooomY0?oo09Go2?ooool2ob00o`?ooooo
1OlJo`000ooooooo803oooooo`0Aooooo`07ok;o0?ooooooooooo`2EooooooooG@3oooooo`02ofT0
o`03ooooool2o`3ooooo00Oooooo00?o0?nWooooooooool04Oooool6ob3o00Gooooo00?oJ@3ooooo
ool0Sol02Oooool00ol0of_o0?ndo`3oV`02o`3oV`Co07go00?oG@3ooh40ooooool08?ooool00ol0
okCoooooooooo`0Aooooo`03o`2?oooooooooooo01_ooooo3on10?l4oeOo01[ooooo0_lP0?l00ooo
oooo0?m<o`3oC004o`3oC0cooooo2?l0OOl:ooooo`Go8?l01?mY0?l2ob3o00co0?o`ZOooool002So
oooo00?ogMgMoeEEEOl000000_l000000omEEEGogMgMooooo`0?ooooo`06oiRHV?lQ8B7o0000o`00
0?lb<S;oZJVY3_ooool00ol0003oooooooooo`07ooooo`04ofT0oooX0?ooo`3DofWo00Gooooo01Go
olP0o`0Rool0]?ooo`3Dool0l_ooR`3o?P3oo`3o@?l05_ooooooog/0ool20?oo0?l@ooooool0oeoo
ooooonP0oom:o`3oMOl0oe3o0?nh0?l00_ooool02?n7o`3oooooo`1gool0ooco08oooh40oolP0?oo
0?nd0oooool02_lJo`3oKol0o`3o5_oooooo0_l0oed0oooooooo00CooooooomY0?l6ooooo`;o8?l0
00Co0?nWoeOo0?l0=?oo0?m<1?ooool01_l0oo3ooooooeL0oooooooo07goo`3oJ`?ooooo0_lJ0?l0
1?oooooo?_l0ocko0?lno`04oooooa3o00[o1_ooool3oaX0o`06ocko0?oooooo0?nKo`3oVol0of_o
E`3o0_ooool01_l0oo3o8?l0oooooooooooo0?m<o`0do`?ooooo00Co0?nWooooool2o`3oG@3o0_oo
ool00omY0?ooooooooooo`07ooooo`?o803o1?ooool3ob00oa?ooooo00[o/_l0oooooom_o`3o09Go
oed0ooooooooJ@3oo`04oooooooo0_l02?ooool00ol0ojOoooooooooo`0>ooooo`Co8?l03?ooool0
0omY0?ooooooo`2?o`03ooooo`Co0?m[00?o0?nKo`1mool0OOl00ol0OOl4ooooo`03oed0oooooooo
P@3o023ooooo00?o0?ndooooooooool04?ooool00ol0Soooooooooooo`0Cooooo`WoP@3o3?ooool3
oeOo01cooooo1?l0od`3ob00oaSooooo2_l0OOl00oooooooJ@3oofT0o`02ofT0o`Ko0?o`00?ooooo
ob3o0?lPo`002_lPo`2Xooooo`00Doooool00ol0003oooooooooo`07ooooo`04obH0oooX0?ooo`3D
olX0o`;oJOl00oooool05Ol08_oo0;Coool0e?oo0?;obP3oooooooln0?oo01Kooooooomk0?oo5?l0
o`80ool0oa3o0?mOoooooooX0?oooooood[o0?meo`3oW`3ookP0o`02ooooo`08ohOo0?oooooo07Oo
o`2?ooooooooP@3oo`3of?l0ok@2ooooo`08oa[o0?m_o`3o/_l0o`3o5_l2o`3ooooooed0ool01?l2
ooooo`03ofT0oooooooooooo00?ooooo00Ko8?l0ooooool0ojOoEol0o`0dool0od`4ooooo`03o`3o
l?mG0?ooE`3o00;o07go0oooool2oaX0o`03o`3oVolno`3o?_l000;ooooo1Ol02_l00ooooooo043o
o`10o`0<o`10o`04ooooool02_oo00[oo`0:o`Kooooo0_lJ0?l2ooooo`0;o`3oVol0OOooE`3ooooo
ool0oo3oooooob3o0?oooooo0?m<ooooool0=?l00_ooool02?l0ojOoooooooooool2o`3oG@3ooooo
oomY0?oo09Go2oooool4ob00oaGooooo00[o/_l0oooooom_o`3o09Gooed0ooooooooJ@3oo`04oooo
oooo0_l02?ooool00ol0ojOoooooooooo`0=ooooo`;o8?l04?ooool00omY0?ooooooo`2?o`02o`3o
J`03o`3oVol0OOoo07go00?o07go0_ooool00ol0okCoooooooooo`05ooooo`03oed0oon10?oooooo
01kooooo00?o0?ndooooooooool04?ooool00ol0Soooooooooooo`0Aooooo`?oP@3o4_ooool3oeOo
01_ooooo1?l0od`7ooooo`;o803o7?ooool5ofT0o`[o07go3Oooool;ob3o09gooooo001Cooooo`03
o`000?oooooooooo00Sooooo00Coj03oool0e?l08_oobP3o1?mYo`003Ol08_ooo`3Doooooooo0?;o
oh/0och0ool0od3o01Kooooooomk0?oo0P3oo`3o4?l0oel00_ooool01OoX0?ooB_l0ogGo0?m@o`3o
^03o00;ooooo00SoQol0ooooool0Mooo08ooo`3oo?n10?oo803oo`3o]0?ooooo00[o6_l0ok;o0?l0
oaKoooooo`;o0?mM0?oo09Goo`04ooooooooJ@3o1Oooool01_lPo`3oooooo`3oYooooooo03Coo`3o
C0?ooooo0_l0oo000omG0?ooooooo`1mo`03ooooo`;o6P3o00Co0?nKocko0?oooooooooo0ol02_l0
0ooooooo043oo`10o`03o`10o`kooooo1?l0@?l3o`0:o`Gooooo00go6P3ooooooooooooo0?nKo`1m
oomG0?ooooooo`3ol?oooooo8?l0ooooool0odco03Co00?ooooo00Co0?nWooooool2o`3oG@3o0_oo
ool00omY0?ooooooooooo`0Qooooo`0:ok;o0?ooooooKol0o`2EoomM0?ooooooofT0ool01?oooooo
o`;o00Sooooo00?o0?nWooooooooool03?ooool00omGo`3o8?l0oeOo0002oeOo00kooooo0_l0of/0
0omY0?oo07goo`1mo`02o`1mo`Oooooo00?o0?ndooooooooool01_ooool00omM0?ooP@3oooooo`0L
ooooo`03o`3o]?oooooooooo017ooooo00?o08ooooooooooool03Oooool4oh40oa;ooooo0omGo`0J
ooooo`Co0?m<3Oooool3ob00oaCooooo00?o0?o`ofT0oomY0?l00_mY0?l?ooooo`[o07go3_ooool<
ob3o097ooooo001Cooooo`03o`000?oooooooooo00Sooooo00Coj03oo`80oooo0=CobP3o0ooob000
5ol08_oo0;Coool0e?oo0?;ooh/0och0ool0^_oo01Kooooooomk0?oo5?l0o`80ool0oa3o0?mOoooo
oooX0?ooB_l0onSo0?meo`3oW`3ookP0ooooooooQol000;ooooo00Go07Ooo`2?ooooooooP@3oo`3o
f003ooooo`0:oa[o0?nbo`3oooooo`3o5_l2o`3oG@3oooooool01?ooooooofT0o`Gooooo00Ko8?l0
oooooooooooo0?nWoeOo0?l0=?l3ooooo`03o`3ol?mG0?ooE`3o00;o07go0_ooool2oaX0o`;o0?nK
0_ooool2o`0:o`04ooooool0@?oo043oo`10o`Gooooo3olV0?l3ooooo`?o043o0_l02_l4ooooo`0=
oaX0oooooooo0?nKo`3oJol0OOooE`3oooooool0oo3o8?l0ooooool0odcoooooo`0do`02ooooo`08
o`3oYoooooooooooo`;o0?mM0?ooooooofT0ool0UOlQooooo`0:ok;o0?ooooooKol0o`2EoomM0?oo
ooooofT0ool01?ooooooo`;o00Sooooo00?o0?nWooooooooool02Oooool3oeOo00;o8?l01?ooool3
oeOo00Sooooo0_l0of/01Ol0oi_o07goo`1moomY0?oo08oo00_ooooo00?o0?ndooooooooool01Ooo
ool00omM0?ooP@3oooooo`0Kooooo`03o`3o]?oooooooooo017ooooo00?o08ooooooooooool02_oo
ool4oh40oa?ooooo0omGo`0Jooooo`?o0?m<5?ooool3ob00o`gooooo00?o0?o`ofT0oomY0?l00_mY
0?lMooooo`So07go4_ooool;ob3o08Kooooo001Cooooo`03o`000?oooooooooo00Sooooo00Go^03o
onP0oooo0=Co?P3oolX0o`02o`0Ro`0=o`2doooo0=Coo`3booooooln0?oo0;[oo`3o@?l05_ooN`3o
ooooool20?oo0?l@o`3oG`02ooooo`05onP0oom:o`3oMOl0oil0oonh0?l00_ooool02?n7o`3ooooo
o`1gool0Sooo0?oloh40ool0omSo0?nd0_ooool02_lJo`3oKol0ooooool0oaKo0_l0oooooomM0?oo
00CooooooomY0?l5ooooo`07ob3o0?ooooooooooo`3oYomGo`3o03Coo`3oC002ooooo`05o`3ol?mG
0?ooooooo`1mool0of/00_ooool00olJ0?ooooooo`3oV`02ooooo`;o00[o0ol0@?l5ooooo`?o9P3o
3oooool5obH0o`;ooooo00?o043oo`0:ooooool00oooool01OlJ0?ooooooo`3oVol0of_oE`3o00;o
oooo00Go0?o`ob3o0?oooooo0?m<o`0do`02ooooo`08o`3oYoooooooooooo`;o0?mM0?ooooooofT0
ool0UOlPooooo`0:ok;o0?ooooooKol0o`2EoomM0?ooooooofT0ool01?ooooooo`;o00Wooooo00?o
0?nWooooooooool01_ooool3oeOo00?o8?l02Oooool3oeOo00;ooooo0ol0of/3o`1mo`?ooooo00?o
J@3oo`2?ooooool02_ooool00ol0okCoooooooooo`05ooooo`03oed0oon10?oooooo01Wooooo00?o
0?ndooooooooool04Oooool00ol0Soooooooooooo`08ooooo`?oP@3o5?ooool3oeOo01[ooooo0ol0
od`Jooooo`?o803o1_ooool00ol0oo3oJ@3oofT0o`02ofT0obWooooo2?l0OOlEooooo`co8?l0N_oo
ool005?ooooo00?o0000ooooooooool02?ooool01On10?ooj03oool0e?oo0?;o?P3o00;obP3o01Ko
o`3Dool0l_ln0?oo?P3oooooool0^_oo01Kooooooomk0?oo0P3oooooool0oa3o0?mOoooooooX0?oo
B_l0onSo0?m@o`3o^03ook80ooooooooQol00_ooool01Ol0Mooo08oooooooon10?oo0?oH00?ooooo
00Wo6_l0ok;o0?l0oaKo0_l0oooooomM0?ooooooo`04oomY0?l01Oooool01olPo`3oooooooooool0
ojOoEol0o`0dool0od`00_ooool01_l0oo3oE`3oooooool0OOoo0?m[ooooo`;o6P3o0_l0oi/00ooo
oooo00[oo`0:o`02o`10o`Gooooo0olV0?lGooooo`04obH0ooooooooooooo`10o`;o00[o0oooool0
3?lJ0?ooooooo`3oVol0OOooE`3oooooool0oo3o8?l0ooooool0odcoooooo`0do`;ooooo00So0?nW
oooooooooooo00Cooed0ooooooooJ@3oo`2Eoakooooo00Go/_l0oooooom_o`3o09Gooed0o`02oooo
o`03ofT0oooooooo0_l000Wooooo00?o0?nWooooooooool01?ooool3oeOo0003oooooolPo`3o8?l0
00kooooo0ol0of/3o`1mo`Kooooo00?oJ@3oo`2?ooooool02_ooool00ol0okCoooooooooo`05oooo
o`03oed0ooooooooP@3o01Sooooo00?o0?ndooooooooool04Oooool00ol0Soooooooooooo`07oooo
o`;oP@3o5Oooool2oeOo01_ooooo0_l0od`Pooooo`?o803o1?mY0?leooooo`So07go6Oooool<ob3o
06kooooo001Cooooo`?o00002?ooool00omY0?ooj03oo`0Fo`02ool0e00>o`2doooo0=Coo`3Doch0
ooooR`3oooooo`2jool05_ooooooog/0oooooooo0P3oo`3o4?l0oel2ooooo`05onP0oooXo`3oMOl0
oil0oonh0?l00_ooool02?n7o`3oooooo`1gool0Sooo0?oloh40ool0omSo0?nd0_ooool02_lJo`3o
/_l0ooooool0oaKo0_l0oed0oooooooo00CooooooomY0?l5ooooo`06ob3o0?ooooooooooo`3oYol0
=?oo0?m<0_ooool02_l0oo3oE`3oooooool0OOoo0?m[oooooolJ0?ooooooo`3oVolno`02o`0:o`03
o`10oooooooooooo00?ooooo0olV0?lKooooo`?o9P3o00?oooooo`10ool02_l00_ooool02?lno`3o
6P3oooooool0oi_o07gooeL0oooooooo0?o`0_ooool01Ol0odco03Cooooooooooooo0?nW00;ooooo
00Go0_l0oed0ooooooooJ@3oo`2Eo`0Mooooo`05ok;o0?ooooooKol0o`2EoomM0?l00_ooool00omY
0?oo00Coo`;o0009ooooo`03o`3oYooooooooooo00Cooooo00?oEol0ooooooooool00_lPo`0>oooo
o`;o0?m[0ol0OOl9ooooo`03ofT0ool0Sooooooo00_ooooo00?o0?ndooooooooool01Oooool00omM
0?ooP@3oooooo`0Fooooo`03o`3o]?oooooooooo017ooooo00?o08ooooooooooool01_ooool2oh40
oaGooooo0_mGo`0Kooooo`;o0?m<8?ooool00ol0oo3oJ@3oofT0o`02ofT0o`?o803o?_ooool8o`1m
oagooooo3?lPo`1Rooooo`00Doooool00ol0003oooooooooo`08ooooo`04ofT0oooX0?oo0P3ooooo
o`;oo`3D00?ooooooon;0?ooR`000_ooool04Ol0^_oo01Kooooooomk0?oo0P3oooooool0oa3o0?mO
oooooooX0?ooB_l0oooooom@o`3o^03ook80ooooooooQol000;ooooo00Go07Ooo`2?ooooooooP@3o
o`3of002ooooo`0:ofoo0?lJo`3oooooo`3o5_l2o`3ooooooed0ool01?ooooooofT0o`Gooooo00Ko
8?l0oooooooooooo0?nWo`0dool0od`2ooooo`05o`3ol?mG0?ooooooo`1mool0of/00_lJ0?l01Ooo
oooo0?nKo`0:ool02_oo043o00Gooooo0_lV0?l:ooooo`co>?l02oooool2obH0o`0?o`10ool02_oo
oooooooooolJ0?ooooooo`3oVol0of_o07gooeL0ool0oo3o8?l0ooooool0odco03Co00?ooooo00So
0?nWoooooooooooo00Cooed0ooooooooJ@3oo`2Eoa_ooooo00Go/_l0oooooom_o`3o09Gooed0o`02
ooooo`03ofT0ool01?oo0_l000Wooooo00?o0?nWooooooooool00oooool2oeOo00;ooooo00?o8?l0
ooooooooool03Oooool3o`1mo`?ooooo00?oEol0ooooooooool01oooool00omY0?oo08ooooooo`0:
ooooo`03o`3o]?oooooooooo00Kooooo00?oG@3ooh40ooooool05?ooool00ol0okCoooooooooo`0A
ooooo`03o`2?oooooooooooo00Gooooo0_n10?lEooooo`;oEol06_ooool3o`3oC1kooooo00?o0?o`
ofT0oomY0?l00_mY0?l7ooooo`?o803o@oooool7o`1mob;ooooo2olPo`1Gooooo`00Doooool00ol0
003oooooooooo`08ooooo`06obH0oooX0?oo0P3oo`3og_ooooooN`3o0_ooR`02ooooo`08o`2jool0
5_ooN`3oog/0ool20?oo5?l0o`3o4?l0oel2ooooo`0BonP0oooXo`3oD?l0oil0oonh0?ooooooohOo
0?nho`3oooooo`1gool0Sooo0?oloh40ool0omSo0?ndoooooom_o`3o6_l00_ooool01ol0oaKooooo
oed0oooooooo00CooooooomY0?l01?ooool01_lPo`3oooooooooool0ojOo03Coo`3oC0?ooooo00Go
E`3oooooool0OOoo0?m[oaX0o`02ooooo`;o00[o0_l0@?l4ooooo`;o9P3o2?ooool4ocSo00cooooo
1?lho`09ooooo`03obH0ool0@?oo00[o00;ooooo00Oo6P3oooooool0oi_o0?m[oeL0oooooooo0?o`
00;ooooo00Go0?m<o`0dooooooooooooo`3oY`02ooooo`05o`;o0?mM0?ooooooofT0ool0UOl06_oo
ool01Onbo`3oooooofoo0?l0UOooG@3o00;ooooo00?oJ@3oo`04ool2o`002Oooool00ol0ojOooooo
ooooo`03ooooo`05oeOo0?oooooooooooooooolPo`003_ooool2o`1mo`03o`3oVooooooooooo00Co
oooo00?oEol0ooooooooool01_ooool00omY0?oo08ooooooo`0;ooooo`03o`3o]?oooooooooo00Go
oooo00?oG@3ooh40ooooool04oooool00ol0okCoooooooooo`0Aooooo`03o`2?oooooooooooo00Co
oooo0_n10?lEooooo`;oEol06_ooool2o`3oC1kooooo1?mY0?l>ooooo`?o803oAoooool:o`1mob?o
oooo3?lPo`1;ooooo`00Doooool00ol0003oooooooooo`09ooooo`04onP0ool20?oo01Koo`3ogP;o
N`3o0_ooool00ol0omkoN`3oog/0o`02ooooo`0=o`80oooooooo0?l@o`3oGoooooooj03ood[o0?oo
ooooD?l0okP0oonb0?ooooooohOo0002ooooo`05o`1gool0ooco803ooh40ool0omP00_ooool02_lJ
o`3oooooooooool0oaKooooooed0oooooooo00CooooooomY0?l4ooooo`06ob3o0?oooooooooooooo
ool0=?oo0?m<0oooool00ol0oo3oE`3oo`1mo`02oaX0o`05ooooool02_oo00[oooooool0@?l01?oo
ool2obH0o`Kooooo1?lho`0Dooooo`Co>?l01_ooool02olV0?oo043oo`0:oooooooo6P3oocko0?oo
oooo0?nKo`3oJomG0?oo0?o`00;ooooo00Go0?m<o`0dooooooooooooo`3oY`03ooooo`05o`04oomM
0?ooooooofT0ool0UOl06?ooool01Onbo`3oooooofoo0?l0UOooG@3o00;ooooo00CoJ@3oo`04oooo
oooo0_l02?ooool00ol0ojOoooooooooo`03ooooo`05oeOo0?oooooooooooooooolPo`003_ooool0
0ol0OOoo0?nKo`3oV`08ooooo`03oeOo0?oooooooooo00Gooooo00?oJ@3oo`2?ooooool03?ooool0
0ol0okCoooooooooo`05ooooo`03oed0oon10?oooooo017ooooo00?o0?ndooooooooool04_ooool0
1?l0Soooooooooooooooool3oh40o`[ooooo;?l0l?lIooooo`CoJ@3o5Oooool4ob00odgooooo2ol0
OOlTooooo`_o8?l0@?ooool005?ooooo00?o0000ooooooooool02Oooool01_oX0?oo0?mOo`80ool0
5_oo0?oNooooo`CoN`3o0_ooool01?l20?oo5?l0o`3o4?l0oel2ooooo`0BonP0ooooooooD?l0oil0
oonh0?ooooooohOo0?nho`3oooooo`1gool0Sooo0?oloh40ool0okCo0?oHoooooom_o`3o6_l00_oo
ool01ol0oaKooooooed0ool01?oo09GooooooomY0?l00oooool01_lPo`3ooooooooooooooooo0?nW
o`0do`?ooooo00Co0?o`oeL0ool0OOoo6P3o0_ooool01?l02_oo0?nKooooool0@?l3ooooo`;o9P3o
1?ooool4ocSo01cooooo0_lho`04ooooo`03obH0oooooooo00[o00;ooooo00_o6P3ooooooooooooo
0?nKoeL0oooooooo0?o`ooooool0odcoooooo`0do`02ooooo`08o`3oYoooooooooooo`04oomM0?oo
ooooofT0ool0UOlGooooo`05ok;o0?m_o`3oKol0o`2EoomM0?l00_ooool01?mY0?oo00Coooooool2
o`08ooooo`03o`3oYooooooooooo00?ooooo00GoEol0ooooooooooooooooob3o000=ooooo`;o07go
00?o0?nKooooooooool02?ooool00omGo`3oooooooooo`06ooooo`03ofT0oooooooooooo00_ooooo
00?o0?ndooooooooool01Oooool00omM0?oooooooh40o`0@ooooo`03o`3o]?oooooooooo01;ooooo
00?o08ooooooooooool00_n10?l00ooooooo0?3oo`3`o`0:o`3`o`Wooooo0_mGo`0Iooooo`;o0?m<
1_oooolAo`3`o`Gooooo0omY0?l00ol0oo3oooooooooo`0Jooooo`?o803oEOooool<o`1moagooooo
2ol0=?lkooooo`00Doooool00ol0003oooooooooo`09ooooo`05ok80oooX0?oo0P3oo`3o@?l05_l0
0_l0^_l2o`0Fo`;ooooo00Co0P3ooaCo0?oooooo0?mO0_ooool02?oX0?ooj?l0oe3o0?nO0?oo^03o
ok80ooooooooQol00_ooool02?l0Mooo0?olob00oon10?oo0?oHoooooom_o`3o6_l00_ooool01ol0
oaKooooooed0oooooooo00CooooooomY0?l00oooool01olPo`3ooooooooooooooooo0?nWo`0dool0
od`00_ooool01?l0oo3oE`3oo`1moolJ0?l2ooooo`04o`0:oooooooo0?nKo`10o`?ooooo00?o9P3o
ooooooooool00_ooool2ocSo02;ooooo00?o>?l0ooooooooool00_ooool01_lV0?ooooooo`0:oooo
oooo6P3oocko00;ooooo00?o0?nKoeL0ool0oo000_ooool01Ol0odco03Cooooooooooooo0?nW00;o
oooo00Ko0_l0oed0oonbo`3oJ@3oooooool0UOlDooooo`;o/_l000CoKol0ooooool0UOooG@3o0_oo
ool01?mY0?oo00Coooooool2o`08ooooo`03o`3oYooooooooooo00?ooooo00GoEol0oooooooooooo
ooooob3o000=ooooo`03o`1mool0oi_o0?nK00cooooo00?oEol0ooooooooool01Oooool00omY0?oo
08ooooooo`0<ooooo`03o`3o]?oooooooooo00Go043o00?oG@3oo`10oon10?l08?l0@?l3o`3`o`04
o`2?ool0l?ooP@3ooh40o`?o0?3o4oooool2oeOo01Wooooo0_l0od`Iooooo`03o`3`oomY0?ooJ@3o
00;oJ@3o3?l0l?lGooooo`Co803oGOooool00ol0OOoo03Coo`0do`0Jo`0dodKooooo001Cooooo`03
o`000?oooooooooo00Wooooo00CoP@3oonP0ool0oeoo0P3o1?l05_l3ooooo`04o`80oolDo`3o0?l@
o`3oG`;ooooo01Coj03ooe3o0?meo`3oW`3ookP0ooooooooQol0okSo0?oooooo07Ooo`2?oolP0?oo
P@3oo`3o]?l0omSoKol0ok;o0?lJo`3oooooo`3o5P;ooooo00CoG@3oo`04ooooooooJ@3o1?ooool0
1_lPo`3oooooooooool0ojOo03Coo`3oC0;ooooo00Co0?o`oeL0oooooooo6P3o0_ooool01?l02_oo
ooooo`10ool0@?l3ooooo`04obH0ooooooooooooooooo`;o>?l04_ooool6o`0^o`gooooo00?o>?l0
ooooooooool00_ooool03olV0?ooooooo`0:oooooooo6P3oocko0?oooooo0?nKoeL0oooooooo0?o`
ooooool0odco03CooeOo0002ooooo`08o`3oYoooooooooooo`04oomM0?ooooooofT0ool0UOlCoooo
o`03ok;o0?ooooooKol000;o09Go00OoG@3oooooooooooooJ@3oo`04oooooooo0_l000Wooooo00?o
0?nWooooooooool00_ooool01OmGo`3ooooooooooooooooo8?l000cooooo0_l0OOl00ol0oi_ooooo
ooooo`0=ooooo`03oeOo0?oooooooooo00Cooooo00?oJ@3oo`2?ooooool02?ooool7o`10o`Kooooo
00?oG@3ooooooon10?l03?ooool00ol0okCoooooooooo`0:ooooo`Go0?3o00Coooooo`10ool0@?oo
043o0_n10?l7o`10oa3ooooo00?oEol0ooooooooool05_ooool3o`3oC1Sooooo1?mY0?l2o`3ol0ko
oooo3?l0l?l?ooooo`?o803oA?oooolGo`0do`_ooooo3?l0OOl6ooooo`[o?_l0>oooool005?ooooo
00?o0000ooooooooool02Oooool01OmY0?ooj03oo`3oGooooooo0P3o00;o0?m00oooool01?l20?oo
5?l0ooooool0oel2ooooo`08onP0ooooooooD?l0oil0oonh0?oo/P3oohOo0?nho`02ooooo`0Ao`1g
ooooooooP@3oooooool0omSoooooofoo0?lJo`3oooooo`;o0?l0oaKooooooed0ool01?oo09Gooooo
oomY0?l00oooool01_lPo`3oooooooooool0ojOo03Coo`3oC0;ooooo00Wo0?o`oeL0oooooooo6P3o
o`3oJooooooo00[oooooool0@?l01?ooool00olV0?ooooooooooo`02ocSo00kooooo1ol0;_l5oooo
o`Oo02ko1oooool01Olho`3ooooooooooooooooo9P3o00;ooooo00?o00[ooooooolJ0?l00_ooool0
0omG0?ooooooo`3ol002ooooo`05o`3oC?l0=?ooooooooooool0ojL00_ooool01_l2o`3oG@3ook;o
0?mY0?ooooooo`2Eoa7ooooo00Ko/_l0oooooom_o`3o09GooooooomM0?l2ooooo`04ofT0oooooooo
00Coo`;o00Wooooo00?o0?nWooooooooool00oooool01?mGo`3ooooooooooolPo`0<ooooo`03o`1m
ool0oi_o0?nK013ooooo00?oEol0ooooooooool01Oooool00omY0?ooooooooooo`03ooooo`Co043o
1_ooool00ol0okCoooooooooo`04ooooo`04oed0oooooooooooooh40o`[ooooo00?o0?ndoooooooo
ool01_ooool5o`3`o`Sooooo00?oP@3oooooooooool01oooool8o`10o`Kooooo0_mGo`0Gooooo`;o
0?m<6?ooool3ofT0o`03ooooool0oo3o0?o`01gooooo4_l0l?l3ob00ocGooooo3?l0=?lTooooo`[o
?_l02ol0OOm0ooooo`00Doooool00ol0003oooooooooo`09ooooo`04ofT0oooX0?oo0?l@o`3oG`;o
0P3o0oooool01Ol20?oooooooaCo0?l0oa3o0?mO00;ooooo017oj03ooe3o0?meo`3oW`3ookP0oooo
ooooQol0okSo0?oooooo07Ooo`2?oolP0?ooP@3oo`3o]?l0omSoKol0oa[o0002ooooo`07o`3o5_oo
ooooG@3oooooool01?ooooooofT0o`03ooooo`06ob3o0?ooooooooooooooool0=?oo0?m<0_ooool0
2Ol0oo3oE`3ooooooolJ0?oo0?m[ooooool02_ooooooo`10o`04ooooo`04obH0ooooooooooooocSo
00gooooo0ol0;_l3ooooo`go0?3o0oooool00ol0;_ooooooooooo`05ooooo`07ocSo0?oooooooooo
oooooolV0?ooooooo`0:o`02ooooo`09oaX0oooooooo0?nKoeL0ool0oo3o8?l0ooooool0odco03Co
00;ooooo00[o0?nWooooooooooooooooo`04oomM0?ooooooofT0oooooooo09Go3oooool01_nbo`3o
ooooofoo0?l0UOoooooooed0o`;ooooo00CoJ@3oooooool01?oo0_l02Oooool00ol0ojOooooooooo
o`03ooooo`04oeOo0?ooooooooooob3o00cooooo00?o07goo`3oVoooool02oooool8oaX0o`Kooooo
00?oJ@3oo`10ool0@?l00ol0@?l;ooooo`03o`3o]?oooooooooo00Cooooo00CoG@3ooooooooooooo
P@3o2?ooool00ol0okCoooooooooo`03ooooo`Co0?3o2oooool2oh40oa;ooooo1_l0@?lHooooo`03
o`3oC?oooooooooo01Gooooo0omY0?l01?oooooo0?o`o`3ol?l0oo0aooooo`?o0?3o1?lP0?l:o`3`
oakooooo2Ol0=?lTooooo`co?_l05Oooool5o`1moc_ooooo001Cooooo`03o`000?oooooooooo00Wo
oooo00GoJ@3ook80oooX0?oo0?mOooooo`04o`80o`04oooooolDo`3oooooo`3oG`;ooooo00Soj03o
oe3o0?meo`3oW`3ookP0oonb0?ooQol0okSo00;ooooo017o07Oooooooon10?ooooooo`3of?m_o`3o
/_l0oa[o0?oooooo0_l0o`3o5_ooooooG@3oo`04ool0UOooooooofT0o`02ooooo`06ob3o0?oooooo
ooooooooool0ojOo03Co0oooool02?mG0?oooooooaX0ool0of_oooooo`0:oooooooo043o0oooool2
obH0o`03oooooolho`3o>?l000_ooooo0ol0;_l2ooooo`Co0?3o3Oooool3o`3`o`04ooooool0;_oo
02koo`0^o`Gooooo01;o>?l0ooooooooooooooooobH0oooooooo00[ooooooolJ0?ooooooo`3oVomG
0?ooooooo`3ol?oooooo0?m<o`0doomGo`02ooooo`09o`3oYoooooooooooo`;o0?mM0?oo/_l0oooo
oomY0?oo09Go00kooooo00Ko/_l0oooooom_o`3o09GooooooomM0?l2ooooo`04ofT0oooooooo00Co
o`;o00Wooooo00?o0?nWooooooooool00oooool01?mGo`3ooooooooooolPo`08ooooo`Co0?m<00?o
07goo`3oVoooool03?mG0?l8ooooo`Co6P3o0_l0@?l00omY0?oo08ooooooo`0>ooooo`03o`3o]?oo
oooooooo00Cooooo00GoG@3ooooooooooooooooooh40o`06ooooo`03o`3o]?oooooooooo00Co0?3o
3Oooool2oh40o`03ooooool0Sooooooo01Gooooo00?oEol0ooooool0@?l01Ol0@?l@ooooo`;o0?m<
5Oooool3ofT0o`;ooooo0_l0oo0kooooo`?o803o1oooool;o`3`o`gooooo1_l0=?lLoooooa7o?_l0
HOooool005?ooooo00?o0000ooooooooool02Oooool01OlV0?ooP@3oonP0ool0oa3o0?mO00Cooooo
00?o5?l0ooooool0oel00_ooool06ome0?ooj03ooooooonO0?oo^03ook80oon7o`3ooooookSo0?oo
ooook_l0o`1goolP0?ooP@3oo`3o]?l0omSo/_l0oa[o0?oooooo0_l0o`3o5_ooooooG@3oo`04ool0
UOooooooofT0o`02ooooo`06ob3o0?ooooooooooooooool0ojOo03Co0oooool02?l0oo3oE`3ooaX0
ool0of_oooooo`0:oolno`3o043o0oooool01?lV0?oooooooooooolho`0:ooooo`?o02ko0oooool2
o`3`oaCooooo0ol0l?l00ooooooo02koooooo`04ooooo`0AocSo0?oooooooooooooooolV0?oo043o
o`0:oooooooo6P3oooooool0OOooE`3oo`3ol?lPo`3oooooo`3oC?l0=?l00_ooool02_l0ojOooooo
ooooooooooooG@3oofoo0?nbo`3oJ@3oooooool0UOl<ooooo`06ok;o0?ooooooKol0o`2Eoooooooo
G@3o0_ooool01?mY0?ooooooo`04ool2o`09ooooo`03o`3oYooooooooooo00?ooooo00CoEol0oooo
oooooooo8?l01oooool2o`3oC0?ooooo00Co07gooeL0oomG0?ooE`3o0_l0=?l01?oooooo6P3ooaX0
oolJ0?l6ooooo`03oeL0oooooooooooo00?ooooo00?o043oo`0:ool02_l00ol02_l3oaX0o`03ofT0
ool02_oo00[o00Oo00[o1oooool2o`3o]0Gooooo00GoG@3ooooooooooooooooooh40o`04ooooo`Co
0?3o4?ooool01?n10?ooooooooooool0SolEooooo`;oEol02?ooool6o`10o`Wooooo00?o0?m<oooo
ooooool04_ooool3ofT0o`?ooooo0_l0oo10ooooo`Go803o3Oooool7o`3`o`Ko03Co1?l0l?l=oooo
oa7o?_l0L_ooool005?ooooo00?o0000ooooooooool02Oooool01_l04?ooP@3ookP0oooX0?oo0?l@
o`3oG`;ooooo0_lDo`003?l0oeoooooooooooom:o`3oj03ooooooomeo`3oW`3ookP0oonb0?oooooo
okSo00;ooooo01?o07Ooob00oon10?ooooooo`3of?m_o`3o/_l0oa[o0?l2o`3oooooo`3o5_mM0?oo
ooooo`04ool0UOooooooofT0oooooooo8?l000?ooooo00?o0?nWo`0dooooool00_ooool02?l0oo3o
E`3ooaX0ool0of_oooooo`0:oolno`3o043o0oooool01?lV0?ooooooocSo0?lho`0:ooooo`04o`0^
ooooooooooooooooo`?o0?3o6Oooool2o`3`o`;o02ko1?ooool04Olho`3ooooooooooolV0?oooooo
o`0:oooooooo6P3oooooool0oi_oE`3oo`3ol?lPo`3oooooo`3oC?l0=?ooEol000;ooooo00[o0?nW
oooooooooooo00Cooed0oooooooo/_l0ofT0oooooooo09Go2_ooool01_nbo`3oooooo`2Eool0UOoo
oooooed0o`;ooooo00CoJ@3oooooool01?oo0_l02Oooool00ol0ojOoooooooooo`03ooooo`04oeOo
0?ooooooooooob3o00Oooooo00Co0?m<oooooooooooooooo0_l0=?l00omG0?ooooooooooo`02oooo
o`;o6P3o0_l0=?l00ooooooo0?m<ooooo`05ooooo`03oeL0ool02_oo00[o00?o00[o0_ooool00omG
o`3oooooooooo`03ooooo`03ofT0oolJ0?oooooo00Oooooo0ol02_l6ooooo`03o`3o]?oooooooooo
00?ooooo00GoG@3ooooooooooooooooooh40o`03o`3`oa;ooooo0_n10?l2ooooo`03o`2?oooooooo
oooo01?ooooo00?oEol0ooooooooool03_ooool5o`10o`;ooooo0_l0od`Cooooo`;oJ@3o1?ooool2
o`3ol4Oooooo1_lP0?l8ooooo`Ko03Co2_oooolBo`3`ogkooooo001Cooooo`03o`000?oooooooooo
00[ooooo00CoJ@3ook80oooX0?oooooo1Ol0oel2ooooo`09od[o0?me0?ooj03ooooooonO0?oo^03o
ok80oon7o`3o^?l000;ooooo01?o08ooo`1goolP0?ooP@3oo`3o]?l0omSo/_l0oa[o0?oooooo0_l0
o`3o5_ooooooG@3oo`04ool0UOooooooofT0oooooooo8?l000Cooooo00go03Cooooooooooooooooo
o`3ol?mG0?oo6P3oo`3oJooooooo00[oocko0?l0@?oo0?nK00;ooooo00?o9P3ooooooolho`002_oo
ool2o`0^o`04ooooool0l?oo0?3oo`3`o`Sooooo2?mSo`0>ooooo`03o`3`oooooooo02ko00?ooooo
017o>?l0ooooooooooooooooobH0ool0@?oo00[ooooooolJ0?oo0?nKoeL0oooooooo0?o`ooooool0
odcoooooo`0do`02ooooo`08o`3oYoooooooooooo`;o0?l01?ooG@3ook;o0?mY0?l2ooooo`03o`2E
oooooooooooo00Kooooo00Ko/_l0ooooool0UOooKol0oooooomM0?l2ooooo`04ofT0oooooooo00Co
o`;o00Wooooo00?o0?nWooooooooool00oooool01OmGo`3ooooooooooooooooo8?l000Gooooo0_l0
od`01?oooooo03Coo`0dool0=?l2oeL0o`Cooooo00?o6P3oooooooooool00_ooool00ol0=?oo0?m<
ooooo`02ooooo`?o00[o00?o043ooeL0oomG0?l01Oooool00omGo`3oooooooooo`03ooooo`03ofT0
ool0Sooo6P3o00[ooooo0ol02_l4ooooo`;o0?nd0oooool01OmM0?oo0?3oo`3`ool0l?oo0?nd00;o
P@3o4Oooool2oh40o`Cooooo00?o08ooooooooooool04Oooool2oeOo01Kooooo1?l0@?l@ooooo`?o
J@3o1?ooool2o`3ol4oooooo1OlP0?l3o`0do`Sooooo2_lno`0@ooooo`_o0?3oLoooool005?ooooo
00?o0000ooooooooool02_ooool01?mY0?ooP@3ookP0oooX0?l5o`3o400;oooooom:o`3oj?l0onP0
ooooooooMOl0oil0oonh0?oo/P3ooooooonho`000_ooool03_l0Mooo803ooh40oooooooo0?oHok;o
0?oooooo6_l0o`;o0?oooooo0?lFoed0ool01?oo09Go0_ooool00omY0?ooooooob3o0003ooooo`0=
o`3oYol0=?ooooooooooool0oo3oE`3ooaX0ool0OOooooooo`0:oolno`3o043oo`3oV`02ooooo`03
obH0oooooooo>?l000Wooooo0_l0;_l2ooooo`03o`3`oooooooooooo00?ooooo0_mSo`0>oego00?o
Hol02_ooool00ol0l?ooooooo`0^o`03ooooo`0CocSo0?oooooooooooooooolV0?oo043oo`0:oolJ
0?ooooooo`3oVomG0?oo0?o`ob3o0?oooooo0?m<o`0doomGo`3oooooo`3oY`03ooooo`05o`04oooo
ooooG@3ook;o0?mY0?l00_ooool2o`2Eo`Gooooo00Ko/_l0ooooool0UOooKol0oooooomM0?l2oooo
o`04ofT0ool01?oo00Coo`;o00[ooooo00?o0?nWooooooooool00_ooool01OmGo`3ooooooooooooo
oooo8?l000Cooooo0_l0od`2ooooo`06o`0dooooooooE`3ooeL0oooooooo0?nK0_ooool2oaX0o`Ko
oooo00Co03Coo`0:ool02_oo00[o0_l0@?l4ooooo`03oeL0oooooooooooo00?ooooo00?oEol0oooo
ooooool00oooool00omY0?oooooooaX0o`0<ooooo`?o00[o0oooool4o`3`o`03oed0ool0okCo0?nd
00?ooooo00?oP@3oooooooooool02oooool3oh40o`Gooooo00?o08ooooooooooool04Oooool00omG
o`3oooooooooo`0Eooooo`;o0?m<0oooool4o`10o`[ooooo0_mY0?l5ooooo`;o0?o`Coooool5o`0d
o`;ooooo1_lP0?l5ocko02Gooooo4_l0l?mQooooo`00Doooool00ol0003oooooooooo`0:ooooo`06
ofT0oon10?oo/P3ookP0oooX0?ooD?l01?m:o`002Om@o`3oM@3oonP0oomeo`3oW`3ookP0oonb0?oo
oooookSo0002ooooo`0Co`2?ool0Mooo803ooh40ool0okCo0?oHok;o0?lJo`3o0_l0ooooool0oaKo
G@3oooooool01?oo09GooooooomY0?ooooooob3o0003ooooo`0=oeOo0?l0=?ooooooooooool0oo3o
E`3ooaX0ool0OOoo0?m[o`0:oolno`3o043oo`3oV`02ooooo`03obH0oooooooo>?l000Sooooo0_l0
;_l2ooooo`;o0?3o0oooool00omSo`3oGOl0oego0002oego00kooooo0omMo`04of?o00Oooooo00?o
0?3oo`0^ooooool00oooool04?lho`3ooooooooooolV0?oo043oo`0:oooooooo6P3oo`3oVomG0?oo
ooooo`3ol?oooooo0?m<o`0doomGo`02ooooo`08o`3oYoooooooooooo`;o0?l01?oooooooed0oom_
o`02ofT0o`03ooooool0UOoo09Go00Ko09Go0_ooool01omM0?ooooooofT0oomY0?oo00Coooooool2
o`002_ooool00ol0ojOoooooooooo`02ooooo`05oeOo0?oooooooooooooooolPo`001?ooool00ol0
odcoooooooooo`02o`0do`06oooooomG0?oo0?m[ooooool0oi_ooooo0_lJ0?l6ooooo`?o00[o00?o
03Coo`10ool0@?l01oooool00omG0?ooooooooooo`03ooooo`03oeOo0?oooooooooo00;ooooo00Co
J@3ooooooooooooo6P3o3Oooool01?l0l?oo00[oo`0:ool0l?l4ooooo`03oed0oooooooooooo00Co
oooo1On10?l3ooooo`GoP@3o2?ooool00ol0Soooooooooooo`0@ooooo`03oeOo0?oooooooooo00;o
oooo5ol0f?l6ooooo`?o043o1Oooool2ofT0o`Kooooo00?o0?o`ooooooooool0BOooool6o`0do`;o
oooo2?lno`03ooooo`Ko803o=_oooolBo`3`odoooooo001Cooooo`03o`000?oooooooooo00[ooooo
00KoJ@3ooed0oonb0?oo^03oonP0ooooool4oe3o0008ogD0oooX0?ooooooogGo0?nO0?oo^03ook80
oonho`03ooooo`08o`1goolP0?ooP@3oooooool0omSo/_l0oa[o0?l2o`02ooooo`08o`3o5_mM0?oo
00Coo`2EooooooooJ@3ooooooolPo`04ooooo`0<o`3oYol0=?ooooooo`3ol?mG0?oo6P3oo`1mool0
of_o00[oocko0?l0@?oo0?nK0oooool00olV0?oo>?l0ooooo`06ooooo`;o02ko0_ooool2o`3`o`;o
oooo00CoHol0oego0?mMo`3oGOl05Oooool3oego0003oooooomSo`3oHol000Kooooo00?o0?3oo`0^
ooooool00oooool02olho`3ooooooooooolV0?oo043oo`0:oolJ0?oooooooeL0oooooooo0?o`00;o
oooo00Go0?m<o`0dooooooooooooo`3oY`03ooooo`07o`;o0?l01?ooG@3ooooooom_o`3o/_l0ofT0
o`04ok;o0003oooooom_o`3oKol000;ooooo00OoG@3ooooooomY0?ooooooo`04oooooooo0_l000[o
oooo00?o0?nWooooooooool00_ooool01OmGo`3ooooooooooooooooo8?l000Cooooo00Co0?m<oooo
oooooooo03Co0_ooool01_mG0?oo0?m[ooooool0oi_ooooooaX0o`Kooooo0_l02_l2ooooo`03o`10
ool0=?oo0?m<00Sooooo00?oE`3oooooooooool00oooool00omGo`3oooooooooo`02ooooo`05ofT0
oooooooooooooooooolJ0?l02?ooool4o`3`o`?ooooo0_l02_l4ooooo`03oed0oooooooooooo00Oo
oooo1?n10?l<ooooo`03o`2?oooooooooooo00[ooooo3?l0f?lAooooo`;o0?m<1?ooool9o`3Ho`;o
043o0omY0?l6ooooo`;o0?o`A_ooool6o`0do`So?_l04Oooool6ob00od;ooooo2ol0l?m4ooooo`00
Doooool00ol0003oooooooooo`0:ooooo`09obH0oomY0?ooP@3ook80oonh0?ooj03oogD0oooooooo
M@3o00;oj03o00OoooooogGo0?nO0?oo^03ook80oooooooo^?l000;ooooo00So08ooob00oooooooo
P@3oo`3o]?l0omSoooooo`;o00;ooooo00So0?lFoed0ool01?ooooooo`2EooooooooJ@3oob3o00Co
oooo00goEol0o`0doooooooo0?o`oeL0oolJ0?oo07goo`3oJol02_oo?_l0o`10oooooooo0?nK00;o
oooo00?o9P3oocSo0?ooool01_ooool00ol0;_ooooooooooo`02o`3`o`03oooooomSo`3oGOl000;o
GOl06oooool3oego0003of?o0?oooooooooo00Cooooo00?o0?3oo`0^ooooool00_ooool04?lho`3o
oooooooooolV0?oo043oo`0:oooooooo6P3oo`3oVomG0?oo0?o`ob3o0?oooooo0?m<o`0doomGo`02
ooooo`06o`3oYoooooooooooooooool01?oooooo0_mM0?l2ofoo0003ofT0oom_o`3oKol000;oKol0
0_ooool2oed0o`06oooooomY0?ooooooo`04oooooooo0_l02oooool01Ol0ojOooooooooooooooooo
Eol000?ooooo00?o8?l0ooooooooool00_ooool01?l0odcoooooooooool0=?l2ooooo`04oeL0ool0
of_oooooo`3oV`;o6P3o0_ooool4ocko0003o`0:oooooooooooo00;o043o0_lno`000ol0=?oo0?m<
ooooo`07ooooo`03oeL0oooooooooooo00?ooooo00KoEol0ooooooooooooooooofT0ool0Sol3oooo
o`03oaX0oooooooooooo00;ooooo0ol0l?l9ooooo`;o00[o0_ooool00omM0?ooooooooooo`0Foooo
o`03o`2?oooooooo0=So00_o0=So1_ooool00omGo`3oooooooooo`0Cooooo`03o`3oC?oooooooooo
00gooooo0_mY0?l00ooooooo043oo`10o`0;o`3Hockooooo1Ol0=?l6ocko01oooooo1OlP0?m8oooo
o`Wo0?3o>oooool005?ooooo00?o0000ooooooooool02_ooool01_l04?ooJ@3ooh40oonb0?oo^03o
ooooo`?oj03o0oooool01OnO0?oo^03oohOo0?nb0?oo^?l000;ooooo00Wo08ooo`1goolP0?ooP@3o
o`3o]?l0omSooooooa[o0?l2o`000_ooool01omM0?ooooooo`04ool0UOooooooofT0oolPo`001Ooo
ool03?l0=?oooooooooooomG0?oo6P3oo`1mool0of_o00[oooooool0@?ooooooo`3oV`;ooooo00?o
9P3ooooooolho`001_ooool01Ol0;_ooooooo`3`ool0l?oooooo00?oGOl03_ooool;o`1<o`;o0=So
1_ooool2oego0003of?o0?oooooooooo00?ooooo00?o0?3oo`0^ooooool00_ooool03olho`3ooooo
oooooolV0?oo043oo`0:oolJ0?oo0?nKoeL0oooooooo0?o`ooooool0odco03CooeOo0002ooooo`05
o`3oYoooooooooooooooool2o`000_l01?l00oooooooG@3oooooo`03ofT0o`?ooooo00SoG@3ooooo
oomY0?ooJ@3oooooool01?ooooooo`;o00_ooooo00Go0?nWoooooooooooooooooeOo0003ooooo`03
ob3o0?oooooooooo00;ooooo00_o0?m<ooooooooooooooooo`0dooooooooE`3oo`3oJooooooo0?nK
oaX0o`03ooooo`03ocko0?oooooooooo00;o00[o0_ooool00ol0@?ooooooooooo`03ooooo`03o`0d
ool0odcooooo00Oooooo00?oE`3oooooooooool00_ooool00omGo`3oooooooooo`02ooooo`03ofT0
oooooooooooo00;ooooo00Co6P3oo`3`ool0l?oo0?3o3_ooool2o`0:o`03oooooomM0?oooooo01;o
oooo1?l0f?l00ol0Sooo0=Soooooo`0@ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<oooooooo
ool03?ooool2ofT0o`Gooooo0ol0@?l00ol0oo3oooooooooo`05ooooo`co0=So;oooool3o`0do`Co
?_l0:oooool6ob00ohKooooo001Cooooo`?o00002oooool01_mY0?ooG@3ooh40oonb0?oo^03ooil0
o`Cooooo00GoW`3ookP0oon7o`3o/P3ookSo0002ooooo`09o`2?ooo^o`3o803ooooooon10?oo0?nd
o`3of?oooooo0_l000;ooooo00Oo0?lFoed0ool01?ooooooo`2EooooooooJ@3o00Gooooo00coEol0
o`0doooooooo0?o`oeL0ool0OOoo0?m[o`0:oooooooo043oooooool0oi/2ooooo`03obH0oooooooo
>?l000Kooooo00?o02koooooool0l?l00_ooool00omMo`3oooooooooo`0;ooooo`Co04co2_l0[_l0
0ooooooo04coo`1<o`04o`1<o`Cooooo00?oGOl0of?o0?ooool01?ooool00ol0;_ooooooooooo`02
ooooo`0:ocSo0?oooooo9P3oo`10ool02_oo?_l0oaX0ool0oi_oE`3oo`3ol0;ooooo00Go0?m<o`0d
oomGo`3oooooo`3oY`04ooooo`04o`;o0?oooooo00Coooooo`CoG@3o1OmY0?l01Ooooooo00Coo`04
oooooooo0_l000_ooooo00Go0?nWoooooooooooooooooeOo0003ooooo`03ob3o0?oooooooooo00;o
oooo00_o0?m<ooooooooooooooooo`0dooooooooE`3oo`1moooooooo0?nKoaX0o`02ooooo`;o?_l0
0_ooool00ol02_ooooooooooo`02o`10o`Oooooo00?o03Coocko0?ooool01oooool00omG0?oooooo
ooooo`02ooooo`05oeOo0?oooooooooooooooomY0?l00_ooool3o`3`o`03oaX0oooooooooooo013o
oooo00?o00[ooed0ooooool03_ooool4o`3Ho`?ooooo00?o08ooooooooooool04?ooool00omGo`3o
ooooooooo`0Cooooo`03o`3oC?oooooooooo00_ooooo0_mY0?l8ooooo`03o`3ol?oooooo043o00;o
043o4Oooool<o`3Hoa_ooooo1Olno`03o`0docSooooo2OlP0?mmooooo`00Doooool00ol0003ooooo
ooooo`0;ooooo`06obH0oomY0?ooP@3ook80oooooooo^03o1?nO0?l01Onh0?ooQol0ok80oooooooo
^?l000;ooooo00So08ooob00ooooooooP@3oo`3o]?nbo`3o0?oHo`;o00?ooooo00KoG@3oo`04oooo
oooo09GooooooomY0?l5ooooo`0<oeOo0?l0=?ooooooo`3ol?mG0?oo6P3oo`3oJol02_ooooooo`10
oooooooo0?nK0_ooool00olV0?ooooooocSo0006ooooo`04o`0^oooooooo0?3oooooo`;oGOl02ooo
ool3o`1<o`Co0:ko2_ooool5o`2^o`;ooooo00?o04coooooooooool00_ooool00omMo`3oHol0oooo
o`03ooooo`03o`3`ool0;_oooooo00;ooooo00oo>?l0oooooooooooo9P3oo`0:oooooooo6P3oo`3o
VomG0?oo0?o`ob3o0?oooooo0?m<o`0doomGo`000_ooool01Ol0ojOooooooooooooooooo0_l000;o
oooo00?o00Coooooooooool01oooool01?l01?ooooooooooool2o`0;ooooo`03o`3oYooooooooooo
00;ooooo00GoEol0ooooooooooooooooob3o0003ooooo`03o`3oC?oooooooooo00;o03Co00Kooooo
oeL0ool0OOoo0?m[o`3oVolJ0?l3ocko00?ooooo00Co00[ooooooooooooo043o2Oooool00ol0=?oo
0?m<ooooo`07ooooo`03oeL0oooooooooooo00;ooooo00OoEol0ooooooooooooooooofT0ool0Sooo
0?3o00Cooooo00?o6P3oooooooooool04Oooool00omM0?oo00[oooooo`09ooooo`?o0=So1_ooool0
0ol0Soooooooooooo`0@ooooo`03oeOo0?oooooooooo00Kooooo6?l0oiD2ooooo`;oJ@3o2Oooool0
0ol0oo3oooooooooo`03ooooo`;o043o6oooool:o`3Ho`Wooooo2?lno`02ooooo`?o03CoA?ooool;
ob00og;ooooo001Cooooo`03o`000?oooooooooo00_ooooo00Go013oofT0oon10?oo0_l0ok80o`05
okP0o`04ohOo0?nb0?oooooookSo00;ooooo00Wo08ooob00ool0Mooooooooh40ool0okCo0?oHo`;o
0?lJo`000_ooool01?mM0?ooooooo`04ool0UOl2ooooo`03ofT0oooooooooooo00?ooooo00Wo0?m<
o`0dooooooooE`3ooaX0ool0OOoo00[oooooool0@?l00_ooool01Ol0oi_oooooobH0oooooooo>?l0
00Kooooo00?o02koooooool0l?l00_mMo`0:ooooo`?o04co0ol0[_l7ooooo`?o0?nE2Oooool3o`2^
o`?o04co0_ooool00omMo`3oHol0ooooo`03ooooo`03o`3`ool0;_oooooo00;ooooo00ko>?l0oooo
oolV0?oo043oo`0:oolJ0?oo0?nKoeL0oooooooo0?o`ooooool0odco03CooeOo00;ooooo00?o0?nW
ooooooooool00_ooool01?l2o`3oooooo`04ool01?l7ooooo`04o`04oooooooo0_l0o`;o00cooooo
00Go0?nWoooooooooooooooooeOo0003ooooo`05ob3o0?ooooooooooooooool0od`00_ooool02Ol0
=?oooooooooooomG0?oo07goo`3oJol0oi_o6P3oocko0005ooooo`04o`0:oooooooo043oo`10o`_o
oooo00?o03Coocko0?ooool01oooool00omG0?ooooooooooo`02ooooo`05oeOo0?l0l?oo0?3ooooo
oomY0?l01_ooool00olJ0?ooooooooooo`0Aooooo`03oed0ool02_oooooo00Cooooo1?l0f?l9oooo
o`03o`2?oooooooooooo00Sooooo4Ol0oiD<ooooo`03o`3oC?oooooooooo00Wooooo0_mY0?l9o`3o
U@;o0?o`1_l0oiD2ooooo`?o043o8_ooool8o`3Ho`03ocko0?oooooooooo00Gooooo0ol0=?mBoooo
o`Wo803oJOooool005?ooooo00?o0000ooooooooool02oooool01_l04?ooJ@3ooed0oon10?oo803o
ok80o`Cooooo00ko/P3ooooooonho`3o^?l0ooooool0Sooo803oo`1gooooooooP@3oo`3o]?oooooo
0?oHo`;o00;ooooo00OoG@3oooooool01?ooooooo`2EooooooooJ@3o00Gooooo00WoEol0o`0doooo
oooo0?o`oeL0ool0OOoo00[oooooool0@?l00_ooool01Ol0oi_oooooobH0oooooooo>?l000Kooooo
00Co02koooooool0l?ooGOl02Oooool3o`1<o`?o0:ko0oooool8o`3oU@03ooooool0oiGo0?nE00Oo
0?nE1?ooool2o`2^o`06ooooool0C?oooooooooooomMo`3oHol01?ooool00ol0l?oo02koooooo`02
ooooo`09ocSo0?lV0?oo043oo`0:oolno`3o6P3oo`3oVomG0?oo0?o`00;ooooo00?o0?m<o`0doomG
o`000_ooool01?l0ojOoooooooooooooool2o`;o00;ooooo1ol01?l00ooooooo0_l0ooooo`0<oooo
o`05o`3oYooooooooooooooooomGo`000oooool01OlPo`3ooooooooooooooooo0?m<00;ooooo00Wo
03CooooooomG0?ooE`3oo`1mool0of_ooooooaX0oolno`001?ooool2o`0:o`03ooooool0@?oooooo
00cooooo00?o03Coo`3oC?lno`002?ooool00omG0?ooooooo`3`o`02o`3`o`?ooooo00?oJ@3ooooo
ooooool01Oooool00olJ0?ooooooooooo`0@ooooo`04oed0oooooooo00[oo`0:o`?o0=So3?ooool0
0ol0Soooooooooooo`03ooooo`Ko0?nE1_ooool00omGo`3oooooooooo`0Cooooo`03o`3oC?oooooo
oooo00Sooooo0_mY0?l:ooooo`03o`3ol?oooooooooo00Kooooo1Ol0oiD2o`10oa_ooooo1_lno`07
ooooo`Go0=So0ol0=?mNoooooaSo803oDOooool005?ooooo00?o0000ooooooooool03?ooool01?mG
0?ooJ@3ooh40oolP0?l6ok80o`0=okSo0?ooooooooooo`2?oolP0?oo07Oooooooon10?oo0?olo`3o
]?l0omSo0_l0oa[o0002ooooo`07oed0ool01?ooooooo`2Eoooooooo8?l0ofT0o`05ooooo`08o`0d
oooooooo0?o`oeL0ool0OOoo0?m[o`0:ool0@?l2ooooo`05o`3oVooooooo9P3ooooooolho`001_oo
ool01?l0;_ooGOl0o`3`oomSo`08ooooo`;o04co0ol0[_l3ooooo`?o0?nE4_ooool3o`3oU@?ooooo
00?o0:koooooool0C?l00_ooool00omMo`3oHol0ooooo`03ooooo`0Bo`0^oooooooooooooooooolh
o`3oooooobH0ool02_oooooooaX0ool0oi_oE`3oo`3ol?lPo`3oooooo`3oC?l0=?ooEol00_ooool0
0ol0ojOoooooooooo`03ooooo`;o0_l01oooool00ol2o`3oooooooooo`0;ooooo`05o`3oYooooooo
oooooooooomGo`000oooool00olPo`3oooooooooo`02ooooo`0;o`3oC?oooooo03CooooooomG0?oo
ooooo`1mool0of_ooooooaX0oolno`001?ooool01?l02_ooooooooooool0@?l>ooooo`04o`0dool0
odcoooooocko00Kooooo00?o0?3ooeL0ool0l?l00oooool01OmGo`3ooooooooooomY0?oo08oo00Oo
oooo00?o6P3oooooooooool03oooool01?l0f?ooG@3oo`3Hooooool2o`0:o`gooooo00?o08ooo`3o
UOl0oiD00ol0oiD;ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<ooooooooool01oooool2ofT0
o`_ooooo00?o0?o`ooooooooool03Oooool01?l0oiGo043oo`10ool0@?l5o`3oU@kooooo1Olno`0@
ooooo`;o03Co0_ooool:o`3Hofgooooo5_lP0?lkooooo`00Doooool00ol0003oooooooooo`0<oooo
o`07obH0oomY0?ooG@3ooh40oolP0?oo^?l0ok80o`03okSo00;ooooo00[o08ooob00ooo^o`3o07Oo
ofoo0?n10?oo0?ndooooool0omSo6_l00_ooool01omM0?ooooooo`04oooooooo09Goob3o0?mY0?l0
1Oooool03omGo`3o03CooooooomG0?oo6P3oo`1mool02_ooooooo`10oooooooo0?nKoooooolV0?oo
ooooocSo0006ooooo`03o`0^oomMo`3o0?3o00Wooooo00?o04coo`2^ool0[_l00oooool3o`3oUASo
oooo0_l0oiD2ooooo`;o0:ko00Go04coooooooooooooGOl0of?o0003ooooo`03o`3`ool0;_oooooo
00;ooooo00Wo>?l0obH0ool0@?oo00[ooaX0ool0oi_oE`3oooooool0oo000_ooool01Ol0=?ooEol0
oooooooooooo0?nW00Oooooo1ol2o`0>ooooo`04o`3oYooooooooooooeOo00?ooooo00?o8?l0oooo
ooooool00_ooool02ol0odcoooooo`0dooooooooE`3oooooool0OOoo0?m[oooooolJ0?oo?_l000Co
oooo00Co00[ooooooooooooo043o4?ooool01?l0=?oo0?m<oooooolno`02ooooo`?o0?3o0_ooool0
1OmG0?ooooooooooooooooooEol000;ooooo00?oJ@3oo`2?ooooool01_ooool00olJ0?oooooooooo
o`0<ooooo`?o0=So00?ooooooed0ooooool00oooool2o`0:o`Kooooo1?l0oiD00ol0Sooo0?nEoooo
o`0>ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<ooooooooool01_ooool2ofT0o`_ooooo0_l0
oo0Dooooo`;o043o0oooool;o`3oU@?o?_l04_ooool3o`0do`kooooo2ol0f?ncooooo`00Doooool0
0ol0003oooooooooo`0<ooooo`05o`0@oomY0?ooG@3ooh40oonbo`000_lP0?l4ooooo`0:o`2?oolP
0?ook_l0o`1goom_o`3oP@3oo`3oo?oooooo0?oHoa[o00;ooooo00OoG@3oo`3o5_l01?ooooooo`2E
ooooooooJ@3o00Gooooo00WoEol0o`0doooooooo0?o`oeL0ool0OOoo00[oooooool0@?l00_ooool0
1?l0oi_o9P3ooooooolho`06ooooo`03o`0^oomMo`3o0?3o00Sooooo0_l0C?l00ol0[_oooooooooo
o`03o`3oUAgooooo00Ko0?nEooooooooooooooooo`2^ool0C?l2ooooo`03oego0?mSo`3ooooo00;o
oooo01;o0?3oo`0^ooooooooooooocSo0?oooooo9P3oo`0:oooooooo6P3oo`3oVomG0?oo0?o`ob3o
0?oooooo0?m<o`0doomGo`02ooooo`03o`3oYooooooooooo00Oooooo00?o0_l0ooooooooool03_oo
ool01Ol0ojOoooooooooooooooooEol000;ooooo00?o8?l0ooooooooool00_ooool02ol0odcooooo
o`0dooooooooE`3oooooool0OOoo0?m[oooooolJ0?oo?_l000Cooooo00Co00[ooooooooooooo043o
1oooool8ocSo00;ooooo00Co03Coo`3oC?oooooo?_l00_l0l?l5ooooo`05oeL0oooooooooooooooo
oomGo`000oooool00omY0?ooooooooooo`06ooooo`03oaX0oooooooooooo00Sooooo0ol0f?l5oooo
o`03oed0oooooooooooo00?ooooo0_l02_l4o`3oU@?ooooo00?o08ooooooooooool03_ooool00omG
o`3oooooooooo`0Cooooo`03o`3oC?oooooooooo00Gooooo0_mY0?l<ooooo`03o`3ol?oooooooooo
01Kooooo0ol0@?l4ooooo`Go?_l00_ooool:o`3oU@Wooooo0_l0=?lLooooo`[o0=SoZOooool005?o
oooo00?o0000ooooooooool03Oooool01OmG0?ooJ@3ooh40ool2o`3o/_l000Ko803o00Woooooofoo
0?l0MoooP@3oo`3oo?l0okCo0_l0o`3of?lJo`000_ooool01omM0?ooooooo`04ool0UOooooooob3o
0?mY0?l01Oooool02?l0odco03Coo`3ol?mG0?oo07goo`0:oooooooo043o0_ooool01?l0oi_o9P3o
oooooolho`06ooooo`03o`0^oomSo`3o0?3o00Sooooo00?o04coo`2^ool0[_l00ol0oiDQooooo`;o
0?nE0_ooool01Ol0[_oo04cooooooomMo`3oHol000?ooooo01;o0?3oo`0^ooooooooooooocSo0?oo
oooo9P3oo`0:oooooooo6P3oo`3oVomG0?oo0?o`ob3o0?oooooo0?m<o`0doomGo`02ooooo`03o`3o
Yooooooooooo01Oooooo00Go0?nWoooooooooooooooooeOo0003ooooo`09ob3o0?oooooooooooooo
ool0odcoooooo`0dooooooooE`3o00;ooooo00Co07gooooooolJ0?oo0?nK1?ooool01?l02_oooooo
ooooool0@?l4ooooo`Co>?l02?ooool3ocSo0004o`0dool0l?oo0?3oocko00Kooooo00?oE`3ooooo
ooooool00_ooool01OmGo`3ooooooooooomY0?oo08oo00Sooooo00?o6P3oooooooooool01?ooool3
o`3Ho`Sooooo00?oG@3oooooool0oiD00ol0oiD2ooooo`;o00[o1Oooool00ol0Soooooooooooo`0=
ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<ooooooooool01Oooool00omY0?ooooooooooo`0;
ooooo`03o`3ol?oooooooooo01Wooooo00?o?_l0o`10ool0@?l00_lno`0Aooooo`Oo0?nE0_l0=?lX
ooooo`So0=SoXOooool005?ooooo00?o0000ooooooooool03Oooool01_lV0?ooJ@3ooed0oon10?oo
oooook;o00KoKol000Oo07Oooh40oonbo`3o0?olo`;o0?l0omSo6_l000;ooooo00OoG@3oo`3o5_l0
1?ooooooo`2EoolPo`3oJ@3o00Gooooo00koEol0o`0dooooooooE`3oooooool02_ooooooo`10ooln
o`3oooooo`3oVolV0?ooooooocSo00Gooooo00CoGOl0o`0^oomSo`3o0?3o1oooool2o`1<o`03o`2^
ool0oiGo0?nE00Wooooo4_l0o`X;ooooo`08o`3oUOooooooooooo`2^ool0C?oooooooego0?mSo`03
ooooo`0=o`3`ool0;_oooooooooooolho`3o9P3oo`0:oooooooo6P3oo`3oVol0OOooE`3oo`3ol002
ooooo`05o`0doomGo`3oooooooooool0ojL06?ooool01Ol0ojOoooooooooooooooooEol000?ooooo
00Go8?l0ooooooooooooooooo`3oC002ooooo`08o`0doomG0?ooooooooooool0OOoo0?m[oaX0ool0
oi/4ooooo`04o`0:ooooooooooooo`10o`?ooooo0_lho`0>ooooo`03o`3`ool0=?oo0?m<00;ooooo
00?o?_l0ooooooooool01?ooool01OmG0?ooooooooooooooooooEol000;ooooo00?oJ@3oo`2?oooo
ool01oooool01?lJ0?ooooooooooooooool3o`3Ho`[ooooo0_l0oiD00omM0?ooooooooooo`06oooo
o`;o00[o0_ooool00ol0Soooooooooooo`0=ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<oooo
ooooool01Oooool00omY0?ooooooooooo`0;ooooo`03o`3ol?oooooooooo01Gooooo1Olno`03oooo
o`?o043o5?ooool3o`0do`03ooooool0oiGo0?nE00Go0?nE:_ooool7o`3Hoi[ooooo001Cooooo`03
o`000?oooooooooo00gooooo00Ko013oofT0oomM0?ooP@3oo`;o0?nbo`03ooooo`0Conko0?oooooo
oooooh40oooooooo0?olo`3o]?l0omSooooooa[o0?ooooooG@3oo`3o5_l01?ooooooo`2EoolPo`3o
ooooofT0o`05ooooo`0=o`3oC?l0=?ooE`3ooaX0ool0OOoo00[oooooool0@?ooooooo`3oVolV0?oo
ooooocSo0005ooooo`04oego0?oooooo02koo`3`o`Oooooo00Co04coo`2^ool0[_oo0?nE1_ooool5
o`3o2Q;ooooo0_l0o`X:ooooo`08o`3oUOooooooooooo`1<ool0f?oooooooego0?mSo`02ooooo`0B
o`3`oooooooo02kooooooolho`3oooooobH0ool02_oooooooaX0ool0oi_oE`3oo`3ol?lPo`3ooooo
o`3oC?l0=?ooEol00_ooool00ol0ojOoooooooooo`0Eooooo`04o`3oYooooooooooooeOo00?ooooo
00Go8?l0ooooooooooooooooo`3oC002ooooo`09o`0doomG0?ooooooooooool0OOoo0?m[oooooolJ
0?oo?_l000?ooooo00Co00[ooooooooooooo043o1_l0oo0<ooooo`;o0?3o00?oooooo`0dool0od`0
0_lho`000ooooooo?_l0ooooo`04ooooo`03oeL0oooooooooooo00;ooooo00GoEol0oooooomY0?oo
ooooo`2?o`08ooooo`03oaX0ool0f?oo0=So00[ooooo0ol0oiD2ooooo`03oed0oooooooooooo00So
oooo0_l02_l00ol0Soooooooooooo`0=ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<oooooooo
ool01?ooool00omY0?ooooooooooo`0<ooooo`03o`3ol?oooooooooo00oooooo1_lno`0;ooooo`?o
043o3oooool2o`0do`_ooooo2_l0oiDWooooo`So0=SoT_ooool005?ooooo00?o0000ooooooooool0
3Oooool01_l04?ooJ@3ooed0ool0MoooP@3oo`;o00Co/_l00_l0Mol01_n10?oo0?olo`3o]?oooooo
0?oHoa[o00;ooooo00OoG@3oo`3o5_l01?ooooooo`2EoolPo`3oJ@3o00Gooooo00SoEol0o`0doooo
ooooE`3oo`1mool02_ooooooo`10o`;ooooo00?o9P3ooooooolho`001Oooool01?mMo`3oooooo`0^
ool0l?l6ooooo`;o04co00?o0:koo`3oUOl0oiD01?ooool3o`3o2QWooooo0ol0o`X8ooooo`07o`3o
UOooooooooooo`1<ooooooooGOl0of?o0003ooooo`0Ao`3`ool0;_ooooooocSo0?oooooo9P3oo`0:
oooooooo6P3oo`3oVomG0?oo0?o`ob3o0?oooooo0?m<o`0doomGo`000_ooool00ol0ojOooooooooo
o`0Dooooo`04o`3oYooooooooooooeOo00?ooooo00Go8?l0ooooooooooooooooo`3oC002ooooo`03
o`0dooooooooE`3o00;ooooo00Co07gooooooolJ0?oo?_l00oooool01?l02_ooooooooooool0@?l2
ooooo`;o>?l00oooool2o`3ol0Wooooo00?o0?3oooooooooool00_ooool01Ol0=?oooooooooooolh
o`3o?_l000Gooooo00?oE`3oooooooooool00_ooool01OmGo`3ooooooooooomY0?oo08oo00Kooooo
0ol0f?l00olJ0?ooooooooooo`06ooooo`?o0?nE1_ooool00omM0?ooooooooooo`08ooooo`03o`2?
ool02_oo00[o00gooooo00?oEol0ooooooooool04oooool00ol0odcoooooooooo`04ooooo`03ofT0
oooooooooooo00cooooo00?o0?o`ooooooooool02oooool5ocko01Cooooo0_l0@?l:ooooo`?o03Co
5oooool;o`3oUBCooooo2?l0f?n:ooooo`00Doooool00ol0003oooooooooo`0>ooooo`04oeL0oomY
0?ooG@3oo`1go`;oP@3o00?o0_l0ooooool0Mol00_n10?l01Ol0ooco0_l0ooooool0omSo6_l000;o
oooo00OoG@3oo`3o5_l01?ooooooo`2EoolPo`3oJ@3o00Gooooo00SoEol0o`0dool0ojOoE`3oo`1m
ool02_ooooooo`10o`;ooooo00?o0?nKobH0oolho`001Oooool01OmMo`3oooooo`0^oooooooo0?3o
00Gooooo00Co04coo`2^ool0[_oo0?nE0oooool3o`3o2Pgooooo2Ol0ofD9ooooo`03o`3o2_oooooo
oooo00Kooooo00Oo0?nEooooool0[_oo04cooooooomMo`3oHol000;ooooo017o0?3oooooool0;_oo
ooooocSo0?lV0?oo00[ooooooolJ0?oo0?nKo`1moomG0?oo0?o`ob3o0?oooooo03CooeOo0002oooo
o`03o`3oYooooooooooo01?ooooo00Co0?nWooooooooooooEol00oooool00olPo`3oooooooooo`02
ooooo`05o`3oC?oooooo03CooooooomG0?l00_ooool01?l0OOoo0?m[oaX0ool0oi/3ooooo`04o`0:
ool0oo3o0?o`o`10o`;ooooo00?o>?l0ooooooooool01Oooool00ol0oo3oooooooooo`05ooooo`03
o`3`oooooooooooo00?ooooo00Ko03Coo`3oC?ooooooooooocSo0?lno`05ooooo`03oeL0oooooooo
oooo00;ooooo00CoEol0oooooomY0?oo08oo0oooool3o`3Ho`?ooooo00?o6P3oooooooooool01?oo
ool2o`3oU@[ooooo00?oG@3oooooooooool01oooool00ol0Soooooooooooo`02o`0:o`[ooooo00?o
Eol0ooooooooool04oooool00ol0odcoooooooooo`04ooooo`03ofT0oooooooooooo00cooooo00?o
0?o`ooooooooool02?ooool4ocko01_ooooo0ol0@?l5ooooo`;o03Co9Oooool:o`3oUB;ooooo1ol0
f?n3ooooo`00Doooool00ol0003oooooooooo`0>ooooo`05obH0oomY0?ooG@3ooa[o0?l0ok@01?n1
0?l00ol2o`3o0?ndo`3oo002ooooo`0;o`3of?oooooooooooed0oooooooo00Coooooool0UOoo8?l0
oooooomY0?l01Oooool03?l0odco03CooeL0oolJ0?oo00[oooooool0@?oo?_l0ooooool0oi_o9P3o
ocSo00Gooooo00GoGOl0ooooool0;_ooooooo`3`o`05ooooo`04o`1<ool0[_oo0?nEo`3oU@;ooooo
0_l0o`X:ooooo`Ko0?mU2Oooool6o`3oI@Cooooo0_l0o`X7ooooo`06o`3oUOoooooo0:koo`1<oomM
o`3oHol00oooool01_l0l?oo02kooooooolho`3oooooobH0o`;ooooo00Wo6P3oo`3oVomG0?oo0?o`
ob3o0?oooooo0?m<o`0doomGo`000_ooool00ol0ojOoooooooooo`0Aooooo`05o`3oYooooooooooo
oooooomGo`000oooool01OlPo`3ooooooooooooooooo0?m<00;ooooo00So03CooeL0oooooooooooo
o`1mool0of_o6P3oo`3oV`?ooooo00Co00[oo`3ol?oooooo043o0_ooool00olho`3oooooooooo`07
ooooo`;o0?o`1?ooool00ol0l?ooooooooooo`05ooooo`05o`0doooooooooooooooooolho`001Ooo
ool00omG0?ooooooooooo`02ooooo`05oeOo0?ooooooJ@3oooooool0Sol00_l0f?l7ooooo`03oaX0
oooooooooooo00?o0?nE3?ooool00omM0?ooooooooooo`06ooooo`03o`2?oooooooooooo00?ooooo
0_l02_l7ooooo`03oeOo0?oooooooooo01?ooooo00?o0?m<ooooooooool01Oooool00omY0?oooooo
ooooo`0;ooooo`03o`3ol?oooooooooo00Gooooo1?lno`0Rooooo`;o043o00?oooooo`0dool0=?l0
<Oooool9o`3oUB3ooooo2_l0f?miooooo`00Doooool00ol0003oooooooooo`0>ooooo`05o`0@oomY
0?oo00Cooed0oolJo`000_l0ok@01?oooooo0?ndo`3o]?l0oo`2ooooo`0;o`3of?oooooooooooooo
oomM0?oo0?lFo`04oooooooo09GooooooomY0?l01Oooool02?mGo`3o03Coo`3oYomG0?oo07goo`0:
oooooooo043o0_ooool00olV0?ooooooocSo0004ooooo`05oego0?oooooo02koooooool0l?l01Ooo
ool00ol0C?oo0:koo`3oU@02ooooo`;o0?l:2?ooool4o`3oI@Wooooo1?l0:?l8ooooo`;o0?mU1?oo
ool00ol0o`[oooooooooo`04ooooo`07o`3oUOooooooooooo`1<ool0f?ooGOl0of?o0002ooooo`0A
o`3`ool0;_ooooooocSo0?oooooo9P3oo`0:oooooooo6P3oo`3oVomG0?oo0?o`ob3o0?oooooo0?m<
o`0doomGo`000oooool00ol0ojOoooooooooo`0?ooooo`05o`3oYooooooooooooooooomGo`000ooo
ool01OlPo`3ooooooooooooooooo0?m<00;ooooo00?o03CooooooomG0?l00_ooool01?l0OOoooooo
oaX0ool0oi/2ooooo`07o`0:ool0oo3oooooooooool0@?ooooooocSo000<ooooo`04o`3ol?oooooo
0?3oo`3`o`Sooooo00?o03Coo`3oC?ooool00_ooool00olho`3oooooooooo`02ooooo`03oeL0oooo
oooooooo00?ooooo0_l0f?l00omY0?oo08ooooooo`08ooooo`03o`3oUOlJ0?oo0?nE013ooooo00?o
G@3oooooooooool01?ooool00ol0Soooooooooooo`06ooooo`;o00[o1?ooool00omGo`3ooooooooo
o`0Dooooo`03o`3oC?oooooooooo00Cooooo00?oJ@3oooooooooool02oooool00ol0oo3ooooooooo
o`03ooooo`?o?_l09oooool2o`0do`;o043o>_ooool8o`3oUB;ooooo3?l0f?m]ooooo`00Doooool0
0ol0003oooooooooo`0>ooooo`07o`0@oomY0?oo00Coo`3of?mM0?oo0?olooooo`02o`3o]004o`3o
o?ooooooooooo`3of0?ooooo00GoG@3oooooool01?ooooooo`2Eo`02ooooo`03ofT0oooooooooooo
00;ooooo00SoEol0o`3oC?l0=?ooE`3oo`1mool02_ooooooo`10o`;ooooo00?o0?nKobH0oolho`00
1?ooool01OmMo`3oooooof?o0?l0;_oo0?3o00Gooooo00Co04coo`2^ool0oiGooooo0_l0o`X7oooo
o`?o0?mU1oooool6o`0Xo`Cooooo2?l0:?l2ooooo`?o0?mU0_ooool2o`3o2PGooooo00Ko0?nEoooo
oooooooo04cooooooomMo`03ooooo`0@o`3`ool0;_ooooooocSo0?lV0?oo00[ooooooolJ0?oo0?nK
o`1moomG0?oo0?o`ob3o0?oooooo03CooeOo00Cooooo00?o0?nWooooooooool03Oooool01Ol0ojOo
ooooooooooooooooEol000?ooooo00Go8?l0ooooooooooooooooo`3oC002ooooo`03o`0doooooooo
E`3o00;ooooo00Co07goo`3oJolJ0?oo0?nK0_ooool01Ol02_oo0?o`oooooooooooo043o00;o>?l0
3_ooool00ol0l?ooooooooooo`08ooooo`03o`0dool0odcooooo00;ooooo00?o?_l0ocSo0?ooool0
0oooool00omG0?ooooooo`3Ho`02o`3Ho`05oeOo0?ooooooJ@3oooooool0Sol01Oooool3o`3oU@;o
oooo00?o6P3oooooooooool03_ooool00omM0?ooooooooooo`04ooooo`03o`2?oooooooooooo00So
oooo0_l02_l00oooooooEol0ooooo`0Eooooo`03o`3oC?oooooooooo00Cooooo00?oJ@3ooooooooo
ool02oooool01?l0oo3oooooooooooooool3ocko02Sooooo0_l0=?l4ooooo`;o043o@?ooool8o`3o
UBKooooo3?l0f?mQooooo`00Doooool00ol0003oooooooooo`0>ooooo`05o`2KoomY0?oo6P3oo`04
oomM0?l01?l0oo`00ooooooo6_l0o`3of003ooooo`08oed0oooooooo00CooooooolPo`3o09Gooooo
oomY0?l5ooooo`0<o`3oC?l0=?ooE`3oooooool02_ooooooo`10oolno`3oooooo`3oVolV0?oo>?l0
1?ooool01OmMo`3oooooof?o0?l0;_oo0?3o00Gooooo00Go04coo`2^ool0oiGoooooo`3o2P07oooo
o`;o0?mU1oooool3o`0Xo`Kooooo1Ol0i?l7ooooo`?o02So0_ooool2o`3oI@;ooooo00?o0?l:oooo
ooooool00oooool01_l0oiGoooooo`2^ool0C?ooGOl0of?o00;ooooo00Ko0?3oo`0^oooooooo>?l0
oooooolV0?l2ooooo`09oaX0ool0oi_oE`3oo`3ol?lPo`3oooooo`3oC?l0=?ooEol000Cooooo00?o
0?nWooooooooool02oooool01Ol0ojOoooooooooooooooooEol000?ooooo00Go8?l0oooooooooooo
ooooo`3oC003ooooo`08o`0dooooooooE`3oooooool0OOoo0?m[oaX0ool0oi/2ooooo`06o`3ol?l0
2_ooooooooooool0@?oo>?l03oooool00ol0l?oo0?o`ooooo`02ooooo`OoHol000?oooooo`0doooo
ool00oooool01olho`3ooooooooooooooooo0=SooeL0ool0f?l01?ooool01OmGo`3oJ@3oooooool0
Sooooooo00Co0?nE1Oooool00olJ0?ooooooooooo`0?ooooo`03oed0oooooooooooo00;ooooo00?o
08ooooooooooool02oooool2o`0:oaGooooo00?o0?m<ooooooooool01?ooool00omY0?oooooooooo
o`0;ooooo`03o`3ol?oooooo?_l000;o?_l0:Oooool2o`0do`Sooooo0ol0@?m5ooooo`So0?nE:_oo
ool<o`3HoeGooooo001Cooooo`03o`000?oooooooooo00oooooo00KoE`3oofT0oooooooo00Cooed0
ooooool3oa[o0003o`3of?oooooooooo00;oG@3o0_ooool01Ol01?oo8?l0o`2EooooooooJ@3o00Go
oooo00SoEol0o`0dool0ojOoE`3oo`0:oooooooo043oocko00;ooooo00?o9P3oocSo0?ooool00ooo
ool01_mMo`3oooooof?o0?l0;_ooooooo`3`o`Cooooo00?o04coo`2^ool0oiD00_l0o`X7ooooo`03
o`3oIOoooooooooo00Cooooo0ol0:?l3ooooo`Ko0>Co1?ooool6o`3To`Gooooo00Go02Sooooooooo
ooooooooo`3oI@02ooooo`03o`3o2_oooooooooo00?ooooo00Go0?nEooooool0C?oooooooego0003
ooooo`0Ao`0^oooooooo>?l0oooooolV0?oo00[ooooooolJ0?oo0?nKoeL0ool0oo3oooooob3o0?l0
odco03CooooooomGo`000oooool00ol0ojOoooooooooo`0:ooooo`05o`3oYooooooooooooooooomG
o`000oooool00olPo`3oooooooooo`02ooooo`0?o`3oC?ooooooooooo`0dooooooooE`3oooooool0
OOoo0?m[oaX0oolno`3o0?nKooooool0oo3o00[o00;ooooo00?o043oocSo0?ooool03_ooool01?l0
l?ooHol0of?o0?l0oo03of?o00Kooooo00CoHol0o`0dool0odcoHol00oooool3o`3Ho`03oooooomG
0?oooooo00Cooooo00GoEol0ofT0ool0oiGo08ooo`3oU@0:ooooo`03oaX0oooooooooooo00kooooo
00?oG@3oooooooooool00_ooool00ol0Soooooooooooo`0:ooooo`03oeOo0?oooooooooo00;o00[o
4_ooool00ol0odcoooooooooo`04ooooo`03ofT0oooooooooooo00_ooooo00?o0?o`ocko0?lno`00
:_ooool2o`0do`gooooo0ol0@?m:ooooo`Oo0?nE;oooool;o`3Hod[ooooo001Cooooo`03o`000?oo
oooooooo00oooooo00Go9P3oofT0ool0oaKo00Coo`3of002oed0o`?o0?oH00Cooooooed0oooooooo
oooo0_l01?l01Ooooooo09GoooooooooooooJ@3o00Gooooo00Co0?m<o`0doomG0?oo00[o0_ooool0
1_l0@?ooooooooooool0oi_o9P3oocSo00?ooooo00KoGOl0oooooomSo`3o02koooooool0l?l4oooo
o`04o`1<ool0[_oo0=Soo`3o2POooooo0_l0ofD4ooooo`?o02So00?oooooo`3Tool0i?l00ol0i?l@
o`3o=0?o0>Co0oooool01ol0:?oooooooooooooooooo0?mUooooool0o`X01Oooool01_l0oiGooooo
o`2^ool0C?ooHol0oego00;ooooo017o0?3oo`0^oolho`3oooooobH0ool02_oooooooaX0ool0oi_o
07gooeL0ool0oo3o8?l0ooooool0=?oooooooeOo0004ooooo`;o0?nW2?ooool2o`3oY`Cooooo00Co
Eol0oooooooooooo8?l01?ooool01_l0odcoooooooooool0=?oooooooeL0o`;ooooo00Oo07goo`3o
JolJ0?oo0?nKooooool0oo3o00[o00;ooooo00?o043oocSo0?ooool03Oooool00omSo`3o0?3oof?o
0002ooooo`04o`3ol?ooooooooooooooo`KoGOl000Coooooo`0dool0odcooooo0ol0f?l00olno`3o
>?l0ooooo`02ooooo`04oeL0ooooooooooooooooo`?o0?nE00?oJ@3oooooool0Sol02oooool00olJ
0?ooooooooooo`0>ooooo`04oed0ooooooooooooo`2?o`cooooo00?oEol0ooooooooool00oooool2
o`0:oa3ooooo00?o0?m<ooooooooool00oooool00omY0?ooooooooooo`0:ooooo`03ocko0?l0oo3o
oooo02[ooooo0_l0=?lBooooo`;o043oCoooool8o`3oUC;ooooo2_l0f?m0ooooo`00Doooool3o`00
00oooooo00Co013oofT0ool0UOoo0?lF0_l01?l5oed0o`04ooooool01?oo00Coo`3o5P;ooooo00?o
09GooooooomY0?l01Oooool01ol0odco03CooeL0oooooooo00[oooooool0@?l00_ooool00ol0oi_o
9P3oocSo0003ooooo`06oego0?ooooooHol0o`0^oooooooo0?3o1?ooool01?l0C?oo0:koo`3Hool0
o`X7ooooo`03o`3oIOoooooooooo00;ooooo0_l0:?l01?oooooo0>Coo`3Tool0i?l3ooooo`;o0?ld
3_ooool3o`3o:0;o0?ld0ol0i?l00ooooooo02Soo`0Xo`02ooooo`03o`3oIOoooooo0?l:00Gooooo
00Go0?nEo`2^ool0C?oooooooego0002ooooo`06o`3`ool0;_ooooooocSo0?oooooo9P3o0_ooool0
2_lJ0?oo07gooeL0ool0oo3o8?l0ooooool0odco03CooooooomGo`05ooooo`03o`3oYooooooooooo
00Cooooo00?o0?nWooooooooool00oooool01OmGo`3ooooooooooooooooo8?l000?ooooo00Co0?m<
oooooooooooo03Co0_ooool03OmG0?ooooooo`1mool0of_o6P3oooooool0oi_o0?o`ooooool02_oo
ooooo`10oolho`003?ooool6obH0o`03oooooomMo`3o0?o`00?oGOl01_ooool2oego0008o`0dool0
f?ooGOl0oego0?ooooooHol0ocko0?lho`02ooooo`04oeL0ool0oiGo0?nEo`3oU@;ooooo00CoEol0
ofT0oooooooo08oo2oooool00olJ0?ooooooooooo`0?ooooo`03oed0oooooooo08oo00cooooo00?o
Eol0ooooooooool01Oooool2o`0:o`gooooo00?o0?m<ooooooooool01?ooool00omY0?oooooooooo
o`08ooooo`;o?_l000?o0?o`ooooooooool0:?ooool2o`0doaKooooo0ol0@?mDooooo`Oo0?nE=Ooo
ool5o`3Hoc_ooooo001Cooooo`03o`000?oooooooooo00oooooo00Co02SooeL0oomY0?oo09Go0_oo
ool00ol01?oo8?l0ooooo`02ooooo`03o`04oolPo`3o0?lF00;ooooo00Co09GoooooooooooooJ@3o
1?ooool02?mGo`3o03CooeL0oooooooo00[oooooool0@?oo?_l00_ooool00olV0?oo>?l0ooooo`02
ooooo`06oego0?ooooooHol0o`0^oooooooo0?3o1?ooool00ol0C?oo0:koo`3Ho`07ooooo`;o0?mU
0oooool2o`0Xo`03o`3o:?l0i?oo0>Co00?ooooo0ol0oc@Dooooo`04o`3o:?oooooo0?ldo`3o=0;o
0>Co00Ooooooo`0Xooooooooooooo`3oIOoooooo0?l:00Cooooo00Ko0?nEooooool0[_oo04coof?o
0?mMo`02ooooo`0Ao`0^oooooooo>?l0oooooolV0?oo00[ooooooolJ0?oo0?nKoeL0ool0oo3ooooo
ob3o0?l0odco03CooooooomGo`001_ooool6o`3oY`Gooooo00GoEol0ooooooooooooooooob3o0003
ooooo`04o`3oC?ooooooooooo`0do`;ooooo00goE`3oooooool0OOoooooooaX0oooooooo0?nKo`3o
l?oooooo00[oooooool0@?oo>?l000Wooooo1?lV0?l2of?o0004ooooool0l?oooooooego00;o9P3o
00?oooooo`3ol?ooool01oooool2o`3Ho`04o`0dool0odcoooooooooo`;oGOl000Go?_l0ocSo0?l0
oiGo0?nEoeL0o`05ooooo`04oeOo0?mY0?ooooooo`2?o`cooooo00?o6P3oooooooooool03oooool0
0omM0?ooooooooooo`0:ooooo`03oeOo0?oooooooooo00Sooooo0_l02_l:ooooo`03o`3oC?oooooo
oooo00Cooooo00?oJ@3oooooooooool01oooool2ocko0003ooooool0oo3ooooo02Sooooo0_l0=?lK
ooooo`?o043oF?ooool7o`3oUFkooooo001Cooooo`03o`000?oooooooooo00oooooo00Ko09_ooeL0
oomY0?oo6P3oo`3o5_ooool6o`04o`07o`3o5_ooooooooooooooool0UOooooooofT0o`05ooooo`07
o`3oC?lJ0?ooE`3oo`0:oooooooo043oocko0002ooooo`03obH0oolho`3ooooo00?ooooo00KoGOl0
oooooomSo`3o02koooooool0l?l3ooooo`03o`1<ool0[_oo0=So00Kooooo0_l0ofD3ooooo`;o02So
00?o0?lXo`3Tool0i?l00_ooool3o`3o=1Sooooo0ol0obP01?oooooo0?ldo`3Tooooool2o`0Xo`04
ooooool0ofGoooooo`3o2PCooooo00Go0?nEo`2^ool0C?oooooooego0002ooooo`0?o`3`ool0;_oo
>?l0oooooolV0?oo00[ooooooolJ0?oo0?nKo`1moomG0?oo0?o`ob3o0?oooooo03Co00;ooooo00?o
Eol0ooooooooool03Oooool01OmGo`3ooooooooooooooooo8?l000?ooooo00Co0?m<oooooooooooo
03Co0_ooool02_mG0?ooooooooooool0OOoo6P3oooooool0oi_o0?o`ooooool02_l2ooooo`03o`10
oolho`3ooooo00Oooooo00?o9P3oooooooooool00_mSo`02ooooo`03o`3`oomMo`3oGOl000?ooooo
0_lV0?l6ooooo`;o0=So0_ooool00ol0=?oo0?m<ooooo`03ooooo`;o0?nE00Co>?l0of?o0?oooooo
E`3o1Oooool01?mY0?ooooooooooool0Sol<ooooo`03oaX0oooooooooooo00gooooo00?o08oooooo
oomM0?l02_ooool00omGo`3oooooooooo`0;ooooo`;o00[o1oooool00ol0odcoooooooooo`04oooo
o`03ofT0oooooooooooo00Kooooo0_lno`02ooooo`03o`3ol?oooooooooo02Kooooo0_l0=?lPoooo
o`;o043oGOooool:o`3oUFCooooo001Cooooo`03o`000?oooooooooo00oooooo00Co0?ldobH0oomG
0?ooJ@3o0_l0UOl5ooooo`03o`3o5_oooooooooo00;o09Go00?oooooofT0ooooool01?ooool01ol0
odco6P3ooeL0ool02_oo0?m[o`10oolno`000oooool00olV0?oo>?l0ooooo`02ooooo`06oego0?oo
ooooHol0o`0^oooooooo0?3o0oooool00ol0C?oo0:koo`3Ho`06ooooo`04o`3oIOoooooooooooooo
o`;o02So0_l0obP00ol0i?ooooooo`3o=002o`3o=0Wooooo3ol0ogL6ooooo`;o0?lX00So0?ldo`3T
ool0i?ooooooo`0Xool0ofGoooooo`3o2PCooooo01Oo0?nEooooool0[_oo04coof?o0?mMo`3ooooo
o`3`ool0;_ooooooocSo0?oooooo9P3ooooooolJ0?oo0?nKo`1moomG0?oo0?o`oooooolPo`3o0?m<
o`0do`02ooooo`03oeOo0?oooooooooo00_ooooo00GoEol0ooooooooooooooooob3o0003ooooo`04
o`3oC?ooooooooooo`0do`;ooooo00[oE`3ooooooooooooo07goo`3oJolJ0?ooooooo`3oVol0oo3o
00[o0_ooool00ol0@?oo>?l0ooooo`06ooooo`;o9P3o0_ooool01OmSo`3ooooooooooooooooo0?3o
00Oooooo00?o0?o`obH0ooooool00oooool00ol0f?ooooooooooo`02ooooo`03o`0dool0odcooooo
00?o0?nE00Koooooocko0?oooooo>?l0of?o0?mG0?l5ooooo`04oeOo0?mY0?ooooooo`2?o`cooooo
00?o6P3oooooooooool03Oooool00ol0Sooooooooed0o`09ooooo`04oeOo0?ooooooooooooooo`go
0?mU0_l02_l;o`3oI@03ofT0ool0ofGo0?mU00;o0?mU0oooool2ocko00Cooooo00?o0?o`oooooooo
ool09?ooool2o`0dobCooooo0ol0@?mTooooo`co0?nEF?ooool005?ooooo00?o0000ooooooooool0
4?ooool02?l04?ooE`3oofT0oolJ0?ooooooo`2Eool0oaKooooo0ol0oaH00ooooooo09Goooooo`02
ooooo`03ofT0oooooooooooo00?ooooo00Oo6P3ooeL0ool02_oo07goo`10oooooooo?_l000;ooooo
00?o9P3oocSo0?ooool00_ooool01_mMo`3oooooof?o0?l0;_ooooooo`3`o`?ooooo00?o04coo`2^
ool0f?l01Oooool2o`3oI@?ooooo00?o02Soo`3o:?l0obP00_l0i?l00ooooooo0?ldooooo`09oooo
o`;o0?mg3oooool4o`3oM`Cooooo00Wo0?lXo`3o=?oooooo0>Coooooool0:?oo0?mUooooool0o`X0
1?ooool01Ol0oiGoooooo`1<oomSo`3oGOl000;ooooo00oo02kooooooolho`3oooooobH0ool02_oo
oooooaX0ool0oi_oE`3oo`3ol?oooooo8?l0ooooool0=?l00_ooool00omGo`3oooooooooo`0:oooo
o`05oeOo0?oooooooooooooooolPo`001?ooool00ol0odcoooooo`0do`03ooooo`0=oeL0oooooooo
07goocko0?lJ0?ooooooo`3oVol0oo3oooooo`0:oooooooo043oocSo0007ooooo`05obH0oooooooo
oooooooooomSo`000_ooool00omMo`3o0?3oooooo`08ooooo`03obH0oooooooooooo00;o0=So1Ooo
ool00ol0=?oo0?nEo`3oU@05ooooo`05ocko0?lho`3oGOl0oeL0oomSo`001Oooool00omY0?oooooo
o`2?o`0=ooooo`03oaX0oooooooooooo00_ooooo00Go08oooooooooooooooooooed0o`0<o`3oI@oo
oooo0_l02_l2ooooo`03o`3oC?oooooooooo00?ooooo00?oJ@3oooooooooool00oooool8o`3oI@03
o`3ol?l0ofGooooo02?ooooo0_l0=?lYooooo`?o043oKOooool:o`3oU@gooooo1_lho`0kooooo`00
Doooool00ol0003oooooooooo`0@ooooo`08o`0XoolV0?ooE`3oofT0oooooooo09Goooooool0oaH3
ooooo`05o`2EoooooooooooooooooomY0?l01Oooool01olJ0?ooE`3oo`0:ool0OOoo043oooooooln
o`000_ooool00olV0?oo>?l0ooooo`02ooooo`06oego0?ooooooHol0o`0^oooooooo0?3o0oooool0
0ol0C?oo0:koo`3Ho`05ooooo`04o`3oIOooooooooooooooo`;o02So00Co0?lXooooool0i?oooooo
0_l0oc@8ooooo`?o0?mg1?ooool7o`23o`[ooooo0ol0ogL2ooooo`09o`3o:?l0ocCo0?ldo`3Toooo
oooo02Soo`3oIOoooooo0?l:00Cooooo00Co0?nEo`1<ool0f?ooGOl00_ooool03ol0l?oo02koocSo
0?oooooo9P3oo`0:oooooooo6P3oo`3oVol0OOooE`3ooooooolPo`3oooooo`0do`03ooooo`;oEol0
2Oooool00omGo`3oooooooooo`02ooooo`05ob3o0?ooooooooooooooool0od`00_ooool01?l0=?oo
oooooooooomG0?l2ooooo`07o`1moolJ0?ooooooooooool0oo3oooooo`0:o`02ooooo`03o`10oooo
oooooooo00Gooooo00Go9P3oooooooooooooooooof?o0002ooooo`03oego0?l0l?oooooo00Wooooo
00?o0?o`obH0ool0f?l01_ooool2o`3oU@03o`0dool0odcooooo00Cooooo00Ko?_l0oooooolho`3o
oooooeL0oomSo`04ooooo`04ofT0ooooooooooooo`2?o`gooooo00?o6P3oooooooooool02?ooool2
o`3oI@06o`2?ool0ofGo0?mUo`3oIOooooooG@3o1Oooool00omGo`3oooooooooo`0Dooooo`?o00[o
1?ooool00omY0?ooooooooooo`03ooooo`;o?_l01_ooool00ol0oo3oooooooooo`0;o`3oIAOooooo
0_l0=?l^ooooo`;o043oMOooool8o`3oU@Go>?l0@Oooool005?ooooo00?o0000ooooooooool04?oo
ool01_l0Vooo9P3ooeL0ool0@?ooJ@3oooooo`Go09Go0oooool00omY0?ooooooooooo`03ooooo`07
oaX0ool0=?ooE`3oo`1mool0@?ooooooocko0003ooooo`0:obH0oolho`3ooooooooooomMo`3ooooo
of?o0?l0;_ooooooo`3`o`?ooooo00?o04coo`2^ool0f?l01?ooool2o`3oI@;ooooo0_l0:?l01?l0
obSoooooo`3Tool0i?l2o`3o=0Oooooo0ol0ogL2ooooo`Ko08?o1_ooool6o`23o`Oooooo00co0?mg
ooooooooooooooooo`3o:?l0ocCo0>Coo`0Xoooooooo0?mUooooool0o`X3ooooo`0Fo`3oUOoooooo
04coof?o0?mMo`3oooooo`3`ool0;_ooooooocSo0?oooooo9P3ooooooolJ0?oo0?nKo`1moomG0?oo
0?o`oooooolPo`3oooooo`0do`Cooooo00?oEol0ooooooooool01?ooool2oeOo00Cooooo00Go8?l0
ooooooooooooooooo`3oC002ooooo`04o`0doooooooooooooeL0o`;ooooo00Oo07gooaX0oooooooo
ooooo`3ol?oooooo00[o00;ooooo00?o043oooooooooool01Oooool01OlV0?oooooooooooooooooo
Hol000;ooooo00?oGOl0o`3`ooooool02oooool00olV0?ooooooooooo`03ooooo`;o0?nE0_ooool0
0ol0=?oo0?m<ooooo`05ooooo`04ocko0?oooooo>?l0oeL0o`;oGOl000OoHol0ooooooooooooEol0
ofT0oooooooo08oo00gooooo00Co6P3ooooooooooooooooo1ol0ofD00ooooooo08ooooooo`05oooo
o`05oed0oooooooooooooooooomGo`005oooool00ol0odcoooooooooo`02o`0:o`03oooooomY0?oo
oooo00?ooooo0_lno`08ooooo`03o`3ol?oooooooooo00_ooooo1_l0ofD?ooooo`;o03Co<_ooool3
o`10ofSooooo3?lho`06ooooo`Oo0?nE?oooool005?ooooo00?o0000ooooooooool04?ooool01_l0
ocCo013oobH0oomG0?ooooooofT0o`Oooooo00?oJ@3oooooooooool00oooool01olJ0?oo03CooeL0
ool0OOoo043ooooooolno`000oooool02olV0?oo>?l0ooooooooooooGOl0oooooomSo`3oooooo`0^
oooooooo0?3o00;ooooo00?o04coo`2^ool0f?l01?ooool01_l0ofGooooooooooooooooo02Soo`3o
:0;ooooo00?o0>Coo`3o=?l0oc@01_ooool3o`3oM`;ooooo0ol0Pol2ooooo`oo013o00?oooooo`23
ool0Pol00_l0Pol4ooooo`;o0?mg0_ooool01ol0obSo0?ldo`3Tool0:?oo0?mUooooool0o`X01?oo
ool01?l0oiGo04coo`3HoomMo`02ooooo`0;o`0^oooooooo>?l0oooooolV0?oo00[ooooooolJ0?oo
0?nKoeL0ool0oo000_ooool00olPo`3o03Coooooo`03ooooo`OoEol01Oooool01OlPo`3ooooooooo
oooooooo0?m<00;ooooo00Co03CoooooooooooooE`3o0_ooool02_l0OOoo?_l0oaX0oooooooo0?o`
o`3oVooooooo00[oooooool0@?l7ooooo`05obH0oooooooooooooooooomSo`000_ooool00omMo`3o
0?3oooooo`0;ooooo`03o`3Hool0oo3o9P3o00;ooooo0_l0oiD4ooooo`03o`0dool0odcooooo00Go
oooo00Co?_l0oooooolho`3oE`3o0_ooool01omMo`3oHol0ooooooooooooJ@3oooooool0Sol02ooo
ool3o`3oI@03oaX0ool0ofGo0?mU00Oooooo00?o08ooooooooooool01Oooool01?mM0?oooooooooo
oomGo`0Hooooo`03o`3oC?oooooooooo00;ooooo00?o00[oofT0ooooool00_ooool00olno`3ooooo
ooooo`07ooooo`03o`3ol?oooooooooo01;ooooo1Ol0ofD9ooooo`03o`0doooooooooooo03Gooooo
0ol0@?mJooooo`_o>?l06Oooool4o`3oUC_ooooo001Cooooo`03o`000?oooooooooo017ooooo00Co
013oobH0oomG0?oo043o0_mY0?l4ooooo`;oJ@3o1Oooool01OlJ0?oo03CooeL0ool0OOoo043o00;o
oooo00Go?_l0oooooooooooo9P3oocSo0002ooooo`07oego0?ooooooHol0ooooool0;_ooooooo`3`
o`02ooooo`03o`1<ool0[_oo0=So00Cooooo00?o0?mUooooooooool00_l0:?l2ooooo`;o0>Co00?o
0?ldooooooooool00oooool3o`3oM`;ooooo0ol0Pol5o`0@o`oo05;o1?l04?l00ooooooo08?ooooo
o`04ooooo`0:o`3oMooooooo0?lXooooool0ocCo02Soooooool0ofGoooooo`3o2P?ooooo00Co0?nE
o`1<ool0f?ooGOl00_ooool02ol0l?oo02koocSo0?oooooo9P3oo`0:oooooooo6P3oo`3oVol0OOoo
E`3o00;ooooo00?o8?l0o`3oC?l0=?l03_ooool01OlPo`3ooooooooooooooooo0?m<00;ooooo00Co
03CoooooooooooooE`3o0_ooool02_l0OOoooooooaX0oooooooo0?o`o`3oVooooooo00[oooooool0
@?l7ooooo`06obH0oooooooooooooooooomSo`3ooooo0_mMo`000ooooooo0?3oooooo`0:ooooo`06
o`3Hoooooooo0?o`oooooolV0?oo0?nE1_ooool00ol0=?oo0?m<ooooo`06ooooo`03ocko0?oooooo
E`3o00?ooooo00CoGOl0of?o0?ooooooJ@3o0_ooool00ol0Soooooooooooo`03ooooo`Go0?mU0ooo
ool00olJ0?ooooooooooo`06ooooo`03o`2?oooooooooooo00Oooooo00?oG@3ooooooomGo`005ooo
ool00ol0odcoooooooooo`03ooooo`03ofT0oooooooo00[o00;o00[o2_ooool00ol0oo3ooooooooo
o`0Gooooo`Co0?mU0oooool2o`0doc_ooooo0ol0@?m=ooooo`[o>?l0Hoooool005?ooooo00?o0000
ooooooooool04Oooool01_l04?oo9P3oo`3oYomG0?oo043ooaX0o`GoJ@3o1Oooool01OlJ0?oo00[o
oeL0ool0OOoo043o00;ooooo00Go?_l0ooooooooooooooooobH0o`02ooooo`07oego0?ooooooHol0
ooooool0;_ooooooo`3`o`02ooooo`03o`1<ool0[_oo0=So00Cooooo00Co0?mUooooool0:?oo02So
0oooool00ol0i?ooooooo`3o=004ooooo`;o0?mg0_ooool3o`23o`?o013o1?l0D_l@ooooo`Co05;o
0_l04?l2o`23o`Cooooo00Wo0?mgooooool0obSoooooo`3Tool0:?ooooooo`3oIOl0o`X01?ooool0
4Ol0oiGo04coof?o0?mMo`3oooooo`3`ool0;_ooooooocSo0?oooooo9P3ooooooolJ0?oo0?nKo`1m
oomG0?oo0?o`00;ooooo00?o8?l0o`3oC?l0=?l03?ooool00olPo`3oooooooooo`02ooooo`03o`3o
C?oooooo03Co00?ooooo00GoE`3ooooooooooooo07gooaX0o`02ooooo`03o`3ol?oooooo00[o00;o
oooo00?o043oooooooooool01?ooool01olV0?ooooooooooooooooooHol0oooooomMo`000_ooool0
0ol0l?ooooooooooo`09ooooo`06o`3Hooooooooooooooooool0oo3o9P3o1oooool00ol0=?oooooo
o`3oC006ooooo`04ocko0?oooooooooooeL0o`?ooooo00CoGOl0oooooomY0?ooEol00_ooool00ol0
Sooo0?mUo`3oI@02o`3oI@Wooooo00?o6P3oooooooooool01Oooool00ol0Soooooooooooo`08oooo
o`03oed0oooooooooooo01Gooooo00?o0?m<ooooooooool00oooool01?mY0?ooooooocko0?lno`02
ooooo`;o00[o1oooool00ol0oo3oooooooooo`0Looooo`04o`3oIOl0=?oo03Coo`3oICoooooo0ol0
@?m2ooooo`So>?l0KOooool005?ooooo00?o0000ooooooooool04Oooool02?l0FOoo013oobH0oooo
ooooE`3oo`3ol?oooooo6P3o1Oooool3oaX0o`04o`0:oomG0?oo07goo`10o`;ooooo01?o?_l0oooo
ooooooooooooobH0oolho`3ooooooego0?ooooooHol0ooooool0;_ooooooo`3`oooooooo0?l:o`1<
ool0[_oo0=So00?ooooo0_l0ofD00ooooooo02Soo`3o:002ooooo`;o0>Co00?oooooo`3o=?ooool0
0oooool00ol0ogOoooooooooo`02o`23o`;ooooo00Co013oo`1Bool0D_oo05;o6?ooool2o`1Bo`03
o`0@oooooooo08?o00Cooooo00Go0?mgooooool0obSoooooo`0Xo`02ooooo`03o`3oIOl0o`[ooooo
00;ooooo017o0?nEo`1<ool0f?ooGOl0ooooool0l?oo02kooooooolho`3oooooobH0ool02_oo?_l0
oaX0ool0of_oE`3oo`3ol003ooooo`03ob3o0?l0=?oooooo00[ooooo00?o8?l0ooooooooool00_oo
ool00ol0odcoooooo`0do`03ooooo`0:oeL0ooooooooooooo`1moolno`3o6P3oooooool0oo3o0?nK
o`0:o`;ooooo00?o043oooooooooool01?ooool01olV0?ooooooooooooooooooHol0oooooomMo`00
0_ooool00ol0l?ooooooooooo`09ooooo`08o`3Hooooooooooooooooool0oiGo0?o`oooooolV0?l7
ooooo`03o`0dool0odcooooo00Gooooo00Co?_l0ooooooooooooE`3o1?ooool00omMo`3oooooofT0
o`02o`3oI@03o`2?oooooooooooo00cooooo00?o6P3oooooooooool00oooool00ol0Sooooooooooo
o`08ooooo`03oeOo0?ooooooG@3o01Kooooo00?o0?m<ooooooooool00_ooool00omY0?ooooooocko
0006ooooo`03o`0:oooooooooooo00?ooooo00?o0?o`ooooooooool07Oooool01?l0=?oooooooooo
ooooool4o`3oICkooooo0ol0@?lhooooo`Oo>?l0MOooool002Sooooo00?ogMgMoeEEEOl000000_l0
00000omEEEGogMgMooooo`05ooooo`03ogMgMol0003oMgMg00cooooo0ol0000<ooooo`03o`000?oo
oooooooo01;ooooo00Oo013oobH0ool0ojOo07gooeL0ool0@?oo00[o00Go6P3o0ol02_l00omG0?oo
043oo`10o`02ooooo`0Cocko0?oooooooooooooooolV0?oo>?l0oooooomMo`3oooooof?o0?oooooo
02koooooool0l?ooooooo`3o2_oooooo04coo`3Ho`03ooooo`04o`3oIOooooooooooo`0Xo`?ooooo
00Co0>Cooooooooooooo0?ld0oooool2o`3oM`03ooooool0Pooo08?o00;ooooo0_l04?l00ol0D_oo
ooooooooo`0Kooooo`03o`1Bool04?oo013o00;o08?o0oooool02?l0ogOoooooo`3o:?l0ocCo02So
ooooool0ofGo0?l:0oooool01?l0oiGo04coo`3HoomMo`02ooooo`0;o`0^oooooooo>?l0oooooolV
0?oo00[ooooooolJ0?oo0?nKo`1moomG0?l01?ooool00ol0odco03Coooooo`07ooooo`;o8?l00ooo
ool2o`3oC003ooooool0=?oooooo00;ooooo00goE`3ooooooooooooo07gooooooolJ0?ooooooo`3o
l?l0oi_oooooo`0:oooooooo043o00Oooooo00Ko9P3oooooooooooooHol0oooooomMo`02ooooo`03
o`3`oooooooooooo00Wooooo00Oo0=Soooooooooooooooooo`3oUOoooooo0?o`00;ooooo00?o9P3o
ooooooooool01?ooool00ol0=?oo0?m<ooooo`06ooooo`04ocko0?ooooooE`3oocSo00?ooooo0_l0
ofD01OmY0?ooEol0oooooooooooo08oo00gooooo00?o6P3oooooooooool00_ooool00ol0Sooooooo
ooooo`08ooooo`05oeOo0?oooooooooooooooomM0?l05?ooool00ol0odcoooooooooo`02ooooo`03
ofT0oooooooo?_l000Sooooo0_l02_l3ooooo`03o`3ol?oooooooooo01_ooooo0_l0=?l8ooooo`Co
0?mU?Oooool3o`10obgooooo2?lho`1looooo`009oooool02Oo<c<co0000o`000?nj^[[oooooomgM
gOlQ8B7o0000olc<c005ooooo`?o00003?ooool3o`0000cooooo00?o0000ooooooooool04_ooool0
1?l04?oo02SoobH0ool0ojL2oeL0o`03o`10oooooooo00[o00Co00[o0_mG0?l01Ol0@?oo0?nWoooo
oooooooo?_l000?ooooo00So9P3oocSo0?mMo`3oGOl0oooooomSo`3oooooo`0^o`;ooooo00Go0?3o
o`3o2_oooooo04coo`2^o`03ooooo`04o`3oIOoooooo0?lXo`0Xo`;ooooo0_l0i?l2ooooo`06o`3o
=?ooooooooooooooool0ogOooooo0_l0Pol01?oooooo013oo`0@ool04?l2o`3foaoooooo0_l0D_l0
0ol04?oo0?Koo`23o`03ooooo`08o`3oMol0obSoooooo`3o=?l0:?ooooooo`3oIOl0o`X3ooooo`03
o`3oUOl0C?ooGOl000;ooooo00co0?3oo`0^oooooooo>?l0oooooolV0?oooooooaX0ool0oi_o07go
oeL0ool0oo04ooooo`03o`3oC?l0=?oooooo00Gooooo00?o8?l0ooooooooool00_ooool01?l0odco
ooooooooool0=?l3ooooo`0;oeL0ooooooooooooo`1moooooooo6P3oooooool0oo3oooooo`3oVol0
2_l00_ooool00ol0@?ooooooooooo`04ooooo`06obH0ooooooooooooof?o0?ooooooGOl00_ooool0
0ol0l?ooooooooooo`09ooooo`05o`3Hooooooooooooooooool0oiD00oooool00ol0oo3oooooobH0
o`06ooooo`03o`0doooooooo0?m<00Kooooo00Co?_l0oooooomG0?oooooo0ol0ofD2ooooo`03ofT0
ooooooooEol000;ooooo00?o08ooooooooooool02oooool01?lJ0?ooooooooooool0Sol:ooooo`03
oeOo0?oooooooooo00;ooooo00?oG@3oooooooooool04_ooool01ol0odcoooooooooooooooooJ@3o
oooooolno`002oooool2o`0:o`03o`3ol?oooooooooo01[ooooo0_l0=?l>ooooo`Co0?mU??ooool3
o`10ob;ooooo2?lho`0nooooo`_o0:ko>oooool002Kooooo00CogMgMo`000?l0003o^[Zj0oooool0
1?o^k^ko0000o`000?o^k^h4ooooo`03ogMgMol0003oMgMg00cooooo0ol0000<ooooo`03o`000?oo
oooooooo01;ooooo00Ko013oo`0Xool0oi_o9P3oooooool0=?l2oeL0o`03o`3ol?l0odco0?o`00;o
E`3o00?oooooo`10ool0ojL00_ooool01olno`3ooooooooooooooooo9P3oo`3oVomMo`000_ooool0
2omSo`3oooooooooool0;_ooooooo`3`ool0o`[oooooo`1<ool0[_oo0=So00;ooooo00Co0?mUoooo
ool0obSo02So0_ooool00ol0i?ooooooooooo`02o`3o=0;ooooo0_l0ogL2o`23o`03ooooool04?oo
013o00?o0?Ko2_ooool<o`3oF@gooooo00Co05;oo`0@ool0m_oo08?o0_ooool02?l0ogOoooooo`3o
:?l0ocCo0>Coo`0Xool0ofGo0?l:0oooool04Ol0oiGo04coo`3HoomSo`3oooooo`3`ool0;_oooooo
ocSo0?oooooo9P3oo`0:oolJ0?oo0?nKo`3oJomG0?oo0?o`00Gooooo00?o8?l0o`0doolPo`001?lP
o`03ooooo`;o0?m<0_ooool00ol0=?ooooooooooo`02ooooo`0:oeL0ooooooooooooo`1moolno`3o
6P3oo`3ol?oooooo0?nKo`0:o`;ooooo00?o043oooooooooool01?ooool01_lV0?oooooooooooomS
o`3ooooooego00?ooooo00?o0?3oooooooooool02?ooool01Ol0f?oooooooooooooooooo0?nE00Co
oooo00?o0?o`oooooolV0?l01_ooool00ol0=?ooooooo`3oC007ooooo`04ocko0?l0ofGoE`3oocSo
00Cooooo00?oJ@3ooego0?mGo`000oooool00ol0Soooooooooooo`0:ooooo`03oaX0oooooooo08oo
00[ooooo00?oEol0ooooooooool01?ooool00omM0?ooooooooooo`0@ooooo`07o`3oC?oooooooooo
oooooomY0?ooooooocko000>ooooo`03o`0:oooooooooooo01Wooooo00?o03Coooooooooool04_oo
ool4o`3oIC_ooooo0_l0@?lHooooo`So>?l0=_ooool@o`2^odKooooo000Vooooo`03oeEEEOl0003o
8B4Q00Gooooo00?oEEEEo`000?mEEED04oooool3o`0000cooooo00?o0000ooooooooool04_ooool0
1ol0FOoo013oo`0^oolV0?oo0?nWooooool0=?l01OmG0?l2o`10o`04o`3oYooooooo?_l0ocko00?o
oooo00Co9P3oo`3oVomMo`3ooooo0_mSo`02ooooo`08o`0^oooooooo0?3oo`3o2_oooooo04coo`2^
ool0f?l2ooooo`04o`3oIOoooooo0?lXo`0Xo`;ooooo00Co0>Cooooooooooooo0?ld0oooool01?l0
ogOoooooo`23ooooool2o`0@o`03ooooool0m_oooooo00Oooooo1Ol0oeT<ooooo`Co0?mI2_ooool0
1?l0D_oo013oo`3fool0Pol2ooooo`07o`3oMooooooo0?lXo`3o=?l0:?oo0?mUo`3o2P03ooooo`0A
o`3oUOl0C?oo0=Sooego0?oooooo0?3oo`0^oooooooo>?l0oooooolV0?oo00[ooooooolJ0?oo0?nK
o`1moomG0?l01oooool00ol0=?oo0?m<ooooo`04ooooo`05o`3oC?ooooooooooooooool0=?l01?oo
ool03_mG0?ooooooooooool0OOoooooooaX0ool0oo3oooooo`3oVooooooo00[oooooool0@?oo>?l0
1Oooool01?lV0?oooooooooooomSo`02ooooo`04oego0?ooooooooooo`3`o`[ooooo00Go0=Sooooo
ooooooooooooo`3oU@05ooooo`04o`3ol?ooooooooooobH0o`Gooooo00?o03Coooooool0od`01Ooo
ool3o`3oI@04oooooomG0?ooooooocSo00Cooooo00?oJ@3oof?o0?mGo`000_ooool00ol0Sooooooo
ooooo`0;ooooo`03oaX0oooooooooooo00Sooooo00?oEol0ooooooooool01_ooool00omM0?oooooo
ooooo`0>ooooo`03o`3oC?oooooooooo00;ooooo00?oJ@3oocko0?ooool03Oooool01?l0oo3ooooo
o`0:ool02_lHooooo`03o`0doooooooooooo01Oooooo1?l0ofDiooooo`?o043o2oooool:ocSo02So
oooo5_l0[_mFooooo`009Oooool01?oMgMgo0000o`000?mgMgL5ooooo`04ohN7Qol0003o0000onk^
kQ;ooooo0ol0000<ooooo`03o`000?oooooooooo01;ooooo00Ko05Woo`0@ool0:?oo0?nKobH0ool0
ojL2ooooo`?o07go0_ooool00ol0ojOoooooocko0004ooooo`05obH0ool0oi_oGOl0oooooomSo`00
0oooool02Ol0;_ooooooo`3`ool0o`[oooooo`1<ool0[_oo0=Soooooo`02o`3oI@03o`3o:?l0:?oo
02So00;ooooo00Co0>Cooooooooooooo0?ld0oooool00ol0ogOo08?oo`23o`02o`0@o`;ooooo00?o
0?Koooooooooool01?ooool3o`3oFAGooooo0ol0oeT8ooooo`04o`1Bool04?oo0?Koo`23o`;ooooo
00Oo0?mgooooool0ocCo0>Coo`0Xool0ofGo0?l:00?ooooo00?o0:koo`1<oomMo`000_ooool03?l0
;_oooooooooooolho`3o9P3oo`0:oooooooo6P3oo`3oVol0OOoooooooeL0o`Oooooo00?o03Coo`3o
C?l0od`00ol0od`01?oooooo03Coo`0dool0=?l4ooooo`07oeL0ooooooooooooo`1moooooooo6P3o
o`3ol002ooooo`05o`3oVol02_ooooooo`10oolho`001Oooool01?lV0?oooooooooooomSo`02oooo
o`04oego0?ooooooooooo`3`o`[ooooo00Go0=Soooooooooooooooooo`3oU@07ooooo`03o`3ol?l0
o`[o9P3o00Ko0?l:00?o03Coo`3oC?ooool00_ooool2o`3oI@?ooooo00Co?_l0oeL0oooooooo>?l0
1?ooool01?mY0?ooGOl0of?o0?mGo`02ooooo`03o`2?oooooooooooo00Wooooo00?o08oooooooolJ
0?l02?ooool00omGo`3oooooooooo`08ooooo`03oed0oooooooooooo00gooooo00Ko0?m<oooooooo
ooooooooofT0oolno`0>ooooo`03o`3ol?oooooooooo00;ooooo00?o00[oooooooooool05?ooool0
0ol0=?ooooooooooo`0Looooo`Co0?mU>?ooool3o`10o`So>?l0:_ooool8o`2^ofcooooo000Uoooo
o`04ohN7Qol0003o0000okZj^PGooooo00Co^[Zjo`000?l0003oV9RH2Oooool?o`0000Wooooo00?o
0000ooooooooool04oooool00ol04?oo02Soo`0^o`02obH0o`03o`3oYooooooooooo00;ooooo0_l0
ojL00ooooooo?_l0ooooo`03ooooo`05obH0ool0oi_oGOl0oooooomSo`000oooool03Ol0;_oooooo
ooooool0l?ooooooo`1<ool0[_oo0=Soooooool0ofGoooooo`3o:?l0:?l00oooool01?l0i?oooooo
ooooool0oc@3ooooo`04o`3oMol0Poooooooo`0@o`;ooooo0_l0m_l4ooooo`?o0?mI6oooool3o`3o
F@Kooooo00co05;oo`0@ool04?oo08?oooooool0ogOoooooo`3o:?l0ocCo0>Coo`0Xool0o`X3oooo
o`0Ao`3oUOl0C?ooGOl0of?o0?oooooo0?3oo`0^oooooooo>?l0oooooolV0?oo00[ooaX0ool0oi_o
0?m[o`1moomG0?l02?ooool7o`0do`Gooooo00OoE`3oooooooooooooooooo`1moooooooo6P3o00;o
oooo00Go0?nKo`0:ooooooooooooo`10o`05ooooo`07obH0oooooooooooooooooomSo`3ooooooego
0002ooooo`03o`3`oooooooooooo00Sooooo00Go0=Soooooooooooooooooo`3oU@04ooooo`Co0?l:
00?o0?o`oooooolV0?l01_ooool00ol0=?oo0?l:o`3oI@02o`3oI@?o0?l:0_ooool01Olno`3oE`3o
oooooooooooo>?l000?ooooo00GoJ@3ooooooomMo`3oHol0oeOo0002ooooo`03o`2?oooooooooooo
00Kooooo00Go0>Coo`2?ool0i?oo0>CooaX0o`0Do`3To`03oed0ool0i?oo0>Co00Ko0>Co1Oooool0
1_l0odcoooooooooooooooooJ@3oocko00oooooo00?o0?o`ooooooooool00oooool2o`0:oa;ooooo
0_l0=?lSooooo`Co0?mU:_ooool:ocSo00?ooooo0ol0@?lXooooo`Oo0:koM?ooool002Gooooo00Co
A4A4o`000?l0003oc<c<1Oooool01?oMgMgo0000o`000?mEEED9ooooo`oo00002Oooool00ol0003o
ooooooooo`0Cooooo`06o`1Iool04?oo02koo`3oVomSo`3o9P3o1?l0ojL3ocko00Cooooo00Go9P3o
oego0?l0oi_oooooof?o0003ooooo`0:o`0^ooooooooooooo`3`oooooooo04coo`2^ool0f?oooooo
o`3oI@;o0?lX00Go02Soooooooooooooooooo`3To`02ooooo`04o`3o=?ooooooooooo`3oM`;o08?o
00Goooooo`0@ooooooooooooo`3fo`03ooooo`?o0?mI3Oooool9o`3o>P_ooooo0_l0oeT5ooooo`03
o`1Bool0m_oo013o00;ooooo00Oo0?mgooooool0ocCo0>Coo`0Xool0ofGo0?l:00?ooooo013o04co
o`3HoomSo`3oooooo`3`ool0;_ooooooocSo0?oooooo9P3oo`0:oooooooo6P3oo`3oVol0OOooE`3o
5?ooool03_mG0?ooooooooooool0OOoooooooaX0ool0oo3oooooo`3oVooooooo00[oooooool0@?oo
>?l01?ooool01olV0?ooooooooooooooooooHol0oooooomMo`000oooool00ol0l?ooooooooooo`07
ooooo`05o`3Hooooooooooooooooool0oiD00oooool2o`3o2PCooooo00Co0?o`oooooooooooo9P3o
1Oooool00ol0=?oo0?mUo`3oC005ooooo`;o0?l:00?oooooocko0?mG0?l00_ooool02olho`3ooooo
ooooooooooooJ@3ooooooomMo`3oHol0oeOo0?oooooo0>Co00;o08oo1?l0i?l3o`2?o`Cooooo00?o
6P3oooooooooool00_ooool00omGo`3oooooooooo`0=ooooo`03oed0oooooooooooo00Gooooo2Ol0
i?l00omY0?oo0>Coo`3To`07o`3To`Kooooo00?o0?o`ooooooooool01_ooool00ol02_oooooooooo
o`0>ooooo`03o`0doooooooooooo02Oooooo1?l0ofDNooooo`So>?l04?ooool2o`10oacooooo2_l0
[_mkooooo`009Oooool00olQ8B7o0000o`000007ooooo`;o000000?o<S8booooooooool01oooool0
0omEEEGoQhN7ooooo`06ooooo`?o00003?ooool4o`0001;ooooo00Ko05Woo`0@ool0:?oo0?lXo`3o
VolV0?l2oego00Oooooo0_lV0?l01?mMo`3o0?nKoooooomSo`03ooooo`04o`0^ooooooooooooo`3`
o`;ooooo00Oo04coo`3Hoooooooo0?mUo`3o:?oooooo02So00?ooooo00Co0>Coooooool0ocCo0?ld
0_ooool01_l0ogOo08?ooooooooooooo013oooooo`;o0?Ko0_ooool2o`3oF@Wooooo1ol0ocX8oooo
o`Ko0?lj2?ooool00ol0oeWoooooooooo`03ooooo`0;o`1Bool0m_oo013oooooool0ogOoooooo`3o
:?l0ocCo0>Coo`0Xool0o`X00oooool01_l0[_oo04cooego0?oooooo0?3oo`0^o`;ooooo00Wo>?l0
obH0ool0@?oo00[ooaX0ool0oi_o0?m[o`1moomG0?l04_ooool01omG0?ooooooooooool0OOoooooo
oaX0ool0oo000_ooool01Ol0oi_o00[oooooool0@?oo>?l000Gooooo00Ko9P3oooooooooooooHol0
oooooomMo`03ooooo`03o`3`oooooooooooo00Sooooo00Co0=Sooooooooooooo0?nE0_ooool2o`3o
2POooooo00?o0?o`oooooolV0?l00oooool2o`3oI@03o`0doooooooo0?m<00Oooooo0_l0o`X01OmG
0?oooooooooooolho`3ooooo00;o0>Co00?oJ@3oo`3Tool0i?l00ol0i?l3ooooo`Go08oo1_ooool0
1OlJ0?ooooooooooooooooooEol0017ooooo00?oG@3oooooooooool02?ooool01Ol0odcooooooooo
ooooooooJ@3o00[ooooo1_l0i?l00ol0oo3oooooooooo`07ooooo`03o`0:oooooooooooo00cooooo
00?o03Coooooooooool0;?ooool4o`3oIA;ooooo2?lho`0Jooooo`?o043o4?ooool9o`2^ohGooooo
000Uooooo`?o00001oooool3o`0000[ooooo00?o8B4QokZj^_ooool01Oooool3o`0000cooooo00?o
0000ooooooooool04oooool01_l0Vooo013oo`0Xool0;_ooooooo`3oV`;o9P3o0_mMo`04ooooo`04
obH0oomMo`3oGOl0o`3oV`;oHol00oooool01?l0;_ooooooooooool0l?l2ooooo`07o`1<ool0f?oo
ooooo`3oIOl0obSoooooo`0Xo`03ooooo`03o`3Toooooooo0?ld00?ooooo00?o0?mgo`23ooooool0
0_l04?l01?oooooo0?Koooooooooool2o`3oF@Sooooo0ol0ocX7ooooo`_o0?lR0oooool3o`3o>PKo
oooo00?o0?mIooooooooool00oooool02ol0D_oo013oo`23oooooooo0?mgooooool0ocCo0>Coo`0X
ool0ofGo0?l:00;ooooo00Ko0:koo`1<oomMo`3oHol0ooooool0;_l2ooooo`0:ocSo0?oooooo9P3o
o`0:oolJ0?oo0?nKo`3oJoooooooE`3oo`3ol13ooooo00CoE`3ooooooooooooo07go0_ooool01OlJ
0?ooooooooooool0oi_o00[o00;ooooo00?o043oooooooooool00oooool01_lV0?oooooooooooooo
ooooHol0oego00?ooooo00?o0?3oooooooooool02?ooool01?l0f?ooooooooooool0oiD3o`3o2PWo
oooo00?o0?o`oooooolV0?l00ol0ofD2ooooo`03o`0doooooooo0?m<00Wooooo00?oE`3oo`3o2_l0
i?l00_l0i?l2ooooo`06ofT0oooooooooooooooooomMo`3oEol03oooool00olJ0?oooooooeOo000C
ooooo`03oed0oooooooooooo00Kooooo00Ko0?m<ooooooooooooooooocko0?mY0?l?ooooo`03o`3o
l?l0i?oo0>Co00?o0>Co1_ooool00ol02_ooooooooooo`0:ooooo`03o`0doooooooooooo037ooooo
0ol0ofD8ooooo`Oo>?l09Oooool3o`10o`Oooooo1_l0[_n>ooooo`009Oooool3o`0000Oooooo0ol0
000:ooooo`03omgMgOl@413ok^k^00Gooooo0ol0000<ooooo`03o`000?oooooooooo01Cooooo00Oo
05Woo`0@ool0C?oo02koo`3oVol0o`[oHol000Ko9P3o00Co>?l0o`3oVol0oi_oHol01?ooool01?l0
;_ooooooo`3o2_l0l?l2ooooo`07o`1<oooooooo0=Soo`3oIOl0obSoooooo`0Xo`03ooooo`03o`3T
oooooooo0?ld00?ooooo0_l0Pol01_oooooo013ooooooooooooo0?Koooooo`;o0?mI1_ooool4o`3o
>PCooooo1_l0ob8;ooooo`Co0?lR0_ooool3o`3o>PCooooo00?o0?mIooooooooool00oooool02_l0
D_oo013ooooooooooooo0?mgo`3o:?l0ocCo0>Coo`0Xool0o`X3ooooo`0Bo`1<ool0f?ooHol0oooo
ool0l?oo02kooooooolho`3oooooobH0ool02_oooooooaX0ool0oi_o0?m[o`1moomG0?oo0?o`3_oo
ool01omG0?oooooooooooooooooo07gooooooolJ0?l00_ooool01_l0oi_oooooo`0:oooooooo043o
ocSo00Cooooo00Oo9P3oooooooooooooooooof?o0?ooooooGOl000?ooooo00?o0?3oooooooooool0
1oooool01Ol0f?ooooooooooool0oiGo0?l:00cooooo00?o0?o`o`3oIOlV0?l01_ooool00ol0=?oo
ooooo`3oC005ooooo`?o0>Co00SoE`3oo`3Tool0o`[o0?l:oooooolho`3oooooofT0o`Cooooo00?o
GOl0oeOo0?mGo`003Oooool00olJ0?ooEol0ooooo`0Dooooo`03oed0oooooooooooo00Gooooo00Go
0?m<oooooooooooo?_l0ofT0o`0?ooooo`03o`3ol?oooooooooo00Cooooo1?l0i?l3ooooo`;o00[o
2Oooool00ol0=?ooooooooooo`0eooooo`Co0?mU1?lho`0_ooooo`?o043o1?l0[_nDooooo`009Ooo
ool3o`0000Oooooo0ol0000;ooooo`03okZj^_lQ8B7ooooo00Cooooo0ol0000<ooooo`03o`000?oo
oooooooo01Cooooo00Go05Woo`0@ool0:?oo0:koo`0^o`02o`3oV`;oHol00oooool2o`3oV`;oHol0
1?ooool01?l0;_ooooooo`3o2_l0l?l2ooooo`04o`1<oooooooo0=Soo`3o:0;ooooo00Oo02Sooooo
ooooooooooooo`3Toooooooo0?ld00?ooooo00Go08?oooooool0D_oo013oooooo`02o`3fo`;o0?mI
1Oooool3o`3o>PCooooo1?l0ob87ooooo`Wo0>[o1Oooool3o`3o8P;ooooo0_l0ocX3ooooo`03o`3o
FOoooooooooo00;ooooo00[o05;oo`3fool04?ooooooo`3oMooooooo0?ldo`3Tool0:?oo0?l:0ooo
ool01_l0[_oo04cooego0?oooooo0?3oo`0^o`;ooooo00[o>?l0obH0ool0@?oo00[ooaX0ool0oi_o
ooooo`3oJol0OOooE`3o3Oooool01omG0?oooooooooooooooooo07gooooooolJ0?l00oooool01Ol0
oi_o00[oooooool0@?oo>?l000Gooooo00Ko9P3oooooooooooooooooof?o0?mMo`03ooooo`03o`3`
oooooooooooo00Oooooo00Go0=Sooooooooooooo0?nEo`3o2P0<ooooo`05o`3oIOl0oo3ooooooooo
oolV0?l01Oooool00ol0=?ooooooo`3oC005o`3To`?ooooo00Co?_l0oeL0oooooooooooo0_l0o`X2
ooooo`03ofT0oooooooooooo00;ooooo00?oGOl0of?o0?mGo`003?ooool00omGo`3o6P3oooooo`0E
ooooo`03oed0oooooooooooo00?ooooo00Go0?m<oooooooooooo?_l0ofT0o`0@ooooo`03o`3ol?oo
oooooooo00Sooooo1Ol0i?l00ol02_ooooooooooo`05ooooo`03o`0doooooooooooo03;ooooo1_lh
o`02ooooo`Co0?mU:_ooool6o`2^o`;ooooo0ol0@?nEooooo`009Oooool3o`0000Oooooo0ol0000<
ooooo`03ohN7QomEEEGooooo00?ooooo0ol0000<ooooo`03o`000?oooooooooo01Cooooo00Oo09_o
o`0@ool0:?oo04coo`0^oooooooo0?l:00Go0?nK0_mSo`05ooooo`04o`0^ool0o`[o0?l:o`3`o`;o
oooo00Go04coooooool0f?oo0?lXooooo`02o`0Xo`;ooooo0_l0i?l00ooooooo0?ldooooo`02oooo
o`06o`23oooooooo013oo`0@oooooooo0?Ko0_l0oeT5ooooo`;o0?lj1?ooool3o`3o8PKooooo0_l0
j_l?o`1[o`;o0>[o0oooool2o`3o8P;ooooo00Go0?ljooooooooooooooooo`3oF@04ooooo`0:o`1B
ool04?oo08?oooooool0ogOo0?lXo`3o=?l0:?oo0?mUo`3o2P;ooooo00Ko0:koo`1<oomMo`3oHol0
o`3`ool0;_l2ooooo`0;ocSo0?lV0?oo043oo`0:oooooooo6P3oo`3oVol0of_o07gooeL0ool0oo00
2oooool02?mG0?oooooooooooooooooo07goooooool0oo3o6P3o0_ooool01_l0oi_o00[ooooooooo
oooo043oocSo00Cooooo00Ko9P3oooooooooooooooooof?o0?mMo`03ooooo`03o`3`oooooooooooo
00Sooooo00?o0=Soooooool0oiD03?ooool2o`3oI@05ooooool0oo3ooooooooooolV0?l01Oooool0
0ol0=?oo0>Coo`3To`09ooooo`03oeL0oooooooooooo00;ooooo00?o0?l:oooooomY0?l01Oooool0
1?mMo`3oHol0oeOo0?mGo`07ooooo`?oEol00_ooool00olJ0?ooooooooooo`0Dooooo`03oed0oooo
oooooooo00;ooooo00Go0?m<oooooolno`3oooooofT0o`0?ooooo`03o`3ol?oooooooooo00kooooo
00Co0>Coo`0:ool0i?oo0>Co0oooool00ol0=?ooooooooooo`0Uooooo`ko>?l03?ooool4o`3oIB7o
oooo1Ol0[_l;ooooo`?o043oT_ooool002Gooooo00Co8B4Qo`000?l0003ok^k^1_ooool2o`000003
ob4Q8Ooooooooooo00_ooooo00?oA4A4oiRHV?ooool00_ooool3o`0000cooooo00?o0000oooooooo
ool05Oooool01_l0FOoo013oo`0Xool0C?oo02koooooo`?o0?l:1oooool2o`0^o`03o`3o2_oooooo
0?3o00;ooooo00?o04coooooool0f?l00_ooool01Ol0:?oooooooooooooooooo0>Co00;ooooo00?o
0?ldooooooooool00_l0Pol01_l0D_oo013ooooooooooooo0?Koo`3oF@Kooooo00?o0?ljoooooooo
ool00oooool00ol0ob;oooooooooo`05ooooo`Co06_o3oooool3o`1[o`;o08Wo0_ooool01?l0ob;o
ooooooooool0ocX3ooooo`03o`3oFOoooooooooo00;ooooo00Wo05;oo`0@oooooooo0?mgo`3o:?l0
ocCo0>Coo`0Xool0o`X00oooool01Ol0C?ooGOl0of?o0?oooooo02ko00;ooooo00[o>?l0oooooolV
0?oo043oo`0:oolJ0?oo0?nKooooool0of_o07go0_mG0?l9ooooo`08oeL0ooooooooooooooooool0
OOooooooo`3ol?lJ0?l3ooooo`05o`0:ooooooooooooo`10oolho`001Oooool01_lV0?oooooooooo
oomSo`3ooooooego00?ooooo00?o0?3oooooooooool01oooool00ol0f?oo0?l:o`3oU@0;ooooo`;o
0?mU1?ooool00ol0oo3oooooobH0o`03ooooo`;o0>Co00Co03Cooooooooooooo0?m<2?ooool00omG
0?ooooooooooo`03ooooo`03o`3o2_mY0?oooooo00Gooooo00?oGOl0of?o0?ooool01omGo`05oooo
o`03oaX0oooooooooooo01Gooooo0_mM0?l01_oooooo0?m<oooooolno`3oooooofT0oa3ooooo00?o
0?o`ooooooooool04?ooool01Ol02_ooooooo`3Tool0i?oo03Co01Gooooo4olho`0Nooooo`Go0?mU
6?ooool4o`2^oa?ooooo1?l0@?n>ooooo`009Oooool01?m4A4Co0000o`000?nj^[X5ooooo`04okZj
^_l0003o0000oeEEE@gooooo00?ok^k^oc8b<_o<c<`00_ooool3o`0000cooooo00?o0000oooooooo
ool05Oooool01Ol0FOoo013oo`1Bool0:?oo04co00;o02ko0_ooool6o`3o2P05o`0^oooooooooooo
ooooool0l?l00_ooool00ol0C?ooooooo`3Ho`02ooooo`06o`0Xooooooooooooooooool0i?oooooo
0_l0oc@2ooooo`05o`23ool0ogOo05;oo`0@ooooool00_l0m_l6ooooo`;o0?lj1?ooool2o`3o8PGo
oooo0ol0JolFooooo`;o06_o0_l0ROl01?oooooo0?lRo`3o8_l0ocX4ooooo`03o`3oFOoooooooooo
00;ooooo00So013oo`23oooooooo0?mgo`3o:?l0i?oo02Soo`3oI@?ooooo00Go0:koo`1<oomMo`3o
ooooo`0^o`03ooooo`08ocSo0?lV0?oo043oo`0:oooooooo6P3oo`3oVol0of/2o`1mo`03o`3ol?mG
0?oooooo00Gooooo0_mG0?l3ooooo`04o`1moooooooo0?o`oaX0o`?ooooo00Go0?nKo`0:oooooooo
ooooo`10o`05ooooo`06obH0oooooooooooooooooomSo`3oGOl00oooool00ol0l?ooooooooooo`07
ooooo`03o`3Hool0o`[o0?nE00_ooooo00?o0?mUooooooooool01?ooool01?l0oo3ooooooooooolV
0?l2o`3To`;ooooo00Co03Cooooooooooooo0?m<2?ooool00omG0?oo?_l0ooooo`03ooooo`03ocSo
0?l0o`[oJ@3o00Kooooo00?oGOl0of?o0?ooool03?ooool00olJ0?ooooooooooo`0Fooooo`05oed0
oooooooo?_l0oooooomY0?l04?ooool00ol0oo3oooooooooo`0Aooooo`05ocSo0?l02_oo>?l0o`0d
oolho`000ol0i?lBocSo03Kooooo1?l0ofDAooooo`?o0:ko6oooool3o`10oh_ooooo000Uooooo`04
ohN7Qol0003o0000ojVYZ@Gooooo00Co^[Zjo`000?l0003oV9RH3_ooool01?o<c<co8B4Qonk^k_oo
ool3o`0000cooooo00?o0000ooooooooool05Oooool01_l0Vooo05Woo`0@ool0f?oo02Soo`1<o`;o
02ko1Oooool2o`0^o`?ooooo00Ko0?3ooooooooooooo04coo`3oIOl0f?l2ooooo`07o`0Xoooooooo
ooooooooool0i?ooooooo`3o=003ooooo`07o`23ool0D_oo013oo`0@oooooooo0?Koo`3oF@05oooo
o`;o0?lj1?ooool2o`3o8PCooooo0ol0JolKooooo`?o06_o0_ooool00ol0ob;o0?ljooooo`03oooo
o`0=o`3oFOooooooooooooooool0D_oo013oo`23ool0ogOo0?lXo`3o=?l0:?oo0?mUo`3o2P02oooo
o`06o`2^ool0C?ooGOl0of?o0?l0l?oo02ko0_ooool03?lho`3o9P3oo`10ool02_oooooooaX0ool0
oi_oooooo`3oJooooooo07goo`3ol0KoE`3o1?ooool01Ol0OOooooooo`3ol?lJ0?oo0?m[00;ooooo
00Ko0?nKo`0:ooooooooooooo`10oolho`04ooooo`06obH0oooooooooooooooooomSo`3oGOl00ooo
ool00ol0l?ooooooooooo`07ooooo`03o`3Hool0o`[o0?nE00[ooooo0_l0ofD7ooooo`04o`3ol?oo
oooo0>CoobH0o`Cooooo00Co0?lXo`0dool0obSo0?m<2?l0obP00oooooooE`3oooooo`04ooooo`03
ocSo0?mY0?oo0?l:00Kooooo00?oGOl0of?o0?ooool02oooool00olJ0?ooooooooooo`0Fooooo`05
o`3oC?mM0?oooooooooooomY0?l04?ooool00ol0oo3oooooooooo`0<ooooo`Go>?l00_ooool2o`0:
o`Cooooo0ol0i?m9ooooo`Co0?mU2_ooool3o`2^ob7ooooo0ol0@?n8ooooo`009Oooool01?oMgMgo
0000o`000?mVIVH5ooooo`04ogMgMol0003o0000onk^kPoooooo00?oZJVYoc8b<_ooool00ol0000<
ooooo`03o`000?oooooooooo01Kooooo00Go05Woo`0@ool0D_oo0=Soo`0Xo`02o`2^o`Go02ko0ooo
ool2o`3`o`05ooooool0C?oo04coo`3oIOl0f?l00_ooool01ol0:?oooooooooooooooooo0>Cooooo
ool0oc@00_ooool2o`23o`05o`1Bool04?ooooooo`3oFOl0m_l01_ooool01?l0oc[ooooooooooooo
ool3o`3o8P?ooooo0ol0JolQooooo`;o06_o00?oooooo`3o8_l0ocX00oooool00ol0oeWooooooooo
o`02ooooo`08o`1Bool04?ooooooo`3oMol0obSo0>Coo`0Xool0ofD2ooooo`06o`2^ool0C?ooGOl0
of?o0?l0l?oo02ko0_ooool03Olho`3o9P3oooooool0@?oo00[ooaX0oolno`3o0?nKo`3oJooooooo
07goooooool0oo002?ooool01Ol0OOooooooo`3ol?lJ0?oo0?m[00?ooooo00Go00[ooooooooooooo
043oocSo0005ooooo`06obH0ooooooooooooof?o0?ooooooGOl00oooool00ol0l?ooooooooooo`07
ooooo`03o`3Hoooooooo0?nE00Wooooo00?o0?mUooooooooool01oooool2o`3To`03o`3o:?lV0?oo
0?lX00?o0?lX00Coooooo`0doooooooo0?m<2?ooool00ol0obSoE`3oo`3o:003o`3o:005oooooolh
o`3oJ@3oooooool0o`X01_ooool00omMo`3oHol0ooooo`0;ooooo`03oaX0oooooooooooo01Cooooo
00Go0?m<ocko0?ooooooG@3oofT0o`0@ooooo`03o`3ol?oooooooooo00Sooooo1Olho`06ooooo`04
o`0dooooooooooooo`0:o`Kooooo0ol0i?m:ooooo`Go0?mU0_ooool3o`2^obOooooo1?l0@?n4oooo
o`009_ooool00omEEEGo0000ob4Q8@05ooooo`03ob4Q8Ol0003oEEEE017ooooo00?oIVIVogMgMol0
00000_l0000<ooooo`03o`000?oooooooooo01Kooooo00Go05Woo`1[ool04?oo0>Coo`0Xo`02o`1<
o`03o`2^oooooooooooo00Cooooo00Co0?3oo`1<ool0C?oo04co0_l0ofD01?l0f?ooooooooooool0
:?l3ooooo`03o`3Toooooooo0?ld00;ooooo00Go08?oo`1Bool0D_oo013oooooo`02o`3fo`Gooooo
0_l0ocX2ooooo`;o0?lR1?ooool2o`1[o`[ooooo3ol0oe8=ooooo`04o`1[oooooooo0?lRo`3o>P?o
oooo00go0?mIooooooooooooooooo`1Bool04?oo08?oo`3oMol0obSo0?ldo`0Xool0ofGo0?l:00;o
oooo00Go04coo`3HoomMo`3oooooo`0^o`03ooooo`0:ocSo0?lV0?oo043oo`0:oooooooo6P3oo`3o
Vooooooo0?m[ooooo`;o07go00?o0?o`ooooooooool00oooool2o`1mo`;o0?o`00?o6P3oo`3oJooo
ool00_ooool01Ol0oi_o00[ooooooooooooo043o00Gooooo00Ko9P3oooooooooooooooooof?o0?mM
o`03ooooo`03o`3`oooooooooooo00Oooooo00?o0=Soooooool0oiD02Oooool00ol0ofGooooooooo
o`06ooooo`;o0>Co00Co0?o`o`3o:?oooooo9P3o1Oooool01?l0=?ooooooooooool0od`8ooooo`03
oeL0oolno`3ooooo00;ooooo0ol0obP00omY0?ooooooo`3o2P05ooooo`03oego0?ooooooHol000co
oooo00?o6P3oooooooooool04oooool01Ol0odcooooooooooomY0?ooG@3o00oooooo00?o0?o`oooo
ooooool01?ooool5ocSo00[ooooo00?o03Coooooooooool00_ooool00ol02_ooooooooooo`06oooo
o`;o0>CoC?ooool3o`2^o`;o0?mU;?ooool3o`10oh7ooooo000Vooooo`04omgMgOl0003o0000okZj
^P?ooooo00Co^[Zjo`000?l0003ok^k^4_ooool01?lb<S;o0000o`000?l0000<ooooo`03o`000?oo
oooooooo01Kooooo00Oo09_oo`1Iool04?oo05;oo`3Hool0:?oooooo00;o04co00Oo0:koo`3`ool0
l?oo0?3oo`2^ool0C?oo0?lX00;o0?mU0_l0f?l00ooooooo02Soo`0Xo`03ooooo`03o`3Toooooooo
0?ld00;ooooo00Ko08?oo`1Bool04?oo013oo`3oFOl0m_l6ooooo`03o`3o>_oooooooooo00;o0?lR
1?ooool2o`1[o`Kooooo1_l0oe8>o`3odP03ooooool0oe;o0?mB00;o0?mB2_ooool01?l0Jooo0>[o
o`3o8_l0ocX3ooooo`0<o`3oFOooooooooooooooool0D_oo013oooooool0ogOo0?lXo`0Xool0ofGo
0?l:0_ooool01Ol0[_oo04cooego0?mSo`3o02ko00?ooooo00Co>?l0obH0ool0@?oo00[o0_ooool0
1?lJ0?oo0?nKooooool0of/2ooooo`Ko07go0_l0oo000ooooooo6P3oooooo`03ooooo`06o`3oVol0
2_ooooooooooool0@?oo>?l01?ooool01_lV0?ooooooooooooooooooHol0oego00Cooooo00?o0?3o
ooooooooool01_ooool01?l0f?ooooooo`3oUOooool5o`0^o`Cooooo00?o0?mUooooooooool01?oo
ool2o`3To`04o`3o:?ooooooooooo`3ol0;ooooo00?o9P3oooooooooool00_ooool01?l0=?oooooo
ooooool0od`8ooooo`03oeL0oolno`3ooooo00Gooooo00CoJ@3oo`3o:?l0obSo0?l:1Oooool00omM
o`3oooooof?o000<ooooo`03oaX0oooooooooooo017ooooo00Oo0?m<ooooooooooooooooofT0oooo
ooooG@3o00kooooo00?o0?o`ooooooooool01?lho`0>ooooo`03o`0doooooooooooo00Cooooo00?o
00[oooooooooool01oooool3o`3TodKooooo0ol0[_l5ooooo`Co0?mU:oooool4o`10oggooooo000W
ooooo`06okZj^_l0003o0000okZj^_oooooo^[Zj0_l000000oo<c<coooooooooo`0Aooooo`04onk^
k_l0003o0000o`0000cooooo00?o0000ooooooooool05oooool01_l0FOoo06_oo`0@ool0D_oo0=So
o`0Xo`;ooooo1Ol0C?l2o`3oI@05ooooool0f?ooooooooooool0:?l01?ooool00ol0i?oo0?ldo`3o
=002ooooo`06o`23ool0D_oo013oooooool0oeWo0?Ko1Oooool2o`3o>P03ooooool0ob;o0?lR00Co
oooo0_l0Jol00ol0ROooooooooooo`02ooooo`?o0?mB0oooool3o`3odPkooooo1_l0om82o`3oDPSo
oooo00Co06_oo`3Zool0ob;o0?lj0oooool02ol0oeWoooooooooool0D_oo013oo`23ool0ogOo0?lX
o`3Tool0:?oo0?mU00;ooooo00Ko0:koo`1<oomMo`3oHol0o`3`ool0;_l2ooooo`0;ocSo0?lV0?oo
ooooo`10ool02_oooooooaX0oolno`3o0?nKooooool0of/02Oooool00olJ0?ooooooooooo`02oooo
o`06o`3oVol02_ooooooooooool0@?oo>?l01?ooool01olV0?ooooooooooooooooooHol0oooooomM
o`000oooool00ol0l?ooooooooooo`07ooooo`03o`3Hool0;_oo02ko00;o02ko1?ooool2o`0^o`03
ooooool0ofGooooo00Cooooo0_l0i?l00ol0obSoooooooooo`02ooooo`04o`3ol?ooooooooooobH0
o`Cooooo00Co03Cooooooooooooo0?m<2?ooool00omG0?ooooooocko0005ooooo`03ofT0oooooooo
oooo00?o0?lX1?ooool00omMo`3oooooof?o000<ooooo`03oaX0oooooooooooo00oooooo00Go?_l0
o`3oC?ooooooooooofT0o`03ooooo`03oed0oooooooooooo00[ooooo00Co0?o`ocSo0?lho`3o>?l0
4Oooool00ol0=?ooooooooooo`06ooooo`03o`0:oooooooooooo00Wooooo0ol0i?m0ooooo`?o0:ko
3?ooool4o`3oIB_ooooo1?l0@?miooooo`00:?ooool00ooMgMgoEEEEo`000002o`000003oeEEEOoM
gMgooooo01Cooooo00?oc<c<o`000?l000003?ooool00ol0003oooooooooo`0Gooooo`06o`2Kool0
FOoo0?Koo`0@ool0i?oooooo0_l0:?l6ooooo`;o0=So0_ooool00ol0:?ooooooooooo`02ooooo`03
o`3Tool0ocCooooo00;ooooo00Co08?oo`1Bool04?oo0?mI0_l0m_l4ooooo`;o0?lj0_ooool00ol0
ob;oooooooooo`02ooooo`;o06_o00?o08Woooooooooool00_ooool2o`3oDP03ooooool0om;o0?oB
00?o0?oB0_oooolBo`3<o`?ooooo0_l0om82o`3oDPOooooo00?o06_oo`3Zool0ocX00oooool04ol0
oeWooooooooooooooooo05;oo`0@ool0ogOo0?lXo`3o=?l0:?oo0?mUo`3o2_oooooo0?nEo`1<oooo
ooooGOl0ooooool0;_l00oooool01?lho`3o9P3oo`10ool02_l2ooooo`;o6P3o0_ooool2o`3oJ`Go
oooo0_lJ0?l4ooooo`03o`3oVooooooo00[o00;ooooo00?o043oooooooooool00oooool01_lV0?oo
ooooooooooooooooHol0oego00Cooooo00?o0?3oooooooooool01_ooool00ol0f?oo02koo`3oU@09
ooooo`;o02ko0_ooool2o`3o:003o`3Toooooooooooo00Gooooo00Co0?o`oooooooooooo9P3o1Ooo
ool00ol0=?ooooooo`3oC009ooooo`03oeL0oolno`3ooooo00Gooooo00GoJ@3ooooooooooooooooo
o`3o2P03o`3o:0;ooooo00?oGOl0oooooomSo`003?ooool00olJ0?ooooooooooo`0=ooooo`03ocko
0?l0odcooooo00;ooooo00?oJ@3oooooooooool00_ooool00omM0?ooooooooooo`07ooooo`;o>?l0
00?o0?o`ooooooooool04Oooool00ol0=?ooooooooooo`08ooooo`03o`0:oooooooooooo00_ooooo
0ol0i?ljooooo`?o0:ko4oooool3o`3oIBcooooo0ol0@?mfooooo`00Doooool00ol0003ooooooooo
o`0Gooooo`07o`2Kool0FOoo0?Koo`0@ool0D_oo0>Coooooo`03o`0Xo`Co0=So00Coooooo`0Xool0
:?oo02So1?ooool01?l0i?oo0?ldooooooooool2o`23o`04o`1Bool04?oo0?mIo`3fo`Gooooo00?o
0?ljooooooooool00_l0ob83ooooo`;o06_o00Co08Wooooooooooooooooo0ol0oe82ooooo`03o`3o
d_oooooooooo00;ooooo0ol0c?l4o`3oP`Oooooo1ol0oh<2o`3<o`?ooooo00?o0?oBooooool0oe80
1oooool00ol0Jooo0?lRo`3o>P03ooooo`0;o`3oFOooooooooooo`1Bool04?ooooooo`3oMol0obSo
02Soo`3oIOl0o`X00_ooool01Ol0[_oo04cooego0?mSo`3o02ko00?ooooo00Go>?l0obH0ool0@?oo
ooooo`0:o`03ooooo`03oaX0oolno`3ooooo00Go0?m[00?o6P3oocko0?ooool00oooool00ol0oi_o
ooooo`0:o`02ooooo`03o`10oolho`3ooooo00?ooooo00Oo9P3oooooooooooooooooof?o0?oooooo
GOl000?ooooo00?o0?3oooooooooool01_ooool00ol0f?oo02koo`3oU@09ooooo`03o`3oIOoooooo
02ko00;o0?lX00?oooooo`3Tooooool01oooool01?l0oo3ooooooooooolV0?l5ooooo`04o`0doooo
ooooooooo`3oC0Sooooo00?oE`3ooooooolno`001Oooool00omY0?oo>?l0ooooo`03ooooo`03o`3o
2_oooooo0?lX00;o0?lX00?oGOl0oooooomSo`003?ooool00olJ0?ooooooooooo`0;ooooo`03ocko
0?oooooo0?m<00;ooooo00?oJ@3oooooooooool01?ooool00omM0?ooooooooooo`04ooooo`;o>?l0
00?oooooo`3ol?ooool04_ooool00ol0=?ooooooooooo`0:ooooo`03o`0:oooooooooooo00gooooo
0_l0i?leooooo`?o0:ko6Oooool4o`3oIB_ooooo1?l0@?mbooooo`00Doooool00ol0003ooooooooo
o`0Hooooo`06o`1Iool0Jooo0?Koo`0@ool0D_oo0>Co0_ooool6o`0Xo`Gooooo0_l0i?l01?l0ocCo
ooooooooool0Pol2o`1Bo`03o`0@ool0oeWo0?Ko00Cooooo0_l0ocX2ooooo`04o`3o8_oooooooooo
ooooo`;o06_o0_l0ROl01?oooooo0?mBo`3oD_l0oe83ooooo`;o0?oB0_l0oh<3o`3<o`03o`3oPooo
oooooooo01;ooooo0_l0oh<3o`3<o`05ooooool0om;o0?oBo`3od_l0oe801Oooool01?l0Jooo0>[o
o`3o8_l0ocX2ooooo`0;o`3oFOooooooooooooooool04?oo08?oo`3oMol0obSo0>Coo`0Xool0ofD0
0_ooool01Ol0[_oo04cooego0?mSo`3o02ko00Cooooo00Co9P3oooooool0@?oo00[o0oooool01?l0
oi_o6P3ooaX0oolno`02ooooo`;o6P3o1_ooool00ol0oi_o00[oooooo`02ooooo`03o`10oooooooo
oooo00;ooooo00Oo9P3oooooooooooooooooof?o0?ooooooGOl000Cooooo00?o0?3oooooooooool0
1Oooool01?l0o`[o02koooooool0oiD8ooooo`07o`3oIOooooooooooo`3o:?l0;_ooooooo`3To`09
ooooo`05o`3ol?oooooooooooooooolV0?l01?ooool01?l0=?ooooooooooool0od`8ooooo`04oeL0
ooooooooooooocko00Cooooo00?oJ@3ooooooolho`001?ooool01?l0o`[oooooooooooooool2o`3o
:003oego0?mSo`3ooooo00[ooooo00?o6P3oooooooooool02_ooool00olno`3oooooo`3oC002oooo
o`03ofT0oooooooooooo00Kooooo00?oG@3oooooooooool00_ooool01Olho`3ooooooooooooooooo
0?o`01;ooooo00?o03Coooooooooool03?ooool00ol02_ooooooooooo`0>ooooo`;o0>Co<?ooool3
o`2^ob3ooooo1?l0ofD[ooooo`Co043oK_ooool005?ooooo00?o0000ooooooooool06?ooool01Ol0
Vooo05Woo`3oPol04?oo0?mg00;o05;o2_ooool2o`3To`;o0?ld00Coooooo`23ool0Pooo05;o0_l0
4?l00ooooooo0?Koooooo`03ooooo`03o`3o>_oooooooooo00;o0?lR0oooool01?l0Jooo08Woo`29
ooooool2o`3oDP?ooooo0ol0om84o`3<oa_ooooo0_l0oh<2o`3<o`;ooooo0_l0om85ooooo`04o`1[
ool0j_oo0?lRo`3o>P;ooooo01;o0?mIoooooooooooo05;oo`0@ool0ogOo0?lXo`3o=?l0:?oo0?mU
o`3o2_oooooo0:koo`1<ooooooooGOl0o`3`ool0;_l3ooooo`04ocSo0?lV0?oo043oo`0:o`Cooooo
00?o0?nKoooooolJ0?l00_lJ0?l6ooooo`;o0?nK00Ko00[oooooooooooooooooo`10oolho`03oooo
o`03obH0oooooooooooo00;ooooo00?oHol0oego0?ooool00oooool00ol0l?ooooooooooo`05oooo
o`04o`3o2_l0;_ooooooo`3oU@Sooooo00Co0?mUoooooooooooo0?lX0_ooool00ol0;_oooooooooo
o`09ooooo`04o`3ol?ooooooooooobH0o`Cooooo00Co03Cooooooooooooo0?m<2?ooool01?mG0?oo
oooooooooolno`05ooooo`03ofT0oolho`3ooooo00Cooooo00?o0?l:ooooooooool00_ooool3o`3o
:0_ooooo00?o6P3oooooooooool02?ooool01?lno`3oooooooooool0od`2ooooo`03ofT0oooooooo
oooo00Oooooo00CoG@3ooooooolho`3o>?l00oooool00ol0oo3oooooooooo`0@ooooo`03o`0doooo
oooooooo00kooooo00?o00[oooooooooool03oooool2o`3Tobcooooo0_l0[_lWooooo`Co0?mU:ooo
ool3o`10of_ooooo001Cooooo`03o`000?oooooooooo01Sooooo00So09_oo`1Iool0Jooo0?n3o`0@
ool0ogOo0?ldo`1Bo`?o0>Co0oooool3o`3To`05ooooool0ocCoooooooooool0Pol00_l0D_l01?l0
4?oo0?mIooooool0m_l3ooooo`;o0?lj0_ooool01?l0ob;oooooooooooooool2o`1[o`04o`29oooo
oooo0?mBo`3oDP;ooooo0ol0om800ol0oh?o0<coo`3<o`0:ooooo`;o0?o<3?l0ooH2o`3oc0Oooooo
0_l0oh<2o`3<o`;ooooo00?o0?oBo`3oD_ooool00oooool00ol0Jooo0?lRo`3o>P02ooooo`0Bo`3o
FOooooooooooo`1Bool04?oo08?oo`3oMol0obSo02Soo`3oIOl0o`[oooooo`3oUOl0C?oooooooego
0?mSo`3o02ko0oooool01Olho`3o9P3oooooool0@?oo00[o00Cooooo00?o0?nKooooooooool01_oo
ool00ol0oi_oooooo`0:o`03ooooo`03o`10oolho`3ooooo00;ooooo00?o9P3oooooooooool00_oo
ool00omSo`3ooooooego0004ooooo`03o`3`oooooooooooo00Cooooo00Co0?l:o`0^oooooooo0?nE
2?ooool01?l0ofGoooooo`3o:?l0obP2ooooo`03o`3Toooooooo02ko00[ooooo00Co0?o`oooooooo
oooo9P3o1?ooool01?l0=?ooooooooooool0od`9ooooo`04oeL0ooooooooooooocko00Cooooo00?o
J@3ooooooolho`001Oooool00ol0o`[oooooooooo`03ooooo`04oego0?l0obSo0?lXo`3o:0Wooooo
00?o6P3oooooooooool01_ooool01?lno`3oooooooooool0od`2ooooo`03ofT0oooooooooooo00So
oooo00?o>?l0oed0ooooool01?ooool00ol0oo3oooooooooo`0@ooooo`03o`0doooooooooooo00oo
oooo00?o00[oooooooooool04?ooool3o`3TobOooooo0_l0[_l]ooooo`Go0?mU:Oooool4o`10ofOo
oooo001Cooooo`03o`000?oooooooooo01Wooooo00Co09_oo`1Iool0Jooooooo0_l04?l00ol0ocCo
05;oo`23o`04o`3To`;ooooo0_l0oc@01?l0Pooo05;oo`1Bool0D_l2o`0@o`03ooooool0m_oo0?Ko
00;ooooo0_l0ocX2ooooo`;o0?lR0oooool00ol0Jooo08Woo`29o`02o`3oDP;ooooo0_l0om82o`3o
P`;o0<co1_ooool3o`3oc0Go0?of3?ooool5o`3omP;o0?o<1?ooool00ol0oh?oooooo`3<o`02oooo
o`03o`3od_l0oe;ooooo00;ooooo00Co08Woo`1[ool0ob;o0?lj0_ooool02_l0oeWoooooooooool0
4?oo08?oo`3oMol0obSo02Soooooool0ofD2ooooo`05o`2^ool0C?ooGOl0of?o0?l0;_l01?ooool0
1OlV0?ooooooo`10oooooooo00[o00Cooooo0_l0oi/4ooooo`;o0?nK00?oooooo`0:ooooool00_oo
ool00ol0@?oo>?l0ooooo`03ooooo`07obH0oooooooooooooooooomSo`3ooooooego0004ooooo`03
o`3`oooooooooooo00Cooooo00Co0?l:o`0^ool0f?oo0?nE2?ooool00ol0ofGoooooo`3o:004oooo
o`03o`3Toooooooo02ko00[ooooo00Co0?o`oooooooooooo9P3o1?ooool01Ol0=?oooooooooooooo
oooo0?m<00Sooooo00CoE`3ooooooooooooo?_l01?ooool01?mY0?oooooooooooolho`05ooooo`;o
0?l:1?ooool00omMo`3oHol0of?o0002o`3o:0Sooooo00?o6P3oooooooooool01?ooool01olno`3o
oooooooooooooooo0?m<oooooomY0?l02Oooool2ocSo00;ooooo00GoG@3oooooooooooooooooo`3o
l00Booooo`03o`0doooooooooooo017ooooo0_l02_lCooooo`;o0>Co8_ooool3o`2^ocCooooo1Ol0
ofDXooooo`Co043oHoooool005?ooooo0ol0000Iooooo`08o`2Kool0FOoo06_oo`3oPol0oc[o0?Ko
o`0@ooooool3o`1Bo`Co08?o0ol0D_l2o`3oM`04o`0@ooooooooooooo`3fo`;ooooo0_l0ocX3oooo
o`04o`3o8_ooooooooooooooo`;o06_o00?o08Woo`3oD_l0oe800_ooool2o`3odP;o0?n30_l0c?l5
ooooo`?o0?o<0ol0ooH:ooooo`;o05Wo2_ooool3o`3omP04o`3oc?ooooooooooooooo`;o0?n300Go
0<cooooooooooooo0?oBo`3oDP03ooooo`03o`1[ool0j_oo0?lj00;ooooo01;o0?mIoooooooooooo
05;oo`0@ool0ogOoooooo`3o=?l0:?oo0?mUo`3o2_oooooo0:koo`1<oomMo`3oHol0o`3`ool0;_l3
ooooo`06ocSo0?lV0?ooooooo`10oooooooo00[o1Oooool4o`3oV`;ooooo00Oo00[ooooooooooooo
ooooo`10oooooooo>?l000?ooooo00?o9P3oooooooooool00_ooool00omSo`3oGOl0ooooo`03oooo
o`03o`3`oooooooooooo00Gooooo00Co02koo`3Hoooooooo0?nE1oooool00ol0ofGoooooo`3o:004
ooooo`05o`3Tooooooooooooooooool0;_l02Oooool01?l0oo3ooooooooooolV0?l5ooooo`03o`0d
ool0Pooo08?o00Ko08?o0oooool01OmG0?oooooooooooooooooo?_l000Cooooo00?oJ@3ooooooolh
o`001oooool00ol0o`[oooooooooo`02ooooo`04oego0?ooooooHol0ooooo`?o0?lX1_ooool00olJ
0?ooooooooooo`02ooooo`05ocko0?ooooooooooooooool0od`00_ooool00omY0?ooooooooooo`05
ooooo`;o>?l01Oooool01?mM0?ooooooooooool0oo0Aooooo`03o`0doooooooooooo01Cooooo00?o
00[oooooooooool04_ooool2o`3Toakooooo0_l0[_llooooo`Co0?mU:?ooool4o`10oeoooooo001C
ooooo`03o`000?oooooooooo01[ooooo00Oo09_oo`1Iool0Jooo0?mBo`3fool0oc[o013o00;o0?mg
00?o0?mIo`1Bool0D_l00_l0D_l3o`3oM`;o013o00Coooooo`3fool0m_oooooo0_l0ocX3ooooo`;o
0?lR0oooool01?l0Jooo08Woo`29ool0oe82ooooo`;o0?oB0_l0oh<2o`3<o`Cooooo0ol0ol`3o`3o
mP?ooooo2ol0FOl00ol0ok[o05Woo`1Io`08o`1Io`?ooooo0_l0ooH01_l0olcooooooooooooooooo
0?n3o`3<o`;ooooo00?o0?oBooooooooool00_ooool00ol0Jooo0>[oo`3o>P02ooooo`0Ao`3oFOoo
oooo05;oo`0@ool0Pooo0?mgo`3o:?l0:?oo0?mUo`3o2_oooooo0:koo`1<ooooooooGOl0ooooool0
;_l01?ooool01OlV0?ooooooo`10oooooooo00[o00Wooooo0_l02_l3ooooo`03o`10oooooooo>?l0
00?ooooo00?o9P3oooooooooool00_ooool00omSo`3ooooooego0004ooooo`03o`3`oooooooooooo
00Cooooo00Co02koo`3Hoooooooo0?nE1oooool00ol0ofGoooooo`3o:004ooooo`03o`3Toooooooo
oooo00;ooooo00?o02koooooooooool01oooool01Ol0oo3ooooooooooooooooo9P3o00Co08?o00Co
03Cooooooooooooo0?m<1Oooool3o`23o`06oeL0ool0Pooo08?oo`23oooooooo?_l00oooool01?mY
0?oooooooooooolho`07ooooo`;o0?l:0oooool2oego00?oHol000?oooooo`3o:?l0obP01Oooool0
1?lJ0?oooooooooooolno`04ooooo`03o`3oC?ooooooJ@3o00Kooooo0_lho`08ooooo`03oed0ool0
oo3ooooo017ooooo00?o03Coooooooooool05Oooool00ol02_ooooooooooo`0Cooooo`;o0>Co6_oo
ool2o`2^od;ooooo1Ol0ofDWooooo`Go043o6?ooool7of?o03_ooooo001Cooooo`03o`000?oooooo
oooo01[ooooo00Go09_oo`1Iool0Jooo0?n3o`3oDP02o`3fo`?o013o1?l0ogL3o`0@o`;ooooo00Co
0?Kooooooooooooo0?lj1?ooool01?l0ob;oooooooooooooool2o`1[o`04o`29ool0oe;ooooooooo
o`;o0?oB0_l0oh<2o`3<o`?ooooo0ol0ol`3o`3omP?ooooo0ol0FOl5o`3o^Pkooooo0ol0okX2o`1I
o`?ooooo00?o0?ofo`3oc?l0ol`00_ooool01Ol0oh?o0<cooooooooooooo0?oB00Cooooo00Go06_o
o`3Zool0oc[oooooo`3oF@02ooooo`0>o`0@ool0Pooo0?mgo`3o:?l0:?oo0?mUo`3o2_oooooo0?nE
o`1<ool0f?ooGOl0of?o0?l0;_l4ooooo`06obH0ooooooooooooo`10oooooooo00[o1oooool00ol0
2_ooooooooooo`02ooooo`03o`10oooooooo>?l000?ooooo00?o9P3oooooooooool00oooool00omS
o`3oGOl0ooooo`03ooooo`03o`3`oooooooooooo00Cooooo00Co0?l:o`0^ool0f?oo0?nE1oooool0
0ol0ofGoooooo`3o:004ooooo`03o`3Toooooooooooo00?ooooo00?o02koooooooooool02?ooool3
o`23o`03obH0oooooooooooo00;ooooo00Go03Coooooooooooooooooo`3oC008ooooo`03oeL0oooo
oooooooo00?o08?o0_ooool01OmY0?oooooooooooooooooo>?l000Sooooo00?o0?l:ooooooooool0
0_ooool00omMo`3oooooooooo`03of?o00?o0?lX0oooool00olJ0?oo?_l0ooooo`03ooooo`03o`3o
C?ooooooJ@3o00Gooooo0_lho`0:ooooo`03o`3ol?mM0?oooooo013ooooo00?o03Coooooooooool0
5oooool00ol02_ooooooooooo`0Dooooo`;o0>Co5_ooool2o`2^odWooooo1?l0ofDXooooo`Co043o
2Oooool;of?o04;ooooo001Cooooo`03o`000?oooooooooo01_ooooo00Ko09_oo`1Iool0Jooo0?n3
o`3oD_ooool2o`3fo`03ooooool04?oo013o00;o013o0_ooool3o`3fo`?o0?lj1?ooool01Ol0ob;o
oooooooooooooooo06_o00;o08Wo00Co0?mBooooool0om;o0?oB0_l0oh<2o`3<o`;ooooo0ol0ol`3
o`3omP?ooooo0ol0FOl2o`3o^QWooooo0ol0FOl01?oooooo0?ofo`3om_l0ol`2ooooo`05o`3oPol0
c?ooooooo`3od_l0oe801?ooool05?l0Jooo0?ljoooooooooooo0?mIooooool0D_oo013oo`3oMooo
oooo0>Coo`0Xool0ofGo0?l:ooooool0[_oo04cooego0?mSo`3o02ko1Oooool01OlV0?oooooooooo
ool0@?oooooo00?o00[o0_ooool2o`0:o`Cooooo00?o043ooooooolho`001?ooool00olV0?oooooo
ooooo`02ooooo`03of?o0?mMo`3ooooo00Cooooo00?o0?3oooooooooool01?ooool01?l0;_oo0=So
ooooool0oiD6ooooo`03o`3oIOoooooo0?lX00Cooooo00?o0>Coooooooooool01Oooool00ol0;_oo
ooooooooo`04ooooo`?o08?o00Co0?o`oooooooooooo9P3o1?ooool01Ol0=?oooooooooooooooooo
0?m<00Sooooo00?oE`3oooooooooool00_ooool01Olno`3o08?oo`23ooooooooJ@3o00?ooooo0_lh
o`07ooooo`;o0?l:0oooool2oego00?ooooo0omSo`03o`3o:003oaX0oooooooooooo00?ooooo00?o
0?m<oooooomY0?l00oooool2ocSo00cooooo00?o0?o`of?o0?mM0?l03omSo`000ol0=?ooHol0of?o
0006of?o01?ooooo00?o00[oooooooooool05Oooool3o`3Toa7ooooo0_l0[_m?ooooo`Co0?mU9ooo
ool00omSo`3o043oo`10o`02o`10o`GoHol01oooool;o`3foc_ooooo001Cooooo`03o`000?oooooo
oooo01_ooooo00Ko09_oo`1Iool0c?oo06_oo`3oPol0oe82ooooo`Oo0?Ko0ol0ocX6ooooo`03o`3o
8_oooooooooo00;o06_o00Go08Woo`3oD_ooooooooooo`3odP02o`3oP`;o0<co0_ooool2o`3oc0?o
0?of0oooool3o`1Io`;o0?nj7Oooool2o`3o^P05o`1Iooooooooooooo`3om_l0ol`00_ooool01Ol0
oh?o0<coooooool0om;o0?mB00?ooooo00Go06_oo`3Zool0oc[oooooo`3oF@02ooooo`0>o`0@ool0
Pooo0?mgo`3o=?l0:?oo0?mUo`3o2_oooooo0:koo`1<ooooooooGOl0o`3`ool0;_l4ooooo`05obH0
ooooooooooooooooool0@?l00oooool3o`0:o`?ooooo0_l0@?l00ooooooo>?l0ooooo`03ooooo`03
obH0oooooooooooo00;ooooo00?oHol0oooooomMo`001?ooool00ol0l?ooooooooooo`04ooooo`04
o`0^oooooooo0=Soo`3oU@Oooooo00?o0?mUo`3o:?ooool00oooool01?l0i?ooooooooooooooool7
o`0Xo`;ooooo0ol0Pol3ooooo`04o`3ol?ooooooooooobH0o`Cooooo00Go03Cooooooooooooooooo
o`3oC007ooooo`03o`3oFOmG0?oo0?mI00Ko0?mI00?o08?oofT0ool0oeT03?l0oeT00ooooooo0?l:
ooooo`03ooooo`03oego0?oooooooooo00?ooooo0_mSo`001?lno`3o0?lXoaX0ool0obP2ooooo`03
o`3oC?ooooooJ@3o00;ooooo0_lho`09ooooo`CoHol000Go0?o`oooooooooooooooooed0o`0=oooo
o`03o`0doooooooooooo00Oooooo1?mSo`0@ooooo`03o`0:oooooooooooo01Oooooo0_l0i?l>oooo
o`03o`2^oooooooooooo05?ooooo1?l0ofDKooooo`?oHol02_l0m_l5o`10o`Oo0?KoA_ooool005?o
oooo00?o0000ooooooooool07?ooool00ol0Vooo05Woo`3<o`02o`1[o`03o`3oD_oooooooooo00;o
oooo1?l0ocX7ooooo`;o0?lR00?oooooo`1[ool0Jol00_l0ROl2ooooo`;o0?oB0ol0c?l01?oooooo
0?o<o`3oc?l0ol`2o`3omPCooooo0_l0FOl3o`3o^Pkooooo1_l0ogd>ooooo`;o05Wo00?oooooo`3o
m_l0ooH00_ooool01?l0oh?o0<coooooool0om84ooooo`04o`1[ool0oc[oooooo`3oF@;ooooo00ko
013oo`23ool0ogOo0?lXo`0Xool0ofGo0?l:ooooool0oiGo04cooooooomMo`3oHol0o`0^o`Gooooo
00?o9P3oooooooooool00_l0@?l7ooooo`04o`10ooooooooooooocSo00Cooooo00?o9P3ooooooooo
ool00oooool00omSo`3oGOl0ooooo`04ooooo`03o`3`oooooooooooo00?ooooo00Co02koooooool0
f?oo0?nE1oooool00ol0ofGo0?lXooooo`03ooooo`03o`3Toooooooo02So00;o02So1_ooool00ol0
;_oo02Soo`0Xo`06ooooo`05o`3ol?oooooooooooooooolV0?l01?ooool01?l0=?ooooooooooool0
od`3ooooo`Co0?mI00?ooooooeL0ooooool01?ooool01?lno`3ooooooooooomY0?l2o`23o`Cooooo
0_lho`05ooooo`Wo0?mI1?ooool01Olno`3oHol0of?o0?mSo`3o6P3o00;o0?lX00?o0?m<ofT0ool0
obP00_lho`0;of?o00Cooooo00?o0?o`ooooooooool00_ooool00omM0?ooooooooooo`0:ooooo`03
o`0doooooooooooo00_ooooo1_mSo`0;ooooo`03o`0:oooooooooooo01Sooooo0_l0i?l:ooooo`;o
0:koF_ooool4o`3oI@cooooo3_l0m_l?ooooo`Go043oB?ooool005?ooooo00?o0000ooooooooool0
7?ooool01_l0ol3o09_oo`1Iool0c?oo08Woo`1[o`;o0?mB2Oooool4o`3o8P;ooooo00?o06_oo`29
ool0ROl00_ooool2o`3odP;o0<co0_ooool2o`3oc0?o0?of1?ooool2o`1Io`;o0?nj2oooool6o`3o
O@Kooooo1_l0ogd9ooooo`05o`3o^_l0FOooooooooooool0ooH00_ooool01?l0oh?o0<coooooool0
om83ooooo`0Do`1[ool0j_oo0?ljooooool0oeWoooooo`1Bool04?oo0?mgooooool0:?ooooooo`3o
IOl0o`[o0?nEo`2^ool0C?ooGOl0of?o0?l0;_l5ooooo`03ocSo0?lV0?oooooo00;ooooo0_l0@?l3
ooooo`;o043o0_ooool00olho`3oooooooooo`02ooooo`03obH0oooooooooooo00?ooooo00?oHol0
oego0?ooool01?ooool00ol0l?ooooooooooo`03ooooo`05o`0^ool0o`[o0=Soooooool0oiD01_oo
ool00ol0ofGo0?lXooooo`03ooooo`03o`3Tool0:?oo02So00Wooooo00Co02kooooooooooooo02So
1Oooool01Ol0oo3ooooooooooooooooo9P3o00Cooooo00?o03Coo`3oFOl0oeT01?l0oeT6ooooo`03
oeL0oooooooooooo00?ooooo00Ko?_l0ooooooooooooJ@3oooooool0Pol5ooooo`03ocSo0?oooooo
oooo00Gooooo00?o0?l:ooooooooool00oooool9o`3oF@05oaX0ool0oeWoJ@3oocSo0?ooool01Ol0
obP;ooooo`03o`3ol?oooooooooo00Cooooo00?oG@3oooooooooool02?ooool00ol0=?oooooooooo
o`0Booooo`KoHol01_ooool00ol02_ooooooooooo`0Iooooo`;o0>Co1_ooool2o`2^of3ooooo1?l0
ofD00ooooooo0?Koo`3fo`05o`3fo`CoHol07_ooool5o`10od?ooooo001Cooooo`03o`000?oooooo
oooo01gooooo00Oo09_oo`2Qool0FOoo0?ofo`29ool0Jooo0?n300;o0?mB2?l0ob82ooooo`04o`3o
D_l0Jooo06_oo`29o`;ooooo0_l0om82o`3<o`;ooooo0_l0ol`2o`3omPGooooo0_l0FOl2o`3o^P[o
oooo0ol0ogdBo`2Qo`?o0?mm1oooool01Ol0ok[o05Woo`1Ioooooooo0?of00;ooooo00Co0?n3o`3<
ool0om;o0?mB0oooool01?l0Jooo0?ljooooool0oeT2ooooo`0>o`0@oooooooo0?mgo`3Tool0:?oo
0?mUo`3o2_l0oiGo0:koo`1<ooooooooGOl0o`3`ool0;_l5ooooo`03obH0oooooooooooo00?ooooo
1?l0@?l3ooooo`03ocSo0?oooooooooo00;ooooo00?o9P3oooooooooool00oooool00omSo`3oGOl0
ooooo`04ooooo`03o`3`oooooooooooo00;ooooo00Go02koo`3o2_oooooo0=Soo`3oU@06ooooo`03
o`3oIOoooooo0?lX00?ooooo0_l0:?l9ooooo`;o08?o00Co02kooooooooooooooooo0_l0:?l4oooo
o`05o`3ol?ooooooooooobH0ooooool00ol0oeT01Ol0=?oooooooooooooooooo0?m<00Sooooo00?o
E`3oooooooooool01?ooool00olno`3oooooofT0o`02ooooo`;o08?o1?ooool2ocSo00Kooooo00?o
0?l:ooooooooool01?ooool01?lno`3oGOl0oego0?mMo`03ooooo`03ocSo0?lJ0?ooJ@3o00_o0?mI
0_l0obP5ooooo`03o`3ol?oooooooooo00Gooooo00?oG@3oooooooooool01_ooool00ol0=?oooooo
ooooo`0Iooooo`KoHol000?oooooo`0:ooooool06oooool3o`3To`;ooooo00?o0:koooooooooool0
F_ooool3of?o00So0?Ko0ol0ofD[ooooo`Go043o?_ooool005?ooooo00?o0000ooooooooool07_oo
ool01Ol0Vooo0?njo`1Iool0c?oo08Wo00;o06_o00?oooooo`3oD_l0oe801_l0oe83o`1[o`;o08Wo
0ol0om82o`3<o`04ooooool0olco0?o<o`3oc0;o0?of1Oooool2o`1Io`;o0?nj1_ooool6o`3oO@03
ooooool0XOoo0:7o01;ooooo0ol0XOl3o`3oO@Kooooo00[o0?njo`1Ioooooooo0?ofooooool0oh?o
ooooo`3<ool0om;o0?mB0_ooool01?l0Jooo0?lRo`3o>_l0oeT2ooooo`0>o`0@ool0Pooo0?mgo`3o
:?l0:?oo0?mUo`3o2_oooooo0:koo`1<ooooooooGOl0of?o0?l0;_l5ooooo`03ocSo0?lV0?oooooo
00Wooooo00?o>?l0ooooooooool00_ooool00olV0?ooooooooooo`03ooooo`03of?o0?mMo`3ooooo
00Cooooo00?o0?3oooooooooool00_ooool01Ol0;_oo0?l:ooooool0f?oo0?nE00Oooooo00?o0?mU
o`3o:?ooool00_ooool00ol0:?ooooooooooo`08ooooo`05o`23ooooooooooooooooool0;_l01?oo
ool02Ol0:?oooooooooooooooooo0?o`ooooool0oeWo9P3oo`3oF@03ooooo`05o`0doooooooooooo
ooooool0od`02?ooool00omG0?ooooooooooo`04ooooo`04ocko0?ooooooooooofT0o`?ooooo0_l0
Pol4ooooo`03ocSo0?oooooooooo00Cooooo0_l0o`X3ooooo`03ocko0?oooooooooo00;ooooo00Ko
GOl0ocSo0?lho`3o0?m<ofT0oolJ0?l;ooooo`Ko0?mI00?o0?o`o`3oFOl0oeT01oooool00omM0?oo
ooooooooo`05ooooo`03o`0doooooooooooo01oooooo0_mSo`001?l02_ooHol0of?o0?mSo`0Koooo
o`;o0:ko00?o0>Coooooooooool0C_ooool5of?o00[o0?Ko2oooool4o`3oIBcooooo0ol0@?lkoooo
o`00Doooool00ol0003oooooooooo`0Nooooo`05o`2Kool0XOoo0?njo`1Iool0c?l00_l0ROl9o`1[
o`?o08Wo0_l0om801?oooooo0<coo`3<ooooool2o`3oc0?o0?of1?ooool3o`1Io`03o`3o^_oooooo
oooo00Cooooo0ol0ogd4ooooo`?o0:7o5oooool2o`2Qo`03ooooool0oggo0?mm00Gooooo00Wo0?nj
o`1Ioooooooo0?ofooooool0oh?o0<coooooool0om800oooool05?l0Jooo0?ljooooool0oeWooooo
o`1Bool04?oo0?mgooooool0:?oo0?mUooooool0o`[o0?nEo`1<ooooooooGOl0of?o0?l0l?oo02ko
1Oooool00olho`3o9P3oooooo`06ooooo`;o>?l00oooool2obH0o`Gooooo00?oHol0oego0?ooool0
1Oooool00ol0l?ooooooooooo`02ooooo`05o`0^ool0o`[oooooo`3Hool0oiD01_ooool00ol0ofGo
0?lXooooo`02ooooo`03o`0Xoooooooooooo00Oooooo0_l0Pol4ooooo`03o`0^oooooooooooo00;o
oooo00So02Sooooooooooooo0?mIo`3ol?l0oeWoooooobH0o`Cooooo00Go03Cooooooooooooooooo
o`3oC008ooooo`03oeL0oooooooooooo00Gooooo00?o?_l0oooooomY0?l01Oooool2o`23o`?ooooo
1?lho`04ooooo`;o0?l:00?o?_l0ocSo0?lho`001?lho`001OooooooGOl0ofT0oomMo`3o6P3o017o
oooo00?o0?o`o`3o:?l0obP01Ol0oeT3ooooo`03oed0oooooooooooo00?ooooo00?o03Cooooooooo
ool08oooool00ol02_ooooooooooo`06of?o01?ooooo0_l0[_l3ooooo`;o0>Co@oooool8of?o00So
0?Ko6Oooool4o`3oIB3ooooo2ol0ogLkooooo`00Doooool00ol0003oooooooooo`0Oooooo`05o`2K
oooooooo05Woooooool0ooH00_l0c?l8o`29o`?o0?oB00?oooooo`3<ool0c?l00_ooool00ol0olco
0?ofo`3omP05ooooo`;o05Wo0_l0okX5ooooo`?o0?mm1?ooool3o`2Qo`?ooooo4_l0olH7ooooo`?o
0:7o00?o0?mmooooooooool00oooool02Ol0FOoo0?njo`3oc?l0ooKoooooo`3oPol0c?oo0?oBo`3o
DP02ooooo`04o`1[ool0oc[oooooo`3oF@;ooooo00ko013oooooool0ogOo0>Coo`0Xool0ofGo0?l:
o`3oUOl0[_oo04cooooooomMo`3o0?3oo`0^o`Oooooo00?o9P3oocSo0?ooool00oooool00olho`3o
ooooooooo`02ooooo`03obH0oooooooooooo00Gooooo00?oHol0oego0?ooool01?ooool00ol0l?oo
ooooooooo`02ooooo`05o`0^ool0o`[oooooo`3Hool0oiD01_ooool00ol0ofGo0?lXooooo`02oooo
o`03o`0Xoooooooooooo00Oooooo00?o08?oooooooooool01?ooool00ol0;_ooooooooooo`02oooo
o`05o`3oFOl0:?oo0?mIooooool0oo000oooool00olV0?ooooooooooo`02ooooo`05o`0doooooooo
ooooooooool0od`02?ooool00omG0?ooooooooooo`05ooooo`03ocko0?ooooooJ@3o00Kooooo00?o
08?oooooooooool00oooool7ocSo00;o0?l:1_ooool01_l0odcoJ@3ooooooomMo`3o6P3ooego00oo
oooo00?o0?o`ooooooooool01?ooool00ol0obSo0?mIo`3oF@02o`3oF@05oed0ool0oeWo0?mIo`3o
FOl0=?l09oooool2o`0:o`Kooooo1OmSo`0=ooooo`03o`2^oooooooooooo00Gooooo0ol0i?l^oooo
oa;oHol02?l0m_lUooooo`Co0?mU3Oooool?o`3oM`Oooooo1?l0oc@kooooo`00Doooool00ol0003o
ooooooooo`0Oooooo`03o`2Kool0XOoo0?nj00;o05Wo0_l0ooH3o`3<o`Gooooo1?l0c?l2ooooo`;o
0?o<00?o0?ofooooooooool00oooool2o`1Io`;o0?nj1?ooool3o`3oO@Cooooo0ol0XOl6o`3oaP;o
oooo3_l0ohl2ooooo`Ko0?o61?ooool2o`2Qo`03o`3oOOoooooooooo00;ooooo00?o05Woo`3o^_l0
ooH00_ooool00ol0oh?o0<coo`3odP02ooooo`04o`1[ool0ROoo0?ljo`3oF@;ooooo00ko013oo`23
ool0ogOo0>Coo`0Xool0ofGo0?l:ooooool0[_oo04cooooooomMo`3oHol0o`0^o`Sooooo00?o9P3o
ocSo0?lho`000_lho`03ooooo`;o9P3o1oooool00omSo`3oGOl0ooooo`05ooooo`0:o`3`oooooooo
ooooooooool0;_ooooooo`3o2_l0f?ooooooo`3oU@Gooooo00?o0?mUo`3o:?ooool00_ooool00ol0
:?oo0>Coooooo`07ooooo`03o`23oooooooooooo00Kooooo00?o02koo`1Bool0D_l00_l0D_l01?l0
:?ooooooooooool0oo03ooooo`03obH0oooooooooooo00;ooooo00Go03Coooooooooooooooooo`3o
C008ooooo`03oeL0oooooooooooo00Kooooo00?o?_l0ofT0ooooool01_ooool2o`23o`Oooooo00?o
?_l0ooooooooool00_ooool2o`3o2PCooooo00?oJ@3oooooooooool00_ooool00olJ0?ooGOl0oego
0008oego00Cooooo00?o0?o`ooooooooool02_ooool01OmM0?oo0?lXo`3o:?l0=?oooooo00?o0?mI
9_ooool00ol02_ooooooooooo`08ooooo`_oHol00_l0[_l;ooooo`?o0>Co6_oooolAof?o00cooooo
1_l0m_laooooo`Co0?mU00?oooooo`3oMol0ogL01_l0ogL?ooooo`Oo0?ld?oooool005?ooooo00?o
0000ooooooooool08?ooool01_l0Vooo0:7oo`3o^_l0ok[o05Woooooo`;o0?of00?o0?o<o`3<ool0
c?l00ol0c?l6o`3oc0;o0?of0oooool3o`1Io`03o`3o^_oooooooooo00?ooooo0_l0ogd4ooooo`?o
0:7o0ol0olH3ooooo`Go0?n?3_ooool6o`3oS`;ooooo00?o0?o6ooooooooool00oooool00ol0XOoo
0?mmooooo`03ooooo`03o`1Iool0ok[o0?of00;ooooo00?o0<coo`3od_l0oe800_ooool05?l0Jooo
0?ljooooool0oeWoooooo`1Bool04?oo0?mgo`3o:?l0:?oo0?mUooooool0o`[o0?nEo`1<oooooooo
GOl0of?o0?l0l?oo02ko2?ooool2obH0o`Cooooo00?o9P3oooooooooool01oooool00omSo`3oGOl0
ooooo`04ooooo`0:o`3`ooooooooooooooooool0;_ooooooo`3o2_oooooo0=Soo`3oU@Kooooo00Ko
0?mUooooooooooooooooo`0Xool0i?l8ooooo`03o`23oooooooooooo00Gooooo0_l0D_l00ol0;_oo
05;oooooo`03ooooo`03o`0Xool0D_oo05;o00;o05;o00?oooooobH0ooooool00oooool01Ol0=?oo
oooooooooooooooo0?m<00Sooooo00?oE`3oooooooooool01oooool00olno`3oJ@3oooooo`07oooo
o`03o`23oooooooooooo00;ooooo0_lno`07ooooo`?o0?l:00?oJ@3oooooooooool01?ooool00olJ
0?ooooooooooo`07ooooo`CoGOl000?o0?o`oego0?mMo`001?mMo`07ooooo`03oed0oooooooo03Co
00?o0?lX00Coooooo`3oFOl0oeWo0?mI9?ooool00ol02_ooooooooooo`0Aooooo`03o`2^oomSo`3o
Hol000koHol00_l0i?lHof?o01Wooooo1?l0m_ldooooo`So0?mg0ol0ofD=ooooo`Oo0?ldA_ooool0
05?ooooo00?o0000ooooooooool08Oooool01?l0Vooo0:7oo`3oa_l0okX2o`1Io`03ooooool0ooKo
0?of00[o0?of0oooool2o`1Io`;o0?nj1Oooool2o`3oO@?ooooo0ol0XOl3o`3oaP03ooooool0ohoo
0?n?00?o0?n?1oooool;o`3o`0Oooooo0_l0ohl00ooooooo0?o6ooooo`04ooooo`;o0:7o00_o0?mm
ooooooooooooooooo`1Ioooooooo0?ofooooool0oh?o0<coo`3odP02ooooo`0Do`1[ool0j_oooooo
o`3oFOoooooo0?Koo`0@ool0ogOoooooo`0Xoooooooo0?mUo`3o2_l0oiGo04coo`3HooooooooGOl0
of?o0?l0;_l9ooooo`Go9P3o2Oooool00omSo`3oGOl0ooooo`04ooooo`0:o`3`oooooooooooooooo
ool0;_ooooooo`3o2_oooooo0=Soo`3oU@Kooooo00Ko0?mUooooooooooooooooo`0Xool0i?l8oooo
o`03o`23oooooooooooo00Cooooo0_l0D_l00ol0oeWoooooo`0^o`06ooooo`06o`0Xoooooooo0?o`
ooooool0D_oo9P3o1?ooool00ol0=?ooooooooooo`02ooooo`03o`3oC?oooooooooo00Gooooo00?o
E`3oooooooooool02?ooool00omY0?oo?_l0ocko0007ooooo`;o08?o0_lno`0;ooooo`03o`3oC?mY
0?oo0?l:00Kooooo00?o6P3oooooooooool02Oooool00ol0oo3oooooooooo`05ooooo`SoGOl000Go
G@3ooego0?mMo`3oGOl0ooooo`03o`3o:003ooooool0oeWo0?mI00?o0?mI8?ooool00ol02_oooooo
ooooo`0>ooooo`;o0:ko4oooool3o`3Tob[ooooo1?l0m_l_ooooo`Wo0?mg2oooool4o`3oI@03oooo
ool0ocCo0?ld00Ko0?ldCOooool005?ooooo00?o0000ooooooooool08_ooool00ol0Vooo0:7oo`3o
aP02o`3o^P;o05Wo2_ooool4o`1Io`;o0?nj1Oooool2o`3oO@;ooooo0ol0XOl3o`3oaPCo0?n?1ooo
ool3o`3o`0go09_o1ol0ol02ooooo`03o`3oSooooooo0?o600;o0?o61?ooool01ol0XOoo0?mmoooo
oooooooo05Woo`3o^_l0ooH00_ooool00ol0c?oo0?oBo`3oDP02ooooo`03o`1[ool0oc[o0?mI00;o
oooo00oo013oo`23ool0ogOo0>Coo`0Xool0ofGo0?l:ooooool0[_oo04cooooooomMo`3oHol0o`3`
ool0;_l05Oooool00omSo`3oGOl0ooooo`05ooooo`04o`3`ooooooooooooo`0^o`;ooooo00Co0?l:
ooooool0f?oo0?nE1Oooool01ol0ofGo0?lXoooooooooooo02Soooooool0i?l01oooool00ol0Pooo
ooooooooo`02ooooo`?o05;o0_l0oeT3ooooo`03o`0^oooooooooooo00Cooooo00Go02Soo`3ol?oo
ooooooooobH0o`02o`1Bo`;ooooo00?o03Coooooooooool00_ooool00ol0odcoooooooooo`06oooo
o`03oeL0oooooooooooo00Sooooo00?oJ@3ooooooolno`000_lno`03ooooo`?o?_l000?o08?ooooo
ooooool02_ooool00omY0?ooooooooooo`04o`3o2P?ooooo00?o6P3oooooooooool02?ooool00ol0
oo3oooooooooo`0<ooooo`03o`0dooooooooG@3o00;ooooo1?mMo`03o`3o:0?ooooo1?l0oeTMoooo
o`03o`0:oooooooooooo00cooooo00?o0:koooooooooool05_ooool3o`3Tob?ooooo1?l0m_lXoooo
o`_o0?mg4Oooool7o`3o=0Co0?mUD_ooool005?ooooo00?o0000ooooooooool08oooool01?l0Vooo
0:7oo`3oa_l0ogd2o`3o^P[o05Wo00Coooooo`3o^_l0ok[o0?nj1Oooool2o`3oO@;ooooo0_l0XOl0
0ooooooo0?o6o`3oaP03o`3oS`Gooooo1?l0ol05o`2Ko`gooooo1ol0Vol2o`3o`006ooooool0ohoo
0?n?o`3oSooooooo0?o61?ooool01ol0XOoo0?mmoooooooooooo05Woo`3o^_l0ooH00_ooool06?l0
c?oo0?oBoooooooooooo06_oo`3o>_oooooo0?mIooooool0D_oo013oo`3oMol0i?oo02Soo`3oIOoo
oooo0?l:o`3oUOl0C?oooooooego0?mSo`3o0?3oo`0^oaGooooo00?oHol0oego0?ooool01?ooool0
2_l0l?oooooooooooooooooo02koooooool0o`[oooooo`3Hool0oiD6ooooo`06o`3oIOoooooooooo
ooooool0:?oo0>Co1oooool00ol0Poooooooooooo`02ooooo`04o`1Booooooooooooo`3oF@Gooooo
00?o02koooooooooool01?ooool00ol0:?oo0?o`ooooo`02ooooo`03obH0oooooooo05;o00;ooooo
00Go03Coooooooooooooooooo`3oC008ooooo`03oeL0oooooooooooo00Wooooo00?oJ@3ooooooooo
ool01?lno`04ooooo`;o08?o2Oooool00omY0?ooooooooooo`05ooooo`Co0?l:0_lJ0?l7ooooo`03
o`3ol?oooooooooo00gooooo00Co03CoooooooooooooG@3o1Oooool3oego00?o0?lX1?ooool3o`3o
FA_ooooo00?o00[oooooooooool02Oooool2o`2^oacooooo0_l0i?lMooooo`Co0?Ko8oooool9o`3o
MaCooooo2?l0oc@;ooooo`Go0?mUCOooool005?ooooo00?o0000ooooooooool09?ooool01Ol0Vooo
0:7oo`2Qool0oggooooo00Co0?nj0_ooool5o`3o^PGooooo0ol0ogd2ooooo`;o0:7o0ol0olH2o`3o
S`Gooooo0_l0ol05o`2KoaWooooo0ol0Vol3ooooo`;o0?n?00Ko0?o6ooooooooooooooooo`2Qool0
ogd3ooooo`0Lo`1Iool0ooKo0?o<ooooool0c?oo0?oBo`3oD_oooooo08Woo`1[ool0oc[o0?mIoooo
ool0m_oo013oo`3oMooooooo02Soo`3oIOoooooo0?l:o`3oUOl0C?oo0=SooooooomMo`3oHol0o`0^
oaCooooo00?oHol0oego0?ooool01?ooool02ol0l?oooooooooooooooooo02koooooool0o`[ooooo
o`3Hoooooooo0?nE00Gooooo00Ko0?mUooooooooooooooooo`0Xool0i?l7ooooo`04o`23oooooooo
ooooooooo`;o05;o00?oooooo`3oFOl0oeT01_ooool00ol0;_ooooooooooo`05ooooo`05o`0Xoooo
oooooooooooooolV0?l00_ooool00ol0D_ooooooo`0do`03ooooo`03o`3oC?oooooooooo00Kooooo
00?oE`3oooooooooool02Oooool00omY0?ooooooooooo`0:ooooo`03o`23oooooooooooo00Gooooo
00?oJ@3oo`3oC?ooool02_ooool2o`3o2P03oaX0oooooooooooo00Cooooo00?o0?o`ooooooooool0
3?ooool00ol0=?ooooooooooo`02ooooo`03oed0oooooooooooo00Gooooo0omMo`03o`3o:0Cooooo
0ol0oeTIooooo`03o`0:oooooooooooo00Oooooo00?o0:koooooooooool07_ooool3o`3ToaKooooo
1?l0m_lQooooo`Ko0?mg5_ooool7o`3o=1Sooooo1?l0ofE9ooooo`00Doooool00ol0003ooooooooo
o`0Uooooo`03o`2Kool0ol3o0:7o00;o0?o60oooool3o`3o^PKooooo0ol0ogd3ooooo`;o0:7o0_l0
olH3o`3oS`Cooooo00?o0?o0o`2Kool0Vol00_l0VolQooooo`;o09_o00Go0?o0oooooooooooo0?n?
o`3oaP03ooooo`07o`2Qool0oggoooooooooool0FOoo0?njo`3omP02ooooo`07o`3<ool0om;ooooo
ooooool0Jooo0?ljo`3oF@02ooooo`0?o`0@ool0ogOoooooo`3Tool0:?oo0?mUo`3o2_oooooo0:ko
o`1<ooooooooGOl0of?o0?l0l?oo02ko01?ooooo00?oGOl0ooooooooool00oooool01Ol0l?oooooo
oooooooooooo02ko00;ooooo00Co0?l:ooooool0f?oo0?nE1Oooool01ol0ofGo0?lXoooooooooooo
02Soooooool0i?l01_ooool01Ol0Pooooooooooooooooooo05;o00;ooooo00?o0?mIooooooooool0
1_ooool00ol0;_ooooooooooo`06ooooo`04o`0XooooooooooooobH0o`?ooooo00?o05;oo`0doooo
ool00oooool00ol0odcoooooooooo`05ooooo`03oeL0oooooooooooo00[ooooo00?oJ@3ooooooooo
ool02_ooool2o`23o`Cooooo00?oJ@3oo`3oC?ooool03_ooool01?lJ0?oo0?l:o`3o2_l0o`X2oooo
o`03o`3ol?oooooooooo00cooooo00?o03Coooooooooool00oooool00omM0?ooooooooooo`07oooo
o`?oGOl00ol0obP4ooooo`?o0?mI5oooool00ol02_ooooooooooo`04ooooo`;o0:ko9?ooool3o`3T
oa3ooooo0ol0m_lOooooo`Ko0?mg5_ooool6o`3o=2?ooooo1?l0ofE5ooooo`00Doooool3o`0002Ko
oooo00Go09_oo`3o`?l0XOoo0:7oo`3oaP0;o`3oO@03ooooool0olKo0?o600?o0:7o00Co0?o6o`3o
Sol0ohoo0?n?1?ooool01?l0ol3o09_oo`2Kool0VolWooooo`05o`2Kool0ol3o0?o0ooooool0ohl0
0_l0olH2ooooo`0:o`2Qool0oggoooooooooool0FOoo0?njo`3om_oooooo0<coo`3odP;ooooo00oo
06_oo`3o8_l0oc[o0?mIooooool0D_oo013oo`3oMol0i?oo02Soo`3oIOl0o`[oooooo`3oUOl0C?l0
0_ooool00omMo`3oHol0o`0^o`0Booooo`03of?o0?mMo`3ooooo00Cooooo00Co0?3ooooooooooooo
02ko0_ooool01?l0o`[oooooo`3Hool0oiD5ooooo`07o`3oIOl0obSoooooooooool0:?ooooooo`3T
o`06ooooo`03o`23oooooooooooo00;o05;o00?oooooo`3oFOl0oeT02_ooool00ol0;_oooooooooo
o`05ooooo`04o`0XooooooooooooobH0o`Cooooo00?o03Coooooooooool00_ooool00ol0odcooooo
ooooo`06ooooo`03oeL0oooooooooooo00Wooooo00?oJ@3oooooooooool03?ooool2o`23o`04oooo
oomY0?ooooooo`3oC13ooooo00Go6P3ooooooooooooo0?l:o`3ol003o`3o2P_ooooo00?o03Cooooo
ooooool01?ooool00omM0?ooooooooooo`0:ooooo`;oGOl000Coooooo`3o:?l0obSo0?lX1?ooool3
o`3oFAGooooo00?o00[oooooooooool00_ooool00ol0[_ooooooooooo`0Wooooo`?o0>Co2_ooool3
o`3foacooooo1_l0ogLGooooo`Go0?ld;Oooool5o`3oID3ooooo001Cooooo`03o`000?oooooooooo
02Oooooo00?o09_oo`3o`?l0ol001?l0XOl4o`3oaPOo0:7o0_l0ohl5ooooo`;o0?o00ol0Vol[oooo
o`07o`2Koooooooo0?o0ooooool0ohooooooo`3oaP02ooooo`06o`2Qool0oggoooooo`1Iool0ok[o
0?of0_ooool05ol0c?oo0?oBooooool0ROoo06_oo`3o>_l0oeWoooooo`3fool04?oo0?mgo`3o:?l0
:?oo0?mUooooool0o`[o0?nEo`1<ool0f?oooooooego0?mSo`3o02ko017ooooo00?oHol0oego0?oo
ool01?ooool01?l0l?ooooooooooool0;_l2ooooo`05o`3o2_oooooo0=Soooooool0oiD01Oooool0
1_l0ofGoooooooooool0:?ooooooo`3To`Kooooo00Co08?ooooooooooooo05;o0_ooool00ol0oeWo
ooooooooo`0:ooooo`03o`0^oooooooooooo00Gooooo00Go0?o`o`0XooooooooooooobH0o`03oooo
o`03o`0doooooooooooo00;ooooo00?o0?m<ooooooooool01_ooool00omG0?ooooooooooo`0:oooo
o`03ofT0oooooooooooo00cooooo0_mY0?l00ol0Pooo0?m<ooooo`0Aooooo`04oaX0oooooooooooo
o`3ol0?ooooo1_l0o`X5ooooo`03o`0doooooooooooo00Gooooo00?oG@3oooooooooool02oooool3
oego0004ooooool0obSo0?lXo`3o:0Cooooo0_l0oeTDooooo`04o`0:oooooooo0:koo`2^obgooooo
0_l0i?l5ooooo`?o0?Ko6_ooool5o`3oMaOooooo1_l0oc@gooooo`Go0?mU>oooool005?ooooo00?o
0000ooooooooool0:?ooool2o`2Ko`;o0?o00_l0ohl5o`2Qo`Co0?n?1Oooool3o`3o`0?o09_o;ooo
ool02_l0Voooooooo`3o`?oooooo0?n?ooooool0olKoooooo`2Qool0ogd2ooooo`06o`1Iool0ok[o
0?ofooooool0c?oo0?oB0_ooool00ol0Jooo0?ljo`3oF@02ooooo`0:o`0@ool0ogOoooooo`0Xoooo
oooo0?mUo`3o2_oooooo0:koo`1<o`;ooooo00?oGOl0o`3`ool0;_l03oooool00omSo`3oGOl0oooo
o`04ooooo`05o`3`ooooooooooooooooool0;_l00_ooool01?l0o`[oooooo`3Hool0oiD5ooooo`06
o`3oIOooooooooooo`0Xoooooooo0>Co1_ooool01?l0Poooooooooooool0D_l2ooooo`03o`3oFOoo
oooooooo00_ooooo00?o02koooooooooool01Oooool01Ol0oo3o02Sooooooooooooo9P3o00Cooooo
00Go03Coooooooooooooooooo`3oC008ooooo`03oeL0oooooooooooo00_ooooo00?oJ@3ooooooooo
ool02_ooool01?mY0?ooooooooooooooool2o`23oa;ooooo00?o6P3oo`3ol?ooool02Oooool4o`3o
2P03o`0dool0o`[ooooo00Oooooo00?oG@3oooooooooool03Oooool3oego0003ooooool0obSo0?lX
00Cooooo0ol0oeTBooooo`03o`0:oooooooooooo02oooooo0ol0i?l2o`3foaWooooo1?l0ogLGoooo
o`Go0?ldOOooool005?ooooo00?o0000ooooooooool0:_ooool2o`2Ko`?o0?o02_ooool3o`3o`0?o
09_o<oooool2o`2Ko`04o`3o`?oooooo0?n?o`3oaP;ooooo00Wo0:7oo`3oOOooooooooooo`1Iool0
ooKoooooo`3oPol0c?l00_ooool03ol0Jooo0?lRo`3o>_l0oeWoooooo`0@ool0Pooo0?mgo`3Tool0
:?oo0?mUo`3o2_oooooo0?nEo`1<o`02ooooo`03oego0?mSo`3o02ko00kooooo00?oHol0oego0?oo
ool01Oooool01?l0l?ooooooooooool0;_l2ooooo`05o`3o2_oooooo0=Soooooool0oiD01?ooool0
1?l0ofGo0?lXooooool0:?l2ooooo`03o`3Toooooooooooo00?ooooo00Co08?ooooooooooooo05;o
0_ooool00ol0oeWoooooooooo`0<ooooo`03o`0^oooooooooooo00Gooooo00Go0?o`ooooool0:?oo
ooooobH0o`04ooooo`03o`0dool0D_oooooo00;ooooo00?o0?m<ooooooooool01Oooool00omG0?oo
ooooooooo`0<ooooo`03ofT0oooooooooooo00Sooooo00GoJ@3oooooooooooooooooo`3oC002oooo
o`;o08?o4Oooool00olJ0?ooooooooooo`0;ooooo`03o`0doooooooooooo00Co0?l:1Oooool00omM
0?ooooooooooo`0?ooooo`?oGOl00_l0obP5ooooo`?o0?mI3Oooool2o`2^o`03ooooool02_oo00[o
02kooooo0ol0m_l01?oooooo0>Coo`3Tool0i?lDooooo`Co0?mg5_ooool5o`3o=3gooooo2_l0C?lk
ooooo`00Doooool00ol0003oooooooooo`0/ooooo`Go09_o1Ol0ol06o`2KocSooooo00Go09_oo`3o
`?oooooo0?n?o`3oaP02ooooo`0Fo`2Qool0oggoooooo`1Iool0ok[o0?ofooooool0c?oo0?oBoooo
ool0ROoo06_oo`3o>_l0oeWoooooo`1Bool04?oo0?mgo`3o=?l0:?oo0?mUo`3o2P;ooooo00Ko04co
o`3Hoooooooooooooego0?l0;_l=ooooo`03of?o0?ooooooGOl000Gooooo00Co0?3ooooooooooooo
02ko0_ooool01Ol0o`[oooooooooool0f?oo0?nE00Gooooo00Ko0?mUoooooooooooo02Soooooool0
i?l6ooooo`03o`23oooooooo05;o00;ooooo00?o0?mIooooooooool03_ooool00ol0;_oooooooooo
o`05ooooo`04o`3ol?l0:?ooooooobH0o`Cooooo00?o03Coooooool0D_l00_ooool00ol0odcooooo
ooooo`06ooooo`03oeL0oooooooooooo00cooooo0_mY0?l7ooooo`03ofT0oooooooooooo00;ooooo
00?o0?m<ooooooooool00_ooool2o`23o`oooooo00?o0?o`oaX0ooooool02oooool00ol0=?oooooo
ooooo`04ooooo`?o0?l:0oooool00omM0?ooooooooooo`0Aooooo`;oGOl00_l0obP6ooooo`?o0?mI
2Oooool00ol0[_ooooooooooo`03ooooo`03o`0:oooooooooooo02Sooooo0ol0m_l7ooooo`?o0>Co
3_ooool3o`3oMaGooooo1Ol0oc@boooooa3o04coAOooool005?ooooo00?o0000ooooooooool0<?oo
ool6o`2Kocoooooo00oo09_oo`3o`?oooooo0?n?o`3oa_oooooo0:7oooooool0oggoooooo`1Iool0
ooKoooooo`3<ool0om800_ooool02ol0Jooo0?ljo`3oFOoooooo0?Koo`0@ool0ogOo0?lXo`0Xool0
ofGo0?l:00;ooooo00?o04coo`3Hooooool00_ooool00ol0l?oo02koooooo`09ooooo`;oHol000?o
oooooego0?ooool01?ooool01?l0l?ooooooooooool0;_l3ooooo`04o`3o2_oooooo0=Soo`3oU@Go
oooo00Ko0?mUoooooooooooo02Soooooool0i?l6ooooo`Ko04co4Oooool00ol0;_ooooooooooo`05
ooooo`04o`3ol?l0:?ooooooobH0o`Cooooo00?o03Coooooool0D_l00_ooool00ol0odcooooooooo
o`06ooooo`03oeL0oooooooooooo00kooooo1omY0?l4ooooo`03o`3oC?oooooooooo00Gooooo0_l0
Pol<ooooo`04o`3ol?oooooooooooaX0o`[ooooo00?o03Coooooooooool02?ooool3o`3o2P03oooo
oomM0?oooooo01Cooooo00?oGOl0o`3o:?l0obP01oooool2o`3oF@Gooooo0_l0[_l7ooooo`03o`0:
oooooooooooo02Cooooo0ol0m_l=ooooo`?o0>Co1oooool4o`3oMa?ooooo1Ol0oc@[ooooo`co04co
EOooool005?ooooo00?o0000ooooooooool0M_ooool02?l0Vooo0?o0ooooool0ohoo0?o6ooooool0
XOoo0?mm0_ooool05Ol0FOoo0?ofooooool0c?oo0?mBooooool0ROoo06_oo`3o>_l0oeWoooooo`0@
ool0Poooooooo`0Xoooooooo0?mUo`3o2_oooooo0:koo`1<o`04ooooo`03o`3`ool0;_oooooo00Oo
oooo00CoHol0ooooooooooooGOl01Oooool01Ol0l?oooooooooooooooooo02ko00;ooooo00Go0?l:
ooooool0f?ooooooo`3oU@05ooooo`03o`3oIOoooooo02So00;ooooo00?o0>Coooooooooool00_oo
ool2o`1<o`03ooooool0D_oooooo00;ooooo0_l0C?l@ooooo`03o`0^oooooooooooo00Gooooo00Go
0?o`ooooool0:?ooooooobH0o`03ooooo`04o`0dooooooooooooo`1Bo`;ooooo00?o0?m<oooooooo
ool01Oooool00omG0?ooooooooooo`0Iooooo`03o`3oC?oooooooooo00Oooooo0_l0Pol:ooooo`05
o`3ol?oooooooooooooooolJ0?l02Oooool00ol0=?ooooooooooo`0;ooooo`;o0?l:00?oG@3ooooo
ooooool05Oooool2o`3o:003oego0?oooooooooo00Cooooo0_l0oeT2ooooo`03o`2^oooooooooooo
00Sooooo00?o00[oooooooooool08?ooool3o`3foa?ooooo0ol0i?l4o`3oMa;ooooo1Ol0oc@Woooo
o`Wo04coHOooool005?ooooo00?o0000ooooooooool0Moooool01?l0Vooo0?o0o`3oSol0olH2oooo
o`0Eo`2Qool0oggoooooo`1Iool0ooKoooooo`3<ool0om;oooooo`29ool0Jooo0?ljo`3oFOoooooo
013oo`23ool0ogOo0?ldo`0Xool0ofGo0?l:00;ooooo00?o04coo`3Hooooool00_ooool00omMo`3o
02koof?o0006ooooo`04of?o0?ooooooGOl0oego00Gooooo00Go0?3oooooooooooooooooo`0^o`02
ooooo`05o`3o2_ooooooooooo`3Hool0oiD01Oooool01_l0ofGoooooooooool0:?ooooooo`3To`;o
oooo0ol0C?l00ol0Poooooooo`1Bo`03ooooo`03o`3oFOoooooooooo00;o04co3_ooool00ol0;_oo
ooooooooo`05ooooo`05o`3ol?oooooo02SooooooolV0?l01?ooool01ol0=?ooooooooooool0D_oo
ooooo`3oC?ooool01_l0om800omG0?ooooooooooo`0Hooooo`03o`3oC?oooooooooo00[ooooo0_l0
Pol7ooooo`03o`3ol?oooooooooo00?ooooo00?o6P3oooooooooool01Oooool00ol0=?oooooooooo
o`0>ooooo`03oed0ool0o`[o0?l:01Oooooo00Co0?lXoego0?mMo`3oGOl01Oooool00ol0oeWo0:ko
ooooo`0;ooooo`03o`0:oooooooooooo01cooooo0ol0m_lEooooo`Co0?mg0ol0i?l?ooooo`Co0?ld
9_ooool6o`1<of[ooooo001Cooooo`03o`000?oooooooooo07Sooooo00Oo09_oooooool0ohoo0?o6
ooooool0XOoo0?mm00;ooooo00Co05Woo`3om_l0oh?o0<co0_ooool02ol0Jooo0?ljo`3oFOoooooo
05;oo`0@ool0ogOo0?ldo`0Xool0ofGo0?l:00;ooooo00?o04coo`3Hooooool00oooool01?l0l?oo
02koof?o0?mSo`02ooooo`?oHol000?oGOl0ooooooooool01?ooool01Ol0l?oooooooooooooooooo
02ko00;ooooo00Ko0?l:oooooooooooo0=Soooooool0oiD4ooooo`06o`3oIOooooooooooo`0Xoooo
oooo0>Co0oooool01Ol0C?ooooooooooool0Pooo05;o00?ooooo00?o0?mIooooooooool00oooool0
0ol0C?ooooooooooo`0;ooooo`03o`0^oooooooooooo00Gooooo00Go0?o`ooooool0:?ooooooobH0
o`03ooooo`05o`3od_l0=?oo0?oBo`3od_l0D_l01?l0om84ooooo`;o0?oB00?oE`3oo`3od_l0om80
1_l0om8Aooooo`03o`3oC?oooooooooo00cooooo0_l0Pol5ooooo`03o`3ol?oooooooooo00Cooooo
0_lJ0?l5ooooo`03o`0doooooooooooo00oooooo00?oG@3oooooool0o`X00_l0o`XEooooo`;o0?lX
00?ooooooego0?mMo`001?ooool00ol0[_oo0?mIo`3oF@0;ooooo`03o`0:oooooooooooo01Wooooo
0_l0m_lDooooo`Co0?mg1oooool3o`3To`Oooooo1Ol0oc@Qooooo`Wo04coL?ooool005?ooooo00?o
0000ooooooooool0N?ooool02?l0Vooo0?o0ooooool0ohoo0?o6ooooool0XOoo0?mm0_ooool02?l0
FOooooooo`3<ool0om;oooooo`29ool0Jooo0?mI0_ooool01_l04?oo0?mgo`3o=?l0:?oo0?mUo`3o
2P;ooooo00?o0:koo`1<ooooool01?ooool00ol0;_oo0?3oooooo`02of?o00;ooooo00?oGOl0oooo
ooooool01?ooool01Ol0l?oooooooooooooooooo02ko00?ooooo00Go0?l:ooooool0f?ooooooo`3o
U@04ooooo`04o`3o:?l0ofGoooooo`0Xo`;ooooo00Co0>Coooooool0C?oo04co0_ooool00ol0Pooo
ooooo`1Bo`02ooooo`03o`3oFOl0ocCo0?ld00Co0?ld00?o04coo`3o>_l0ocX01_l0ocX6ooooo`03
o`0^oooooooooooo00Gooooo00Co0?o`o`3od_l0:?oo9P3o0ol0om800ooooooo03Coooooo`02oooo
o`03o`1Boooooooo0?m<00Oooooo00?oE`3oooooooooool01_ooool5o`3odP_ooooo00?o0?m<oooo
ooooool03oooool2o`23o`?ooooo00?o0?o`ooooooooool01_ooool01OlJ0?oooooooooooooooooo
03Co01?ooooo00CoG@3ooooooooooooooooo0_l0o`XEooooo`;o0?lX00Gooooooego0?mMo`3oGOl0
o`2^o`03ooooo`;o0?mI2_ooool00ol02_ooooooooooo`0Fooooo`;o0?Ko4oooool3o`3oM`kooooo
0ol0i?l4o`3o=1kooooo2?l0C?miooooo`00Doooool00ol0003oooooooooo`1iooooo`07o`2Kool0
ol3oooooo`3oa_oooooo0:7oo`3oO@02ooooo`0Ao`1Iool0ooKo0<coo`3od_oooooo08Woo`1[ool0
oc[o0?mIooooool04?oo08?oooooool0:?oo0>Coo`3oIOl0o`X00_ooool00ol0C?oo0=Soooooo`04
ooooo`03o`0^ool0l?ooGOl000?oGOl01oooool01?l0l?ooooooo`0^ool0;_l3ooooo`06o`3o2_oo
ooooooooo`3Hoooooooo0?nE1?ooool00ol0ofGoooooo`0Xo`02ooooo`03o`3Toooooooo04co00?o
oooo00Co08?oooooool0D_oooooo0ol0[_l00ol0ocCoooooooooo`04o`3o>P03o`1<oooooooooooo
00Gooooo0ol0ocX3ooooo`03o`0^oooooooooooo00?ooooo0_l0om801Ol0oo3oooooo`0Xoooooooo
9P3o00?ooooo00Oo03Coooooooooooooooooo`1Boooooooo0?m<00Oooooo00?oE`3oooooooooool0
2oooool3o`3odPSooooo00?o0?m<ooooooooool04Oooool2o`23o`03o`3ol?oooooooooo00Sooooo
00Co6P3ooooooooooooo03Co5?ooool00omM0?ooooooooooo`02ooooo`;o0?l:5Oooool2o`3o:003
ooooool0[_ooGOl000;oGOl00oooool3o`3oF@Sooooo00?o00[oooooooooool05?ooool00ol0m_oo
ooooooooo`0@ooooo`?o0?mg4?ooool4o`3o=0?o0>Co6oooool4o`1<oh7ooooo001Cooooo`03o`00
0?oooooooooo07[ooooo00Oo09_oo`3o`?l0ohoo0?o6ooooool0XOoo0?mm00;ooooo00?o05Wooooo
ool0c?l00_ooool02ol0Jooo0?ljo`3oFOoooooo013oo`23ool0ogOo0?ldo`0Xool0ofGo0?l:00;o
oooo00?o04coo`3Hooooool01Oooool00ol0;_ooooooooooo`08ooooo`03o`3`oooooooo02ko00Co
oooo00Ko0?l:oooooooooooo0=Soooooool0oiD4ooooo`08o`3o:?l0ofGoooooo`0Xoooooooo0>Co
ooooool0C?l3ooooo`03o`23ool0[_oo05;o00;o0:ko00?o0?mIooooool0[_l00ol0[_l4ooooo`03
o`1<oooooooooooo00Sooooo00Co0?ljoooooooooooo02ko0_ooool3o`3odP;ooooo00Go0?o`oooo
ool0:?ooooooobH0o`04ooooo`06o`0dooooooooooooooooool0D_oo0?m<1oooool00omG0?oooooo
ooooo`0>ooooo`Co0?oB0oooool00ol0odcoooooooooo`0Dooooo`;o08?o2_ooool00olJ0?oo03Co
ooooo`0Eooooo`03oed0oooooooooooo00?ooooo0ol0o`XDooooo`03o`2^ool0obSooooo00;ooooo
0omMo`03ooooo`;o0?mI1oooool00ol02_ooooooooooo`0Aooooo`;o0?Ko4?ooool3o`3oM`kooooo
1Ol0oc@7ooooo`?o0>Co5?ooool4o`1<ohGooooo001Cooooo`03o`000?oooooooooo07_ooooo00Ko
09_oooooool0ohoo0?o6o`2Qool0ogd2ooooo`0Do`1Iool0olco0<coo`3od_oooooo08Woo`1[ool0
oeWoooooo`1Bool04?oo0?mgo`3o=?l0:?oo0?mUooooool0o`[oooooo`2^ool0C?l7ooooo`03o`0^
ool0l?oooooo00Gooooo0_l0l?l00ooooooo02koooooo`04ooooo`05o`3o2_oooooo0=Soooooool0
oiD01?ooool01?l0obSo0?mUooooool0:?l2ooooo`03o`3Tool0C?oooooo00;ooooo00Ko0:koo`23
ool0D_ooooooo`3o=?l0oeT4ooooo`03o`3o>_l0[_oo0:ko00Cooooo00?o04coo`3o=?ooool02?oo
ool00ol0oc[oooooo`0^o`02o`3odPGooooo00Go0?o`oooooooooooo02SoobH0o`04ooooo`03o`0d
oooooooooooo00;ooooo00?o05;oooooooooool01_ooool00omG0?ooooooooooo`0Aooooo`Ko0?oB
4oooool00ol0oo3oooooooooo`03o`23o`Sooooo00?o6P3oooooooooool05Oooool00omM0?oooooo
ooooo`05ooooo`;o0?l:4Oooool00ol0[_ooooooooooo`02o`3o:0Cooooo0omMo`02ooooo`;o0?mI
1_ooool00ol02_ooooooooooo`0>ooooo`;o0?Ko4?ooool2o`3oM`kooooo0ol0oc@?ooooo`?o0>Co
3?ooool5o`1<ohWooooo001Cooooo`03o`000?oooooooooo07_ooooo00Ko09_oo`3o`?oooooo0?o6
ooooool0XOl2ooooo`0Eo`1Iool0ooKo0?n3o`3<oooooooo08Woo`1[ool0oc[o0?mIooooool04?oo
08?oo`3o=?l0:?oo0>Coo`3oIOl0o`[oooooo`3oUOl0C?oo0=So00Oooooo00?o02koo`3`ool0l?l0
1?l0l?l00ooooooo02koo`0^o`05ooooo`06o`3o2_ooooooooooo`3Hoooooooo0?nE1?ooool00ol0
ofGoooooo`0Xo`02ooooo`04o`3Tool0C?ooooooooooo`;o0:ko00Go08?oooooool0D_oo0?ldo`3o
F@04ooooo`05o`3o>_ooooooooooooooool0[_l01?ooool00ol0C?oo0?ldooooo`07ooooo`;o0?oB
00?o02koooooooooool01Oooool01Ol0oo3oooooooooool0:?oo9P3o00Cooooo00?o03Cooooooooo
ool00_ooool00ol0D_oo0?m<ooooo`06ooooo`03oeL0oooooooooooo01?ooooo00Co0?m<oooooooo
oooooooo1Ol0om8>ooooo`03o`3ol?oooooooooo00?ooooo0ol0Pol4ooooo`03o`0doooooooo6P3o
01Oooooo00?oG@3oooooooooool01_ooool2o`3o2Pkooooo00?o0:koooooooooool00oooool2o`3o
:0Gooooo0omMo`000ooooooo0?mIo`3oF@05ooooo`03o`0:oooooooooooo00_ooooo0_l0m_l@oooo
o`;o0?mg3Oooool3o`3o=1Gooooo0ol0i?l3ooooo`Ko04coS_ooool005?ooooo00?o0000oooooooo
ool0O?ooool01_l0Vooo0?o0o`3oSol0olKo0:7oo`3oO@;ooooo00?o05Woooooool0c?l00_ooool0
2ol0Jooo0?ljo`3oFOoooooo013oo`23oooooooo0?ldo`0Xool0ofGo0?l:00;ooooo00?o04coo`3H
ooooool01oooool3o`0^o`04ooooool0;_oo02koo`0^o`Kooooo00Ko0?l:oooooooooooo0=Sooooo
ool0oiD4ooooo`04o`3o:?l0ofGoooooo`0Xo`;ooooo00_o04cooooooooooooo0:koooooool0Pooo
ooooo`1Bool0ocCoooooo`3oF@02ooooo`;o0?lj1?ooool5o`0@o`03o`1<ool0ocCooooo00Kooooo
00Go0?oBoooooooooooo0?ljo`0^o`07ooooo`04o`3ol?oooooo02SoobH0o`Cooooo00?o03Cooooo
ooooool00oooool00ol0D_ooooooooooo`05ooooo`03oeL0oooooooooooo01?ooooo00?o0?m<oooo
ooooool01_ooool6o`3odPOooooo00?o0?o`ooooooooool01oooool2o`23o`03ooooool0=?oooooo
00;ooooo00?o6P3oooooooooool05?ooool00omM0?ooooooooooo`08ooooo`;o0?l:2oooool00ol0
[_ooooooooooo`06ooooo`;o0?lX1_ooool3oego00;o0?mI1?ooool2o`0:o`Wooooo0_l0m_l?oooo
o`?o0?mg3?ooool3o`3o=1Wooooo1Ol0C?nDooooo`00Doooool00ol0003oooooooooo`1mooooo`05
o`2Koooooooo0?o6ooooool0XOl00_ooool05Ol0FOoo0?ofo`3<ool0om;oooooo`1[ool0oc[o0?mI
ooooool04?oo08?oo`3oMol0ocCo02Soo`3oIOoooooo0?l:ooooool0[_oo04coo`3Ho`0:ooooo`03
o`0^oooooooooooo00Oooooo00Ko0?l:oooooooooooo0=Soooooool0oiD3ooooo`04o`3o:?l0ofGo
ooooo`0Xo`;ooooo00Co04cooooooooooooo0:ko0_ooool01Ol0Pooo05;oo`3o=?oooooo0?mI00;o
oooo00Co0?ljoooooooooooooooo0ol04?l2ooooo`03o`2^oooooooooooo00;o013o00?o0?ldoooo
ooooool00_ooool2o`3odPCooooo00?o02koooooooooool01Oooool01Ol0oo3oooooooooool0:?oo
9P3o00Cooooo00?o03Coooooooooool00_ooool00ol0D_ooooooooooo`05ooooo`03oeL0oooooooo
oooo01;ooooo00?o0?m<ooooooooool03Oooool6o`3odP03ooooool0oo3ooooo00[ooooo00?o08?o
o`0dool0Pol00oooool00olJ0?ooooooooooo`0Dooooo`03oed0oooooooooooo00Wooooo0_l0o`X8
ooooo`03o`2^oooooooooooo00Wooooo0ol0obP8ooooo`;o0?mI1?mMo`000ol02_ooooooooooo`04
ooooo`;o0?Ko3oooool2o`3oM`cooooo0ol0oc@Iooooo`?o04co1Oooool3o`3Toi7ooooo001Coooo
o`03o`000?oooooooooo07gooooo01co09_oo`3o`?l0ohoo0?o6o`2Qool0oggoooooo`1Iool0ooKo
0?n3o`3<oooooooo08Woo`1[ool0oeWoooooo`1Bool04?oo08?oo`3o=?l0:?oo0>Coo`3oIOl0o`[o
ooooo`2^ool0C?oo0=So4oooool01_l0o`[oooooooooool0f?ooooooo`3oU@Cooooo00?o0?lXo`3o
IOl0:?l00_ooool01?l0C?ooooooooooool0[_l2ooooo`05o`23ool0D_ooooooooooool0oeT00_oo
ool00ol0oc[oooooooooo`02o`0@o`Kooooo00Oo0:kooooooooooooo04coo`0@ool0ocCooooo00;o
0?oB1_ooool00ol0;_oo0?ljooooo`05ooooo`05o`3ol?ooooooooooo`0XoolV0?l01?ooool00ol0
=?ooooooooooo`03ooooo`03o`1Boooooooooooo00Gooooo00?oE`3oooooooooool04Oooool00ol0
odcoooooooooo`0Cooooo`03o`3od_l0oo3o0?oB00;o0?oB2?ooool00ol0=?ooooooooooo`02o`23
o`;ooooo00?o6P3oooooooooool05?ooool00omM0?ooooooooooo`0:ooooo`;o0?l:1Oooool00ol0
[_ooooooooooo`0=ooooo`;o0?lX2?ooool2o`3oF@;ooooo00?oGOl0o`0:oomMo`000omMo`000ol0
m_ooooooooooo`0=ooooo`;o0?mg2oooool3o`3o=1Wooooo0ol0C?l;ooooo`Co0>CoSOooool005?o
oooo00?o0000ooooooooool0O_ooool01Ol0Voooooooo`3oa_oooooo0:7o00;ooooo00?o05Woo`3o
m_l0c?l00_ooool04?l0Jooo0?ljo`3oFOoooooo013oo`23oooooooo0?ldo`0Xool0ofGoooooo`3o
2_oooooo04coooooool0f?lAooooo`04o`3o2_ooooooooooo`3Ho`;ooooo00Oo0?nEoooooooooooo
ooooo`3o:?l0ofGo02So00;ooooo00Co04coo`3Toooooooo0:ko0_ooool01Ol0Pooo0?ldo`1Boooo
oooo0?mI00;ooooo00Co0?ljoooooooooooo013o2?ooool01ol0[_ooooooooooool0C?ooooooo`0@
ool0om802?ooool00ol0;_oo0?ljooooo`05ooooo`05o`3ol?ooooooooooo`0XoolV0?l01?ooool0
0ol0=?ooooooooooo`03ooooo`03o`1Boooooooooooo00Gooooo00?oE`3oooooooooool04?ooool0
0ol0odcoooooooooo`0Dooooo`03o`3ol?oooooooooo00;ooooo1_l0om82ooooo`03o`0doooooooo
oooo00;ooooo0_l0Pol00ooooooo6P3oooooo`0Eooooo`03oed0oooooooooooo00_ooooo0_l0o`X2
ooooo`03o`2^oooooooooooo013ooooo0_l0obP8ooooo`?o0?mI00?oooooo`0:ool02_l00_l0m_l6
oego00Sooooo0_l0ogL:ooooo`?o0?ld6?ooool4o`1<oa;ooooo0ol0i?n:ooooo`00Doooool3o`00
07oooooo01_o09_oo`3oSol0olKo0:7oo`3oOOoooooo05Woo`3om_l0c?oo0?oBooooool0Jooo0?lj
o`3oFOoooooo013oo`23ool0ogOo0?ldo`0Xool0ofGoooooo`3o2_oooooo0:koo`1<ool0f?l04Ooo
ool01_l0o`[oooooooooool0f?ooooooo`3oU@?ooooo00Oo0?lXo`3oIOoooooo02Soooooool0C?oo
0>Co00;o0:ko0oooool01ol0Pooo05;ooooooooooooo0?mIooooool0ocX00_ooool00ol04?oooooo
ooooo`08ooooo`06o`2^ooooooooooooo`1<oooooooo013o0_ooool6o`3oP`03o`0^ool0c?oo0<co
00?o0<co0_ooool01Ol0oo3ooooooooooooooooo9P3o00Cooooo00?o03Coooooooooool00oooool0
0ol0odco05;oooooo`05ooooo`03oeL0oooooooooooo013ooooo00?o0?m<ooooooooool05?ooool0
0ol0oo3oooooooooo`08ooooo`03o`3od_l0=?oo0?oB00?o0?oB0oooool2o`23o`03oaX0oooooooo
oooo01Cooooo00?oG@3oooooooooool03?ooool00ol0o`[o0:koooooo`0Dooooo`;o0?lX2Oooool0
1?l0oeWo0?Koo`3fool02_l7ooooo`GoGOl000?oooooo`3oMol0ogL02Oooool3o`3o=1Sooooo0ol0
C?lIooooo`?o0>Co?oooool=oego03_ooooo001Cooooo`03o`000?oooooooooo07oooooo01co09_o
o`3o`?l0olKo0:7oo`3oOOoooooo05Woo`3om_l0oh?o0<coooooool0Jooo0?lRo`3oFOoooooo013o
o`23ool0ogOo0?ldo`0Xool0i?oo0?mUooooool0o`[o0:koo`1<oooooooo0=So3oooool01_l0o`[o
ooooooooool0f?ooooooo`3oU@Cooooo00Oo0?lXo`3oIOl0:?ooooooo`1<oooooooo0:ko00Cooooo
00Oo08?oo`1Booooooooooooo`3oFOoooooo0?lj00;ooooo00?o013oooooooooool02Oooool01?l0
[_ooooooo`3od_l0C?l2o`3oP`03o`0@ool0oh?o0?n300;ooooo1?l0c?l00ol0;_oo0?n3o`3oP`02
o`3oP`Go0<co00?oooooobH0ooooool01?ooool00ol0=?ooooooooooo`03ooooo`03o`1Boooooooo
oooo00Gooooo00?oE`3oooooooooool03_ooool00ol0odcoooooooooo`0Dooooo`03o`3ol?oooooo
oooo00[ooooo00?o03Coooooooooool00_ooool5o`3odP03o`23oolJ0?oooooo01Gooooo00?oG@3o
ooooooooool02oooool00ol0[_oo0?l:o`3o2P0Fooooo`;o0?lX1_ooool2o`3fo`;ooooo00?o0?mI
o`0:ooooool02Oooool2o`3oM`SoGOl00ol0oc@6oego01;ooooo0ol0C?lOooooo`?o0>Co9?oooolH
oego04Sooooo001Cooooo`03o`000?oooooooooo083ooooo01Wo09_oo`3oSol0olKo0:7oooooool0
ok[o05Woo`3om_l0c?ooooooo`29ool0Jooo0?ljo`3oFOl0D_oo013oo`23oooooooo0?ldo`0Xool0
ofGoooooo`3o2_oooooo04co00;ooooo00?o0=Soooooooooool02oooool01_l0o`[ooooooooooooo
oooo0=Soo`3oU@Cooooo00Oo0?lXo`3oIOl0:?ooooooo`1<oooooooo0:ko00Cooooo00Go08?ooooo
ool0D_ooooooo`3oF@02ooooo`03o`3o>_oooooo013o00_ooooo00Go0?mBo`2^ool0om;o0?n3o`1<
o`02ooooo`03o`3o=?l04?oo0<co00;o0<co00Go0?mBooooooooooooooooo`0^o`02ooooo`03o`3o
>_oooooo0?n300;ooooo00Go0?o`ooooool0c?oo02SoobH0o`04ooooo`03o`0doooooooooooo00?o
oooo00?o0?m<o`1Booooool01Oooool00omG0?ooooooooooo`0=ooooo`03o`3oC?oooooooooo01Go
oooo00?o0?o`ooooooooool02Oooool00ol0=?ooooooooooo`08ooooo`04o`3od_lJ0?oo08?oo`3o
dQGooooo00?oG@3oooooooooool02_ooool00ol0[_ooooooooooo`02o`3o2QKooooo0ol0obP2oooo
o`03o`3foooooooooooo00Cooooo0_l02_l00ol0oeWoooooooooo`03ooooo`;o0?mg2?ooool2o`3o
=0Wooooo3omMo`03o`1<o`GoGOl08?ooool4o`3To`_ooooo5OmMo`1Pooooo`00Doooool00ol0003o
ooooooooo`21ooooo`0Ko`2Kool0olKo0:7oo`3oOOoooooo05Woo`3om_l0c?oo0?oBooooool0Jooo
0?ljo`3oFOoooooo013oo`23ool0ogOo0?ldo`0Xoooooooo0?mUooooool0o`[o0:koo`1<oooooooo
0=So00cooooo00Oo0?l:ooooooooooooooooo`3Hoooooooo0?nE00?ooooo00Oo0?lXo`3oIOoooooo
02Soo`1<oooooooo0:ko00Gooooo00Co08?oo`1Boooooooo0?mI0_ooool00ol0oc[oooooo`0@o`09
ooooo`?o0?mB00?oooooo`3od_l0[_l00_ooool01?l0C?oo0<coo`3<ool04?l4ooooo`;o0?mB00Go
ooooo`0^ooooooooooooo`3o>P02ooooo`;o0?n300Ko0?o`ooooooooooooooooobH0ool0c?l3oooo
o`03o`0doooooooooooo00Cooooo00?o0?m<o`1Booooool01?ooool00omG0?ooooooooooo`0=oooo
o`03o`3oC?oooooooooo01Gooooo00?o0?o`ooooooooool02Oooool00ol0=?ooooooooooo`0:oooo
o`03oaX0ool0Pooo08?o00;o0?oB4_ooool00omM0?ooooooooooo`09ooooo`03o`2^oooooooooooo
00?ooooo0_l0o`XGooooo`;o0?Ko2Oooool01?l02_oo0?mIo`3oFOl0oeT2o`3oM`Oooooo0ol0oc@G
ooooo`?o04co2?oooolToego00?o0>Co2?mMo`1eooooo`00Doooool00ol0003oooooooooo`21oooo
o`0Io`2Kool0ohoo0:7oo`3oOOoooooo05Woo`3om_l0oh?o0<coooooool0Jooo0?lRo`3oFOoooooo
013oo`23ool0ogOo0?ldo`0Xoooooooo0?mUooooool0o`[o0:koo`1<o`02ooooo`03o`3Hoooooooo
oooo00Wooooo00Ko0?l:oooooooooooo0=Soooooool0oiD4ooooo`07o`3oIOoooooo02Soo`1<oooo
oooo0:koo`3To`04ooooo`09o`23oooooooo05;oooooool0oeWoooooo`3o>_oooooo013o00Wooooo
00Go0?mBoooooooooooo0?n3o`3odP02ooooo`03o`2^ool0c?oo04co00;ooooo00?o0?ldo`0@oooo
ool00_ooool3o`3oc003o`0^ool0olco0?o<00Go0?o<00Ko0?o`o`3oPoooooooooooobH0ooooool3
o`3<o`03o`0doooooooooooo00Cooooo00?o0?m<o`1Booooool01?ooool00omG0?ooooooooooo`0<
ooooo`03o`3oC?oooooooooo01Gooooo00?o0?o`ooooooooool02Oooool00ol0=?ooooooooooo`0<
ooooo`04oaX0oooooooo08?oo`23o`Co0?oB3oooool00omM0?ooooooooooo`07ooooo`03o`2^oooo
oooooooo00Kooooo0_l0o`XDooooo`03o`3foooooooooooo00;o0?lX2?ooool2o`0:o`03o`3oMol0
oeWo0?mI00Cooooo0ol0oc@Gooooo`?o04co<_ooool4o`3TogWooooo001Cooooo`03o`000?oooooo
oooo08;ooooo01Co09_oo`3oa_l0XOoo0?mmo`3o^_l0FOoo0?ofo`3<oooooooo06_oo`3o8_l0oc[o
0?mIo`1Bool04?oo08?oooooool0ocCo02Soo`3oI@;ooooo00?o0?l:o`2^ool0C?l00_ooool00ol0
f?ooooooooooo`07ooooo`06o`3o2_ooooooooooo`3Hoooooooo0?nE1?ooool01?l0obSo0?mUoooo
ool0:?l2ooooo`03o`2^oooooooooooo00;ooooo00Wo0?ldo`23ool0D_ooooooo`3oFOoooooo0?lj
ooooool04?l02Oooool00ol0oe;oooooooooo`02o`3odP?ooooo00?o0:koooooool0C?l00_ooool0
0ol0olco013oo`3oc002o`3oc0;ooooo00?o0?mBo`0^ooooool00oooool02?l0oc[oooooooooool0
olco0?o`o`3oc?l0oh?o9P3o1?ooool00ol0c?oo03Coooooo`05ooooo`03o`3oC?l0D_oooooo00Co
oooo00?oE`3oooooooooool02_ooool00ol0odcoooooooooo`0Fooooo`03o`3ol?oooooooooo00Wo
oooo00?o03Coooooooooool03Oooool01?lJ0?ooooooooooool0Pol3ooooo`?o0?oB3Oooool00omM
0?ooooooooooo`05ooooo`03o`2^oooooooooooo00Wooooo0_l0o`X@ooooo`;o0?Ko1Oooool2o`3o
:0Gooooo0_l0ogL01?oooooo00[oooooooooool3o`3oF@03o`3o=?oooooooooo01Kooooo0_l0C?li
ooooo`?o0>CoM_ooool005?ooooo00?o0000ooooooooool0P_ooool05Ol0Vooo0?o6o`2Qool0oggo
0?njo`1Iool0ooKo0<coo`3od_oooooo06_oo`3o>_l0oeWoooooo`0@ool0Poooooooo`3o=?l0:?oo
ooooo`3oI@02ooooo`03o`3o2_l0[_oo04co00;ooooo00?o0=Soooooooooool01Oooool01?l0o`[o
ooooo`3Hool0f?l2o`3oU@Cooooo00Co0?lXo`3oIOoooooo02So0_ooool00ol0[_oo0>Coooooo`02
ooooo`05o`3o=?l0Pooo05;oooooool0oeT00_ooool00ol0oc[o013oooooo`08ooooo`04o`3oD_oo
oooo0?n3o`3odPCooooo00Wo0<coooooool0[_ooooooo`1<ool0olcoooooo`3o=?l04?l01Oooool0
0ol0oe;o02koooooo`02ooooo`06o`3o>_ooooooooooooooool0oo3ooooo0_l0ol`00olV0?oooooo
ooooo`02ooooo`03o`0dool0c?oooooo00Gooooo00?o05;oooooooooool00oooool00omG0?oooooo
ooooo`0:ooooo`03o`3oC?oooooooooo01Gooooo00?o0?o`ooooooooool02Oooool00ol0=?oooooo
ooooo`0?ooooo`04oaX0ooooooooooooo`23o`Gooooo0ol0om8;ooooo`03oed0oooooooooooo00?o
oooo00?o0:koooooooooool03?ooool2o`3o2Pgooooo00?o0?Koooooooooool01oooool3o`3o:0;o
0?mg1?ooool01Ol02_oo0?ldo`3o=?l0ocCooooo00?o0?mI5?ooool2o`1<ockooooo0ol0i?mcoooo
o`00Doooool00ol0003oooooooooo`22ooooo`0Eo`3o`?l0Vooo0?o6o`2Qoooooooo05Woo`3om_l0
oh?o0<coooooool0Jooo0?ljo`3oFOoooooo013oo`23ool0ogOo0?ldo`3Tool0:?oo0?mU00?ooooo
00?o0:koo`1<ooooool00_ooool2o`3Ho`?ooooo0_l0o`X2o`3Ho`03ooooool0oiGooooo00Gooooo
00?o0?mUooooool0:?l00_ooool00ol0[_oo0>Coooooo`02ooooo`09o`3o=?l0Poooooooo`1Boooo
oooo0?mIooooool0oc[o013o00Sooooo0_l0oe800ooooooo0?n3o`3odP04ooooo`06o`3<oooooooo
ooooo`2^ool0olco04co0_ooool00ol0ocCo013oooooo`05ooooo`03o`0^ool0oe;ooooo00;ooooo
00Co0?ljoooooooooooo0?o`0oooool00olV0?oo0?o<o`3oc002ooooo`03o`0doooooooo0<co00Ko
oooo00?o05;oooooooooool00_ooool00omG0?ooooooooooo`09ooooo`03o`3oC?oooooooooo01Ko
oooo00?o0?o`ooooooooool02Oooool00ol0=?ooooooooooo`0@ooooo`03oaX0oooooooooooo00;o
08?o1_ooool3o`3odPSooooo00?oG@3oooooooooool00_ooool00ol0[_ooooooooooo`0?ooooo`?o
0?l:2?ooool2o`3fo`_ooooo0_l0ogL3o`3o:004ooooool0ocCo0?ldo`3o=0;o00[o1Oooool2o`3o
F@oooooo0ol0C?m3ooooo`Co0>CoKoooool005?ooooo00?o0000ooooooooool0Poooool05Ol0Vooo
0?o6o`2Qool0oggo0?njo`1Iool0ooKo0<coooooool0Jooo0?lRo`3o>_l0oeWo05;oo`0@ool0Pooo
ooooo`3Tool0:?ooooooo`3oI@03ooooo`03o`2^ool0C?oooooo00;ooooo1_l0f?l2ooooo`03o`3o
UOoooooooooo00Cooooo00Oo0?mUooooool0C?oo02Soooooool0[_oo0>Co00?ooooo00Wo0?ldoooo
ool0Pooo05;oooooool0oeWoooooo`3o>_l04?l02?ooool01Ol0oe;oooooooooool0oh?o0?oB00Co
oooo00Oo0<coooooool0olco0?o<o`2^oooooooo04co00;ooooo00?o0?ldooooool04?l01Oooool0
0ol0;_ooooooo`3oDP02ooooo`04o`3o>_ooooooooooo`3ol0?ooooo00?o9P3oo`3oPoooool00_l0
ol`01?l0=?ooooooooooool0c?l5ooooo`03o`1Bool0odcooooo00;ooooo00?oE`3oooooooooool0
2?ooool00ol0odcoooooooooo`0Gooooo`03o`3ol?oooooooooo00Sooooo00?o03Coooooooooool0
4_ooool01OlJ0?oooooooooooooooooo08?o00Sooooo0ol0om86ooooo`04oed0ooooooooooooo`2^
oaGooooo0_l0o`X5ooooo`03o`3foooooooooooo00Wooooo0_l0ogL4ooooo`;o0?ld00?o0?lXoooo
ooooool00_ooool00ol02_ooooooooooo`04ooooo`?o0?mI2_ooool2o`1<od[ooooo0ol0i?m/oooo
o`00Doooool00ol0003oooooooooo`23ooooo`0Eo`2Kool0ohoo0:7oo`3oOOl0ok[o05Woo`3om_l0
c?oo0?oBo`1[ool0j_oo0?ljo`3oFOoooooo013oo`23oooooooo0?ldo`0Xoooooooo0?mU00?ooooo
00?o0:koo`1<ool0oiD00oooool2o`3o2PCooooo00?o0?nEooooooooool01?ooool02?l0obSo0?mU
o`1<ool0:?ooooooo`2^oooooooo0>Co0_ooool02Ol0ocCoooooo`23ool0D_ooooooo`3oFOoooooo
0?ljo`0@o`08ooooo`05o`3oD_ooooooooooo`3oPol0om801?ooool00ol0c?ooooooo`3oc003oooo
o`03o`2^oooooooo04co00;ooooo00?o0?ldo`0@ooooool01?ooool01?l0;_ooooooooooool0oe82
ooooo`03o`3o>_oooooo0?o`00?ooooo00?o9P3oooooool0oh<00_ooool01Ol0olco03Cooooooooo
oooo0<co00Gooooo00?o05;oo`3oC?ooool00_ooool00omG0?ooooooooooo`06ooooo`03o`3oC?oo
oooooooo01Oooooo00?o0?o`ooooooooool02Oooool00ol0=?ooooooooooo`0Booooo`03oaX0oooo
oooooooo00;ooooo0_l0Pol9ooooo`;o0?oB1Oooool00omM0?oo0:koooooo`0Gooooo`;o0?l:00?o
ooooo`3fool0m_l02_ooool2o`3oM`?ooooo0ol0oc@3ooooo`?o0?lX0_ooool00ol02_oooooooooo
o`06ooooo`;o0?mI1_ooool2o`1<odoooooo1?l0i?mXooooo`00Doooool00ol0003oooooooooo`24
ooooo`0Do`2Kool0olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;o06_oo`29ool0oc[o0?mIooooool0
D_oo013oo`3oMol0ocCo0>Coo`0Xool0ofD4ooooo`05o`2^ool0C?oo0?nEo`3oUOl0o`X01?ooool2
o`3oU@Oooooo0_l0C?l01Ooooooo02Soo`2^oooooooo0>Co00?ooooo00So0?ldo`23oooooooo05;o
ooooool0oeWoooooo`0@o`Sooooo00Go0?mBoooooooooooo0?n3o`3odP03ooooo`;o0<co0_l0ol`4
ooooo`03o`2^oooooooo04co00;ooooo00?o0?ldooooool04?l01?ooool01ol0;_oooooooooooooo
oooo0?mBooooool0ocX00_ooool01_l0oo3ooooooooooolV0?oo02Soo`3oP`?ooooo00Go03Coo`3o
c?ooooooooooo`3<o`04ooooo`03o`1Bool0odcooooo00;ooooo00?oE`3oooooooooool01Oooool0
0ol0odcoooooooooo`0Hooooo`03o`3ol?oooooooooo00Sooooo00?o03Coooooooooool05?ooool0
0olJ0?ooooooooooo`03ooooo`03o`23oooooooooooo00Sooooo0_l0om83ooooo`03o`2^oomM0?oo
oooo01Wooooo00?o0?Koo`3o2_l0o`X02Oooool00ol0ogOoooooooooo`03o`3o=0Wooooo0ol0obP2
o`0:o`Sooooo0ol0oeT00ooooooo04coo`1<o`1Eooooo`Co0>CoI?ooool002Sooooo00?ogMgMoeEE
EOl000000_l000000omEEEGogMgMooooo`05ooooo`03ogMgMol0003oMgMg00Oooooo00?ok^k^ogMg
MolQ8B400_l000000olQ8B7oV9RHooooo`0<ooooo`03o`000?oooooooooo08Cooooo01Go09_oo`3o
a_l0XOoo0?mmo`3o^_l0FOoo0?ofo`3<oooooooo06_oo`3o8_l0oc[o0?mIooooool04?oo08?ooooo
ool0i?oo02Soooooool0ofD01?ooool00ol0[_oo04coooooo`05o`3oU@Sooooo00Co04cooooooooo
oooo02So0oooool02ol0i?ooooooooooool0ocCoooooo`23ool0D_ooooooo`3oFOoooooo013o00So
oooo00Ko0?mBooooooooooooooooo`3oPol0om82o`3o8P03o`3<ool0ob;o0?o<00;o0?lR1?ooool0
0ol0[_ooooooo`1<o`02ooooo`03o`3o=?oooooo013o00Gooooo00Co02kooooooooooooo0?mB0_oo
ool00ol0oc[oooooo`3ol003ooooo`03obH0oooooooo0?n300;ooooo00?o03Coooooool0ol`00_oo
ool00ol0c?ooooooooooo`02ooooo`05o`1Bool0odco0?m<oooooomG0?l01_ooool00ol0odcooooo
ooooo`0Hooooo`03o`3ol?oooooooooo00Wooooo00?o03Coooooooooool05Oooool00olJ0?oooooo
ooooo`03ooooo`03o`23oooooooooooo00Wooooo00?o0?oBooooool0[_l00_ooool00omM0?oooooo
ooooo`0Fooooo`04o`3fooooooooooooooooo`;o0?l:1Oooool2o`3oM`03ooooool0ocCo0?ld00oo
oooo0_l0obP00ol02_ooooooooooo`07ooooo`;o04co0_l0oeUIooooo`Co0>CoH?ooool002Oooooo
00Woc<c<o`000?l0003o^[ZjoooooooMgMgo8B4Qo`000?o<c<`01Oooool3o`0000Kooooo00[oc<c<
oa0@4?l0003oV9RHooooooo^k^koMgMgo`000?lQ8B7ok^k^2oooool00ol0003oooooooooo`24oooo
o`0Eo`2Kool0ohoo0:7oo`3oOOl0ok[o05Woo`3om_l0c?oo0?oBo`1[ool0ob;o0?ljo`3oFOoooooo
013oo`23oooooooo0?ldo`3Tool0:?oo0?mU00Gooooo00?o0:koo`1<ooooool02_ooool2o`1<o`04
ooooool0[_oo0:koo`0Xo`;ooooo00_o0>Cooooooooooooo0?ldooooool0Poooooooo`1Bool0oeWo
ooooo`0@o`08ooooo`0;o`3oD_ooooooooooooooool0oh?o0?oBo`3o8_oooooo0<coooooool0ol`0
0_ooool3o`3o8P;ooooo00Co0:kooooooooooooo04co0_ooool00ol0ocCoooooo`0@o`04ooooo`09
o`0^ooooooooooooooooool0oe;oooooo`3o>_oooooo0?o`00?ooooo00Ko9P3ooooooooooooo0?n3
ooooool0=?l2ooooo`04o`3oc?ooooooooooo`3<o`?ooooo00Go05;ooooooooooooo0?m<oeL0o`04
ooooo`;o0?m<6oooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooooooo01Oooooo00?o6P3o
ooooooooool00oooool2o`23o`[ooooo00Go0:koo`3od_oooooooooooed0o`0Fooooo`;o0?Ko1_oo
ool3o`3o2P;o0?mg00?oooooo`3o=?l0oc@04oooool00ol0obSo00[oo`3o:005ooooo`;o04co1?oo
ool2o`3oFE_ooooo1?l0i?mLooooo`009_ooool01?oMgMgo0000o`000?nj^[X3ooooo`04onk^k_l0
003o0000onk^kPCooooo00?oMgMgo`000?mgMgL01Oooool01?oMgMgo0000o`000?nj^[X4ooooo`03
odA4A?l0003oA4A400_ooooo00?o0000ooooooooool0QOooool05Ol0Vooo0?o6o`2Qool0oggo05Wo
o`3om_l0c?oo0?oBo`1[ool0j_oo0?ljo`3oFOoooooo05;oo`0@ool0ogOo0?ldo`3Tool0obSo02So
o`3oI@04ooooo`03o`2^oooooooo04co00Sooooo0_l0C?l01Ol0ofGo0?lXo`2^oooooooo02So00;o
oooo00co0>Cooooooooooooo0?ldooooool0Poooooooo`1Bool0oeWoooooo`3o>_l04?l7ooooo`06
o`3oD_ooooooooooo`3o8_l0oh?o0?oB0_ooool00ol0c?ooooooo`3oc006ooooo`03o`3o8_oooooo
0:ko00;ooooo00Ko04cooooooooooooo0?ldooooool04?l4ooooo`05o`0^ooooooooooooooooool0
oe800_ooool00ol0oc[o0?o`ooooo`02ooooo`07obH0ooooooooooooooooool0oh?oooooo`0do`02
ooooo`04o`3oc?ooooooooooo`3<o`?ooooo00Go05;ooooooooooooo0?m<oeL0o`03o`3oC1gooooo
00?o0?o`ooooooooool02?ooool00ol0=?ooooooooooo`0Hooooo`03oaX0oooooooooooo00Cooooo
00?o08?oooooooooool01_ooool00ol0[_ooooooooooo`02o`3odP03oooooomM0?oooooo01?ooooo
00?o0?Koooooooooool02?ooool01?l0ogOo0?l:o`3o=?l0oc@Gooooo`;o00[o0_l0obP2o`1<o`So
oooo0ol0oeULooooo`Co0>CoF?ooool002Kooooo00?oEEEEo`000?lQ8B401Oooool00omEEEGo0000
oeEEE@0<ooooo`03oc8b<_l0003o8B4Q00Gooooo00CoZJVYo`000?l0003oZJVY2_ooool00ol0003o
ooooooooo`25ooooo`0Fo`2Kool0olKo0:7oo`3oOOl0ok[o05Woo`3om_l0c?oo06_oo`29ool0ob;o
0?ljo`3oFOoooooo013oo`23oooooooo0?ldo`3Tool0:?ooooooo`3oI@Cooooo00?o0:koooooool0
C?l00_l0C?l3ooooo`;o04co00Koooooo`3oIOl0obSo0:koooooool0:?l2ooooo`04o`3Toooooooo
ooooo`3o=0;ooooo00Ko08?oo`1Boooooooo0?mIooooool04?l7ooooo`06o`3oD_ooooooooooo`3o
Mol0oh?o0?oB0_l0ogL00ol0c?oo0?mgo`3oc008ooooo`05o`3o8_oooooo0:koooooool0C?l00ooo
ool00ol0ocCoooooo`0@o`03ooooo`03o`0^oooooooooooo00;ooooo00Go0?mBooooool0oc[ooooo
o`3ol002ooooo`03obH0ool0:?oooooo00;ooooo00?o0?n3o`0dooooool00_ooool2o`3oc005oooo
ool0c?ooooooooooool0D_l00oooool00omG0?ooooooooooo`0Mooooo`03o`3ol?oooooooooo00Wo
oooo00?o03Coooooooooool06Oooool00olJ0?ooooooooooo`04ooooo`03o`23oooooooooooo00Go
oooo00?o0:koooooooooool00_ooool2o`3odP03oed0oooooooooooo013ooooo00?o0?Kooooooooo
ool01oooool2o`3oM`;o0?ld0_ooool2o`3o2QOooooo0_l02_l2o`3o:0_ooooo0_l0oeUNooooo`Co
0>CoE?ooool002Gooooo00CogMgMo`000?l0003oMgMg1Oooool01?n7QhOo0000o`000?o^k^h:oooo
o`04okZj^_l0003o0000ohN7Q`Gooooo00Cok^k^o`000?l0003oA4A42_ooool00ol0003ooooooooo
o`25ooooo`0Fo`2Kool0ohoo0?o6o`2Qool0ok[o05Woo`3om_l0c?oo0?oBo`1[ool0ob;o0?ljo`3o
FOoooooo013oo`23oooooooo0?ldo`3Tool0obSo02Soo`3oI@Gooooo0_l0[_l2ooooo`?o04co00?o
ooooo`3oIOl0ofD00_l0[_l00ooooooo02Soooooo`02ooooo`0;o`3Tooooooooooooo`3o=?oooooo
08?oooooool0D_oo0?mIooooool04?l01oooool01_l0oe;o0?mgo`3oMol0ogOo0?n3o`3odP;ooooo
00Co0<coooooool0ogOo0?o<2?ooool00ol0ob;oooooo`2^o`02ooooo`06o`1<ooooooooooooo`3o
=?oooooo013o1?ooool02Ol0;_oooooooooooooooooo0?mBooooool0oc[oooooo`3ol003ooooo`03
obH0oooooooooooo00;ooooo00?o03Coooooooooool00oooool00ol0olcoooooo`3<o`02ooooo`04
o`1BoooooooooooooeL0oaoooooo00?o0?o`ooooooooool02?ooool00ol0=?ooooooooooo`0Koooo
o`03oaX0oooooooooooo00Cooooo0_l0Pol4ooooo`03o`2^oooooooooooo00Gooooo00?o0?oBoed0
oomM0?l03_ooool2o`3fo`Sooooo0_l0ogL2o`3o=0Kooooo0ol0o`XBooooo`;o04co0_ooool2o`0:
o`?o0?lX2_ooool3o`3oFEoooooo1?l0i?m@ooooo`009Oooool01?n7QhOo0000o`000?nj^[X5oooo
o`04okZj^_l0003o0000oiRHV0[ooooo00CoEEEEo`000?l0003o^[Zj1_ooool3o`0000[ooooo00?o
0000ooooooooool0Q_ooool05Ol0Vooo0?o6o`2Qool0oggo05Woo`3om_l0c?oo0?oBo`1[ool0ob;o
0?ljooooool0oeWo05;oo`0@ool0ogOoooooo`3Tool0obSo02Soooooo`02o`3oI@Cooooo1?l0[_l0
0ooooooo0:koo`2^o`02o`2^o`;ooooo00Go02Soooooooooooooooooo`3To`02ooooo`08o`3o=?oo
oooo08?oooooool0D_oo0?mIooooool04?l7ooooo`;o0?mg00Go0?lRooooool0oh?oooooo`3odP02
ooooo`04o`3<oooooooo0?o<ooooo`;o0?mg1Oooool3o`3omP04o`2^ool0ooKoooooo`1<o`;ooooo
00?o0?ldooooool04?l01?ooool00ol0;_ooooooooooo`02ooooo`04o`3oD_oooooo0?ljo`3ol0?o
oooo00?o9P3oooooooooool00_ooool00ol0=?ooooooooooo`04ooooo`05o`3oc?oooooo0<cooooo
ool0D_l00_ooool00omG0?ooooooooooo`0Looooo`03o`3ol?oooooooooo00Wooooo00?o03Cooooo
ooooool06oooool00olJ0?ooooooooooo`06ooooo`04o`23ooooooooooooo`2^o`[ooooo00?o0?oB
oed0ooooool02oooool00ol0m_ooooooooooo`06ooooo`;o0?mg0_l0oc@;ooooo`?o0?l:3_ooool0
0ol0C?ooooooooooo`04ooooo`03o`0:oooooooooooo00?o0?lX2_ooool2o`3oFF7ooooo1?l0i?m<
ooooo`009Oooool01?m4A4Co0000o`000?o<c<`5ooooo`04omgMgOl0003o0000oeEEE@[ooooo00?o
8B4Qo`000?l000001oooool3o`0000[ooooo00?o0000ooooooooool0Q_ooool04?l0Vooo0?n?o`2Q
ool0oggo0?njo`1Iool0c?oo0?oBo`1[ool0ROoo0?lRo`3o>_l0oeWoooooo`0@ool0Pol2ooooo`03
o`3Tool0obSo02So00;ooooo00?o0?mUooooooooool01Oooool2o`2^o`05ooooool0obSooooooooo
ool0:?l00oooool01?l0i?ooooooooooool0oc@2ooooo`06o`23ool0D_ooooooo`3oFOl0oc[o013o
1_ooool00ol0ogOo0?mBo`3o8P02ooooo`07o`3oPol0om;oooooooooool0c?ooooooo`3oc004oooo
o`Go0?of0oooool01?l0[_ooooooo`3om_l0C?l3ooooo`03o`3o=?oooooo013o00?ooooo00?o02ko
ooooooooool00_ooool01?l0oe;oooooo`3o>_l0oo03ooooo`03obH0ool0:?oooooo00?ooooo00?o
03Coooooooooool01?ooool01Ol0olcoooooo`3<oooooooo05;o00;ooooo00?oE`3oooooooooool0
6oooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooooooo01gooooo00?o6P3oooooooooool0
1_ooool2o`23o`gooooo00?oG@3oo`3od_ooool02?ooool00ol0m_ooooooooooo`06ooooo`03o`3o
Mol0ocCooooo013ooooo1?l0o`X8ooooo`;o04co2?ooool2o`0:o`?ooooo0ol0obP9ooooo`?o0?mI
H_ooool3o`3TodWooooo000Uooooo`03ob4Q8Ol0003o000000Oooooo0_l000000olb<S;ooooooooo
o`08ooooo`?o00001_ooool01?nj^[[o0000o`000?l0000:ooooo`Co0000QOooool04?l0Vooo0?o0
o`3oa_l0XOoo0?njo`1Iool0ooKo0<coooooool0Jooo0?lRo`3o>_l0oeWoooooo`0@ool0Pol2oooo
o`05o`3Toooooooo0?lXo`0Xooooool00_l0ofD6ooooo`04o`3oIOoooooo0?lXooooo`;o02So0ooo
ool01?l0i?ooooooooooool0oc@2ooooo`06o`23ool0D_ooooooo`3oFOoooooo013o1Oooool2o`3o
M`06o`3oD_l0ob;oooooooooool0oh?o0?oB0_ooool00ol0c?ooooooo`3oc004ooooo`03o`3om_l0
ogOooooo00Oooooo00?o0:koooooool0C?l00_l0ooH01?oooooo0?ldooooool04?l3ooooo`03o`0^
oooooooooooo00?ooooo00?o0?mBooooool0oo000oooool00olV0?oo02Soooooo`03ooooo`03o`0d
ool0oh?ooooo00Gooooo00Oo0?o<ooooool0c?ooooooo`1BooooooooE`3o01gooooo00?o0?o`oooo
ooooool02?ooool00ol0=?ooooooooooo`0Nooooo`03oaX0oooooooooooo00Kooooo00?o0:koo`23
ooooool03?ooool00omM0?oo0?oBooooo`06ooooo`03o`3foooooooooooo00Gooooo0_l0ogLGoooo
o`Co0?l:0_ooool2o`1<o`cooooo0_l02_l4ooooo`?o0?lX2Oooool3o`3oFF;ooooo1?l0i?m5oooo
o`009Oooool3o`0000Oooooo0ol0000:ooooo`?o00001_ooool01?mgMgOo0000o`000?m4A4@:oooo
o`03o`000?oooooooooo08Oooooo013o09_oo`3oa_l0XOoo0?mmo`1Iool0ooKo0<coo`3od_l0Jooo
0?lRo`3o>_oooooo0?mIo`0@ool0Pooo0?mg0_ooool01?l0i?ooooooo`3o:?l0:?l2ooooo`Ko0?mU
0_l0obP00ooooooo02Soooooo`04ooooo`03o`3Toooooooo0?ld00;ooooo00Ko08?oooooool0D_oo
0?mIooooool04?l5ooooo`08o`3oMooooooo0?mBooooool0ob;oooooo`3oPol0om82ooooo`03o`3<
oooooooo0?o<00?ooooo0_l0ooH2ooooo`03o`3oMooooooooooo00Gooooo00Go0:kooooooooooooo
04coooooo`02o`3omP;ooooo00Go013oooooooooooooooooo`0^o`05ooooo`03o`3oD_l0oc[o0?o`
00?ooooo00?o9P3oooooooooool00_ooool00ol0=?ooooooo`3oP`06ooooo`;o0?o<00Co0<coo`1B
ooooooooE`3o7?ooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooooooo023ooooo00?o6P3o
ooooooooool01?ooool01?l0[_ooooooooooool0Pol=ooooo`03oed0ool0om;o0?oB00Gooooo00?o
0?Koooooooooool00oooool2o`3oMagooooo00?o0?l:o`1<ool0o`X03oooool2o`0:o`Gooooo0ol0
obP9ooooo`?o0?mIHoooool4o`3Tod7ooooo000Uooooo`?o00001oooool3o`0000[ooooo0ol00000
0onYZJWoooooooooo`02ooooo`05onk^k_l0003o0000o`000?o<c<`02_ooool00ol0003ooooooooo
o`27ooooo`0@o`2Kool0ohoo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;o06_oo`29ool0ob;o0?ljo`3o
FOoooooo013oo`23o`;ooooo00Co0?ldo`3Toooooooo02So1oooool01?l0obSoooooooooool0:?l5
ooooo`0<o`3Tooooooooooooo`3o=?oooooo08?oooooool0D_ooooooo`3oFOl0oc[o013o1?ooool0
3Ol0ogOoooooo`3oD_oooooo0?lRooooool0oh?oooooo`3od_oooooo0<coooooool0ol`00oooool0
0ol0ooKoooooooooo`03ooooo`03o`3oMooooooooooo00Cooooo00Co0:koo`3o8_oooooo04co0ooo
ool00ol0ooKoooooo`0@o`03ooooo`03o`0^oooooooooooo00?ooooo00?o0?mBooooool0oo000ooo
ool00olV0?ooooooooooo`02ooooo`03o`0doooooooo0?n300Sooooo00Co0?o<o`3<ool0D_ooE`3o
7?ooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooooooo027ooooo00?o6P3oooooooooool0
0_ooool00ol0[_ooooooooooo`02ooooo`;o08?o3?ooool2oed0o`;o0?oB0_ooool00ol0m_oooooo
ooooo`02ooooo`03o`3o=?l0ogOooooo01gooooo0_l0C?l2ooooo`Co0?l:3Oooool2o`0:o`Kooooo
0ol0obP9ooooo`?o0?mII?ooool3o`3Tockooooo000Uooooo`?o00001oooool3o`0000[ooooo00Go
8B4Qo`000?l0003o0000ojVYZ@02ooooo`05okZj^_lQ8B7o0000o`000?nHV9P02oooool00ol0003o
ooooooooo`27ooooo`0@o`2Kool0ol3o0?o6o`2Qool0ok[o05Woo`3om_l0c?ooooooo`1[ool0ob;o
0?ljo`3oFOoooooo013oo`23o`?ooooo00?o0?ldo`3Tooooool00_l0:?l3ooooo`;o0?lX00?ooooo
o`0Xool0:?l01Oooool01?l0i?ooooooooooool0oc@2ooooo`06o`23ool0D_ooooooo`3oFOoooooo
013o1?ooool03Ol0ogOoooooooooool0oe;o0?lRooooool0oh?oooooo`3od_oooooo0<coooooool0
ol`00_ooool2o`3omPOooooo00?o0?mgooooooooool00oooool01?l0[_ooooooo`3o8_l0C?l3oooo
o`03o`3o=?l0ooKo013o00?ooooo00?o02koooooooooool01?ooool00ol0oe;o0?o`ooooo`02oooo
o`03obH0ool0:?oooooo00?ooooo00?o03Coooooool0oh<02?ooool01?l0olco05;ooooooomG0?lJ
ooooo`03o`3ol?oooooooooo00Sooooo00?o03Coooooooooool08oooool01?lJ0?ooooooooooool0
[_l7ooooo`03o`23oooooooooooo00_ooooo00CoG@3oooooool0om;o0?Ko0oooool00ol0ocCo0?mg
o`3oM`0Mooooo`;o04co2?ooool4o`3o2P_ooooo0_l02_l7ooooo`?o0?lX2Oooool3o`3oFFCooooo
0ol0i?lkooooo`009Oooool3o`0000Oooooo0ol0000:ooooo`06ofIVI_l0003o0000oiRHV?mEEEGo
8B4Q0_l000000ol@413oEEEEomgMg@0<ooooo`03o`000?oooooooooo08Oooooo017o09_oo`3o`?l0
olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;o06_oo`3o8_l0oc[oooooo`3oFOl04?ooooooo`23o`02
ooooo`05o`3o=?l0i?ooooooooooool0obP01_l0:?l5ooooo`;o0>Co0_ooool02Ol0ocCooooooooo
ool0Pooo05;oooooool0oeWoooooo`0@o`04ooooo`09o`3oMoooooooooooo`3oD_l0ob;oooooo`3o
Pooooooo0?oB00;ooooo00Go0<coo`3oc?ooooooooooo`3omP09ooooo`03o`3oMooooooooooo00Co
oooo00?o0:koo`3o8_l0C?l00oooool01?l0ocCoooooo`3om_l04?l2ooooo`03o`0^oooooooooooo
00Cooooo00?o0?mBo`3ol?l0ocX00_ooool00olV0?oo02Soooooo`03ooooo`04o`0doooooooooooo
o`3oP`Sooooo00?o0?o<o`1BoomG0?l06_ooool00ol0oo3oooooooooo`08ooooo`03o`0doooooooo
oooo02?ooooo00Co6P3ooooooooooooo0:ko2?ooool00ol0Poooooooooooo`0;ooooo`03oed0ool0
m_oooooo00;o0?oB0_l0ogLNooooo`03o`1<oooooooooooo00cooooo1?l0o`X9ooooo`03o`0:oooo
oooooooo00Oooooo0ol0obP9ooooo`?o0?mIWoooool002Gooooo00Co8B4Qo`000?l0003ok^k^1_oo
ool2o`000003ob4Q8Ooooooooooo00Sooooo00Co^[Zjo`000?l0003oMgMg4oooool00ol0003ooooo
ooooo`28ooooo`0@o`2Kool0ohoo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;oooooo`1[ool0ob;o0?lj
o`3oFOoooooo013oo`23o`;ooooo00Co0?ldooooool0i?oo0>Co2oooool01Ol0i?oooooooooooooo
oooo0?ld00;ooooo00Ko08?oooooool0D_ooooooo`3oFOl04?l4ooooo`09o`3oMoooooooooooo`3o
D_l0ob;oooooo`3oPooooooo0?oB00;ooooo00Go0<coo`3oc?ooooooooooo`3omP0;ooooo`03o`3o
Mooooooooooo00?ooooo00Co0:koooooool0ob;o04co0oooool00ol0ocCoooooo`0@o`02ooooo`03
o`0^oooooooooooo00Gooooo00?o0?mBo`3ol?ooool00_ooool00olV0?ooooooooooo`02ooooo`05
o`0dooooooooooooooooool0oh<02?ooool00ol0D_ooE`3oooooo`0Iooooo`03o`3ol?oooooooooo
00Oooooo00?o03Coooooooooool09Oooool00olJ0?oo0:koooooo`09ooooo`03o`23oooooooooooo
00[ooooo00Go0?Kooed0ool0ocCo0?ldo`3oM`02o`3odQcooooo0_l0C?lCooooo`Go0?l:1Oooool2
o`0:o`[ooooo0ol0obP9ooooo`?o0?mIW?ooool002Gooooo00CoA4A4o`000?l0003o^[Zj1Oooool0
1?nj^[[o0000o`000?mEEED;ooooo`04oc8b<_l0003o410@onk^kQ;ooooo00?o0000ooooooooool0
R?ooool04Ol0Vooo0?o0o`3oa_l0XOoo0?njo`1Iool0ooKo0<coooooool0Jooo0?lRo`3o>_oooooo
0?mIo`0@oooooooo08?o00;ooooo00Co0?ldoooooooooooo0>Co2Oooool00ol0i?ooooooooooo`02
o`3o=0?ooooo00Ko08?oo`1Boooooooo0?mIo`3o>_l04?l3ooooo`05o`3oMoooooooooooo`3oD_l0
ob800_ooool01_l0oh?o0?oBoooooooooooo0<coo`3oc0;ooooo00?o0?ofooooooooool02_ooool0
0ol0ogOoooooooooo`03ooooo`04o`2^oooooooo0?lRo`1<o`?ooooo00?o0?ldooooool04?l00ooo
ool00ol0;_ooooooooooo`05ooooo`06o`3ol?oooooooooooooooolV0?oo02So0oooool01Ol0=?oo
oooooooooooooooo0?n300Wooooo00?o05;ooeL0ooooool05oooool00ol0oo3oooooooooo`08oooo
o`03o`0doooooooooooo02Gooooo00?o0:kooaX0ooooool02_ooool00ol0Poooooooooooo`08oooo
o`05o`3fool0ocCo0?ldoed0ool0ogL00oooool2o`3odQSooooo0_l0C?lJooooo`Go0?l:0_ooool2
o`0:o`_ooooo1?l0obP8ooooo`?o0?mIVOooool002Gooooo00CoQhN7o`000?l0003oZJVY1Oooool0
1?nj^[[o0000o`000?nHV9P;ooooo`04olc<c?l0003o0000ogMgMa;ooooo00?o0000ooooooooool0
R?ooool04Ol0Vooo0?o0o`3oa_l0XOoo0?njo`1Iool0ooKo0<coo`3od_l0Jooo0?lRo`3o>_oooooo
0?mIo`3fool04?oo08?o00?ooooo00Co0?ldoooooooooooo0>Co1oooool01?l0i?ooooooooooool0
oc@4ooooo`06o`23ool0D_ooooooo`3oFOoooooo013o0_ooool2o`3oM`;ooooo00[o0?mBooooool0
ob;oooooo`3oPooooooo0?oBooooool0c?oo0?o<0_ooool00ol0ooKoooooooooo`0;ooooo`03o`3o
Mooooooooooo00?ooooo00Co0:kooooooooooooo04co0oooool01?l0ocCoooooooooool04?l2oooo
o`03o`0^oooooooooooo00Gooooo00Ko0?o`o`3o>_ooooooooooobH0ool0:?l3ooooo`03o`0doooo
oooooooo00;ooooo00?o0?n3ooooooooool01_ooool00ol0D_ooE`3oo`3<o`0Gooooo`03o`3ol?oo
oooooooo00Oooooo00?o03Coooooooooool09_ooool00ol0[_oooooooaX0o`0;ooooo`03o`23oooo
oooooooo00Kooooo00Go0?Koo`3o=?ooooooooooo`3oM`02oed0o`Cooooo0_l0om8Eooooo`03o`1<
oooooooooooo01oooooo1?l0o`X2o`0:o`gooooo0ol0obP8ooooo`?o0?mIU_ooool002Gooooo00Co
gMgMo`000?l0003oIVIV1Oooool01?mgMgOo0000o`000?o^k^h<ooooo`04oiRHV?l0003o0000olc<
c17ooooo00?o0000ooooooooool0ROooool04Ol0Vooo0?n?o`2Qool0oggo05Woo`3om_l0c?oo0?oB
ooooool0Jooo0?lRo`3o>_oooooo0?mIo`0@oooooooo08?o00?ooooo00?o0?ldooooooooool01ol0
i?l2ooooo`03o`3o=?oooooooooo00;ooooo00Ko08?oo`1Booooooooooooo`3oFOl04?l2ooooo`03
o`3oMooooooooooo00;ooooo00Wo0?mBo`3o8_oooooo0?n3ooooool0om;oooooo`3<ool0ol`00_oo
ool00ol0ooKoooooooooo`0=ooooo`03o`3oMooooooooooo00?ooooo00?o0:koooooool0C?l01?oo
ool01_l0ocCoooooo`0@ool0ooKoooooo`0^o`Oooooo00Ko0?o`o`3oD_ooooooooooobH0ool0:?l4
ooooo`03o`0doooooooooooo00;ooooo00?o0?n3ooooooooool01_ooool00omG0?ooooooo`3<o`0E
ooooo`03o`3ol?oooooooooo00Sooooo00?o03Coooooooooool09Oooool01Ol0[_oooooooooooooo
oooo6P3o00_ooooo00?o08?oooooooooool00oooool01?l0ocCo0?Koooooooooool2o`3oM`?ooooo
00?oG@3oooooooooool00oooool2o`3odQ7ooooo0_l0C?lWooooo`03o`3o2_l02_oo00[o00;o0?l:
3?ooool3o`3o:0Sooooo0ol0oeVCooooo`009_ooool00omEEEGo0000ob4Q8@05ooooo`03ob4Q8Ol0
003oEEEE00kooooo00CoV9RHo`000?l0003oc<c<4?ooool00ol0003oooooooooo`29ooooo`0Ao`2K
ool0ol3o0?o6o`2Qool0ok[o05Woo`3<ool0om;oooooo`1[ool0ob;o0?ljooooool0oeWo0?Koo`0@
ool0Pol01?ooool00ol0ocCoooooooooo`06ooooo`;o0?ld1?ooool01?l0Pooo05;oooooooooool2
o`0@o`;ooooo00?o0?mgooooooooool00_ooool03?l0oe;o0?lRooooool0oh?oooooo`3od_oooooo
0<coooooool0olcoooooo`3omQ3ooooo00?o0?mgooooooooool00oooool01?l0[_ooooooooooool0
C?l3ooooo`06o`3o=?oooooo013oooooool0ooKo02ko1oooool00ol0oo3o0?mBo`3o>P02ooooo`03
obH0oooooooooooo00;ooooo00?o03Coooooooooool00_ooool00ol0oh?oooooooooo`06ooooo`04
o`1BoomG0?ooooooo`3<oaCooooo00?o0?o`ooooooooool01oooool00ol0=?ooooooooooo`0Uoooo
o`03o`2^oooooooooooo00?ooooo00?o6P3oooooooooool02Oooool2o`23o`04ooooool0ocCo0?ld
o`3fo`;ooooo00?o0?mgooooooooool01?ooool2oed0o`Gooooo00?o0?oBooooooooool03?ooool2
o`1<obcooooo0ol02_l5o`3o2PWooooo1?l0obP7ooooo`?o0?mIT?ooool002Kooooo00CogMgMo`00
0?l0003o^[Zj0oooool01?nj^[[o0000o`000?o^k^h?ooooo`04oiRHV?l0003o0000okZj^Poooooo
00?o0000ooooooooool0ROooool04_l0Vooo0?o0o`3oa_l0XOoo0?njo`1Iool0ooKo0<coo`3od_l0
ROoo06_oooooool0oc[o0?mIo`3fool04?ooooooo`23o`Cooooo0ol0oc@3ooooo`;o0?ld1Oooool0
1_l0Pooo05;ooooooooooooo013oo`3o>P;ooooo00?o0?mgooooooooool00_ooool01_l0oe;o0?lR
ooooool0oh?oooooo`3odP;ooooo00Co0<coo`3oc?oooooo0?of4_ooool00ol0ogOoooooooooo`02
ooooo`04o`2^ooooooooooooo`1<o`?ooooo00Oo0?ldooooool04?ooooooo`3om_oooooo02ko00Oo
oooo00Ko0?o`o`3oD_ooooooooooobH0ool0:?l3ooooo`03o`0doooooooooooo00?ooooo00?o0?n3
ooooooooool01_ooool01?mG0?ooooooooooool0c?lCooooo`03o`3ol?oooooooooo00Oooooo00?o
03Coooooooooool09?ooool00ol0[_ooooooooooo`05ooooo`03oaX0oooooooooooo00[ooooo00?o
08?oooooool0m_l00_ooool00ol0ogOoooooooooo`07ooooo`03oed0oooooooooooo00?ooooo0_l0
om8;ooooo`03o`1<oooooooooooo02oooooo0_l02_l3ooooo`So0?l:1Oooool3o`3o:0Oooooo0ol0
oeU<ooooo`KoG@3o>oooool002Oooooo00Ko^[Zjo`000?l0003o^[Zjoooooonj^[X2o`000003olc<
c?oooooooooo00oooooo00Gok^k^oeEEEOl0003oEEEEokZj^P0=ooooo`03o`000?oooooooooo08Wo
oooo01;o09_oo`3o`?l0olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;oooooo`1[ool0ob;o0?ljoooo
ool0oeWo0?Koo`0@ool0Pol6ooooo`Co0?ld1_ooool02Ol0Pooo05;ooooooooooooo013oooooool0
oc[oooooo`3oM`04ooooo`0:o`3oD_l0ob;oooooooooool0oh?oooooo`3od_oooooo0<coo`3oc0;o
oooo00?o0?ofooooooooool04?ooool00ol0ogOoooooooooo`02ooooo`05o`2^ooooooooooooo`1<
ool0ob800_ooool01ol0ocCoooooooooool04?ooooooo`3om_l0;_l01oooool01_l0oo3o0?mBo`3o
>_oooooo9P3oo`0Xo`?ooooo00?o03Coooooooooool01?ooool00ol0oh?oooooooooo`05ooooo`06
oeL0ooooooooooooooooool0c?oo0?o<4?ooool00ol0oo3oooooooooo`07ooooo`03o`0doooooooo
oooo02Gooooo00?o0:koooooooooool01Oooool00olJ0?ooooooooooo`08ooooo`;o0?ld00Gooooo
o`23ooooooooooooo`3oM`0;ooooo`;oG@3o1Oooool2o`3odPOooooo0_l0C?ldooooo`;o00[o2Ooo
ool7o`3o2P03ooooool0obSo0?lX00;o0?lX1_ooool3o`3oFD7ooooo2?mM0?m1ooooo`00:?ooool0
0ooMgMgoEEEEo`000002o`000003oeEEEOoMgMgooooo01?ooooo00KogMgMohN7Qom4A4Co8B4QodA4
A?oMgMd:ooooo`03o`000?oooooooooo08[ooooo017o09_oo`3o`?l0olKo0:7oo`1Iool0ooKo0<co
o`3od_l0oe;o06_oo`3o8_oooooo0?ljo`3oFOl0m_oo013oooooo`02o`23o`gooooo00Wo08?oo`1B
ooooooooooooo`0@oooooooo0?ljooooool0ogL01?ooool02_l0oe;o0?lRoooooooooooo0?n3oooo
ool0om;oooooo`3<ool0ol`2ooooo`03o`3om_l0m_oo0?Ko00Co0?Ko3_ooool00ol0ogOooooooooo
o`02ooooo`04o`2^oooooooo04coo`3o8P?ooooo00Ko0?ldooooool04?ooooooo`3om_l0;_l7oooo
o`06o`3ol?oooooo0?mBoooooolV0?oo02So1?ooool00ol0=?ooooooooooo`04ooooo`03o`3oPooo
oooooooo00Gooooo00KoE`3oooooooooooooooooo`3<ool0ol`?ooooo`03o`3ol?oooooooooo00Oo
oooo00?o03Coooooooooool09?ooool00ol0[_ooooooooooo`07ooooo`03oaX0oooooooooooo00Go
oooo0_l0oc@2ooooo`04o`3foooooooo08?oo`3oM`kooooo0_mM0?l5ooooo`;o0?oB1?ooool00ol0
C?ooooooooooo`0fooooo`?o00[o3Oooool5o`3o2PCo0?lX1Oooool3o`3oFCKooooo2?mM0?m9oooo
o`00Doooool00ol0003oooooooooo`2:ooooo`0Do`2Kool0ol3o0?o6o`2Qool0ok[o05Woo`3om_l0
c?oo0?oBo`29ool0Joooooooo`3o>_oooooo0?Koooooool04?oo0?mgooooool0Pol;ooooo`09o`23
ool0D_ooooooooooool04?ooooooo`3o>_oooooo0?mg00Gooooo00[o0?mBoooooooooooo0?n3oooo
ool0om;oooooo`3<ool0olcooooo1?l0m_l5ooooo`;o0?Ko3?ooool00ol0ogOoooooooooo`02oooo
o`05o`2^oooooooo04coooooool0ob800_ooool00ol0ocCoooooo`0@o`02ooooo`03o`0^oooooooo
oooo00Gooooo00?o0?o`ooooool0oe800_ooool00olV0?oo02Soooooo`02ooooo`03o`0doooooooo
oooo00Cooooo00?o0?n3ooooooooool01Oooool00omG0?oo05;oooooo`02ooooo`03o`3<ool0olco
oooo00cooooo00?o0?o`ooooooooool01oooool00ol0=?ooooooooooo`0Tooooo`03o`2^oooooooo
oooo00Wooooo00?o6P3oooooooooool00_ooool2o`3o=0Cooooo00Co0?Koo`3oMooooooo08?o4?oo
ool2oed0o`Gooooo0_l0om82o`1<occooooo0_l02_lCooooo`03o`3o2_l0obSo0?lX00;o0?lX0_l0
o`X2ooooo`?o0?mI:oooool8oed0oe7ooooo001Cooooo`03o`000?oooooooooo08[ooooo01Co09_o
o`3o`?l0olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;oooooo`1[ool0ob;oooooo`3o>_l0oeWo0?Ko
ooooool04?oo0?mgo`23o`[ooooo00Go08?oo`1Booooooooooooo`0@o`02ooooo`03o`3o>_l0ogOo
oooo00Cooooo00co0?mBoooooooooooo0?n3ooooool0om;oooooo`3<oooooooo0?o<o`3fool0ooH:
ooooo`;o0?Ko2_ooool00ol0ogOoooooooooo`02ooooo`05o`2^ooooooooooooo`1<ool0ob800_oo
ool01ol0ocCoooooooooool04?ooooooo`3om_l0;_l01oooool01_l0oo3oooooo`3oD_oooooo9P3o
o`0Xo`?ooooo00?o03Coooooooooool01Oooool00ol0oh?oooooooooo`04ooooo`03oeL0ool0D_oo
oooo00?ooooo00?o0<coo`3oc?ooool02oooool00ol0oo3oooooooooo`07ooooo`03o`0doooooooo
oooo02Cooooo00?o0:koooooooooool02_ooool01?lJ0?ooooooo`3o=?l0oc@5ooooo`03o`3fool0
ogOooooo00;ooooo00?o08?oooooooooool03oooool2oed0o`Cooooo00?o04coo`3od_l0om80?_oo
ool2o`0:oaKooooo0ol0obP4o`3o2P?o0?mI8Oooool7oed0oeWooooo001Cooooo`03o`000?oooooo
oooo08_ooooo00oo09_oo`3oa_oooooo0:7oo`1Iool0ooKo0<coo`3od_l0oe;o06_oo`3o8_oooooo
0?ljooooool0m_l00_ooool00ol04?oo0?mgo`23o`02o`23o`Cooooo0ol0Pol01?l0D_ooooooo`0@
ool04?l2ooooo`;o0?mg1Oooool01?l0oe;oooooooooool0oh<2ooooo`03o`3od_oooooo0<co00;o
0?Ko00?o0?ofooooooooool01?ooool8o`1[o`[ooooo00Go0?mgooooooooooooooooo`2^o`02oooo
o`05o`1<ool0ob;oooooooooool0oc@00_ooool01?l04?ooooooooooool0;_l7ooooo`06o`3ol?oo
oooo0?mBoooooolV0?oo02So0oooool00ol0=?ooooooooooo`06ooooo`03o`3oPooooooooooo00Co
oooo00?oE`3oo`1Booooool00oooool2o`3<o`[ooooo00?o0?o`ooooooooool01oooool00ol0=?oo
ooooooooo`0Tooooo`03o`2^oooooooooooo00_ooooo00?o0?ldoaX0ooooool01Oooool00ol0m_oo
0?mgooooo`04ooooo`;o08?o4Oooool2oed0o`;o04co0oooool2o`3odSkooooo0ol02_lFooooo`Co
0?lX0_ooool01?l0o`[o0?mIo`3oFOl0oeT4o`3o2Q?ooooo1omM0?mPooooo`00Doooool00ol0003o
ooooooooo`2;ooooo`0=o`2Kool0ol3o0?o6o`2Qool0ok[o05Woo`3om_l0c?oo0?oBo`29ool0Jooo
0?lRo`3o>P02ooooo`03o`3foooooooo013o00;o05;o00?oooooo`23ool0Pol01?l0Pol2o`1Bo`03
ooooool04?oo0?mI00;ooooo00?o0?mgooooooooool01?ooool03?l0oe;ooooooooooooooooo0?n3
ooooool0om;oooooo`3<ool0m_ooooooo`3omPCooooo0ol0Jol8ooooo`;o06_o2?ooool00ol0ogOo
ooooooooo`02ooooo`05o`2^oooooooo04coooooool0ob800_ooool00ol0ocCoooooo`0@o`02oooo
o`03o`0^oooooooooooo00Gooooo00Ko0?o`oooooooooooo0?mBobH0ool0:?l4ooooo`03o`0doooo
oooooooo00Kooooo00?o0?n3ooooooooool00oooool00omG0?oo05;oooooo`05ooooo`03o`3<ool0
olcooooo00Oooooo00?o0?o`ooooooooool01oooool00ol0=?ooooooooooo`0Sooooo`03o`2^oooo
oooooooo00[ooooo0_l0oc@2ooooo`03oaX0oooooooooooo00;ooooo00?o0?Koooooooooool01ooo
ool00ol0Poooooooooooo`0?ooooo`03o`1<oomM0?ooG@3o00Gooooo0_l0om8oooooo`;o00[o6?oo
ool4o`3o:0;ooooo0ol0oeT00ooooooo0?l:o`3o2P06o`3o2P?ooooo2?mM0?mWooooo`00Doooool3
o`0008_ooooo01;o09_oo`3o`?l0olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0om;oooooo`1[ool0ob;o
ooooo`3o>_oooooo0?Koo`3oFOooool2o`0@o`Oo05;o0_ooool00ol04?oo0?mIooooo`02o`3oM`Ko
oooo00co0?lRo`3oD_ooooooooooo`3oPooooooo0?oBo`3fool0c?oo0?o<ooooool0ooH4ooooo`03
o`1[oooooooooooo00Wooooo00?o0?Koooooool0Jol01oooool00ol0ogOoooooooooo`02ooooo`05
o`2^oooooooo04coooooool0ob800_ooool00ol0ocCoooooo`0@o`02ooooo`03o`0^ool0ooKooooo
00Kooooo00Ko0?o`ooooool0oe;oooooobH0ool0:?l3ooooo`03o`0doooooooooooo00Oooooo00?o
0?n3ooooooooool00_ooool00omG0?ooooooo`1Bo`06ooooo`;o0<co1_ooool00ol0oo3ooooooooo
o`07ooooo`03o`0doooooooooooo02Cooooo00?o0:koooooooooool02Oooool00ol0ocCooooooooo
o`03ooooo`04oaX0ooooooooooooo`3fo`_ooooo00?o08?oooooooooool03?ooool2o`1<o`?ooooo
0omM0?l4ooooo`;o0?oB?oooool2o`0:oa[ooooo1?l0obP00ooooooo0?mIo`3oF@02o`3oF@SoG@3o
1Ol0o`YZooooo`00Doooool00ol0003oooooooooo`2<ooooo`0;o`2Kool0olKoooooo`2Qool0FOoo
0?ofo`3<oooooooo0?oBo`1[ool0ob800_ooool00ol0oc[o0?Koo`3oF@03ooooo`03o`0@ool0ogOo
oooo00Cooooo0_l04?l01?l0oeWoooooo`3oMol0ocX6ooooo`06o`3o8_l0oe;oooooooooool0oh?o
oooo0_l0m_l01Ol0c?ooooooo`3oc?oooooo0?of00;ooooo0_l0Jol9ooooo`Ko05Wo00?o06_ooooo
ooooool01Oooool01Ol0ogOooooooooooooooooo0:ko00;ooooo00Go04coo`3o8_ooooooooooo`3o
=002ooooo`04o`0@oooooooo02koo`3omPOooooo00Ko0?o`oooooooooooo0?mBobH0ool0:?l3oooo
o`03o`0doooooooooooo00Oooooo00?o0?n3ooooooooool00oooool00omG0?ooooooo`1Bo`07oooo
o`03o`3<ool0olcooooo00?ooooo00?o0?o`ooooooooool01oooool00ol0=?ooooooooooo`0Soooo
o`03o`2^oooooooooooo00Wooooo00?o0?ldooooooooool01Oooool00olJ0?oo0?Koooooo`0<oooo
o`03o`23oooooooooooo00[ooooo00?o04coooooooooool01_ooool3oed0o`?ooooo0_l0om8ooooo
o`?o00[o6Oooool7oed0o`?o0?mI2_ooool:o`3o2V3ooooo001Cooooo`03o`000?oooooooooo08co
oooo017o09_oo`3o`?l0olKo0:7oo`3o^_l0FOoo0?ofo`3<ool0om;oooooo`1[ool0ob;oooooo`3o
>_oooooo0?Koo`3oF@03ooooo`Ko013o1?l0ogL00ol0oc[oooooooooo`04ooooo`0=o`3o8_l0oe;o
ooooooooool0oh?oooooo`3fool0om;o0<coooooool0olcoooooo`3omP02ooooo`03o`1[oooooooo
oooo00Oooooo0ol0FOl4ooooo`04o`3fool0FOoo05Woo`1Io`Gooooo00Go0?mgoooooooooooooooo
o`2^o`02ooooo`05o`1<oooooooo0?lRooooool0oc@00_ooool01Ol04?ooooooooooool0;_oo0?of
00Kooooo00Ko0?o`oooooooooooo0?mBobH0ool0:?l4ooooo`03o`0doooooooooooo00Oooooo00?o
0?n3ooooooooool00_ooool00omG0?ooooooo`1Bo`08ooooo`;o0<co00?o0?o<ooooool0oo002Ooo
ool00ol0=?ooooooooooo`0Sooooo`03o`2^oooooooooooo00Sooooo0_l0oc@7ooooo`03o`3oMol0
m_oo6P3o00kooooo00?o08?oooooooooool01oooool2o`1<o`cooooo0omM0?l2ooooo`;o0?oB@?oo
ool3o`0:o`gooooo2OmM0?l7ooooo`?o0?lX0ol0oeTAooooo`_o0?l:EOooool005?ooooo00?o0000
ooooooooool0S?ooool03?l0Vooo0?o0o`3oa_l0XOoo0?mmo`1Iool0ooKo0<coo`3od_l0oe;o06_o
o`3o8P;ooooo00?o0?ljooooool0m_l00_l0oeT5ooooo`04o`3oFOl0ogOo0?mgooooo`;o0?lj1_oo
ool01Ol0ob;o0?mBoooooooooooo0?n300;o0?Ko00Oo0?oBooooool0c?oo0?o<ooooool0ooKooooo
00;o06_o1oooool3o`1Io`Sooooo00Co0?Koooooool0Jooo05Wo1?ooool00ol0ogOoooooooooo`02
ooooo`05o`2^oooooooo04coooooool0ob800_ooool00ol0ocCoooooo`0@o`02ooooo`03o`0^ool0
ooKooooo00Kooooo00Go0?o`ooooool0oc[o9P3oo`0Xo`04ooooo`03o`0doooooooooooo00Sooooo
00Go0?n3oooooooooooooooooeL0o`02ooooo`03o`1Boooooooooooo00Oooooo0_l0c?l00ol0oo3o
ooooooooo`06ooooo`03o`0doooooooooooo02Cooooo00?o0:koooooooooool01oooool00ol0ocCo
ooooooooo`06ooooo`05o`3oMol0m_oooooooooooolJ0?l03_ooool00ol0Poooooooooooo`05oooo
o`03o`1<oooooooooooo00oooooo1omM0?m0ooooo`03o`0:oomM0?ooG@3o00[oG@3o5Oooool01?l0
obSo0?mIo`3oFOl0oeTIoooooa3o0?l:AOooool005?ooooo00?o0000ooooooooool0SOooool03?l0
Vooo0?o6ooooool0XOoo05Woo`3om_l0c?oo0?n3o`3od_l0Joooooooo`3o8P;ooooo0_l0ocX00ol0
m_ooooooo`3oF@05o`3oF@;ooooo00?o0?ljooooooooool01Oooool00ol0ob;oooooo`3oDP02oooo
o`0:o`3foooooooo0?oBooooool0c?oo0?o<ooooool0ooKoooooo`1[o`Oooooo0_l0FOl;ooooo`05
o`3foooooooo06_oooooool0FOl01?ooool01ol0ogOooooooooooooooooo0:koooooool0C?l00_oo
ool00ol0ob;oooooo`3o=002ooooo`05o`0@oooooooo02koooooool0ooH01_ooool01_l0oo3ooooo
ooooool0oe;o9P3oo`0Xo`?ooooo00?o03Coooooooooool02Oooool01ol0oh?ooooooooooooooooo
E`3oooooool0D_l02oooool00ol0c?oo0?o<ooooo`06ooooo`03o`0doooooooooooo02?ooooo00?o
0:koooooooooool01oooool00ol0ocCoooooooooo`06ooooo`03o`3oMol0m_oooooo00?ooooo00?o
6P3oooooooooool03?ooool00ol0Poooooooooooo`02ooooo`;o04co6?ooool00ol0om;oG@3ooed0
o`05oed0obKooooo5?mM0?l2ooooo`?o00[o8?ooool4o`3oF@03o`3o:?oooooooooo02;ooooo2_l0
o`Xkooooo`00Doooool00ol0003oooooooooo`2=ooooo`0=o`2Kool0ol3o0?o6o`2Qool0ok[o05Wo
o`3om_l0c?oo0?oBo`3oD_l0Joooooooo`3o8P03ooooo`03o`3o>_l0m_oooooo00Kooooo00?o0?lj
ooooooooool01Oooool01?l0ob;oooooo`3oD_ooool2o`3fo`07ooooool0om;oooooo`3<ool0olco
ooooo`3omP02o`1[o`Oooooo00?o05Woooooooooool03?ooool01Ol0m_ooooooo`1[oooooooo05Wo
00?ooooo00Go0?mgooooooooooooooooo`2^o`02ooooo`05o`1<oooooooo0?lRooooool0oc@00_oo
ool01Ol04?ooooooo`0^oooooooo0?of00Kooooo00Ko0?o`oooooooooooo0?ljobH0ool0:?l4oooo
o`03o`0doooooooooooo00Wooooo00Co0?n3ooooooooooooE`3o0_ooool00ol0D_ooooooooooo`07
ooooo`04o`3ol?oooooo0<coo`3<o`Gooooo00?o03Coooooooooool09?ooool00ol0[_oooooooooo
o`05ooooo`;o0?ld2?ooool00ol0ogOo0?Koooooo`05ooooo`03oaX0oooooooooooo00cooooo0_l0
Pol00ooooooo04coooooo`0Kooooo`;o0?oB1?oooolVoed0oaWooooo0ol02_lQooooo`Co0?mI00?o
0?lXooooooooool07Oooool;o`0^oc_ooooo001Cooooo`03o`000?oooooooooo08gooooo00_o09_o
o`3o`?l0olKo0:7oo`3oOOl0FOoo0?ofo`3<ool0oh?o0?oBo`1[o`02ooooo`06o`3o8_oooooooooo
ooooool0oc[o0?Ko1?ooool2o`3o>POooooo00Ko0?lRooooool0oe;oooooo`3fool0oh<2ooooo`06
o`3od_l0c?ooooooo`3oc?l0ooKo06_o1oooool2o`1Io`Wooooo1_l0olH01Ooooooo0?Koooooool0
Jooo05Wo00?ooooo00Go0?mgooooooooooooooooo`2^o`02ooooo`05o`1<oooooooo0?lRooooool0
oc@00_ooool01_l04?ooooooooooool0;_ooooooo`3omPKooooo00Go0?o`oooooooooooo9P3oo`0X
o`04ooooo`03o`0doooooooooooo00Wooooo00Co0?n3ooooooooooooE`3o0oooool00ol0D_oooooo
ooooo`06ooooo`04o`3ol?ooooooooooooooo`;o0<co0oooool00ol0=?ooooooooooo`0Sooooo`03
o`2^oooooooooooo00Gooooo00?o0?ldooooooooool01oooool00ol0ogOo0?Koooooo`06ooooo`03
oaX0oooooooooooo00gooooo0_l0C?lOooooo`;o0?oBA?ooool3o`0:ob;ooooo0ol0oeT3o`3o:0Wo
oooo4Ol0;_m6ooooo`00Doooool00ol0003oooooooooo`2>ooooo`0:o`2Kool0olKoooooo`2Qool0
FOooooooo`3om_l0c?oo0?oBo`1[o`?ooooo00Ko0?lRooooooooooooooooo`3o>_l0m_l3o`3o>PSo
oooo00?o0?lRooooool0oe800_l0m_l02Ol0oh?oooooooooool0om;o0<coooooool0olcoooooo`1[
o`07ooooo`03o`1Ioooooooooooo00Kooooo1?l0olH5o`3oS`06o`3oa_l0m_ooooooo`1[oooooooo
05Wo0_ooool00ol0ogOoooooooooo`02ooooo`03o`2^oooooooo04co00;ooooo00Go0?lRooooool0
ocCoooooo`0@o`02ooooo`03o`0^oooooooo0?of00Kooooo00Ko0?o`oooooooooooo9P3oo`3oD_l0
:?l3ooooo`03o`0doooooooooooo00[ooooo00Co0?n3ooooooooooooE`3o0_ooool00ol0D_oooooo
ooooo`05ooooo`03o`3ol?oooooooooo00Cooooo0_l0c?l00ol0=?ooooooooooo`0Sooooo`03o`2^
oooooooooooo00Cooooo0_l0oc@:ooooo`03o`3foooooooooooo00Oooooo00?o6P3oooooooooool0
2oooool01?l0C?ooooooooooool0PolPooooo`;o0?oBAOooool3o`0:ob;ooooo00?o0?mIo`0^ool0
;_l02Ol0;_mGooooo`00Doooool00ol0003oooooooooo`2>ooooo`0;o`2Kool0ol3o0?o6o`2Qool0
ok[o05Woo`3om_l0c?ooooooo`3od_l0Jol00_ooool00ol0ob;oooooooooo`03ooooo`03o`3foooo
oooooooo00Oooooo00Ko0?lRo`3fool0m_oo0?Koooooool0oh<2ooooo`06o`3od_oooooo0<coo`3o
c?oooooo06_o1oooool00ol0FOooooooooooo`06ooooo`04o`3oa_l0ohoo0?n?o`3oS`Kooooo0_l0
ohl01Ol0m_oo0?o6o`1[oooooooo05Wo00;ooooo00Oo0?mgooooooooooooooooo`2^oooooooo04co
00;ooooo00?o0?lRooooool0oc@00_ooool00ol04?ooooooo`0^o`02ooooo`03o`3om_oooooooooo
00?ooooo00Ko0?o`ooooooooooooooooobH0ool0:?l4ooooo`03o`0doooooooooooo00[ooooo00?o
0?n3oooooomG0?l00oooool00ol0D_ooooooooooo`04ooooo`03o`3ol?oooooooooo00Kooooo00Co
03Coo`3<ool0olco0?o<8_ooool00ol0[_ooooooooooo`03ooooo`03o`3o=?oooooooooo00Wooooo
00?o0?mgo`3fooooool02Oooool00olJ0?ooooooooooo`08ooooo`;o04co1?ooool2o`23ob3ooooo
0_l0om96ooooo`?o00[o5oooool9o`0^o`?ooooo1?l0oeT5o`3o:5Kooooo001Cooooo`03o`000?oo
oooooooo08kooooo00co09_oo`3o`?l0olKo0:7oo`3oOOl0FOooooooo`3om_l0c?oo0?oBo`29ool0
Jol2ooooo`;o0?lR1?ooool3o`3fo`Gooooo0_l0m_l01?oooooo0?mBooooool0oh<2ooooo`06o`3o
d_oooooo0<coo`3oc?oooooo06_o1oooool00ol0FOooooooooooo`05ooooo`;o0?o63?ooool02?l0
m_oo0?n?o`1[ool0olKoooooo`1Ioooooooo0?mg0oooool02?l0[_ooooooooooool0C?ooooooo`3o
8_oooooo0?ld0_ooool00ol04?ooooooo`0^o`02ooooo`03o`3om_oooooooooo00Cooooo00Go0?o`
oooooooooooo9P3oo`0Xo`04ooooo`03o`0doooooooooooo00_ooooo00?o0?n3oeL0ooooool00ooo
ool00ol0D_ooooooooooo`02ooooo`03o`3ol?oooooooooo00Kooooo00?o03Coooooooooool00_l0
c?l3o`3oc1kooooo00?o0:koooooooooool00oooool00ol0ocCoooooooooo`09ooooo`03o`3oMol0
m_oooooo00_ooooo00?o6P3oooooooooool01_ooool00ol0C?ooooooooooo`06ooooo`03o`23oooo
oooooooo01oooooo0_l0om97ooooo`?o00[o3?ooool8o`0^oa3ooooo0ol0oeT2ooooo`Go0?lXDOoo
ool005?ooooo00?o0000ooooooooool0Soooool02ol0Vooo0?o6ooooool0XOoo0?njo`1Iool0ooKo
0?n3o`3<ool0oe;o06_o00Cooooo00?o0?lRooooooooool00oooool7o`3fo`04ooooool0oe;ooooo
o`3oP`;ooooo00Co0?oBooooool0c?oo0?o<0_l0Jol7ooooo`03o`1Ioooooooooooo00?ooooo1Ol0
ROl=ooooo`07o`3foooooooo06_oooooool0FOooooooo`3oM`03ooooo`04o`2^ooooooooooooo`1<
o`;ooooo00Go0?lRooooool0ocCoooooo`0@o`02ooooo`04o`0^ooooooooooooo`3omPGooooo00Go
0?o`oooooooooooo9P3oo`0Xo`05ooooo`03o`0doooooooooooo00_ooooo00?o0?n3oeL0ooooool0
0_ooool00ol0D_ooooooooooo`02ooooo`03o`3ol?oooooooooo00Kooooo00?o03Coooooooooool0
0_ooool2o`3<o`04ooooool0olco0?o<o`3oc1[ooooo00?o0:koooooooooool00_ooool2o`3o=0_o
oooo00?o0?mgo`3fooooool03Oooool00olJ0?ooooooooooo`04ooooo`03o`1<oooooooooooo00So
oooo00?o08?oooooooooool08?ooool3o`3odTOooooo1?l02_l00ooooooo02koo`0^o`05o`0^oa_o
oooo1?l0oeT3ooooo`Go0?lXC?ooool005?ooooo00?o0000ooooooooool0Soooool03?l0Vooo0?o0
o`3oa_l0XOoo0?mmo`1Iool0ooKo0?o<o`3<ool0om;o0?mBo`1[o`?ooooo0_l0ob87ooooo`;o0?lR
00Goooooo`3oD_l0oe;oooooo`3oP`02ooooo`06o`3od_oooooo0<coo`3oc?l0Jooo0?of1_ooool2
o`1Io`;ooooo1?l0ROl5o`3Zo`;o08Wo2oooool02?l0m_ooooooo`1[ool0olKoooooo`1Ioooooooo
0?mg0oooool00ol0[_ooooooo`1<o`02ooooo`03o`3o8_oooooo0?ld00;ooooo00?o013oooooool0
;_l00_ooool00ol0ooKoooooooooo`03ooooo`06o`3ol?ooooooooooobH0ool0oc[o02So1?ooool0
0ol0=?ooooooooooo`0<ooooo`03oeL0oooooooooooo00;ooooo00Co05;ooooooooooooo0?o`2?oo
ool00ol0=?ooooooooooo`05ooooo`;o0<co0_ooool3o`3oc1Oooooo00Go0:kooooooooooooooooo
o`3o=00<ooooo`03o`3oMol0m_oooooo00oooooo00Co6P3ooooooooooooooooo0_l0C?l<ooooo`03
o`23oooooooooooo02;ooooo0_l0om94ooooo`Go02ko0ol02_lTooooo`?o0?mI1Oooool5o`3o:4Oo
oooo001Cooooo`03o`000?oooooooooo093ooooo00_o09_oo`3oa_l0XOoo0?mmo`3o^_l0FOoo0?of
ooooool0c?ooooooo`1[o`05ooooo`Oo0?lR0_ooool03?l0oe;ooooooooooooooooo0?n3ooooool0
om;oooooo`3<ool0olco06_oo`3omPKooooo00?o05Woooooool0ROl00_l0ROl2o`3Zo`03o`3oa_l0
ohoooooo00Gooooo00?o0>[oo`29ool0ROl02Oooool02?l0m_ooooooo`1[oooooooo0?o6ooooool0
FOoo0?mg0oooool00ol0[_ooooooo`1<o`03ooooo`07o`3o8_l0ocCoooooooooool04?ooooooo`0^
o`02ooooo`03o`3om_oooooooooo00Cooooo00Go0?o`oooooooooooo9P3oo`0Xo`04ooooo`03o`0d
oooooooooooo00cooooo00?oE`3oo`3oPoooool00oooool00ol0D_ooooooo`3ol008ooooo`03o`0d
oooooooooooo00Oooooo0_l0c?l3ooooo`?o0?o<4oooool01Ol0[_oooooooooooooooooo0?ld00co
oooo00?o0?mgooooool0m_l04Oooool00olJ0?ooooooo`1<o`0?ooooo`;o08?o9?ooool2o`3odSgo
oooo1Ol0;_l8ooooo`?o00[o9?ooool4o`3oF@Kooooo1Ol0obP3ooooo`Co0?lR>oooool005?ooooo
00?o0000ooooooooool0T?ooool03Ol0Vooo0?o0o`3oa_l0XOooooooo`1Iool0ooKoooooo`3<ool0
om;oooooo`1[ool0oe802oooool03?l0oe;ooooooooooooooooo0?n3ooooool0om;oooooo`3<oooo
oooo06_oo`3omPKooooo00?o05Woo`29ool0ROl00ol0j_l00ol0olKo0?n?o`3oS`08ooooo`;o0>[o
00?o08Woooooooooool01oooool01ol0m_ooooooo`1[ool0olKo0?n?ooooool0FOl00oooool01?l0
[_ooooooooooool0C?l2ooooo`07o`3o8_oooooo0?ldooooool04?ooooooo`0^o`03ooooo`03o`3o
m_oooooooooo00?ooooo00Ko0?o`oooooooooooo9P3oo`0Xool0oe84ooooo`03o`0doooooooooooo
00cooooo00?oE`3oo`3oPoooool00_ooool00ol0D_ooooooo`3ol007ooooo`03o`0doooooooooooo
00[ooooo0_l0c?l4ooooo`?o0?o<3oooool00ol0[_ooooooooooo`02o`3o=0cooooo00?o0?mgoooo
ool0m_l04oooool00olJ0?ooooooooooo`0@ooooo`03o`23oooooooooooo02?ooooo0ol0om8eoooo
o`Go02ko4?ooool4o`0:obCooooo0ol0oeT6ooooo`;o0?lR00?o0?lXo`3Zool0j_l01?l0j_lkoooo
o`00Doooool00ol0003oooooooooo`2@ooooo`0>o`2Kool0ol3o0?o6o`2Qool0oggo05Woooooool0
ooKoooooo`3<ool0om;o08Woo`1[ool0oe88ooooo`;o0?mB0oooool02?l0oh?oooooo`3od_oooooo
0<coooooool0Jooo0?of1_ooool01?l0FOoo08Woo`3Zool0j_l2ooooo`03o`3oa_l0ohoooooo00Oo
oooo1?l0ogd00ol0j_oo08Woo`29o`07ooooo`08o`3foooooooo06_oooooool0olKoooooo`1Iool0
ogL2ooooo`04o`2^ooooooooooooo`1<o`;ooooo00Go0?lRooooool0ocCoooooo`0@o`02ooooo`04
o`0^ooooooooooooo`3omPGooooo00Ko0?o`oooooooooooo9P3oo`3o>_l0:?l4ooooo`03o`0doooo
oooooooo00cooooo00?oE`3oooooool0oh<00oooool00ol0D_ooooooooooo`06ooooo`03o`0doooo
oooooooo00cooooo0ol0c?l4ooooo`?o0?o<3?ooool00ol0[_ooooooo`3o=00=ooooo`03o`3oMooo
oooo0?Ko01;ooooo0_l0C?l00ooooooo6P3oooooo`0Aooooo`03o`23oooooooooooo02Gooooo0_l0
om8^ooooo`Go02ko6Oooool3o`0:ob?ooooo2_l0j_l4ooooo`;o0?lX>oooool005?ooooo00?o0000
ooooooooool0TOooool03_l0Vooo0?o6o`2Qool0oggo0?njo`1Iool0olco0?ofo`3<oooooooo0?oB
o`29ool0Jooo0?mB1Oooool2o`3oDPCooooo00Go0?n3o`3od_l0om;oooooo`3<o`02o`1[o`03o`3o
m_oooooooooo00?ooooo00Co08Woo`1Iool0j_oo0>[o0oooool00ol0olKo0?n?ooooo`04ooooo`Co
0?mm0oooool2o`3oO@;o0>[o00?o08Woooooooooool01?ooool00ol0m_ooooooo`1[o`02ooooo`03
o`3oa_oooooo05Wo00?ooooo00?o0:koooooool0C?l00oooool01ol0ob;o0?ldoooooooooooo013o
ooooool0;_l00oooool00ol0ooKoooooooooo`03ooooo`06o`3ol?oooooo9P3oooooool0:?oo0?mB
1?ooool00ol0=?ooooooooooo`0;ooooo`04oeL0ooooooooooooo`3oP`;ooooo00?o0?o`o`1Boooo
ool01Oooool00ol0=?ooooooooooo`0@ooooo`;o0<co1Oooool3o`3oc0Sooooo00?o0:koooooool0
oc@03Oooool00ol0ogOoooooo`3fo`0Booooo`03o`1<oooooooooooo00;ooooo00?o6P3ooooooooo
ool04?ooool2o`23obOooooo0ol0om8Vooooo`Go02ko8Oooool5o`0:oa?ooooo2ol0j_l01?l0ob;o
ooooooooooooool4o`3oFD?ooooo001Cooooo`03o`000?oooooooooo097ooooo00ko09_oo`3o`?l0
olKo0:7oo`3oOOl0FOooooooo`3om_oooooo0<coo`3od_oooooo08Woo`1[o`Ko0?mB1?ooool02?l0
oh?o0?oBoooooooooooo0<coo`1[ool0olco0?of1Oooool00ol0ROoo05Woo`3Zo`04ooooo`03o`3o
a_l0ohoooooo00;ooooo0ol0ogd;ooooo`03o`29ool0oggooooo00Gooooo00?o0?Koooooool0Jol0
0_ooool00ol0olKo05Woooooo`02ooooo`03o`2^oooooooo04co00?ooooo00Oo0?lRooooool0ocCo
ooooo`0@oooooooo02ko00?ooooo00?o0?ofooooooooool00oooool01_l0oo3ooooooooooolV0?oo
02Soo`3oDPGooooo00?o03Coooooooooool02oooool01OmG0?ooooooooooool0oh?o0?o`00;ooooo
00?o05;oooooooooool00_ooool00ol0=?ooooooooooo`0Cooooo`;o0<co1_ooool3o`3oc0Gooooo
00?o0:koo`3o=?ooool03?ooool01?l0ogOoooooooooool0m_lAooooo`03o`1<oooooooooooo00Co
oooo00?o6P3oooooooooool04Oooool00ol0Poooooooooooo`0Wooooo`;o0?oB8?ooool4o`0^ob_o
oooo1_l02_l00ooooooo0>[oo`3Zo`0:o`3Zo`03ooooool0ob;o0?lR00Co0?lR3?ooool3o`3oFD3o
oooo001Cooooo`03o`000?oooooooooo09;ooooo00[o09_oo`3oa_l0XOoo0?mmo`3o^_l0FOoooooo
o`3om_oooooo0<co0_l0om800ol0ROoo06_oooooo`06ooooo`;o0?n300?o0?oBooooooooool00_l0
Jol00ol0olco0?ofooooo`03ooooo`;o08Wo00?o05Woooooooooool00oooool00ol0olKo0?n?oooo
o`02ooooo`03o`3oOOoooooooooo00cooooo00?o0>[oo`29ool0ogd01Oooool00ol0m_ooooooo`1[
o`02ooooo`03o`3oa_l0FOoooooo00;ooooo00?o0:koooooool0C?l00oooool01ol0ob;oooooo`3o
=?oooooo013oooooool0;_l01?ooool00ol0ooKoooooooooo`03ooooo`06o`3ol?oooooo9P3ooooo
ool0:?oo0?mB1?ooool00ol0=?ooooooooooo`0;ooooo`06oeL0ooooooooooooooooool0oo3o0?n3
0_ooool01Ol0D_oooooooooooooooooo03Co01Oooooo0ol0c?l6ooooo`?o0?o<00?oooooo`2^ool0
oc@03Oooool01?l0ogOoooooooooool0m_l@ooooo`;o04co2?ooool2oaX0oa;ooooo00?o08?ooooo
ooooool0:?ooool2o`3odQWooooo1Ol0;_l/ooooo`Wo0>[o1_l02_l2ooooo`Ko0?lR5Oooool5o`3o
FC_ooooo001Cooooo`?o0000T_ooool03_l0Vooo0?o6o`2Qoooooooo0?mmo`3o^_l0FOoo0?ofo`3o
c?oooooo0<coo`3oPol0ROoo0>[o0_l0Jol2ooooo`?o0?n30_l0om800ooooooo06_oo`1[o`02o`3o
c003o`3om_oooooooooo00;ooooo00?o08Woo`3Zool0FOl01Oooool01?l0olKo0?n?ooooooooool2
o`3oOA3ooooo00?o0>[oo`29ool0ogd01Oooool00ol0m_ooooooo`1[o`02ooooo`05o`3oa_l0FOoo
ooooooooool0[_l00_ooool02?l0C?oooooooooooooooooo0?lRo`3o=?oooooo013o0_ooool01Ol0
;_oooooooooooooooooo0?of00Gooooo00Ko0?o`oooooolV0?ooooooo`0Xool0oe85ooooo`03o`0d
oooooooooooo00[ooooo00CoE`3ooooooooooooo0?o`0_ooool01_l0oh?oooooooooool0D_oooooo
o`0doa_ooooo0_l0c?l7ooooo`03o`2^ool0olcooooo00cooooo00Co0?mgoooooooooooo0?Ko4?oo
ool00ol0C?ooooooooooo`0:ooooo`03oaX0oooooooooooo013ooooo00?o08?oooooooooool0:Ooo
ool3o`3odQ7ooooo1Ol0;_lYooooo`So0>[o3?ooool3o`3o8PGo00[oF?ooool005?ooooo00?o0000
ooooooooool0Toooool02_l0Vooo0?o6o`2Qool0oggo0?njo`1Ioooooooo0?ofo`3oc?ooool2o`3<
o`03o`29ool0om;o0?oB00So06_o00Co0<coo`3oc?oooooo0?of0oooool2o`29o`03ooooool0FOoo
oooo00Cooooo00Go0?o6o`3oSoooooooooooo`3oO@04ooooo`Wo0?nj1_ooool00ol0j_oo08Woo`3o
O@04ooooo`03o`3foooooooo06_o00;ooooo00?o0?o6o`1Iooooool00_ooool00ol0[_ooooooo`1<
o`03ooooo`07o`3o8_oooooo0?ldooooool04?ooooooo`0^o`04ooooo`03o`3om_oooooooooo00?o
oooo00Ko0?o`obH0oooooooo02Soo`3o>_l0oe84ooooo`03o`0doooooooooooo00_ooooo00?oE`3o
ooooool0oo000oooool01?l0oh?oooooooooool0=?lNooooo`;o0<co1Oooool01?l0[_ooooooo`3o
c?l0ol`;ooooo`03o`3oMooooooo0?Ko013ooooo00?o04coooooooooool03?ooool00olJ0?oooooo
ooooo`0@ooooo`;o08?o;?ooool2o`3odP_ooooo1?l0;_lWooooo`Oo0>[o3_ooool6o`3o8PSooooo
1ol02_mAooooo`00Doooool00ol0003oooooooooo`2Cooooo`0:o`2Kool0olKo0:7oo`3oOOoooooo
0?njo`1Ioooooooo0?ofo`3oc0;ooooo00?o0<coo`29ool0ROl00ol0om82ooooo`?o0<co00Co0?o<
o`3om_l0ooKooooo0_l0j_l01?l0ROooooooooooool0FOl5ooooo`03o`3oa_l0ohoooooo00;o0?mm
0oooool2o`3o^PKooooo1Ol0ol04ooooo`04o`3Zool0ROooooooo`3oO@?ooooo00?o0?Koooooool0
Jol00oooool01ol0olKo05Wooooooooooooo0:koooooool0C?l00oooool01ol0ob;oooooo`3o=?oo
oooo013oooooool0;_l01?ooool00ol0ooKoooooooooo`03ooooo`07o`3ol?oooooo9P3oooooool0
:?oo0?ljo`3oDP04ooooo`03o`0doooooooooooo00[ooooo00?oE`3oooooool0oo001?ooool00ol0
oh?oooooo`0do`0Pooooo`?o0<co00?oooooo`2^ooooool00oooool3o`3oc0Oooooo00Co0?mgoooo
oooooooo0?Ko3_ooool2o`1<oa3ooooo00?o6P3oooooooooool04Oooool00ol0Poooooooooooo`0[
ooooo`?o0?oB0oooool5o`0^ob?ooooo2?l0j_l?ooooo`Ko0?lR5Oooool7o`0:od[ooooo001Coooo
o`03o`000?oooooooooo09?ooooo00Oo09_oo`3o`?l0olKo0:7oo`3oOOl0ok[o05Wo00;ooooo00?o
0?ofo`3oc?ooool00ol0c?l00ol0ROoo0<coo`3<o`02o`3<o`04ooooool0olcoooooo`3omP;ooooo
00?o0>[oo`29ool0ROl00_ooool00ol0FOooooooooooo`03ooooo`04o`3oa_l0ohooooooo`3oO@;o
oooo0ol0okX4ooooo`Co0?o01?ooool4o`3o`0;ooooo00Co0>[oo`29oooooooo0?mm0oooool00ol0
m_ooooooo`1[o`02ooooo`07o`3oa_l0FOooooooooooool0[_ooooooo`1<o`04ooooo`04o`3o8_l0
ocCoooooo`0@o`;ooooo00?o02koooooooooool00_ooool00ol0ooKoooooooooo`03ooooo`06o`3o
l?lV0?ooooooo`0Xool0oc[o0?mB1?ooool00ol0=?ooooooooooo`0;ooooo`03oeL0oooooooooooo
00Cooooo00?o03Coo`3oPol0D_l08_ooool00ol0c?oo0:koooooo`06ooooo`;o0?o<1?ooool01?l0
ogOoooooooooool0m_l>ooooo`03o`1<oooooooooooo017ooooo0_lJ0?lBooooo`03o`23oooooooo
oooo02gooooo0ol0;_lPooooo`So0>[o4Oooool6o`3o8R;ooooo1ol02_m3ooooo`00Doooool00ol0
003oooooooooo`2Dooooo`07o`2Kool0ohoo0:7oo`3oOOoooooo0?njo`1Io`02ooooo`03o`3om_l0
olco0?o<00?ooooo2ol0ROl3ooooo`03o`1Ioooooooooooo00?ooooo00Go0?o6o`3oSol0oggo0?mm
ooooo`02o`3o^PCooooo0ol0ol0:ooooo`06o`3o^_oooooo0?o0ooooool0j_oo08Wo0_ooool01_l0
oggoooooooooool0m_ooooooo`1[o`?ooooo00Co05Wooooooooooooo0:ko0_ooool02ol0C?oooooo
oooooooooooo0?lRooooool0ocCoooooo`0@oooooooo02ko00Cooooo00?o0?ofooooooooool00ooo
ool01ol0oo3o9P3oooooool0:?ooooooo`3o>_l0oe800oooool00ol0=?ooooooooooo`0;ooooo`03
o`3ol?mG0?oooooo00?ooooo00Go03Cooooooooooooo0?n3o`1Bo`0Pooooo`03o`3o=?l0[_oooooo
00;o0<co1oooool2o`3oc005ooooool0ogOoooooooooool0m_l03_ooool00ol0C?ooooooooooo`0D
ooooo`03oaX0oooooooooooo013ooooo0_l0PolZooooo`?o02ko0oooool3o`3odQKooooo1ol0j_lC
ooooo`Ko0?lR;oooool8o`0:oc_ooooo001Cooooo`03o`000?oooooooooo09Cooooo00So09_oo`3o
`?l0olKo0:7oo`3oOOoooooo0?njo`1Io`;ooooo0_l0ooH6o`3oc003ooooool0ooKo0?of00Oooooo
00?o05Woooooooooool00_ooool2o`3oaP05o`3oSol0oggoooooooooool0okX01?ooool2o`3o`0ko
oooo00So0?njooooool0ol3o0?o0o`3Zool0ROooooooo`3oO@;ooooo00?o0?Koooooool0Jol00ooo
ool01ol0olKo05Wooooooooooooo0:koooooool0C?l01?ooool01_l0ob;o0?ldooooool04?oooooo
o`0^o`Cooooo00?o0?ofooooooooool00oooool01ol0oo3o9P3ooooooooooooo02Soo`3o>_l0oe80
1?ooool2o`0do`[ooooo00?o0?o`oooooomG0?l00oooool00ol0=?ooooooooooo`02ooooo`03o`3o
Pol0D_oooooo01gooooo00?o0?ldo`2^ooooool00oooool2o`3<o`Oooooo0_l0ol`00ooooooo0?Ko
ooooo`0<ooooo`;o04co6?ooool00olJ0?ooooooooooo`0Aooooo`;o08?o9Oooool3o`0^o`Wooooo
0ol0om8=ooooo`Ko0>[o5?ooool6o`3o8WSooooo001Cooooo`03o`000?oooooooooo09Gooooo00So
09_oooooool0XOoo0?mmooooool0ok[oooooo`1Io`;ooooo2?l0ooH8ooooo`03o`1Ioooooooooooo
00;ooooo00Go0?o6o`3oSol0ohoo0?mmooooo`02o`3o^PCooooo00?o0?o0ooooooooool03_ooool0
1_l0ok[ooooooooooooooooo0>[oo`29o`;ooooo00Ko0?mmoooooooooooo0?Koooooool0Jol2oooo
o`07o`3oMol0FOooooooooooool0[_ooooooo`1<o`04ooooo`06o`3o8_l0ocCoooooo`0@oooooooo
02ko1Oooool00ol0ooKoooooooooo`03ooooo`07o`3ol?lV0?ooooooo`0Xoooooooo0?ljo`3oDP05
ooooo`03o`0doooooooooooo00Kooooo00Oo0?o`oooooooooooooooooeL0oooooooo03Co00Oooooo
00?o05;oooooooooool06_ooool00ol0ocCoooooo`2^o`06ooooo`03o`3<oooooooooooo00?ooooo
00Go0?mgoooooooooooo0?o<o`3fo`0<ooooo`03o`1<oooooooooooo01Wooooo00?o6P3ooooooooo
ool04_ooool00ol0Poooooooooooo`0Oooooo`?o02ko3oooool3o`3odPKooooo1?l0j_lEooooo`Go
0?lRO_ooool005?ooooo00?o0000ooooooooool0UOooool02?l0Vooo0?o0o`3oa_l0XOoo0?mmoooo
ool0ok[o05Wo4Oooool00ol0FOooooooooooo`02ooooo`04o`3oa_l0ohoo0?mmooooo`;o0?nj1?oo
ool2o`3o`1;ooooo00So0?njoooooooooooo0>[oo`3o`?l0ROooooooo`3oO@;ooooo00?o0?Kooooo
ool0Jol00oooool01_l0olKo05Woooooool0[_ooooooo`1<o`Cooooo00Co0?lRooooool0ocCo013o
0_ooool00ol0;_ooooooooooo`02ooooo`03o`3om_oooooooooo00?ooooo00Co0?o`obH0oooooooo
02So0_ooool00ol0oc[o0?mBooooo`03ooooo`03o`0doooooooooooo00Gooooo00?o0?o`oooooooo
ool00_ooool00omG0?oo03Coooooo`08ooooo`;o05;o6Oooool00ol0ocCoooooo`2^o`08ooooo`;o
0<co0_ooool01_l0ogOooooooooooooooooo0?Koooooo`?o0?o<2?ooool00ol0C?ooooooooooo`0K
ooooo`03oaX0oooooooooooo01;ooooo0_l0PolLooooo`?o02ko5Oooool2o`3odPCo0>[o5?ooool5
o`3o8X?ooooo001Cooooo`03o`000?oooooooooo09Kooooo00So09_oooooool0XOooooooo`3oOOl0
ok[oooooo`1Io`gooooo0ol0FOl4ooooo`03o`3oa_l0ohoo0?mm00;o0?nj1Oooool00ol0ol3ooooo
ooooo`08ooooo`Co09_o1oooool01Ol0ok[oooooooooool0j_oo08Wo00;ooooo00Go0?mmooooool0
m_ooooooo`1[o`03ooooo`04o`3oMol0FOooooooo`2^o`;ooooo00?o04coooooooooool00_ooool0
1_l0ob;o0?ldooooool04?ooooooo`0^o`Gooooo00?o0?ofooooooooool00oooool01olV0?oooooo
ooooool0:?ooooooo`3o>_l0oe801Oooool2o`0do`Cooooo00?o0?o`ooooooooool00_ooool00ol0
=?oooooooeL0o`0;ooooo`03o`1Bool0oh?ooooo01Gooooo00Co0?ldoooooooooooo0:ko2_ooool2
o`3<o`?ooooo00?o0?Koooooooooool00oooool2o`3oc0Cooooo0_l0C?lOooooo`;o6P3o5?ooool2
o`23oaOooooo0ol0;_lFooooo`Co0>[o00Coooooo`3od_l0om;o0?oB3oooool5o`3o8XSooooo001C
ooooo`03o`000?oooooooooo09Kooooo00Ko09_oooooool0ohoo0:7oooooool0ogd2o`3o^P?o05Wo
2?ooool2o`1Io`Kooooo00Co0?o6o`3oSol0ok[o0?nj1Oooool2o`3o`0Kooooo1Ol0Vol4ooooo`?o
09_o1Oooool01ol0ok[oooooo`3Zoooooooo08Woooooool0ogd00_ooool00ol0m_ooooooo`1[o`02
ooooo`07o`3oMol0FOoo0?n?ooooool0[_ooooooo`1<o`04ooooo`06o`3o8_l0ocCoooooo`0@oooo
oooo02ko1Oooool00ol0ooKoooooooooo`04ooooo`03obH0oooooooo02So00;ooooo00?o0?ljo`3o
D_ooool01Oooool2o`0do`04ooooool0oo3oooooooooo`?o03Co0oooool00omG0?ooooooooooo`09
ooooo`;o05;o00?o0?n3ooooooooool04Oooool01?l0ocCoooooooooool0[_l;ooooo`05o`3oMooo
oooo0<coo`3<ool0m_l02?ooool2o`3oc003ooooool0C?oooooo02;ooooo00?o6P3oooooooooool0
4oooool00ol0Poooooooooooo`0Aooooo`?o02ko5Oooool4o`3Zo`Sooooo0_l0om89ooooo`Co0?lR
SOooool005?ooooo00?o0000ooooooooool0U_ooool02Ol0Vooo0?o0ooooool0olKo0:7oooooool0
oggoooooo`3o^P02ooooo`;o05Wo1?ooool2o`1Io`Oooooo00?o0?o6o`3o^_l0okX01_ooool00ol0
ol3oooooooooo`03ooooo`?o09_o3?ooool3o`2Ko`;ooooo00Go0?njoooooooooooo0>[oo`29o`02
ooooo`05o`3oOOoooooo0?Koooooool0Jol00oooool01_l0ogOo05Woooooool0[_ooooooo`1<o`Co
oooo00Ko0?lRooooool0ocCo013oooooool0;_l6ooooo`03o`3om_oooooooooo00?ooooo00?o9P3o
o`3ol?l0:?l00_ooool00ol0oc[o0?mBooooo`06ooooo`03o`3ol?l0=?oo03Co00?o03Co1Oooool0
0omG0?ooooooooooo`0;ooooo`04o`1Bool0oh?o0?n3o`3oPa3ooooo00Co0?ldoooooooooooo0:ko
2_ooool00ol0ogOoooooooooo`02ooooo`;o0<co2Oooool00ol0C?oo0?o<ooooo`0Sooooo`;o6P3o
5?ooool2o`23o`kooooo0ol0;_lDooooo`Co0>[o3_ooool3o`3odP03ooooool0ob;o0?lR00?o0?lR
TOooool005?ooooo00?o0000ooooooooool0Uoooool01_l0Voooooooo`3oSol0XOoo0?o6o`3oO@;o
oooo00Co0?njoooooooooooooooo1?l0FOl8ooooo`03o`3oa_l0ok[o0?mm00Gooooo0_l0ol05oooo
o`03o`2Koooooooooooo013ooooo00ko09_ooooooooooooo0?njooooool0j_oo08Woo`3o`?oooooo
0?mmooooool0m_ooooooo`1[o`?ooooo00Ko0?mgo`1Iool0ohoo0:koooooool0C?l5ooooo`06o`3o
8_l0ocCoooooo`0@oooooooo02ko1Oooool00ol0ooKoooooooooo`03ooooo`04obH0oooooooo0?o`
o`0Xo`;ooooo00?o0?ljo`3oD_ooool01?ooool00ol0oo3oooooooooo`0:ooooo`03oeL0oooooooo
oooo00_ooooo0_l0D_l01?oooooo0?n3o`3oPol0oh<<ooooo`04o`3o=?ooooooooooo`2^o`[ooooo
00?o0?mgooooooooool00_ooool01?l0m_ooooooooooool0c?l7ooooo`03o`1<oooooooooooo00;o
0?o<9?ooool00olJ0?ooooooooooo`0Cooooo`;o08?o2_ooool2o`0^oaCooooo0ol0j_lBooooo`?o
0?lR0ol0om:Dooooo`00Doooool00ol0003oooooooooo`2Gooooo`06o`2Kool0ol3oooooo`3oSol0
XOoo0?o60_l0ogd00ooooooo0?njooooo`0;ooooo`;o0?o600?o0?mmooooooooool01?ooool00ol0
ol3oooooooooo`03ooooo`;o09_o0oooool6o`2Qo`[ooooo00oo09_oooooooooooooooooo`3o^_l0
j_ooooooo`29ool0ol3oooooo`3oOOoooooo0?Koooooool0Jol00_ooool01?l0ogOoooooo`1Iool0
[_l2ooooo`03o`1<oooooooooooo00;ooooo00Ko0?lRo`3o=?oooooo013oooooool0;_l5ooooo`03
o`3om_oooooooooo00?ooooo00Go9P3ooooooooooooo02Soo`3ol002ooooo`03o`3oD_oooooooooo
00?ooooo00?o0?o`ooooooooool02_ooool00omG0?ooooooooooo`0=ooooo`04o`1Boooooooooooo
ooooo`?o0?n32?ooool01?l0ocCoooooooooool0[_l:ooooo`03o`3oMooooooooooo00;ooooo00?o
0?Koooooooooool00_ooool2o`3<o`Cooooo00?o04coooooooooool00oooool2o`3oc2?ooooo0_lJ
0?lEooooo`;o08?o1Oooool3o`0^oa?ooooo0ol0j_l@ooooo`Go0?lR1_ooool2o`3odY;ooooo001C
ooooo`03o`000?oooooooooo09Sooooo00Wo09_oo`3o`?oooooo0:7oo`3oSol0olKoooooo`3oOOoo
ool00ol0okX7ooooo`03o`3o^_l0olKo0?mm00Kooooo0_l0ol04ooooo`;o09_o00?oooooo`2Qool0
XOl00_l0XOl5ooooo`Co0:7o2?ooool03_l0Vooooooooooooooooooo0?njo`3Zool0ROoo0?o0oooo
ool0oggoooooo`3foooooooo06_o0oooool01_l0ogOo05Woo`3oSol0[_ooooooo`1<o`Gooooo00Go
0?lRo`3o=?l04?ooooooo`0^o`06ooooo`03o`3om_oooooooooo00?ooooo00?o9P3oooooool0:?l0
0ol0oo000ol0oc[o0?mBooooo`03o`3ol0kooooo00?oE`3oooooooooool03Oooool00ol0D_oooooo
ooooo`03ooooo`?o0?n31?ooool01Ol0ocCooooooooooooooooo0:ko00[ooooo00Go0?mgoooooooo
ooooooooo`3fo`07ooooo`;o0<co0_l0C?l8ooooo`03o`3oc?oooooooooo02;ooooo00?o6P3ooooo
ooooool05?ooool00ol0Poooooooooooo`02o`0^oa?ooooo0ol0j_l>ooooo`Go0?lR3Oooool3o`3o
dXoooooo001Cooooo`03o`000?oooooooooo09Wooooo00?o09_oo`3o`?ooool00_l0XOl2o`3oaP03
o`3oOOoooooooooo00Oo0?nj0_l0olH00ol0oggoooooooooo`04ooooo`03o`3o`?oooooooooo00?o
oooo00Co09_oo`2Qool0XOoo0:7o3Oooool2o`2Qo`Kooooo00?o09_oooooooooool00_ooool02Ol0
j_oo08Woooooool0ol3oooooo`3oOOl0m_ooooooo`1[o`03ooooo`06o`3oMol0FOoo0?n?o`2^oooo
oooo04co1Oooool01Ol0ob;o0?ldo`0@oooooooo02ko00Kooooo00?o0?ofooooooooool00oooool0
1?lV0?ooooooooooool0:?l2ooooo`?o0?o`4_ooool00omG0?ooooooooooo`0=ooooo`03o`1Boooo
oooooooo00Gooooo0ol0oh<01Ol0ocCooooooooooooooooo0:ko00[ooooo00?o0?mgooooooooool0
0_ooool00ol0m_ooooooooooo`06ooooo`03o`1<ool0c?oo0<co00Wooooo0_l0ol`Sooooo`;o6P3o
5Oooool2o`0^oa;ooooo0ol0j_l=ooooo`Co0?lR5Oooool3o`3odXcooooo001Cooooo`03o`000?oo
oooooooo09[ooooo00Oo09_oo`3o`?ooooooooooo`2Qool0ohoo0?o600Co0?mm00?oooooo`3oOOl0
olH00_l0olH00ol0ohooooooooooo`04ooooo`;o0?o01?ooool2o`2Ko`03o`2Qoooooooooooo013o
oooo00?o0:7oooooooooool01?ooool03_l0Vooooooooooooooooooo0>[oooooool0ROoo0?o0oooo
ool0oggoooooo`3foooooooo06_o0_ooool01?l0ogOoooooo`1Iool0[_l2ooooo`03o`1<oooooooo
oooo00;ooooo00Ko0?lRo`3o=?oooooo013oooooool0;_l6ooooo`03o`3om_oooooooooo00;ooooo
00Co9P3ooooooooooooo02So0oooool00ol0oc[o0?mBooooo`0Booooo`03oeL0oooooooooooo00go
oooo00?o05;oooooooooool01_ooool01_l0ocCo0?n3o`3oPol0oh?oooooo`2^o`Wooooo00?o0?mg
ooooooooool00_ooool00ol0m_ooooooooooo`06ooooo`05o`1<ooooooooooooooooool0c?l02_oo
ool2o`3oc2?ooooo00?o6P3oooooooooool03oooool3o`0^o`;ooooo0_l0Pol=ooooo`?o0>[o2ooo
ool5o`3o8Qcooooo0_l0om::ooooo`00Doooool00ol0003oooooooooo`2Kooooo`06o`2Kool0ol3o
ooooooooool0XOoo0?n?1_l0olH3o`3oS`Kooooo00Co0?o0oooooooooooooooo0ol0VolFooooo`03
o`2Qoooooooooooo00Cooooo00go09_oooooooooooooooooo`3Zool0ROooooooo`3o`?l0oggooooo
o`3foooooooo06_o00;ooooo00Oo0?mgooooool0FOoo0?n?o`2^oooooooo04co00Gooooo00Go0?lR
o`3o=?l04?ooooooo`0^o`06ooooo`03o`3om_oooooooooo00;ooooo00Go9P3ooooooooooooooooo
o`0Xo`03ooooo`03o`3o>_l0oe;ooooo017ooooo00?oE`3oooooooooool03_ooool2o`1Bo`Gooooo
00?o0?ldooooooooool00_ooool00ol0[_oo0?n3o`3oP`07ooooo`03o`3oMooooooooooo00;ooooo
00?o0?Koooooooooool01_ooool00ol0C?ooooooooooo`03ooooo`;o0<co2_ooool2o`3oc2;ooooo
0_lJ0?l=ooooo`;o02ko1oooool00ol0Poooooooooooo`07ooooo`?o0>[o2_ooool4o`3o8R?ooooo
0ol0om98ooooo`Co0?mm>oooool005?ooooo00?o0000ooooooooool0W?ooool01?l0Vooo0?o0o`3o
`?ooool2o`2Qo`Go0?n?1oooool2o`3o`0;ooooo0_l0Vol00ol0XOooooooooooo`0Gooooo`03o`2Q
oooooooooooo00Cooooo00co09_ooooooooooooo0>[oo`29oooooooo0?o0ooooool0oggo0?Kooooo
ool0Jol3ooooo`06o`3oMooooooo05Woo`2^oooooooo04co1Oooool01Ol0ob;o0?ldo`0@oooooooo
02ko00Oooooo00?o0?ofooooooooool00_ooool01?lV0?ooooooooooool0:?l4ooooo`03o`3oD_oo
oooooooo017ooooo00?oE`3oooooooooool03oooool2o`1Bo`;ooooo00?o0?ldooooooooool00_oo
ool01?l0[_ooooooooooooooool3o`3oP`?ooooo00?o0?mgooooooooool00_ooool00ol0m_oooooo
ooooo`05ooooo`;o04co2?ooool2o`3<o`[ooooo0_l0ol`Rooooo`?o6P3o1oooool3o`0^o`[ooooo
0_l0Pol4ooooo`?o0>[o2Oooool4o`3o8R[ooooo0ol0om8nooooo`Oo0?mm?oooool005?ooooo0ol0
002Mooooo`03o`2Koooooooo0?o000;ooooo00?o0:7oooooooooool02?ooool00ol0ol3oooooo`2Q
o`02o`2Koagooooo00?o0:7oooooooooool00oooool03Ol0Voooooooooooool0ok[o0>[oo`29oooo
oooo0?o0o`3oOOoooooo0?Koooooool0Jol00_ooool01?l0ogOoooooo`1Iool0[_l2ooooo`03o`1<
oooooooooooo00;ooooo00Ko0?lRooooool0ocCo013oooooool0;_l6ooooo`03o`3om_oooooooooo
00;ooooo00Co9P3ooooooooooooo02So1Oooool00ol0oe;oooooooooo`0Aooooo`03oeL0oooooooo
oooo013ooooo00?o05;oo`3o=?ooool01?ooool00ol0[_ooooooooooo`04ooooo`?o0?n31Oooool0
0ol0m_ooooooooooo`04ooooo`03o`1<oooooooooooo00[ooooo00?o0<coooooooooool02Oooool2
o`3oc2?ooooo0_lJ0?l3ooooo`;o02ko3oooool2o`23o`;o0>[o2Oooool3o`3o8S7ooooo0ol0om8e
ooooo`Ko0?mmA_ooool005?ooooo00?o0000ooooooooool0W_ooool00ol0Voooooooo`3o`002oooo
o`?o0:7o1?ooool2o`3o`0?o0:7o00?o09_oooooooooool07_ooool00ol0XOooooooooooo`03oooo
o`0<o`2Kooooooooooooo`3Zool0ROooooooo`3o`?oooooo0?mmo`3foooooooo06_o0_ooool01?l0
ogOoooooo`1Iool0[_l2ooooo`03o`1<oooooooooooo00?ooooo00Go0?lRo`3o=?l04?ooooooo`0^
o`06ooooo`03o`3om_oooooooooo00;ooooo00Go9P3oooooooooooooooooo`0Xo`04ooooo`03o`3o
>_l0oe;ooooo01;ooooo00?oE`3oooooooooool03oooool00ol0ocCo05;oo`1Bo`03ooooo`03o`2^
oooooooooooo00Oooooo00?o0?mgo`3oPol0oh<00_ooool00ol0m_ooooooooooo`04ooooo`03o`1<
oooooooooooo00cooooo0_l0c?l;ooooo`;o0?o<8oooool2oaX0o`03o`0^oooooooooooo00kooooo
0_l0j_l00ooooooo08?oo`23o`05ooooo`Co0?lR=oooool3o`3odRcooooo1_l0oge<ooooo`00Dooo
ool00ol0003oooooooooo`2Oooooo`03o`2Koooooooo0?o000?o0?o01ol0XOl00ooooooo09_oo`2K
o`0Qooooo`03o`2Qoooooooooooo00Cooooo00Co09_oooooool0j_oo08Wo0_ooool01Ol0ol3o0?mm
o`3foooooooo06_o00?ooooo00Ko0?mgooooool0FOoo0:koooooool0C?l5ooooo`05o`3o8_l0ocCo
013oooooool0;_l01oooool00ol0ooKoooooooooo`02ooooo`04obH0ooooooooooooo`0Xo`Gooooo
00?o0?ljo`3oD_ooool04_ooool00omG0?ooooooooooo`0=ooooo`04o`3o=?ooooooooooooooo`;o
05;o00?oooooo`2^ooooool01oooool01_l0ogOooooooooooooooooo0?n3o`3fo`Kooooo00?o04co
ooooooooool03oooool2o`3<o`_ooooo00?o0?o<ooooooooool07_ooool3o`0^o`04oooooolJ0?oo
6P3ooaX0o`_ooooo0ol0j_l5ooooo`;o08?o0ol0ob8nooooo`Co0?oB8_ooool6o`3oOE;ooooo001C
ooooo`03o`000?oooooooooo0:3ooooo0_l0Vol2ooooo`?o0?o01?ooool2o`2KobCooooo00?o0:7o
ooooooooool01?ooool02ol0Voooooooo`3Zool0ROooooooo`3o`?oooooo0?mmo`3foooooooo06_o
00;ooooo00Ko0?mgooooool0FOoo0:koooooool0C?l5ooooo`06o`3o8_oooooo0?ldo`0@oooooooo
02ko1_ooool00ol0ooKoooooooooo`02ooooo`05obH0ooooooooooooooooool0:?l01Oooool00ol0
oe;oooooooooo`0Booooo`03oeL0oooooooooooo00_ooooo00?o0?ldooooooooool01?ooool00ol0
D_ooooooooooo`06ooooo`03o`3oMooooooooooo00;ooooo00?o0?Koooooool0oh<00_l0oh<2oooo
o`03o`1<oooooooooooo01;ooooo00?o0<coooooooooool02Oooool2o`3oc1cooooo0_l0;_l7oooo
o`?o6P3o1Oooool3o`3Zo`Kooooo0ol0ob800ooooooo08?oo`23o`13ooooo`?o0?oB6Oooool6o`3o
OESooooo001Cooooo`03o`000?oooooooooo0:;ooooo2Ol0VolWooooo`03o`2Qoooooooooooo00?o
oooo00Co09_oooooool0j_oo08Wo0_ooool01Ol0ol3o0?mmo`3foooooooo06_o00;ooooo00Oo0?mg
ooooool0FOoo0:koo`3oSooooooo04co00Gooooo00Go0?lRo`3o=?l04?ooooooo`0^o`07ooooo`05
o`3om_oooooooooooooooolV0?l00oooool00ol0:?ooooooooooo`04ooooo`03o`3oD_oooooooooo
01;ooooo00?oE`3oooooooooool02Oooool00ol0ocCoooooooooo`04ooooo`04o`2^oooooooo05;o
o`1Bo`Gooooo00?o0?mgooooooooool00oooool00ol0m_ooooooooooo`02ooooo`;o04co5_ooool2
o`3<o`_ooooo0_l0ol`Gooooo`?o02ko3?ooool3oaX0o`;o0>[o1Oooool4o`3o8PKooooo0_l0Pom4
ooooo`?o0?oB4?ooool6o`3oOA[ooooo2Ol0okXkooooo`00Doooool00ol0003oooooooooo`3Coooo
o`03o`2Qoooooooooooo00?ooooo00?o09_oo`3Zool0ROl00_ooool01Ol0ol3oooooo`3foooooooo
06_o00?ooooo00Ko0?mgooooool0FOoo0:koooooool0C?l5ooooo`05o`3o8_l0ocCo013oooooool0
;_l01oooool00ol0ooKoooooooooo`02ooooo`04obH0ooooooooooooo`0Xo`Oooooo00?o0?mBoooo
ooooool04_ooool00omG0?ooooooooooo`07ooooo`03o`3o=?oooooooooo00Gooooo00Co0:kooooo
oooooooooooo0_l0D_l2ooooo`03o`3oMooooooooooo00?ooooo00?o0?Koooooooooool00_ooool0
0ol0C?ooooooooooo`03o`3oPaGooooo0_l0c?l;ooooo`;o0?o<4_ooool3o`0^o`oooooo0ol0j_l3
oaX0o`Co0?lR3?ooool2o`23odGooooo1?l0om86ooooo`Ko0?mm5Oooool;o`3o^TCooooo001Coooo
o`03o`000?oooooooooo0=?ooooo00?o0:7oooooooooool00oooool01?l0Voooooooo`3Zool0ROl2
ooooo`05o`3o`?l0oggo0?Koooooool0Jol00_ooool01_l0ogOoooooo`1Iool0[_oo0?n?o`1<o`Ko
oooo00Co0?lRo`3o=?l04?oo02ko2?ooool01Ol0ooKooooooooooooooooo9P3o00?ooooo00?o02So
ooooooooool01Oooool2o`3oDQ?ooooo00?oE`3oooooooooool01_ooool00ol0ocCoooooooooo`04
ooooo`03o`2^oooooooooooo00Cooooo00?o05;oo`3oMoooool01?ooool00ol0m_ooooooooooo`02
ooooo`03o`1<oooooooooooo00Cooooo0_l0oh<Eooooo`03o`3<oooooooooooo00[ooooo0_l0ol`>
ooooo`;o02ko3oooool3o`3Zo`Go0?lR00CooooooaX0oolJ0?oo6P3o3oooool2o`23odOooooo0ol0
om83o`3oOA7ooooo2_l0okY?ooooo`00Doooool00ol0003oooooooooo`3Dooooo`03o`2Qoooooooo
oooo00?ooooo00?o09_oo`3Zool0ROl00_ooool01Ol0ol3o0?mmo`3foooooooo06_o00;ooooo00Oo
0?mgooooool0FOoo0:koo`3oSooooooo04co00Gooooo00Go0?lRo`3o=?l04?ooooooo`0^o`07oooo
o`03o`3om_oooooooooo00;ooooo00Co9P3ooooooooooooo02So2?ooool00ol0oc[o0?mBooooo`0B
ooooo`;oE`3o1Oooool00ol0ocCoooooooooo`05ooooo`03o`2^oooooooooooo00Gooooo0_l0D_l3
ooooo`03o`3foooooooooooo00;ooooo00?o04coooooooooool01oooool2o`3oPaCooooo0_l0c?l<
ooooo`?o0?o<2?ooool3o`0^o`oooooo0_l0j_l3o`3o8PWooooo0olJ0?l>ooooo`;o08?o?oooool6
o`3oO@?ooooo1?l0om88ooooo`So0?njFOooool005?ooooo00?o0000ooooooooool0e?ooool00ol0
XOooooooooooo`03ooooo`03o`2Koooooooo08Wo00?ooooo00Co0?o0o`3foooooooo06_o0oooool0
1_l0ogOoooooo`1Iool0olKo0?n?o`1<o`Kooooo00Co0?lRo`0@oooooooo02ko2?ooool01Ol0ooKo
oooooooooooooooo9P3o00?ooooo00?o02Soooooooooool01_ooool00ol0oc[o0?mBooooo`0Coooo
o`05oeL0ooooooooooooooooool0oc@01oooool00ol0[_ooooooooooo`05ooooo`03o`3oMooooooo
oooo00;o05;o00?oooooo`3fooooool00_ooool00ol0C?ooooooooooo`0:ooooo`?o0?n34oooool2
o`3<o`gooooo0_l0ol`4ooooo`;o02ko3_ooool01Ol0ob;o0>[oo`3Zool0j_oo0?lR013ooooo1?lJ
0?l<ooooo`;o08?o=oooool6o`3oO@gooooo1?l0om84o`3o^V7ooooo001Cooooo`03o`000?oooooo
oooo0=Gooooo00?o0:7oooooooooool00oooool00ol0Vooo0>[oo`29o`02ooooo`05o`3o`?l0oggo
0?Koooooool0Jol00_ooool01_l0ogOoooooo`1Iool0[_oo0?n?o`1<o`Kooooo00Co0?lRo`3o=?l0
4?oo02ko2?ooool00ol0ooKoooooooooo`02ooooo`04obH0ooooooooooooo`0Xo`Wooooo00?o0?lj
o`3oD_ooool04oooool2oeL0o`03o`3o=?oooooooooo00Kooooo00?o0:koooooooooool01?ooool0
0ol0ogOoooooooooo`03ooooo`05o`1Booooooooooooooooool0C?l04?ooool2o`3oPa?ooooo00?o
0<coooooooooool03?ooool01?l0olco02koo`0^ool0;_l<ooooo`;o0?lR0ol0j_lHooooo`Co6P3o
2_ooool2o`23oboooooo1_l0ogd<ooooo`So0?nj0oooool3o`3odV;ooooo001Cooooo`03o`000?oo
oooooooo0=Gooooo00?o0:7oooooooooool00oooool00ol0Vooo0>[oo`29o`02ooooo`05o`3o`?oo
oooo0?Koooooool0Jol00_ooool01ol0ogOoooooooooool0FOoo0?n?ooooool0C?l01_ooool01?l0
ob;o013oooooool0;_l8ooooo`05o`3om_oooooooooooooooolV0?l00oooool00ol0:?oooooooooo
o`08ooooo`03o`3oD_oooooooooo01;ooooo00?o0?ldoeL0ooooool01_ooool00ol0[_oooooooooo
o`04ooooo`03o`3oMooooooooooo00?ooooo00Go0?Koooooool0D_oo05;oo`1<o`0Cooooo`;o0?n3
4_ooool2o`3<o`[ooooo0ol0;_l00ooooooo0?o<o`3oc007ooooo`Go0?lR0_l0j_lOooooo`Go6P3o
1oooool2o`23obOooooo1_l0ogd:ooooo`So0?nj3_ooool4o`3odUkooooo000Xooooo`03omgMgOmE
EEGo000000;o000000?oEEEEomgMgOooool01Oooool00omgMgOo0000ogMgM`06ooooo`03omgMgOmg
MgOo<S8b00?o000000?o<S8bofIVI_oMgMd03?ooool00ol0003oooooooooo`3Fooooo`03o`2Qoooo
oooooooo00?ooooo00?o09_oo`29ooooool00_ooool01?l0ol3o0?Koooooool0Jol3ooooo`06o`3o
Mooooooo05Woo`3oa_l0ohoo04co1_ooool01?l0ob;o013oooooool0;_l9ooooo`05o`3om_oooooo
oooooooooolV0?l00_ooool00ol0:?ooooooooooo`09ooooo`;o0?mB00?o0?ljooooooooool03_oo
ool00ol0ocCoooooooooo`02oeL0o`Cooooo00?o0:koooooooooool01?ooool00ol0ogOooooooooo
o`04ooooo`04o`3fooooooooooooo`1<o`;o05;o5?ooool2o`3oPa;ooooo0_l0c?l5ooooo`?o02ko
1_ooool2o`3oc0Go0?lR0oooool2o`3ZobKooooo1OlJ0?l4ooooo`;o08?o8?ooool5o`3oO@Sooooo
2?l0okXJooooo`Co0?oBF_ooool002Oooooo00Woc<c<o`000?l0003o^[ZjoooooooMgMgo8B4Qo`00
0?o<c<`01Oooool3o`0000Gooooo00SoV9RHo`000?l0003oA4A4olc<c?ooooook^k^ohN7Q`;o0000
00?oV9RHooooooooool02Oooool00ol0003oooooooooo`3Fooooo`03o`2Qoooooooooooo00?ooooo
00?o09_oo`3Zool0ROl00_ooool01Ol0ol3oooooo`3foooooooo06_o00;ooooo00Ko0?mgooooool0
FOoo0:koo`3oSol0C?l6ooooo`04o`3o8_oooooo013oo`0^o`Wooooo00Go0?ofoooooooooooooooo
obH0o`03ooooo`03o`0Xoooooooooooo00[ooooo00?o0?mBo`3o>_ooool03Oooool00ol0ocCooooo
ooooo`03ooooo`;oE`3o0_ooool00ol0[_ooooooooooo`04ooooo`03o`3oMooooooooooo00?ooooo
00Co0?Kooooooooooooo04co0oooool00ol0D_ooooooooooo`0Cooooo`;o0?n34_ooool00ol0c?oo
ooooo`0^o`02o`0^o`Oooooo1?l0ob83o`3oc0;ooooo0ol0j_l]ooooo`Ko6P3o0ol0PolGooooo`Ko
0?mm1_ooool7o`3o^RKooooo0ol0om9Gooooo`009_ooool01?oMgMgo0000o`000?nj^[X3ooooo`04
onk^k_l0003o0000onk^kPCooooo00?oMgMgo`000?mgMgL01?ooool01?nYZJWo0000o`000?lb<S85
ooooo`04ohN7Qol0003o0000okZj^P[ooooo00?o0000ooooooooool0e_ooool00ol0XOoooooooooo
o`03ooooo`03o`2Koooooooo08Wo00?ooooo00Co0?o0o`3foooooooo06_o0_ooool01ol0ogOooooo
ooooool0FOoo0?o6o`3oSol0C?l01_ooool01?l0ob;o013oooooool0;_l9ooooo`05o`3om_oooooo
oooooooooolV0?l00_ooool00ol0:?ooooooooooo`0;ooooo`;o0?mB3?ooool00ol0ocCooooooooo
o`06ooooo`03oeL0ool0[_oooooo00Gooooo00?o0?mgooooooooool00oooool01?l0m_oooooooooo
ool0C?l5ooooo`;o05;o5Oooool2o`3oP`gooooo1Ol0;_l00ol0c?ooooooooooo`02ooooo`Go0?lR
1oooool2o`3ZocKooooo1OlJ0?l00ol0Poooooooooooo`0=ooooo`Go0?mm1_ooool6o`3o^S3ooooo
1?l0om9Cooooo`009_ooool00omEEEGo0000ob4Q8@05ooooo`03oeEEEOl0003oEEEE00_ooooo00Co
8B4Qo`000?l0003oZJVY1Oooool01?o^k^ko0000o`000?lQ8B4:ooooo`03o`000?oooooooooo0=Oo
oooo00?o0:7oooooooooool00oooool00ol0Vooo08Woooooo`02ooooo`04o`3o`?l0m_oo0?mmo`1[
o`?ooooo00Ko0?mgooooool0FOoo0?o6o`3oSol0C?l6ooooo`04o`3o8_l04?oo0?ldo`0^o`Wooooo
00Go0?ofooooooooooooooooobH0o`02ooooo`03o`0Xoooooooooooo00gooooo00?o0?mBo`3o>_l0
ocX02?ooool00ol0ocCoooooooooo`08ooooo`;oE`3o1?ooool00ol0ogOoooooooooo`03ooooo`04
o`3fooooooooooooo`1<o`Sooooo00?o05;oooooooooool05?ooool3o`3oP`Kooooo1?l0;_l5oooo
o`03o`3o8_l0c?oo0<co00;o0?lR2_ooool2o`3Zo`;ooooo0_l0ol`iooooo`Wo6P3o0_ooool5o`3o
O@Kooooo1Ol0okXjooooo`Go0?oBC_ooool002Gooooo00CogMgMo`000?l0003oMgMg1Oooool01?n7
QhOo0000o`000?o^k^h:ooooo`?o00001oooool3o`0000[ooooo00?o0000ooooooooool0eoooool0
0ol0XOooooooooooo`03ooooo`03o`2Kool0j_oo08Wo00?ooooo00Co0?o0o`3foooooooo06_o0_oo
ool01_l0ogOoooooo`1Iool0[_oo0?o6o`1<o`Oooooo00Co0?lRo`0@oooooooo02ko2Oooool01Ol0
ooKooooooooooooooooo9P3o00;ooooo00?o02Soooooooooool03Oooool2o`3oDPGo0?lj0_ooool0
0ol0ocCoooooooooo`08ooooo`03o`2^oooooooooooo00;oE`3o00?oooooo`3oMoooool01Oooool0
0ol0m_ooooooo`1<o`0:ooooo`;o05;o5oooool2o`3oP`Co02ko1?ooool5o`3o8P?ooooo0_l0c?l8
ooooo`;o0>[o1_ooool3o`3oc3[ooooo0ol0Pol2o`3oO@Wo6P3o1?l0okY4ooooo`Go0?oBBOooool0
02Gooooo00CoQhN7o`000?l0003o^[Zj1Oooool01?nj^[[o0000o`000?nHV9P:ooooo`?o00001_oo
ool01?nj^[[o0000o`000?l0000:ooooo`03o`000?oooooooooo0=Sooooo00?o0:7oooooooooool0
0oooool00ol0Vooo08Woooooo`02ooooo`04o`3o`?l0m_ooooooo`1[o`;ooooo00Oo0?mgoooooooo
oooo05Woo`3oa_l0ohoo04co00Kooooo00Co0?lRo`0@oooooooo02ko2Oooool01Ol0ooKooooooooo
oooooooo9P3o00;ooooo00?o02Soooooooooool03oooool2o`3oDP?ooooo1ol0ocX5ooooo`03o`2^
oooooooooooo00?ooooo0_mG0?l5ooooo`03o`3foooooooo04co00gooooo00?o05;oooooooooool0
4Oooool5o`0^o`;o0?n31_l0ob8:ooooo`;o0<co1?ooool2o`3Zo`_ooooo0ol0ol`eooooo`Co0?mm
00?oooooo`23ool0Pol00_ooool5o`3o^P;ooooo1_lJ0?m7ooooo`Go0?oBA?ooool002Gooooo00Co
A4A4o`000?l0003oc<c<1Oooool01?oMgMgo0000o`000?mEEED:ooooo`04oeEEEOl0003o0000olc<
c0Cooooo00Gok^k^ob4Q8Ol0003o0000odA4A00:ooooo`03o`000?oooooooooo0=Sooooo00?o0:7o
ooooooooool00oooool00ol0Vooo08Woooooo`03ooooo`03o`3fool0oggo06_o00?ooooo00Ko0?mg
ooooool0FOoo0:koooooool0C?l7ooooo`04o`0@ool0ocCoooooo`0^o`Wooooo00Go0?ofoooooooo
ooooooooobH0o`02ooooo`03o`0Xoooooooooooo013ooooo0_l0oe800ooooooo0?ldooooo`05oooo
o`Go0?lj00?o0:koo`3o>_l0ocX00_l0ocX00ol0ogOo0?ljo`3o>P02oeL0o`;o0?lj00?o0?Koo`3o
>_l0C?l01_l0ocX9ooooo`03o`1Boooooooooooo00_ooooo00?o0?lRo`0^ool0;_l00_l0;_l4o`3o
8P?ooooo0_l0oh<@ooooo`;o0<co0_l0j_l@ooooo`?o0?o<;Oooool5o`3oO@Cooooo0ol0okX3o`23
o`cooooo4_lJ0?ljooooo`Go0?oB1?l0ocXkooooo`009Oooool00olQ8B7o0000o`000007ooooo`;o
000000?o<S8booooooooool02?ooool01?o^k^ko8B4Qo`000?mEEED3ooooo`03omgMgOlQ8B7o0000
00;o000000?oc<c<ooooooooool02?ooool4o`000=Sooooo00?o0:7oooooooooool00oooool00ol0
Vooo08Woooooo`02ooooo`04o`3o`?l0m_ooooooo`1[o`;ooooo00Ko0?mgoooooooooooo05Woo`3o
a_l0C?l7ooooo`04o`3o8_l04?ooooooo`0^o`[ooooo00Oo0?ofooooooooooooooooobH0oooooooo
02So01Cooooo0_l0oe8:ooooo`03o`2^oooooooooooo00?ooooo00?o0?mgooooooooool00_ooool0
1?mG0?oo0?Koooooool0C?l7ooooo`Oo0?lj0oooool2o`1Bo`Kooooo0_l0ob84o`0^o`gooooo0_l0
oh<=ooooo`;o0>[o00?oooooo`3<ool0c?l04oooool3o`3oc2Kooooo1?l0ogd4ooooo`Go0?nj1_oo
ool3o`23oa_ooooo7OlJ0?lBooooo`Go0?lj3olJ0?lkooooo`009Oooool3o`0000Oooooo0ol0000;
ooooo`06onk^k_lb<S;o0000oiRHV?ooooooZJVY1?l000000onHV9Soooooooooo`09ooooo`03o`00
0?oooooooooo0=Wooooo00?o0:7oooooooooool00oooool00ol0Vooo08Woooooo`03ooooo`03o`3f
ool0oggo06_o00;ooooo00Oo0?mgoooooooooooo05Woo`3oa_oooooo04co00Oooooo00Co013oo`3o
=?oooooo02ko2_ooool01?l0ooKooooooooooolV0?l2ooooo`03o`0Xoooooooooooo013ooooo00?o
0?ldooooooooool00ol0oe87ooooo`03o`2^oooooooooooo00;ooooo00?o0?mgooooooooool01?oo
ool2oeL0o`oooooo1Ol0ocX01?l0D_oo0?lRo`3o8_l0ob84o`0^oa?ooooo0_l0oh<9ooooo`;o0>[o
1Oooool00ol0c?ooooooooooo`0Cooooo`?o0?o<7oooool4o`3oO@?ooooo1Ol0okX>ooooo`?o08?o
=OoooolGoaX0o`kooooo00?o0?oBooooooooool0>Oooool002Gooooo0ol00007ooooo`?o00003Ooo
ool00on7QhOo0000odA4A004o`000003olc<c?oooooooooo00[ooooo00?o0000ooooooooool0f_oo
ool00ol0XOooooooooooo`02ooooo`03o`2Kool0ROoooooo00?ooooo00?o0?Koo`3oOOl0Jol00ooo
ool01_l0ogOoooooo`1Iool0[_oo0?o6o`1<o`Oooooo00Co013oo`3o8_l0ocCo02ko2_ooool01Ol0
ooKooooooooooooooooo9P3o00;ooooo00?o02Soooooooooool03_ooool00ol0ocCoooooooooo`04
ooooo`Co0?mB0_ooool00ol0[_ooooooooooo`02ooooo`03o`3oMooooooooooo00Cooooo00?o0?Ko
o`1<ooooool00_mG0?l>ooooo`Co0?lR1?l0;_l3o`3o>QKooooo0_l0oh<5ooooo`;o0>[o2?ooool2
o`3<oaKooooo0ol0ol`Hooooo`Co0?mm0_ooool5o`3o^QKooooo0ol0Pol]ooooo`_o0?ljFoooool0
02Gooooo0ol00007ooooo`?o00003Oooool00onj^[[o410@o`000002o`000003oc8b<_o^k^kooooo
00cooooo00?o0000ooooooooool0f_ooool00ol0XOooooooooooo`03ooooo`03o`2Kool0ROoooooo
00;ooooo00Co0?o0o`3fool0oggo06_o0_ooool01ol0ogOoooooooooool0FOoo0?o6ooooool0C?l0
1oooool01?l04?ooooooo`3o=?l0;_l:ooooo`07o`3om_oooooooooooooooolV0?ooooooo`0Xo`0?
ooooo`03o`3o=?oooooooooo00Wooooo00?o0?mBo`2^ool0oe800_l0oe800ooooooo0?mgooooo`05
ooooo`03o`3fool0C?oooooo00?ooooo0_mG0?l9ooooo`?o0?lR1?l0;_l3ooooo`04o`1Boooooooo
ooooooooo`Go0?lj4oooool2o`3oP`03ooooool0j_oo0>[o00cooooo0_l0c?lGooooo`?o0?o<4_oo
ool3o`3oO@;ooooo1?l0okXNooooo`Co08?o7Oooool<o`3o>VKooooo000Uooooo`?o00001oooool3
o`0000cooooo00?oMgMgo`000?l000000ol000000omEEEGogMgMooooo`0<ooooo`03o`000?oooooo
oooo0=[ooooo00?o0:7oooooooooool00oooool00ol0Vooo08Woooooo`03ooooo`03o`3fool0oggo
06_o00?ooooo00Ko0?mgooooool0FOoo0:koo`3oa_l0C?l7ooooo`04o`0@ool0ob;oooooo`0^o`_o
oooo00Co0?ofoooooooooooo9P3o0_ooool00ol0:?ooooooooooo`0;ooooo`03o`3o=?oooooooooo
00[ooooo00?o0:koooooooooool00_ooool01?l0ogOo0?mBo`3oD_l0oe84ooooo`03o`1<oooooooo
oooo00Gooooo00?oE`3oooooooooool00_ooool3o`3o8PCo02ko2?ooool2o`1Bo`Kooooo1?l0ocX?
ooooo`?o0>[o0_l0oh<>ooooo`;o0<co6?ooool3o`3oc0_ooooo1?l0ogd5o`3o^RKooooo1?l0Pol=
ooooo`co0?ljL_ooool002Gooooo00Co8B4Qo`000?l0003ok^k^1_ooool2o`000003ob4Q8Ooooooo
oooo00Wooooo00GoEEEEo`000?l0003o0000oeEEE@02onk^kP04odA4A?l0003oEEEEonk^kP_ooooo
00?o0000ooooooooool0foooool00ol0XOooooooooooo`03ooooo`03o`2Kool0ROoooooo00;ooooo
00Co0?Koooooool0oggo06_o0_ooool01ol0ogOoooooo`1Iool0[_oo0?o6o`1<ool0ohl01_ooool0
1Ol04?ooooooo`3o8_l0;_oo0?ld00_ooooo00Co0?ofoooooooooooo9P3o0_ooool00ol0:?oooooo
ooooo`09ooooo`03o`3o=?oooooooooo00_ooooo00Go0:koooooooooooooooooo`3oM`04ooooo`?o
0?mB00?o04coooooooooool01oooool2oeL0o`;o0?lR0ol0;_l>ooooo`03o`1Boooooooooooo00Oo
oooo0ol0ocX:ooooo`;o0>[o1Oooool2o`3oP`kooooo0_l0c?lIooooo`?o0?o<1?ooool4o`3oO@Co
0?nj;oooool3o`23o`[o0?ljO_ooool002Gooooo00CoA4A4o`000?l0003o^[Zj1Oooool01?nj^[[o
0000o`000?mEEED:ooooo`05ogMgMol0003o0000o`000?nHV9P01?ooool01?lb<S;o0000ob4Q8Oo^
k^h:ooooo`03o`000?oooooooooo0=_ooooo00?o0:7oooooooooool00oooool00ol0Vooo08Wooooo
o`03ooooo`03o`3fool0oggo06_o00?ooooo00Ko0?mgooooool0FOoo0:koo`3oa_l0C?l7ooooo`05
o`0@ool0ob;oooooo`0^ool0oc@02_ooool01ol0ooKooooooooooooooooo9P3oooooool0:?l02Ooo
ool2o`3o=0gooooo00?o0:koooooooooool00_ooool00ol0ogOoooooooooo`04ooooo`03o`1<oooo
oooo0?mB00Co0?mB0_ooool3o`3o8P03o`0^oomG0?ooE`3o01;ooooo0_l0D_l:ooooo`Go0?lj0ooo
ool2o`3Zo`Wooooo0_l0oh<>ooooo`;o0<co6_ooool4o`3oc0Co0?nj:Oooool;o`3o>P;ooooo1?l0
Pon4ooooo`009Oooool01?n7QhOo0000o`000?nYZJT5ooooo`04okZj^_l0003o0000oiRHV0[ooooo
00Co410@o`000?l0003oMgMg1Oooool01?o<c<co0000o`000?mEEED:ooooo`03o`000?oooooooooo
0=cooooo00?o0:7oooooooooool00oooool00ol0ROooooooooooo`02ooooo`03o`3foooooooo06_o
00?ooooo00Oo0?mgooooool0FOoo0:koo`3oa_l0C?oo0?n?00Kooooo00Go013oooooool0ob;o02ko
o`3o=00;ooooo`04o`3om_ooooooooooobH0o`;ooooo00?o02Soooooooooool01Oooool00ol0ocCo
ooooooooo`0<ooooo`03o`2^oooooooooooo00;ooooo00?o0?mgooooooooool01?ooool00ol0C?oo
ooooooooo`04ooooo`03o`3o8_l0oe;o0?mB00?o02ko0oooool2oeL0oa;ooooo00?o05;ooooooooo
ool03?ooool3o`3Zo`?o0?lj2_ooool3o`3oP`gooooo0_l0c?lDooooo`?o0?mm1Ol0okX3o`3oc1Wo
oooo4Ol0ocXAooooo`Co08?oP?ooool002Gooooo00CogMgMo`000?l0003oIVIV1Oooool01?mgMgOo
0000o`000?o^k^h:ooooo`?o000000?ogMgMooooooooool01?ooool3o`0000[ooooo00?o0000oooo
ooooool0g?ooool00ol0XOooooooooooo`03ooooo`03o`2Kool0ROoooooo00;ooooo00Co0?Koo`3o
`?l0oggo06_o0oooool01_l0ogOo05Woo`2^ool0olKo04coo`3oS`Kooooo00Ko013ooooooooooooo
0?lRo`0^ool0oc@;ooooo`04o`3om_ooooooooooobH0o`;ooooo00?o02Soooooooooool00_ooool2
o`3o=0kooooo00?o0:koooooooooool00_ooool00ol0ogOoooooooooo`04ooooo`03o`1<ool0m_oo
oooo00;ooooo0ol0ob800ooooooo02koo`0^o`03ooooo`Go0?mB00?oE`3oooooooooool04?ooool0
0ol0D_ooooooooooo`09ooooo`;o0>[o1_ooool<o`3o>P04ooooool0oh?o0?n3o`3oP`cooooo0ol0
c?l=ooooo`?o0?mm1?l0okX8ooooo`Co0?o<5Ol0ocXVooooo`Co08?oO?ooool002Kooooo00?oEEEE
o`000?lQ8B401Oooool00olQ8B7o0000oeEEE@0;ooooo`03oa0@4?l0003o000000Kooooo00Cok^k^
o`000?l0003o00002_ooool00ol0003oooooooooo`3Mooooo`03o`2Qoooooooooooo00;ooooo00?o
09_oo`29ooooool00oooool00ol0m_oo0?mmo`1[o`03ooooo`07o`3oMooooooo05Woo`2^ool0olKo
04coo`3oS`06ooooo`05o`0@ooooooooooooo`3o8_l0;_l00_l0oc@:ooooo`06o`3om_oooooooooo
obH0oooooooo02So0oooool00ol0ocCoooooooooo`0>ooooo`05o`2^ooooooooooooooooool0ogL0
1_ooool01?l0C?oo0?Koooooooooool2o`3o8P;ooooo0_l0;_l:ooooo`03o`3oD_mG0?ooE`3o017o
oooo0_l0D_l7ooooo`;o0>[o5?ooool4o`3o>P?o0?n31Ol0ocX7ooooo`?o0<co1oooool3o`3oO@?o
0?nj3_l0ocX2ooooo`Co0?o<>oooool5o`23ogOooooo000Vooooo`04omgMgOl0003o0000okZj^P?o
oooo00Co^[Zjo`000?l0003ok^k^2oooool01?nYZJWo0000o`000?n7QhL5ooooo`04ogMgMol0003o
0000ogMgM`[ooooo00?o0000ooooooooool0gOooool00ol0XOooooooooooo`03ooooo`03o`29ool0
j_oooooo00;ooooo00Co0?Koooooool0oggo06_o0_ooool01ol0ogOoooooo`1Iool0[_oo0?o6o`1<
ool0ohl01_ooool02?l04?oooooooooooooooooo0?lRo`0^oooooooo0?ld2_ooool01_l0ooKooooo
oooooolV0?ooooooo`0Xo`;o0?ld4?ooool01Ol0[_oooooooooooooooooo0?mg00Kooooo00?o04co
o`3fool0ob800_l0ob82ooooo`;o02ko3oooool2oeL0o`03o`3oD_oooooooooo00kooooo00Co05;o
oooooooooooooooo0ol0j_lMooooo`?o0?n30_ooool:o`3o>P?o0<co1?l0ogd3o`3o^QOooooo0ol0
ol`mooooo`Co08?oLoooool002Oooooo00Ko^[Zjo`000?l0003o^[Zjoooooonj^[X2o`000003olc<
c?oooooooooo00_ooooo00SoV9RHo`000?l0003oQhN7onk^k_oooooogMgMogMgM`;o000000?oEEEE
ooooooooool02Oooool00ol0003oooooooooo`3Mooooo`03o`2Qoooooooooooo00?ooooo00?o09_o
o`29ooooool00_ooool01?l0m_oo0?o0o`3oOOl0Jol3ooooo`07o`3oMooooooo05Woo`2^ool0olKo
04coo`3oS`05ooooo`03o`0@oooooooooooo00;ooooo00?o02koooooooooool00_l0oc@9ooooo`;o
0?of00CoooooobH0ool0ocCo02So4?ooool01Ol0[_oooooooooooooooooo0?mg00Kooooo00?o04co
o`3fool0ob800oooool2o`0^oa?ooooo00CoE`3oo`3oD_l0oe;o0?mB3_ooool2o`1Bo`03o`3Zoooo
oooooooo027ooooo1?l0oh<7ooooo`Co0?mm0ol0c?l00ol0ok[oooooooooo`0Kooooo`Go0?o<??oo
ool4o`23ofoooooo000Xooooo`03omgMgOmEEEGo000000;o000000?oEEEEomgMgOooool03_ooool0
0oo^k^koQhN7oc8b<P03o`000003oa0@4?mEEEGo^[Zj00cooooo00?o0000ooooooooool0g_ooool0
0ol0XOooooooooooo`03ooooo`03o`29oooooooooooo00;ooooo00?o0?Koooooool0Jol00oooool0
2?l0ogOoooooo`1Iool0[_oo0?o6o`1<oooooooo0?n?1Oooool01_l04?oooooooooooooooooo0?lR
o`0^o`?ooooo0_l0oc@7ooooo`;o0?ld00Go0?ofoooooolV0?ooooooo`0Xo`0?ooooo`04o`2^oooo
ooooooooo`3oM`Kooooo00?o04coo`3o8_l0m_l00_ooool2o`0^oaKooooo0_mG0?l01?oooooo0?mB
o`3oD_l0oe8:ooooo`;o0>[o00?oooooo`1Booooool09_ooool5o`3oP`;o0?mm00Coooooo`3o^_l0
ok[o0?nj0oooool3o`3<ob3ooooo1Ol0ol`kooooo`Go08?o8_ooool6obH0o`OoE`3o>oooool005?o
oooo00?o0000ooooooooool0g_ooool00ol0XOooooooooooo`03ooooo`03o`2Kool0ROoooooo00;o
oooo00Co0?Koo`3o`?l0oggo06_o0oooool01ol0ogOoooooo`1Iool0[_oo0?o6o`1<ool0ohl01Ooo
ool00ol04?ooooooooooo`02ooooo`03o`3o8_l0;_oooooo00?ooooo1ol0oc@3ooooo`05o`3om_oo
oooo9P3oobH0ool0:?l03Oooool01Ol0[_oooooooooooooooooo0?mg00Cooooo00Go0?lRo`1<oooo
oooo0?Koooooo`02o`0^oa[ooooo0_mG0?l2ooooo`?o0?mB1Oooool2o`3Zo`Cooooo0_l0D_lToooo
o`Co0?mm0_ooool3o`3o^P;o0?n31oooool3o`3<ob;ooooo1Ol0ol`kooooo`Go08?o1_oooolBobH0
o`_oE`3o@_ooool005?ooooo00?o0000ooooooooool0goooool00ol0XOooooooooooo`03ooooo`08
o`29ooooooooooooooooool0m_oo0?o0ooooool0Jol3ooooo`08o`3oMooooooo05Woo`2^ool0olKo
ooooo`1<ool0ohl5ooooo`03o`0@oooooooooooo00;ooooo00?o0?lRo`0^ooooool03Oooool01Ol0
ooKooooooooooolV0?oo02So00_ooooo00Go0:koooooooooooooooooo`3oM`02ooooo`?o0?lR00?o
04coooooool0m_l00_l0;_lNooooo`;oE`3o0oooool3o`3oDP;o0>[o2?ooool2o`1Boakooooo1?l0
ogd3ooooo`?o0?nj1Oooool4o`3oP`Kooooo0ol0c?lTooooo`Go0?o<;ooooolBobH0o`Kooooo3?mG
0?m=ooooo`00Doooool00ol0003oooooooooo`3Oooooo`03o`2Qoooooooooooo00?ooooo00?o08Wo
o`3Zooooool00_ooool01?l0m_oo0?o0o`3oOOl0Jol3ooooo`07o`3oMooooooo05Woo`2^ool0olKo
04coo`3oS`05ooooo`03o`0@oooooooooooo00?ooooo00?o02koo`3o8_ooool03Oooool00ol0ooKo
ooooooooo`03obH0o`Sooooo00Go0:koooooooooooooooooo`3oM`03o`3o8P04ooooool0C?oo04co
ooooo`;o02ko8_ooool3oeL0o`?o0>[o1?l0oe88ooooo`03o`1Boooooooooooo01Oooooo1?l0ogd3
ooooo`Co0?nj3?ooool5o`3oP`Cooooo0ol0c?lVooooo`Go0?o<7_ooool<obH0o`_ooooo3OmG0?mI
ooooo`00Doooool00ol0003oooooooooo`3Pooooo`03o`2Qoooooooooooo00;ooooo00?o09_oo`29
ooooool00_ooool01?l0m_oo0?o0ooooool0Jol3ooooo`08o`3oMooooooo05Woooooool0[_oo0?o6
o`1<ool0ohl5ooooo`03o`0@oooooooooooo00?ooooo00?o02koo`3o8_ooool03Oooool2o`3omP?o
oooo0_lV0?l5ooooo`06o`2^ooooooooooooooooool0ogOo0?lR0oooool01Ol0C?ooooooo`0^ool0
;_oo0?Ko02Cooooo0_l0j_l2oeL0o`Gooooo1?l0oe85ooooo`;o05;o4oooool4o`3oO@?ooooo1?l0
okXEooooo`Go0?n30_ooool4o`3<obOooooo1Ol0ol`=ooooo`co9P3o2oooool<oeL0o`gooooo1_l0
Pol=ooooo`_o08Wo>oooool005?ooooo00?o0000ooooooooool0h?ooool00ol0XOooooooooooo`03
ooooo`09o`29ool0j_ooooooooooool0m_oo0?o0ooooool0oggo06_o00?ooooo00So0?mgo`1Ioooo
oooo0:koo`3oa_l0C?ooooooo`3oS`Gooooo00?o013oooooooooool00oooool00ol0;_oo0?lRo`3o
8P0>ooooo`06o`3om_ooooooooooooooool0:?oo9P3o0oooool01Ol0[_ooooooo`3o8_l0ob;o0?mg
00Cooooo0ol0;_l00ooooooo0?Koooooo`0Rooooo`;o0>[o1?ooool2oeL0o`Oooooo0ol0oe84oooo
o`03o`1Boooooooooooo00cooooo1?l0ogd3ooooo`Co0?nj7_ooool5o`3oP`03ooooool0c?oo0<co
00;o0<co:?ooool2o`3oc0_o9P3o3?ooool;oeL0oa3ooooo3ol0ROl7o`23o`Ko08WoA_ooool005?o
oooo0ol0003Qooooo`03o`2Qoooooooooooo00;ooooo00?o08Woo`3Zooooool00_ooool01?l0m_oo
0?o0ooooool0Jol4ooooo`07o`3oMol0FOooooooo`2^ool0olKo04coo`3oS`05ooooo`03o`0@oooo
oooooooo00Cooooo0_l0;_l2o`3o8Pgooooo0_l0ooH2ooooo`03o`0XoolV0?oo9P3o00?o9P3o00?o
ooooo`3oMoooool00_ooool2o`0^o`?ooooo00?o0?Koooooooooool08?ooool2o`3Zo`Sooooo0_mG
0?l8ooooo`Co0?mB00?oooooo`1Bool0D_l01oooool5o`3oO@?ooooo1?l0okXWooooo`Go0?n31?l0
c?lLooooo`[o9P3o1?ooool5o`3oc0;ooooo3?mG0?l9oooooa;o08Wo5_ooool7o`23odGooooo001C
ooooo`03o`000?oooooooooo0>7ooooo00?o0:7oooooooooool00oooool01_l0ROoo0?njoooooooo
oooo0?Koo`3o`0;ooooo00co06_oooooooooooooooooo`3oMol0FOooooooo`2^ool0olKo04cooooo
ool0ohl5ooooo`03o`0@oooooooooooo00Gooooo00Co02koooooool0ob;o0?lR3Oooool02?l0ooKo
ooooooooool0:?oo0:koo`3o8_oooooo0?mg0olV0?l2o`0^o`05o`1<ooooooooooooooooool0m_l0
8Oooool2o`3Zo`cooooo0omG0?l9ooooo`?o0?mB0_l0D_l5o`3oO@Cooooo1?l0okXaooooo`?o0?n3
1?l0c?l@ooooo`So9P3o2_ooool;oeL0o`Co0?o<0_ooool?o`29oboooooo1ol0Polnooooo`00Dooo
ool00ol0003oooooooooo`3Rooooo`03o`2Qoooooooooooo00;ooooo00?o08Woo`2Kooooool00_oo
ool01?l0m_oo0?o0ooooool0Jol4ooooo`07o`3oMol0FOooooooo`2^ool0olKo04coo`3oS`05oooo
o`03o`0@oooooooooooo00Kooooo00?o02koooooooooool00ol0ob8;ooooo`;o0?of00Go0:koo`0X
ool0:?oo0?mgooooo`03o`0^o`Ko9P3o7oooool3o`3Zoa7ooooo0omG0?l5ooooo`Go0?mm00Co0?mB
o`1Bool0D_oo05;o0_ooool4o`3o^Scooooo1?l0c?l3o`3oP`03oooooolV0?oo9P3o00Ko9P3o00?o
oooooeL0oomG0?l03omG0?l9ooooo`So08Wo1?l0ola1ooooo`?o08?o>oooool005?ooooo00?o0000
ooooooooool0h_ooool00ol0XOooooooooooo`03ooooo`03o`29ool0ok[ooooo00;ooooo00Co0?Ko
oooooooooooo06_o1?ooool01ol0FOooooooo`2^oooooooo0?o6o`1<ool0ohl01Oooool00ol04?oo
ooooooooo`06ooooo`;o02ko0oooool;o`3o8P07ooooool0[_oo0?ofo`3om_l0;_oo02Soo`0^o`02
ooooo`03o`1<oooooooooooo00;ooooo00?o0?KooooooolV0?l01_lV0?lFooooo`;o0>[o5_ooool0
1?l0oggoE`3ooeL0oomG0?l2o`3oO@Oooooo0_l0okX2o`1Bo`03o`3oD_oooooooooo03cooooo4_mG
0?lCooooo`Oo08Wo3?ooool6o`3oc7Wooooo001Cooooo`03o`000?oooooooooo0>?ooooo00?o0:7o
ooooooooool00_ooool00ol0ROoo09_oooooo`02ooooo`04o`3fool0ol3oooooo`1[o`Cooooo00So
0?mgo`1Ioooooooo0:koo`3oa_l0C?ooooooo`3oS`Cooooo00?o013oooooooooool02?ooool2o`0^
o`cooooo00Wo0:koo`0^ool0;_oo02koooooool0ooKo02Soo`3om_l0C?l01?ooool00ol0m_oooooo
ooooo`07ooooo`ko9P3o1_ooool2o`3Zoa;ooooo1_l0ogd4ooooo`?oE`3o00?oooooo`3o^_l0okX0
0ol0okX4ooooo`;o05;o0ol0oe8_ooooo`_oE`3o00?o9P3oooooooooool01_ooool5o`3<o`;ooooo
2?l0oh<3ooooo`[o08Wo6Oooool5o`3oc7Cooooo001Cooooo`03o`000?oooooooooo0>?ooooo00?o
0:7oooooooooool00oooool00ol0ROoo0>[oooooo`02ooooo`04o`3fool0ol3oooooo`1[o`Cooooo
00So05Wooooooooooooo0:koo`3oa_l0C?ooooooo`3oS`Cooooo00?o013oooooooooool02Oooool4
o`0^o`Kooooo0ol0;_l00ooooooo0?mgooooo`03ooooo`06o`0Xool0ooKo0?ofo`3om_oooooo0?Ko
6?ooool5obH0o`03o`3Zoooooooooooo00gooooo1Ol0ogd9ooooo`Co0?nj1_mG0?l6ooooo`?o05;o
1?l0oe8Rooooo`WoE`3o1OlV0?lDooooo`03o`3<ool0ROoo08Wo00[o08Wo1Ol0oh<Sooooo`Ko0?o<
K_ooool005?ooooo00?o0000ooooooooool0i?ooool00ol0XOooooooooooo`02ooooo`03o`29ool0
Vooooooo00;ooooo00Co0?Koooooool0ol3o06_o1Oooool01ol0FOooooooooooool0[_ooooooo`1<
ool0ohl01Oooool00ol04?ooooooooooo`0<ooooo`Ko02ko00Co0:koooooool0ogOo0?mg0oooool2
o`1<o`05ooooool0:?oo02Soooooool0m_l00_l0ooHIooooo`;o0>[o00?oooooobH0oolV0?l00olV
0?l6ooooo`Go0?mm2_ooool4o`3o^P[ooooo1_mG0?l3ooooo`?o05;o00?oooooo`3oD_l0oe801?l0
oe8Fooooo`KoE`3o1olV0?lCooooo`Wo08Wo1?ooool4o`3<o`Wooooo2?l0oh<Qooooo`Oo0?o<Iooo
ool005?ooooo00?o0000ooooooooool0i?ooool00ol0XOooooooooooo`03ooooo`03o`29ool0Vooo
oooo00;ooooo00Co0?Koooooool0ol3o06_o1Oooool01ol0FOooooooooooool0[_ooooooo`1<ool0
ohl01?ooool00ol04?ooooooooooo`0Aooooo`03o`2^oooooooo0?mg00Cooooo00?o04cooooooooo
ool00oooool2o`0Xo`;ooooo0ol0ooHDooooo`;o0>[o2?ooool4obH0o`;o0?mm2_ooool5o`3o^QCo
oooo8omG0?l5obH0oaKooooo1Ol0ROlAooooo`Go0<co3?ooool7o`3oPb7ooooo2?l0olaOooooo`00
Doooool00ol0003oooooooooo`3Uooooo`03o`2Qoooooooooooo00?ooooo00?o08Woooooooooool0
0_ooool01?l0m_oo0?o0o`1[ool0ogd4ooooo`08o`1Iool0ogOoooooooooool0[_ooooooo`1<ool0
ohl4ooooo`03o`0@oooooooooooo00kooooo0_l0[_l00ooooooo0?mgooooo`02ooooo`;o04co1Ooo
ool01?l0m_ooooooooooool0:?l4ooooo`?o0?of3oooool2o`3Zo`Oooooo1?l0ogd3ooooo`Go9P3o
0oooool4o`3o^R;ooooo0ol0D_l=ooooo`Oo9P3o1ol0oe8Aooooo`Ko08Wo6oooool5o`3<o`kooooo
2_l0oh<Oooooo`So0?o<Eoooool005?ooooo00?o0000ooooooooool0iOooool00ol0XOoooooooooo
o`03ooooo`03o`29ool0Vooooooo00;ooooo00Go0?Koooooool0ol3o06_oo`3oO@04ooooo`04o`1I
ool0ogOoooooooooo`;o0:ko00?o04coo`3oSoooool00oooool00ol04?ooooooooooo`0<ooooo`04
o`2^ooooooooooooo`3oM`?ooooo00?o04coooooooooool01?ooool00ol0m_ooooooooooo`02oooo
o`;o02So1Oooool4o`3omPWooooo0_l0j_l5ooooo`Co0?mm2_ooool2o`3o^PKo9P3o9_ooool3o`1B
o`?ooooo1olV0?l>ooooo`_o0?mB00?oooooo`29ool0ROl00ol0ROlVooooo`Go0<co4oooool;o`3o
Pacooooo2_l0ola=ooooo`00Doooool00ol0003oooooooooo`3Vooooo`03o`2Qoooooooooooo00?o
oooo00?o08Woo`3Zooooool00_ooool01?l0m_ooooooo`3o`?l0Jol5ooooo`06o`1Ioooooooooooo
o`3oa_oooooo0:ko0_l0C?l3ooooo`03o`0@oooooooooooo00[ooooo0_l0[_l2ooooo`03o`3oMooo
oooooooo00;o04co1_ooool00ol0m_ooooooooooo`05ooooo`?o02So1_ooool4o`3omP;ooooo0ol0
j_l4ooooo`?o0?mm2Oooool5o`3o^PSooooo2_lV0?lMooooo`Go9P3o00?o05;oooooooooool06Ooo
ool5o`29ob;o0?mB3_ooool6o`3<oaSooooo4_l0oh<Dooooo`_o0?o<@_ooool005?ooooo00?o0000
ooooooooool0ioooool00ol0XOooooooooooo`02ooooo`03o`29ool0Vooooooo00;ooooo00Go0?Ko
oooooooooooo06_oo`3oO@04ooooo`05o`1Iool0ogOo0?mgooooool0olH00_ooool00ol0[_oo04co
o`1<o`02ooooo`03o`0@oooooooooooo00Sooooo00?o0:koooooooooool00_l0ogL2ooooo`03o`1<
oooooooooooo00Cooooo0_l0m_l;ooooo`;o02So2?ooool2o`3Zo`04o`3om_ooooooooooooooo`?o
0?mm2?ooool4o`3o^QOooooo7OlV0?l6ooooo`Co05;o4_ooool5o`29obOooooo5?l0oe85o`3<obGo
0?mB4_l0oh<=o`3oDPOo0?o<>oooool005?ooooo00?o0000ooooooooool0ioooool00ol0XOoooooo
ooooo`03ooooo`03o`29ool0Vooooooo00;ooooo00Go0?Koooooool0ol3o06_oo`3oO@04ooooo`05
o`1Ioooooooo0?mgo`3oMol0olH00_ooool00ol0[_oo0?n?o`1<o`02ooooo`03o`0@oooooooooooo
00Gooooo0_l0[_l3o`3oM`;ooooo0_l0C?l6ooooo`03o`3foooooooooooo00gooooo0ol0:?l3oooo
o`;o0>[o0_ooool00ol0oggo0?ofo`3omP02o`3omPGooooo1Ol0okY2ooooo`Co05;o2Oooool5o`29
odGooooo1ol0c?l`ooooo`_o0?n3A?ooool005?ooooo00?o0000ooooooooool0j?ooool00ol0XOoo
ooooooooo`02ooooo`03o`29ool0Vooo0?nj00?ooooo00Go0?Koooooool0ol3o06_oo`3oO@04oooo
o`05o`1Iooooooooooooo`3oMol0olH00_ooool2o`2^o`;o04co00?o013oooooooooool01Ol0[_l0
1?oooooo0?mgooooooooool3o`1<o`Oooooo00?o0?Koooooooooool04Oooool3o`0Xo`04ooooool0
oggo0?mmo`3oO@Gooooo1?l0ooH00ol0ok[oooooooooo`19ooooo`Co05;o1Ol0ROmAooooo`So0<co
<_ooool:o`3o`3_ooooo001Cooooo`03o`000?oooooooooo0>Sooooo00?o0:7oooooooooool00ooo
ool00ol0ROoo09_oo`3o^P03ooooo`05o`3foooooooo06_oooooool0ogd00oooool01ol0FOoooooo
oooooooooooo0?mgo`3oa_l0ogL00_ooool2o`3oS`03o`1<ool04?oo04co00;o04co00?oooooo`1<
ool0C?l01?l0C?l9ooooo`03o`3foooooooooooo017ooooo0_l0j_l2o`3oO@;o02So1Oooool3o`3o
^P?ooooo1?l0ooI7ooooo`Go08Wo0ol0D_mKooooo`So0<co7_ooool<o`3o`003o`3oSooooooooooo
04;ooooo001Cooooo`03o`000?oooooooooo0>Wooooo00?o0:7oooooooooool00oooool00ol0ROoo
09_oo`3o^P03ooooo`05o`3foooooooo06_oooooool0ogd00oooool00ol0FOooooooooooo`02oooo
o`03o`3oa_l0ogOo0?mg00;o0?mg0_l0ohl01Ol04?oo0?mgo`3oMol0C?oo0?mg00gooooo00?o0?Ko
ooooooooool04?ooool2o`3Zo`;o0?mm1?ooool3o`0Xo`;o0?nj2_ooool4o`3omSkooooo1Ol0ROl8
ooooo`Go05;oG_ooool8o`3<o`Gooooo4Ol0ol000ol0ohooooooooooo`1>ooooo`00Doooool00ol0
003oooooooooo`3Zooooo`03o`2Qoooooooooooo00?ooooo00?o08Woo`3o^_ooool00oooool2o`3f
o`04o`1[oooooooo0?mmo`3oO@;ooooo00?o05Woooooooooool00_ooool2o`3oaPCooooo00?o0?n?
o`0@ooooool03Oooool2o`3foa7ooooo0_l0j_l00ol0oggoooooooooo`04ooooo`?o0?nj00?ooooo
o`0Xool0:?l03_ooool4o`3omSCooooo1_l0ROlBooooo`Ko05;oE?ooool<o`3o`0So0<co0ol0ohmL
ooooo`00Doooool00ol0003oooooooooo`3Zooooo`03o`2Qoooooooooooo00?ooooo00?o08Woo`2K
ool0okX01Oooool01?l0m_oo06_oooooooooool2o`3oO@03ooooool0FOoooooo00Cooooo00?o0?o6
ooooooooool00oooool00ol04?ooooooooooo`09ooooo`;o0?Ko4?ooool00ol0oggo0>[oo`3Zo`06
ooooo`?o0?nj1_ooool3o`0Xo`oooooo0ol0ooH[ooooo`Ko08Wo7_ooool7o`1Bod;ooooo2ol0ol0<
o`3oS`Sooooo1ol0c?mHooooo`00Doooool3o`000>_ooooo00?o0:7oooooooooool00oooool00ol0
ROoo09_oo`3o^P05ooooo`03o`3fool0Jooooooo00;ooooo0_l0ogd00ol0FOooooooooooo`03oooo
o`;o0?o61?ooool00ol04?oo0?n?o`3oS`06ooooo`;o0?Ko3oooool2o`3oO@;o0>[o1Oooool3o`3o
^Pcooooo0ol0:?l?ooooo`Co0?of8Oooool6o`29ob_ooooo2?l0D_l^ooooo`co0?o02ol0ohlKoooo
o`[o0<coC_ooool005?ooooo00?o0000ooooooooool0joooool00ol0XOooooooooooo`04ooooo`03
o`29ool0j_oo0?nj00Kooooo00?o06_oooooooooool00_ooool00ol0oggo05Woooooo`05ooooo`03
o`3oa_oooooooooo00;ooooo0_l04?l2o`3oS`;ooooo0_l0m_l>ooooo`?o0?mm00?oooooo`3Zoooo
ool00oooool3o`3o^Q;ooooo0ol0:?l@ooooo`Co0?of5oooool6o`29ocWooooo2?l0D_lJooooo`co
0?o03?l0ohl`ooooo`co0<co@_ooool005?ooooo00?o0000ooooooooool0k?ooool00ol0XOoooooo
ooooo`04ooooo`03o`29ool0j_oo0>[o00Gooooo00?o06_oo`3fool0m_l00oooool00ol0oggo05Wo
o`3oO@05ooooo`;o0?o61?ooool01?l04?ooooooo`3oSol0m_l<ooooo`Co0?mm0_ooool2o`3Zo`;o
oooo0ol0okXHooooo`?o02So4Oooool5o`3omPgooooo1Ol0ROm7ooooo`[o05;o4?l0ol07o`3oSdGo
oooo3ol0XOlkooooo`00Doooool00ol0003oooooooooo`3]ooooo`03o`2Qoooooooooooo00Cooooo
00Co08Woooooool0j_oo0?nj1?ooool00ol0Joooooooo`3fo`04ooooo`04o`1Iool0oggo0?mmo`3o
O@Cooooo00?o0?o6ooooooooool00_ooool00ol04?oo0?Koo`3oS`04o`3oS`;ooooo1_l0ogd4oooo
o`;o0>[o00Coooooo`3o^_l0ok[o0?nj7_ooool3o`0Xoa?ooooo1Ol0ooH8o`29od?ooooo4_l0ol00
0ol0ohoo05;oo`1Bo`09o`1Bob;ooooo;ol0XOm:ooooo`00Doooool00ol0003oooooooooo`3^oooo
o`03o`2Qoooooooooooo00Cooooo00Co08Woooooool0j_oo0?nj1?ooool00ol0Joooooooo`3fo`02
o`3fo`;ooooo00Co05Wooooooooooooo0?mm1?ooool4o`3fo`03ooooool04?oooooo00;ooooo0_l0
ogd3o`3oS`Oooooo0_l0j_l3o`3o^RCooooo0ol0:?lEo`29o`Ko0?of>_ooool;o`3o`0;ooooo3?l0
ohl@ooooo`co05;o5_l0XOmiooooo`00Doooool00ol0003oooooooooo`3_ooooo`03o`2Qoooooooo
oooo00?ooooo00Co09_oo`29oooooooo0>[o0_l0okX3ooooo`;o06_o00?oooooo`3o`?l0m_l00_l0
m_l2o`1Io`Go0?Ko0ol0ogd3o`3oaP03o`0@ool0oggo0?mm00Gooooo1?l0ohl3o`3Zo`;o0?nj7ol0
ohl9o`29o`;ooooo1?l0:?lGooooo`Ko0?of:?ooool<o`3o`003ooooool0ohoo0?n?00[o0?n?5Ooo
oolBo`2Qo`03ooooool0D_oo05;o00Wo05;oQ?ooool005?ooooo00?o0000ooooooooool0l?ooool0
0ol0XOooooooooooo`03ooooo`03o`2Kool0ROoooooo00;o0>[o00?o0?njooooooooool00_ooool0
1?l0Joooooooo`3o`?l0ol03ooooo`03o`1Ioooooooooooo00Sooooo00?o0?o6o`0@ool04?l01_oo
ool3o`3Zo`;o0?nj5Oooool=o`29o`Oooooo2?l0ohl4o`0Xo`Go0?n?5?ooool7o`3omQGooooo3?l0
ol0=o`3oSaGooooo3?l0XOlNoooooaOo05;oKOooool005?ooooo00?o0000ooooooooool0lOooool0
0ol0XOooooooooooo`03ooooo`05o`2Kool0ROoo08Woooooool0j_l00ol0okX2ooooo`;o06_o00?o
ooooo`3o`?ooool00_ooool2o`1Io`_ooooo0_l04?l01?l0olKo0>[oo`3Zool0j_l2o`3o^Q?ooooo
1Ol0ROlPooooo`Go02So6ol0ohl6o`3omPCo0?n?2ol0ol04o`3oSaWooooo4Ol0XOm1oooooa;o05;o
Foooool005?ooooo00?o0000ooooooooool0l_ooool00ol0XOooooooooooo`04ooooo`04o`2Kool0
ROooooooo`3Zo`;ooooo0_l0okX2ooooo`03o`1[oooooooo0?o000;o0?o00_ooool00ol0FOoooooo
ooooo`07ooooo`03o`3o^_l0j_oo0>[o00;o013o1Ol0olH<ooooo`Ko08Wo1OoooolUo`3o`0Ko02So
6ol0ol09o`3omQ;ooooo4Ol0XOmTooooob3o05;o>oooool005?ooooo00?o0000ooooooooool0looo
ool2o`2Qo`Gooooo00Co09_oo`29ool0ROoo08Wo0_l0j_l01?oooooo0?njo`3o^_l0okX2o`1[o`;o
oooo0ol0ol02o`1Io`?ooooo0_l0okX3o`3Zo`Cooooo0ol04?l2ooooo`Ko0?o61_l0ROl7o`3oaPCo
0?o0:oooool6o`0Xoakooooo1_l0ooH<o`2Qo`Go0?ofboooool005?ooooo00?o0000ooooooooool0
mOooool00ol0XOooooooooooo`03ooooo`03o`2Koooooooooooo00;o08Wo1Ol0j_l00ol0ok[o06_o
o`3o^P03o`3o^P;o0?o000?o05Woo`3Zool0j_l00_l0j_l00ol0ol3oooooooooo`07ooooo`?o013o
1Ol0ROl7o`3o`0Kooooo2ol0olHZooooo`Ko02So4_ooool<o`2Qoa7ooooo4_l0ooJiooooo`00Dooo
ool00ol0003oooooooooo`3fooooo`03o`2Qoooooooooooo00?ooooo0ol0Vol01?oooooo08Woo`29
ool0ROl2ooooo`;o0>[o0ol0Jol4o`3Zo`?o05Wo0_ooool7o`3o`0Co08Wo00?oooooo`0@ool04?l0
0_l04?lIooooo`co0?o69?ooool:o`0Xo`So0:7o;ooooolGo`3omZ;ooooo001Cooooo`03o`000?oo
oooooooo0?Oooooo00?o0:7oooooooooool01Oooool2o`2Ko`;ooooo0_l0ROl5ooooo`Ko06_o00Co
ooooo`1Iool0FOoo05Wo0oooool3o`29o`Wooooo1?l04?lQooooo`co0?o64?ooool?o`2Qo`?ooooo
<ol0:?lKooooobCo0?of@ol0:?lkooooo`00Doooool00ol0003oooooooooo`3hooooo`?o0:7o1_oo
ool01?l0Voooooooooooooooool;o`29o`?o06_o00Co08Woo`1Iool0FOoo08Wo4?ooool3o`0@o`?o
oooo=ol0XOm5ooooocoo02So3_l0Joleo`3omS_ooooo001Cooooo`03o`000?oooooooooo0?_ooooo
0ol0XOl4ooooo`?o09_o3_ooool3o`1[o`?o05Wo4Ol0Jol4o`0@o`Ko06_o:OoooolCo`3oaQoooooo
4?l0olHXo`1[oa;o0?o6SOooool005?ooooo00?o0000ooooooooool0o_ooool2o`2Qo`Gooooo0ol0
VolAooooo`Ko05Wo1_l0XOl9ooooo`Ko013o3_l0Jol^oooooaoo0?o61?ooool<o`1[olOooooo001C
ooooo`03o`000?oooooooooo0?oooooo0Oooool5o`2Qo`?ooooo1Ol0Vol5ooooo`[o0:7o0oooool8
o`1Io`gooooo2Ol04?l5oooooaWo06_o8?oooolHo`1[om?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo1_ooool8o`2Qo`So09_o4_ooool<o`1Io`[ooooo2ol04?lCooooob3o06_ojoooool005?o
oooo0ol0003ooooooaKooooo7_l0Vol<o`1Io`Wooooo2Ol04?n8oooooe;o013o>oooool005?ooooo
00?o0000ooooooooool0oooooom0ooooo`co05Wo1Ol0Vol00ooooooo013oo`0@o`08o`0@ocKooooo
00?o09_oo`0@ool04?l0AOl04?lFo`2KogOooooo001Cooooo`03o`000?oooooooooo0?ooooooC?oo
ool9o`1Io`Oo09_o=ol04?n<ooooo`go05Wo>oooool005?ooooo00?o0000ooooooooool0oooooomE
oooooaKo05Wo6OoooonKo`1IodSooooo001Cooooo`03o`000?oooooooooo0?ooooooJooooolIo`1I
on?ooooo001Cooooo`03o`000?oooooooooo0?oooooooooooomXooooo`00Doooool00ol0003ooooo
ooooo`3oooooooooooooJ?ooool005?ooooo00?o0000ooooooooool0ooooooooooooofSooooo001C
ooooo`03o`000?oooooooooo0?oooooooooooomXooooo`00Doooool00ol0003oooooooooo`3ooooo
ooooooooJ?ooool005?ooooo00?o0000ooooooooool0ooooooooooooofSooooo001Cooooo`03o`00
0?oooooooooo0?oooooooooooomXooooo`00Doooool00ol0003oooooooooo`3oooooooooooooJ?oo
ool00?oooooooooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooo
oooooonnooooo`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooooonnoooo
o`00oooooooooooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00oooooooooooookkooooo
003ooooooooooooo__ooool00?Cooooo00?o^[Zjo`000?oMgMd01oooool00omgMgOo<S8booooo`0<
ooooo`03onk^k_n7QhOo<S8b00?o000000?o410@oeEEEOnHV9P02Oooool01Om4A4Coooooolc<c?mV
IVKo8B4Q00;o000000?o410@ofIVI_o^k^h04?ooool00oo^k^koMgMgoc8b<P03o`000003oc8b<_n7
QhOogMgM00Sooooo00OogMgMoeEEEOl0003o0000oa0@4?mEEEGogMgM00Oooooo00?o410@o`000?o<
c<`01Oooool00olQ8B7o0000oiRHV005ooooo`06olc<c?m4A4Co0000o`000?lQ8B7oV9RH1oooool0
1oo<c<coA4A4o`000?l0003o<S8bohN7Qoo^k^h01Oooool00ol@413o0000olc<c005ooooo`03ob4Q
8Ol0003oV9RH00Cooooo00CoQhN7o`000?l@413oQhN71?ooool00ol@413o0000olc<c009ooooo`05
ohN7Qol0003o0000ob4Q8OnHV9P00_ooool01?oMgMgo0000oa0@4?nHV9P4ooooo`04ohN7Qol0003o
410@ohN7Q`Cooooo00Cok^k^oa0@4?l0003oMgMg1Oooool01ooMgMgoEEEEo`000?l0003o410@oeEE
EOoMgMd01oooool00ol@413o0000olc<c005ooooo`03ob4Q8Ol0003oV9RH0=oooooo003dooooo`03
okZj^_l0003oEEEE00Oooooo00?oA4A4o`000?nj^[X02oooool01OnYZJWo0000odA4A?nYZJWok^k^
00;ooooo00Go^[ZjogMgMol0003o<S8bonk^kP07ooooo`05oc8b<_l0003o0000odA4A?nj^[X00_oo
ool01?nYZJWo8B4Qo`000?o<c<`>ooooo`04ojVYZOl0003o<S8bojVYZ@;ooooo00Gok^k^okZj^_mV
IVKo410@ogMgM`06ooooo`09omgMgOl0003o8B4QokZj^_oooooogMgMogMgMol0003oMgMg00Kooooo
00?oIVIVo`000?mVIVH01?ooool01Onj^[[o0000o`000?oMgMgoZJVY00?ooooo00SogMgMo`000?l0
003o^[ZjoooooooMgMgoA4A4oc8b<PGooooo00Woc<c<o`000?l0003oV9RHooooooo^k^koV9RHob4Q
8OnYZJT01?ooool00omVIVKo0000ofIVIP04ooooo`05okZj^_l0003o0000omgMgOnYZJT00oooool0
1OmVIVKo0000odA4A?o<c<coIVIV00?ooooo00?oIVIVo`000?mgMgL02?ooool00onHV9So0000oeEE
E@02onk^kP08oiRHV?mEEEGok^k^okZj^_l0003o<S8bolc<c?mVIVH3ooooo`05ofIVI_l0003oA4A4
olc<c?mVIVH00oooool01On7QhOo0000oc8b<_o<c<coIVIV00?ooooo00WogMgMo`000?lQ8B7o^[Zj
oooooooMgMgoMgMgo`000?mgMgL01_ooool00omVIVKo0000ofIVIP04ooooo`05okZj^_l0003o0000
omgMgOnYZJT0g_ooool00?Cooooo00Co^[Zjo`000?l0003ogMgM1_ooool00olb<S;o0000oc8b<P0:
ooooo`03okZj^_l0003oQhN700Oooooo00Cok^k^odA4A?lQ8B7ok^k^1_ooool00omVIVKo0000oeEE
E@05ooooo`04onk^k_lQ8B7o410@onk^kPcooooo00?o^[Zjo`000?mEEED01oooool01?o^k^koEEEE
oc8b<_o^k^h4ooooo`03oeEEEOl0003o^[Zj00Cooooo00?oc<c<o`000?mEEED01Oooool00onj^[[o
0000oa0@4005ooooo`;o000000?oc<c<ojVYZOoMgMd00_ooool00omEEEGo0000oiRHV004ooooo`03
oiRHV?mEEEGooooo00?ooooo00?oA4A4o`000?nHV9P01?ooool00oo^k^koEEEEofIVIP03ooooo`03
okZj^_l0003o410@00Gooooo0_l000000oo<c<coZJVYomgMg@02ooooo`06okZj^_l0003o8B4Qoooo
oonYZJWoEEEE0_ooool00onj^[[o0000ob4Q8@08ooooo`03ob4Q8Ol0003ok^k^00?ooooo00?oc<c<
oc8b<_nYZJT00_l000000oooooooZJVYoeEEE@02ooooo`06okZj^_l0003o8B4QoooooonYZJWoEEEE
0_ooool01_nj^[[o0000ob4Q8Oooooooc<c<ogMgM`;ooooo00?oEEEEo`000?nj^[X01?ooool00oo<
c<co0000oeEEE@05ooooo`03okZj^_l0003o410@00Gooooo0_l000000oo<c<coZJVYomgMg@3Moooo
o`00m?ooool01?mgMgOo0000o`000?mEEED6ooooo`04ob4Q8Ol0003o0000omgMg@Wooooo00?o<S8b
oa0@4?ooool02Oooool00olb<S;oEEEEooooo`05ooooo`03ohN7Qol@413ooooo00Kooooo00?oZJVY
o`000?mgMgL03?ooool2oa0@40[ooooo00?oV9RHob4Q8Oo^k^h00oooool2o`0000Kooooo00?oV9RH
o`000?mVIVH01Oooool2o`000003olc<c?oooooooooo00;ooooo00GoA4A4o`000?n7QhOoooooodA4
A002ooooo`03oa0@4?l0003ok^k^00Gooooo00?o^[Zjooooooooool00_ooool2o`0000Oooooo00?o
V9RHooooooooool00_ooool2o`000003olc<c?oooooooooo00;ooooo00GoA4A4o`000?n7QhOooooo
odA4A003ooooo`;o000000?ogMgMoooooonj^[X00oooool2o`000003omgMgOoooooooooo00Gooooo
0_l00005ooooo`07olc<c?m4A4Co0000o`000?oMgMgoooooojVYZ@03ooooo`;o000000?ogMgMoooo
oonj^[X00oooool2o`000003omgMgOoooooogMgM00;ooooo0_l00006ooooo`03oiRHV?l0003oIVIV
00Gooooo0_l000000oo<c<coooooooooo`02ooooo`05odA4A?l0003oQhN7oooooom4A4@0gOooool0
0?Cooooo00GoMgMgo`000?l0003o0000omgMg@05ooooo`;o000000?oMgMgoeEEEOooool02?ooool0
0ol0003o<S8booooo`09ooooo`03omgMgOl0003ogMgM00Gooooo00?o^[ZjofIVI_ooool01oooool0
0ol0003o8B4Qooooo`0:ooooo`03oiRHV?l0003oV9RH00_ooooo00?oc<c<onk^k_ooool00_ooool2
o`0000Oooooo00?o<S8bo`000?nYZJT01?ooool00omEEEGo0000ofIVIP04ooooo`05oiRHV?l0003o
A4A4oooooooMgMd00_ooool2o`0000_ooooo0_l0000<ooooo`03oeEEEOl0003oIVIV00Cooooo00Go
V9RHo`000?m4A4CoooooomgMg@03ooooo`03oeEEEOl0003oQhN700Gooooo00?oEEEEo`000?n7QhL0
1oooool2o`000003omgMgOoooooooooo00?ooooo00CoMgMgo`000?l0003oV9RH1Oooool00omEEEGo
0000ohN7Q`05ooooo`03oeEEEOl0003oV9RH00Cooooo0_l00007ooooo`03oc8b<_l0003oZJVY00Co
oooo00?oEEEEo`000?mVIVH01?ooool01OnHV9So0000odA4A?oooooogMgM0=gooooo003dooooo`05
ogMgMol0003o0000o`000?mEEED01Oooool2o`000003ooooool@413ogMgM00Sooooo00?o0000ob4Q
8Oooool02_ooool00omgMgOoEEEEooooo`04ooooo`03onk^k_mgMgOooooo00Kooooo00?ok^k^o`00
0?l000002oooool00om4A4Co0000omgMg@0@ooooo`;o000000?oc<c<ooooooooool01?ooool00onj
^[[o0000oa0@4004ooooo`04oiRHV?l0003o0000onk^kP?ooooo00?ogMgMo`000?l000001?ooool2
o`0000_ooooo0_l000000oo<c<coooooooooo`09ooooo`04oiRHV?l0003o0000onk^kP?ooooo00?o
gMgMo`000?l000001Oooool00onHV9So0000odA4A005ooooo`03oiRHV?l0003o410@00Oooooo00?o
<S8bo`000?nHV9P01_ooool00ol@413o0000oeEEE@05ooooo`03oiRHV?l0003oA4A400Gooooo00?o
V9RHo`000?m4A4@01?ooool2o`000003olc<c?oooooooooo00Cooooo00?o^[Zjo`000?l@41001?oo
ool01?nHV9So0000o`000?o^k^h3ooooo`03omgMgOl0003o00000=oooooo003dooooo`06oc8b<_l0
003oIVIVokZj^_l0003ogMgM0oooool01_o<c<co0000o`000?ooooooV9RHoeEEE@Sooooo00?o8B4Q
o`000?o^k^h02_ooool00ooMgMgo0000ooooo`0=ooooo`03oiRHV?l0003o000000_ooooo0_l0000A
ooooo`03oc8b<_l0003oQhN700Oooooo00?o<S8bo`000?nHV9P00oooool01?o^k^ko0000o`000?mg
MgL4ooooo`03ob4Q8Ol0003o^[Zj00?ooooo00?o8B4Qo`000?o<c<`02_ooool00om4A4Co0000o`00
0002oeEEE@03oiRHV?o^k^kooooo00Kooooo00Cok^k^o`000?l0003oMgMg1?ooool00olQ8B7o0000
okZj^P04ooooo`04onk^k_l0003o0000onk^kPCooooo00Cok^k^o`000?l0003oZJVY1_ooool00omg
MgOo0000odA4A006ooooo`03oiRHV?l0003o410@00Gooooo00Cok^k^o`000?l0003ok^k^1?ooool0
0oo^k^ko0000o`000004ooooo`03oc8b<_l0003oQhN700Oooooo00?o<S8bo`000?nHV9P00oooool0
1?o^k^ko0000o`000?mgMgL4ooooo`03ob4Q8Ol0003o^[Zj0=kooooo003dooooo`06oc8b<_l0003o
MgMgoooooom4A4CoEEEE0oooool00onj^[[o0000oc8b<P02ooooo`03oa0@4?oMgMgooooo00Kooooo
00?oEEEEo`000?nYZJT02oooool00olQ8B7o^[Zjooooo`0;ooooo`04olc<c?l0003o0000odA4A0_o
oooo0_l0000Aooooo`03ohN7Qol0003o8B4Q00Oooooo00?oV9RHo`000?lb<S801?ooool01?lb<S;o
0000o`000?oMgMd3ooooo`03ofIVI_l0003oIVIV00?ooooo00?oIVIVo`000?n7QhL02_ooool02OnH
V9So0000oa0@4?oooooogMgMogMgMol@413oMgMgonk^kP06ooooo`04oc8b<_l0003o0000omgMg@?o
oooo00?oIVIVo`000?mVIVH01Oooool00olb<S;o0000ojVYZ@05ooooo`03oc8b<_l0003o<S8b00Ko
oooo00CogMgMo`000?l0003ogMgM1_ooool00ol@413o0000olc<c005ooooo`03oc8b<_l0003oZJVY
00Gooooo00?o<S8bo`000?o<c<`00oooool00on7QhOo0000ob4Q8@07ooooo`03oiRHV?l0003o<S8b
00Cooooo00Co<S8bo`000?l0003ogMgM0oooool00omVIVKo0000ofIVIP3Nooooo`00m?ooool01olb
<S;o0000ohN7QooooooogMgMo`000?oMgMd00_ooool00onYZJWo0000oc8b<P02ooooo`03oiRHV?mE
EEGooooo00Kooooo00?oV9RHo`000?mEEED02oooool00on7QhOoIVIVooooo`0:ooooo`05olc<c?l0
003o0000o`000?nj^[X02oooool2o`00017ooooo00Cok^k^o`000?l0003o^[Zj1_ooool00oo<c<co
0000o`000004ooooo`04ohN7Qol0003o<S8bodA4A0?ooooo00?oZJVYo`000?lQ8B400oooool00oo<
c<co0000ob4Q8@0;ooooo`03oa0@4?l0003oZJVY00;ooooo00Coc<c<ob4Q8Ol0003oc<c<1Oooool0
1?n7QhOo0000oc8b<_m4A4@3ooooo`03ojVYZOl0003o8B4Q00Gooooo00?oQhN7o`000?mEEED01Ooo
ool01?n7QhOo0000oa0@4?nYZJT6ooooo`03ogMgMol0003oEEEE00Kooooo00?oIVIVo`000?n7QhL0
1Oooool00on7QhOo0000oeEEE@05ooooo`03ohN7Qol0003oMgMg00?ooooo00Cok^k^o`000?l0003o
^[Zj1_ooool00oo<c<co0000o`000004ooooo`04ohN7Qol0003o<S8bodA4A0?ooooo00?oZJVYo`00
0?lQ8B40g_ooool00?Cooooo0_l000000onj^[[oooooooooo`02oeEEE@;ooooo00?oMgMgo`000?mV
IVH00oooool00ol@413ok^k^ooooo`05ooooo`03omgMgOl0003o000000_ooooo00?ogMgMoa0@4?oo
ool02Oooool01Oo<c<co0000o`000?l0003oV9RH00cooooo00?o8B4Qo`000?nj^[X04Oooool01?n7
QhOo0000oa0@4?o^k^h6ooooo`;o00001?ooool01Oo<c<co0000oa0@4?n7QhOo^[Zj00?ooooo0_l0
00001oo^k^koooooooooooooooooA4A4o`000?nj^[X02_ooool00onj^[[o0000ob4Q8@03ooooo`04
onk^k_l@413o0000olc<c0Cooooo00Goc<c<o`000?l@413oQhN7okZj^P03ooooo`;o000000?ok^k^
ooooooooool00_ooool00ooMgMgo0000o`000005ooooo`05omgMgOl0003o410@oeEEEOo^k^h01Ooo
ool01?o^k^ko8B4Qo`000?nj^[X5ooooo`03ojVYZOl0003oA4A400Gooooo00?ogMgMo`000?l00000
1Oooool00ooMgMgo0000ob4Q8@04ooooo`04ohN7Qol0003o410@onk^kPKooooo0_l00004ooooo`05
olc<c?l0003o410@ohN7Qonj^[X00oooool2o`000003onk^k_oooooooooo0=_ooooo003dooooo`;o
000000[o^[Zjooooooooooook^k^o`000?oMgMgoooooogMgMol0003oMgMg0oooool00on7QhOoMgMg
ooooo`06ooooo`03oa0@4?l0003oc<c<00_ooooo00?o410@omgMgOooool01oooool01Oo<c<co0000
o`000?l0003oV9RH00gooooo00?oA4A4o`000?n7QhL04_ooool00omEEEGo0000oeEEE@06ooooo`;o
00001Oooool01OlQ8B7o0000olc<c?mVIVKok^k^00;ooooo00?o<S8bo`000?nHV9P00oooool00oo^
k^ko0000ob4Q8@04ooooo`03odA4A?l0003oIVIV00Cooooo00?oQhN7o`000?mgMgL00oooool00onY
ZJWo0000odA4A005ooooo`05ob4Q8Ol0003oc<c<ofIVI_o^k^h00_ooool00olb<S;o0000oiRHV005
ooooo`03oa0@4?l0003oc<c<00Gooooo0_l000000onHV9SoIVIVooooo`05ooooo`04olc<c?l0003o
410@onk^kPCooooo00?o^[Zjo`000?l000001_ooool00ol@413o0000olc<c005ooooo`03oa0@4?l0
003ok^k^00Cooooo00?oEEEEo`000?mEEED01_ooool2o`0000Gooooo00Go8B4Qo`000?o<c<coIVIV
onk^kP02ooooo`03oc8b<_l0003oV9RH0=gooooo003dooooo`;o00001?ooool01_mgMgOoEEEEoooo
oom4A4Co0000ohN7Q`?ooooo00?ok^k^oa0@4?o^k^h01_ooool00omVIVKo0000ofIVIP0;ooooo`03
ofIVI_n7QhOooooo00Kooooo00Goc<c<o`000?l0003o0000oiRHV00>ooooo`03oiRHV?l0003oA4A4
01?ooooo00?o<S8bo`000?n7QhL01?ooool00oo<c<co0000oeEEE@05ooooo`05oeEEEOl0003oQhN7
onk^k_n7QhL00_ooool00omgMgOo0000oeEEE@04ooooo`03olc<c?l0003oEEEE00?ooooo00?o8B4Q
o`000?l000001Oooool00omEEEGo0000oiRHV003ooooo`;o00001Oooool01OmEEEGo0000ohN7Qoo^
k^koQhN700;ooooo00?oMgMgo`000?mEEED01Oooool00omVIVKo0000ofIVIP05ooooo`08oa0@4?l0
003oMgMgogMgMonHV9So^[Zjo`000?mEEED3ooooo`04olc<c?l0003o8B4Qonk^kP?ooooo00Co^[Zj
o`000?l0003oZJVY1Oooool00omVIVKo0000ofIVIP04ooooo`04onk^k_lQ8B7o0000oiRHV0Gooooo
00?o<S8bo`000?n7QhL01?ooool00oo<c<co0000oeEEE@05ooooo`05oeEEEOl0003oQhN7onk^k_n7
QhL00_ooool00omgMgOo0000oeEEE@3Mooooo`00loooool00ooMgMgo0000o`000004ooooo`06onk^
k_l0003ogMgMoc8b<_l0003o^[Zj1?ooool2ogMgM`Kooooo00?o^[Zjo`000?lQ8B402oooool00onj
^[[o<S8booooo`05ooooo`05omgMgOl0003o0000o`000?nHV9P03oooool01?o^k^ko0000o`000?oM
gMdCooooo`09ofIVI_l0003oA4A4olc<c?oooooogMgMob4Q8Ol0003ogMgM00Cooooo0ol000002?lQ
8B7oooooolc<c?mgMgOok^k^oeEEEOl0003oA4A41Oooool02?o<c<co410@oc8b<_o<c<coooooolc<
c?l0003o<S8b1_ooool01On7QhOo0000ogMgMoo^k^koc<c<00;o00001?ooool3o`000008ob4Q8Ooo
ooooc<c<ogMgMoo^k^koEEEEo`000?m4A4@3ooooo`05omgMgOnj^[[oQhN7o`000?lQ8B400_nj^[X0
0on^[Zko0000o`000002o`000003ob4Q8Ooooooo8B4Q00?o00001?ooool02_o<c<co410@oa0@4?nY
ZJWoooooonk^k_lQ8B7oEEEEo`000?mVIVH3ooooo`05omgMgOnj^[[oQhN7o`000?lQ8B400_nj^[X0
0oo^k^ko0000o`000002o`000003oeEEEOoooooooooo00Cooooo00WoIVIVo`000?m4A4Coc<c<oooo
oooMgMgo8B4Qo`000?oMgMd01?ooool3o`000008ob4Q8Oooooooc<c<ogMgMoo^k^koEEEEo`000?m4
A4CMooooo`00loooool00onj^[[o0000oa0@4005ooooo`05oiRHV?mEEEGo410@o`000?nj^[X01?oo
ool00oo^k^ko410@onk^kP06ooooo`;o000000?ogMgMooooooooool02Oooool00ol0003ok^k^oooo
o`04ooooo`04oeEEEOl0003o0000olc<c17ooooo00?oMgMgo`000?mEEED05?ooool00onj^[[oEEEE
oa0@4002o`000003odA4A?o<c<cooooo00Cooooo00_ogMgMojVYZOmVIVKo8B4Qonk^k_ooooook^k^
oeEEEOl0003o410@olc<c006ooooo`03onk^k_mgMgOo8B4Q00;o000000?oA4A4onk^k_ooool01_oo
ool01_oMgMgoEEEEoa0@4?l0003o410@ojVYZ@Cooooo00_ogMgMojVYZOmVIVKo8B4Qonk^k_oooooo
k^k^oeEEEOl0003o410@olc<c003ooooo`03okZj^_l0003o000000Co000000_o^[Zjolc<c?nHV9So
IVIVoc8b<_l0003ogMgMonk^k_mEEEGo0000oeEEE@06ooooo`08ohN7QolQ8B7o0000o`000?mgMgOo
c<c<ob4Q8Ol@4103ooooo`03okZj^_l0003o000000Co000000Ko^[Zjonk^k_nj^[[oQhN7oeEEEOlQ
8B47ooooo`03okZj^_mEEEGo410@00;o000000?oA4A4olc<c?ooool01?ooool02ooMgMgoZJVYofIV
I_lQ8B7ok^k^ooooooo^k^koEEEEo`000?l@413oc<c<0=gooooo003cooooo`03okZj^_l0003o<S8b
00Kooooo00Co410@o`000?l0003ok^k^1Oooool2ogMgM`Kooooo00?oEEEEo`000?n7QhL02oooool0
0omEEEGoV9RHooooo`04ooooo`;o000000?oQhN7ooooooooool01?ooool00omgMgOok^k^ooooo`0:
ooooo`03ob4Q8Ol0003oc<c<00_ooooo00?oMgMgonk^k_ooool0BOooool01Oo^k^koA4A4o`000?l0
003o^[Zj01kooooo00Gok^k^odA4A?l0003o0000okZj^P3oooooo`?ooooo003cooooo`03oiRHV?l0
003oA4A400Kooooo00?oZJVYo`000?l000001_ooool00oo^k^ko8B4Qooooo`05ooooo`03ojVYZOl0
003oA4A400_ooooo00?oV9RHoeEEEOooool01?ooool2o`0000Oooooo00?oEEEEokZj^_ooool02_oo
ool01?o<c<co0000ob4Q8Oo^k^h:ooooo`03ob4Q8Onj^[[ooooo04_ooooo00?oEEEEo`000?n7QhL0
8?ooool00omEEEGo0000ohN7Q`3oooooo`?ooooo003cooooo`03ogMgMol0003oMgMg00Kooooo00?o
gMgMo`000?l000001oooool00omgMgOoV9RHooooo`04ooooo`04onk^k_l0003o0000onk^kP[ooooo
00?ok^k^o`000?o^k^h01?ooool00om4A4Co0000onk^kP06ooooo`03ob4Q8On7QhOooooo00_ooooo
00CoZJVYo`000?m4A4Cok^k^2?ooool00ooMgMgo0000ogMgM`1<ooooo`03onk^k_lQ8B7oEEEE023o
oooo00?ok^k^ob4Q8OmEEED0ooooool3ooooo`00loooool00olb<S;o0000ogMgM`06ooooo`03okZj
^_l0003o<S8b00Oooooo00?ok^k^oa0@4?o^k^h01Oooool00olQ8B7o0000oiRHV00;ooooo`03o`00
0?nHV9Sooooo00?ooooo00?oZJVYo`000?n7QhL01Oooool00onj^[[o0000ofIVIP0=ooooo`04okZj
^_l0003o8B4QomgMg@Oooooo00?o<S8bo`000?mEEED0COooool00oo<c<coA4A4ooooo`0Pooooo`03
olc<c?m4A4Cooooo00Gooooo0_lQ8B7jooooo`00l_ooool01Onj^[[o0000o`000?m4A4Cok^k^00Go
oooo00CoIVIVo`000?l0003oc<c<1_ooool01?nj^[[o0000ob4Q8Oo<c<`3ooooo`06ojVYZOl0003o
0000o`000?nHV9Sok^k^2?ooool01?nHV9So0000o`000?nYZJT4ooooo`07oeEEEOl0003oMgMgomgM
gOooooook^k^oiRHV002o`000003oc8b<_oooooooooo00cooooo00KogMgMoc8b<_l0003oEEEEokZj
^_o^k^h2ooooo`05ojVYZOlQ8B7o0000o`000?lQ8B40N?ooool2ob4Q8O[ooooo003aooooo`03oc8b
<_l0003o000000?o000000CoMgMgooooooooooooMgMg1Ol000000olb<S;oooooooooo`02ooooo`Go
00000_nj^[X7o`000003okZj^_oooooooooo00Cooooo1Ol000000omgMgOoooooooooo`02ooooo`09
oiRHV?lb<S;o0000o`000?l@413oEEEEolc<c?o^k^ko<S8b013ooooo00?oc<c<ofIVI_lb<S800ol0
00001Olb<S;oQhN7omgMgOo<c<co00000?ooooooMOooool00?oooooooooooonnooooo`00oooooooo
oooookkooooo003ooooooooooooo__ooool00?oooooooooooonnooooo`00\
\>"],
  ImageRangeCache->{{{0, 699}, {431.625, 0}} -> {-44.7096, -0.109561, \
0.538383, 0.00278653}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(movie = 
      animation[sim, \ {W, \ 0, \ 1}, \ {0, \ 300, \ 25}, \ 
        cellCoordinates \[Rule] \ xymeristem, 
        RGBColors \[Rule] \ {{1, 0, 1}, {0, 1, 0}}, \ 
        cellNumbers \[Rule] \ False, \ wallThickness \[Rule] \ 0.001, 
        Background \[Rule] \ Blue, ImageSize \[Rule] \ 400, 
        TextStyle \[Rule] \ {FontFamily \[Rule] \ Times, \ 
            FontSize \[Rule] \ 32}]\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -35.7188 0 ]
[.5 1.04444 35.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -96.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
119.812 29.000 moveto
(D) show
130.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
1 0 1 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
1 0 1 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
1 0 1 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
1 0 1 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
1 0 1 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
1 0 1 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
1 0 1 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
1 0 1 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
1 0 1 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
1 0 1 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
1 0 1 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
1 0 1 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
1 0 1 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
1 0 1 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
1 0 1 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
1 0 1 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
1 0 1 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
1 0 1 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
1 0 1 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
1 0 1 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
1 0 1 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
1 0 1 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
1 0 1 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
1 0 1 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
1 0 1 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
1 0 1 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
1 0 1 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
1 0 1 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
1 0 1 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
1 0 1 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
1 0 1 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
1 0 1 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
1 0 1 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
1 0 1 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
1 0 1 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
1 0 1 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
1 0 1 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
1 0 1 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
1 0 1 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
1 0 1 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
1 0 1 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
1 0 1 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
1 0 1 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
1 0 1 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
1 0 1 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
1 0 1 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
1 0 1 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
1 0 1 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
1 0 1 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
1 0 1 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
1 0 1 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
1 0 1 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
1 0 1 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
1 0 1 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
1 0 1 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
1 0 1 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
1 0 1 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
1 0 1 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
1 0 1 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
1 0 1 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
1 0 1 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
1 0 1 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
1 0 1 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
1 0 1 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
1 0 1 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
1 0 1 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
1 0 1 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
1 0 1 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
1 0 1 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
1 0 1 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
1 0 1 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
1 0 1 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
1 0 1 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
1 0 1 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
1 0 1 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
1 0 1 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
1 0 1 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
1 0 1 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
1 0 1 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
1 0 1 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
1 0 1 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
1 0 1 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
1 0 1 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
1 0 1 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
1 0 1 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
1 0 1 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
1 0 1 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
1 0 1 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
1 0 1 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
1 0 1 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
1 0 1 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
1 0 1 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
1 0 1 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
1 0 1 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
1 0 1 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
1 0 1 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
1 0 1 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
1 0 1 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
1 0 1 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
1 0 1 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
1 0 1 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
1 0 1 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
1 0 1 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
1 0 1 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
1 0 1 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
1 0 1 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
1 0 1 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
1 0 1 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
1 0 1 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
1 0 1 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
1 0 1 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
1 0 1 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
1 0 1 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
1 0 1 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
1 0 1 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
1 0 1 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
1 0 1 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
1 0 1 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
1 0 1 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
1 0 1 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
1 0 1 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
1 0 1 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
1 0 1 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
1 0 1 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
1 0 1 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
1 0 1 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
1 0 1 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
1 0 1 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
1 0 1 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
1 0 1 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
1 0 1 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
1 0 1 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
1 0 1 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
1 0 1 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
1 0 1 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
1 0 1 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
1 0 1 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
1 0 1 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
1 0 1 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
1 0 1 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
1 0 1 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
1 0 1 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
1 0 1 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
1 0 1 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
1 0 1 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
1 0 1 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
1 0 1 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
1 0 1 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
1 0 1 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
1 0 1 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
1 0 1 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
1 0 1 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
1 0 1 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
1 0 1 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
1 0 1 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
1 0 1 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
1 0 1 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
1 0 1 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
1 0 1 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
1 0 1 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
1 0 1 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
1 0 1 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
1 0 1 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
1 0 1 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
1 0 1 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
1 0 1 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
1 0 1 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
1 0 1 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
1 0 1 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
1 0 1 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
1 0 1 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
1 0 1 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
1 0 1 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
1 0 1 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
1 0 1 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
1 0 1 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
1 0 1 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
1 0 1 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
1 0 1 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
1 0 1 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
1 0 1 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
1 0 1 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
1 0 1 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
1 0 1 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
1 0 1 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
1 0 1 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
1 0 1 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
1 0 1 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
1 0 1 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
1 0 1 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
1 0 1 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
1 0 1 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
1 0 1 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
1 0 1 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
1 0 1 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
1 0 1 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
1 0 1 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
1 0 1 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
1 0 1 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
1 0 1 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
1 0 1 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
1 0 1 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
1 0 1 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
1 0 1 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
1 0 1 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
1 0 1 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
1 0 1 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
1 0 1 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
1 0 1 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
1 0 1 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
1 0 1 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
1 0 1 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
1 0 1 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
1 0 1 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
1 0 1 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
1 0 1 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
1 0 1 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
1 0 1 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
1 0 1 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
1 0 1 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
1 0 1 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
1 0 1 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
1 0 1 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
1 0 1 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
1 0 1 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
1 0 1 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
1 0 1 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
1 0 1 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
1 0 1 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
1 0 1 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
1 0 1 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
1 0 1 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
1 0 1 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
1 0 1 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
1 0 1 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
1 0 1 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
1 0 1 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
1 0 1 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?oo0?ooo`3oo`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000Coo`3o00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00goo`3o1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ool0o`?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0
o`04o`000?oo0?ooo`3oool0o`Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?oo0?l00ol0003oo`3oool0o`07ool0
o`Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003oo`3oool0o`08ool0
o`;o00002ooo0?l3o`0000?oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00coo`3o1_l00002ool0o`?o00000ooo0?l3o`0000oo
o`3o00?o0000ool0oooo0?l02ooo0?l3o`0000Koo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?oo`3o00?o0000ool0oooo0?l04Ooo0?l3o`0000Woo`3o
0_l0000<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000001?oo0?oo0000o`000?l0000:ool0o`03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00[oo`3o
0_l00009ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oool0o`0=ool0o`?o00001Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ool0oooo0?l04?oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l04_oo0?l2o`0001Ooo`3o00?o0000ool0oooo0?l03ooo0?l=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000Koo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0ool000005Ooo0?l0
0ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02?oo0?l7
o`0000?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[oo`3o0_l0000@ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo
000001Coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0;ool0o`04o`000?oo0?oo
o`3oool0o`Ko00002_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000goo`3o00Co0000ool0ool0003o00003Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo
0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l3o`00013oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003ooo0?l00ol0003oo`3oool0o`02ool0o`;o00002ooo0?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017oo`3o00?o0000ool0
oooo0?l01Ooo0?l2o`0000Woo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00_oo`3o0_l0
0003ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0
o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?oo
o`3o00koo`3o00?o0000ool0oooo0?l03_oo0?l3o`0001?oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00000ooo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03
o`000?oo0?ooo`3o00goo`3o0_l00006ool0o`;o00003ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03
o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00[oo`3o
0_l0000:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`06ool0o`?o00003Ooo
0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l2o`0001;oo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o01Ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000E
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`03
ool0o`03o`000?oo0?ooo`3o00Soo`3o1Ol0000Cool0o`?o00004_oo0?l00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Hool0o`?o00006?oo0?l2o`0000Koo`3o00?o0000ool0
oooo0?l05Ooo0?l00ol0003oo`3oool0o`02ool0o`04o`000?oo0?ooo`3oool0o`Oo00001Ooo0?l0
0ol0003oo`3oool0o`0?ool0o`04o`000?oo0?ooo`3oool0o`;o00004Ooo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0Gool0o`Go00006_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o01Koo`3o00Co0000ool0oooo0?ooo`3o1?l0000=ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l01?oo0?l2o`0000ooo`3o00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0E
ool0o`?o000000Koo`3oo`000?oo0?oo0000ool0ool0000Jool0o`;o00000_oo0?l00ol0003oo`3o
ool0o`0Hool0o`03o`000?oo0?oo000001;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000Woo`3o
0_l00007ool0o`So00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo`3o0ol0000Bool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l04_oo0?l3o`0000?oo`3o00Co0000ool0oooo0?oo00000_oo0?l00ol0003oo`3oool0o`0Iool0
o`03o`000?oo0?oo000001_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00_oo`3o1ol00008ool0o`Co00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`02ool0o`?o00003ooo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o0ol00005ool0o`05o`000?oo0?ooo`3oool0
ool000000ooo0?l00ol0003oo`3oool0o`0Iool0o`03o`000?oo0?ooo`3o01[oo`3o00?o0000ool0
oooo0?l04ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol0000;ool0o`Co00001Ooo0?l00ol0003o
o`3oool0o`0=ool0o`?o00002?oo0?l01Ol0003oo`3oool0oooo0?oo000000Coo`3o00?o0000ool0
oooo0?l06?oo0?l00ol0003oo`3oool0o`0Iool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0
oooo0?l00ooo0?l2o`0000ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000Ko
o`3o0_l00004ool0o`?o000000?oo`3oo`000?oo0?l03?oo0?l3o`0000[oo`3o00?o0000ool0oooo
0?l00_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o01Ooo`3o00?o0000ool0oooo
0?l06Ooo0?l00ol0003oo`3oool0o`0Fool0o`05o`000?oo0?ooo`3oool0ool000004Ooo0?l00ol0
003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l3o`000003ool0ool0003o000000Wo
o`3o0_l0000:ool0o`?o00003Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Hool0o`03o`000?oo0?ooo`3o01Oo
o`3o00?o0000ool0ool000004Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000?ool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?oo0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l00ol0000Aool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01_oo
0?l2o`0001Goo`3o0ol0000Hool0o`03o`000?oo0?ooo`3o01Woo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o0_l0000D
ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@
ool0o`;o00000ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01[oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l03Ooo0?l2o`0000Koo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o
01[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0ool0
00003ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo
0?l01Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l0000:ool0o`03
o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l06_oo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?oo0?ooo`3oo`0000oo
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00_o
o`3o0_l0000@ool0o`03o`000?oo0?ooo`3o01_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l0
1ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l0000@ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l06ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0=ool0o`03o`000?oo0?ooo`3o00;oo`3o0_l0000Cool0o`;o00003?oo0?l00ol0003oo`3oool0
o`0Lool0o`?o00003ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo
o`3o00Coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0>ool0o`04o`000?oo0?oo
0000o`0001Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Lool0o`03o`000?oo
0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo
o`3o01Soo`3o0_l00009ool0o`03o`000?oo0?ooo`3o01_oo`3o00?o0000ool0oooo0?l01?oo0?l4
o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0
003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000>ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Jool0o`03o`000?oo0?ooo`3o
00Coo`3o0ol0000Lool0o`03o`000?oo0?ooo`3o00Woo`3o0ol00004ool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`04
o`000?oo0?ooo`3oo`0000coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o01_oo`3o0_l00003ool0o`04o`000?oo0?ooo`3oool0o`?o00006?oo0?l0
0ol0003oo`3oool0o`0=ool0o`?o000000?oo`3oo`000?oo0?l04?oo0?l00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00;oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l07_oo0?l00ol0003oo`3oo`000007ool0o`?o00005?oo0?l00ol0
003oo`3oool0o`0Aool0o`;o00004Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`;o00001_oo0?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Oool0o`03
o`000?oo0?ooo`3o00Woo`3o0ol0000@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo
0?l03_oo0?l4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o01ooo`3o00?o0000ool0oooo0?l03?oo0?l3o`0000goo`3o
00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0;ool0o`;o00001?oo0?l5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0=ool0o`03o`000?oo
0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l07_oo
0?l00ol0003oo`3oool0o`0@ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`0Fool0o`Oo00001Ooo
0?l00ol0003oo`3oool0o`09ool0o`Co00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?oo0?ooo`3oool0ool000004?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Nool0o`03o`000?oo
0?ooo`3o01?oo`3o0ol00005ool0o`03o`000?oo0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l01?oo
0?l5o`00013oo`3o0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`03
ool0oa;o00002?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000
ool0oooo0?ooo`3oo`00000?ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l07ooo
0?l00ol0003oo`3oool0o`0Fool0o`?o000000?oo`3oo`000?oo0?l06?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l00006ool0o`03o`000?oo0?oo
o`3o00Ooo`3o0_l0000Bool0o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02ooo0?l3
o`00023oo`3o00?o0000ool0oooo0?l06_oo0?l00ol0003oo`3oool0o`0Hool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l00_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`07ool0o`Co00000_oo0?l00ol0003oo`3oool0o`0Nool0
o`03o`000?oo0?ooo`3o01[oo`3o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Bool0o`Ko00001_oo0?l2o`0001Ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03ool0o`Co00001ooo0?l00ol0003o
o`3oool0o`0Lool0o`03o`000?oo0?ooo`3o01coo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l0
0ooo0?l2o`0000?oo`3o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?oo000000?o00003?oo0?l00ol0003oo`3oool0o`0Kool0o`03o`000?oo0?ooo`3o01coo`3o
00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0ool000006_oo
0?l5o`0000_oo`3o0ol0000Aool0o`03o`000?oo0?ooo`3o01[oo`3o00?o0000ool0oooo0?l07Ooo
0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Woo`3o00?o0000
ool0oooo0?l00_oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l04ooo0?l3o`0001Ooo`3o0_l0000P
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003ooo0?l00ol0
003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l06?oo0?l00ol0
003oo`3oool0o`0:ool0o`?o00005_oo0?l00ol0003oo`3oool0o`05o`00013oo`3o0_l000000ooo
0?oo0000ool0o`0Oool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05_oo0?l00ol0003oo`3oool0o`0=ool0o`03
o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l01_oo0?l4o`0000_oo`3o00?o0000ool0oooo
0?l00_oo0?l00ol0003oo`3oool0o`0Nool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo
0?l03ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`Go00001?oo0?l2o`0000Goo`3o
00?o0000ool0oooo0?l07_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oo`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_oo`3o4?l0000?ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00ooo`3o1?l00008ool0o`03o`000?oo0?ooo`3o01koo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l00003ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oo`000009ool0o`03o`000?oo0?ooo`3o01goo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00005
ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03_oo0?l3o`0001Coo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0@ool0o`04o`000?oo0?ooo`3oo`0000Woo`3o00?o0000ool0oooo0?l07_oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l4o`0000;oo`3o00?o0000ool0
oooo0?l04_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00ooo`3o00Go0000ool0
oooo0?ooo`3oo`00000:ool0o`03o`000?oo0?ooo`3o01goo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00009ool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l01Ooo0?l4o`0000Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o013oo`3o00Go0000ool0oooo0?ooo`3oo`00000:ool0o`03o`000?oo0?oo
o`3o01goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Cool0o`04o`000?oo0?oo
o`3oool0o`;o00003?oo0?l00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o00Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo
o`3o00Co00002ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l07?oo0?l3o`0000[oo`3o00?o0000ool0oooo0?l05?oo0?l01?l0003oo`3oool0ool0
000>ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o01;oo`3o00Co0000ool0ool0003o00003ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo
0?oo000000ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l06Ooo0?l3o`0000?oo`3o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`0Cool0o`Go00003ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`04o`000?oo0?ooo`3oo`00017oo`3o00?o
0000ool0oooo0?l03ooo0?l01Ol0003oo`3oool0oooo0?oo000000[oo`3o1?l0000Aool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Fool0o`;o0000
1ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000coo`3o00?o
0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`03ool0o`04o`000?oo0?ooo`3oool0o`Ko0000
0ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`?o00002_oo0?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000goo`3o00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`03o`0000?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00Goo`3o0ol0000:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01Ooo
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000>ool0o`03o`000?oo
0?ooo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0;
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0;
ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`?o00004Ooo0?l5o`0001;oo`3o0_l0000<ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo`3oool0o`09ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00005?oo0?l00ol0
003oo`3oool0o`02ool0o`;o00003ooo0?l00ol0003oo`3oool0o`0=ool0o`Go00002?oo0?l01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o00goo`3o1Ol00004ool0o`?o00005Ooo0?l00ol0003oo`3oool0o`05ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0
o`Oo000000Coo`3oo`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0
oooo0?l03_oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00coo`3o0ol00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Co00006?oo0?l00ol0003oo`3oool0o`06ool0
o`;o00002Ooo0?l2o`00017oo`3o00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ool0oooo0?l04Ooo0?l01?l0003oo`3oool0ool0000>ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000?oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01_oo0?l00ol0
003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00Woo`3o0_l00006ool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ool0oooo0?l04ooo0?l2o`0000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`08ool0o`;o00001_oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o01Co
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o017o
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01_oo0?l2o`0000Woo`3o00Go0000ool0oooo0?oo
o`3oo`00000;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00goo`3o0_l000000ooo0?oo0000ool0o`0Cool0o`03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01?oo0?l2o`0000coo`3o00?o0000ool0ool000003?oo0?l00ol0003o
o`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001Woo`3o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?oo
o`3oo`00000@ool0o`03o`000?oo0?ooo`3o00;oo`3o0_l0000?ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o017o
o`3o00?o0000ool0oooo0?l04?oo0?l2o`0001?oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ool0oooo0?l05_oo0?l3o`0000Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3o
ool0o`0>ool0o`Co00004?oo0?l00ol0003oo`3oool0o`02o`00017oo`3o00?o0000ool0oooo0?l0
2ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?oo000000;o00004?oo0?l00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003oo`3oool0o`0Cool0o`;o00000ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`;o00003_oo
0?l3o`0001?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo
0?ooo`3o00;oo`3o0ol0000=ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?oo0?ooo`3o00Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Eool0o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000coo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo
0?l3o`0000Woo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Soo`3o00?o0000
ool0ool000005ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000
ool0oooo0?l02?oo0?l3o`0001Goo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ool0oooo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?oo0?l2o`00
00_oo`3o00?o0000ool0oooo0?l05_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00[oo`3o0_l00005ool0o`?o00000ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o
00;o00002Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00[oo`3o0ol00004ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0000=ool0o`03o`000?oo0?ooo`3o01Ko
o`3o00?o0000ool0oooo0?l00ooo0?l6o`0000ooo`3o0_l000000ooo0?oo0000o`000007ool0o`;o
00004?oo0?l00ol0003oo`3oool0o`03ool0o`?o00001_oo0?l00ol0003oo`3oool0o`09ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Cool0o`03
o`000?oo0?ooo`3o00goo`3o1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`04ool0o`;o00004?oo0?l00ol0003oo`3o
ool0o`0Fool0o`Go00001Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`;o00000_oo0?l>o`0001;oo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o013oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l05Ooo
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02_oo
0?l2o`0000_oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000goo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Bool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ool0ool0003o00005?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Eool0o`04o`000?oo0?oo0000o`00017oo`3o
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l02ooo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo
0?l2o`0000koo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0@ool0o`Co00001Ooo
0?l00ol0003oo`3oool0o`0Fool0o`04o`000?oo0?ooo`3oool0o`;o00004?oo0?l00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o01Goo`3o5?l0000?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0ool000003ooo
0?l2o`0000?oo`3o00Co0000ool0oooo0?oo00003Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00coo`3o0ol00004ool0o`?o00000_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?oo0?ooo`3o00?oo`3o0_l0000?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l01?l0003oo`3oool0
ool0000Aool0o`03o`000?oo0?oo000000Coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Woo`3o0ol0000:ool0o`;o00006?oo0?l00ol0003oo`3o
ool0o`06ool0o`;o00003_oo0?l00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`06ool0o`?o00003_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo
0?ooo`3o00Soo`3o0_l0000=ool0o`03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol0000B
ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000coo`3o0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo`3oool0o`0Cool0o`?o00005?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo0000
00;o00005Ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ooo`3o1?l00002ool0o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o01Go
o`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l4o`0000Koo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Ooo`3o
00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0@ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo
0?l4o`0000[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Bool0o`;o000000?o
o`3oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`04ool0o`Co00003_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`04o`0001;oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0
003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000Gool0o`03
o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l03?oo0?l4o`000003ool0ool0003oo`3o00go
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0>ool0o`05o`000?oo0?ooo`3oool0
ool000004_oo0?l00ol0003oo`3oool0o`0Hool0o`?o00004_oo0?l00ol0003oo`3oool0o`0Dool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`02ool0o`;o00003_oo0?l00ol0
003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00ooo`3o00Co0000ool0oooo0?oo00004_oo0?l0
0ol0003oo`3oool0o`0Hool0o`03o`000?oo0?ooo`3o00?o00003ooo0?l5o`0001;oo`3o00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08
ool0o`03o`000?oo0?ooo`3o00ooo`3o1Ol0000Aool0o`03o`000?oo0?ooo`3o01Ooo`3o00?o0000
ool0oooo0?l01?oo0?l3o`0000coo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000[oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l2o`00
00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00goo`3o0ol00005ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05_oo0?l00ol0
003oo`3oool0o`08ool0o`?o00002?oo0?l00ol0003oo`3oool0o`0:ool0o`Oo00000ooo0?l00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o01?oo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0:ool0oa[o00002Ooo0?l00ol0003oo`3oool0o`0<ool0o`?o
00005_oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0@ool0o`;o00000_oo0?l3o`0001;oo`3o00?o0000ool0oooo0?l01?oo0?l2o`0000koo`3o
00?o0000ool0oooo0?l01ooo0?l2o`0000[oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`08ool0o`;o00002_oo0?l2o`0000?oo`3o0_l0000Cool0o`03o`000?oo0?ooo`3o013oo`3o
1?l0000Gool0o`03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`000005ool0o`;o00004?oo
0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01?oo
0?l2o`0000coo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo
0?ooo`3o00Goo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l01?l0003oo`3oool0ool0000Gool0o`03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l2o`0000;oo`3o00?o
0000ool0oooo0?l01Ooo0?l2o`0000ooo`3o00Go0000ool0oooo0?ooo`3oo`00000Cool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000[oo`3o0_l0000>ool0o`03o`00
0?oo0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Hool0o`03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l01_oo0?l3o`0000_oo`3o1Ol0000Eool0o`04o`00
0?oo0?oo0000o`00013oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`04
o`000?oo0?oo0000o`0000koo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l00ooo0?l00ol0003oo`3oool0o`0Eool0o`;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l00006ool0o`03
o`000?oo0?ooo`3o00Woo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo
0?l05?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo
0?l04Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00005ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3o
ool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3o
ool0o`0Aool0o`;o00000ooo0?l4o`0001?oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3o
ool0o`0Dool0o`05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o00goo`3o00Co0000ool0oooo0?ooo`3o0_l00009ool0o`03
o`000?oo0?ooo`3o00goo`3o0ol000000ooo0?oo0000ool0o`07ool0o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l04ooo0?l3o`0000?oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
o`3oool0o`07ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oo`00000;ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?oo000001Coo`3o00?o0000ool0oooo0?l0
1?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
4Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o00Co0000ool0oooo0?oo0000
5?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l0
2Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo`3oool0o`0>ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00
000Bool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0
o`02ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ool0oooo0?l03Ooo
0?l01?l0003oo`3oool0ool0000<ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l0
2ooo0?l00ol0003oo`3oool0o`0<ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`00
0?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo
0?ooo`3o00koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo
0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`04
ool0o`?o00002_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo0000
00Co00000_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0
oooo0?l03?oo0?l01Ol0003oo`3oool0oooo0?oo000001;oo`3o0ol00009ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000ooo
0?oo0000ool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0
003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o0ol00008ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?oo0000
01;oo`3o00Co0000ool0oooo0?ooo`3o0_l00006ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0
003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`06
ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo0000
013oo`3o3_l00006ool0o`;o00003?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`;o00002?oo0?l2o`00
0003ool0ool0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Dool0o`?o00003ooo0?l00ol0003oo`3oool0o`0<ool0o`04o`000?oo0?ooo`3oool0
o`;o00003ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l04ooo0?l01Ol0003oo`3oool0oooo0?oo000000goo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oo`00000Aool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Go
o`3o4Ol0000Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`07ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o
o`3oool0o`0=ool0o`04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00?o00003_oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Aool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01_oo0?l2o`0001Coo`3o00?o0000ool0oooo
0?l01ooo0?l2o`00017oo`3o0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03Ooo0?l4o`000003ool0ool0003oo`3o00koo`3o
00?o0000ool0oooo0?l00ooo0?l3o`0000[oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`05ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00002ool0o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o00[oo`3o0ol00004ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l3o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo
0?oo000000;o00001_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o
0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo`3o0ol00007ool0o`03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l3o`0000;oo`3o00?o0000ool0oooo0?l02ooo0?l0
1Ol0003oo`3oool0oooo0?oo000001Koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`02ool0o`?o00005Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ool0oooo0?ooo`3o0ol000001?oo0?oo0000o`000?l0000:ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03Ooo0?l2o`0000ooo`3o00?o0000ool0ool00000
5ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
2Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00;o00000ooo0?l2o`0001?oo`3o
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05_oo
0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02ooo
0?l5o`0000coo`3o00?o0000ool0ool000001ooo0?l2o`00017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`06
ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05_oo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`02
ool0o`Wo00001?oo0?l00ol0003oo`3oool0o`08ool0o`;o00003ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o
01?oo`3o1?l00005ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l4o`00
00goo`3o0_l0000>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Coo`3o0ol000000ooo0?oo
0000ool0o`0>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03Ooo0?l2o`0000_o
o`3o0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l2o`0001Coo`3o0ol0000@ool0o`;o0000
2_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000?ool0o`;o0000
2?oo0?l01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o4ol0000>ool0o`?o0000
0_oo0?l00ol0003oo`3oool0o`0<ool0o`Go00000_oo0?l00ol0003oo`3oool0o`0<ool0o`;o0000
3?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0ool00000
4?oo0?l2o`0000Coo`3o0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`?o00001_oo
0?l00ol0003oo`3oool0o`06ool0o`Go00002?oo0?l00ol0003oo`3oool0o`08ool0o`?o00003ooo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ooo`3o00Go0000ool0oooo0?ooo`3o
o`00000Aool0o`;o000000?oo`3oo`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o
0000ool0oooo0?l01Ol0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l0000Bool0o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l00_oo0?l3o`0000goo`3o0ol0000C
ool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00goo`3o0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`Co00004Ooo0?l00ol0003oo`3oo`000002o`00
00ooo`3o00?o0000ool0ool000005Ooo0?l00ol0003oo`3oo`000002o`0001Ooo`3o00?o0000ool0
oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0
oooo0?l02Ooo0?l3o`0000;oo`3o00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Go
o`3o0ol00004ool0o`03o`000?oo0?ooo`3o00koo`3o0_l0000Aool0o`04o`000?oo0?ooo`3oo`00
01Koo`3o00?o0000ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`04ool0o`Co00001Ooo0?l00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo
0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00;oo`3o0ol00008ool0o`03
o`000?oo0?ooo`3o00coo`3o0ol0000?ool0o`;o00000ooo0?l00ol0003oo`3oool0o`0Dool0o`03
o`000?oo0?ooo`3o01Woo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l00ol00009ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o1_l0000<ool0o`03o`000?oo0?ooo`3o00[oo`3o00Go0000ool0oooo0?oo
o`3oo`00000=ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o
o`3oool0o`0Iool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0:ool0o`;o00003?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l02ooo0?l3o`0000Goo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o00coo`3o0_l00008ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0Jool0o`go0000
3_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0003ool0o`?o000000?oo`3oo`000?oo0?l01_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l01_oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Woo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00Goo`3o0_l00009ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l0
1?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l00ooo0?l2o`0000Woo`3o00?o
0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Hool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l2
o`0000_oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
000000koo`3o00Go0000ool0oooo0?ooo`3oo`00000;ool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000Iool0o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003oo`3oo`000002o`0000goo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0ool000003?oo0?l00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?oo000000;o00005Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00koo`3o0_l0000=ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001;oo`3o00?o0000ool0
oooo0?l04_oo0?l01?l0003oo`3oool0oooo0?l3o`0001;oo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l2o`0000ooo`3o00?o0000ool0
ool000003_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Goo`3o0ol0000?ool0
o`03o`000?oo0?ooo`3o01?oo`3o0ol00002ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oo`00000>ool0o`05o`000?oo0?ooo`3oool0ool000003Ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol0000:ool0o`;o00005_oo0?l00ol0003oo`3oool0o`03ool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo`3oool0oooo0?oo000000coo`3o00?o0000ool0
oooo0?l00_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l03?oo0?l2o`0000Koo`3o0_l000000ooo0?oo0000ool0o`0Dool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l02Ooo0?l4o`00013oo`3o00?o0000ool0oooo
0?l03ooo0?l3o`000003ool0ool0003o000000Coo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`07ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`05ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o00;oo`3o0ol0000=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0
o`04ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0
o`07ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l01_oo0?l3o`0000Soo`3o0_l0
000Eool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000[oo`3o00?o0000ool0oooo0?l01?oo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0000<ool0o`?o00000_oo0?l3
o`000003ool0ool0003oo`3o01Coo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06
ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l03?oo0?l01?l0003oo`3oool0ool0000=ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?oo
o`3o00ooo`3o0_l00005ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o1Ol0000;ool0o`03o`000?oo0?oo
o`3o00Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0
oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?oo000000ooo`3o00Co0000ool0
oooo0?oo00003_oo0?l01?l0003oo`3oool0ool0000Cool0o`03o`000?oo0?ooo`3o00Coo`3o00?o
0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Wo00000_oo0?l00ol0003oo`3oool0
o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o013oo`3o1?l0000>ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0ool000003ooo0?l0
0ol0003oo`3oo`00000Cool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`0<ool0o`Co00000ooo0?l7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00goo`3o0ol00004ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`;o00005?oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`04ool0
o`?o00004?oo0?l00ol0003oo`3oool0o`0?ool0o`Co00001ooo0?l3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l02ooo0?l3o`0000Soo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol000000ooo0?oo0000ool0o`0Bool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l02ooo0?l3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`08ool0o`?o0000
3?oo0?l2o`0000Woo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Woo`3o0_l00005ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00goo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0
o`05ool0o`?o00004Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00ooo`3o00Co
0000ool0oooo0?ooo`3o0_l00005ool0o`;o00002?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`00
0?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?oo`3o0ol0
000Eool0o`03o`000?oo0?ooo`3o00Coo`3o4ol00006ool0o`03o`000?oo0?oo000000;o00002_oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000coo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo`3oool0o`0F
ool0o`Co000000?oo`3oo`000?oo0?l04?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0=ool0o`04o`000?oo0?oo
0000o`0000[oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Cool0o`;o00001?oo0?l00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0:
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_oo0?l2o`0000Soo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Coo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l03_oo0?l<o`0000ooo`3o00?o0000ool0oooo0?l01?oo0?l2o`00
00Koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo`3oool0o`0>ool0o`;o00001ooo0?l01?l0003oo`3oo`000?l0000>ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2o`0000?oo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`05o`000?oo0?ooo`3oool0ool000004Ooo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo`3o0_l00009ool0
o`05o`000?oo0?ooo`3oool0ool000003Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Woo`3o0_l000000ooo0?oo0000ool0o`08ool0o`Ko00004ooo0?l01?l0003oo`3oool0ool0
000Aool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?oo
o`3o00Ooo`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00?oo`3o1?l00008ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l;o`0000Goo`3o00?o0000ool0oooo0?l04_oo0?l0
0ol0003oo`3oo`00000@ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?oo0?ooo`3o00Coo`3o0_l0000<ool0o`03o`000?oo0?ooo`3o00?oo`3o00Co0000ool0
oooo0?ooo`3o1Ol00003ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04_oo0?l3
o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0
oooo0?l00_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0
oooo0?l01Ooo0?l3o`0000coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`04ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04o`00
00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ool0ool0
003o00003_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`09ool0o`;o00003ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`09ool0
o`Co00003ooo0?l00ol0003oo`3oool0o`05ool0o`Co00001_oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Go
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ko
o`3o0ol000000ooo0?oo0000ool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Soo`3o00Co0000ool0oooo
0?ooo`3o1Ol00009ool0o`03o`000?oo0?ooo`3o00[oo`3o1?l00002ool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo
0?l01_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l00_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00Koo`3o1Ol00003ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000Bool0o`03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o
00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?oo000000;o0000
2?oo0?l00ol0003oo`3oool0o`0=ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0;ool0o`?o0000
4ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000Woo`3o0_l0
000<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l00_oo0?l3o`000003ool0ool0
003oo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000
ool0oooo0?l01_oo0?l01?l0003oo`3oool0oooo0?l3o`0000Koo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o00Goo`3o0ol00002ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00coo`3o0ol0000:
ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?ooo`3o
00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o
00Woo`3o0_l0000Aool0o`03o`000?oo0?ooo`3o00Goo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o
00[oo`3o00Go0000ool0oooo0?ooo`3oo`00000:ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?oo0?ooo`3o00Soo`3o1?l0000<ool0o`03o`000?oo0?ooo`3o
00;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0
003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l00005ool0o`;o00002?oo0?l00ol0
003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`07o`0000?o
o`3o00?o0000ool0oooo0?l02_oo0?l01Ol0003oo`3oool0oooo0?oo000000coo`3o00Co0000ool0
oooo0?oo00004Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000
ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ool0o`03o`000?oo0?ooo`3o
00Woo`3o00Co0000ool0oooo0?oo00003?oo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?oo
o`3o00ooo`3o00Co0000ool0oooo0?oo00004Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l0000<
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oo`00000C
ool0o`04o`000?oo0?ooo`3oool0o`;o00003Ooo0?l2o`0000Koo`3o00Go0000ool0oooo0?ooo`3o
o`00000@ool0o`03o`000?oo0?ooo`3o01Coo`3o0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo`3oo`00000Aool0o`03o`000?oo0?ooo`3o00?oo`3o00Go0000ool0oooo0?ooo`3o
o`00000>ool0o`?o00005?oo0?l2o`0000?oo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oool0o`0Aool0o`;o00001?oo0?l01?l0003oo`3oool0ool0000:ool0o`Co0000
0ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00009ool0o`03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol0
000Gool0o`03o`000?oo0?ooo`3o01?oo`3o00Ko0000ool0oooo0?ooo`3oo`000?oo0?l5o`0000Co
o`3o0ol00008ool0o`03o`000?oo0?ooo`3o00goo`3o0_l0000:ool0o`;o00001ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`?o0000
0_oo0?l00ol0003oo`3oool0o`0Eool0o`;o00005Ooo0?l00ol0003oo`3oool0o`02o`0000Goo`3o
1?l0000<ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l0000>ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04Ooo0?l5o`0000?oo`3o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00006ool0o`03o`000?oo
0?ooo`3o01?oo`3o00Co0000ool0oooo0?oo00005Ooo0?l2o`0000Woo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`07ool0o`;o00004_oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Woo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0
o`03o`0000[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo
0?ooo`3o01;oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00Coo`3o0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000>
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0@
ool0o`;o00002ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003_oo0?l2o`00
0003ool0ool0003oo`3o00[oo`3o00?o0000ool0oooo0?l03_oo0?l01?l0003oo`3oo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l01Ol0
003oo`3oool0oooo0?oo000001;oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000?oo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00000Cool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0
o`03o`000?oo0?ooo`3o00Goo`3o0ol00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0
oooo0?l03ooo0?l00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`;o00002Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l04Ooo0?l2o`00017oo`3o00?o0000ool0oooo0?l0
4_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00ooo`3o00Co0000ool0ool0003o
00002ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3o
o`000002o`0000koo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`05ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000ooo0?l00ol0003oo`3oool0
o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0000;ool0o`;o00005_oo0?l7o`0001Coo`3o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?oo0?ooo`3oool0o`?o00005?oo0?l00ol0003oo`3oool0
o`06ool0o`?o00002?oo0?l00ol0003oo`3oo`000002o`0001;oo`3o00?o0000ool0oooo0?l00_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`03
ool0o`;o00003ooo0?l00ol0003oo`3oool0o`03ool0o`04o`000?oo0?ooo`3oo`0001?oo`3o00?o
0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`06ool0oaCo00003_oo0?l3o`000003ool0ool0003o
o`3o00Ooo`3o0ol0000;ool0o`03o`000?oo0?ooo`3o00Coo`3o00Go0000ool0oooo0?ooo`3oo`00
000Bool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01ooo0?l?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00008ool0o`03o`000?oo0?oo
o`3o00Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0<ool0
o`;o00001Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
o`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
o`3oool0o`0>ool0o`?o000000?oo`3oo`000?oo0?l02?oo0?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00goo`3o4_l00005ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3o
o`00000?ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000Cool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o
00Go0000ool0oooo0?ooo`3oo`00000@ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`09ool0o`04o`000?oo0?ooo`3oo`0000ko
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000Cool0o`03o`000?oo0?ooo`3o00So
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017o
o`3o00?o0000ool0ool000004Ooo0?l00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o0_l00003ool0o`03o`000?oo0?ooo`3o013o
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
1ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0
o`0:ool0o`;o00001_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l2
o`0000_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?oo
o`3o01?oo`3o4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l01ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?oo`3oo`000?oo0?l02_oo0?l00ol0
003oo`3oool0o`09ool0o`Ko00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01?oo0?l3o`00
00Soo`3o0_l0000;ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l00004ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`04ool0o`?o00005?oo0?l3o`00
017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03o`0000?o
o`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Go
o`3o0ol00007ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o`3oool0o`08ool0o`03o`000?oo0?ooo`3o013oo`3o00Go0000ool0oooo0?ooo`3oo`00000@ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?oo0?l00ol0003o
o`3oool0o`0;ool0o`;o00001ooo0?l01?l0003oo`3oool0oooo0?l2o`0000ooo`3o00?o0000ool0
oooo0?l00ooo0?l2o`0000[oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`05ool0
o`;o00003?oo0?l00ol0003oo`3oool0o`0=ool0o`;o00001Ooo0?l00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo0000017o
o`3o00Co0000ool0oooo0?ooo`3o0_l0000=ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0
oooo0?l01?oo0?l00ol0003oo`3oool0o`0=ool0o`Co00002_oo0?l00ol0003oo`3oool0o`06ool0
o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l04Ooo0?l3o`00013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000ool0oooo0?ooo`3o1_l00003ool0
o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o013o
o`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`02ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l01ooo0?l3o`0000coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l0
4Ooo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00;o00004Ooo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`0=ool0o`;o00005?oo0?l3o`0000Coo`3o00?o0000ool0ool000004ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02_oo0?l3o`000003ool0ool0003oo`3o017oo`3o0_l00003ool0o`;o00000_oo0?l2
o`0001Coo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Koo`3o0ol00005ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00007ool0o`?o00005Ooo0?l00ol0003oo`3oool0o`0;ool0
o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00Coo`3o1Ol00003ool0o`03o`000?oo0?ooo`3o017o
o`3o00?o0000ool0oooo0?l01?oo0?l2o`0000Woo`3o00?o0000ool0oooo0?l02_oo0?l2o`0000_o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Wo
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l02_oo0?l3o`0001Goo`3o00?o0000ool0oooo0?l00ol0000<ool0o`03o`00
0?oo0?ooo`3o00Ooo`3o0_l0000=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00coo`3o00?o
0000ool0oooo0?l05?oo0?l2o`0000ooo`3o00?o0000ool0oooo0?l01Ooo0?l2o`0000ooo`3o00?o
0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l00_oo0?l2o`0001;oo`3o00?o0000ool0oooo0?l04Ooo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o
00koo`3o00?o0000ool0oooo0?l04_oo0?l01?l0003oo`3oool0ool0000@ool0o`04o`000?oo0?oo
0000o`0001Coo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000
ool0oooo0?l03Ooo0?l4o`00013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`07ool0o`Ko00000ooo0?l00ol0
003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l01_l0000:ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
5Ooo0?l3o`00017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ool0oooo0?l04_oo0?l9o`0000Ooo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0
o`0:ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0
o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo
o`3o00Koo`3o1ol0000<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00coo`3o00Co0000ool0oooo0?ooo`3o1_l0
0007ool0o`03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04Ooo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o1?l0000:ool0o`Co00001_oo0?l2
o`0000Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_oo0?l00ol0003oo`3oool0o`0=ool0o`?o00003?oo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00ooo`3o1?l0000Gool0o`04o`000?oo0?ooo`3oool0o`Ko00000ooo0?l0
0ol0003oo`3oool0o`0:ool0o`;o000000?oo`3oo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o
00?o00002_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Soo`3o1ol00003ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000ooo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002ooo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00?oo`3o0ol00008ool0o`03o`000?oo0?ooo`3o00Ko
o`3o00Co0000ool0oooo0?ooo`3o1ol0000:ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ool0o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l01_oo0?l3o`0000Koo`3o00?o0000ool0oooo0?l01?oo0?l5o`0001;o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`?o00001?oo0?l00ol0003oo`3o
ool0o`03o`000003ool0ool0003oo`3o01Coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?oo`3oo`000?oo0?l04?oo0?l00ol0003oo`3oool0
o`0<ool0o`?o000000Coo`3oo`000?l0003o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000
4ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0
o`0@ool0o`04o`000?oo0?ooo`3oo`0001;oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0@ool0o`?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l03_oo
0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o00koo`3o00?o0000ool0oooo0?l01?oo0?l2o`0000koo`3o00?o0000ool0oooo0?l03Ooo0?l0
0ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00Goo`3o00?o0000ool0ool000000_l0000:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003o
o`3oool0o`02ool0o`?o00001ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo`3o1?l0000:ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00?o00003Ooo
0?l01?l0003oo`3oool0oooo0?l6o`0000?oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l3o`000003ool0
ool0003oo`3o013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0
0009ool0o`03o`000?oo0?ooo`3o00Soo`3o0ol0000?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l02ooo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l02?oo0?l0
0ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0ol0000=ool0o`03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00coo`3o0ol00002ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03Ooo0?l00ol0003oo`3oool0o`0:ool0o`?o00000ooo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o`3oool0o`0?ool0o`;o00003ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Oo
o`3o0ol00007ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`03ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03ool0o`?o0000
2ooo0?l9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0
o`02ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0
o`03o`0000koo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aool0o`03o`000?oo
0?ooo`3o00koo`3o00?o0000ool0oooo0?l03Ooo0?l01?l0003oo`3oool0ool0000>ool0o`03o`00
0?oo0?ooo`3o013oo`3o0_l0000Aool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000ooo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0=ool0o`Go00003?oo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Ooo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l3
o`0000Woo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l01_oo0?l4o`0000Goo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`?o000000?oo`3oo`000?oo
0?l04_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001ooo0?l3o`00013oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o
00004ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ool0o`04o`000?oo0?ooo`3oool0o`;o00003ooo0?l00ol0003oo`3oool0o`06ool0o`;o
00004ooo0?l00ol0003oo`3oool0o`0Aool0o`;o00004Ooo0?l00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo`3oo`000?oo0?l01Ooo0?l2o`0000goo`3o00?o0000ool0oooo0?l0
1?oo0?l2o`0000;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`04o`00
0?oo0?ooo`3oo`00013oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3o
ool0o`03ool0o`03o`000?oo0?ooo`3o013oo`3o4_l00004ool0o`;o00003Ooo0?l00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo`3oool0o`08ool0o`;o00002ooo0?l00ol0003oo`3oool0o`02o`0000Ooo`3o00?o
0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Coo`3o00?o
0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0
o`0;ool0o`Ko00001?oo0?l4o`0000[oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l0000:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00?oo`3o1?l00003ool0o`03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0;ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`09ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o
o`3oool0o`08ool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02ooo0?l2o`0000Go
o`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`07ool0o`03o`00
0?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03Ooo0?l01Ol0003oo`3oool0oooo0?oo000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3o
ool0o`0:ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3o
ool0o`0;ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3o
ool0o`0=ool0o`Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000goo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00coo`3o0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02_oo0?l2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Woo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo
0?l00_oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ool0oooo0?l03_oo0?l01?l0003oo`3oool0oooo0?l4o`0000koo`3o00?o0000ool0oooo
0?l01?oo0?l2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?oo000000Coo`3o
1_l00007ool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l3o`0000ooo`3o00?o0000ool0oooo0?l02Ooo
0?l5o`0000;oo`3o00Co0000ool0oooo0?ooo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ool0oooo0?ooo`3o
o`00000<ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l00ol0000<ool0o`03o`00
0?oo0?ooo`3o00koo`3o0ol000000ooo0?oo0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3o
o`00000<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Soo`3o
00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003oo`3oo`00000=ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l01ooo0?l3o`0000Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo`3oo`000?oo0?l05?oo0?l00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?oo0?ooo`3o
00Soo`3o1?l0000;ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?oo0?ooo`3oool0o`Oo00001?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
o`3oool0o`06ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003oo`3oool0
o`02ool0o`03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?oo0?ooo`3oo`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oo`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00a_l00?l7oooo01;o003o1oooo`2Yo`00o`7ooooo0036o`00o`;oool000?oMgN7o`00ool00?l0
6?l00?l00omgMhOoool0oooo002Yo`00o`7ooooo0036o`00o`;oool07?l00?l2oooo0:Wo003o0Ooo
ool00<Ko003o0_ooo`0Lo`00o`;oool0ZOl00?l1ooooo`00a_l00?l2oooo01co003o0_ooo`2Yo`00
o`7ooooo002]o`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00_o
003o00OoMgN7omgM8Oooo`3oool0omgM8On7QgOo413^00[o003o0_ooo`2Yo`00o`7ooooo002]o`00
o`03oiRHI_ooo`3oMgN700Oo003o00?oV9QVoooo0?mgMhL03?l00?l2oooo00Wo003o00[o413^omgM
8Oooo`3oMgN7oa0@k_l00?ooEEFYoooo0?oMgB7o413^2Ol00?l2oooo0:Wo003o0Oooool00:go003o
00?ok^h@oooo0?oMgB401ol00?l00oo^kQ3oool0omgM8@0<o`00o`;oool02Ol00?l00ooMgB7oool0
ogMgQ`04o`00o`03odA4^_ooo`3ogMdQ00Wo003o0_ooo`2Yo`00o`7ooooo002/o`00o`05oc8bc?oo
o`3oool0oooo0?l@4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`08o`00o`03
ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP02?l00?l2oooo0:Wo003o0Oooool00:co003o
00GoZJUEoooo0?ooo`3oool0ofIVV005o`00o`05oiRHI_ooo`3oool0oooo0?mgMhL02ol00?l2oooo
00So003o0_ooo`000onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@00So003o0_ooo`2Yo`00
o`7ooooo002/o`00o`?oool000?oIVJHokZjA?l00?l01?l00?l01Oo^kQ3oool0oooo0?mVIYSogMdQ
00_o003o0_ooo`07o`00o`04oeEEZOooo`3oool0ofIVV0Ko003o00CoEEFYoooo0?ooo`3o<S;<1ol0
0?l2oooo0:Wo003o0Oooool00:_o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o413^00?o003o
00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o8B7M00[o003o0_ooo`07o`00o`04oiRHI_ooo`3oool0
odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg1ol00?l2oooo0:Wo003o0Oooool00:_o003o00OoZJUE
oooo0?ooo`3oV9QVo`00oonHV6KoIVJH00?o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN7
00[o003o0_ooo`07o`00o`04olc<<_ooo`3oool0oa0@kPOo003o0_ooo`000oo<c3;o003oo`00o`05
o`00o`;oool0ZOl00?l1ooooo`00Zol00?l3oooo0004ob4QgOl00?ooA4BjokZjA0?o003o0oooo`00
1?lb</co003oodA4^_oMgB4:o`00o`;oool01ol00?l3oooo00So003o0_ooo`000oo^kQ3o003oo`00
o`05o`00o`;oool0ZOl00?l1ooooo`00Z_l00?l01?mEEJWoool0oooo0?oMgB43o`00o`04oooo0?l0
0?oo003ooeEEZ@;oool000Kok^h@o`00ool00?oo003ooooo0?lQ8Md9o`00o`;oool01ol00?l3oooo
00So003o0oooo`07o`00o`;oool0ZOl00?l1ooooo`00Z_l00?l01?nYZEGoool0oooo0?mgMhL3o`00
o`04ojVYEOmEEJWo003oojVYE@;oool000KoV9QVo`00ool00?oo003oojVYEOmgMhL9o`00o`;oool0
1ol00?l3oooo00So003o0oooo`07o`00o`;oool0ZOl00?l1ooooo`00Z_l00?l3oooo0007ob4QgOl0
0?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l00?oo003oo`00oomEEJWogMdQ2Ol00?l2
oooo00Oo003o0oooo`08o`00o`?oool01ol00?l2oooo0:Wo003o0Oooool00:Wo003o00CoEEFYoooo
0?ooo`3ogMdQ1Ol00?l01Oo^kQ3oEEFYoooo0?ooo`3ok^h@00Go003o00?oool0ob4QgOl00?l01ol0
0?l2oooo00Oo003o0oooo`08o`00o`?oool01ol00?l2oooo0:Wo003o0Oooool00:Wo003o00CoZJUE
oooo0?ooo`3oMgN71Ol00?l01Onj^TCok^h@oooo0?ooo`3oQhMg00Go003o00?oZJUEogMgQol00?l0
1ol00?l2oooo00Oo003o00Coc<`boooo0?ooo`3o<S;<1_l00?l01?lQ8Mgoool0oooo0?o<c387o`00
o`;oool0ZOl00?l1ooooo`00Z?l00?l01Ol@4>koool0oooo0?ooo`3o8B7M00Go003o00GoIVJHoooo
0?ooo`3oool0ob4Qg@05o`00o`03oeEEZOoMgB7o003o00Oo003o0_ooo`07o`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oV9QV1ol00?l2oooo0:Wo003o0Oooool00:So003o00Co
IVJHoooo0?ooo`3ogMdQ1_l00?l01?mVIYSoool0oooo0?oMgB47o`00o`03oooo0?lQ8Mgo003o00Ko
003o0_ooo`07o`00o`04oeEEZOooo`3oool0ogMgQ`Ko003o00CoIVJHoooo0?ooo`3oEEFY1ol00?l2
oooo0:Wo003o0Oooool00:So003o00Coc<`boooo0?ooo`3oMgN71_l00?l01?nj^TCoool0oooo0?mg
MhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`08o`00o`;oool000?oZJUEo`00ool00?l01?l0
0?l00onYZEGoool0onk^4008o`00o`;oool0ZOl00?l1ooooo`00Yol00?l01OlQ8Mgoool0oooo0?oo
o`3o8B7M00Go003o00Go413^oooo0?ooo`3oool0ob4Qg@07o`00o`03oeEEZOoMgB7o003o00Ko003o
0_ooo`08o`00o`04ohN7Moooo`3oool0oa0@kPCo003o00Co413^oooo0?ooo`3oIVJH2?l00?l2oooo
0:Wo003o0Oooool00:Oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oMgB49
o`00o`03oooo0?lQ8Mgo003o00Go003o0_ooo`09o`00o`03omgM8Oooo`3oQhMg00Co003o00?oQhMg
oooo0?o<c3802Ol00?l2oooo0:Wo003o0Oooool00:Go003o00?o8B7MohN7Moooo`000_ooo`000oo^
kQ3o<S;<o`00o`03o`00o`06oeEEZOooo`3oool0oooo0?o^kQ3o<S;<1_l00?l01_lQ8MgoQhMgoooo
0?o^kQ3oEEFYoa0@kPCo003o0_ooo`09o`00o`04oa0@k_oMgB7oool0ogMgQ`;o413^00CoMgN7oooo
0?oMgB7o413^2Ol00?l2oooo0:Wo003o0Oooool00:Co003o00?oA4Bjoooo0?ooo`001oooo`000on7
QgOoool0oooo0007oooo00;o003o00?oQhMgoooo0?ooo`001Oooo`001?m4A;[o003oo`00ool00?l2
oooo0003ogMgQol00?oo003o00Oo003o00?o413^ohN7MooMgB400_ooo`000ooMgB7oQhMgo`00o`09
o`00o`03ogMgQoooo`3oool00:Wo003o0Oooool00<Ko003o1oooo`0Bo`00o`Ooool0ZOl00?l1oooo
o`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.7188 0 ]
[.5 1.04444 43.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(25) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
135.812 29.000 moveto
(D) show
146.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.998 .002 .998 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.998 .002 .998 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.998 .002 .998 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.998 .002 .998 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.989 .011 .989 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.998 .002 .998 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.988 .012 .988 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.99 .01 .99 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.987 .013 .987 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.998 .002 .998 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.979 .021 .979 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.998 .002 .998 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.964 .036 .964 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.966 .034 .966 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
.999 .001 .999 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.941 .059 .941 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.979 .021 .979 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.997 .003 .997 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.998 .002 .998 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.998 .002 .998 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.988 .012 .988 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.88 .12 .88 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.954 .046 .954 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.932 .068 .932 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.93 .07 .93 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.951 .049 .951 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.983 .017 .983 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.986 .014 .986 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
.998 .002 .998 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.937 .063 .937 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.976 .024 .976 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.895 .105 .895 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.984 .016 .984 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.976 .024 .976 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.957 .043 .957 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.97 .03 .97 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.914 .086 .914 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.984 .016 .984 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.939 .061 .939 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.998 .002 .998 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.988 .012 .988 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.926 .074 .926 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.775 .225 .775 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.813 .187 .813 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.988 .012 .988 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.991 .009 .991 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.961 .039 .961 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.998 .002 .998 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.926 .074 .926 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.917 .083 .917 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.809 .191 .809 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.789 .211 .789 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.738 .262 .738 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.919 .081 .919 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.939 .061 .939 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.998 .002 .998 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.938 .062 .938 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.989 .011 .989 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.785 .215 .785 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.968 .032 .968 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.965 .035 .965 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.819 .181 .819 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.742 .258 .742 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.866 .134 .866 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.608 .392 .608 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.614 .386 .614 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.664 .336 .664 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.802 .198 .802 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.814 .186 .814 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.97 .03 .97 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.638 .362 .638 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.622 .378 .622 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.934 .066 .934 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.991 .009 .991 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.998 .002 .998 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.693 .307 .693 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.738 .262 .738 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.862 .138 .862 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.998 .002 .998 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.929 .071 .929 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.728 .272 .728 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.83 .17 .83 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.593 .407 .593 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.851 .149 .851 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.723 .277 .723 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.989 .011 .989 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.529 .471 .529 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.577 .423 .577 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.96 .04 .96 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.556 .444 .556 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.538 .462 .538 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.876 .124 .876 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.981 .019 .981 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.663 .337 .663 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.526 .474 .526 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.548 .452 .548 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.838 .162 .838 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.578 .422 .578 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.648 .352 .648 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.984 .016 .984 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.548 .452 .548 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.499 .501 .499 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.521 .479 .521 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.495 .505 .495 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.583 .417 .583 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.624 .376 .624 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.938 .062 .938 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.657 .343 .657 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.753 .247 .753 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.504 .496 .504 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.491 .509 .491 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.497 .503 .497 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.515 .485 .515 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.52 .48 .52 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.757 .243 .757 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.88 .12 .88 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
.998 .002 .998 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.951 .049 .951 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.655 .345 .655 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.512 .488 .512 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.773 .227 .773 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.986 .014 .986 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.54 .46 .54 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.591 .409 .591 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.522 .478 .522 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.56 .44 .56 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.901 .099 .901 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.577 .423 .577 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.998 .002 .998 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.516 .484 .516 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.967 .033 .967 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.993 .007 .993 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.88 .12 .88 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.899 .101 .899 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.583 .417 .583 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.977 .023 .977 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.496 .504 .496 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.49 .51 .49 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.702 .298 .702 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.771 .229 .771 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.521 .479 .521 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.552 .448 .552 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.649 .351 .649 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.78 .22 .78 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
.998 .002 .998 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.523 .477 .523 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.998 .002 .998 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.987 .013 .987 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.507 .493 .507 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.55 .45 .55 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.584 .416 .584 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.946 .054 .946 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.642 .358 .642 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.988 .012 .988 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.661 .339 .661 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.599 .401 .599 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.569 .431 .569 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.899 .101 .899 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.941 .059 .941 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.87 .13 .87 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.545 .455 .545 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.65 .35 .65 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.709 .291 .709 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.848 .152 .848 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.959 .041 .959 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.998 .002 .998 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.989 .011 .989 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.655 .345 .655 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.759 .241 .759 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.624 .376 .624 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.968 .032 .968 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.915 .085 .915 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.998 .002 .998 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.856 .144 .856 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.968 .032 .968 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.989 .011 .989 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.653 .347 .653 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.715 .285 .715 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.988 .012 .988 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.693 .307 .693 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.9 .1 .9 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.831 .169 .831 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.839 .161 .839 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.761 .239 .761 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.973 .027 .973 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.943 .057 .943 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.942 .058 .942 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.963 .037 .963 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.808 .192 .808 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.992 .008 .992 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.964 .036 .964 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.809 .191 .809 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.805 .195 .805 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.926 .074 .926 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.87 .13 .87 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.998 .002 .998 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.989 .011 .989 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.969 .031 .969 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.989 .011 .989 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.829 .171 .829 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.988 .012 .988 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.962 .038 .962 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.937 .063 .937 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.998 .002 .998 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.921 .079 .921 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.885 .115 .885 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.998 .002 .998 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.931 .069 .931 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.998 .002 .998 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.998 .002 .998 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.898 .102 .898 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.998 .002 .998 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.928 .072 .928 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.998 .002 .998 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.934 .066 .934 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.971 .029 .971 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.953 .047 .953 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.985 .015 .985 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.989 .011 .989 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.967 .033 .967 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.926 .074 .926 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.963 .037 .963 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.987 .013 .987 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.975 .025 .975 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.978 .022 .978 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.998 .002 .998 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.958 .042 .958 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.988 .012 .988 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.998 .002 .998 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.991 .009 .991 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.991 .009 .991 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.964 .036 .964 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.99 .01 .99 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.989 .011 .989 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.967 .033 .967 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.997 .003 .997 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.998 .002 .998 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.988 .012 .988 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.998 .002 .998 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.998 .002 .998 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.998 .002 .998 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.998 .002 .998 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.998 .002 .998 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.998 .002 .998 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?om0_goo@;mo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?om
0_goo@;m00Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo@;mo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ood2oOom0_goo@;mo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bood2o@Co00000ool0o`00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ood2o@03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o008oo`3o003o`00
0?om0_goo@;m013oo@;m00?o0000oo`3o?ol0o`01Ool0o`00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ood2oOl0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo@;mood2o@05ood2o@03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?ol
0ocoo0?l00Woo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?oo
0?ooo`3o00ooo`3o00Co0000oo`3o?ol0ocoo0?l0_l0000?ool0o`;o00001?om0_d00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo0?lo`00000?ool0o`03
o`000?ol0ocoo0?l00Woo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo0?loo`3o008oo`3o003
o`000?oo0?ooo`3o00goo`3o00?o0000oo`3o?ol0o`01?ol0o`3o`0000Woo`3o0ol00006ood2o@03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l03?oo0?l2o`0000?oo0?l
00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?om0_goo@;m00coo@;m
00?o0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?ol0ocoo0?l00Soo0?l
0_l00005ool0o`;o00002Oom0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo0?loo`3o003oo`3o003o`000?oo
0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`02ool0o`00ol0003oo@;mood2o@0<ood2o@03o`000?ol
0ocoo0?l00_oo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o00;oo`3o0;o000000?o
o`3oo`000?l000003?om0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ood2o@03o`000?oo0?oo
o`3o00Soo`3o0_l00007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`03?ol0o`0
0ol0003oo@;mood2o@0:ood2o@03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l01ooo0?l2
o`00013oo0?l00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo@;mo`000009ool0
o`03o`000?om0_goo@;m00goo@;m0_l00008ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0
oooo0?l02_oo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?om0_goo@;m00Woo@;m00?o0000oo`3
o?ol0o`03_ol0o`00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ood2
oOom0_d03?om0_d00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo@;mood2oOom0_d2o`0000Goo`3o0_l0000?ood2
o@04o`000?ok1?_on`Cko`0000Koo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo`3oool0o`09
ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o00?
oo`3o003o`000?oo0?ooo`3o00?oo`3o00?o0000oo`3o?ol0o`04Ool0o`00ol0003oo@;mood2o@0=
ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo@;mood2o@04ood2o@05o`000?oo0?ooo`3o
ool0ool000003oom0_d2o`0000Con`Ck00Co0000ool0oooo0?ooo`3o0_l0000<oo`3o003o`000?oo
0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo@;mood2o@06ood2o@03o`000?ol
0ocoo0?l017oo0?l00Go0000ool0oooo0?ooo`3oo`00000Doo`3o003o`000?om0_goo@;m00goo@;m
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m00Goo@;m00?o0000ool0ool000003oom
0_d00ol0003on`Ckoo/4n`05oo/4n`03o`000?oo0?oo000000ooo0?l00?o0000ool0oooo0?l02?oo
0?l00ol0003oo0?loo`3o00>oo`3o003o`000?om0_goo@;m00Koo@;m00?o0000oo`3o?ol0o`04_ol
0o`00ol0003oo`3oo`00000Doo`3o003o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ood2oOom0_d01oom0_d00ol0003oo@;mood2o@0<ood2o@;o00002Ook1?/00ol0003oo0?loo`3o00>
oo`3o003o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`03ool0o`00ol0003oo@;mood2o@04
ood2o@03o`000?ol0ocoo0?l01Coo0?l00?o0000oo`3o?ol0o`04ool0o`00ol0003oo@;mood2o@0?
ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?om0_goo@;m
00Soo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4n`09oo/4n`03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o00?oo`3o003o`000?om0_goo@;m
00Coo@;m00?o0000oo`3o?ol0o`05?ol0o`00ol0003oo0?loo`3o00Coo`3o003o`000?om0_goo@;m
00ooo@;m00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ood2oOom
0_d02?om0_d2o`0000gon`Ck00?o0000oo`3o?ol0o`03_ol0o`00ol0003oo`3oool0o`06ool0o`03
o`000?ol0ocoo0?l017oo0?l00Co0000ood2oOom0_goo@;m0ol0000Foo`3o003o`000?ol0ocoo0?l
01?oo0?l00?o0000ood2oOom0_d03oom0_d00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ok1?_on`Ck
00gon`Ck1?l0000>oo`3o003o`000?oo0?ooo`3o00Goo`3o00?o0000oo`3o?ol0o`04Ool0o`01?l0
003oo@;mo`000?l00003ooL8m`?o00004ool0o`00ol0003oo0?loo`3o00Coo`3o003o`000?om0_go
o@;m013oo@;m00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`0>oo/4
n`04o`000?oc3??ol`ccoo<<l`Go00002Ool0o`00ol0003oo`3oool0o`05ool0o`03o`000?ol0oco
o0?l01;oo0?l00?o0000ooL8moog2?L01_og2?L2o`00013oo0?l0ol0000Coo`3o003o`000?om0_go
o@;m017oo@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ood2
oOom0_d03?om0_d00ol0003oo@;mood2o@03ood2o@;o00004?ok1?/00ol0003ol`ccoo<<l`07oo<<
l`Go00001Ool0o`00ol0003oo`3oool0o`03ool0o`?o00004ool0o`00ol0003om`SgooL8m`08ooL8
m`;o00002ool0o`3o`0000?omPWf00?o0000oo`3o?ol0o`04?ol0o`00ol0003oo@;mood2o@0Aood2
o@03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d00_om0_d00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?oc3??ol`cc00col`cc1_l00002ool0o`?o00000ooj1OX3o`0000oo
o0?l00?o0000ooL8moog2?L02oog2?L3o`0000Koo0?l0_l00007ooH9mP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ood2oOom0_d04_om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo@;mood2o@02o`0001?on`Ck00?o0000oo<<looc3?<04Ooc3?<3o`0000WonPGj
0_l0000<oo`3o003o`000?og2?Oom`Sg00oom`Sg0_l000001?ol0oco0000o`000?l0000:ooH9mP03
o`000?ol0ocoo0?l00koo0?l00?o0000ood2oOom0_d04_om0_d00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;m
ood2o@0?ood2o@;o00005?ok1?/00ol0003ol`ccoo<<l`0Coo<<l`03o`000?oj1O[onPGj00[onPGj
0_l00009oo`3o003o`000?og2?Oom`Sg01;om`Sg00?o0000ooH9m_of2OH03?of2OH00ol0003oo0?l
oo`3o00=oo`3o003o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l00_oo0?l7o`0000Coo@;m
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo@;mood2o@0@ood2o@03o`000?ok1?_on`Ck01?on`Ck00?o0000oo<<looc3?<04_oc
3?<00ol0003onPGjooX5nP0=ooX5nP?o00001Ool0o`00ol0003om`SgooL8m`0CooL8m`03o`000?of
2OKomPWf00gomPWf00?o0000oo`3o?ol0o`02ool0o`00ol0003oo@;mood2o@0Dood2o@Co00002oom
0_d00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?om0_goo@;m013oo@;m0_l0000Eoo/4n`03o`000?oc3??ol`cc01;ol`cc00?o0000
ooX5n_oj1OX04?oj1OX2o`0000;oo0?l00?o0000ooL8moog2?L05?og2?L00ol0003omPWfooH9mP0>
ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o0000ood2oOom0_d04oom0_d00ol0003oo@;mood2o@0>
ood2o@03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo@;mood2o@0=ood2o@?o00000_og2?L00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?oc3??ol`cc
01?ol`cc00?o0000ooX5n_oj1OX04_oj1OX2o`0001Oom`Sg00?o0000ooH9m_of2OH03oof2OH=o`00
017oo@;m1?l0000Aood2o@03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?ol0oco0000o`000?oo0?oo00003Oom0_d3o`0000Kom`Sg00?o0000oo/4nook1?/04?ok1?/0
0ol0003ol`ccoo<<l`0Boo<<l`03o`000?oj1O[onPGj01?onPGj00?o0000oo0?l?l000005Oog2?L0
0ol0003omPWfooH9mP0@ooH9mP03o`000?of2OKomPWf00WomPWf00?o0000ood2oOom0_d02?om0_d7
o`0000?om`Sg00?o0000ood2oOom0_d03oom0_d00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo0?loo`3o002oo`3o0;o00002_om0_d3o`0000[om`Sg0_l0000@oo/4
n`03o`000?oc3??ol`cc01;ol`cc00?o0000ooX5n_oj1OX04_oj1OX01Ol0003ol0o`oo0?l?o`3o3o
000001Com`Sg00?o0000ooH9m_of2OH03oof2OH00ol0003omPWfooH9mP0;ooH9mP04o`000?om0_go
o@;mood2o@Ko00002_og2?L00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ood2oOom0_d01?om0_d3
o`0000gom`Sg00Co0000ondBkOl0003o00003Ook1?/00ol0003ol`ccoo<<l`0Boo<<l`03o`000?oj
1O[onPGj01?onPGj00?o0000oo0?l?o`3o000_o`3o000ol0003om`SgooL8m`0AooL8m`03o`000?of
2OKomPWf00oomPWf00?o0000ooH9m_of2OH03?of2OH3o`00013om`Sg00?o0000ood2oOom0_d03oom
0_d00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o007
oo`3o003o`000?om0_goo@;m00?o00003oog2?L00ol0003okA;]ondBk@02ondBk@;o00002ook1?/0
0ol0003ol`ccoo<<l`0Boo<<l`03o`000?oj1O[onPGj01;onPGj00?o0000oo0?l?o`3o001?o`3o00
0ol0003om`SgooL8m`0@ooL8m`03o`000?of2OKomPWf00komPWf00?o0000ooH9m_of2OH03Oof2OH0
0ol0003om`SgooL8m`0AooL8m`03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000oo`3o?ol0o`02Ool0o`2o`00017om`Sg00?o0000ondB
kOo]4^d01Oo]4^d2o`0000Won`Ck00?o0000oo<<looc3?<04_oc3?<00ol0003onPGjooX5nP0BooX5
nP03o`000?o`3o3ol0o`00Gol0o`00?o0000ooL8moog2?L03oog2?L00ol0003omPWfooH9mP0>ooH9
mP03o`000?of2OKomPWf00gomPWf00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00[o
o0?l00?o0000ooL8moog2?L04?og2?L00ol0003okA;]ondBk@07ondBk@03o`000?ok1?_on`Ck00Go
n`Ck00?o0000oo<<looc3?<04_oc3?<00ol0003onPGjooX5nP0CooX5nP03o`000?o`3o3ol0o`00Ko
l0o`00?o0000ooL8moog2?L03_og2?L00ol0003omPWfooH9mP0=ooH9mP03o`000?of2OKomPWf00ko
mPWf00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000ooL8moog2?L0
3oog2?L00ol0003okA;]ondBk@09ondBk@;o00001Ook1?/00ol0003ol`ccoo<<l`0Boo<<l`03o`00
0?oj1O[onPGj01;onPGj00?o0000oo0?l?o`3o002?o`3o000ol0003om`SgooL8m`0=ooL8m`03o`00
0?of2OKomPWf00gomPWf00?o0000ooH9m_of2OH03_of2OH00ol0003om`SgooL8m`0AooL8m`03o`00
0?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000oo`3o?ol0o`02ool0o`00ol0003om`SgooL8m`0?ooL8m`03o`000?o]4^gokA;]00_okA;]0_l0
0003oo/4n`03o`000?oc3??ol`cc01;ol`cc00?o0000ooX5n_oj1OX04_oj1OX00ol0003ol0o`oo0?
l009oo0?l003o`000?og2?Oom`Sg00_om`Sg00?o0000ooH9m_of2OH03Oof2OH00ol0003omPWfooH9
mP0?ooH9mP03o`000?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d04?om0_d00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?og2?Oo
m`Sg00kom`Sg00?o0000ondBkOo]4^d03_o]4^d3o`0001?ol`cc0ol0000CooX5nP03o`000?o`3o3o
l0o`00_ol0o`00?o0000ooL8moog2?L02_og2?L00ol0003omPWfooH9mP0=ooH9mP03o`000?of2OKo
mPWf00oomPWf00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00com`Sg00?o0000ondB
kOo]4^d04Oo]4^d00ol0003ol`ccoo<<l`0?oo<<l`;o00000ooV6NH00ol0003onPGjooX5nP0@ooX5
nP03o`000?o`3o3ol0o`00col0o`00?o0000ooL8moog2?L02Oog2?L00ol0003omPWfooH9mP0=ooH9
mP03o`000?of2OKomPWf013omPWf00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?ol0ocoo0?l00ooo0?l00?o0000ooL8moog2?L03?og2?L00ol0003okA;]ondBk@0AondBk@03
o`000?oc3??ol`cc00gol`cc0_l00006onHIiP;o00003ooj1OX00ol0003ol0o`oo0?l00>oo0?l003
o`000?og2?Oom`Sg00Som`Sg00?o0000ooH9m_of2OH03?of2OH00ol0003omPWfooH9mP0AooH9mP03
o`000?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d03oom0_d00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooL8moog2?L02oog2?L00ol0003okA;]ondBk@0CondBk@03o`000?oc3??ol`cc00[ol`cc
0_l0000:onHIiP03o`000?oj1O[onPGj00conPGj00?o0000oo0?l?o`3o003oo`3o000ol0003om`Sg
ooL8m`07ooL8m`03o`000?of2OKomPWf00comPWf00?o0000ooH9m_of2OH04Oof2OH00ol0003om`Sg
ooL8m`0AooL8m`03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og
2?Oom`Sg00[om`Sg00?o0000ondBkOo]4^d05Oo]4^d00ol0003ol`ccoo<<l`06oo<<l`?o00003OoV
6NH2o`0000_onPGj00?o0000oo0?l?o`3o004Oo`3o000ol0003om`SgooL8m`06ooL8m`03o`000?of
2OKomPWf00_omPWf00?o0000ooH9m_of2OH04_of2OH00ol0003om`SgooL8m`0AooL8m`03o`000?om
0_goo@;m013oo@;m00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000oo`3o?ol0o`04Ool0o`00ol0003om`SgooL8m`0:ooL8m`03o`000?o]4^go
kA;]01GokA;]00?o0000oo<<looc3?<01?oc3?<2o`0001;oiQWV00?o0000ooX5n_oj1OX02?oj1OX0
0ol0003ol0o`oo0?l00Boo0?l003o`000?og2?Oom`Sg00Gom`Sg00?o0000ooH9m_of2OH02oof2OH0
0ol0003omPWfooH9mP0BooH9mP03o`000?og2?Oom`Sg017om`Sg00?o0000ood2oOom0_d04?om0_d2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000oo`3o?ol0o`04_ol0o`00ol0
003om`SgooL8m`09ooL8m`03o`000?o]4^gokA;]01OokA;]00Co0000oo<<looc3??ol`cc0_l0000E
onHIiP03o`000?oj1O[onPGj00KonPGj00?o0000oo0?l?o`3o005?o`3o000ol0003om`SgooL8m`03
ooL8m`03o`000?of2OKomPWf00SomPWf1Ol0000CooH9mP?o00004_og2?L00ol0003oo@;mood2o@0@
ood2o@03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo0?l01Coo0?l00?o0000ooL8
moog2?L02Oog2?L00ol0003okA;]ondBk@0HondBk@?o00006?oV6NH2o`0000KonPGj00?o0000oo0?
l?o`3o005Oo`3o000ol0003om`SgooL8m`02ooL8m`04o`000?of2OKomPWfooH9mPOo00001Oo]4^d0
0ol0003omPWfooH9mP0?ooH9mP04o`000?o]4^gokA;]ondBk@;o00004Oog2?L00ol0003oo@;mood2
o@0>ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo0?l00?o0000ooL8moog2?L02?og2?L0
0ol0003okA;]ondBk@0GondBk@Go00006_oV6NH00ol0003onPGjooX5nP03ooX5nP03o`000?o`3o3o
l0o`01Kol0o`00Co0000ooL8moog2?Oom`Sg1?l0000=ondBk@03o`000?of2OKomPWf00gomPWf00?o
0000ondBkOo]4^d01?o]4^d2o`0000oom`Sg00?o0000ood2oOom0_d02_om0_d4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo0?loo`3o002o`0001Goo0?l00?o0000ooL8moog2?L01_og2?L00ol0003okA;]ondBk@0E
ondBk@?o000000KofBKIo`000?oF:MKo0000ol0o`?l0000JonHIiP;o00000_oj1OX00ol0003ol0o`
oo0?l00Hoo0?l003o`000?og2?Oo000001;okA;]00?o0000ooH9m_of2OH02_of2OH2o`0000WokA;]
0_l00007ooL8m`So00001?om0_d7o`0000?oo@;m00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?ol
0ocoo0?loo`3o?l0003om0_d0ol0000Boo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000ondBkOo]
4^d04_o]4^d3o`0000?ofBKI00Co0000omHYe_oF:MKo00000_o0?l000ol0003oiQWVonHIiP0IonHI
iP03o`000?oj1O[o000001_ol0o`00?o0000ondBkOo]4^d04_o]4^d00ol0003omPWfooH9mP08ooH9
mP03o`000?o]4^gokA;]00_okA;]1ol00008ooH9mPCo00002oom0_d00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000oo`3o?ol0o`00_ol0o`00ol0003om0_doo@;m002oo@;m0?o00003ool0o`00ol0003o
m`SgooL8m`05ooL8m`03o`000?o]4^gokA;]013okA;]0ol00005omTVf@05o`000?oF:MKoeRWFomHY
e_l000000oo0?l000ol0003oiQWVonHIiP0IonHIiP03o`000?o`3o3ol0o`01[ol0o`00?o0000ondB
kOo]4^d04oo]4^d00ol0003omPWfooH9mP06ooH9mP03o`000?o]4^gokA;]00cokA;]00?o0000ooH9
m_of2OH03?of2OH00ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o0?loo`3o003oo`3o003o`000?od2oCom0_d00Gom0_d0ol0000;oo`3o0Co00001Oog2?L00ol0003o
kA;]ondBk@0=ondBk@?o00002?oI9]T01Ol0003oeRWFomHYe_oF:MKo000000Co`3o000?o0000onHI
i_oV6NH06?oV6NH00ol0003ol0o`oo0?l00Ioo0?l003o`000?o]4^gokA;]01GokA;]00?o0000ooH9
m_of2OH00oof2OH2o`0000ookA;]00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@0=ood2
o@03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo0?l00?o0000oo@;m?od2o@02?od2o@3o`0000Ko
o0?l0_l00004oo0?l0?o000000?om`Sgo`000?o]4^d03?o]4^d3o`0000[ofBKI00?o0000omHYe_oF
:MH00_oF:MH00ol0003o`3o0ol0o`003ol0o`003o`000?oV6NKoiQWV01OoiQWV00?o0000oo0?l?o`
3o006Oo`3o000ol0003okA;]ondBk@0FondBk@05o`000?of2OKomPWfooH9m_l000004Oo]4^d00ol0
003omPWfooH9mP0<ooH9mP03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?ol0ocoo0?l00Koo0?l00?o0000oo@;m?od2o@02ood2o@3o`000003oo`3o?l0003o000000Wo
l0o`0_l0000:ondBk@?o00003OoI9]T00ol0003oeRWFomHYeP02omHYeP03o`000?o0?l3o`3o000Co
`3o000?o0000onHIi_oV6NH05ooV6NH00ol0003ol0o`oo0?l00Hoo0?l003o`000?o]4^gokA;]01Oo
kA;]00?o0000ooH9m_l000004Oo]4^d00ol0003omPWfooH9mP0=ooH9mP03o`000?om0_goo@;m00ko
o@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo@;m?od2o@0
3_od2o@00ol0003ol0o`oo0?l00;oo0?l003o`000?o]4^gokA;]00CokA;]0ol0000?omTVf@03o`00
0?oF:MKoeRWF00?oeRWF00?o0000ol0o`?o0?l001Oo0?l000ol0003oiQWVonHIiP0FonHIiP03o`00
0?o`3o3ol0o`01Ool0o`00?o0000ondBkOo]4^d06Oo]4^d00ol0003okA;]ondBk@0@ondBk@03o`00
0?of2OKomPWf00gomPWf00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000oo`3o?ol0o`02?ol0o`00ol0003om0_doo@;m00>oo@;m003o`000?o`3o3ol0o`00col0o`00?o
0000ondBkOo]4^d00ol0000AomTVf@03o`000?oF:MKoeRWF00CoeRWF00?o0000ol0o`?o0?l001_o0
?l02o`0001GoiQWV0ol0000Hoo0?l003o`000?o]4^gokA;]01WokA;]00?o0000ondBkOo]4^d04?o]
4^d00ol0003omPWfooH9mP0=ooH9mP03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
oo`3o?ol0o`02Ool0o`00ol0003om0_doo@;m00>oo@;m003o`000?o`3o3ol0o`00gol0o`0_l0000D
omTVf@03o`000?oF:MKoeRWF00CoeRWF00?o0000ol0o`?o0?l002?o0?l000ol0003oiQWVonHIiP0@
onHIiP;o00000oo5>/D00ol0003ol0o`oo0?l00Doo0?l003o`000?o]4^gokA;]01[okA;]00?o0000
ondBkOo]4^d04?o]4^d00ol0003omPWfooH9mP0=ooH9mP03o`000?om0_goo@;m013oo@;m00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo0?l0_l0000?oo@;m003o`000?o`3o3ol0o`
00kol0o`00?o0000omTVfOoI9]T04_oI9]T00ol0003oeRWFomHYeP05omHYeP03o`000?o0?l3o`3o0
00Wo`3o000?o0000onHIi_oV6NH03OoV6NH2o`0000KoaC[50_l0000Doo0?l003o`000?o]4^gokA;]
01[okA;]00?o0000ondBkOo]4^d04?o]4^d00ol0003omPWfooH9mP0=ooH9mP03o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo@;m?l0
00003ood2o@00ol0003ol0o`oo0?l00>oo0?l003o`000?oI9]WofBKI01;ofBKI00?o0000omHYe_oF
:MH01OoF:MH00ol0003o`3o0ol0o`00:ol0o`003o`000?oV6NKoiQWV00[oiQWV0_l0000:olDja@03
o`000?o`3o3ol0o`017ol0o`00?o0000ondBkOo]4^d06_o]4^d00ol0003okA;]ondBk@0?ondBk@03
o`000?of2OKomPWf00komPWf00?o0000ood2oOom0_d04Oom0_d00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo0?loo`3o00:oo`3o004o`000?od2oCom0_do`0000oo
m0_d00?o0000oo0?l?o`3o003oo`3o000ol0003ofBKIomTVf@0@omTVf@03o`000?oF:MKoeRWF00Ko
eRWF00?o0000ol0o`?o0?l002oo0?l000ol0003oiQWVonHIiP08onHIiP03o`000?o5>/GoaC[500_o
aC[50_l0000@oo0?l003o`000?o]4^gokA;]01_okA;]00?o0000ondBkOo]4^d03oo]4^d00ol0003o
mPWfooH9mP0>ooH9mP03o`000?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?od2oCom0_d00;om0_d00?o0000oo@;m?od2o@0
3?od2o@00ol0003ol0o`oo0?l00?oo0?l003o`000?oI9]WofBKI00oofBKI00?o0000omHYe_oF:MH0
1ooF:MH00ol0003o`3o0ol0o`00<ol0o`003o`000?oV6NKoiQWV00GoiQWV0_l0000@olDja@03o`00
0?o`3o3ol0o`00gol0o`00?o0000ondBkOo]4^d06oo]4^d00ol0003okA;]ondBk@0?ondBk@03o`00
0?of2OKomPWf00komPWf00?o0000ood2oOom0_d04_om0_d00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<oo`3o003o`000?od2oCom0_d00?om0_d00?o0000oo@;m?od2o@02ood2o@00ol0003ol0o`oo0?
l00@oo0?l003o`000?oI9]WofBKI00oofBKI00?o0000omHYe_oF:MH01ooF:MH00ol0003o`3o0ol0o
`00=ol0o`003o`000?oV6NKoiQWV00;oiQWV0_l0000ColDja@;o00003?o`3o000ol0003okA;]ondB
k@0LondBk@?o00003oo]4^d00ol0003omPWfooH9mP0>ooH9mP03o`000?om0_goo@;m01;oo@;m00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo0?loo`3o00:oo`3o003o`000?od2oCo
m0_d00Com0_d00?o0000oo@;m?od2o@02ood2o@00ol0003ol0o`oo0?l00@oo0?l003o`000?oI9]Wo
fBKI00kofBKI00?o0000omHYe_oF:MH02?oF:MH00ol0003o`3o0ol0o`00>ol0o`004o`000?oV6NKo
0000o`0001OoaC[500?o0000oo0?l?o`3o002Oo`3o000ol0003okA;]ondBk@0LondBk@03o`000?oU
6^GoiA[U00?o00003?o]4^d00ol0003omPWfooH9mP0>ooH9mP03o`000?om0_goo@;m01?oo@;m00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo0?loo`3o009oo`3o003o`000?od2oCo
m0_d00Gom0_d00?o0000oo@;m?od2o@02ood2o@00ol0003ol0o`oo0?l00Aoo0?l003o`000?oI9]Wo
fBKI00cofBKI00?o0000omHYe_oF:MH02OoF:MH00ol0003o`3o0ol0o`00?ol0o`003o`000?o5>/Go
aC[501SoaC[50_l00009oo0?l003o`000?o]4^gokA;]01_okA;]00?o0000onDJiOoU6^D01?oU6^D4
o`0000SokA;]00?o0000ooH9m_of2OH03_of2OH00ol0003oo@;mood2o@0Cood2o@03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000oo@;m?od2o@01_od2o@00ol0
003om0_doo@;m00;oo@;m003o`000?o`3o3ol0o`013ol0o`0_l0000>omTVf@03o`000?oF:MKoeRWF
00WoeRWF00?o0000ol0o`?o0?l003oo0?l000ol0003oaC[5olDja@0JolDja@03o`000?o`3o3ol0o`
00Col0o`0ol0000LondBk@03o`000?oU6^GoiA[U00WoiA[U0ol00004ondBk@03o`000?of2OKomPWf
00oomPWf00?o0000ood2oOom0_d05?om0_d2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o006oo`3o003
o`000?od2oCom0_d00Som0_d00?o0000oo@;m?od2o@02Ood2o@00ol0003ol0o`oo0?l00@oo0?l004
o`000?oA;]7odBkAo`0000cofBKI00?o0000omHYe_oF:MH02_oF:MH00ol0003o`3o0ol0o`00?ol0o
`003o`000?o5>/GoaC[501_oaC[50_l00003oo0?l004o`000?oD:mCoe2_Dom@[e0?o00006?o]4^d0
0ol0003oiA[UonDJi@0=onDJi@?o000000?okA;]o`000?of2OH04?of2OH00ol0003oo@;mood2o@0D
ood2o@03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo0?loo`3o004oo`3o003o`000?od2oCom0_d
00Wom0_d00?o0000oo@;m?od2o@02Ood2o@00ol0003ol0o`oo0?l00?oo0?l003o`000?oA;]7odBkA
00;odBkA00?o0000omTVfOoI9]T02OoI9]T00ol0003oeRWFomHYeP0:omHYeP03o`000?o0?l3o`3o0
00ko`3o000?o0000olDjaOo5>/D07_o5>/D00ol0003ol0o`o`000007om@[e0?o00005?o]4^d00ol0
003oiA[UonDJi@0AonDJi@;o00004Oof2OH00ol0003oo@;mood2o@0Cood2o@03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo0?loo`3o003oo`3o003o`000?od2oCom0_d00[om0_d00?o0000oo@;m?od
2o@02Ood2o@00ol0003ol0o`oo0?l00=oo0?l0;o00001_oA;]400ol0003ofBKIomTVf@07omTVf@03
o`000?oF:MKoeRWF00_oeRWF00?o0000ol0o`?o0?l003_o0?l000ol0003oaC[5olDja@0OolDja@03
o`000?oD:mCoe2_D00Woe2_D0ol0000@ondBk@03o`000?oU6^GoiA[U01?oiA[U00?o0000ooH9m_of
2OH03_of2OH4o`00017oo@;m0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000oo`3o?ol0o`00_ol0o`00ol0003om0_d
oo@;m00;oo@;m003o`000?od2oCom0_d00Wom0_d00?o0000oo0?l?o`3o003?o`3o000ol0003odBkA
om4^d@07om4^d@03o`000?oI9]WofBKI00GofBKI00?o0000omHYe_oF:MH03?oF:MH00ol0003o`3o0
ol0o`00>ol0o`003o`000?o5>/GoaC[501ooaC[500?o0000om@[e?oD:m@03?oD:m@3o`0000gokA;]
00?o0000onDJiOoU6^D05?oU6^D00ol0003omPWfooH9mP0;ooH9mP;o00001?of2OH5o`0000Woo@;m
0ol000000ool0oco0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ool0oco0000oo@;m00=oo@;m003o`000?od
2oCom0_d00Som0_d00?o0000oo0?l?o`3o002oo`3o02o`0000_odBkA00?o0000omTVfOoI9]T01?oI
9]T00ol0003oeRWFomHYeP0<omHYeP03o`000?o0?l3o`3o000ko`3o000?o0000olDjaOo5>/D07_o5
>/D00ol0003oe2_Dom@[e00@om@[e0?o00002Oo]4^d00ol0003oiA[UonDJi@0FonDJi@Oo00001Oof
2OH00ol0003omPWfooH9mP09ooH9mPCo00000_om0_d3o`0000Goo0?l00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?oj1O[onPGjooX5n_l000004?od2o@00ol0003om0_doo@;m007oo@;m003o`000?o`
3o3ol0o`00[ol0o`00?o0000om4^dOoA;]403?oA;]400ol0003ofBKIomTVf@02omTVf@03o`000?oF
:MKoeRWF00goeRWF00?o0000ol0o`?o0?l003_o0?l000ol0003oaC[5olDja@0NolDja@03o`000?oD
:mCoe2_D01?oe2_D0ol00005ondBk@03o`000?oU6^GoiA[U01OoiA[U00?o0000ondBkOo]4^d01?o]
4^d5o`00013omPWf0_l00008oo`3o003o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003onPGjooX5nP03
ooX5nQ;o00002?od2o@00ol0003ol0o`oo0?l009oo0?l003o`000?oA;]7odBkA00kodBkA00Go0000
omTVfOoI9]WofBKIo`00000?omHYeP03o`000?o0?l3o`3o000go`3o000?o0000olDjaOo5>/D07oo5
>/D00ol0003oe2_Dom@[e00Fom@[e0?o000000?okA;]o`000?oU6^D06?oU6^D00ol0003okA;]ondB
k@09ondBk@03o`000?of2OKomPWf00oomPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooX5nP03o`000?o^4NkokQ7^00ookQ7^0_l00006oo@;m003o`000?o`3o3o
l0o`00Ool0o`0_l0000Bom4^d@03o`000?oI9]Wo0000013oeRWF00?o0000ol0o`?o0?l002oo0?l03
o`00023oaC[500?o0000om@[e?oD:m@06_oD:m@00ol0003oiA[UonDJi@0HonDJi@03o`000?o]4^go
kA;]00WokA;]00?o0000ooH9m_of2OH03oof2OH00ol0003oo0?loo`3o007oo`3o003o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003onPGjooX5nP06ooX5nP03o`000?o^4NkokQ7^017okQ7^00?o0000oo@;
m?od2o@00_od2o@00ol0003ol0o`oo0?l007oo0?l003o`000?oA;]7odBkA01?odBkA00?o0000omHY
e_oF:MH03ooF:MH00ol0003o`3o0ol0o`007ol0o`0Co00000_nWF:L00ol0003oaC[5olDja@0NolDj
a@03o`000?oD:mCoe2_D01[oe2_D00?o0000onDJiOoU6^D05ooU6^D00ol0003okA;]ondBk@0:ondB
k@03o`000?of2OKomPWf00oomPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooX5n_oj1OX01ooj1OX00ol0003okQ7^onhAkP0BonhAkPKo00001_o`3o02o`0001Ko
dBkA00?o0000omHYe_oF:MH03ooF:MH00ol0003o`3o0ol0o`003ol0o`0Co00001onWF:L00ol0003o
aC[5olDja@0LolDja@03o`000?oD:mCoe2_D01coe2_D00?o0000onDJiOoU6^D05OoU6^D00ol0003o
kA;]ondBk@0;ondBk@03o`000?of2OKomPWf00oomPWf00?o0000oo`3o?ol0o`02?ol0o`00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooX5nP03o`000?o^4NkokQ7^01;okQ7^00?o0000onTFjOoY5^T0
0ooY5^T2o`0000?ol0o`00?o0000om4^dOoA;]405ooA;]400ol0003oeRWFomHYeP0>omHYeP03o`00
0?o0?l3o000000?o00003?nWF:L00ol0003oaC[5olDja@0KolDja@03o`000?oD:mCoe2_D01coe2_D
00?o0000onDJiOoU6^D05OoU6^D00ol0003okA;]ondBk@0<ondBk@03o`000?of2OKomPWf00gomPWf
00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooX5n_oj1OX02_oj
1OX00ol0003okQ7^onhAkP0AonhAkP03o`000?oY5^WojAKY00KojAKY00?o0000oo0?l?l000006_oA
;]45o`0000_oeRWF0ol0000AojMHY`03o`000?o5>/GoaC[501[oaC[500?o0000om@[e?oD:m@07OoD
:m@00ol0003oiA[UonDJi@0ConDJi@03o`000?o]4^gokA;]00gokA;]00?o0000ooH9m_of2OH03Oof
2OH00ol0003oo0?loo`3o00:oo`3o003o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?oj1O[onPGj00conPGj00?o0000
onhAk_o^4Nh03oo^4Nh00ol0003ojAKYonTFj@08onTFj@03o`000?oA;]7odBkA01WodBkA00?o0000
ojUFZOnYEZT00_nYEZT7o`0000?oeRWF00?o0000ojMHYonWF:L04onWF:L3o`0001OoaC[50_l0000P
om@[e003o`000?oU6^GoiA[U01?oiA[U00?o0000ondBkOo]4^d03Oo]4^d00ol0003omPWfooH9mP0=
ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003ooj1OX00ol0
003okQ7^onhAkP0>onhAkP03o`000?oY5^WojAKY00WojAKY00?o0000om4^dOoA;]406?oA;]400ol0
003oZEJYojUFZ@0:ojUFZ@?o00005_nWF:L00ol0003oUFZEoiEZU@05o`00013oaC[50_l000000onY
EZWo0000om@[e00Oom@[e003o`000?oU6^GoiA[U01;oiA[U00?o0000ondBkOo]4^d03_o]4^d00ol0
003omPWfooH9mP0=ooH9mP03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?ol0ocoo0?l00Coo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okQ7^onhAkP0>onhAkP03
o`000?oY5^WojAKY00[ojAKY00?o0000om4^dOoA;]405_oA;]400ol0003oZEJYojUFZ@0=ojUFZ@03
o`000?nWF:OoYeRW01?oYeRW00?o0000oiEZUOnEJYD01_nEJYD4o`0000_oaC[500?o0000ojUFZOnY
EZT00_nYEZT00ol0003oe2_Dom@[e00Nom@[e003o`000?oU6^GoiA[U013oiA[U00?o0000ondBkOo]
4^d03oo]4^d00ol0003omPWfooH9mP0<ooH9mP;o00003Ool0o`00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000oo`3o?ol0o`01Ool0o`00ol0003onPGjooX5nP0<ooX5nP03o`000?o^4NkokQ7^00gokQ7^
00?o0000onTFjOoY5^T03?oY5^T00ol0003odBkAom4^d@0Dom4^d@03o`000?nYEZWoZEJY00ooZEJY
00?o0000ojMHYonWF:L04_nWF:L00ol0003oUFZEoiEZU@0:oiEZU@Go00001?o5>/D2o`0000GoZEJY
00?o0000om@[e?oD:m@07_oD:m@00ol0003oiA[UonDJi@0@onDJi@03o`000?o]4^gokA;]00ookA;]
00?o0000ooH9m_of2OH02oof2OH00ol0003om`Sgo`00000>oo`3o003o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo0?loo`3o005oo`3o003o`000?oj1O[onPGj00_onPGj4?l0000?onTFj@03o`000?oA
;]7odBkA01CodBkA00?o0000ojUFZOnYEZT03onYEZT00ol0003oYeRWojMHY`0BojMHY`03o`000?nE
JYGoUFZE00ooUFZE1?l00008ojUFZ@03o`000?oD:mCoe2_D01koe2_D00?o0000onDJiOoU6^D03_oU
6^D00ol0003okA;]ondBk@0@ondBk@03o`000?of2OKomPWf00WomPWf0_l00003ooL8m`03o`000?ol
0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000
ooX5n_oj1OX02ooj1OX00ol0003okQ7^onhAkP0<onhAkP03o`000?oY5^WojAKY00kojAKY00?o0000
om4^dOoA;]404_oA;]400ol0003oZEJYojUFZ@0@ojUFZ@03o`000?nWF:OoYeRW017oYeRW00?o0000
oiEZUOnEJYD04OnEJYD00ol0003oUFZEo`000009ojUFZ@03o`000?oD:mCoe2_D01goe2_D00?o0000
onDJiOoU6^D03_oU6^D00ol0003okA;]ondBk@0@ondBk@03o`000?of2OKomPWf00OomPWf0_l00005
ooL8m`03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?ol0ocoo0?l
00Koo0?l00?o0000ooX5n_oj1OX02_oj1OX00ol0003okQ7^onhAkP0<onhAkP03o`000?oY5^WojAKY
00oojAKY00?o0000om4^dOoA;]403_oA;]43o`0001CoZEJY00?o0000ojMHYonWF:L04?nWF:L00ol0
003oUFZEoiEZU@0@oiEZU@04o`000?nEJYGoUFZEo`0000WoZEJY00?o0000om@[e?oD:m@07_oD:m@0
0ol0003oiA[UonDJi@0<onDJi@03o`000?o]4^gokA;]017okA;]00?o0000ooH9m_of2OH01_of2OH0
0ol0003om`SgooL8m`06ooL8m`03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?ol0ocoo0?l00Ooo0?l00?o0000ooX5n_oj1OX02Ooj1OX00ol0003okQ7^onhAkP0;onhA
kP03o`000?oY5^WojAKY013ojAKY00?o0000om4^dOoA;]402_oA;]44o`0000;oZEJY00?o0000ojUF
ZOnYEZT04_nYEZT00ol0003oYeRWojMHY`0@ojMHY`03o`000?nEJYGoUFZE00ooUFZE00Go0000oiEZ
UOnEJYGoUFZEo`00000:ojUFZ@03o`000?oD:mCoe2_D01goe2_D00?o0000onDJiOoU6^D02ooU6^D0
0ol0003okA;]ondBk@0CondBk@03o`000?of2OKomPWf00?omPWf0_l00009ooL8m`03o`000?ol0oco
o0?l00_oo0?l00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0ocoo0?l00Soo0?l00?o0000ooX5
n_oj1OX02?oj1OX00ol0003okQ7^onhAkP0;onhAkP03o`000?oY5^WojAKY017ojAKY00?o0000om4^
dOoA;]401OoA;]44o`0000OoZEJY00?o0000ojUFZOnYEZT04OnYEZT00ol0003oYeRWojMHY`0?ojMH
Y`03o`000?nEJYGoUFZE013oUFZE00Go0000oiEZUOnEJYGoUFZEo`00000:ojUFZ@03o`000?oD:mCo
e2_D01goe2_D00?o0000onDJiOoU6^D02ooU6^D00ol0003okA;]ondBk@0CondBk@04o`000?of2OKo
mPWfooH9mP;o00003?og2?L00ol0003oo0?loo`3o00;oo`3o0co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo0?loo`3o007oo`3o003o`000?oj1O[o
nPGj00OonPGj00?o0000onhAk_o^4Nh03?o^4Nh00ol0003ojAKYonTFj@0BonTFj@03o`000?oA;]7o
dBkA00Co00002onYEZT00ol0003oZEJYojUFZ@0BojUFZ@03o`000?nWF:OoYeRW00koYeRW00?o0000
oiEZUOnEJYD03onEJYD00ol0003oUFZEoiEZU@02oiEZU@03o`000?nYEZWoZEJY00WoZEJY00?o0000
om@[e?oD:m@07?oD:m@3o`0000[oiA[U00?o0000ondBkOo]4^d05?o]4^d01?l0003omPWfooH9m_l0
000>ooL8m`03o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0oco
o0?l00Soo0?l00?o0000ooX5n_oj1OX01_oj1OX00ol0003okQ7^onhAkP0;onhAkP03o`000?oY5^Wo
jAKY01;ojAKY00Co0000oll`col0003o00003onYEZT00ol0003oZEJYojUFZ@0AojUFZ@03o`000?n<
Lhco000000ooYeRW00?o0000oiEZUOnEJYD03_nEJYD00ol0003oUFZEoiEZU@03oiEZU@03o`000?nY
EZWoZEJY00WoZEJY00?o0000om@[e?oD:m@06OoD:m@3o`0000?occ3?00?o0000onDJiOoU6^D01ooU
6^D00ol0003okA;]ondBk@0CondBk@Go00003oog2?L00ol0003oo0?loo`3o008oo`3o003o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o009oo`3o003o`000?oj1O[onPGj00GonPGj00?o0000
onhAk_o^4Nh02oo^4Nh00ol0003ojAKYonTFj@0AonTFj@04o`000?o?<<oocc3?o`00017oZEJY00?o
0000ojUFZOnYEZT03onYEZT01Ol0003oS7><ohacS?n<Lhco000000[oYeRW1?l0000AoiEZU@03o`00
0?nEJYGoUFZE00?oUFZE00?o0000ojUFZOnYEZT02_nYEZT00ol0003oe2_Dom@[e00Fom@[e0;o0000
1oo?<<l00ol0003oiA[UonDJi@05onDJi@03o`000?o]4^gokA;]01?okA;]00?o0000ooD:mOoe2_D0
0ooe2_D00ol0003om`SgooL8m`0=ooL8m`03o`000?ol0ocoo0?l00Koo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?ol0ocoo0?l00Woo0?l00?o0000ooX5n_oj1OX01?oj1OX3o`0000cokQ7^00?o
0000onTFjOoY5^T04?oY5^T00ol0003occ3?oll`c`02oll`c`03o`000?nYEZWoZEJY00koZEJY00?o
0000ojUFZOnYEZT03_nYEZT00ol0003oS7><ohacS003ohacS004o`000?nWF:OoYeRWojMHY`Ko0000
0on:MHX00ol0003oUFZEoiEZU@0>oiEZU@03o`000?nEJYGoUFZE00CoUFZE00?o0000ojUFZOnYEZT0
2_nYEZT00ol0003oe2_Dom@[e00Com@[e0?o00002_o?<<l00ol0003oiA[UonDJi@03onDJi@03o`00
0?o]4^gokA;]01?okA;]00?o0000ooD:mOoe2_D01Ooe2_D2o`0000gom`Sg00?o0000oo`3o?ol0o`0
1Ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000oo`3o?ol0o`02Ool0o`00ol0003onPGjooX5
nP03o`0000?omPWf00?o0000onhAk_o^4Nh02?o^4Nh00ol0003ojAKYonTFj@0@onTFj@03o`000?o?
<<oocc3?00?occ3?00?o0000ojUFZOnYEZT03_nYEZT00ol0003oZEJYojUFZ@0=ojUFZ@03o`000?n<
LhcoS7><00GoS7><0ol0000:ohYeRP03o`000?nEJYGoUFZE00coUFZE00?o0000oiEZUOnEJYD01OnE
JYD00ol0003oZEJYojUFZ@0;ojUFZ@03o`000?oD:mCoe2_D013oe2_D0_l0000>oll`c`03o`000?oU
6^GoiA[U00;oiA[U00?o0000ondBkOo]4^d04_o]4^d00ol0003om@[eooD:m@08ooD:m@03o`000?og
2?Oom`Sg00_om`Sg00?o0000oo`3o?ol0o`00ool0o`00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
oo`3o?ol0o`02Ool0o`3o`0000OomPWf00?o0000onhAk_o^4Nh01oo^4Nh00ol0003ojAKYonTFj@0?
onTFj@03o`000?o?<<oocc3?00Cocc3?00?o0000ojUFZOnYEZT03onYEZT00ol0003oZEJYojUFZ@0;
ojUFZ@03o`000?n<LhcoS7><00KoS7><00?o0000ohYeR_n:MHX02on:MHX00ol0003oUFZEoiEZU@0;
oiEZU@03o`000?nEJYGoUFZE00GoUFZE00?o0000ojUFZOnYEZT03?nYEZT00ol0003oe2_Dom@[e00<
om@[e0?o00004Oo?<<l5o`0001;okA;]0_l0000<ooD:m@03o`000?og2?Oom`Sg00[om`Sg00?o0000
oo`3o?ol0o`00_ol0o`00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0
003omPWfooH9mP09ooH9mP;o00001oo^4Nh00ol0003ojAKYonTFj@0>onTFj@03o`000?o?<<oocc3?
00Kocc3?00?o0000ojUFZOnYEZT03_nYEZT00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?n<LhcoS7><
00OoS7><00?o0000ohYeR_n:MHX02on:MHX00ol0003oUFZEoiEZU@0:oiEZU@03o`000?nEJYGoUFZE
00KoUFZE00?o0000ojUFZOnYEZT03?nYEZT00ol0003oe2_Dom@[e00:om@[e0;o00005?o?<<l00ol0
003okQ7^onhAkP02onhAkP;o00003oo]4^d00ol0003om@[eooD:m@0=ooD:m@Go00002?og2?L01?l0
003oo0?loo`3o?l0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003omPWfooH9mP0<ooH9
mP03o`000?o^4NkokQ7^00?okQ7^00?o0000onTFjOoY5^T03_oY5^T00ol0003occ3?oll`c`07oll`
c`03o`000?nYEZWoZEJY00koZEJY00?o0000ojUFZOnYEZT02OnYEZT00ol0003oS7><ohacS008ohac
S003o`000?n:MH[oRWF:00coRWF:00?o0000oiEZUOnEJYD02?nEJYD00ol0003oUFZEoiEZU@07oiEZ
U@03o`000?nYEZWoZEJY00goZEJY1Ol00004om@[e0?o00005Oo?<<l00ol0003okQ7^onhAkP05onhA
kP03o`000?o]4^gokA;]00_okA;]00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@02ood2
o@Oo000000Com`Sgo`000?ol0oco00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9
m_of2OH03_of2OH2o`0000?okQ7^00?o0000onTFjOoY5^T03OoY5^T00ol0003occ3?oll`c`08oll`
c`03o`000?nYEZWoZEJY00ooZEJY00?o0000ojUFZOnYEZT01onYEZT00ol0003oS7><ohacS009ohac
S003o`000?n:MH[oRWF:00coRWF:0ol00008oiEZU@03o`000?nEJYGoUFZE00OoUFZE00?o0000ojUF
ZOnYEZT03OnYEZT00ol0003o/Djaok5>/@02ok5>/@Co00006?o?<<l00ol0003okQ7^onhAkP06onhA
kP;o00002Oo]4^d2o`00017om@[e00?o0000ood2oOom0_d02Oom0_d3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?ol0ocoo0?l00Co
o0?l00?o0000ooH9m_of2OH04Oof2OH01?l0003okQ7^onhAk_l0000>onTFj@03o`000?o?<<oocc3?
00[occ3?00?o0000ojUFZOnYEZT03_nYEZT00ol0003oZEJYojUFZ@06ojUFZ@03o`000?n<LhcoS7><
00[oS7><00?o0000ohYeR_n:MHX02_n:MHX2o`0000?oQGZ500?o0000oiEZUOnEJYD01?nEJYD00ol0
003oUFZEoiEZU@08oiEZU@03o`000?nYEZWoZEJY00coZEJY00?o0000ok5>/OnaC[401_naC[400ol0
003occ3?oll`c`0Eoll`c`03o`000?o^4NkokQ7^00WokQ7^0_l00006ondBk@03o`000?oe2_Gom@[e
013om@[e00?o0000ood2oOom0_d03?om0_d2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?ol0ocoo0?l00?o
o0?l00?o0000ooH9m_of2OH04oof2OH2o`0000kojAKY00?o0000oll`coo?<<l02oo?<<l00ol0003o
ZEJYojUFZ@0>ojUFZ@03o`000?nYEZWoZEJY00GoZEJY00?o0000ohacS?n<Lh`02on<Lh`00ol0003o
RWF:ohYeRP08ohYeRP;o00001_n5NXD00ol0003oUFZEoiEZU@02oiEZU@03o`000?nEJYGoUFZE00Wo
UFZE00?o0000ojUFZOnYEZT03?nYEZT00ol0003o/Djaok5>/@07ok5>/@03o`000?o?<<oocc3?01Co
cc3?00?o0000onhAk_o^4Nh02oo^4Nh00ol0003okA;]ondBk@02ondBk@03o`000?oe2_Gom@[e017o
m@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?ol0ocoo0?l00;oo0?l00?o0000ooH9m_of2OH05Oof2OH00ol0003ojAKYonTFj@0;onTFj@03o`00
0?o?<<oocc3?00gocc3?00?o0000ojUFZOnYEZT03_nYEZT00ol0003oZEJYojUFZ@03ojUFZ@03o`00
0?n<LhcoS7><00coS7><00?o0000ohYeR_n:MHX01_n:MHX2o`0000WoQGZ500Go0000oiEZUOnEJYGo
UFZEo`00000;oiEZU@03o`000?nYEZWoZEJY00coZEJY00?o0000ok5>/OnaC[401onaC[400ol0003o
cc3?oll`c`0Coll`c`03o`000?o^4NkokQ7^00gokQ7^0_l000000oo]4^go0000ooD:m@0CooD:m@03
o`000?om0_goo@;m00coo@;m00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?ol0ocoo0?loo`3o?l000006?of2OH00ol0003ojAKYonTFj@0:onTFj@03o`000?o?<<oocc3?00ko
cc3?00?o0000ojUFZOnYEZT03_nYEZT00ol0003oZEJYojUFZ@02ojUFZ@03o`000?n<LhcoS7><00go
S7><00?o0000ohYeR_n:MHX01?n:MHX2o`0000coQGZ500?o0000oiEZUOl000003?nEJYD00ol0003o
ZEJYojUFZ@0;ojUFZ@03o`000?naC[7o/Dja00Wo/Dja00?o0000oll`coo?<<l04Oo?<<l00ol0003o
kQ7^onhAkP0@onhAkP03o`000?oe2_Gom@[e01;om@[e00?o0000ood2oOom0_d03?om0_d00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WomPWf00?o0000onTFjOoY5^T0
2?oY5^T00ol0003occ3?oll`c`0?oll`c`03o`000?nYEZWoZEJY00koZEJY00Go0000ojUFZOnYEZWo
ZEJYo`00000@ohacS003o`000?n:MH[oRWF:00;oRWF:0_l0000?ohEjQ@03o`000?nEJYGoUFZE00_o
UFZE00?o0000ojUFZOnYEZT02onYEZT00ol0003o/Djaok5>/@09ok5>/@03o`000?o?<<oocc3?017o
cc3?00?o0000onhAk_o^4Nh04?o^4Nh2o`0001?om@[e00?o0000ood2oOom0_d03?om0_d00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo@;m
00?o0000ooH9m_of2OH05_of2OH3o`0000OojAKY00?o0000oll`coo?<<l04Oo?<<l00ol0003oZEJY
ojUFZ@0>ojUFZ@Co00004?n<Lh`00ol0003oRWF:ohYeRP02o`00017oQGZ500?o0000oiEZUOnEJYD0
2onEJYD00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?naC[7o/Dja00_o/Dja00?o0000oll`coo?<<l0
3oo?<<l00ol0003okQ7^onhAkP0AonhAkP03o`000?oj1O[o000000;o00004?oe2_D00ol0003oo@;m
ood2o@0<ood2o@03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ood2oOom0_d01?om
0_d00ol0003omPWfooH9mP0CooH9mP;o00000oo`3o000ol0003ojAKYonTFj@03onTFj@03o`000?o?
<<oocc3?01;occ3?00?o0000ojUFZOnYEZT03OnYEZT00ol0003oSW6>ohiaSP02ohiaSP;o00003_n<
Lh`3o`0001?oQGZ500?o0000oiEZUOnEJYD02onEJYD00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?na
C[7o/Dja00_o/Dja00?o0000oll`coo?<<l03oo?<<l00ol0003okQ7^onhAkP0AonhAkP03o`000?oj
1O[onPGj00;onPGj0ol0000=ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003omPWfooH9mP0A
ooH9mP03o`000?o`3o3ol0o`00Col0o`00Go0000onTFjOoY5^WojAKYo`00000Eoll`c`03o`000?nY
EZWoZEJY00coZEJY00?o0000ohiaS_n>LHh01On>LHh2o`0000coS7><00?o0000ohEjQOn5NXD05?n5
NXD00ol0003oUFZEoiEZU@0:oiEZU@03o`000?nYEZWoZEJY00[oZEJY00?o0000ok5>/OnaC[403?na
C[400ol0003occ3?oll`c`0=oll`c`03o`000?o^4NkokQ7^01;okQ7^00?o0000ooX5n_oj1OX01Ooj
1OX3o`0000Wom@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?om0_goo@;m00Koo@;m00?o0000ooH9m_of2OH03_of2OH2o`0000Sol0o`00?o0000
onTFjOl000005oo?<<l00ol0003oZEJYojUFZ@0:ojUFZ@03o`000?n>LHkoSW6>00SoSW6>00?o0000
ohacS?n<Lh`02?n<Lh`3o`0001GoQGZ50_l0000;oiEZU@03o`000?nYEZWoZEJY00WoZEJY00?o0000
ok5>/OnaC[403_naC[400ol0003occ3?oll`c`0<oll`c`03o`000?o^4NkokQ7^01;okQ7^00?o0000
ooX5n_oj1OX02?oj1OX2o`0000Oom@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo@;mood2o@08ood2o@;o00003?of2OH2o`00
00_ol0o`00?o0000oll`coo?<<l05_o?<<l00ol0003oZEJYojUFZ@09ojUFZ@03o`000?n>LHkoSW6>
00[oSW6>0_l00005ohacS0?o00000on1OX400ol0003oQGZ5ohEjQ@0AohEjQ@03o`000?n5NXGoQGZ5
00;o00002OnEJYD00ol0003oZEJYojUFZ@09ojUFZ@03o`000?naC[7o/Dja00ko/Dja00?o0000oll`
coo?<<l02oo?<<l00ol0003okQ7^onhAkP0ConhAkP03o`000?oj1O[onPGj00[onPGj0ol00004ooD:
m@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o@;mood2o@0:ood2o@03o`000?of2OKomPWf00OomPWf0_l0000=oo0?l003o`000?o?<<oocc3?01Ko
cc3?00?o0000ojUFZOnYEZT00onYEZT6o`0000ooSW6>0_l000000on<Lhco0000o`000007oh5nP@;o
00004?n5NXD00ol0003oQGZ5ohEjQ@03ohEjQ@?o00001_nEJYD00ol0003oZEJYojUFZ@09ojUFZ@03
o`000?naC[7o/Dja00oo/Dja00?o0000oll`coo?<<l02_o?<<l00ol0003okQ7^onhAkP0ConhAkP03
o`000?oj1O[onPGj00gonPGj1?l0000>ood2o@03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ood2oOom0_d02oom0_d00ol0003omPWfooH9mP04ooH9mP;o00004?o`3o000ol0003occ3?
oll`c`0Foll`c`Go00001OnSG:<00ol0003oSW6>ohiaSP0?ohiaSP03o`000?n1OX7oPGj100WoPGj1
00?o0000ohEjQOn5NXD03?n5NXD00ol0003oQGZ5ohEjQ@07ohEjQ@;o00000_nEJYD>o`0001;o/Dja
00?o0000oll`coo?<<l02Oo?<<l00ol0003okQ7^onhAkP0DonhAkP03o`000?oj1O[onPGj013onPGj
00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ood2oOom0_d03Oom
0_d00ol0003omPWfooH9mP02ooH9mP03o`000?o`3o3ol0o`013ol0o`00?o0000oll`coo?<<l05Oo?
<<l00ol0003oXebSoj=LX`09oj=LX`03o`000?n>LHkoSW6>00koSW6>00?o0000oh5nPOn1OX402_n1
OX42o`0000_oQGZ500?o0000ohEjQOn5NXD02_n5NXD2o`0000goVFJI00?o0000ok5>/OnaC[404Ona
C[400ol0003occ3?oll`c`07oll`c`03o`000?o^4NkokQ7^01GokQ7^0_l0000BooX5nP03o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m00koo@;m00Co0000
ooH9m_l0003o00005?o`3o000ol0003occ3?oll`c`0Coll`c`03o`000?nSG:?oXebS00[oXebS00?o
0000ohiaS_n>LHh03_n>LHh00ol0003oPGj1oh5nP@0<oh5nP@03o`000?n5NXGoQGZ500OoQGZ500?o
0000ohEjQOn5NXD02on5NXD00ol0003oVFJIoiUVV@0=oiUVV@03o`000?naC[7o/Dja013o/Dja00?o
0000oll`coo?<<l01oo?<<l00ol0003okQ7^onhAkP0EonhAkP04o`000?oi1_Wo0000o`00017onPGj
00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ood2oOom0_d03oom
0_d00ol0003ol0o`oo0?l00Doo0?l003o`000?o?<<oocc3?01;occ3?00?o0000oj=LXonSG:<02onS
G:<00ol0003oSW6>ohiaSP0>ohiaSP03o`000?n1OX7oPGj100goPGj100?o0000ohEjQOn5NXD01?n5
NXD2o`0000koQGZ500?o0000oiUVVOnIIYT03OnIIYT00ol0003o/Djaok5>/@0@ok5>/@Co00001Oo?
<<l00ol0003okQ7^onhAkP0FonhAkP04o`000?oi1_Won@KiooT6n@;o00004?oj1OX00ol0003oo@;m
ood2o@08ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo@;mood2o@0?ood2o@03o`000?o`
3o3ol0o`01Gol0o`5?l0000?oj=LX`03o`000?n>LHkoSW6>00coSW6>00?o0000ogn0Ool000003on1
OX42o`0000?oQGZ500Co0000ogj1O_mnPGko00003On5NXD00ol0003oVFJIoiUVV@0>oiUVV@03o`00
0?naC[7o/Dja00co/Dja0ol00004ol8m`P?o00000_o?<<l00ol0003okQ7^onhAkP0FonhAkP03o`00
0?oi1_Won@Ki00?on@Ki0_l0000?ooX5nP03o`000?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?om0_goo@;m013oo@;m00?o0000oo0?l?o`3o005Oo`3o000ol0003obCK9olTf
b@0@olTfb@03o`000?nSG:?oXebS00goXebS00?o0000ohiaS_n>LHh02on>LHh01?l0003oOh1oogn0
Ool0000Aoh5nP@03o`000?n5NXGo000000CoOX5n00?o0000ohEjQOn5NXD02_n5NXD00ol0003oVFJI
oiUVV@0>oiUVV@03o`000?naC[7o/Dja00Wo/Dja0ol0000:ol8m`P;o00006?o^4Nh00ol0003on@Ki
ooT6n@06ooT6n@;o00003_oj1OX00ol0003oo@;mood2o@04ood2o@?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_om
0_d00ol0003ol0o`oo0?l00Eoo0?l003o`000?o9=/WobCK9013obCK900?o0000oj=LXonSG:<03OnS
G:<00ol0003oSW6>ohiaSP0:ohiaSP03o`000?moP7ooOh1o00;oOh1o00?o0000oh5nPOn1OX403on1
OX400ol0003oOX5nogj1OP04ogj1OP03o`000?n5NXGoQGZ500WoQGZ500?o0000oiUVVOnIIYT03_nI
IYT00ol0003o/Djaok5>/@06ok5>/@?o00003_o2?L800ol0003okQ7^onhAkP0FonhAkP03o`000?oi
1_Won@Ki00Son@Ki0_l0000=ooX5nP03o`000?om0_goo@;m00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ood2o@0@ood2o@03o`000?o`3o3ol0o`01Gol0o`00?o0000
olTfbOo9=/T04_o9=/T00ol0003oXebSoj=LX`0=oj=LX`03o`000?n>LHkoSW6>00WoSW6>00?o0000
ogn0OomoP7l00_moP7l00ol0003oPGj1oh5nP@0?oh5nP@03o`000?mnPGkoOX5n00GoOX5n00?o0000
ohEjQOn5NXD02?n5NXD00ol0003oVFJIoiUVV@0?oiUVV@03o`000?naC[7o/Dja00;o/Dja0ol0000B
ol8m`P03o`000?o^4NkokQ7^01GokQ7^00?o0000ooT6nOoi1_T02_oi1_T2o`0000conPGj0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ood2oOom0_d03_om0_d00ol0
003ol0o`oo0?l00Coo0?l0?o00005?o9=/T00ol0003oXebSoj=LX`0=oj=LX`03o`000?n>LHkoSW6>
00SoSW6>00?o0000ogn0OomoP7l01?moP7l00ol0003oPGj1oh5nP@0>oh5nP@03o`000?mnPGkoOX5n
00KoOX5n00?o0000ohEjQOn5NXD01on5NXD00ol0003oVFJIoiUVV@0?oiUVV@03o`000?naC[7o0000
00;o00005Oo2?L800ol0003okQ7^onhAkP0EonhAkP03o`000?oi1_Won@Ki00con@Ki0_l0000:ooX5
nP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o@;mood2o@0=ood2o@03o`000?o`3o3ol0o`00ool0o`1?l00002on4Nh@03o`000?o9=/WobCK901;o
bCK900?o0000oj=LXonSG:<03OnSG:<00ol0003oSW6>ohiaSP07ohiaSP03o`000?moP7ooOh1o00Go
Oh1o00?o0000oh5nPOn1OX403On1OX400ol0003oOX5nogj1OP08ogj1OP03o`000?n5NXGoQGZ500Ko
QGZ500?o0000oiUVVOnIIYT04?nIIYT00ol0003o`Sg2ol8m`P0Fol8m`P03o`000?o^4NkokQ7^01Go
kQ7^00?o0000ooT6nOoi1_T03_oi1_T2o`0000OonPGj00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o002oo`3o04o`0000KohAkQ
00?o0000olTfbOo9=/T04oo9=/T00ol0003oXebSoj=LX`0=oj=LX`03o`000?n>LHkoSW6>00GoSW6>
00?o0000ogn0OomoP7l01omoP7l00ol0003oPGj1oh5nP@0<oh5nP@03o`000?mnPGkoOX5n00WoOX5n
00?o0000ohEjQOn5NXD01On5NXD00ol0003oVFJIoiUVV@0@oiUVV@03o`000?o2?L;o`Sg201Oo`Sg2
00?o0000onhAk_o^4Nh05?o^4Nh00ol0003on@KiooT6n@0@ooT6n@;o00001?oj1OX00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?om0_goo@;m00coo@;m00?o0000oo0?l?o`3o001oo`
3o04o`0000[ohAkQ00?o0000olTfbOo9=/T04oo9=/T00ol0003oXebSoj=LX`0=oj=LX`03o`000?n>
LHkoSW6>00CoSW6>00?o0000ogn0OomoP7l02?moP7l00ol0003oPGj1oh5nP@0<oh5nP@03o`000?mn
PGkoOX5n00[oOX5n00?o0000ohEjQOn5NXD01?n5NXD00ol0003oVFJIoiUVV@0@oiUVV@03o`000?o2
?L;o`Sg201Oo`Sg200?o0000onhAk_o^4Nh05?o^4Nh00ol0003on@KiooT6n@0BooT6n@;o000000?o
nPGjo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ood2oOom0_d02_om0_d0
0ol0003ol0o`oo0?l004oo0?l0Co00003_oQ7^400ol0003obCK9olTfb@0ColTfb@03o`000?nSG:?o
XebS00goXebS00?o0000ohiaS_n>LHh01?n>LHh00ol0003oOh1oogn0O`09ogn0O`03o`000?n1OX7o
PGj100_oPGj100?o0000ogj1O_mnPGh02omnPGh00ol0003oQGZ5ohEjQ@03ohEjQ@03o`000?nIIYWo
VFJI013oVFJI00?o0000ol8m`_o2?L805oo2?L800ol0003okQ7^onhAkP0ConhAkP03o`000?oi1_Wo
n@Ki01Gon@Ki00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ood2
oOom0_d02Oom0_d00ol0003ol0o`oo0?l004o`0001;ohAkQ00?o0000olTfbOo9=/T04oo9=/T00ol0
003oXebSoj=LX`0>oj=LX`03o`000?n>LHkoSW6>00;oSW6>00?o0000ogn0OomoP7l02_moP7l00ol0
003oPGj1oh5nP@0:oh5nP@03o`000?mnPGkoOX5n00goOX5n00?o0000ohEjQOn5NXD00_n5NXD00ol0
003oVFJIoiUVV@0@oiUVV@03o`000?o2?L;o`Sg201So`Sg200?o0000onhAk_o^4Nh04_o^4Nh00ol0
003on@KiooT6n@0EooT6n@03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo@;m1?l0000Gon4Nh@03
o`000?o9=/WobCK901?obCK900?o0000oj=LXonSG:<03?nSG:<4o`000003ohiaS_l0003oOh1o00go
Oh1o00?o0000oh5nPOn1OX402On1OX400ol0003oOX5nogj1OP0>ogj1OP05o`000?n5NXGoQGZ5ohEj
QOl000004_nIIYT00ol0003o`Sg2ol8m`P0Hol8m`P?o00004_o^4Nh00ol0003on@KiooT6n@0DooT6
n@03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00?o
000000Coo@;mo`000?l0003o00000_og2?L00ol0003ohAkQon4Nh@0Fon4Nh@03o`000?o9=/WobCK9
01?obCK900?o0000oj=LXonSG:<02onSG:<00ol0003oQgR7ohMhQ`02ohMhQ`;o00003_moP7l00ol0
003oPGj1oh5nP@09oh5nP@03o`000?mnPGkoOX5n00ooOX5n00Co0000ohEjQOn5NXGo00004_nIIYT0
0ol0003o`Sg2ol8m`P0Hol8m`P03o`000?oD:mCoe2_D00?o00003oo^4Nh5o`0001;on@Ki00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ood2oOom0_d01?om0_d00ol0003om`SgooL8m`04
ooL8m`03o`000?oQ7^7ohAkQ01GohAkQ00?o0000olTfbOo9=/T04oo9=/T00ol0003oXebSoj=LX`0:
oj=LX`03o`000?n7N8OoQgR700GoQgR700?o0000ogn0OomoP7l03?moP7l00ol0003oPGj1oh5nP@08
oh5nP@03o`000?mnPGkoOX5n00ooOX5n1Ol0000AoiUVV@03o`000?o2?L;o`Sg201Oo`Sg200?o0000
om@[e?oD:m@01?oD:m@3o`0000cokQ7^00?o0000ooT6nOoi1_T00_oi1_T7o`0000[on@Ki00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?om0_goo@;m00Goo@;m00?o0000ooL8moog2?L01Oog2?L00ol0
003ohAkQon4Nh@0Don4Nh@03o`000?o9=/WobCK901?obCK900?o0000oj=LXonSG:<02?nSG:<2o`00
00WoQgR700?o0000ogn0OomoP7l02omoP7l00ol0003oPGj1oh5nP@07oh5nP@03o`000?mnPGkoOX5n
00goOX5n0ol00005ohEjQ@03o`000?nIIYWoVFJI00koVFJI00?o0000ol8m`_o2?L805_o2?L800ol0
003oe2_Dom@[e008om@[e0?o00002?o^4Nh00ol0003on@KiooT6n@0:ooT6n@Oo00000ooi1_T00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0003om`SgooL8m`06ooL8m`03
o`000?oQ7^7ohAkQ01?ohAkQ0_l0000EolTfb@03o`000?nSG:?oXebS00KoXebS00?o0000ohMhQon7
N8L02_n7N8L00ol0003oOh1oogn0O`0:ogn0Oa[o00002On5NXD00ol0003oVFJIoiUVV@0<oiUVV@?o
00005_o2?L800ol0003oe2_Dom@[e00<om@[e0?o00001?o^4Nh00ol0003on@KiooT6n@0BooT6n@?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000ooL8moog2?L01oog2?L00ol0003ohAkQ
on4Nh@0@on4Nh@;o00000_o6>LH3o`0001;obCK900?o0000oj=LXonSG:<01?nSG:<2o`0000koQgR7
00?o0000ogn0OomoP7l01omoP7l2o`0000[oOH9m00?o0000ogf2OOmmPWd03?mmPWd00ol0003oQGZ5
ohEjQ@08ohEjQ@;o00002_nIIYT2o`0000?oWf2O0_l0000Col8m`P03o`000?oD:mCoe2_D013oe2_D
1?l0000GooT6n@03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?og
2?Oom`Sg00Som`Sg00?o0000on4NhOoQ7^403_oQ7^400ol0003oiA[Uo`000005olHiaP;o00004?o9
=/T00ol0003oXebSoj=LX`03oj=LX`03o`000?n7N8OoQgR700ooQgR700?o0000ogn0OomoP7l01?mo
P7l2o`0000coOH9m00?o0000ogf2OOmmPWd03?mmPWd00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?nI
IYWoVFJI00GoVFJI0_l00007oimPW`03o`000?o2?L;o`Sg200oo`Sg200?o0000om@[e?oD:m@04OoD
:m@01?l0003ojaC[on/Djol0000GooT6n@03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo@;mood2
o@09ood2o@03o`000?og2?Oom`Sg00Wom`Sg00?o0000on4NhOoQ7^402ooQ7^42o`0000;oiA[U00?o
0000olHia_o6>LH01Oo6>LH2o`0000oobCK900Go0000oj=LXonSG:?oXebSo`00000CohMhQ`03o`00
0?moP7ooOh1o00;oOh1o00?o0000ogf2OOmmPWd03OmmPWd00ol0003oOH9mogf2O@0;ogf2O@03o`00
0?n5NXGoQGZ500_oQGZ500?o0000oiUVVOnIIYT00_nIIYT2o`0000[oWf2O0_l0000>ol8m`P03o`00
0?oD:mCoe2_D017oe2_D00Go0000on/Djoo[5>_ojaC[o`00000HooT6n@03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?om0_goo@;m00[oo@;m00?o0000ooL8moog2?L02_og2?L00ol0003ohAkQon4Nh@09on4Nh@03o`00
0?oU6^GoiA[U00?oiA[U00?o0000olHia_o6>LH01_o6>LH3o`0000_obCK91Ol0000EohMhQ`04o`00
0?moP7oo0000o`00013oOH9m00?o0000ogf2OOmmPWd02ommPWd00ol0003oQGZ5ohEjQ@0<ohEjQ@04
o`000?nIIYWo0000o`0000koWf2O0_l0000;ol8m`P03o`000?oD:mCoe2_D017oe2_D00?o0000on/D
joo[5>/00oo[5>/00ol0003on@KiooT6n@0EooT6n@;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom
0_d02oom0_d00ol0003om`SgooL8m`0;ooL8m`03o`000?oQ7^7ohAkQ00KohAkQ0_l00006onDJi@03
o`000?o6>LKoaSW600WoaSW60_l00008olTfb@03o`000?nOH9ooWf2O00;oWf2O00?o0000ohMhQon7
N8L05?n7N8L00ol0003oOH9mogf2O@0@ogf2O@03o`000?mmPWgoOH9m00_oOH9m00?o0000ohEjQOn5
NXD03On5NXD00ol0003oWf2OoimPW`0@oimPW`03o`000?o2?L;o`Sg200Oo`Sg200?o0000om@[e?oD
:m@04OoD:m@00ol0003ojaC[on/Dj`04on/Dj`03o`000?oi1_Won@Ki01Gon@Ki00?o0000oo`3o?l0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00com`Sg
00?o0000on4NhOoQ7^401?oQ7^400ol0003oiA[UonDJi@06onDJi@03o`000?o6>LKoaSW600_oaSW6
0_l00005olTfb@03o`000?nOH9ooWf2O00CoWf2O00?o0000ohMhQon7N8L04on7N8L00ol0003oOH9m
ogf2O@0@ogf2O@03o`000?mmPWgoOH9m00_oOH9m00?o0000ohEjQOn5NXD03On5NXD00ol0003oWf2O
oimPW`0AoimPW`;o00000oo2?L84o`0001?oe2_D00?o0000on/Djoo[5>/01Oo[5>/00ol0003on@Ki
ooT6n@0DooT6n@05o`000?ol0ocoo0?loo`3o?l000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;m
ood2o@0=ood2o@03o`000?og2?Oom`Sg00gom`Sg00Co0000on4NhOoQ7^7ohAkQ0_l00009onDJi@03
o`000?o6>LKoaSW600goaSW60ol000000oo9=/Wo0000oimPW`07oimPW`03o`000?n7N8OoQgR701;o
QgR700?o0000ogf2OOmmPWd04?mmPWd00ol0003oOH9mogf2O@0;ogf2O@03o`000?n5NXGoQGZ500go
QGZ500?o0000oimPWonOH9l04onOH9l3o`0000?ocS7>00?o0000om@[e?oD:m@04?oD:m@00ol0003o
jaC[on/Dj`07on/Dj`03o`000?oi1_Won@Ki01;on@Ki00?o0000oo`3o?ol0o`00ool0o`00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog2?L0
3_og2?L00ol0003ohAkQo`00000;onDJi@03o`000?o6>LKoaSW6013oaSW600?o0000oimPWonOH9l0
2?nOH9l00ol0003oQgR7ohMhQ`0AohMhQ`03o`000?mmPWgoOH9m017oOH9m00?o0000ogf2OOmmPWd0
2_mmPWd00ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?n;M8_o000001CoWf2O00?o0000olhac_o><Lh0
1?o><Lh00ol0003oe2_Dom@[e00>om@[e003o`000?o[5>_ojaC[00SojaC[00?o0000ooT6nOoi1_T0
4Ooi1_T00ol0003oo0?loo`3o005oo`3o003o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?om
0_d00ol0003om`SgooL8m`0?ooL8m`03o`000?oU6^GoiA[U00_oiA[U00?o0000olHia_o6>LH03oo6
>LH00ol0003oWf2OoimPW`09oimPW`03o`000?n7N8OoQgR7013oQgR700?o0000ogf2OOmmPWd04Omm
PWd00ol0003oOH9mogf2O@0:ogf2O@03o`000?n5NXGoQGZ500_oQGZ500Co0000oh]dRon;M8_o0000
5?nOH9l00ol0003ocS7>olhacP05olhacP03o`000?oD:mCoe2_D00coe2_D00?o0000on/Djoo[5>/0
2Oo[5>/00ol0003on@KiooT6n@0@ooT6n@03o`000?ol0ocoo0?l00Ooo0?l00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Oom0_d00ol0003om`SgooL8m`0>ooL8m`;o00003OoU6^D00ol0003oaSW6olHi
aP0?olHiaP03o`000?nOH9ooWf2O00[oWf2O00?o0000ohMhQon7N8L03_n7N8L00ol0003oOX5no`00
000Bogf2O@03o`000?mmPWgoOH9m00[oOH9m00?o0000ohEjQOn5NXD02_n5NXD00ol0003oRgB;oh]d
R`02oh]dR`03o`000?nOH9ooWf2O013oWf2O00?o0000olhac_o><Lh01oo><Lh00ol0003oe2_Dom@[
e00:om@[e003o`000?o[5>_ojaC[00[ojaC[00?o0000ooT6nOoi1_T03ooi1_T00ol0003oo0?loo`3
o009oo`3o004o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo@;m00?o0000ooL8moog2?L03Oog
2?L01?l0003ol`ccoo<<lol0000<onDJi@03o`000?o6>LKoaSW600ooaSW600?o0000oimPWonOH9l0
2onOH9l00ol0003oQgR7ohMhQ`0<ohMhQ`05o`000?mnPGkoOX5nogj1O_l000004OmmPWd00ol0003o
OH9mogf2O@0:ogf2O@03o`000?n5NXGoQGZ500WoQGZ500?o0000oh]dRon;M8/00on;M8/00ol0003o
Wf2OoimPW`0@oimPW`03o`000?o><LkocS7>00SocS7>00?o0000om@[e?oD:m@02?oD:m@00ol0003o
jaC[on/Dj`0<on/Dj`03o`000?oi1_Won@Ki00gon@Ki00?o0000oo`3o?ol0o`02ool0o`00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ood2o@?o00003Oog2?L00ol0003ol`ccoo<<l`02oo<<l`03o`00
0?oU6^GoiA[U00WoiA[U00?o0000olHia_o6>LH03_o6>LH00ol0003oWf2OoimPW`0=oimPW`03o`00
0?n7N8OoQgR700[oQgR700?o0000ogj1O_mnPGh00omnPGh00ol0003oOH9mogf2O@0?ogf2O@03o`00
0?mmPWgoOH9m00WoOH9m00?o0000ohEjQOn5NXD02?n5NXD00ol0003oRgB;oh]dR`05oh]dR`03o`00
0?nOH9ooWf2O00ooWf2O00?o0000olhac_o><Lh02Oo><Lh00ol0003oe2_Dom@[e006om@[e003o`00
0?o[5>_ojaC[00gojaC[00?o0000ooT6nOoi1_T03?oi1_T00ol0003oo0?loo`3o00<oo`3o003o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ood2oOl0003o000000?oo0?l0_l0000:ooL8m`03o`000?oc
3??ol`cc00Col`cc00?o0000onDJiOoU6^D02?oU6^D00ol0003oaSW6olHiaP0>olHiaP03o`000?nO
H9ooWf2O00koWf2O00?o0000ohMhQon7N8L02?n7N8L00ol0003oOX5nogj1OP05ogj1OP03o`000?mm
PWgoOH9m00koOH9m00?o0000ogf2OOmmPWd02OmmPWd00ol0003oQGZ5ohEjQ@07ohEjQ@03o`000?n;
M8_oRgB;00KoRgB;00?o0000oimPWonOH9l03onOH9l00ol0003ocS7>olhacP09olhacP03o`000?oD
:mCoe2_D00Goe2_D00?o0000on/Djoo[5>/03_o[5>/00ol0003on@KiooT6n@0;ooT6n@03o`000?ol
0ocoo0?l00goo0?l00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol0ocoo0?l00Goo0?l0_l00007
ooL8m`03o`000?oc3??ol`cc00Gol`cc00?o0000onDJiOoU6^D02OoU6^D00ol0003oaSW6olHiaP0=
olHiaP03o`000?nOH9ooWf2O00ooWf2O00?o0000ohMhQon7N8L01_n7N8L00ol0003oOX5nogj1OP07
ogj1OP03o`000?mmPWgoOH9m00goOH9m00?o0000ogf2OOmmPWd02OmmPWd00ol0003oQGZ5ohEjQ@04
ohEjQ@?o00002_n;M8/00ol0003oWf2OoimPW`0=oimPW`03o`000?o><LkocS7>00_ocS7>00?o0000
om@[e?oD:m@00ooD:m@00ol0003ojaC[on/Dj`0@on/Dj`03o`000?oi1_Won@Ki00Won@Ki00?o0000
oo`3o?ol0o`03_ol0o`00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000oo`3o?ol0o`01ool0o`2o`00
00Com`Sg00?o0000oo<<looc3?<01ooc3?<00ol0003oiA[UonDJi@08onDJi@03o`000?o6>LKoaSW6
00goaSW600?o0000oimPWonOH9l04?nOH9l00ol0003oQgR7ohMhQ`05ohMhQ`03o`000?mnPGkoOX5n
00SoOX5n00?o0000ogf2OOmmPWd03?mmPWd00ol0003oOH9mogf2O@09ogf2O@03o`000?n5NXGo0000
00Co00000_n1OX400ol0003oRgB;oh]dR`08oh]dR`03o`000?nOH9ooWf2O00goWf2O00?o0000olha
c_o><Lh03?o><Lh01Ol0003oe2_Dom@[e?oD:mCo000001;ojaC[0ol00009ooT6n@03o`000?ol0oco
o0?l00ooo0?l00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol0ocoo0?l00Woo0?l0_l000000oog
2?Oo0000oo<<l`0:oo<<l`03o`000?oU6^GoiA[U00OoiA[U00?o0000olHia_o6>LH03Oo6>LH00ol0
003oWf2OoimPW`0AoimPW`03o`000?n7N8OoQgR700?oQgR700?o0000ogj1O_mnPGh02_mnPGh00ol0
003oOH9mogf2O@0;ogf2O@03o`000?mmPWgoOH9m00SoOH9m0ol00008oh5nP@03o`000?n;M8_oRgB;
00SoRgB;00?o0000oimPWonOH9l03?nOH9l00ol0003ocS7>olhacP0=olhacP03o`000?oD:mCo0000
01;ojaC[00Co0000ooP7n?oh1oSon0Oh0_l00006ooT6n@03o`000?ol0ocoo0?l013oo0?l00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?ol0ocoo0?l00coo0?l00?o0000oo<<looc3?<02_oc3?<00ol0
003oiA[UonDJi@07onDJi@03o`000?o6>LKoaSW600goaSW600?o0000oimPWonOH9l04_nOH9l01Ol0
003oQgR7ohMhQon7N8Oo000000koOX5n00?o0000ogf2OOmmPWd02ommPWd00ol0003oOH9mogf2O@06
ogf2O@03o`000?n1OX7oPGj100WoPGj100?o0000oh]dRon;M8/02On;M8/00ol0003oWf2OoimPW`0:
oimPW`03o`000?o><LkocS7>00oocS7>00?o0000on/Djoo[5>/04?o[5>/00ol0003on0OhooP7n004
ooP7n003o`000?oi1_Won@Ki00;on@Ki00?o0000oo`3o?ol0o`04Ool0o`00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol`ccoo<<l`0;oo<<l`03o`000?oU6^GoiA[U
00KoiA[U00?o0000olHia_o6>LH03Oo6>LH00ol0003oWf2OoimPW`0CoimPW`03o`000?n7N8Oo0000
013oOX5n3_l00006ogf2O@;o00003?n1OX400ol0003oRgB;oh]dR`09oh]dR`03o`000?nOH9ooWf2O
00[oWf2O00?o0000olhac_o><Lh03oo><Lh00ol0003ojaC[on/Dj`0>on/Dj`;o00002?oh1oP2o`00
0003ooT6nOl0003oo0?l017oo0?l0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000oo`3o?ol0o`03?ol0o`00ol0003o
l`ccoo<<l`0<oo<<l`03o`000?oU6^GoiA[U00KoiA[U00?o0000olHia_o6>LH02oo6>LH00ol0003o
Wf2OoimPW`0DoimPW`?o00003omnPGh00ol0003oOh1oogn0O`0<ogn0O`04o`000?mmPWgoOH9mogf2
O@;o00003on1OX400ol0003oRgB;oh]dR`09oh]dR`03o`000?nOH9ooWf2O00WoWf2O00?o0000olha
c_o><Lh04?o><Lh00ol0003ojaC[on/Dj`0<on/Dj`03o`000?oh1oSon0Oh00[on0Oh00?o0000oo`3
o?ol0o`03?ol0o`5o`0000;oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00go
o0?l00?o0000oo<<looc3?<03Ooc3?<00ol0003oiA[UonDJi@05onDJi@03o`000?o6>LKoaSW600_o
aSW600?o0000oimPWonOH9l04onOH9l01Ol0003oRGJ9ohUfROn9MXWo000000goOX5n00?o0000ogn0
OomoP7l03_moP7l00ol0003oOH9mo`00000Aoh5nP@03o`000?n;M8_oRgB;00WoRgB;00?o0000oimP
WonOH9l02OnOH9l00ol0003ocS7>olhacP0@olhacP03o`000?o[5>_ojaC[00_ojaC[00?o0000ooP7
n?oh1oP02ooh1oP00ol0003oo0?loo`3o007oo`3o0Go00002?om0_d00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003ol`ccoo<<l`0=oo<<l`03o`000?oU6^GoiA[U00Go
iA[U4Ol0000BoimPW`03o`000?n9MXWoRGJ900?oRGJ900?o0000ogj1O_mnPGh02OmnPGh00ol0003o
Oh1oogn0O`0@ogn0O`03o`000?n1OX7oPGj1017oPGj100?o0000oh]dRon;M8/02On;M8/00ol0003o
Wf2OoimPW`07oimPW`03o`000?o><LkocS7>017ocS7>00?o0000on/Djoo[5>/02_o[5>/00ol0003o
n0OhooP7n00=ooP7n004o`000?ol0ocoo0?loo`3o0Go00003_om0_d3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o0?loo`3o00>oo`3o003o`000?oc3??ol`cc00gol`cc00?o0000onDJiOoU6^D00ooU6^D00ol0003o
d2o@om0_d00<om0_d003o`000?nKI9_oVfBK00?o00003_nOH9l00ol0003oRGJ9ohUfR@05ohUfR@03
o`000?mnPGkoOX5n00OoOX5n00?o0000ogn0OomoP7l04OmoP7l00ol0003oPGj1oh5nP@0Aoh5nP@03
o`000?n;M8_oRgB;00WoRgB;00?o0000oimPWonOH9l01_nOH9l2o`0001CocS7>00?o0000on/Djoo[
5>/01oo[5>/2o`00017on0Oh0ol0000Cood2o@03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?ol0ocoo0?l00koo0?l00?o0000oo<<looc3?<03Ooc3?<4o`000003onDJiOl0003od2o@00kod2o@
00?o0000oi]TVonKI9/00onKI9/3o`0000[oWf2O00?o0000ohUfROn9MXT01on9MXT00ol0003oOX5n
ogj1OP05ogj1OP03o`000?moP7ooOh1o01;oOh1o00?o0000oh5nPOn1OX404On1OX400ol0003oRgB;
oh]dR`0:oh]dR`03o`000?nOH9ooWf2O00;oWf2O0ol00002ojMHY`03o`000?o><LkocS7>017ocS7>
00?o0000on/Djoo[5>/01_o[5>/00ol0003on0OhooP7n00AooP7n003o`000?om0_goo@;m01;oo@;m
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00?oo`3o003o`000?oc
3??ol`cc00[ol`cc0ol00004onl@k`03o`000?o@;m3od2o@00kod2o@00?o0000oi]TVonKI9/01_nK
I9/3o`0000KoWf2O00?o0000ohUfROn9MXT02On9MXT00ol0003oOX5nogj1OP03ogj1OP03o`000?mo
P7ooOh1o01?oOh1o00?o0000oh5nPOn1OX404_n1OX400ol0003oRgB;oh]dR`09oh]dR`03o`000?nO
H9oo000000;o00001_nWF:L00ol0003ocS7>olhacP0@olhacP03o`000?o[5>_ojaC[00GojaC[00?o
0000ooP7n?oh1oP04_oh1oP00ol0003oo@;mood2o@0Bood2o@03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000oo`3o?ol0o`03ool0o`3o`0000Ool`cc0ol00007onl@k`03o`000?o@;m3o
d2o@00god2o@00?o0000oi]TVonKI9/02_nKI9/3o`0000;oWf2O00?o0000ohUfROn9MXT02on9MXT0
1Ol0003oOX5nogj1O_mnPGko000001KoOh1o00?o0000oh5nPOn1OX404_n1OX400ol0003oRgB;oh]d
R`0:oh]dR`03o`000?nWF:OoYeRW00SoYeRW00?o0000olhac_o><Lh04?o><Lh00ol0003ojaC[on/D
j`02on/Dj`?o00005Ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?ol0oco
o0?l00koo0?l00Co0000ooX5n_oj1O[onPGj0ol000001?oc3??o0000o`000?l0000:onl@k`03o`00
0?o@;m3od2o@00god2o@00?o0000oi]TVonKI9/03OnKI9/2o`0000ooRGJ900?o0000ogj1O_l00000
5omoP7l00ol0003oPGj1oh5nP@0Coh5nP@03o`000?n;M8_oRgB;00WoRgB;00?o0000ojMHYonWF:L0
2OnWF:L00ol0003ocS7>olhacP0?olhacP03o`000?o[5>_ojaC[00;o00000oo_4>l2o`0001?on0Oh
00?o0000ood2oOom0_d04?om0_d00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?ol0o`03Ool
0o`00ol0003onPGjooX5nP05ooX5nP03o`000?o_4>ooka3_00_oka3_00?o0000om0_d?o@;m003Oo@
;m000ol0003oVfBKoi]TV`0>oi]TV`03o`000?n9MXWoRGJ900koRGJ900?o0000ogn0OomoP7l05_mo
P7l00ol0003oPGj1oh5nP@0Coh5nP@03o`000?n;M8_oRgB;00SoRgB;00?o0000ojMHYonWF:L02onW
F:L5o`0000cocS7>00?o0000on/Djol000001oo_4>l2o`00017on0Oh00?o0000ood2oOom0_d03oom
0_d00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003onPGjooX5nP06
ooX5nP03o`000?o_4>ooka3_00_oka3_00?o0000om0_d?o@;m003Oo@;m000ol0003oVfBKoi]TV`0>
oi]TV`03o`000?n9MXWoRGJ900koRGJ900?o0000ogn0OomoP7l05_moP7l00ol0003oPGj1oh5nP@0C
oh5nP@03o`000?n;M8_oRgB;00OoRgB;00?o0000ojMHYonWF:L03?nWF:L00ol0003ocS7>olhacP02
olhacPWo00001?o><Lh00ol0003oka3_onl@k`08onl@k`;o00003ooh1oP00ol0003oo@;mood2o@0?
ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00SonPGj00?o0000onl@koo_4>l02oo_4>l00ol0003od2o@om0_d00<om0_d003o`000?nKI9_oVfBK
00koVfBK00?o0000ohUfROn9MXT03on9MXT00ol0003oOh1oogn0O`0Eogn0O`03o`000?n1OX7oPGj1
01?oPGj11?l00005oh]dR`03o`000?nWF:OoYeRW00goYeRW00?o0000olhac_o><Lh02oo><Lh4o`00
00goka3_0_l0000>ooP7n003o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?ol0ocoo0?l00_oo0?l00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oka3_onl@k`0;onl@k`03
o`000?o@;m3od2o@00_od2o@00?o0000oi]TVonKI9/03onKI9/00ol0003oRGJ9ohUfR@0?ohUfR@03
o`000?moP7ooOh1o01GoOh1o00?o0000oh5nPOn1OX404?n1OX43o`0000CoTFjA0ol000000on;M8_o
0000ojMHY`0>ojMHY`03o`000?o><LkocS7>00oocS7>00?o0000onl@koo_4>l03Oo_4>l2o`0000_o
n0Oh0ol0000>ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo0?loo`3o00;oo`3o003o`00
0?oj1O[onPGj00_onPGj00?o0000onl@koo_4>l02_o_4>l00ol0003od2o@om0_d00;om0_d003o`00
0?nKI9_oVfBK00ooVfBK00?o0000ohUfROn9MXT03on9MXT2o`0001CoOh1o0ol0000@oh5nP@;o0000
2_nAKY400ol0003oYeRWojMHY`0>ojMHY`03o`000?o><LkocS7>013ocS7>0_l0000?onl@k`;o0000
2?oh1oP01?l0003oo0?loo`3o?ol0o`2o`0000_oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_oj1OX00ol0003oka3_onl@k`0:onl@k`03o`000?o@;m3od2o@00_od2o@4ol0000>ohUfR@?o0000
0_n6NHH00ol0003oOh1oogn0O`0<ogn0O`Go00000_n3O8<00ol0003oPGj1oh5nP@0<oh5nP@;o0000
3?nAKY400ol0003oYeRWojMHY`0>ojMHY`03o`000?o><LkocS7>013ocS7>00?o0000on8Mh_l00000
4?o_4>l2o`0000Con0Oh0_l00006oo`3o003o`000?om0_goo@;m00Soo@;m00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oka3_onl@k`09onl@k`03o`000?o@
;m3od2o@00_od2o@00?o0000oieRWOnMHYd03onMHYd00ol0003oRGJ9ohUfR@09ohUfR@?o00001_n6
NHH00ol0003oOh1oogn0O`06ogn0O`Go00002?n3O8<00ol0003oPGj1oh5nP@08oh5nP@?o00003onA
KY400ol0003oYeRWojMHY`0=ojMHY`03o`000?o><LkocS7>00oocS7>00Go0000on8Mh_oR7N;ohQgR
o`00000Aonl@k`;o000000?on0Oho`000?ol0o`02?ol0o`2o`0000Ooo@;m00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oj1O[onPGj00conPGj00?o0000onl@koo_4>l02Oo_4>l00ol0003od2o@om0_
d00;om0_d003o`000?nMHYgoWF:M00ooWF:M00?o0000ohUfROn9MXT01_n9MXT3o`0000[oQWV600?o
0000ogn0OomoP7l01Ol0000>oh=lP`03o`000?n1OX7oPGj100GoPGj10_l0000Boi5^T@03o`000?nW
F:OoYeRW00coYeRW00?o0000olhac_o><Lh04?o><Lh00ol0003ohQgRon8MhP02on8MhP03o`000?o_
4>ooka3_013oka3_00?o0000oo`3o?ol0o`02_ol0o`2o`0000Goo@;m00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?oj1O[onPGj00conPGj00?o0000onl@koo_4>l02Oo_4>l00ol0003od2o@om0_d00;
om0_d003o`000?nMHYgoWF:M013oWF:M00?o0000ohUfROn9MXT00_n9MXT3o`0000goQWV60ol0000C
oh=lP`03o`000?n1OX7oPGj100?oPGj10_l0000Eoi5^T@03o`000?nWF:OoYeRW00_oYeRW00?o0000
olhac_o><Lh03oo><Lh00ol0003ohQgRon8MhP04on8MhP03o`000?o_4>ooka3_00goka3_0ol0000>
oo`3o003o`000?om0_goo@;m00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oj1O[onPGj00conPGj00?o0000onl@
koo_4>l02Oo_4>l00ol0003od2o@om0_d008om0_d0Co00004OnMHYd00ol0003oRGJ9o`000002o`00
00ooQWV600?o0000ohEjQOl000005On3O8<00ol0003oPGj1o`000002o`0001OoTFjA00?o0000ojMH
YonWF:L02onWF:L00ol0003ocS7>olhacP0>olhacP03o`000?oR7N;ohQgR00KohQgR00?o0000onl@
koo_4>l02Oo_4>l3o`0000;ol`cc00?o0000oo`3o?ol0o`03Ool0o`2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooX5n_oj1OX03?oj1OX00ol0003oka3_onl@k`09onl@k`03o`000?o@;m3od2o@00Go
d2o@0ol00004oka3_003o`000?nMHYgoWF:M00koWF:M0_l0000AohIiQP04o`000?n5NXGoQGZ5o`00
01KoPgb300?o0000oi5^TOnAKY406?nAKY400ol0003oYeRWojMHY`0;ojMHY`03o`000?o><LkocS7>
00kocS7>00?o0000on8Mh_oR7N801ooR7N800ol0003oka3_onl@k`04onl@k`Co00001Ooc3?<00ol0
003oo0?loo`3o00=oo`3o003o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooX5n_oj
1OX03?oj1OX00ol0003oka3_onl@k`08onl@k`03o`000?o@;m3od2o@00;od2o@0ol00008oka3_003
o`000?nMHYgoWF:M00coWF:M0ol0000?ohIiQP;o00000on5NXD00ol0003oPgb3oh=lP`0Doh=lP`03
o`000?nAKY7oTFjA01WoTFjA00?o0000ojMHYonWF:L02_nWF:L00ol0003ocS7>olhacP0=olhacP03
o`000?oR7N;ohQgR00WohQgR00?o0000onl@koo_4>l00ol00009oo<<l`03o`000?ol0ocoo0?l00go
o0?l00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o_4>ooka3_00Ooka3_1_l0000<oka3_003o`000?nMHYgoWF:M00[oWF:M00Go0000oiMXUonGJ9Oo
UfRGo`00000=ohIiQP03o`000?n5NXGoQGZ500CoQGZ500?o0000oh=lPon3O8<04on3O8<00ol0003o
TFjAoi5^T@0Ioi5^T@03o`000?nWF:OoYeRW00WoYeRW00?o0000olhac_o><Lh03_o><Lh00ol0003o
hQgRon8MhP0:on8MhP;o00003?oc3?<00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooX5n_oj1OX02ooj1OX3o`0000Goka3_0_l00004ondBk@03o`00
0?nl@kco_4>l00co_4>l0_l00008oieRW@;o00001OnGJ9L00ol0003oQWV6ohIiQP09ohIiQP03o`00
0?n5NXGoQGZ500GoQGZ500?o0000oh=lPon3O8<04on3O8<00ol0003oTFjAoi5^T@0Joi5^T@go0000
3_o><Lh00ol0003ohQgRon8MhP0;on8MhP03o`000?oc3??ol`cc00_ol`cc00?o0000oo`3o?ol0o`0
3?ol0o`00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oj1O[onPGj00OonPGj0ol0
0003oo/4n`?o000000?oka3_o`000?o]4^d01_o]4^d00ol0003o_4>loka3_00=oka3_003o`000?nM
HYgoWF:M00CoWF:M00?o0000oiMXUonGJ9L01_nGJ9L2o`0000SoQWV600?o0000ohEjQOn5NXD01_n5
NXD00ol0003oPgb3oh=lP`0Doh=lP`03o`000?nAKY7oTFjA01WoTFjA00?o0000okM8]ongB;L02_ng
B;L00ol0003ocS7>olhacP0;olhacP03o`000?oR7N;ohQgR00cohQgR00?o0000oo<<looc3?<02_oc
3?<00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oj1O[o
nPGj00GonPGj0_l00009oo/4n`03o`000?o]4^gokA;]00KokA;]00?o0000oka3_?nl@k`03_nl@k`0
1?l0003oWF:MoieRWOnMHYd2o`0000_oUfRG00?o0000ohIiQ_n6NHH00on6NHH2o`0000WoQGZ500?o
0000oh=lPon3O8<05?n3O8<00ol0003oTFjAoi5^T@0Hoi5^T@03o`000?ngB;Oo]dRg00co]dRg00?o
0000olhac_o><Lh02Oo><Lh00ol0003ohQgRon8MhP0=on8MhP03o`000?oc3??ol`cc00[ol`cc00?o
0000oo`3o?ol0o`03?ol0o`00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooX5n_oj1OX00_oj1OX2
o`0000_on`Ck00?o0000ondBkOo]4^d01oo]4^d00ol0003o_4>loka3_00>oka3_003o`000?nMHYgo
000000koUfRG00Go0000ohIiQ_n6NHKoQWV6o`00000;ohEjQ@03o`000?n3O8?oPgb301CoPgb30_l0
000Ioi5^T@03o`000?ngB;Oo]dRg00go]dRg0_l00008olhacP03o`000?oR7N;ohQgR00kohQgR00?o
0000oo<<looc3?<02_oc3?<00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003onPGjo`000002o`0000gon`Ck00?o0000ondBkOo]4^d01oo]4^d00ol0003o_4>loka3_00?
oka3_003o`000?nGJ9OoUfRG00koUfRG00?o0000ohIiQ_l000003?n5NXD00ol0003oPgb3oh=lP`0D
oh=lP`03o`000?n<Lhco000000;o00005OnAKY400ol0003o]dRgokM8]`0@okM8]`03o`000?o><Lko
cS7>00GocS7>00?o0000on8Mh_oR7N803ooR7N800ol0003ol`ccoo<<l`09oo<<l`03o`000?ol0oco
o0?l00_oo0?l00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?ok1?_on`Ck00kon`Ck00?o0000ondB
kOo]4^d02?o]4^d00ol0003o_4>loka3_00>oka3_003o`000?nGJ9OoUfRG00koUfRG0_l0000=ohEj
Q@03o`000?n3O8?oPgb301?oPgb300?o0000ohacS?n<Lh`00on<Lh`2o`0001;oTFjA00?o0000okM8
]ongB;L04_ngB;L01?l0003ocS7>olhac_o><Lh3o`0001;ohQgR00?o0000oo<<looc3?<02Ooc3?<0
0ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003on`Ckoo/4n`0>oo/4
n`03o`000?o]4^gokA;]00SokA;]00?o0000oka3_?nl@k`03Onl@k`2o`0000ooUfRG00?o0000oi=/
Tol000003_n5NXD00ol0003oPgb3oh=lP`0Boh=lP`03o`000?n<LhcoS7><00GoS7><0ol0000?oi5^
T@03o`000?ngB;Oo]dRg01?o]dRg0ol00002omhQgP03o`000?oR7N;ohQgR013ohQgR00?o0000oo<<
looc3?<02Ooc3?<00ol0003oo0?loo`3o00;oo`3o003o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
n`Ckoo/4n`0?oo/4n`03o`000?o]4^gokA;]00WokA;]00?o0000oka3_?nl@k`02onl@k`00ol0003o
_D:mo`00000>oiMXU`05o`000?nCK9?oTfbCoi=/Tol000003On5NXD00ol0003oPgb3oh=lP`0Aoh=l
P`03o`000?n<LhcoS7><00WoS7><0ol0000:oi5^T@;o00005_ngB;L00ol0003ogR7NomhQgP03omhQ
gP03o`000?oR7N;ohQgR013ohQgR00?o0000oo<<looc3?<02?oc3?<00ol0003oo0?loo`3o00:oo`3
o003o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o]4^gokA;]00Wo
kA;]00?o0000oka3_?nl@k`02_nl@k`01Ol0003o_D:moke2_Onm@[go000000coUfRG00?o0000oi=/
TonCK9<00_nCK9<00ol0003oQGZ5ohEjQ@0;ohEjQ@03o`000?n3O8?oPgb3017oPgb300?o0000ohac
S?n<Lh`03?n<Lh`2o`0000KoTFjA0_l000000onWF:Oo0000okM8]`0DokM8]`03o`000?oN8MkogR7N
00GogR7N00?o0000on8Mh_oR7N803ooR7N800ol0003ol`ccoo<<l`08oo<<l`03o`000?ol0ocoo0?l
00[oo0?l00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?ok1?_on`Ck00oon`Ck00?o0000ondBkOo]
4^d02_o]4^d00ol0003o_4>loka3_007oka3_0;o00001Onm@[d00ol0003oUfRGoiMXU`08oiMXU`03
o`000?nCK9?oTfbC00CoTfbC00?o0000ohEjQOn5NXD02On5NXD4o`00013oPgb300?o0000ohacS?n<
Lh`03on<Lh`3o`000003oi5^TOl0003o000000CoYeRW00?o0000okM8]ongB;L04OngB;L00ol0003o
gR7NomhQgP07omhQgP03o`000?oR7N;ohQgR00oohQgR00?o0000oo<<looc3?<01ooc3?<00ol0003o
o0?loo`3o00:oo`3o003o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`00
0?o]4^gokA;]00[okA;]00?o0000oka3_?nl@k`01_nl@k`00ol0003o_D:moke2_@05oke2_@03o`00
0?nGJ9OoUfRG00OoUfRG00?o0000oi=/TonCK9<01OnCK9<00ol0003oQGZ5ohEjQ@08ohEjQ@03o`00
0?n3O8?oPgb300;oPgb30ol0000=oh=lP`03o`000?n<LhcoS7><01;oS7><00?o0000ojMHYonWF:L0
1OnWF:L00ol0003o]dRgokM8]`0@okM8]`03o`000?oN8MkogR7N00OogR7N00?o0000on8Mh_oR7N80
3ooR7N800ol0003ol`ccoo<<l`07oo<<l`03o`000?ol0ocoo0?l00[oo0?l00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?ok1?_on`Ck013on`Ck00?o0000ondBkOo]4^d02oo]4^d00ol0003o_4>loka3
_004oka3_003o`000?nm@[go_D:m00Oo_D:m00?o0000oiMXUonGJ9L01OnGJ9L00ol0003oTfbCoi=/
T`07oi=/T`03o`000?n5NXGoQGZ500KoQGZ500?o0000oh=lPon3O8<01_n3O8<3o`0000SoPgb30_l0
000EohacS003o`000?nWF:OoYeRW00KoYeRW00?o0000okM8]ongB;L03_ngB;L00ol0003ogR7NomhQ
gP09omhQgP03o`000?oR7N;ohQgR00kohQgR00?o0000oo<<looc3?<01ooc3?<00ol0003oo0?loo`3
o009oo`3o003o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?o]4^go
kA;]00_okA;]00?o0000oka3_?nl@k`00_nl@k`2o`0000[o_D:m00?o0000oiMXUonGJ9L01?nGJ9L0
0ol0003oTfbCoi=/T`09oi=/T`03o`000?n5NXGoQGZ500?oQGZ50_l0000<oh=lP`?o00000_n3O8<3
o`000003ohAkQ?l0003oS7><01CoS7><00?o0000ojMHYonWF:L01onWF:L00ol0003o]dRgokM8]`0<
okM8]`03o`000?oN8MkogR7N00_ogR7N00?o0000on8Mh_oR7N803_oR7N800ol0003ol`ccoo<<l`06
oo<<l`03o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok1?_on`Ck
017on`Ck00?o0000ondBkOo]4^d03?o]4^d01?l0003o_4>loka3_?l0000=oke2_@03o`000?nGJ9Oo
UfRG00;oUfRG00?o0000oi=/TonCK9<02_nCK9<00ol0003oQGZ5ohEjQ@02ohEjQ@03o`000?n3O8?o
Pgb300ooPgb30_l00005ohAkQ003o`000?n<LhcoS7><01;oS7><00?o0000ojMHYonWF:L02?nWF:L0
0ol0003o]dRgokM8]`0:okM8]`03o`000?oN8MkogR7N00gogR7N1Ol0000;on8MhP03o`000?oc3??o
l`cc00Kol`cc00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000oo/4
nook1?/04Ook1?/00ol0003okA;]ondBk@0<ondBk@03o`000?nl@kco000000oo_D:m00Co0000oiMX
UonGJ9Oo00003_nCK9<01?l0003oQGZ5ohEjQOl0000Coh=lP`03o`000?n4NhCoQ7^400CoQ7^400?o
0000ohacS?n<Lh`04?n<Lh`00ol0003oYeRWojMHY`09ojMHY`03o`000?ngB;Oo]dRg00[o]dRg00?o
0000omhQg_oN8Mh03OoN8Mh00ol0003oka3_onl@k`02onl@k`Wo00000_oR7N800ol0003ol`ccoo<<
l`06oo<<l`03o`000?ol0ocoo0?l00Woo0?l00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?ok1?_o
n`Ck013on`Ck1?l0000>ondBk@03o`000?nm@[go_D:m00ko_D:m00?o0000oiMXUol000003onCK9<0
0ol0003oQGZ5o`00000Coh=lP`03o`000?n4NhCoQ7^400GoQ7^400?o0000ohacS?n<Lh`04?n<Lh`0
0ol0003oYeRWojMHY`0:ojMHY`03o`000?ngB;Oo]dRg00So]dRg00?o0000omhQg_oN8Mh03OoN8Mh0
0ol0003oka3_onl@k`0<onl@k`Co00000ooc3?<7o`0000Soo0?l00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?ok1?_on`Ck00gon`Ck0ol00004ooT6n@03o`000?o]4^gokA;]00_okA;]00?o0000oke2
_Onm@[d03onm@[d00ol0003oTfbCoi=/T`0>oi=/T`;o00005?n3O8<00ol0003oQ7^4ohAkQ006ohAk
Q003o`000?n<LhcoS7><00ooS7><00?o0000ojMHYonWF:L02onWF:L00ol0003o]dRgokM8]`04okM8
]`?o00004?oN8Mh00ol0003oka3_onl@k`0?onl@k`Co00001ool0o`3o`0000?oo0?l1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000oo/4nook1?/02ook1?/3o`0000Son@Ki00?o0000ondBkOo]4^d02Oo]4^d00ol0003o
_D:moke2_@0@oke2_@03o`000?nCK9?oTfbC00_oTfbC0ol000000on<Lhco0000oh=lP`0Boh=lP`03
o`000?n4NhCoQ7^400OoQ7^400?o0000ohacS?n<Lh`03on<Lh`00ol0003oYeRWojMHY`0<ojMHY`03
o`000?ngB;Oo]dRg00?o00000ooF:MH00ol0003ogR7NomhQgP0=omhQgP03o`000?o_4>ooka3_00oo
ka3_00?o0000oo`3o?ol0o`02ool0o`3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003on`Ckoo/4n`08oo/4n`?o0000
3?oi1_T2o`0000WokA;]00?o0000oke2_Onm@[d04?nm@[d3o`0000WoTfbC0_l00005ohacS003o`00
0?n3O8?oPgb3013oPgb300?o0000ohAkQ?n4Nh@02?n4Nh@00ol0003oS7><ohacS00>ohacS003o`00
0?nWF:OoYeRW00goYeRW0_l00007omHYeP03o`000?oN8MkogR7N00_ogR7N00?o0000onl@koo_4>l0
3oo_4>l00ol0003oo0?loo`3o00<oo`3o003o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003on`Ckoo/4
n`05oo/4n`?o00004Ooi1_T00ol0003okA;]ondBk@06ondBk@03o`000?nm@[go_D:m00oo_D:m00Co
0000ok5>/OnaC[7o/Dja0_l00005oi=/T`;o00002?n<Lh`00ol0003oPgb3oh=lP`0>oh=lP`03o`00
0?n4NhCoQ7^400[oQ7^400?o0000ohacS?n<Lh`03?n<Lh`00ol0003oYeRWojMHY`0>ojMHY`03o`00
0?oF:MKoeRWF00OoeRWF00?o0000omhQg_oN8Mh02_oN8Mh00ol0003oka3_onl@k`0?onl@k`03o`00
0?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?on`Ck0ol0
000EooT6n@03o`000?o]4^gokA;]00CokA;]4ol00006ok5>/@03o`000?nCK9?o000000;o00002_n<
Lh`00ol0003oPgb3oh=lP`0=oh=lP`03o`000?n4NhCoQ7^400_oQ7^400?o0000ohacS?n<Lh`03?n<
Lh`00ol0003oYeRWojMHY`0=ojMHY`03o`000?oF:MKoeRWF00WoeRWF00?o0000omhQg_oN8Mh02?oN
8Mh00ol0003oka3_onl@k`0?onl@k`03o`000?ol0ocoo0?l00goo0?l00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Ooi1_T00ol0003okA;]ondBk@03ondBk@03o`000?oM8]go
gB;M00oogB;M00?o0000ok5>/OnaC[401OnaC[400ol0003oS7><ohacS00<ohacS003o`000?n3O8?o
Pgb300coPgb300?o0000ohAkQ?n4Nh@03?n4Nh@2o`0000coS7><00?o0000ojMHYonWF:L03OnWF:L0
0ol0003oeRWFomHYeP0:omHYeP03o`000?oN8MkogR7N00OogR7N00?o0000onl@koo_4>l03oo_4>l0
0ol0003oo0?loo`3o00=oo`3o003o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003on@KiooT6n@0F
ooT6n@Co000000?okA;]o`000?oM8]d04?oM8]d00ol0003o/Djaok5>/@06ok5>/@03o`000?n<Lhco
S7><00coS7><00?o0000oh=lPon3O8<02on3O8<00ol0003oQ7^4ohAkQ00=ohAkQ004o`000?n=LXgo
0000o`0000[oS7><00?o0000ojMHYonWF:L03OnWF:L00ol0003oeRWFomHYeP0;omHYeP03o`000?oN
8MkogR7N00KogR7N00?o0000onl@koo_4>l03oo_4>l00ol0003oo0?loo`3o00<oo`3o003o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003on@KiooT6n@0CooT6n@;o00001?oh1oP00ol0003ogB;MomdRg@0@
omdRg@03o`000?naC[7o/Dja00Ko/Dja00?o0000ohacS?n<Lh`03On<Lh`00ol0003oPgb3oh=lP`0:
oh=lP`03o`000?n4NhCoQ7^400coQ7^400?o0000ohebSOn=LXd00_n=LXd2o`0000SoS7><00?o0000
ojMHYonWF:L03?nWF:L00ol0003oeRWFomHYeP0=omHYeP03o`000?oN8MkogR7N00CogR7N00?o0000
onl@koo_4>l03oo_4>l00ol0003oo0?loo`3o00=oo`3o003o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003on@KiooT6n@0AooT6n@03o`000?oh1oSon0Oh00Con0Oh0_l0000@omdRg@03o`000?naC[7o/Dja
00Oo/Dja00?o0000ohacS?n<Lh`03_n<Lh`<o`0000ooQ7^400?o0000ohebSOn=LXd01?n=LXd2o`00
00KoS7><00?o0000ojMHYonWF:L03?nWF:L00ol0003oeRWFomHYeP0>omHYeP03o`000?oN8MkogR7N
00?ogR7N00?o0000onl@koo_4>l03oo_4>l00ol0003oo0?loo`3o00=oo`3o003o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003on@KiooT6n@0>ooT6n@;o00001ooh1oP01?l0003ojaC[o`000?l0000>omdR
g@03o`000?naC[7o/Dja00So/Dja00?o0000ohacS?n<Lh`03On<Lh`00ol0003oQGZ5ohEjQ@08ohEj
Q@03o`000?n4NhCoQ7^400coQ7^400?o0000ohebSOn=LXd01on=LXd2o`0000?oS7><00?o0000ojMH
YonWF:L03OnWF:L00ol0003oeRWFomHYeP0?omHYeP05o`000?oN8MkogR7NomhQg_l000004Oo_4>l0
0ol0003oo0?loo`3o00>oo`3o003o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000con@Ki0_l00009ooP7
n005o`000?o[5>_ojaC[on/Djol000003OoM8]d00ol0003o/Djaok5>/@08ok5>/@03o`000?n<Lhco
S7><00coS7><00?o0000ohEjQOn5NXD02_n5NXD00ol0003oQ7^4ohAkQ00;ohAkQ003o`000?n=LXgo
SG:=00WoSG:=0_l000000on<Lhco0000ojMHY`08ojMHY`Ko00004ooF:MH01?l0003ogR7NomhQg_l0
000Aonl@k`03o`000?ol0ocoo0?l00koo0?l00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oi1_Wo
n@Ki00Oon@Ki0_l0000:ooP7n003o`000?o[5>_ojaC[00?ojaC[1?l00008omdRg@03o`000?naC[7o
/Dja00Wo/Dja00?o0000ohacS?n<Lh`03?n<Lh`00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?n4NhCo
Q7^400[oQ7^400?o0000ohebSOn=LXd03?n=LXd;o`0000Go`Sg200?o0000omHYe_oF:MH04_oF:MH0
0ol0003ogR7No`00000@onl@k`03o`000?ol0ocoo0?l00ooo0?l00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?oi1_Won@Ki00Con@Ki0_l0000<ooP7n003o`000?o[5>_ojaC[00?ojaC[00Co0000olPg
b?o8=lSob3O81Ol00003omdRg@03o`000?naC[7o/Dja00Wo/Dja00?o0000ohacS?n<Lh`02on<Lh`0
0ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?n4NhCoQ7^400WoQ7^400?o0000ohebSOn=LXd03?n=LXd0
0ol0003oYUVVojIIYP02ojIIYP03o`000?o2?L;o`Sg200Wo`Sg200?o0000omHYe_oF:MH04_oF:MH3
o`0000ooka3_00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ooT6
nOoi1_T00_oi1_T00ol0003on0OhooP7n00<ooP7n003o`000?o[5>_ojaC[00CojaC[00?o0000olPg
b?o8=lP01Oo8=lP3o`0000co/Dja00?o0000ohacS?n<Lh`02on<Lh`00ol0003oQGZ5ohEjQ@0<ohEj
Q@03o`000?n4NhCoQ7^400SoQ7^400?o0000ohebSOn=LXd03?n=LXd00ol0003oYUVVojIIYP04ojII
YP03o`000?o2?L;o`Sg200So`Sg200?o0000omHYe_oF:MH04_oF:MH00ol0003on0OhooP7n004o`00
00_oka3_00?o0000oo`3o?ol0o`03ool0o`00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ooT6nOl0
003o00003_oh1oP00ol0003ojaC[on/Dj`05on/Dj`03o`000?o8=lSob3O800Oob3O800?o0000ok5>
/OnaC[402_naC[400ol0003oS7><ohacS009ohacS0;o00003on5NXD00ol0003oQ7^4ohAkQ008ohAk
Q003o`000?n=LXgoSG:=00coSG:=00?o0000ojIIY_nVFJH01?nVFJH00ol0003o`Sg2ol8m`P09ol8m
`PCo00003ooF:MH00ol0003on0OhooP7n005ooP7n0Co00001_o_4>l00ol0003oo0?loo`3o00?oo`3
o003o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003on0OhooP7n00>ooP7n003o`000?o[5>_ojaC[00Go
jaC[00?o0000olPgb?o8=lP02?o8=lP00ol0003o/Djaok5>/@09ok5>/@03o`000?n<LhcoS7><00Ko
S7><0ol000000onCK9?o0000ohEjQ@0?ohEjQ@03o`000?n4NhCoQ7^400KoQ7^400?o0000ohebSOn=
LXd03On=LXd00ol0003oYUVVojIIYP05ojIIYP03o`000?o2?L;o`Sg200So`Sg200Co0000onHIi_oV
6NKoiQWV1Ol00009omHYeP03o`000?oh1oSon0Oh00[on0Oh1?l00002onl@k`03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?oh1oSon0Oh00kon0Oh00?o0000on/Djoo[
5>/01_o[5>/00ol0003ob3O8olPgb007olPgb003o`000?naC[7o/Dja00[o/Dja00?o0000ohacS?n<
Lh`00_n<Lh`3o`0000GoTfbC00?o0000ohEjQOn5NXD03On5NXD00ol0003oQ7^4ohAkQ006ohAkQ003
o`000?n=LXgoSG:=00coSG:=00?o0000ojIIY_nVFJH01_nVFJH00ol0003o`Sg2ol8m`P08ol8m`P03
o`000?oV6NKoiQWV00KoiQWV1Ol00003omHYeP03o`000?oh1oSon0Oh00oon0Oh0_l0000Boo`3o003
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003on0OhooP7n00>ooP7n003o`000?o[5>_ojaC[00KojaC[
00?o0000olPgb?o8=lP01oo8=lP00ol0003o/Djaok5>/@0:ok5>/@03o`000?n<Lhco000000;o0000
2?nCK9<00ol0003oQGZ5ohEjQ@0=ohEjQ@Co00001?n4Nh@00ol0003oSG:=ohebS@0=ohebS@03o`00
0?nVFJKoYUVV00OoYUVV00?o0000ol8m`_o2?L801oo2?L800ol0003oiQWVonHIiP0;onHIiP?o0000
4ooh1oP00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003on0OhooP7
n00<ooP7n003o`000?o[5>_ojaC[00OojaC[00?o0000olPgb?o8=lP02?o8=lP3o`0000Wo/Dja0_l0
000<oi=/T`03o`000?n5NXGoQGZ500_oQGZ500?o0000ohm`Son?L8l00_n?L8l3o`000003ohAkQ?l0
003oSG:=00koSG:=00?o0000ojIIY_nVFJH01onVFJH00ol0003o`Sg2ol8m`P06ol8m`P03o`000?oV
6NKoiQWV00koiQWV00?o0000ooP7n?oh1oP04_oh1oP00ol0003oo0?loo`3o00?oo`3o003o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003on0OhooP7n00<ooP7n003o`000?o[5>_ojaC[00SojaC[00?o0000
olPgb?o8=lP01_o8=lP01?l0003ocC;=oldbcOo=</d3o`0000Ko/Dja00?o0000oi=/TonCK9<03?nC
K9<00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?n?L8ooSg2?00KoSg2?00?o0000ohebSOn=LXd03On=
LXd00ol0003oYUVVojIIYP09ojIIYP03o`000?o2?L;o`Sg200Go`Sg200?o0000onHIi_oV6NH03_oV
6NH00ol0003on0OhooP7n00BooP7n003o`000?ol0ocoo0?l00ooo0?l00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?oh1oSon0Oh00con0Oh00?o0000on/Djoo[5>/02?o[5>/00ol0003ob3O8olPgb005
olPgb003o`000?o=</gocC;=00GocC;=0ol00002ok5>/@03o`000?nCK9?oTfbC00goTfbC00?o0000
ohEjQOn5NXD02?n5NXD00ol0003oSg2?ohm`S`07ohm`S`03o`000?n=LXgoSG:=00coSG:=0ol0000:
ojIIYP03o`000?o2?L;o`Sg200Go`Sg200?o0000onHIi_oV6NH03_oV6NH00ol0003on0OhooP7n00B
ooP7n003o`000?ol0ocoo0?l00ooo0?l00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?oh1oSon0Oh
00_on0Oh00?o0000on/Djoo[5>/02Oo[5>/00ol0003ob3O8olPgb004olPgb003o`000?o=</gocC;=
00WocC;=0_l0000Aoi=/T`03o`000?n5NXGoQGZ500GoQGZ50_l0000;ohm`S`03o`000?n=LXgoSG:=
00[oSG:=00Go0000ojAKY?nTFjCoY5^To`00000:ojIIYP03o`000?o2?L;o`Sg200Co`Sg200?o0000
onHIi_oV6NH03_oV6NH00ol0003on0OhooP7n00CooP7n003o`000?ol0ocoo0?l00goo0?l00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?oh1oSon0Oh00Son0Oh1?l0000<on/Dj`03o`000?o8=lSob3O8
00;ob3O800?o0000oldbcOo=</d02_o=</d2o`00017oTfbC00?o0000ohEjQOn5NXD01?n5NXD00ol0
003oSg2?ohm`S`0<ohm`S`03o`000?n=LXgoSG:=00OoSG:=0_l00005ojAKY0;o00002?nVFJH00ol0
003o`Sg2ol8m`P04ol8m`P03o`000?oV6NKoiQWV00goiQWV00?o0000ooP7n?oh1oP05?oh1oP00ol0
003oo0?loo`3o00=oo`3o003o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003on0OhooP7n007o`0000?o
n`Ck00?o0000on/Djoo[5>/02_o[5>/01Ol0003ob3O8olPgb?o8=lSo000000cocC;=00Co0000okY5
^_njAK[o00004OnCK9<00ol0003oQGZ5ohEjQ@02ohEjQ@03o`000?n?L8ooSg2?00koSg2?00?o0000
ohebSOn=LXd01On=LXd00ol0003oY5^TojAKY007ojAKY003o`000?nVFJKoYUVV00KoYUVV00?o0000
ol8m`_o2?L800oo2?L800ol0003oiQWVonHIiP0=onHIiP03o`000?oh1oSon0Oh01Con0Oh00?o0000
oo`3o?ol0o`03Ool0o`00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;oo/4n`03o`000?o[5>_ojaC[
00WojaC[00Co0000olPgb?o8=lSo00003?o=</d00ol0003o^TFjokY5^P02okY5^P03o`000?nCK9?o
TfbC00ooTfbC00Co0000ohEjQOn5NXGo00004On?L8l00ol0003oSG:=ohebS@04ohebS@03o`000?nT
FjCoY5^T00WoY5^T00?o0000ojIIY_nVFJH01OnVFJH00ol0003o`Sg2ol8m`P03ol8m`P03o`000?oV
6NKoiQWV00goiQWV00?o0000ooP7n?oh1oP05Ooh1oP00ol0003oo0?loo`3o00<oo`3o003o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?o[5>_ojaC[00WojaC[0_l0000<
oldbc@03o`000?njAK[o^TFj00?o^TFj00?o0000oi=/TonCK9<03onCK9<00ol0003oQGZ5o`00000C
ohm`S`04o`000?n=LXgoSG:=ohebS@;o00003OnTFj@2o`0000KoYUVV00Go0000ol8m`_o2?L;o`Sg2
o`00000@onHIiP03o`000?oh1oSon0Oh01Con0Oh0ol0000=oo`3o003o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?o[5>_ojaC[00SojaC[00?o0000oldbcOo=</d02_o=
</d00ol0003o^TFjokY5^P05okY5^P03o`000?nCK9?oTfbC00ooTfbC00?o0000ohm`Son?L8l04on?
L8l00ol0003oSG:=o`00000AojAKY003o`000?nVFJKoYUVV00?oYUVV00Go0000ol8m`_o2?L;o`Sg2
o`00000>onHIiP?o00005?oh1oP2o`0000?oo`3o0_l0000;oo`3o003o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?o[5>_ojaC[00SojaC[00?o0000oldbcOo=</d02Oo=
</d00ol0003o^TFjokY5^P07okY5^P03o`000?nCK9?oTfbC00koTfbC00?o0000ohm`Son?L8l05?n?
L8l00ol0003oY5^TojAKY00AojAKY0;o00001?nVFJH01?l0003o`Sg2ol8m`_l0000:onHIiPCo0000
0ooi1_T00ol0003on0OhooP7n00@ooP7n003o`000?oo0?ooo`3o00Goo`3o0_l00009oo`3o003o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?o[5>_ojaC[00KojaC[00?o
0000oldbcOo=</d02Oo=</d00ol0003o^TFjokY5^P08okY5^P03o`000?nCK9?oTfbC00_oTfbC0ol0
000Gohm`S`03o`000?nTFjCoY5^T01?oY5^T00Ko0000ojIIY_nVFJKoYUVVo`000?o2?L85o`0000Co
iQWV0ol00008ooT6n@03o`000?oh1oSon0Oh00gon0Oh0_l0000:ool0o`;o00001ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000oo/4nook1?/04Ook1?/00ol0003ojaC[on/Dj`05on/Dj`03o`00
0?o=</gocC;=00SocC;=00?o0000okY5^_njAKX02_njAKX00ol0003oTfbCoi=/T`07oi=/T`?o0000
0_nEJYD00ol0003oSg2?ohm`S`0Eohm`S`;o00005OnTFj@00ol0003oYUVVojIIYP02o`0000GofbCK
1?l0000<ooT6n@03o`000?oh1oSon0Oh00[on0Oh0_l0000>ool0o`;o00001?ol0o`00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000oo/4nook1?/04Ook1?/5o`0000?ojaC[00?o0000oldbcOo=</d01oo=
</d00ol0003o^TFjokY5^P0;okY5^P03o`000?nCK9?oTfbC00CoTfbC0ol00006oiEZU@03o`000?n?
L8ooSg2?01?oSg2?00Co0000ojIIY_nVFJKo00005OnTFj@2o`0000WofbCK00?o0000ooT6nOoi1_T0
3?oi1_T00ol0003on0OhooP7n007ooP7n0;o00004_oo0?l2o`0000;oo0?l00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?on`Ck00?o
0000ondBkOo]4^d00oo]4^d3o`0000WocC;=00?o0000okY5^_njAKX03OnjAKX00ol0003oTfbCoi=/
T`03o`0000[oUFZE00?o0000ohm`Son?L8l04On?L8l00ol0003oYUVVojIIYP02ojIIYP03o`000?nT
FjCoY5^T01;oY5^T00?o0000om/TfooK9=/02?oK9=/00ol0003on@KiooT6n@0=ooT6n@03o`000?oh
1oSon0Oh00Con0Oh0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?ok1?_on`Ck013on`Ck00?o0000
ondBkOo]4^d01oo]4^d00ol0003ocC;=oldbc@05oldbc@03o`000?njAK[o^TFj00oo^TFj0_l0000>
oiEZU@03o`000?n?L8ooSg2?00ooSg2?00?o0000ojIIY_nVFJH01?nVFJH00ol0003oY5^TojAKY00@
ojAKY0;o00002ooK9=/00ol0003on@KiooT6n@0=ooT6n@03o`000?oh1oSon0Oh00;on0Oh00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003on`Ckoo/4n`0>oo/4n`03o`000?o]4^gokA;]
00WokA;]00?o0000oldbcOo=</d00oo=</d00ol0003o^TFjokY5^P0@okY5^P03o`000?nEJYGoUFZE
00goUFZE00?o0000ohm`Son?L8l03_n?L8l00ol0003oYUVVojIIYP06ojIIYP;o00003_nTFj@2o`00
0003okE:]Ol0003ofbCK00[ofbCK00?o0000ooT6nOoi1_T03_oi1_T01?l0003on0Oho`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?ok1?_on`Ck00con`Ck00?o0000ondBkOo]4^d02oo]4^d01Ol0
003ocC;=oldbcOo=</go000001;o^TFj00?o0000oiEZUOnEJYD03onEJYD00ol0003oSg2?ohm`S`0<
ohm`S`03o`000?nVFJKoYUVV00WoYUVV00?o0000ojAKY?nTFj@02OnTFj@2o`0000?o]DZe00?o0000
om/TfooK9=/02OoK9=/00ol0003on@KiooT6n@0?ooT6n@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?ok1?_on`Ck00_on`Ck00?o0000ondBkOo]4^d03Oo]4^d00ol0003ocC;=o`00000CokY5
^P03o`000?nEJYGoUFZE013oUFZE00?o0000ohm`Son?L8l02_n?L8l00ol0003oYUVVojIIYP0;ojII
YP03o`000?nTFjCoY5^T00GoY5^T0ol00006okE:]@03o`000?oK9=_ofbCK00SofbCK00?o0000ooT6
nOoi1_T03ooi1_T00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003on`Ckoo/4n`09oo/4n`03o`000?o]4^gokA;]00oo
kA;]00?o0000okY5^_njAKX04OnjAKX00ol0003oUFZEoiEZU@0AoiEZU@03o`000?n?L8ooSg2?00Wo
Sg2?00?o0000ojIIY_nVFJH03OnVFJH00ol0003oY5^TojAKY002ojAKY0;o00002OneB[D00ol0003o
fbCKom/Tf`09om/Tf`03o`000?oi1_Won@Ki00kon@Ki00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?ok1?_on`Ck00Son`Ck00?o0000ondBkOo]4^d04Oo]4^d2o`00017o^TFj00?o0000oiEZUOnEJYD0
4_nEJYD00ol0003oSg2?ohm`S`07ohm`S`03o`000?nVFJKoYUVV00ooYUVV00Co0000ojAKY?l0003o
00002oneB[D00ol0003ofbCKom/Tf`09om/Tf`03o`000?oi1_Won@Ki00kon@Ki00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000ondBkOo]4^d04_o]4^d00ol0003od2o@
o`000002o`0000ko^TFj00?o0000oiEZUOnEJYD04onEJYD00ol0003oSg2?ohm`S`05ohm`S`03o`00
0?nVFJKoYUVV017oYUVV00?o0000okE:]OneB[D03?neB[D00ol0003ofbCKom/Tf`08om/Tf`03o`00
0?oi1_Won@Ki00gon@Ki00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000ook1?/00ol0003okA;]ondB
k@0BondBk@03o`000?o@;m3od2o@00?od2o@0_l0000;okY5^P;o00005_nEJYD7o`0001CoYUVV00?o
0000okE:]OneB[D03?neB[D00ol0003ofbCKom/Tf`08om/Tf`03o`000?oi1_Won@Ki00gon@Ki00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?ok1?_on`Ckoo/4n`?o00005?o]4^d00ol0003od2o@om0_
d006om0_d0?o00002?njAKX00ol0003oYEZUo`000002o`0001;oUFZE00?o0000oiMXUonGJ9L00_nG
J9L00ol0003oTfbCo`00000DojIIYP03o`000?neB[Go]DZe00co]DZe00?o0000om/TfooK9=/02?oK
9=/00ol0003on@KiooT6n@0=ooT6n@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?ok1?_on`Ck00Con`Ck00?o0000
ondBkOo]4^d04_o]4^d00ol0003od2o@om0_d009om0_d0;o00001OnjAKX00ol0003oYEZUojEJY@03
ojEJY@;o00003onEJYD00ol0003oUfRGoiMXU`03oiMXU`04o`000?nCK9?oTfbCo`0001?oYUVV00?o
0000okE:]OneB[D03OneB[D00ol0003ofbCKom/Tf`08om/Tf`03o`000?oi1_Won@Ki00_on@Ki0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003on`Ckoo/4n`06oo/4naCo00003_o@;m03o`000003okY5^_l0003o
YEZU00OoYEZU0ol0000;oiEZU@03o`000?nGJ9OoUfRG00CoUfRG00Go0000oi=/TonCK9?oTfbCo`00
000BojIIYP03o`000?neB[Go]DZe00go]DZe00?o0000om/TfooK9=/01ooK9=/?o`0000?oo@;m0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?ok1?_on`Ck00Kon`Ck00?o0000onXEj_oZ5NX04?oZ5NX0
0ol0003od2o@om0_d00?om0_d003o`000?nUFZGoYEZU00[oYEZU0_l00008oiEZU@03o`000?nGJ9Oo
UfRG00GoUfRG00?o0000oi=/TonCK9<00_nCK9<00ol0003oYUVVojIIYP0?ojIIYP03o`000?neB[Go
]DZe00go]DZe00?o0000om/TfooK9=/01_oK9=/00ol0003ol@kaoo4>l@0<oo4>l@03o`000?om0_go
o@;m00?oo@;m00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003on`Ckoo/4n`08oo/4
n`03o`000?oZ5N[ojQGZ00oojQGZ00?o0000om0_d?o@;m003oo@;m000ol0003oYEZUojEJY@0<ojEJ
Y@;o00001OnEJYD00ol0003oUfRGoiMXU`06oiMXU`03o`000?nCK9?oTfbC00?oTfbC00?o0000ojII
Y_nVFJH03_nVFJH00ol0003o]DZeokE:]@0>okE:]@03o`000?oK9=_ofbCK00CofbCK00?o0000oo4>
lOoa3_403Ooa3_400ol0003oo@;mood2o@04ood2o@;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
n`Ckoo/4n`08oo/4n`03o`000?oZ5N[ojQGZ00kojQGZ00?o0000om0_d?o@;m004?o@;m000ol0003o
YEZUojEJY@0>ojEJY@?o000000?oUFZEo`000?nGJ9L02?nGJ9L00ol0003oTfbCoi=/T`04oi=/T`03
o`000?nVFJKoYUVV00goYUVV4_l00005om/Tf`03o`000?oa3_7ol@ka00gol@ka00?o0000ood2oOom
0_d01oom0_d2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000oo/4nook1?/02?ok1?/00ol0003ol0o`
o`00000?onXEjP03o`000?o@;m3od2o@00ood2o@0_l0000CojEJY@03o`000?nGJ9OoUfRG00SoUfRG
00?o0000oi=/TonCK9<01OnCK9<00ol0003oYUVVojIIYP0<ojIIYP03o`000?oI9]WofBKI00oofBKI
00Go0000om/TfooK9=_ofbCKo`00000@oo4>l@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003on`Ckoo/4n`09oo/4n`04o`000?o`3o3ol0o`o`0000ko
jQGZ00?o0000om0_d?o@;m003_o@;m000ol0003o_4>lo`00000CojEJY@03o`000?nGJ9OoUfRG00So
UfRG00?o0000oi=/TonCK9<01OnCK9<00ol0003oYUVVojIIYP0;ojIIYP03o`000?oI9]WofBKI017o
fBKI00?o0000om/Tfol000004Ooa3_400ol0003oo@;mood2o@0:ood2o@;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?ok1?_on`Ck00Son`Ck00?o0000oo0?l?o`3o000_o`3o000ol0003o
jQGZonXEjP0:onXEjP03o`000?o@;m3od2o@00god2o@0_l00003oka3_003o`000?nUFZGoYEZU013o
YEZU00?o0000oiMXUonGJ9L02?nGJ9L00ol0003oTfbCoi=/T`06oi=/T`03o`000?nVFJKoYUVV00[o
YUVV00?o0000omTVfOoI9]T04_oI9]T00ol0003ol@kaoo4>l@0@oo4>l@03o`000?om0_goo@;m00co
o@;m00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo0?l?o`3o00
0oo`3o000ol0003ojQGZonXEjP09onXEjP03o`000?o@;m3od2o@00cod2o@00?o0000oka3_?nl@k`0
0onl@k`00ol0003oYEZUojEJY@0?ojEJY@03o`000?nGJ9OoUfRG00WoUfRG00?o0000oi=/TonCK9<0
1onCK9<00ol0003oYUVVojIIYP09ojIIYP03o`000?oI9]WofBKI01;ofBKI00?o0000oo4>lOoa3_40
4?oa3_400ol0003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003on`Ckoo/4
n`09oo/4n`03o`000?o`3o3ol0o`00Gol0o`00?o0000onXEj_oZ5NX02?oZ5NX00ol0003od2o@om0_
d00:om0_d0;o00001_nl@k`00ol0003oYEZUojEJY@0?ojEJY@03o`000?nGJ9OoUfRG00WoUfRG00?o
0000oi=/TonCK9<02?nCK9<00ol0003oYUVVojIIYP07ojIIYP03o`000?oI9]WofBKI01?ofBKI00?o
0000oo4>lOoa3_403ooa3_400ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003on`Ckoo/4n`09oo/4n`03o`000?o`3o3ol0o`00Gol0o`00?o0000onXEj_oZ5NX02?oZ5NX0
0ol0003od2o@om0_d009om0_d003o`000?nl@kco_4>l00Oo_4>l00?o0000ojEJYOnUFZD03OnUFZD2
o`0000_oUfRG00?o0000oi=/TonCK9<02OnCK9<00ol0003oYUVVojIIYP06ojIIYP03o`000?oI9]Wo
fBKI01?ofBKI4ol0000?ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?ok1?_on`Ck00Won`Ck00?o0000oo0?
l?o`3o001oo`3o000ol0003ojQGZonXEjP06onXEjP03o`000?o@;m3od2o@00Wod2o@00?o0000oka3
_?nl@k`02?nl@k`00ol0003oYEZUojEJY@0;ojEJY@;o000000?oWf2Oo`000?nGJ9L02_nGJ9L00ol0
003oTfbCoi=/T`09oi=/T`Ko00000onVFJH00ol0003ofBKIomTVf@0ComTVf@03o`000?oa3_7ol@ka
00ool@ka00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003on`Ckoo/4n`09oo/4n`03o`000?o`3o3ol0o`00Sol0o`00?o0000onXEj_oZ5NX01?oZ5NX3o`00
00Sod2o@0_l0000;oka3_003o`000?nUFZGoYEZU00WoYEZU0_l00004oimPW`03o`000?nGJ9OoUfRG
00SoUfRG00?o0000oi=/TonCK9<02?nCK9<00ol0003o/dbcok=</`04ok=</`?o00005?oI9]T3o`00
017ol@ka00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?ok1?_on`Ck00Won`Ck00?o0000oo0?l?o`3o002_o`3o000ol0003ojQGZonXEjP03o`0000?o
iA[U00?o0000om0_d?o@;m001?o@;m000ol0003o_4>loka3_00<oka3_003o`000?nUFZGoYEZU00Go
YEZU0ol00007oimPW`03o`000?nGJ9OoUfRG00OoUfRG00?o0000oi=/TonCK9<01onCK9<00ol0003o
/dbcok=</`08ok=</`03o`000?oI9]WofBKI013ofBKI00Go0000onXEj_oZ5N[ojQGZo`00000@oo4>
l@03o`000?om0_goo@;m00coo@;m00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?ok1?/00ol0003o
l0o`oo0?l00;oo0?l0;o00001ooU6^D01?l0003od2o@om0_d?o@;m02o`0000oo_4>l00?o0000ojEJ
YOnUFZD00onUFZD2o`0000[oWf2O00?o0000oiMXUonGJ9L01onGJ9L00ol0003oTfbCoi=/T`05oi=/
T`;o00003?ncC;<00ol0003ofBKIomTVf@0=omTVf@;o00001OoZ5NX00ol0003ol@kaoo4>l@0=oo4>
l@03o`000?om0_goo@;m00coo@;m00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?ok1?_on`Ck00Wo
n`Ck00?o0000oo0?l?o`3o003?o`3o000ol0003oiA[UonDJi@07onDJi@03o`000?o@;m3o0000017o
_4>l00Co0000ojEJYOnUFZGoYEZU0_l0000=oimPW`03o`000?nGJ9OoUfRG00KoUfRG00?o0000oi=/
TonCK9<01?nCK9<00ol0003o/dbcok=</`0=ok=</`Co00002_oI9]T00ol0003ojQGZonXEjP06onXE
jP03o`000?oa3_7ol@ka00col@ka00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo/4nook1?/02?ok1?/00ol0003ol0o`oo0?l00;oo0?l003o`000?oU6^GoiA[U00Wo
iA[U00?o0000oka3_?nl@k`04Onl@k`3o`00013oWf2O00?o0000oiMXUonGJ9L01OnGJ9L00ol0003o
TfbCoi=/T`03oi=/T`03o`000?ncC;?o/dbc00ko/dbc00Co0000omhQg_oN8MkogR7N1_l00003omTV
f@03o`000?oZ5N[ojQGZ00SojQGZ00?o0000oo4>lOoa3_402ooa3_400ol0003oo@;mood2o@0<ood2
o@03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003on`Ckoo/4n`06oo/4n`03o`000?o`3o3ol0o`00_o
l0o`00?o0000onDJiOoU6^D02_oU6^D00ol0003o_4>loka3_00Aoka3_003o`000?nOH9ooWf2O013o
Wf2O00?o0000oiMXUonGJ9L01OnGJ9L00ol0003oTfbCoi=/T`02oi=/T`03o`000?ncC;?o/dbc00oo
/dbc00?o0000omhQg_oN8Mh01ooN8Mh3o`0000cojQGZ00?o0000oo4>lOoa3_402_oa3_400ol0003o
o@;mood2o@0;ood2o@?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?ok1?_on`Ck00Gon`Ck00?o0000oo0?l?o`3o00
2_o`3o000ol0003oiA[UonDJi@0<onDJi@03o`000?nl@kco_4>l013o_4>l00?o0000oimPWonOH9l0
4OnOH9l00ol0003oUfRGoiMXU`04oiMXU`03o`000?nCK9?oTfbC00;o00004OncC;<00ol0003ogR7N
omhQgP0:omhQgP03o`000?oZ5N[ojQGZ00_ojQGZ3Ol0000;ood2o@;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003on`Ckoo/4n`03oo/4n`03o`000?o`3o3ol0o`00[ol0o`00?o0000onDJiOoU6^D03_oU
6^D00ol0003o_4>loka3_00=oka3_0;o00005?nOH9l3o`0000CoUfRG00?o0000oi=/Tol000004onc
C;<00ol0003ogR7NomhQgP0:omhQgP03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ooH9m_of2OH02Oof
2OH00ol0003oo@;mood2o@07ood2o@;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
oo/4nook1?/00_ok1?/00ol0003ol0o`oo0?l00:oo0?l003o`000?oU6^GoiA[U00koiA[U00?o0000
oka3_?nl@k`02_nl@k`3o`000003okU6^Ol0003oWf2O017oWf2O0_l00003ojQGZ0;o00000_nGJ9L2
o`0001Co/dbc00?o0000omhQg_oN8Mh02_oN8Mh00ol0003ojQGZonXEjP0;onXEjP03o`000?of2OKo
mPWf00[omPWf00?o0000ood2oOom0_d01Oom0_d00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Oo`3o000ol0003oiA[UonDJi@0@onDJi@03o`000?nl@kco_4>l00Ko_4>l0ol00005okU6
^@03o`000?nOH9ooWf2O00goWf2O0_l00007ojQGZ0?o00005OncC;<00ol0003ogR7NomhQgP0;omhQ
gP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooH9m_of2OH03?of2OH3o`0000;oo@;m0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?oi1_Won@Ki00Con@Ki1Ol00003oo0?l003o`000?oU6^GoiA[U017o
iA[U00?o0000oka3_?nl@k`01?nl@k`2o`0000Wo^DJi00?o0000oimPWonOH9l02_nOH9l2o`0000_o
Z5NX00?o0000ok=</oncC;<04_ncC;<00ol0003ogR7NomhQgP0<omhQgP03o`000?oZ5N[ojQGZ00Wo
jQGZ00?o0000ooH9m_of2OH03?of2OH00ol0003oo@;mood2o@02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooT6nOoi1_T02_oi1_T3o`0001GoiA[U00?o0000oka3_?nl@k`00ol0000<okU6^@03o`00
0?nOH9ooWf2O00OoWf2O0_l0000=ojQGZ003o`000?ncC;?o/dbc01;o/dbc00?o0000omhQg_oN8Mh0
3?oN8Mh00ol0003ojQGZonXEjP09onXEjP03o`000?of2OKomPWf00_omPWf00?o0000ood2oOom0_d0
0_om0_d00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oi1_Won@Ki00con@Ki00?o
0000onDJiOoU6^D05?oU6^D2o`0000oo^DJi00?o0000oimPWonOH9l01OnOH9l2o`0000ooZ5NX00?o
0000ok=</oncC;<04_ncC;<00ol0003ogR7NomhQgP0<omhQgP03o`000?oZ5N[ojQGZ00WojQGZ00?o
0000ooH9m_of2OH02_of2OH00ol0003oo@;mood2o@04ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?oi1_Won@Ki00gon@Ki00?o0000onDJiOoU6^D04ooU6^D2
o`00013o^DJi00?o0000oimPWonOH9l00_nOH9l2o`0001;oZ5NX00?o0000ok=</oncC;<04OncC;<0
0ol0003ogR7NomhQgP0<omhQgP03o`000?oZ5N[ojQGZ00WojQGZ00?o0000ooH9m_of2OH02Oof2OH0
0ol0003oo@;mood2o@05ood2o@03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oi1_Won@Ki
00kon@Ki00?o0000onDJiOoU6^D04_oU6^D01?l0003oe2_Dom@[e?l0000@okU6^@04o`000?nOH9oo
0000o`0001CoZ5NX00?o0000ok=</oncC;<04?ncC;<00ol0003ogR7NomhQgP0>omhQgP03o`000?oZ
5N[ojQGZ00OojQGZ00?o0000ooH9m_of2OH02Oof2OH00ol0003oo@;mood2o@06ood2o@03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003on@KiooT6n@0>ooT6n@03o`000?oU6^GoiA[U017oiA[U00?o0000
om@[e?oD:m@00_oD:m@00ol0003o^DJiokU6^@0>okU6^@03o`000?nXEjSoZ5NX01CoZ5NX00?o0000
ok=</oncC;<03OncC;<4o`00013ogR7N00?o0000onXEj_oZ5NX01ooZ5NX00ol0003omPWfooH9mP09
ooH9mP03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oi1_Won@Ki
013on@Ki00?o0000onDJiOoU6^D04?oU6^D00ol0003oe2_Dom@[e003om@[e003o`000?niA[Wo^DJi
00go^DJi00?o0000ojQGZ?nXEjP05?nXEjP00ol0003o/dbcok=</`07ok=</`Ko00000oo7><L00ol0
003ogR7NomhQgP0>omhQgP03o`000?oZ5N[ojQGZ00OojQGZ00?o0000ooH9m_of2OH02?of2OH00ol0
003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003on@KiooT6n@0@ooT6n@03
o`000?oU6^GoiA[U00ooiA[U00?o0000om@[e?oD:m@01OoD:m@00ol0003o^DJiokU6^@0<okU6^@03
o`000?nXEjSoZ5NX01GoZ5NX00?o0000ok=</oncC;<01_l0000:olLha`03o`000?oN8MkogR7N00go
gR7N00?o0000onXEj_oZ5NX01ooZ5NX00ol0003omPWfooH9mP07ooH9mP03o`000?om0_goo@;m00[o
o@;m00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oi1_Won@Ki013on@Ki00?o0000onDJiOoU6^D0
3ooU6^D00ol0003oe2_Dom@[e006om@[e003o`000?niA[Wo^DJi00_o^DJi00?o0000ojQGZ?nXEjP0
5OnXEjP3o`00017oacS700?o0000omhQg_oN8Mh03?oN8Mh00ol0003ojQGZonXEjP07onXEjP03o`00
0?of2OKomPWf00KomPWf00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooT6nOoi1_T04_oi1_T9o`0000OoiA[U00?o0000om@[e?oD:m@02?oD:m@00ol0003o^DJiokU6
^@0:okU6^@03o`000?nXEjSoZ5NX01GoZ5NX00?o0000olLhaoo7><L04Oo7><L00ol0003ogR7NomhQ
gP0=omhQgP03o`000?oZ5N[ojQGZ00GojQGZ00?o0000ooH9m_of2OH01oof2OH00ol0003oo@;mood2
o@0;ood2o@03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003on@KiooT6n@0BooT6n@03o`000?o`3o3o
l0o`00Kol0o`1ol0000<om@[e003o`000?niA[Wo^DJi00Wo^DJi00?o0000ojQGZ?nXEjP05?nXEjP0
0ol0003oacS7olLha`0ColLha`03o`000?oN8MkogR7N00cogR7N00Co0000onXEj_oZ5N[ojQGZ1_l0
0007ooH9mP03o`000?om0_goo@;m00goo@;m1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooT6nOoi1_T04Ooi1_T0
0ol0003ol0o`oo0?l00=oo0?l003o`000?oD:mCoe2_D00_oe2_D00?o0000okU6^OniA[T02OniA[T0
0ol0003oZ5NXojQGZ00CojQGZ003o`000?o7><OoacS701CoacS71?l0000:omhQgPCo00001_og2?L2
o`0000ComPWf00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_oi1_T00ol0003ol0o`oo0?l00=oo0?l0?o00003?oD:m@00ol0003o^DJiokU6^@08okU6
^@03o`000?nXEjSoZ5NX00ooZ5NX1?l0000GolLha`04o`000?oV6NKoiQWVonHIiPKo00000ooN8Mh0
0ol0003om`SgooL8m`0:ooL8m`;o000000?omPWfo`000?om0_d03oom0_d00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo0?loo`3o002oo`3o0?o00003_oi1_T00ol0003ol0o`oo0?l00>oo0?l003o`000?oL8mcog2?L
00?o00002_oD:m@00ol0003o^DJiokU6^@07okU6^@03o`000?nXEjSoZ5NX00SoZ5NX1ol00003ol4n
`@03o`000?o7><OoacS701CoacS700?o0000onHIi_oV6NH02?oV6NH3o`0000oom`Sg00?o0000ood2
oOom0_d03_om0_d00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008oo`3o0?o00002ooi1_T00ol0003o
l0o`oo0?l00>oo0?l003o`000?oL8mcog2?L00?og2?L0ol00008om@[e003o`000?niA[Wo^DJi00Ko
^DJi00Co0000ojQGZ?nXEjSoZ5NX1ol0000:ol4n`@03o`000?o7><OoacS701CoacS700?o0000onHI
i_oV6NH02_oV6NH00ol0003om`SgooL8m`0=ooL8m`03o`000?om0_goo@;m00koo@;m00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?ol0ocoo0?l00_oo0?l0ol00008ooT6n@03o`000?o`3o3ol0o`00ko
l0o`00?o0000om`Sg?oL8m`01_oL8m`3o`0000Koe2_D00?o0000okU6^OniA[T01?niA[T5o`0001;o
`Ck100?o0000olLhaoo7><L04_o7><L00ol0003oiQWVonHIiP0;onHIiP03o`000?og2?Oom`Sg00ko
m`Sg00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ool0o`3o`0000Con@Ki
00?o0000oo0?l?o`3o003oo`3o000ol0003og2?Lom`Sg009om`Sg0?o00001?oD:m@00ol0003o^DJi
okU6^@03o`000003on0Oh?l0003o`Ck101Co`Ck100?o0000olLhaoo7><L04_o7><L00ol0003oiQWV
onHIiP0;onHIiP03o`000?og2?Oom`Sg00oom`Sg00?o0000ood2oOom0_d02_om0_d00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo0?loo`3o00Boo`3o0?o000000?on@Kio`000?o`3o004?o`3o000ol0003og2?Lom`S
g00<om`Sg0?o000000Coe2_Do`000?l0003o00001?oP7n000ol0003o`Ck1ol4n`@0Bol4n`@;o0000
4oo7><L00ol0003oiQWVonHIiP0<onHIiP03o`000?og2?Oom`Sg00oom`Sg00?o0000ood2oOom0_d0
2_om0_d00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000oo`3o?ol0o`05?ol0o`00ol0003ol0o`oo0?
l00@oo0?l003o`000?oL8mcog2?L00oog2?L00?o0000on0Oh?oP7n001_oP7n000ol0003o`Ck1ol4n
`@0@ol4n`@04o`000?o5>/GoaC[5o`0001;oacS700?o0000onHIi_oV6NH03?oV6NH00ol0003om`Sg
ooL8m`0@ooL8m`?o00002?om0_d00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000oo`3o?ol0o`04ool
0o`00ol0003ol0o`oo0?l00@oo0?l003o`000?oL8mcog2?L00oog2?L00?o0000on0Oh?oP7n001_oP
7n000ol0003o`Ck1ol4n`@0?ol4n`@03o`000?o5>/GoaC[500;oaC[500?o0000olLhaoo7><L03_o7
><L00ol0003oiQWVonHIiP0=onHIiP03o`000?og2?Oom`Sg013om`Sg00?o0000ood2oOom0_d00ol0
0005ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo0?loo`3o00Boo`3o003o`000?o`3o3o
l0o`013ol0o`00?o0000om`Sg?oL8m`03_oL8m`00ol0003oh1oPon0Oh007on0Oh003o`000?o1?/7o
`Ck100ko`Ck100?o0000olDjaOo5>/D01?o5>/D2o`0000koacS700?o0000onHIi_oV6NH03OoV6NH0
0ol0003om`SgooL8m`0?ooL8m`03o`000?om0_goo@;m00Coo@;m0ol000000oom0_go0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000oo`3o?ol0o`04Ool0o`00ol0003ol0o`oo0?l00@oo0?l003o`000?oL8mcog2?L
00gog2?L00?o0000on0Oh?oP7n002?oP7n000ol0003o`Ck1ol4n`@0=ol4n`@03o`000?o5>/GoaC[5
00GoaC[500?o0000on4NhOl000000_l0000:olLha`03o`000?oV6NKoiQWV00koiQWV00?o0000ooL8
moog2?L03_og2?L00ol0003oo@;mood2o@08ood2o@03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o0?loo`3o00@oo`3o003o`000?o`3o3ol0o`013ol0o`00?o0000om`Sg?oL8m`03?oL8m`00ol0003o
h1oPon0Oh00:on0Oh003o`000?o1?/7o`Ck100_o`Ck100?o0000olDjaOo5>/D01_o5>/D00ol0003o
hAkQon4Nh@02on4Nh@?o00001oo7><L00ol0003oiQWVonHIiP0>onHIiP03o`000?og2?Oom`Sg00go
m`Sg00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000oo`3o?ol0o`0
3ool0o`3o`00013ol0o`1?l0000:om`Sg003o`000?oP7n3oh1oP00_oh1oP00?o0000ol4n`Oo1?/40
2_o1?/400ol0003oaC[5olDja@06olDja@03o`000?oQ7^7ohAkQ00KohAkQ0_l00004olLha`03o`00
0?oV6NKoiQWV00ooiQWV00?o0000ooL8moog2?L03Oog2?L00ol0003oo@;mood2o@0:ood2o@03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00?o00003Oo`
3o001?l0003oka3_onl@koo_4>l6o`0000?og2?L00?o0000on0Oh?oP7n003?oP7n000ol0003o`Ck1
ol4n`@09ol4n`@03o`000?o5>/GoaC[500OoaC[500?o0000on4NhOoQ7^402?oQ7^43o`000003olLh
aol0003oiQWV013oiQWV00?o0000ooL8moog2?L03?og2?L00ol0003oo@;mood2o@0;ood2o@03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?of2OKomPWf00ComPWf0ol0
0009oo0?l003o`000?o_4>ooka3_00Soka3_0ol0000?on0Oh003o`000?o1?/7o`Ck100So`Ck100?o
0000olDjaOo5>/D02?o5>/D00ol0003ohAkQon4Nh@0;on4Nh@03o`000?oV6NKoiQWV013oiQWV00?o
0000ooL8moog2?L02oog2?L00ol0003oo@;mood2o@0=ood2o@Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?ol0oco
o0?l00[oo0?l00?o0000ooH9m_of2OH02?of2OH3o`0000Gol0o`00?o0000onl@koo_4>l02oo_4>l0
0ol0003oh1oPon0Oh00=on0Oh003o`000?o1?/7o`Ck100Oo`Ck100?o0000olDjaOo5>/D02?o5>/D0
0ol0003ohAkQon4Nh@0<on4Nh@03o`000?oV6NKoiQWV00koiQWV0ol0000=ooL8m`03o`000?om0_go
o@;m00goo@;m00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo0?loo`3o008oo`3
o003o`000?of2OKomPWf00comPWf0ol00002oo0?l003o`000?o_4>ooka3_00_oka3_00?o0000on0O
h?oP7n003_oP7n000ol0003o`Ck1ol4n`@05ol4n`@03o`000?o5>/GoaC[500WoaC[500?o0000on4N
hOoQ7^403OoQ7^400ol0003oiQWVonHIiP0:onHIiP?o00000ooe2_D00ol0003om`SgooL8m`09ooL8
m`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000oo`3o?ol0o`01ool0o`00ol0003o
mPWfooH9mP0?ooH9mP;o00003oo_4>l00ol0003oh1oPon0Oh00=on0Oh003o`000?o1?/7o`Ck100Co
`Ck100?o0000olDjaOo5>/D02_o5>/D00ol0003ohAkQon4Nh@0=on4Nh@03o`000?oV6NKoiQWV00Oo
iQWV0ol00007ooD:m@03o`000?og2?Oom`Sg00Oom`Sg00?o0000ood2oOom0_d03_om0_d00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`01Ool0o`00ol0003omPWfooH9mP0AooH9mP03o`00
0?o_4>ooka3_00goka3_00?o0000on0Oh?oP7n003OoP7n000ol0003o`Ck1ol4n`@03ol4n`@03o`00
0?o5>/GoaC[500[oaC[500?o0000on4NhOoQ7^403ooQ7^400ol0003oiQWVonHIiP03onHIiP?o0000
2ooe2_D9o`00017oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?ol0ocoo0?l00?oo0?l0_l0
000CooH9mP03o`000?o_4>ooka3_00goka3_00?o0000on0Oh?oP7n003OoP7n000ol0003o`Ck1ol4n
`@02ol4n`@03o`000?o5>/GoaC[500_oaC[500?o0000on4NhOoQ7^403ooQ7^400ol0003oiQWVonHI
iP03o`0000kom@[e00?o0000ood2oOom0_d01Oom0_d00ol0003oo@;mood2o@0?ood2o@03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo0?loo`3o?ol0oco000000;oo0?l0_l0000AooH9mP03o`000?o_
4>ooka3_00koka3_00?o0000on0Oh?oP7n003OoP7n001?l0003o`Ck1ol4n`Ol0000>olDja@03o`00
0?oQ7^7ohAkQ013ohAkQ0_l0000AooD:m@03o`000?om0_goo@;m00Koo@;m00?o0000ood2oOom0_d0
3_om0_d00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000oo`3o?l000001Ool0o`2o`0000oomPWf00?o
0000onl@koo_4>l03_o_4>l00ol0003oh1oPon0Oh00=on0Oh0Go00003?o5>/D00ol0003ohAkQon4N
h@0Aon4Nh@03o`000?oe2_Gom@[e013om@[e00?o0000ood2oOom0_d01oom0_d00ol0003oo@;mood2
o@0<ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo0?loo`3o006oo`3o0;o00003Oof2OH0
0ol0003oka3_onl@k`0>onl@k`03o`000?oP7n3oh1oP00goh1oP00?o0000on4NhOoQ7^400_oQ7^43
o`0000WoaC[500?o0000on4NhOoQ7^404OoQ7^400ol0003om@[eooD:m@0?ooD:m@03o`000?om0_go
o@;m00Woo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:oo`3
o0;o00002oof2OH00ol0003oka3_onl@k`0?onl@k`03o`000?oP7n3oh1oP00_oh1oP00?o0000on4N
hOoQ7^401_oQ7^44o`0000GoaC[500?o0000on4NhOoQ7^404OoQ7^400ol0003om@[eooD:m@0?ooD:
m@03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?ol0o`00ol0003omPWfooH9mP08ooH9mP03o`000?o_4>ooka3_00oo
ka3_00?o0000on0Oh?oP7n002_oP7n000ol0003ohAkQon4Nh@0;on4Nh@?o000000?oaC[5o`000?oQ
7^404_oQ7^400ol0003om@[eooD:m@0@ooD:m@03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02_om0_d00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<oo`3o0;o
00001oof2OH3o`00013oka3_00?o0000on0Oh?oP7n002OoP7n000ol0003ohAkQon4Nh@0?on4Nh@;o
00004ooQ7^400ol0003om@[eooD:m@0@ooD:m@03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?ol0ocoo0?l00_oo0?l
0_l00004ooH9mP04o`000?og2?Oom`SgooL8m`;o00003oo_4>l00ol0003oh1oPon0Oh006on0Oh0;o
00004ooQ7^400ol0003ohAkQon4Nh@0Aon4Nh@;o00004Ooe2_D00ol0003oo@;mood2o@0<ood2o@03
o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo0?l
oo`3o00<oo`3o0;o000000?omPWfo`000?og2?L01Oog2?L2o`0000goka3_00?o0000on0Oh?oP7n00
1?oP7n02o`0000;ol0o`00?o0000on4NhOoQ7^404OoQ7^400ol0003ohAkQon4Nh@0?on4Nh@04o`00
0?ob3O;olPgbo`00013om@[e00?o0000ood2oOom0_d03Oom0_d00ol0003oo@;mood2o@02ood2o@Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`03_ol0o`00ol0003om`Sg
ooL8m`07ooL8m`03o`000?o_4>ooka3_00[oka3_00?o0000on0Oh?oP7n000ooP7n000ol0003ol0o`
oo0?l003oo0?l003o`000?oQ7^7ohAkQ013ohAkQ4_l00004oo8=lP;o00003Ooe2_D00ol0003oo@;m
ood2o@0?ood2o@Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000oo`3o?ol0o`03Ool
0o`00ol0003om`SgooL8m`08ooL8m`;o00002oo_4>l00ol0003oh1oPon0Oh002o`0000Ool0o`00?o
0000on4NhOoQ7^403ooQ7^400ol0003oiQWVonHIiP0>onHIiP03o`000?ob3O;olPgb00ColPgb00?o
0000ooD:mOoe2_D02_oe2_D00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000oo`3o?ol0o`02ool0o`00ol0003om`SgooL8
m`0;ooL8m`Ko00001?o_4>l4o`0000[ol0o`00?o0000on4NhOoQ7^403_oQ7^400ol0003oiQWVonHI
iP0>onHIiP03o`000?ob3O;olPgb00GolPgb0_l0000:ooD:m@03o`000?om0_goo@;m00koo@;m00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000oo`3o?ol0o`02_ol0o`0
0ol0003om`SgooL8m`0;ooL8m`03o`000?oh1oSon0Oh00?on0Oh1?l00003ooD:m@03o`000?o`3o3o
l0o`00Wol0o`00?o0000on4NhOoQ7^403?oQ7^400ol0003oiQWVonHIiP0>onHIiP03o`000?ob3O;o
lPgb00SolPgb0_l00008ooD:m@03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`02?ol0o`00ol0003om`SgooL8m`0;ooL8
m`03o`000?oh1oSon0Oh00Oon0Oh00?o0000ooD:mOoe2_D00_oe2_D00ol0003ol0o`oo0?l009oo0?
l003o`000?oQ7^7ohAkQ00_ohAkQ00?o0000onHIi_oV6NH03_oV6NH00ol0003olPgboo8=lP0:oo8=
lP03o`000?oe2_Gom@[e00Gom@[e00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l00Soo0?l00?o0000ooL8moog2?L02_og2?L00ol0003o
n0OhooP7n008ooP7n003o`000?oe2_Gom@[e00;om@[e00?o0000oo0?l?o`3o002_o`3o000ol0003o
hAkQon4Nh@0:on4Nh@03o`000?oV6NKoiQWV00koiQWV00?o0000oo8=l_ob3O802oob3O82o`0000Go
m@[e00?o0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?ol0ocoo0?l00Koo0?l00?o0000ooL8moog2?L02oog2?L00ol0003on0OhooP7n007ooP7n003o`00
0?oe2_Gom@[e00?om@[e00?o0000oo0?l?o`3o002oo`3o000ol0003ohAkQon4Nh@09on4Nh@03o`00
0?oV6NKoiQWV00koiQWV00?o0000oo8=l_ob3O803Oob3O801Ol0003om@[eooD:mOoe2_Go000000ko
o@;m00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000oo`3o?ol0o`01Ool0o`00ol0003om`Sg
ooL8m`0:ooL8m`03o`000?oh1oSon0Oh00Son0Oh00?o0000ooD:mOoe2_D01?oe2_D00ol0003ol0o`
oo0?l00;oo0?l003o`000?oQ7^7ohAkQ00OohAkQ00?o0000onHIi_oV6NH03ooV6NH00ol0003olPgb
oo8=lP0=oo8=lPGo00003Oom0_d00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gom`Sg00?o0000ooP7n?oh1oP02?oh
1oP00ol0003om@[eooD:m@04ooD:m@03o`000?o`3o3ol0o`00col0o`00?o0000on4NhOoQ7^401_oQ
7^400ol0003oiQWVonHIiP0>onHIiP03o`000?ob3O;olPgb00colPgb0_l00004oo`3o003o`000?om
0_goo@;m00[oo@;m00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00?oo@;m00?o0000
ooL8moog2?L02_og2?L00ol0003on0OhooP7n008ooP7n003o`000?oe2_Gom@[e00Kom@[e00?o0000
oo0?l?o`3o003?o`3o000ol0003ohAkQon4Nh@05on4Nh@03o`000?oV6NKoiQWV00koiQWV00?o0000
oo8=l_ob3O802_ob3O82o`0000Koo0?l00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ood2oOom0_d01Oom0_d00ol0003om`SgooL8m`08ooL8m`03o`000?oh1oSon0Oh
00Won0Oh00?o0000ooD:mOoe2_D01_oe2_D00ol0003ol0o`oo0?l00=oo0?l003o`000?oQ7^7ohAkQ
00CohAkQ00?o0000onHIi_oV6NH03_oV6NH00ol0003olPgboo8=lP08oo8=lP;o00002Ool0o`;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000ooP7n?oh
1oP02Ooh1oP00ol0003om@[eooD:m@07ooD:m@03o`000?o`3o3ol0o`00gol0o`00?o0000on4NhOoQ
7^400_oQ7^400ol0003oiQWVonHIiP0?onHIiP03o`000?ob3O;olPgb00KolPgb0_l0000;oo`3o003
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?om0_goo@;m00Soo@;m
00?o0000ooL8moog2?L01_og2?L00ol0003on0OhooP7n009ooP7n003o`000?oe2_Gom@[e00Som@[e
00?o0000oo0?l?o`3o003_o`3o001?l0003ohAkQon4NhOoQ7^44o`0000koiQWV00?o0000oo8=l_ob
3O801?ob3O82o`0000coo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ood2oOom0_d02_om0_d00ol0003om`SgooL8m`04ooL8m`03o`000?oh1oSon0Oh00[on0Oh
00?o0000ooD:mOoe2_D02?oe2_D00ol0003ol0o`oo0?l00?oo0?l003o`000?oQ7^7o000000Com`Sg
1_l00007onHIiP03o`000?ob3O;olPgb00?olPgb0_l0000>oo`3o003o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ood2oOom0_d02oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?oh
1oSon0Oh00[on0Oh00?o0000ooD:mOoe2_D02Ooe2_D3o`0000ool0o`00?o0000ooL8moog2?L02Oog
2?L5o`0000;oiQWV00Co0000oo8=l_ob3O;olPgb0_l0000@oo`3o003o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00goo@;m00Go0000ooL8moog2?Oom`Sg
o`00000<ooP7n003o`000?oe2_Gom@[e00[om@[e00?o0000oo/4nook1?/00ol0000<oo0?l003o`00
0?og2?Oom`Sg00kom`Sg0ol000000oob3O;o0000o`00000Aoo`3o003o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?om0_goo@;m00koo@;m00Go0000ooL8moog2?Oom`Sg
o`00000<ooP7n003o`000?oe2_Gom@[e00Wom@[e00?o0000oo/4nook1?/01?ok1?/3o`0000Sol0o`
00?o0000ooL8moog2?L04_og2?L00ol0003oo0?loo`3o00Aoo`3o003o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Oom0_d00ol0003om`Sgo`00000=ooP7n003o`000?oe
2_Gom@[e00Wom@[e00?o0000oo/4nook1?/01ook1?/3o`0000Col0o`00?o0000ooL8moog2?L04oog
2?L00ol0003oo0?loo`3o00Aoo`3o003o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000ooD:mOoe2_D02Ooe2_D0
0ol0003on`Ckoo/4n`0;oo/4n`?o000000?ol0o`o`000?og2?L05?og2?L00ol0003oo0?loo`3o00@
oo`3o003o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ood2o@03o`000?oh1oSon0Oh
00Son0Oh1?l0000;ooD:m@03o`000?ok1?_on`Ck00kon`Ck00?o0000ooL8moog2?L05Oog2?L00ol0
003oo0?loo`3o00>oo`3o0;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ood2o@04
o`000?oh1oSon0OhooP7n0Oo00001?om0_d00ol0003om@[eooD:m@07ooD:m@03o`000?ok1?_on`Ck
00oon`Ck00?o0000ooL8moog2?L05Oog2?L00ol0003oo0?loo`3o00<oo`3o0;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ood2o@Co00003?om0_d00ol0003o
m@[eooD:m@06ooD:m@03o`000?ok1?_on`Ck00oon`Ck00?o0000ooL8moog2?L05Oog2?L00ol0003o
o0?loo`3o00:oo`3o0;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o@;m00?o0000ood2oOom0_d03_om0_d00ol0003om@[eooD:m@05ooD:m@03o`000?ok1?_on`Ck00oo
n`Ck00?o0000ooL8moog2?L05Oog2?L00ol0003oo0?loo`3o007oo`3o0?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ood2o@03o`000?om0_goo@;m013oo@;m00?o0000ooD:mOoe2_D0
0ooe2_D00ol0003on`Ckoo/4n`0@oo/4n`03o`000?og2?Oom`Sg01Kom`Sg00?o0000oo`3o?ol0o`0
1?ol0o`2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ood2o@;o00004oom0_d00ol0003om@[eooD:
m@02ooD:m@03o`000?ok1?_on`Ck013on`Ck6_l00004oo`3o0;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0Cood2o@04o`000?oe2_Gom@[eo`0001?on`Ck00?o
0000ooh1o_on0Oh05oon0Oh01?l0003oo0?lo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ood2oOom0_d04_om0_d00ol0003om@[eo`00000Coo/4n`03o`000?on
0OkooP7n01SooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@0Cood2o@03o`000?ok1?_on`Ck017on`Ck00?o0000
ooh1o_on0Oh06Oon0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?om0_goo@;m01;oo@;m00?o0000oo/4nook1?/03?ok1?/6o`00
01[ooP7n0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom
0_d04_om0_d00ol0003on`Ckoo/4n`02oo/4n`Wo00001Ooo0?l00ol0003ooP7nooh1oP0Gooh1oP03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ood2oOom0_d04_om0_d5o`0000ooo`3o00?o0000ooh1o_on0Oh05?on0Oh2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?om
0_goo@;m017oo@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04?on
0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ood2oOom0_d03oom0_d00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o
01Goo`3o00?o0000ooh1o_on0Oh03?on0Oh2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Oon0Oh2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ooh1oP;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003ooP7no`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00__l00?l7oooo02;o003o1oooo`2Qo`00o`7ooooo002no`00o`;oool000?oMgN7o`00ool00?l0
:?l00?l00omgMhOoool0oooo002Qo`00o`7ooooo002no`00o`;oool0;?l00?l2oooo0:7o003o0Ooo
ool00;ko003o0_ooo`0/o`00o`;oool0XOl00?l1ooooo`00__l00?l2oooo02co003o0_ooo`2Qo`00
o`7ooooo002Uo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o3?ooo`001olQ8Mgo003oo`00ool00?oo<S;<ojVYEOo^kQ000oooo`001?oMgB7oZJUEofIVV?l@
4>h;o`00o`;oool0XOl00?l1ooooo`00YOl00?l00onHV6Koool0ogMgQ`07o`00o`03oiRHI_ooo`3o
MgN700co003o0_ooo`07o`00o`03oc8bc?ooo`3oool000Woool000CoV9QVo`00ool00?oo003o1?oo
o`001onj^TCo8B7Mo`00oolb</coZJUEoooo0?mgMhL02_l00?l2oooo0:7o003o0Oooool00:Go003o
00?ok^h@oooo0?oMgB401ol00?l00oo^kQ3oool0omgM8@0<o`00o`;oool02?l00?l00om4A;[oool0
oooo0009oooo0007oa0@k_l00?oo003ookZjA?ooo`3oc<`bodA4^P05o`00o`03ofIVV?ooo`3oZJUE
00Wo003o0_ooo`2Qo`00o`7ooooo002To`00o`05oc8bc?ooo`3oool0oooo0?l@4>h01Ol00?l01Olb
</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`09o`00o`03ofIVV?o^kQ3o413^00Ko003o00?oA4Bj
onk^4?n7QgL03?l00?l00onYZEGoool0ojVYE@08o`00o`;oool0XOl00?l1ooooo`00Y?l00?l01OnY
ZEGoool0oooo0?ooo`3oIVJH00Go003o00GoV9QVoooo0?ooo`3oool0ogMgQ`0;o`00o`;oool02_l0
0?l00onHV6KogMdQoa0@kP06o`00o`03odA4^_nYZEGo003o00_o003o00Co<S;<oooo0?ooo`3oA4Bj
1ol00?l2oooo0:7o003o0Oooool00:Co003o0oooo`000omVIYSo^[Y4o`00o`04o`00o`05onk^4?oo
o`3oool0ofIVV?oMgB402ol00?l2oooo00_o003o00?oZJUEomgM8Ol@4>h05?l00?l2oooo0003okZj
A?l00?oo003o00Go003o0_ooo`2Qo`00o`7ooooo002So`00o`07oeEEZOooo`3oool0onk^4?l00?oo
k^h@oa0@kP03o`00o`07oeEEZOooo`3oool0onk^4?l00?ook^h@ob4Qg@0:o`00o`;oool02ol00?l0
0ol@4>kogMdQojVYE@0Do`00o`?oool01ol00?l2oooo0:7o003o0Oooool00:?o003o00OoZJUEoooo
0?ooo`3oV9QVo`00oonHV6KoIVJH00?o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN700[o
003o0_ooo`0<o`00o`03oa0@k_ooo`3oZJUE01;o003o00CoEEFYoooo0?ooo`3oool01ol00?l2oooo
0:7o003o0Oooool00:?o003o0oooo`001?lQ8Mgo003oodA4^_nj^T@3o`00o`?oool000Co<S;<o`00
oom4A;[ogMdQ2_l00?l2oooo00go003o00?o<S;<oooo0?mgMhL04Ol00?l01?nj^TCoool0oooo0?oo
o`07o`00o`;oool0XOl00?l1ooooo`00X_l00?l01?mEEJWoool0oooo0?oMgB43o`00o`04oooo0?l0
0?oo003ooeEEZ@;oool000Kok^h@o`00ool00?oo003ooooo0?lQ8Md9o`00o`;oool03_l00?l00on7
QgOoool0oeEEZ@0?o`00o`05ojVYEOooo`3oool0oooo0?nYZED01ol00?l2oooo0:7o003o0Oooool0
0:;o003o00CoZJUEoooo0?ooo`3oMgN70ol00?l01?nYZEGoEEFYo`00oonYZED2oooo0006oiRHI_l0
0?oo003oo`00oonYZEGoMgN72Ol00?l2oooo00oo003o00?ok^h@oooo0?lQ8Md03?l00?l00olb</co
c<`boooo0003oooo0003ob4QgOl00?oo003o00Go003o0_ooo`2Qo`00o`7ooooo002Ro`00o`?oool0
00Oo8B7Mo`00ool00?oo003ooeEEZOnYZEGo003o00?oool000Ko<S;<o`00ool00?oo003ooeEEZOoM
gB49o`00o`;oool03ol00?l00omgMhOoool0olc<<P09o`00o`03odA4^_mgMhOogMdQ00Goool000?o
IVJHo`00ool00?l01_l00?l2oooo0:7o003o0Oooool00:7o003o00CoEEFYoooo0?ooo`3ogMdQ1Ol0
0?l01Oo^kQ3oEEFYoooo0?ooo`3ok^h@00Go003o00?oool0ob4QgOl00?l01ol00?l2oooo00oo003o
00Co8B7Moooo0?ooo`3oEEFY1Ol00?l00olb</coool0oooo0007oooo0003ofIVV?l00?oo003o00Oo
003o0_ooo`2Qo`00o`7ooooo002Qo`00o`04ojVYEOooo`3oool0ogMgQ`Go003o00Go^[Y4onk^4?oo
o`3oool0ohN7M`05o`00o`03ojVYEOmgMhOo003o00Oo003o0_ooo`0@o`00o`;oool000?o^[Y4o`00
ool00?l00ol00?l00olQ8Mgoool0oooo0005oooo0003ojVYEOlQ8Mgo003o00Wo003o0_ooo`2Qo`00
o`7ooooo002Po`00o`05oa0@k_ooo`3oool0oooo0?lQ8Md01Ol00?l01OmVIYSoool0oooo0?ooo`3o
8B7M00Go003o00?oEEFYomgM8Ol00?l01ol00?l2oooo00Oo003o00?o^[Y4ob4QgOl00?l01_l00?l3
oooo00Ko003o00OoZJUEoooo0?o^kQ3oc<`bohN7MomEEJWo413^00co003o0_ooo`2Qo`00o`7ooooo
002Po`00o`04ofIVV?ooo`3oool0omgM8@Ko003o00CoIVJHoooo0?ooo`3ogMdQ1ol00?l00oooo`3o
8B7Mo`00o`06o`00o`;oool01ol00?l00onj^TCoV9QVo`00o`05o`00o`04oeEEZOooo`3oool0oooo
00Ko003o00?o8B7Monk^4?l00?l04?l00?l2oooo0:7o003o0Oooool00:3o003o00Coc<`boooo0?oo
o`3oMgN71_l00?l01?nj^TCoool0oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`07
o`00o`03ofIVV?ooo`3o<S;<00Go003o00Coc<`boooo0?ooo`3oool01ol00?l00oo<c3;oEEFYo`00
o`0?o`00o`;oool0XOl00?l1ooooo`00Wol00?l01OlQ8Mgoool0oooo0?ooo`3o8B7M00Go003o00Go
413^oooo0?ooo`3oool0ob4Qg@07o`00o`03oeEEZOoMgB7o003o00Ko003o0_ooo`07o`00o`08oa0@
k_ooo`3oool0ofIVV?l@4>ko003ooc8bc?o<c383oooo0003okZjA?l00?oo003o00Go003o00?oA4Bj
olc<<_l00?l03ol00?l2oooo0:7o003o0Oooool009oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l0
1?mgMhOoool0oooo0?oMgB49o`00o`03oooo0?lQ8Mgo003o00Go003o0_ooo`08o`00o`03ofIVV?oo
o`3oool000Ooool000?o<S;<o`00ool00?l01_l00?l00oo<c3;oool0oooo0005oooo0003olc<<_l0
0?oo003o00Ko003o0_ooo`2Qo`00o`7ooooo002Mo`00o`03ob4QgOn7QgOoool000;oool000?ok^h@
oc8bc?l00?l00ol00?l01_mEEJWoool0oooo0?ooo`3ok^h@oc8bc0Ko003o00Ko8B7MohN7Moooo`3o
k^h@oeEEZOl@4>h4o`00o`;oool02Ol00?l00on7QgOoool0oooo0005oooo0003ofIVV?l00?oo003o
00Oo003o00?oIVJHoooo0?ooo`001_ooo`000olQ8Mgo003oo`00o`05o`00o`;oool0XOl00?l1oooo
o`00W?l00?l00om4A;[oool0oooo0007oooo0003ohN7Moooo`3oool000Ooool00_l00?l00on7QgOo
ool0oooo0005oooo0004odA4^_l00?oo003oo`00o`;oool000?oMgN7o`00ool00?l01ol00?l00om4
A;[o^[Y4oooo0002oooo0003ojVYEOlb</co003o00[o003o00?ok^h@oooo0?ooo`001Oooo`000omg
MhOo003oo`00o`04o`00o`03ogMgQoooo`3oool00:7o003o0Oooool00;ko003o1oooo`0No`00o`04
ogMgQooMgB7o003oo`00o`Ooool0XOl00?l1ooooo`00i?l00?l00olQ8Mgo003oo`00o`2Xo`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.7188 0 ]
[.5 1.04444 43.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(50) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
135.812 29.000 moveto
(D) show
146.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
.999 .001 .999 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.997 .003 .997 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.997 .003 .997 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.997 .003 .997 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.996 .004 .996 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.994 .006 .994 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
.999 .001 .999 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.99 .01 .99 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.99 .01 .99 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.98 .02 .98 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.993 .007 .993 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.997 .003 .997 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.955 .045 .955 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.988 .012 .988 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.981 .019 .981 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.98 .02 .98 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.985 .015 .985 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.994 .006 .994 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.996 .004 .996 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.977 .023 .977 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.991 .009 .991 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.961 .039 .961 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.994 .006 .994 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.992 .008 .992 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.988 .012 .988 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.987 .013 .987 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.973 .027 .973 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.994 .006 .994 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.978 .022 .978 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
.999 .001 .999 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.997 .003 .997 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.967 .033 .967 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.892 .108 .892 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.906 .094 .906 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.997 .003 .997 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.99 .01 .99 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.967 .033 .967 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.966 .034 .966 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.918 .082 .918 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.901 .099 .901 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.839 .161 .839 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.963 .037 .963 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.98 .02 .98 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
.999 .001 .999 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.981 .019 .981 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.96 .04 .96 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.997 .003 .997 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.881 .119 .881 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.992 .008 .992 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.991 .009 .991 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.927 .073 .927 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.84 .16 .84 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.932 .068 .932 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.711 .289 .711 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.71 .29 .71 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.804 .196 .804 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.892 .108 .892 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.909 .091 .909 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.993 .007 .993 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.767 .233 .767 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.741 .259 .741 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.982 .018 .982 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
.999 .001 .999 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.797 .203 .797 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.869 .131 .869 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.954 .046 .954 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.978 .022 .978 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.835 .165 .835 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.934 .066 .934 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.676 .324 .676 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.947 .053 .947 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.87 .13 .87 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.997 .003 .997 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.594 .406 .594 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.652 .348 .652 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.99 .01 .99 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.649 .351 .649 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.6 .4 .6 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.959 .041 .959 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.995 .005 .995 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.799 .201 .799 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.573 .427 .573 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.611 .389 .611 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.934 .066 .934 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.665 .335 .665 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.777 .223 .777 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.996 .004 .996 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.637 .363 .637 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.533 .467 .533 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.564 .436 .564 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.518 .482 .518 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.687 .313 .687 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.77 .23 .77 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.983 .017 .983 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.814 .186 .814 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.88 .12 .88 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.545 .455 .545 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.512 .488 .512 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.522 .478 .522 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.555 .445 .555 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.57 .43 .57 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.899 .101 .899 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.962 .038 .962 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.984 .016 .984 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.787 .213 .787 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.553 .447 .553 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.912 .088 .912 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.996 .004 .996 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.625 .375 .625 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.719 .281 .719 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.587 .413 .587 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.652 .348 .652 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.963 .037 .963 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.696 .304 .696 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.565 .435 .565 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.991 .009 .991 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.998 .002 .998 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.962 .038 .962 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.97 .03 .97 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.693 .307 .693 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.993 .007 .993 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.529 .471 .529 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.51 .49 .51 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.843 .157 .843 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.888 .112 .888 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.586 .414 .586 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.631 .369 .631 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.779 .221 .779 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.91 .09 .91 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.586 .414 .586 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.996 .004 .996 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.547 .453 .547 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.625 .375 .625 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.696 .304 .696 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.985 .015 .985 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.758 .242 .758 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.997 .003 .997 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.803 .197 .803 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.724 .276 .724 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.658 .342 .658 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.968 .032 .968 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.981 .019 .981 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.953 .047 .953 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.627 .373 .627 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.761 .239 .761 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.834 .166 .834 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.936 .064 .936 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.989 .011 .989 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.997 .003 .997 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.77 .23 .77 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.867 .133 .867 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.751 .249 .751 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.992 .008 .992 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.973 .027 .973 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.932 .068 .932 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.991 .009 .991 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.997 .003 .997 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.781 .219 .781 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.836 .164 .836 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.997 .003 .997 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.841 .159 .841 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.956 .044 .956 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.934 .066 .934 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.921 .079 .921 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.889 .111 .889 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.99 .01 .99 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.98 .02 .98 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.981 .019 .981 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.99 .01 .99 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.913 .087 .913 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.998 .002 .998 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.991 .009 .991 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.925 .075 .925 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.913 .087 .913 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.979 .021 .979 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.944 .056 .944 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.997 .003 .997 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.933 .067 .933 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.997 .003 .997 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.991 .009 .991 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.978 .022 .978 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
.999 .001 .999 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.974 .026 .974 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.957 .043 .957 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.978 .022 .978 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.97 .03 .97 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.981 .019 .981 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.978 .022 .978 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.992 .008 .992 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.985 .015 .985 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.995 .005 .995 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.997 .003 .997 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.992 .008 .992 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.98 .02 .98 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.99 .01 .99 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.992 .008 .992 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.996 .004 .996 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.992 .008 .992 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.993 .007 .993 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.989 .011 .989 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.997 .003 .997 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.998 .002 .998 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.991 .009 .991 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.997 .003 .997 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.997 .003 .997 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.992 .008 .992 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.997 .003 .997 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
.999 .001 .999 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7no`00000?ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh03?on0Oh0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ool0
oooo0?l02_oo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`09
ool0o`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ooh1oP03o`000?oo
0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000oooP7n00?o0000ool0oooo0?l02?oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`06ool0o`03
o`000?on0OkooP7n017ooP7n00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ooh1oP03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0
003oo`3oo`000?l00003ood2o@?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ok1?_on`Ckoo/4n`Go00002Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?on0Oko
oP7n01;ooP7n00?o0000ood2oOom0_d01_om0_d2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003on`Ckoo/4n`07oo/4
n`Go00001Oon0Oh00ol0003oo`3oool0o`03ool0o`?o00004oon0Oh00ol0003oo@;mood2o@08ood2
o@;o00002ooo0?l3o`0000?oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ok1?_on`Ck00con`Ck1_l00002ool0o`?o00000oon0Oh3o`0000oo
oP7n00?o0000ood2oOom0_d02oom0_d3o`0000Koo`3o0_l00007ood2o@03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo/4nook1?/04Ook1?/3o`0000WooP7n
0_l0000<ooh1oP03o`000?om0_goo@;m00ooo@;m0_l000001?oo0?oo0000o`000?l0000:ood2o@03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n
0_l00009ooh1oP03o`000?om0_goo@;m01;oo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo/4nook1?/04_ok
1?/00ol0003ooP7nooh1oP0=ooh1oP?o00001Oon0Oh00ol0003oo@;mood2o@0Cood2o@03o`000?om
0_goo@;m00goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;ooP7n00?o0000ood2oOom0_d05?om0_d00ol0003oo@;mood2o@0>
ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_om0_d00ol0003ooP7nooh1oP0Aooh1oP03o`000?ok1?_on`Ck
01?on`Ck00?o0000ooh1o_on0Oh04_on0Oh2o`0001Ooo@;m00?o0000ood2oOom0_d03oom0_d=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000Koo@;m00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oom0_d0
0ol0003oo@;mood2o@0@ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l02?oo0?l7
o`0000?oo@;m00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[oo@;m0_l0000@ooh1
oP03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001Coo@;m00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0;ood2o@04o`000?oo0?oo
o`3oool0o`Ko00002_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000goo@;m00Co0000ooX5n_l0003o00003Oon0Oh00ol0003on`Ckoo/4n`0Boo/4n`03o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003oo@;mood2o@0Aood2o@03o`000?om
0_goo@;m00ooo@;m00?o0000ood2oOom0_d03?om0_d3o`00013oo@;m00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oom0_d00ol0003onPGjooX5nP02ooX5nP;o00002oon0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003oo@;mood2o@0@ood2o@03o`000?om0_goo@;m00koo@;m00?o0000ood2oOom0_d03Oom0_d0
0ol0003oo@;mood2o@0Aood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017oo@;m00?o0000ooX5
n_oj1OX01Ooj1OX2o`0000WooP7n00?o0000oo/4nook1?/04_ok1?/00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ood2oOom0_d03oom0_d00ol0003oo@;mood2o@0>ood2
o@03o`000?om0_goo@;m00goo@;m00?o0000ood2oOom0_d04Oom0_d00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ood2oOom0_d04?om0_d00ol0003onPGjooX5nP07ooX5nP03o`000?on0OkooP7n00Go
oP7n00?o0000oo/4nook1?/04_ok1?/00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_goo@;m00ko
o@;m00?o0000ood2oOom0_d04Oom0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d0
3oom0_d00ol0003onPGjooX5nP09ooX5nP;o00001Oon0Oh00ol0003on`Ckoo/4n`0Boo/4n`03o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003oo@;mood2o@0=ood2o@03o`00
0?om0_goo@;m00goo@;m00?o0000ood2oOom0_d03_om0_d00ol0003oo@;mood2o@0Aood2o@03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0?ood2o@03o`000?oj1O[onPGj00_onPGj0_l0
0003ooh1oP03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?om0_goo@;m00_oo@;m00?o0000ood2oOom0_d03Oom0_d00ol0003oo@;mood2
o@0?ood2o@03o`000?om0_goo@;m017oo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_go
o@;m00koo@;m00?o0000ooX5n_oj1OX03_oj1OX3o`0001?on`Ck0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ood2oOom0_d02_om0_d00ol0003oo@;mood2o@0=ood2o@03o`000?om0_go
o@;m00ooo@;m00?o0000ood2oOom0_d04Oom0_d00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooX5
n_oj1OX04Ooj1OX00ol0003on`Ckoo/4n`0?oo/4n`;o00000oof2OH00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ood2oOom0_d02Oom0_d00ol0003oo@;mood2o@0=ood2
o@03o`000?om0_goo@;m013oo@;m00?o0000ood2oOom0_d04Oom0_d00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ood2oOom0_d03?om0_d00ol0003onPGjooX5nP0AooX5nP03
o`000?ok1?_on`Ck00gon`Ck0_l00006ooH9mP;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d03?om0_d00ol0003oo@;mood2o@0Aood2o@03
o`000?om0_goo@;m017oo@;m00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ood2oOom0_d02oom0_d00ol0003onPGjooX5nP0CooX5nP03o`000?ok1?_on`Ck00[on`Ck
0_l0000:ooH9mP03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003oo@;m
ood2o@07ood2o@03o`000?om0_goo@;m00coo@;m00?o0000ood2oOom0_d04Oom0_d00ol0003oo@;m
ood2o@0Aood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?om
0_goo@;m00[oo@;m00?o0000ooX5n_oj1OX05Ooj1OX00ol0003on`Ckoo/4n`06oo/4n`?o00003Oof
2OH2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003oo@;mood2o@06ood2o@03o`000?om
0_goo@;m00_oo@;m00?o0000ood2oOom0_d04_om0_d00ol0003oo@;mood2o@0Aood2o@03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo@;mood2o@0:ood2o@03o`000?oj1O[o
nPGj01GonPGj00?o0000oo/4nook1?/01?ok1?/2o`0001;omPWf00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?om0_goo@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d0
0ol0003oo@;mood2o@0Bood2o@03o`000?om0_goo@;m017oo@;m00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003oo@;mood2o@09ood2o@03o`000?oj1O[onPGj01OonPGj00Co0000oo/4nook1?_on`Ck0_l0000E
ooH9mP03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003oo@;mood2o@03
ood2o@03o`000?om0_goo@;m00Soo@;m1Ol0000Cood2o@?o00004_om0_d00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ood2
oOom0_d02Oom0_d00ol0003onPGjooX5nP0HooX5nP?o00006?of2OH2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003oo@;mood2o@02ood2o@04o`000?om0_goo@;mood2o@Oo00001Ooj1OX0
0ol0003oo@;mood2o@0?ood2o@04o`000?ok1?_on`Ckoo/4n`;o00004Oom0_d00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ood2oOom0_d02?om0_d0
0ol0003onPGjooX5nP0GooX5nPGo00006_of2OH00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ood2oOom0_goo@;m1?l0000=ooX5nP03o`000?om0_goo@;m00goo@;m00?o
0000oo/4nook1?/01?ok1?/2o`0000ooo@;m00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ood2oOom0_d01_om0_d00ol0003onPGjooX5nP0E
ooX5nP?o000000KolPgbo`000?o_4>oo0000on4NhOl0000JooH9mP;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?om0_go000001;onPGj00?o0000ood2oOom0_d02_om0_d2o`0000Won`Ck
0_l00007ood2o@So00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo0?l0ol0000Bool0o`03o`000?om0_goo@;m00Koo@;m00?o0000ooX5n_oj
1OX04_oj1OX3o`0000?olPgb00Co0000onl@koo_4>oo00000_oQ7^400ol0003omPWfooH9mP0IooH9
mP03o`000?on0Oko000001_on`Ck00?o0000ooX5n_oj1OX04_oj1OX00ol0003oo@;mood2o@08ood2
o@03o`000?ok1?_on`Ck00_on`Ck1ol00008ood2o@Co00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?loo`3o002oo`3o0?o00003ooo0?l00ol0003o
o@;mood2o@05ood2o@03o`000?oj1O[onPGj013onPGj0ol00005oo8=lP05o`000?o_4>ooka3_onl@
kol000000ooQ7^400ol0003omPWfooH9mP0IooH9mP03o`000?ok1?_on`Ck01[on`Ck00?o0000ooX5
n_oj1OX04ooj1OX00ol0003oo@;mood2o@06ood2o@03o`000?ok1?_on`Ck00con`Ck00?o0000ood2
oOom0_d03?om0_d00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?ol0ocoo0?l00Goo0?l0ol0000;ool0o`Co00001Oom0_d00ol0003o
nPGjooX5nP0=ooX5nP?o00002?ob3O801Ol0003oka3_onl@koo_4>oo000000CohAkQ00?o0000ooH9
m_of2OH06?of2OH00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?oj1O[onPGj01GonPGj00?o0000ood2
oOom0_d00oom0_d2o`0000oon`Ck00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000oo`3o?ol0o`02?ol0o`3o`0000Ko
o`3o0_l00004oo/4n`?o000000?oo@;mo`000?oj1OX03?oj1OX3o`0000[olPgb00?o0000onl@koo_
4>l00_o_4>l00ol0003ohAkQon4Nh@03on4Nh@03o`000?of2OKomPWf01OomPWf00?o0000oo/4nook
1?/06Ook1?/00ol0003onPGjooX5nP0FooX5nP05o`000?om0_goo@;mood2oOl000004Ook1?/00ol0
003oo@;mood2o@0<ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000oo`3o?ol0o`02ool0o`3o`000003ool0ool0003o000000Wo
n`Ck0_l0000:ooX5nP?o00003Oob3O800ol0003oka3_onl@k`02onl@k`03o`000?oQ7^7ohAkQ00Co
hAkQ00?o0000ooH9m_of2OH05oof2OH00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?oj1O[onPGj01Oo
nPGj00?o0000ood2oOl000004Ook1?/00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`0
3_ol0o`00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oj1O[onPGj00ConPGj0ol0000?oo8=lP03o`00
0?o_4>ooka3_00?oka3_00?o0000on4NhOoQ7^401OoQ7^400ol0003omPWfooH9mP0FooH9mP03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000ooX5n_oj1OX06Ooj1OX00ol0003on`Ckoo/4n`0@oo/4n`03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00con`Ck00?o
0000ooX5n_oj1OX00ol0000Aoo8=lP03o`000?o_4>ooka3_00Coka3_00?o0000on4NhOoQ7^401_oQ
7^42o`0001GomPWf0ol0000Hoo/4n`03o`000?oj1O[onPGj01WonPGj00?o0000oo/4nook1?/04?ok
1?/00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?ok1?_on`Ck00gon`Ck0_l0000D
oo8=lP03o`000?o_4>ooka3_00Coka3_00?o0000on4NhOoQ7^402?oQ7^400ol0003omPWfooH9mP0@
ooH9mP;o00000ooS7><00ol0003on`Ckoo/4n`0Doo/4n`03o`000?oj1O[onPGj01[onPGj00?o0000
oo/4nook1?/04?ok1?/00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?oo`3o003o`000?ok1?_on`Ck
00kon`Ck00?o0000oo8=l_ob3O804_ob3O800ol0003oka3_onl@k`05onl@k`03o`000?oQ7^7ohAkQ
00WohAkQ00?o0000ooH9m_of2OH03Oof2OH2o`0000KohacS0_l0000Doo/4n`03o`000?oj1O[onPGj
01[onPGj00?o0000oo/4nook1?/04?ok1?/00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000oo`3o?l0
00003ool0o`00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ob3O;olPgb01;olPgb00?o0000onl@koo_
4>l01Oo_4>l00ol0003ohAkQon4Nh@0:on4Nh@03o`000?of2OKomPWf00[omPWf0_l0000:on<Lh`03
o`000?ok1?_on`Ck017on`Ck00?o0000ooX5n_oj1OX06_oj1OX00ol0003on`Ckoo/4n`0?oo/4n`03
o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?ol0ocoo0?lo`0000oo
o0?l00?o0000oo/4nook1?/03ook1?/00ol0003olPgboo8=lP0@oo8=lP03o`000?o_4>ooka3_00Ko
ka3_00?o0000on4NhOoQ7^402ooQ7^400ol0003omPWfooH9mP08ooH9mP03o`000?oS7>?ohacS00_o
hacS0_l0000@oo/4n`03o`000?oj1O[onPGj01_onPGj00?o0000oo/4nook1?/03ook1?/00ol0003o
o@;mood2o@0>ood2o@03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0ocoo0?l00;oo0?l00?o0000oo`3o?ol0o`0
3?ol0o`00ol0003on`Ckoo/4n`0?oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000onl@koo_4>l0
1oo_4>l00ol0003ohAkQon4Nh@0<on4Nh@03o`000?of2OKomPWf00GomPWf0_l0000@on<Lh`03o`00
0?ok1?_on`Ck00gon`Ck00?o0000ooX5n_oj1OX06ooj1OX00ol0003on`Ckoo/4n`0?oo/4n`03o`00
0?om0_goo@;m00koo@;m00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?ol0ocoo0?l00?oo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000onl@koo_4>l01oo_4>l00ol0003ohAkQon4N
h@0=on4Nh@03o`000?of2OKomPWf00;omPWf0_l0000Con<Lh`;o00003?ok1?/00ol0003onPGjooX5
nP0LooX5nP?o00003ook1?/00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?ol0oco
o0?l00Coo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ob3O;o
lPgb00kolPgb00?o0000onl@koo_4>l02?o_4>l00ol0003ohAkQon4Nh@0>on4Nh@04o`000?of2OKo
0000o`0001OohacS00?o0000oo/4nook1?/02Ook1?/00ol0003onPGjooX5nP0LooX5nP03o`000?oh
1oSon0Oh00?o00003?ok1?/00ol0003oo@;mood2o@0>ood2o@03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?ol0oco
o0?l00Goo0?l00?o0000oo`3o?ol0o`02ool0o`00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?ob3O;o
lPgb00colPgb00?o0000onl@koo_4>l02Oo_4>l00ol0003ohAkQon4Nh@0?on4Nh@03o`000?oS7>?o
hacS01SohacS0_l00009oo/4n`03o`000?oj1O[onPGj01_onPGj00?o0000ooP7n?oh1oP01?oh1oP4
o`0000Son`Ck00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000oo`3o?ol0o`01_ol0o`00ol0
003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck013on`Ck0_l0000>oo8=lP03o`000?o_4>ooka3_
00Woka3_00?o0000on4NhOoQ7^403ooQ7^400ol0003ohacSon<Lh`0Jon<Lh`03o`000?ok1?_on`Ck
00Con`Ck0ol0000LooX5nP03o`000?oh1oSon0Oh00Won0Oh0ol00004oo/4n`03o`000?om0_goo@;m
00ooo@;m00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?ol0ocoo0?l00Soo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0@oo/4n`04
o`000?o]4^gokA;]o`0000colPgb00?o0000onl@koo_4>l02_o_4>l00ol0003ohAkQon4Nh@0?on4N
h@03o`000?oS7>?ohacS01_ohacS0_l00003oo/4n`04o`000?o_4>ooka3_onl@k`?o00006?oj1OX0
0ol0003on0OhooP7n00=ooP7n0?o000000?on`Cko`000?om0_d04?om0_d00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?ol0ocoo0?l
00Woo0?l00?o0000oo`3o?ol0o`02Ool0o`00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o]4^gokA;]
00;okA;]00?o0000oo8=l_ob3O802Oob3O800ol0003oka3_onl@k`0:onl@k`03o`000?oQ7^7ohAkQ
00kohAkQ00?o0000on<LhooS7><07_oS7><00ol0003on`Cko`000007onl@k`?o00005?oj1OX00ol0
003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?ol0ocoo0?l00[oo0?l00?o0000oo`3o?ol
0o`02Ool0o`00ol0003on`Ckoo/4n`0=oo/4n`;o00001_o]4^d00ol0003olPgboo8=lP07oo8=lP03
o`000?o_4>ooka3_00_oka3_00?o0000on4NhOoQ7^403_oQ7^400ol0003ohacSon<Lh`0Oon<Lh`03
o`000?o_4>ooka3_00Woka3_0ol0000@ooX5nP03o`000?oh1oSon0Oh01?on0Oh00?o0000ood2oOom
0_d03_om0_d4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo0?l
oo`3o00;oo`3o003o`000?ol0ocoo0?l00Woo0?l00?o0000oo/4nook1?/03?ok1?/00ol0003okA;]
ondBk@07ondBk@03o`000?ob3O;olPgb00GolPgb00?o0000onl@koo_4>l03?o_4>l00ol0003ohAkQ
on4Nh@0>on4Nh@03o`000?oS7>?ohacS01oohacS00?o0000onl@koo_4>l03?o_4>l3o`0000gonPGj
00?o0000ooP7n?oh1oP05?oh1oP00ol0003oo@;mood2o@0;ood2o@;o00001?om0_d5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000oo`3o00=oo`3o003o`000?ol
0ocoo0?l00Soo0?l00?o0000oo/4nook1?/02ook1?/2o`0000_okA;]00?o0000oo8=l_ob3O801?ob
3O800ol0003oka3_onl@k`0<onl@k`03o`000?oQ7^7ohAkQ00kohAkQ00?o0000on<LhooS7><07_oS
7><00ol0003oka3_onl@k`0@onl@k`?o00002Ooj1OX00ol0003on0OhooP7n00FooP7n0Oo00001Oom
0_d00ol0003oo@;mood2o@09ood2o@Co00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?ol0o`00ol0003oo0?loo`3o007oo`3o003o`000?ok
1?_on`Ck00[on`Ck00?o0000ondBkOo]4^d03?o]4^d00ol0003olPgboo8=lP02oo8=lP03o`000?o_
4>ooka3_00goka3_00?o0000on4NhOoQ7^403_oQ7^400ol0003ohacSon<Lh`0Non<Lh`03o`000?o_
4>ooka3_01?oka3_0ol00005ooX5nP03o`000?oh1oSon0Oh01Oon0Oh00?o0000ooX5n_oj1OX01?oj
1OX5o`00013oo@;m0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?ol0o`00ol0003on`Ckoo/4n`09oo/4n`03o`000?o]4^gokA;]00kokA;]00Go0000
oo8=l_ob3O;olPgbo`00000?onl@k`03o`000?oQ7^7ohAkQ00gohAkQ00?o0000on<LhooS7><07ooS
7><00ol0003oka3_onl@k`0Fonl@k`?o000000?onPGjo`000?oh1oP06?oh1oP00ol0003onPGjooX5
nP09ooX5nP03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ok1?_on`Ck00oon`Ck0_l00006oo`3o003o`000?ok1?_o
n`Ck00Oon`Ck0_l0000BondBk@03o`000?ob3O;o0000013oka3_00?o0000on4NhOoQ7^402ooQ7^43
o`00023ohacS00?o0000onl@koo_4>l06_o_4>l00ol0003on0OhooP7n00HooP7n003o`000?oj1O[o
nPGj00WonPGj00?o0000ood2oOom0_d03oom0_d00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck017on`Ck00?o0000oo`3
o?ol0o`00_ol0o`00ol0003on`Ckoo/4n`07oo/4n`03o`000?o]4^gokA;]01?okA;]00?o0000onl@
koo_4>l03oo_4>l00ol0003ohAkQon4Nh@07on4Nh@Co00000_o9=/T00ol0003ohacSon<Lh`0Non<L
h`03o`000?o_4>ooka3_01[oka3_00?o0000ooP7n?oh1oP05ooh1oP00ol0003onPGjooX5nP0:ooX5
nP03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003on`Ckoo/4n`0Boo/4n`Ko00001_ok1?/2o`0001Ko
kA;]00?o0000onl@koo_4>l03oo_4>l00ol0003ohAkQon4Nh@03on4Nh@Co00001oo9=/T00ol0003o
hacSon<Lh`0Lon<Lh`03o`000?o_4>ooka3_01coka3_00?o0000ooP7n?oh1oP05Ooh1oP00ol0003o
nPGjooX5nP0;ooX5nP03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ok1?_on`Ck01;on`Ck00?o0000ooT6nOoi1_T0
0ooi1_T2o`0000?on`Ck00?o0000ondBkOo]4^d05oo]4^d00ol0003oka3_onl@k`0>onl@k`03o`00
0?oQ7^7o000000?o00003?o9=/T00ol0003ohacSon<Lh`0Kon<Lh`03o`000?o_4>ooka3_01coka3_
00?o0000ooP7n?oh1oP05Ooh1oP00ol0003onPGjooX5nP0<ooX5nP03o`000?om0_goo@;m00goo@;m
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?oi1_Won@Ki00Kon@Ki00?o0000oo/4nol000006_o]
4^d5o`0000_oka3_0ol0000AolTfb@03o`000?oS7>?ohacS01[ohacS00?o0000onl@koo_4>l07Oo_
4>l00ol0003on0OhooP7n00CooP7n003o`000?oj1O[onPGj00gonPGj00?o0000ood2oOom0_d03Oom
0_d00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo/4nook1?/03ook1?/00ol0003on@KiooT6n@08ooT6n@03o`000?o]4^gokA;]01WokA;]00?o0000
ol`cc?o<<l`00_o<<l`7o`0000?oka3_00?o0000olTfbOo9=/T04oo9=/T3o`0001OohacS0_l0000P
onl@k`03o`000?oh1oSon0Oh01?on0Oh00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oo@;mood2o@0=
ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003on`Ckoo/4n`0>oo/4n`03o`000?oi1_Won@Ki00Won@Ki00?o0000ondBkOo]4^d06?o]4^d00ol0
003oc3?<ol`cc00:ol`cc0?o00005_o9=/T00ol0003o/Djaok5>/@05o`00013ohacS0_l000000oo=
</go0000onl@k`0Oonl@k`03o`000?oh1oSon0Oh01;on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0
003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?oi1_Won@Ki00[on@Ki00?o0000ondBkOo]4^d05_o]4^d00ol0003oc3?<ol`cc00=ol`cc003
o`000?o9=/WobCK901?obCK900?o0000ok5>/OnaC[401_naC[44o`0000_ohacS00?o0000oldbcOo=
</d00_o=</d00ol0003oka3_onl@k`0Nonl@k`03o`000?oh1oSon0Oh013on0Oh00?o0000ooX5n_oj
1OX03ooj1OX00ol0003oo@;mood2o@0<ood2o@;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ok1?_on`Ck00gon`Ck
00?o0000ooT6nOoi1_T03?oi1_T00ol0003okA;]ondBk@0DondBk@03o`000?o<<lcoc3?<00ooc3?<
00?o0000olTfbOo9=/T04_o9=/T00ol0003o/Djaok5>/@0:ok5>/@Go00001?oS7><2o`0000GocC;=
00?o0000onl@koo_4>l07_o_4>l00ol0003on0OhooP7n00@ooP7n003o`000?oj1O[onPGj00oonPGj
00?o0000ood2oOom0_d02oom0_d00ol0003oo@;mo`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooT6n@03o`000?o]
4^gokA;]01CokA;]00?o0000ol`cc?o<<l`03oo<<l`00ol0003obCK9olTfb@0BolTfb@03o`000?na
C[7o/Dja00oo/Dja1?l00008oldbc@03o`000?o_4>ooka3_01koka3_00?o0000ooP7n?oh1oP03_oh
1oP00ol0003onPGjooX5nP0@ooX5nP03o`000?om0_goo@;m00Woo@;m0_l00003ood2o@03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003onPGjooX5nP0<ooX5nP03o`000?oi1_Won@Ki00kon@Ki00?o0000
ondBkOo]4^d04_o]4^d00ol0003oc3?<ol`cc00@ol`cc003o`000?o9=/WobCK9017obCK900?o0000
ok5>/OnaC[404OnaC[400ol0003o/Tfbo`000009oldbc@03o`000?o_4>ooka3_01goka3_00?o0000
ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5nP0@ooX5nP03o`000?om0_goo@;m00Ooo@;m0_l00005
ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003onPGjooX5nP0<ooX5nP03o`000?oi1_Won@Ki
00oon@Ki00?o0000ondBkOo]4^d03_o]4^d3o`0001Coc3?<00?o0000olTfbOo9=/T04?o9=/T00ol0
003o/Djaok5>/@0@ok5>/@04o`000?nbCK;o/Tfbo`0000WocC;=00?o0000onl@koo_4>l07_o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oj1O[onPGj017onPGj00?o0000ood2oOom0_d01_om0_d0
0ol0003oo@;mood2o@06ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP0;ooX5
nP03o`000?oi1_Won@Ki013on@Ki00?o0000ondBkOo]4^d02_o]4^d4o`0000;ocC;=00?o0000ol`c
c?o<<l`04_o<<l`00ol0003obCK9olTfb@0@olTfb@03o`000?naC[7o/Dja00oo/Dja00Go0000ok9=
/_nbCK;o/Tfbo`00000:oldbc@03o`000?o_4>ooka3_01goka3_00?o0000ooP7n?oh1oP02ooh1oP0
0ol0003onPGjooX5nP0CooX5nP03o`000?om0_goo@;m00?oo@;m0_l00009ood2o@03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oi1_Won@Ki017on@Ki00?o0000ondB
kOo]4^d01Oo]4^d4o`0000OocC;=00?o0000ol`cc?o<<l`04Oo<<l`00ol0003obCK9olTfb@0?olTf
b@03o`000?naC[7o/Dja013o/Dja00Go0000ok9=/_nbCK;o/Tfbo`00000:oldbc@03o`000?o_4>oo
ka3_01goka3_00?o0000ooP7n?oh1oP02ooh1oP00ol0003onPGjooX5nP0CooX5nP04o`000?om0_go
o@;mood2o@;o00003?om0_d00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000ooX5n_oj1OX03?oj1OX00ol0003on@KiooT6n@0BooT6n@03o`000?o]4^go
kA;]00Co00002oo=</d00ol0003oc3?<ol`cc00Bol`cc003o`000?o9=/WobCK900kobCK900?o0000
ok5>/OnaC[403onaC[400ol0003o/Tfbok9=/P02ok9=/P03o`000?o=</gocC;=00WocC;=00?o0000
onl@koo_4>l07?o_4>l3o`0000[on0Oh00?o0000ooX5n_oj1OX05?oj1OX01?l0003oo@;mood2oOl0
000>ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oi1_Wo
n@Ki01;on@Ki00Co0000on/Djol0003o00003oo=</d00ol0003oc3?<ol`cc00Aol`cc003o`000?nS
G:?o000000oobCK900?o0000ok5>/OnaC[403_naC[400ol0003o/Tfbok9=/P03ok9=/P03o`000?o=
</gocC;=00WocC;=00?o0000onl@koo_4>l06Oo_4>l3o`0000?ok1?/00?o0000ooP7n?oh1oP01ooh
1oP00ol0003onPGjooX5nP0CooX5nPGo00003oom0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
ooX5n_oj1OX02ooj1OX00ol0003on@KiooT6n@0AooT6n@04o`000?o[5>_ojaC[o`00017ocC;=00?o
0000ol`cc?o<<l`03oo<<l`01Ol0003oXebSoj=LXonSG:?o000000[obCK91?l0000Aok5>/@03o`00
0?nbCK;o/Tfb00?o/Tfb00?o0000oldbcOo=</d02_o=</d00ol0003oka3_onl@k`0Fonl@k`;o0000
1oo/4n`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj01?onPGj00?o0000ood2oOom0_d0
0oom0_d00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000conPGj00?o
0000ooT6nOoi1_T04?oi1_T00ol0003ojaC[on/Dj`02on/Dj`03o`000?o=</gocC;=00kocC;=00?o
0000ol`cc?o<<l`03_o<<l`00ol0003oXebSoj=LX`03oj=LX`04o`000?o9=/WobCK9olTfb@Ko0000
0onOGil00ol0003o/Djaok5>/@0>ok5>/@03o`000?nbCK;o/Tfb00Co/Tfb00?o0000oldbcOo=</d0
2_o=</d00ol0003oka3_onl@k`0Conl@k`?o00002_o/4n`00ol0003on0OhooP7n003ooP7n003o`00
0?oj1O[onPGj01?onPGj00?o0000ood2oOom0_d01Oom0_d2o`0000goo@;m00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?oo@;m00?o0000ooX5n_oj1OX02?oj1OX00ol0003on@KiooT6n@0@ooT6n@03o`000?o[
5>_ojaC[00?ojaC[00?o0000oldbcOo=</d03_o=</d00ol0003oc3?<ol`cc00=ol`cc003o`000?nS
G:?oXebS00GoXebS0ol0000:oimOW`03o`000?naC[7o/Dja00co/Dja00?o0000ok9=/_nbCK801Onb
CK800ol0003ocC;=oldbc@0;oldbc@03o`000?o_4>ooka3_013oka3_0_l0000>on`Ck003o`000?oh
1oSon0Oh00;on0Oh00?o0000ooX5n_oj1OX04_oj1OX00ol0003oo@;mood2o@08ood2o@03o`000?om
0_goo@;m00_oo@;m00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000Ooo@;m00?o0000ooX5n_oj1OX01ooj1OX00ol0003on@KiooT6n@0?
ooT6n@03o`000?o[5>_ojaC[00CojaC[00?o0000oldbcOo=</d03oo=</d00ol0003oc3?<ol`cc00;
ol`cc003o`000?nSG:?oXebS00KoXebS00?o0000oimOWonOGil02onOGil00ol0003o/Djaok5>/@0;
ok5>/@03o`000?nbCK;o/Tfb00Go/Tfb00?o0000oldbcOo=</d03?o=</d00ol0003oka3_onl@k`0<
onl@k`?o00004Oo/4n`5o`0001;onPGj0_l0000<ood2o@03o`000?om0_goo@;m00[oo@;m00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo@;mood2o@09ood2o@;o00001ooj1OX00ol0003on@KiooT6n@0>ooT6n@03o`000?o[5>_ojaC[
00KojaC[00?o0000oldbcOo=</d03_o=</d00ol0003oc3?<ol`cc00:ol`cc003o`000?nSG:?oXebS
00OoXebS00?o0000oimOWonOGil02onOGil00ol0003o/Djaok5>/@0:ok5>/@03o`000?nbCK;o/Tfb
00Ko/Tfb00?o0000oldbcOo=</d03?o=</d00ol0003oka3_onl@k`0:onl@k`;o00005?o/4n`00ol0
003onPGjooX5nP02ooX5nP;o00003ooj1OX00ol0003oo@;mood2o@0=ood2o@Go00002?om0_d01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@0<ood2
o@03o`000?oj1O[onPGj00?onPGj00?o0000ooT6nOoi1_T03_oi1_T00ol0003ojaC[on/Dj`07on/D
j`03o`000?o=</gocC;=00kocC;=00?o0000ol`cc?o<<l`02Oo<<l`00ol0003oXebSoj=LX`08oj=L
X`03o`000?nOGiooWenO00coWenO00?o0000ok5>/OnaC[402?naC[400ol0003o/Tfbok9=/P07ok9=
/P03o`000?o=</gocC;=00gocC;=1Ol00004onl@k`?o00005Oo/4n`00ol0003onPGjooX5nP05ooX5
nP03o`000?oj1O[onPGj00_onPGj00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000Coo@;mo`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d03_om0_d2o`0000?onPGj00?o0000ooT6nOoi1_T03Ooi1_T00ol0003ojaC[on/Dj`08on/D
j`03o`000?o=</gocC;=00oocC;=00?o0000ol`cc?o<<l`01oo<<l`00ol0003oXebSoj=LX`09oj=L
X`03o`000?nOGiooWenO00coWenO0ol00008ok5>/@03o`000?nbCK;o/Tfb00Oo/Tfb00?o0000oldb
cOo=</d03Oo=</d00ol0003oebSGomLXe`02omLXe`Co00006?o/4n`00ol0003onPGjooX5nP06ooX5
nP;o00002Ooj1OX2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ood2oOom0_d04Oom0_d01?l0003onPGjooX5n_l0000>ooT6n@03o`000?o[5>_ojaC[
00[ojaC[00?o0000oldbcOo=</d03_o=</d00ol0003oc3?<ol`cc006ol`cc003o`000?nSG:?oXebS
00[oXebS00?o0000oimOWonOGil02_nOGil2o`0000?oUVVF00?o0000ok5>/OnaC[401?naC[400ol0
003o/Tfbok9=/P08ok9=/P03o`000?o=</gocC;=00cocC;=00?o0000omLXeooG:=L01_oG:=L00ol0
003ok1?/on`Ck00Eon`Ck003o`000?oj1O[onPGj00WonPGj0_l00006ooX5nP03o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ood2oOom0_d04oom0_d2o`0000kon@Ki00?o0000on/Djoo[5>/02oo[5>/00ol0003o
cC;=oldbc@0>oldbc@03o`000?o<<lcoc3?<00Goc3?<00?o0000oj=LXonSG:<02onSG:<00ol0003o
WenOoimOW`08oimOW`;o00001_nFJIH00ol0003o/Djaok5>/@02ok5>/@03o`000?nbCK;o/Tfb00Wo
/Tfb00?o0000oldbcOo=</d03?o=</d00ol0003oebSGomLXe`07omLXe`03o`000?o/4ncok1?/01Co
k1?/00?o0000ooX5n_oj1OX02ooj1OX00ol0003onPGjooX5nP02ooX5nP03o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ood2oOom0_d05Oom0_d00ol0003on@KiooT6n@0;ooT6n@03o`00
0?o[5>_ojaC[00gojaC[00?o0000oldbcOo=</d03_o=</d00ol0003oc3?<ol`cc003ol`cc003o`00
0?nSG:?oXebS00coXebS00?o0000oimOWonOGil01_nOGil2o`0000WoUVVF00Go0000ok5>/OnaC[7o
/Djao`00000;ok9=/P03o`000?o=</gocC;=00cocC;=00?o0000omLXeooG:=L01ooG:=L00ol0003o
k1?/on`Ck00Con`Ck003o`000?oj1O[onPGj00gonPGj0_l000000ooj1O[o0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?om0_d00ol0003on@KiooT6n@0:ooT6n@03o`000?o[5>_ojaC[00ko
jaC[00?o0000oldbcOo=</d03_o=</d00ol0003oc3?<ol`cc002ol`cc003o`000?nSG:?oXebS00go
XebS00?o0000oimOWonOGil01?nOGil2o`0000coUVVF00?o0000ok5>/Ol000003?nbCK800ol0003o
cC;=oldbc@0;oldbc@03o`000?oG:=OoebSG00WoebSG00?o0000on`Ck?o/4n`04Oo/4n`00ol0003o
nPGjooX5nP0@ooX5nP03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001Woo@;m00?o0000ooT6nOoi1_T0
2?oi1_T00ol0003ojaC[on/Dj`0?on/Dj`03o`000?o=</gocC;=00kocC;=00Go0000ol`cc?o<<lco
c3?<o`00000@oj=LX`03o`000?nOGiooWenO00;oWenO0_l0000?oiIYUP03o`000?nbCK;o/Tfb00_o
/Tfb00?o0000oldbcOo=</d02oo=</d00ol0003oebSGomLXe`09omLXe`03o`000?o/4ncok1?/017o
k1?/00?o0000ooX5n_oj1OX04?oj1OX2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ood2oOom0_d05_om0_d3o`0000Oon@Ki00?o0000on/Djoo[5>/04Oo[5>/00ol0003ocC;=
oldbc@0>oldbc@Co00004?nSG:<00ol0003oWenOoimOW`02o`00017oUVVF00?o0000ok9=/_nbCK80
2onbCK800ol0003ocC;=oldbc@0:oldbc@03o`000?oG:=OoebSG00_oebSG00?o0000on`Ck?o/4n`0
3oo/4n`00ol0003onPGjooX5nP0AooX5nP03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003oo@;mood2o@0Cood2o@;o00000ooj1OX00ol0003on@KiooT6n@03ooT6n@03o`000?o[
5>_ojaC[01;ojaC[00?o0000oldbcOo=</d03Oo=</d00ol0003oYUVVojIIYP02ojIIYP;o00003_nS
G:<3o`0001?oUVVF00?o0000ok9=/_nbCK802onbCK800ol0003ocC;=oldbc@0:oldbc@03o`000?oG
:=OoebSG00_oebSG00?o0000on`Ck?o/4n`03oo/4n`00ol0003onPGjooX5nP0AooX5nP03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0A
ood2o@03o`000?oj1O[onPGj00ConPGj00Go0000ooT6nOoi1_Won@Kio`00000Eon/Dj`03o`000?o=
</gocC;=00cocC;=00?o0000ojIIY_nVFJH01OnVFJH2o`0000coXebS00?o0000oiIYU_nFJIH05?nF
JIH00ol0003o/Tfbok9=/P0:ok9=/P03o`000?o=</gocC;=00[ocC;=00?o0000omLXeooG:=L03?oG
:=L00ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj01;onPGj00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d03_om0_d2o`0000SonPGj00?o0000
ooT6nOl000005oo[5>/00ol0003ocC;=oldbc@0:oldbc@03o`000?nVFJKoYUVV00SoYUVV00?o0000
oj=LXonSG:<02?nSG:<3o`0001GoUVVF0_l0000;ok9=/P03o`000?o=</gocC;=00WocC;=00?o0000
omLXeooG:=L03_oG:=L00ol0003ok1?/on`Ck00<on`Ck003o`000?oj1O[onPGj01;onPGj00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?om0_d2o`00
00_onPGj00?o0000on/Djoo[5>/05_o[5>/00ol0003ocC;=oldbc@09oldbc@03o`000?nVFJKoYUVV
00[oYUVV0_l00005oj=LX`?o00000on;M8/00ol0003oUVVFoiIYUP0AoiIYUP03o`000?nFJIKoUVVF
00;o00002OnbCK800ol0003ocC;=oldbc@09oldbc@03o`000?oG:=OoebSG00koebSG00?o0000on`C
k?o/4n`02oo/4n`00ol0003onPGjooX5nP0CooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Ooo@;m0_l0000=ooX5nP03o`000?o[5>_ojaC[01Ko
jaC[00?o0000oldbcOo=</d00oo=</d6o`0000ooYUVV0_l000000onSG:?o0000o`000007oh]dR`;o
00004?nFJIH00ol0003oUVVFoiIYUP03oiIYUP?o00001_nbCK800ol0003ocC;=oldbc@09oldbc@03
o`000?oG:=OoebSG00ooebSG00?o0000on`Ck?o/4n`02_o/4n`00ol0003onPGjooX5nP0CooX5nP03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@04ood2o@;o00004?oj1OX00ol0003ojaC[
on/Dj`0Fon/Dj`Go00001Oo4>l@00ol0003oYUVVojIIYP0?ojIIYP03o`000?n;M8_oRgB;00WoRgB;
00?o0000oiIYU_nFJIH03?nFJIH00ol0003oUVVFoiIYUP07oiIYUP;o00000_nbCK8>o`0001;oebSG
00?o0000on`Ck?o/4n`02Oo/4n`00ol0003onPGjooX5nP0DooX5nP03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo@;mood2o@02ood2o@03o`000?oj1O[onPGj013onPGj00?o0000on/Djoo[5>/05Oo[
5>/00ol0003oa3_4ol@ka009ol@ka003o`000?nVFJKoYUVV00koYUVV00?o0000oh]dRon;M8/02_n;
M8/2o`0000_oUVVF00?o0000oiIYU_nFJIH02_nFJIH2o`0000go^DJi00?o0000omLXeooG:=L04OoG
:=L00ol0003ok1?/on`Ck007on`Ck003o`000?oj1O[onPGj01GonPGj0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ood2oOl0003o00005?oj1OX00ol0003ojaC[on/Dj`0Con/Dj`03o`000?o4>lCoa3_400[oa3_400?o
0000ojIIY_nVFJH03_nVFJH00ol0003oRgB;oh]dR`0<oh]dR`03o`000?nFJIKoUVVF00OoUVVF00?o
0000oiIYU_nFJIH02onFJIH00ol0003o^DJiokU6^@0=okU6^@03o`000?oG:=OoebSG013oebSG00?o
0000on`Ck?o/4n`01oo/4n`00ol0003onPGjooX5nP0EooX5nP04o`000?om0_go0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003onPGjooX5nP0DooX5nP03o`000?o[5>_ojaC[01;ojaC[00?o0000ol@ka?o4>l@02oo4
>l@00ol0003oYUVVojIIYP0>ojIIYP03o`000?n;M8_oRgB;00goRgB;00?o0000oiIYU_nFJIH01?nF
JIH2o`0000koUVVF00?o0000okU6^OniA[T03OniA[T00ol0003oebSGomLXe`0@omLXe`Co00001Oo/
4n`00ol0003onPGjooX5nP0FooX5nP04o`000?om0_goo@;mood2o@;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oj
1O[onPGj01GonPGj5?l0000?ol@ka003o`000?nVFJKoYUVV00coYUVV00?o0000ohQgR?l000003on;
M8/2o`0000?oUVVF00Co0000ohMhQon7N8Oo00003OnFJIH00ol0003o^DJiokU6^@0>okU6^@03o`00
0?oG:=OoebSG00coebSG0ol00004on<Lh`?o00000_o/4n`00ol0003onPGjooX5nP0FooX5nP03o`00
0?om0_goo@;m00?oo@;m0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oiQWVonHI
iP0@onHIiP03o`000?o4>lCoa3_400goa3_400?o0000ojIIY_nVFJH02onVFJH01?l0003oR7N8ohQg
R?l0000Aoh]dR`03o`000?nFJIKo000000CoQgR700?o0000oiIYU_nFJIH02_nFJIH00ol0003o^DJi
okU6^@0>okU6^@03o`000?oG:=OoebSG00WoebSG0ol0000:on<Lh`;o00006?oj1OX00ol0003oo@;m
ood2o@06ood2o@;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003onPGjooX5nP0EooX5nP03o`000?oV6NKoiQWV013oiQWV00?o0000ol@ka?o4>l@03Oo4
>l@00ol0003oYUVVojIIYP0:ojIIYP03o`000?n8MhSoR7N800;oR7N800?o0000oh]dRon;M8/03on;
M8/00ol0003oQgR7ohMhQ`04ohMhQ`03o`000?nFJIKoUVVF00WoUVVF00?o0000okU6^OniA[T03_ni
A[T00ol0003oebSGomLXe`06omLXe`?o00003_oS7><00ol0003onPGjooX5nP0FooX5nP03o`000?om
0_goo@;m00Soo@;m0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?oj1O[onPGj01GonPGj00?o0000
onHIi_oV6NH04_oV6NH00ol0003oa3_4ol@ka00=ol@ka003o`000?nVFJKoYUVV00WoYUVV00?o0000
ohQgR?n8MhP00_n8MhP00ol0003oRgB;oh]dR`0?oh]dR`03o`000?n7N8OoQgR700GoQgR700?o0000
oiIYU_nFJIH02?nFJIH00ol0003o^DJiokU6^@0?okU6^@03o`000?oG:=OoebSG00;oebSG0ol0000B
on<Lh`03o`000?oj1O[onPGj01GonPGj00?o0000ood2oOom0_d02_om0_d2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003onPGjooX5nP0CooX5nP?o00005?oV6NH00ol0003oa3_4ol@ka00=ol@ka003o`000?nVFJKoYUVV
00SoYUVV00?o0000ohQgR?n8MhP01?n8MhP00ol0003oRgB;oh]dR`0>oh]dR`03o`000?n7N8OoQgR7
00KoQgR700?o0000oiIYU_nFJIH01onFJIH00ol0003o^DJiokU6^@0?okU6^@03o`000?oG:=Oo0000
00;o00005OoS7><00ol0003onPGjooX5nP0EooX5nP03o`000?om0_goo@;m00coo@;m0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oj1O[onPGj00oonPGj1?l00002oo@;m003o`000?oV6NKoiQWV01;o
iQWV00?o0000ol@ka?o4>l@03Oo4>l@00ol0003oYUVVojIIYP07ojIIYP03o`000?n8MhSoR7N800Go
R7N800?o0000oh]dRon;M8/03On;M8/00ol0003oQgR7ohMhQ`08ohMhQ`03o`000?nFJIKoUVVF00Ko
UVVF00?o0000okU6^OniA[T04?niA[T00ol0003ohacSon<Lh`0Fon<Lh`03o`000?oj1O[onPGj01Go
nPGj00?o0000ood2oOom0_d03_om0_d2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooX5n_oj1OX02ooj1OX4o`0000Kom0_d
00?o0000onHIi_oV6NH04ooV6NH00ol0003oa3_4ol@ka00=ol@ka003o`000?nVFJKoYUVV00GoYUVV
00?o0000ohQgR?n8MhP01on8MhP00ol0003oRgB;oh]dR`0<oh]dR`03o`000?n7N8OoQgR700WoQgR7
00?o0000oiIYU_nFJIH01OnFJIH00ol0003o^DJiokU6^@0@okU6^@03o`000?oS7>?ohacS01OohacS
00?o0000ooX5n_oj1OX05?oj1OX00ol0003oo@;mood2o@0@ood2o@;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ooX5n_oj1OX01ooj
1OX4o`0000[om0_d00?o0000onHIi_oV6NH04ooV6NH00ol0003oa3_4ol@ka00=ol@ka003o`000?nV
FJKoYUVV00CoYUVV00?o0000ohQgR?n8MhP02?n8MhP00ol0003oRgB;oh]dR`0<oh]dR`03o`000?n7
N8OoQgR700[oQgR700?o0000oiIYU_nFJIH01?nFJIH00ol0003o^DJiokU6^@0@okU6^@03o`000?oS
7>?ohacS01OohacS00?o0000ooX5n_oj1OX05?oj1OX00ol0003oo@;mood2o@0Bood2o@;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003onPGjooX5nP04ooX5nPCo00003_od2o@00ol0003oiQWVonHIiP0ConHIiP03o`000?o4>lCo
a3_400goa3_400?o0000ojIIY_nVFJH01?nVFJH00ol0003oR7N8ohQgR009ohQgR003o`000?n;M8_o
RgB;00_oRgB;00?o0000ohMhQon7N8L02on7N8L00ol0003oUVVFoiIYUP03oiIYUP03o`000?niA[Wo
^DJi013o^DJi00?o0000on<LhooS7><05ooS7><00ol0003onPGjooX5nP0CooX5nP03o`000?om0_go
o@;m01Goo@;m00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003onPGjooX5nP04o`0001;om0_d00?o0000onHIi_oV6NH04ooV6NH00ol0
003oa3_4ol@ka00>ol@ka003o`000?nVFJKoYUVV00;oYUVV00?o0000ohQgR?n8MhP02_n8MhP00ol0
003oRgB;oh]dR`0:oh]dR`03o`000?n7N8OoQgR700goQgR700?o0000oiIYU_nFJIH00_nFJIH00ol0
003o^DJiokU6^@0@okU6^@03o`000?oS7>?ohacS01SohacS00?o0000ooX5n_oj1OX04_oj1OX00ol0
003oo@;mood2o@0Eood2o@03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000Goo@;m003
o`000?oV6NKoiQWV01?oiQWV00?o0000ol@ka?o4>l@03?o4>l@4o`000003ojIIY_l0003oR7N800go
R7N800?o0000oh]dRon;M8/02On;M8/00ol0003oQgR7ohMhQ`0>ohMhQ`05o`000?nFJIKoUVVFoiIY
U_l000004_niA[T00ol0003ohacSon<Lh`0Hon<Lh`?o00004_oj1OX00ol0003oo@;mood2o@0Dood2
o@03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003om0_doo@;m00Foo@;m003o`000?oV6NKoiQWV
01?oiQWV00?o0000ol@ka?o4>l@02oo4>l@00ol0003oV6NHoiQWV002oiQWV0;o00003_n8MhP00ol0
003oRgB;oh]dR`09oh]dR`03o`000?n7N8OoQgR700ooQgR700Co0000oiIYU_nFJIKo00004_niA[T0
0ol0003ohacSon<Lh`0Hon<Lh`03o`000?o^4NkokQ7^00?o00003ooj1OX5o`0001;oo@;m00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?od2oCom0_d01Gom0_d00?o0000onHIi_oV6NH04ooV6NH00ol0003oa3_4ol@ka00:
ol@ka003o`000?nHIiSoV6NH00GoV6NH00?o0000ohQgR?n8MhP03?n8MhP00ol0003oRgB;oh]dR`08
oh]dR`03o`000?n7N8OoQgR700ooQgR71Ol0000AokU6^@03o`000?oS7>?ohacS01OohacS00?o0000
onhAk_o^4Nh01?o^4Nh3o`0000conPGj00?o0000ood2oOom0_d00_om0_d7o`0000[oo@;m00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003om0_doo@;m00Doo@;m003o`000?oV6NKoiQWV01?oiQWV00?o0000ol@ka?o4>l@02?o4>l@2o`00
00WoV6NH00?o0000ohQgR?n8MhP02on8MhP00ol0003oRgB;oh]dR`07oh]dR`03o`000?n7N8OoQgR7
00goQgR70ol00005oiIYUP03o`000?niA[Wo^DJi00ko^DJi00?o0000on<LhooS7><05_oS7><00ol0
003okQ7^onhAkP08onhAkP?o00002?oj1OX00ol0003oo@;mood2o@0:ood2o@Oo00000oom0_d00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?od2oCom0_d01?om0_d0_l0000EonHIiP03o`000?o4>lCoa3_400Koa3_400?o0000oiQWV?nH
IiP02_nHIiP00ol0003oR7N8ohQgR00:ohQgR1[o00002OnFJIH00ol0003o^DJiokU6^@0<okU6^@?o
00005_oS7><00ol0003okQ7^onhAkP0<onhAkP?o00001?oj1OX00ol0003oo@;mood2o@0Bood2o@?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003om0_d
oo@;m00@oo@;m0;o00000_oT6n@3o`0001;oiQWV00?o0000ol@ka?o4>l@01?o4>l@2o`0000koV6NH
00?o0000ohQgR?n8MhP01on8MhP2o`0000[oPgb300?o0000oh9mP_n2OH803?n2OH800ol0003oUVVF
oiIYUP08oiIYUP;o00002_niA[T2o`0000?o`3o00_l0000Con<Lh`03o`000?o^4NkokQ7^013okQ7^
1?l0000Good2o@03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000oo@;m?od2o@03_od2o@00ol0003omPWfo`000005on@Ki0;o00004?oV
6NH00ol0003oa3_4ol@ka003ol@ka003o`000?nHIiSoV6NH00ooV6NH00?o0000ohQgR?n8MhP01?n8
MhP2o`0000coPgb300?o0000oh9mP_n2OH803?n2OH800ol0003oUVVFoiIYUP0:oiIYUP03o`000?ni
A[Wo^DJi00Go^DJi0_l00007ol0o`003o`000?oS7>?ohacS00oohacS00?o0000onhAk_o^4Nh04Oo^
4Nh01?l0003on@KiooT6nOl0000Good2o@03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@02ood2o@2o`0000;omPWf00?o
0000on@Ki?oT6n@01OoT6n@2o`0000ooiQWV00Go0000ol@ka?o4>lCoa3_4o`00000CoiQWV003o`00
0?n8MhSoR7N800;oR7N800?o0000oh=lPon3O8<03On3O8<00ol0003oPWf2oh9mPP0;oh9mPP03o`00
0?nFJIKoUVVF00_oUVVF00?o0000okU6^OniA[T00_niA[T2o`0000[o`3o00_l0000>on<Lh`03o`00
0?o^4NkokQ7^017okQ7^00Go0000ooT6nOoi1_Won@Kio`00000Hood2o@03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003om0_doo@;m009oo@;m003o`00
0?of2OKomPWf00?omPWf00?o0000on@Ki?oT6n@01_oT6n@3o`0000_oiQWV1Ol0000EoiQWV004o`00
0?n8MhSo0000o`00013oPgb300?o0000oh9mP_n2OH802on2OH800ol0003oUVVFoiIYUP0<oiIYUP04
o`000?niA[Wo0000o`0000ko`3o00_l0000;on<Lh`03o`000?o^4NkokQ7^017okQ7^00?o0000ooT6
nOoi1_T00ooi1_T00ol0003oo@;mood2o@0Eood2o@;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Kom0_d0_l00006ooH9mP03
o`000?oT6nCoi1_T00Woi1_T0_l00008onHIiP03o`000?nm@[go_D:m00;o_D:m00?o0000oiQWV?nH
IiP05?nHIiP00ol0003oPgb3oh=lP`0@oh=lP`03o`000?n2OH;oPWf200_oPWf200?o0000oiIYU_nF
JIH03OnFJIH00ol0003o`3o0ol0o`00@ol0o`003o`000?oS7>?ohacS00OohacS00?o0000onhAk_o^
4Nh04Oo^4Nh00ol0003on@KiooT6n@04ooT6n@03o`000?om0_goo@;m01Goo@;m00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000oo@;m?od2o@01?od2o@00ol0003omPWfooH9mP06ooH9mP03o`000?oT6nCoi1_T00_oi1_T
0_l00005onHIiP03o`000?nm@[go_D:m00Co_D:m00?o0000oiQWV?nHIiP04onHIiP00ol0003oPgb3
oh=lP`0@oh=lP`03o`000?n2OH;oPWf200_oPWf200?o0000oiIYU_nFJIH03OnFJIH00ol0003o`3o0
ol0o`00Aol0o`0;o00000ooS7><4o`0001?okQ7^00?o0000ooT6nOoi1_T01Ooi1_T00ol0003oo@;m
ood2o@0Dood2o@05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000oo@;m?od2oCom0_d0_l00009ooH9mP03
o`000?oT6nCoi1_T00goi1_T0ol000000ooV6NKo0000oke2_@07oke2_@03o`000?nHIiSoV6NH01;o
V6NH00?o0000oh=lPon3O8<04?n3O8<00ol0003oPWf2oh9mPP0;oh9mPP03o`000?nFJIKoUVVF00go
UVVF00?o0000ol0o`?o0?l004oo0?l03o`0000?ojAKY00?o0000onhAk_o^4Nh04?o^4Nh00ol0003o
n@KiooT6n@07ooT6n@03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003om0_do`00000;ooH9mP03o`000?oT6nCoi1_T013oi1_T00?o0000oke2_Onm@[d0
2?nm@[d00ol0003oV6NHoiQWV00AoiQWV003o`000?n3O8?oPgb3017oPgb300?o0000oh9mP_n2OH80
2_n2OH800ol0003oUVVFoiIYUP0<oiIYUP03o`000?nPGj3o000001Co`3o000?o0000onTFjOoY5^T0
1?oY5^T00ol0003okQ7^onhAkP0>onhAkP03o`000?oi1_Won@Ki00Son@Ki00?o0000ood2oOom0_d0
4Oom0_d00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?of2OKomPWf00_omPWf00?o0000on@Ki?oT6n@03ooT
6n@00ol0003o_D:moke2_@09oke2_@03o`000?nHIiSoV6NH013oV6NH00?o0000oh=lPon3O8<04On3
O8<00ol0003oPWf2oh9mPP0:oh9mPP03o`000?nFJIKoUVVF00_oUVVF00Co0000oj1OX?nPGj3o0000
5?o0?l000ol0003ojAKYonTFj@05onTFj@03o`000?o^4NkokQ7^00cokQ7^00?o0000ooT6nOoi1_T0
2Ooi1_T00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oof2OH00ol0003oi1_Ton@K
i00?on@Ki003o`000?nm@[go_D:m00[o_D:m00?o0000oiQWV?nHIiP03_nHIiP00ol0003oQ7^4o`00
000Boh=lP`03o`000?n2OH;oPWf200[oPWf200?o0000oiIYU_nFJIH02_nFJIH00ol0003oX5nPoj1O
X002oj1OX003o`000?o0?l3o`3o0013o`3o000?o0000onTFjOoY5^T01ooY5^T00ol0003okQ7^onhA
kP0:onhAkP03o`000?oi1_Won@Ki00[on@Ki00?o0000ood2oOom0_d03oom0_d00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooH9mP03o`000?oT6nCoi1_T00ooi1_T00?o0000oke2_Onm@[d0
2onm@[d00ol0003oV6NHoiQWV00<oiQWV005o`000?n4NhCoQ7^4ohAkQ?l000004On3O8<00ol0003o
PWf2oh9mPP0:oh9mPP03o`000?nFJIKoUVVF00WoUVVF00?o0000oj1OX?nPGj000onPGj000ol0003o
`3o0ol0o`00@ol0o`003o`000?oY5^WojAKY00SojAKY00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o
n@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00goo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?of2OKomPWf00WomPWf00?o0000on@Ki?oT6n@03_oT6n@00ol0003o_D:moke2_@0=oke2_@03o`00
0?nHIiSoV6NH00[oV6NH00?o0000ohAkQ?n4Nh@00on4Nh@00ol0003oPgb3oh=lP`0?oh=lP`03o`00
0?n2OH;oPWf200WoPWf200?o0000oiIYU_nFJIH02?nFJIH00ol0003oX5nPoj1OX005oj1OX003o`00
0?o0?l3o`3o000oo`3o000?o0000onTFjOoY5^T02OoY5^T00ol0003okQ7^onhAkP06onhAkP03o`00
0?oi1_Won@Ki00gon@Ki00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?ooP7n0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooH9m_of2OH02?of2OH00ol0003oi1_Ton@Ki00>on@Ki003o`000?nm
@[go_D:m00ko_D:m00?o0000oiQWV?nHIiP02?nHIiP00ol0003oQ7^4ohAkQ005ohAkQ003o`000?n3
O8?oPgb300koPgb300?o0000oh9mP_n2OH802On2OH800ol0003oUVVFoiIYUP07oiIYUP03o`000?nP
Gj3oX5nP00KoX5nP00?o0000ol0o`?o0?l003oo0?l000ol0003ojAKYonTFj@09onTFj@03o`000?o^
4NkokQ7^00GokQ7^00?o0000ooT6nOoi1_T03_oi1_T00ol0003oo@;mood2o@0;ood2o@03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n00GooP7n0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003oi1_Ton@Ki00=
on@Ki003o`000?nm@[go_D:m00oo_D:m00?o0000oiQWV?nHIiP01_nHIiP00ol0003oQ7^4ohAkQ007
ohAkQ003o`000?n3O8?oPgb300goPgb300?o0000oh9mP_n2OH802On2OH800ol0003oUVVFoiIYUP04
oiIYUP?o00002_nPGj000ol0003o`3o0ol0o`00=ol0o`003o`000?oY5^WojAKY00_ojAKY00?o0000
onhAk_o^4Nh00oo^4Nh00ol0003on@KiooT6n@0@ooT6n@03o`000?om0_goo@;m00Woo@;m00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh01oon0Oh2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003omPWfooH9mP08ooH9mP03o`000?oT6nCoi1_T
00goi1_T00?o0000oke2_Onm@[d04?nm@[d00ol0003oV6NHoiQWV005oiQWV003o`000?n4NhCoQ7^4
00SoQ7^400?o0000oh=lPon3O8<03?n3O8<00ol0003oPWf2oh9mPP09oh9mPP03o`000?nFJIKo0000
00Co00000_n<Lh`00ol0003oX5nPoj1OX008oj1OX003o`000?o0?l3o`3o000go`3o000?o0000onTF
jOoY5^T03?oY5^T01Ol0003okQ7^onhAk_o^4Nko000001;on@Ki0ol00009ood2o@03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n00WooP7n0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?of2OKomPWf00OomPWf00?o0000on@Ki?oT6n@03OoT6n@00ol0
003o_D:moke2_@0Aoke2_@03o`000?nHIiSoV6NH00?oV6NH00?o0000ohAkQ?n4Nh@02_n4Nh@00ol0
003oPgb3oh=lP`0;oh=lP`03o`000?n2OH;oPWf200SoPWf20ol00008ohacS003o`000?nPGj3oX5nP
00SoX5nP00?o0000ol0o`?o0?l003?o0?l000ol0003ojAKYonTFj@0=onTFj@03o`000?o^4Nko0000
01;on@Ki00Co0000ood2oOom0_goo@;m0_l00006ood2o@03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0
003omPWfooH9mP07ooH9mP03o`000?oT6nCoi1_T00goi1_T00?o0000oke2_Onm@[d04_nm@[d01Ol0
003oV6NHoiQWV?nHIiSo000000koQ7^400?o0000oh=lPon3O8<02on3O8<00ol0003oPWf2oh9mPP06
oh9mPP03o`000?n<LhcoS7><00WoS7><00?o0000oj1OX?nPGj002OnPGj000ol0003o`3o0ol0o`00:
ol0o`003o`000?oY5^WojAKY00oojAKY00?o0000ooT6nOoi1_T04?oi1_T00ol0003oo@;mood2o@04
ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?of2OKomPWf
00KomPWf00?o0000on@Ki?oT6n@03OoT6n@00ol0003o_D:moke2_@0Coke2_@03o`000?nHIiSo0000
013oQ7^43_l00006oh9mPP;o00003?n<Lh`00ol0003oX5nPoj1OX009oj1OX003o`000?o0?l3o`3o0
00[o`3o000?o0000onTFjOoY5^T03ooY5^T00ol0003on@KiooT6n@0>ooT6n@;o00002?om0_d2o`00
0003ood2oOl0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003o
o0?loo`3o00<oo`3o003o`000?of2OKomPWf00KomPWf00?o0000on@Ki?oT6n@02ooT6n@00ol0003o
_D:moke2_@0Doke2_@?o00003on4Nh@00ol0003oQGZ5ohEjQ@0<ohEjQ@04o`000?n2OH;oPWf2oh9m
PP;o00003on<Lh`00ol0003oX5nPoj1OX009oj1OX003o`000?o0?l3o`3o000Wo`3o000?o0000onTF
jOoY5^T04?oY5^T00ol0003on@KiooT6n@0<ooT6n@03o`000?om0_goo@;m00[oo@;m00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00go
oP7n00?o0000oo`3o?ol0o`03Ool0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oT6nCoi1_T00_o
i1_T00?o0000oke2_Onm@[d04onm@[d01Ol0003oVFJIoiUVVOnIIYWo000000goQ7^400?o0000ohEj
QOn5NXD03_n5NXD00ol0003oPWf2o`00000AohacS003o`000?nPGj3oX5nP00WoX5nP00?o0000ol0o
`?o0?l002Oo0?l000ol0003ojAKYonTFj@0@onTFj@03o`000?oi1_Won@Ki00_on@Ki00?o0000ood2
oOom0_d02oom0_d00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?of2OKomPWf00Go
mPWf4Ol0000Boke2_@03o`000?nIIYWoVFJI00?oVFJI00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o
QGZ5ohEjQ@0@ohEjQ@03o`000?n<LhcoS7><017oS7><00?o0000oj1OX?nPGj002OnPGj000ol0003o
`3o0ol0o`007ol0o`003o`000?oY5^WojAKY017ojAKY00?o0000ooT6nOoi1_T02_oi1_T00ol0003o
o@;mood2o@0=ood2o@04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
oP7nooh1oP0>ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH00oof2OH00ol0003o
iaSWonLHi`0<onLHi`03o`000?nfBKKo]TVf00?o00003_nm@[d00ol0003oVFJIoiUVV@05oiUVV@03
o`000?n4NhCoQ7^400OoQ7^400?o0000ohEjQOn5NXD04On5NXD00ol0003oS7><ohacS00AohacS003
o`000?nPGj3oX5nP00WoX5nP00?o0000ol0o`?o0?l001_o0?l02o`0001CojAKY00?o0000ooT6nOoi
1_T01ooi1_T2o`00017oo@;m0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?on0OkooP7n00kooP7n00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooH9m_l0003oiaSW00koiaSW
00?o0000okI9]_nfBKH00onfBKH3o`0000[o_D:m00?o0000oiUVVOnIIYT01onIIYT00ol0003oQ7^4
ohAkQ005ohAkQ003o`000?n5NXGoQGZ501;oQGZ500?o0000ohacS?n<Lh`04On<Lh`00ol0003oX5nP
oj1OX00:oj1OX003o`000?o0?l3o`3o000;o`3o00ol00002olLha`03o`000?oY5^WojAKY017ojAKY
00?o0000ooT6nOoi1_T01_oi1_T00ol0003oo@;mood2o@0Aood2o@03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ol
0ocoo0?l00[oo0?l0ol00004ooX5nP03o`000?oW6>OoiaSW00koiaSW00?o0000okI9]_nfBKH01_nf
BKH3o`0000Ko_D:m00?o0000oiUVVOnIIYT02OnIIYT00ol0003oQ7^4ohAkQ003ohAkQ003o`000?n5
NXGoQGZ501?oQGZ500?o0000ohacS?n<Lh`04_n<Lh`00ol0003oX5nPoj1OX009oj1OX003o`000?o0
?l3o000000;o00001_o7><L00ol0003ojAKYonTFj@0@onTFj@03o`000?oi1_Won@Ki00Gon@Ki00?o
0000ood2oOom0_d04_om0_d00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ooh1o_on0Oh03oon0Oh3o`0000Ooo0?l0ol00007ooX5nP03o`000?oW6>Oo
iaSW00goiaSW00?o0000okI9]_nfBKH02_nfBKH3o`0000;o_D:m00?o0000oiUVVOnIIYT02onIIYT0
1Ol0003oQ7^4ohAkQ?n4NhCo000001KoQGZ500?o0000ohacS?n<Lh`04_n<Lh`00ol0003oX5nPoj1O
X00:oj1OX003o`000?o7><OoacS700SoacS700?o0000onTFjOoY5^T04?oY5^T00ol0003on@KiooT6
n@02ooT6n@?o00005Oom0_d00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?on0Oko
oP7n00kooP7n00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:ooX5nP03o`00
0?oW6>OoiaSW00goiaSW00?o0000okI9]_nfBKH03OnfBKH2o`0000ooVFJI00?o0000ohAkQ?l00000
5on5NXD00ol0003oS7><ohacS00CohacS003o`000?nPGj3oX5nP00WoX5nP00?o0000olLhaoo7><L0
2Oo7><L00ol0003ojAKYonTFj@0?onTFj@03o`000?oi1_Won@Ki00;o00000ooj1OX2o`0001?oo@;m
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000onLHiooW6>L03OoW
6>L00ol0003o]TVfokI9]P0>okI9]P03o`000?nIIYWoVFJI00koVFJI00?o0000ohEjQOn5NXD05_n5
NXD00ol0003oS7><ohacS00CohacS003o`000?nPGj3oX5nP00SoX5nP00?o0000olLhaoo7><L02oo7
><L5o`0000cojAKY00?o0000ooT6nOl000001ooj1OX2o`00017oo@;m00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1oP06
ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000onLHiooW6>L03OoW6>L00ol0003o]TVfokI9]P0>
okI9]P03o`000?nIIYWoVFJI00koVFJI00?o0000ohEjQOn5NXD05_n5NXD00ol0003oS7><ohacS00C
ohacS003o`000?nPGj3oX5nP00OoX5nP00?o0000olLhaoo7><L03?o7><L00ol0003ojAKYonTFj@02
onTFj@Wo00001?oY5^T00ol0003onPGjooX5nP08ooX5nP;o00003oom0_d00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?on0OkooP7n
00SooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003oiaSWonLHi`0<onLHi`03o`000?nfBKKo]TVf
00ko]TVf00?o0000oiUVVOnIIYT03onIIYT00ol0003oQGZ5ohEjQ@0EohEjQ@03o`000?n<LhcoS7><
01?oS7><1?l00005oj1OX003o`000?o7><OoacS700goacS700?o0000onTFjOoY5^T02ooY5^T4o`00
00gonPGj0_l0000>ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03
o`000?oW6>OoiaSW00_oiaSW00?o0000okI9]_nfBKH03onfBKH00ol0003oVFJIoiUVV@0?oiUVV@03
o`000?n5NXGoQGZ501GoQGZ500?o0000ohacS?n<Lh`04?n<Lh`3o`0000CoZ5NX0ol000000onPGj3o
0000olLha`0>olLha`03o`000?oY5^WojAKY00oojAKY00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
o@;m0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?on0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003oiaSWonLHi`0;onLHi`03o`00
0?nfBKKo]TVf00oo]TVf00?o0000oiUVVOnIIYT03onIIYT2o`0001CoQGZ50ol0000@ohacS0;o0000
2_nXEjP00ol0003oacS7olLha`0>olLha`03o`000?oY5^WojAKY013ojAKY0_l0000?ooX5nP;o0000
2?om0_d01?l0003ooP7nooh1o_on0Oh2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oW6>OoiaSW00_oiaSW4ol0000>oiUVV@?o0000
0_nBKI800ol0003oQGZ5ohEjQ@0<ohEjQ@Go00000_n=LXd00ol0003oS7><ohacS00<ohacS0;o0000
3?nXEjP00ol0003oacS7olLha`0>olLha`03o`000?oY5^WojAKY013ojAKY00?o0000oo@;m?l00000
4?oj1OX2o`0000Coo@;m0_l00006ooh1oP03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oW
6>OoiaSW00_oiaSW00?o0000okE:]OneB[D03oneB[D00ol0003oVFJIoiUVV@09oiUVV@?o00001_nB
KI800ol0003oQGZ5ohEjQ@06ohEjQ@Go00002?n=LXd00ol0003oS7><ohacS008ohacS0?o00003onX
EjP00ol0003oacS7olLha`0=olLha`03o`000?oY5^WojAKY00oojAKY00Go0000oo@;m?od2oCom0_d
o`00000AooX5nP;o000000?oo@;mo`000?on0Oh02?on0Oh2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oiaSWonLH
i`0;onLHi`03o`000?neB[Go]DZe00oo]DZe00?o0000oiUVVOnIIYT01_nIIYT3o`0000[oTVfB00?o
0000ohEjQOn5NXD01Ol0000>ohebS@03o`000?n<LhcoS7><00GoS7><0_l0000BojQGZ003o`000?o7
><OoacS700coacS700?o0000onTFjOoY5^T04?oY5^T00ol0003om0_doo@;m002oo@;m003o`000?oj
1O[onPGj013onPGj00?o0000ooh1o_on0Oh02_on0Oh2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oiaSWonLHi`0;
onLHi`03o`000?neB[Go]DZe013o]DZe00?o0000oiUVVOnIIYT00_nIIYT3o`0000goTVfB0ol0000C
ohebS@03o`000?n<LhcoS7><00?oS7><0_l0000EojQGZ003o`000?o7><OoacS700_oacS700?o0000
onTFjOoY5^T03ooY5^T00ol0003om0_doo@;m004oo@;m003o`000?oj1O[onPGj00gonPGj0ol0000>
ooh1oP03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oiaSWonLHi`08onLHi`Co00004OneB[D00ol0003oVFJIo`000002o`00
00ooTVfB00?o0000oi1_T?l000005On=LXd00ol0003oS7><o`000002o`0001OoZ5NX00?o0000olLh
aoo7><L02oo7><L00ol0003ojAKYonTFj@0>onTFj@03o`000?od2oCom0_d00Kom0_d00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ooh1o_on0Oh03Oon0Oh2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oW6>OoiaSW00Go
iaSW0ol00004omHYeP03o`000?neB[Go]DZe00ko]DZe0_l0000Aoi9]TP04o`000?n@Ki3oT6n@o`00
01KoSG:=00?o0000ojQGZ?nXEjP06?nXEjP00ol0003oacS7olLha`0;olLha`03o`000?oY5^WojAKY
00kojAKY00?o0000oo@;m?od2o@01ood2o@00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oW6>OoiaSW00;oiaSW0ol00008omHYeP03
o`000?neB[Go]DZe00co]DZe0ol0000?oi9]TP;o00000on@Ki000ol0003oSG:=ohebS@0DohebS@03
o`000?nXEjSoZ5NX01WoZ5NX00?o0000olLhaoo7><L02_o7><L00ol0003ojAKYonTFj@0=onTFj@03
o`000?od2oCom0_d00Wom0_d00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oj1O[onPGj00OonPGj1_l0000<omHYeP03o`000?neB[Go]DZe00[o]DZe00Go0000ojeB[On]DZgo
[E:]o`00000=oi9]TP03o`000?n@Ki3oT6n@00CoT6n@00?o0000ohebSOn=LXd04on=LXd00ol0003o
Z5NXojQGZ00IojQGZ003o`000?o7><OoacS700WoacS700?o0000onTFjOoY5^T03_oY5^T00ol0003o
m0_doo@;m00:oo@;m0;o00003?ol0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000GonPGj0_l00004ooL8m`03o`00
0?oF:MKoeRWF00coeRWF0_l00008okE:]@;o00001On]DZd00ol0003oTVfBoi9]TP09oi9]TP03o`00
0?n@Ki3oT6n@00GoT6n@00?o0000ohebSOn=LXd04on=LXd00ol0003oZ5NXojQGZ00JojQGZ0go0000
3_oY5^T00ol0003om0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ooh1o_on0Oh0
3?on0Oh00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?onPGjo`000?og2?L01_og2?L00ol0003oeRWFomHYeP0=omHYeP03o`000?ne
B[Go]DZe00Co]DZe00?o0000ojeB[On]DZd01_n]DZd2o`0000SoTVfB00?o0000oi1_T?n@Ki001_n@
Ki000ol0003oSG:=ohebS@0DohebS@03o`000?nXEjSoZ5NX01WoZ5NX00?o0000omHYe_oF:MH02_oF
:MH00ol0003ojAKYonTFj@0;onTFj@03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol
0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o0000omHYe_oF:MH03_oF:MH0
1?l0003o]DZeokE:]OneB[D2o`0000_o[E:]00?o0000oi9]T_nBKI800onBKI82o`0000WoT6n@00?o
0000ohebSOn=LXd05?n=LXd00ol0003oZ5NXojQGZ00HojQGZ003o`000?oF:MKoeRWF00coeRWF00?o
0000onTFjOoY5^T02OoY5^T00ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooL8moog2?L01oog2?L00ol0003oeRWFomHYeP0>omHYeP03o`000?neB[Go
000000ko[E:]00Go0000oi9]T_nBKI;oTVfBo`00000;oi1_T003o`000?n=LXgoSG:=01CoSG:=0_l0
000IojQGZ003o`000?oF:MKoeRWF00goeRWF0_l00008onTFj@03o`000?od2oCom0_d00kom0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooL8moog2?L01oog2?L00ol0003oeRWFomHYeP0?
omHYeP03o`000?n]DZgo[E:]00ko[E:]00?o0000oi9]T_l000003?n@Ki000ol0003oSG:=ohebS@0D
ohebS@03o`000?nOGioo000000;o00005OnXEjP00ol0003oeRWFomHYeP0@omHYeP03o`000?oY5^Wo
jAKY00GojAKY00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o009oo`3o003o`000?on0Oko
oP7n00_ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooL8
moog2?L02?og2?L00ol0003oeRWFomHYeP0>omHYeP03o`000?n]DZgo[E:]00ko[E:]0_l0000=oi1_
T003o`000?n=LXgoSG:=01?oSG:=00?o0000oimOWonOGil00onOGil2o`0001;oZ5NX00?o0000omHY
e_oF:MH04_oF:MH01?l0003ojAKYonTFjOoY5^T3o`0001;om0_d00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?og2?Oom`Sg00Som`Sg00?o0000omHYe_oF:MH03OoF:MH2o`0000oo[E:]00?o0000ojII
Y_l000003_n@Ki000ol0003oSG:=ohebS@0BohebS@03o`000?nOGiooWenO00GoWenO0ol0000?ojQG
Z003o`000?oF:MKoeRWF01?oeRWF0ol00002oo4>l@03o`000?od2oCom0_d013om0_d00?o0000oo`3
o?ol0o`02Ool0o`00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o0000omHYe_oF:MH02ooF:MH00ol0003o
ebSGo`00000>ojeB[@05o`000?nVFJKoYUVVojIIY_l000003On@Ki000ol0003oSG:=ohebS@0Aoheb
S@03o`000?nOGiooWenO00WoWenO0ol0000:ojQGZ0;o00005_oF:MH00ol0003ol@kaoo4>l@03oo4>
l@03o`000?od2oCom0_d013om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0:ooh1
oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000omHYe_oF:MH02_oF:MH01Ol0003oebSGomLXeooG:=Oo000000co[E:]00?o0000ojII
Y_nVFJH00_nVFJH00ol0003oT6n@oi1_T00;oi1_T003o`000?n=LXgoSG:=017oSG:=00?o0000oimO
WonOGil03?nOGil2o`0000KoZ5NX0_l000000oo5>/Go0000omHYeP0DomHYeP03o`000?oa3_7ol@ka
00Gol@ka00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?on0OkooP7n
00[ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooL8moog
2?L02_og2?L00ol0003oeRWFomHYeP07omHYeP;o00001OoG:=L00ol0003o[E:]ojeB[@08ojeB[@03
o`000?nVFJKoYUVV00CoYUVV00?o0000oi1_T?n@Ki002On@Ki04o`00013oSG:=00?o0000oimOWonO
Gil03onOGil3o`000003ojQGZ?l0003o000000CoaC[500?o0000omHYe_oF:MH04OoF:MH00ol0003o
l@kaoo4>l@07oo4>l@03o`000?od2oCom0_d00oom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003o
oP7nooh1oP0:ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?og2?Oom`Sg00[om`Sg00?o0000omHYe_oF:MH01_oF:MH00ol0003oebSGomLXe`05omLXe`03o`00
0?n]DZgo[E:]00Oo[E:]00?o0000ojIIY_nVFJH01OnVFJH00ol0003oT6n@oi1_T008oi1_T003o`00
0?n>LHkoSW6>00;oSW6>0ol0000=ohebS@03o`000?nOGiooWenO01;oWenO00?o0000olDjaOo5>/D0
1Oo5>/D00ol0003oeRWFomHYeP0@omHYeP03o`000?oa3_7ol@ka00Ool@ka00?o0000oo@;m?od2o@0
3ood2o@00ol0003oo0?loo`3o007oo`3o003o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L02oog2?L00ol0003oeRWFomHY
eP04omHYeP03o`000?oG:=OoebSG00OoebSG00?o0000ojeB[On]DZd01On]DZd00ol0003oYUVVojII
YP07ojIIYP03o`000?n@Ki3oT6n@00KoT6n@00?o0000ohiaS_n>LHh01_n>LHh3o`0000SoSG:=0_l0
000EoimOW`03o`000?o5>/GoaC[500KoaC[500?o0000omHYe_oF:MH03_oF:MH00ol0003ol@kaoo4>
l@09oo4>l@03o`000?od2oCom0_d00kom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003ooP7nooh1
oP09ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?og2?Oo
m`Sg00_om`Sg00?o0000omHYe_oF:MH00_oF:MH2o`0000[oebSG00?o0000ojeB[On]DZd01?n]DZd0
0ol0003oYUVVojIIYP09ojIIYP03o`000?n@Ki3oT6n@00?oT6n@0_l0000<ohiaSP?o00000_n=LXd3
o`000003oi1_T?l0003oWenO01CoWenO00?o0000olDjaOo5>/D01oo5>/D00ol0003oeRWFomHYeP0<
omHYeP03o`000?oa3_7ol@ka00_ol@ka00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o006
oo`3o003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooL8moog2?L03?og2?L01?l0003oeRWFomHYe_l0000=omLXe`03o`000?n]DZgo
[E:]00;o[E:]00?o0000ojIIY_nVFJH02_nVFJH00ol0003oT6n@oi1_T002oi1_T003o`000?n>LHko
SW6>00ooSW6>0_l00005oi1_T003o`000?nOGiooWenO01;oWenO00?o0000olDjaOo5>/D02?o5>/D0
0ol0003oeRWFomHYeP0:omHYeP03o`000?oa3_7ol@ka00gol@ka1Ol0000;oo@;m003o`000?ol0oco
o0?l00Koo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003om`SgooL8m`0<ooL8m`03o`000?oF:MKo000000ooebSG00Co0000ojeB
[On]DZgo00003_nVFJH01?l0003oT6n@oi1_T?l0000CohiaSP03o`000?n@Ki3oT6n@00CoT6n@00?o
0000oimOWonOGil04?nOGil00ol0003oaC[5olDja@09olDja@03o`000?oF:MKoeRWF00[oeRWF00?o
0000oo4>lOoa3_403Ooa3_400ol0003onPGjooX5nP02ooX5nPWo00000_od2o@00ol0003oo0?loo`3
o006oo`3o003o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooL8m`03o`000?oG:=OoebSG00koebSG00?o0000ojeB[Ol000003onVFJH0
0ol0003oT6n@o`00000CohiaSP03o`000?n@Ki3oT6n@00GoT6n@00?o0000oimOWonOGil04?nOGil0
0ol0003oaC[5olDja@0:olDja@03o`000?oF:MKoeRWF00SoeRWF00?o0000oo4>lOoa3_403Ooa3_40
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000SooP7n00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000omLX
eooG:=L03ooG:=L00ol0003oYUVVojIIYP0>ojIIYP;o00005?n>LHh00ol0003oT6n@oi1_T006oi1_
T003o`000?nOGiooWenO00ooWenO00?o0000olDjaOo5>/D02oo5>/D00ol0003oeRWFomHYeP04omHY
eP?o00004?oa3_400ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?ooP7n1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003o
ebSGomLXe`0@omLXe`03o`000?nVFJKoYUVV00_oYUVV0ol000000onLHico0000ohiaSP0BohiaSP03
o`000?n@Ki3oT6n@00OoT6n@00?o0000oimOWonOGil03onOGil00ol0003oaC[5olDja@0<olDja@03
o`000?oF:MKoeRWF00?o00000oo[5>/00ol0003ol@kaoo4>l@0=oo4>l@03o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Wom`Sg00?o0000omLXeooG:=L04?oG:=L3o`0000WoYUVV0_l00005oiaSW003o`00
0?n>LHkoSW6>013oSW6>00?o0000oi1_T?n@Ki002?n@Ki000ol0003oWenOoimOW`0>oimOW`03o`00
0?o5>/GoaC[500goaC[50_l00007on/Dj`03o`000?oa3_7ol@ka00_ol@ka00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003om`SgooL8m`06ooL8m`03o`000?oG:=OoebSG00ooebSG00Co
0000ol`cc?o<<lcoc3?<0_l00005ojIIYP;o00002?nLHi`00ol0003oSW6>ohiaSP0>ohiaSP03o`00
0?n@Ki3oT6n@00[oT6n@00?o0000oimOWonOGil03?nOGil00ol0003oaC[5olDja@0>olDja@03o`00
0?o[5>_ojaC[00OojaC[00?o0000oo4>lOoa3_402_oa3_400ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?og2?Oom`Sg00Com`Sg4ol00006ol`cc003o`000?nVFJKo000000;o00002_nL
Hi`00ol0003oSW6>ohiaSP0=ohiaSP03o`000?n@Ki3oT6n@00_oT6n@00?o0000oimOWonOGil03?nO
Gil00ol0003oaC[5olDja@0=olDja@03o`000?o[5>_ojaC[00WojaC[00?o0000oo4>lOoa3_402?oa
3_400ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?o^4Nko
kQ7^00ookQ7^00?o0000ol`cc?o<<l`01Oo<<l`00ol0003oW6>LoiaSW00<oiaSW003o`000?n>LHko
SW6>00coSW6>00?o0000oi1_T?n@Ki003?n@Ki02o`0000coWenO00?o0000olDjaOo5>/D03Oo5>/D0
0ol0003ojaC[on/Dj`0:on/Dj`03o`000?oa3_7ol@ka00Ool@ka00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?om`Sgo`000?o^4Nh04?o^4Nh00ol0003oc3?<ol`cc006ol`cc003o`000?nLHico
W6>L00coW6>L00?o0000ohiaS_n>LHh02on>LHh00ol0003oT6n@oi1_T00=oi1_T004o`000?nQGZ7o
0000o`0000[oWenO00?o0000olDjaOo5>/D03Oo5>/D00ol0003ojaC[on/Dj`0;on/Dj`03o`000?oa
3_7ol@ka00Kol@ka00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?ol0o`00ol0003okQ7^onhAkP0@
onhAkP03o`000?o<<lcoc3?<00Koc3?<00?o0000oiaSW?nLHi`03OnLHi`00ol0003oSW6>ohiaSP0:
ohiaSP03o`000?n@Ki3oT6n@00coT6n@00?o0000oj5NXOnQGZ400_nQGZ42o`0000SoWenO00?o0000
olDjaOo5>/D03?o5>/D00ol0003ojaC[on/Dj`0=on/Dj`03o`000?oa3_7ol@ka00Col@ka00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?ol0ocoo0?l00Coo0?l0_l0000@onhAkP03o`000?o<<lcoc3?<
00Ooc3?<00?o0000oiaSW?nLHi`03_nLHi`<o`0000ooT6n@00?o0000oj5NXOnQGZ401?nQGZ42o`00
00KoWenO00?o0000olDjaOo5>/D03?o5>/D00ol0003ojaC[on/Dj`0>on/Dj`03o`000?oa3_7ol@ka
00?ol@ka00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001ool0o`01?l0003omPWfo`000?l0000>onhA
kP03o`000?o<<lcoc3?<00Soc3?<00?o0000oiaSW?nLHi`03OnLHi`00ol0003oTFjAoi5^T@08oi5^
T@03o`000?n@Ki3oT6n@00coT6n@00?o0000oj5NXOnQGZ401onQGZ42o`0000?oWenO00?o0000olDj
aOo5>/D03Oo5>/D00ol0003ojaC[on/Dj`0?on/Dj`05o`000?oa3_7ol@kaoo4>lOl000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009oo`3
o005o`000?of2OKomPWfooH9m_l000003Oo^4Nh00ol0003oc3?<ol`cc008ol`cc003o`000?nLHico
W6>L00coW6>L00?o0000oi5^TOnAKY402_nAKY400ol0003oT6n@oi1_T00;oi1_T003o`000?nQGZ7o
XEjQ00WoXEjQ0_l000000onOGioo0000olDja@08olDja@Ko00004oo[5>/01?l0003ol@kaoo4>lOl0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:oo`3o003o`000?of2OKomPWf00?omPWf1?l00008onhAkP03o`000?o<<lco
c3?<00Woc3?<00?o0000oiaSW?nLHi`03?nLHi`00ol0003oTFjAoi5^T@0:oi5^T@03o`000?n@Ki3o
T6n@00[oT6n@00?o0000oj5NXOnQGZ403?nQGZ4;o`0000GogB;M00?o0000on/Djoo[5>/04_o[5>/0
0ol0003ol@kao`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<oo`3o003o`000?of2OKomPWf00?omPWf00Co0000on4N
hOoQ7^7ohAkQ1Ol00003onhAkP03o`000?o<<lcoc3?<00Woc3?<00?o0000oiaSW?nLHi`02onLHi`0
0ol0003oTFjAoi5^T@0<oi5^T@03o`000?n@Ki3oT6n@00WoT6n@00?o0000oj5NXOnQGZ403?nQGZ40
0ol0003o`Sg2ol8m`P02ol8m`P03o`000?oM8]gogB;M00WogB;M00?o0000on/Djoo[5>/04_o[5>/3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o00<oo`3o003o`000?of2OKomPWf00ComPWf00?o0000on4N
hOoQ7^401OoQ7^43o`0000coc3?<00?o0000oiaSW?nLHi`02onLHi`00ol0003oTFjAoi5^T@0<oi5^
T@03o`000?n@Ki3oT6n@00SoT6n@00?o0000oj5NXOnQGZ403?nQGZ400ol0003o`Sg2ol8m`P04ol8m
`P03o`000?oM8]gogB;M00SogB;M00?o0000on/Djoo[5>/04_o[5>/00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_ol0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oQ7^7ohAkQ00OohAkQ00?o0000ol`c
c?o<<l`02_o<<l`00ol0003oW6>LoiaSW009oiaSW0;o00003onAKY400ol0003oT6n@oi1_T008oi1_
T003o`000?nQGZ7oXEjQ00coXEjQ00?o0000ol8m`_o2?L801?o2?L800ol0003ogB;MomdRg@09omdR
g@Co00003oo[5>/00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00Go
mPWf00?o0000on4NhOoQ7^402?oQ7^400ol0003oc3?<ol`cc009ol`cc003o`000?nLHicoW6>L00Ko
W6>L0ol000000onZEJ[o0000oi5^T@0?oi5^T@03o`000?n@Ki3oT6n@00KoT6n@00?o0000oj5NXOnQ
GZ403OnQGZ400ol0003o`Sg2ol8m`P05ol8m`P03o`000?oM8]gogB;M00SogB;M00Co0000oo@;m?od
2oCom0_d1Ol00009on/Dj`03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00koo0?l00?o0000ooH9m_of
2OH01_of2OH00ol0003ohAkQon4Nh@07on4Nh@03o`000?o<<lcoc3?<00[oc3?<00?o0000oiaSW?nL
Hi`00_nLHi`3o`0000GoZUFZ00?o0000oi5^TOnAKY403OnAKY400ol0003oT6n@oi1_T006oi1_T003
o`000?nQGZ7oXEjQ00coXEjQ00?o0000ol8m`_o2?L801_o2?L800ol0003ogB;MomdRg@08omdRg@03
o`000?od2oCom0_d00Kom0_d1Ol00003on/Dj`03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00KomPWf
00?o0000on4NhOoQ7^401ooQ7^400ol0003oc3?<ol`cc00:ol`cc003o`000?nLHico000000;o0000
2?nZEJX00ol0003oTFjAoi5^T@0=oi5^T@Co00001?n@Ki000ol0003oXEjQoj5NX@0=oj5NX@03o`00
0?o2?L;o`Sg200Oo`Sg200?o0000omdRgOoM8]d01ooM8]d00ol0003om0_doo@;m00;oo@;m0?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo0?loo`3
o00<oo`3o003o`000?of2OKomPWf00OomPWf00?o0000on4NhOoQ7^402?oQ7^43o`0000Woc3?<0_l0
000<ojYEZP03o`000?nAKY7oTFjA00_oTFjA00?o0000ojIIY_nVFJH00_nVFJH3o`000003oi1_T?l0
003oXEjQ00koXEjQ00?o0000ol8m`_o2?L801oo2?L800ol0003ogB;MomdRg@06omdRg@03o`000?od
2oCom0_d00kom0_d00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?of2OKomPWf00SomPWf00?o0000
on4NhOoQ7^401_oQ7^401?l0003oi1_Ton@Ki?oT6n@3o`0000Koc3?<00?o0000ojYEZ_nZEJX03?nZ
EJX00ol0003oTFjAoi5^T@09oi5^T@03o`000?nVFJKoYUVV00KoYUVV00?o0000oj5NXOnQGZ403OnQ
GZ400ol0003o`Sg2ol8m`P09ol8m`P03o`000?oM8]gogB;M00GogB;M00?o0000oo@;m?od2o@03_od
2o@00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?ol0ocoo0?l00coo0?l00?o0000ooH9m_of2OH02?of2OH00ol0003ohAkQon4Nh@05
on4Nh@03o`000?oT6nCoi1_T00Goi1_T0ol00002ol`cc003o`000?nZEJ[oZUFZ00goZUFZ00?o0000
oi5^TOnAKY402?nAKY400ol0003oYUVVojIIYP07ojIIYP03o`000?nQGZ7oXEjQ00coXEjQ0ol0000:
ol8m`P03o`000?oM8]gogB;M00GogB;M00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003ohAkQon4Nh@04on4Nh@03o`000?oT6nCoi1_T
00Woi1_T0_l0000AojYEZP03o`000?nAKY7oTFjA00GoTFjA0_l0000;ojIIYP03o`000?nQGZ7oXEjQ
00[oXEjQ00Go0000ol8m`_o2?L;o`Sg2o`00000:ol8m`P03o`000?oM8]gogB;M00CogB;M00?o0000
oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00Soo0?l1?l0000<ooH9mP03o`000?oQ7^7ohAkQ
00;ohAkQ00?o0000on@Ki?oT6n@02_oT6n@2o`00017oZUFZ00?o0000oi5^TOnAKY401?nAKY400ol0
003oYUVVojIIYP0<ojIIYP03o`000?nQGZ7oXEjQ00OoXEjQ0_l00005ol8m`P;o00002?o2?L800ol0
003ogB;MomdRg@04omdRg@03o`000?od2oCom0_d00gom0_d00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o007o`0000?o
oP7n00?o0000ooH9m_of2OH02_of2OH01Ol0003ohAkQon4NhOoQ7^7o000000coi1_T00Co0000omDZ
eOoE:]Go00004OnZEJX00ol0003oTFjAoi5^T@02oi5^T@03o`000?nVFJKoYUVV00koYUVV00?o0000
oj5NXOnQGZ401OnQGZ400ol0003o`Sg2ol8m`P07ol8m`P03o`000?o2?L;o`Sg200Ko`Sg200?o0000
omdRgOoM8]d00ooM8]d00ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?of2OKomPWf
00WomPWf00Co0000on4NhOoQ7^7o00003?oT6n@00ol0003oeB[EomDZe@02omDZe@03o`000?nZEJ[o
ZUFZ00ooZUFZ00Co0000oi5^TOnAKY7o00004OnVFJH00ol0003oXEjQoj5NX@04oj5NX@03o`000?o2
?L;o`Sg200Wo`Sg200?o0000ol8m`_o2?L801Oo2?L800ol0003ogB;MomdRg@03omdRg@03o`000?od
2oCom0_d00gom0_d00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00WomPWf0_l0000<
on@Ki003o`000?oE:]GoeB[E00?oeB[E00?o0000ojYEZ_nZEJX03onZEJX00ol0003oTFjAo`00000C
ojIIYP04o`000?nQGZ7oXEjQoj5NX@;o00003Oo2?L82o`0000Ko`Sg200Go0000omdRgOoM8]gogB;M
o`00000@oo@;m003o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?of2OKomPWf00SomPWf00?o0000on@Ki?oT6n@02_oT
6n@00ol0003oeB[EomDZe@05omDZe@03o`000?nZEJ[oZUFZ00ooZUFZ00?o0000ojIIY_nVFJH04onV
FJH00ol0003oXEjQo`00000Aol8m`P03o`000?o2?L;o`Sg200?o`Sg200Go0000omdRgOoM8]gogB;M
o`00000>oo@;m0?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?of2OKomPWf00SomPWf00?o0000on@Ki?oT6n@02OoT
6n@00ol0003oeB[EomDZe@07omDZe@03o`000?nZEJ[oZUFZ00koZUFZ00?o0000ojIIY_nVFJH05?nV
FJH00ol0003o`Sg2ol8m`P0Aol8m`P;o00001?o2?L801?l0003ogB;MomdRgOl0000:oo@;m0Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?of2OKomPWf00KomPWf00?o
0000on@Ki?oT6n@02OoT6n@00ol0003oeB[EomDZe@08omDZe@03o`000?nZEJ[oZUFZ00_oZUFZ0ol0
000GojIIYP03o`000?o2?L;o`Sg201?o`Sg200Ko0000ol8m`_o2?L;o`Sg2o`000?oM8]d5o`0000Co
m0_d0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`00
0?oT6nCoi1_T00Soi1_T00?o0000omDZeOoE:]D02_oE:]D00ol0003oZUFZojYEZP07ojYEZP?o0000
0_n_D:l00ol0003oYUVVojIIYP0EojIIYP;o00005Oo2?L800ol0003o`Sg2ol8m`P02o`0000GokQ7^
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?omPWf00?o0000on@Ki?oT6n@01ooT
6n@00ol0003oeB[EomDZe@0;omDZe@03o`000?nZEJ[oZUFZ00CoZUFZ0ol00006ojm@[`03o`000?nV
FJKoYUVV01?oYUVV00Co0000olLhaoo7><Oo00005Oo2?L82o`0000WokQ7^00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooL8moog2?L00oog2?L3o`0000Woi1_T00?o0000omDZeOoE:]D03OoE:]D00ol0003oZUFZojYE
ZP03o`0000[o[e2_00?o0000ojIIY_nVFJH04OnVFJH00ol0003oacS7olLha`02olLha`03o`000?o2
?L;o`Sg201;o`Sg200?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooL8moog2?L01oog2?L00ol0003oi1_Ton@Ki005on@Ki003o`000?oE:]GoeB[E00ooeB[E0_l0000>
ojm@[`03o`000?nVFJKoYUVV00ooYUVV00?o0000olLhaoo7><L01?o7><L00ol0003o`Sg2ol8m`P0@
ol8m`P;o00002oo^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00?o0000on@Ki?oT6n@00ooT6n@00ol0003oeB[EomDZe@0@omDZe@03o`000?n_D:oo[e2_
00go[e2_00?o0000ojIIY_nVFJH03_nVFJH00ol0003oacS7olLha`06olLha`;o00003_o2?L82o`00
0003omDZeOl0003okQ7^00[okQ7^00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02oog2?L01Ol0
003oi1_Ton@Ki?oT6nCo000001;oeB[E00?o0000ojm@[on_D:l03on_D:l00ol0003oYUVVojIIYP0<
ojIIYP03o`000?o7><OoacS700WoacS700?o0000ol8m`_o2?L802Oo2?L82o`0000?oeB[E00?o0000
onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooL8moog2?L03Oog2?L00ol0003oi1_To`00000ComDZ
e@03o`000?n_D:oo[e2_013o[e2_00?o0000ojIIY_nVFJH02_nVFJH00ol0003oacS7olLha`0;olLh
a`03o`000?o2?L;o`Sg200Go`Sg20ol00006omDZe@03o`000?o^4NkokQ7^00SokQ7^00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?og2?Oom`Sg00oo
m`Sg00?o0000omDZeOoE:]D04OoE:]D00ol0003o[e2_ojm@[`0Aojm@[`03o`000?nVFJKoYUVV00Wo
YUVV00?o0000olLhaoo7><L03Oo7><L00ol0003o`Sg2ol8m`P02ol8m`P;o00002OoE:]D00ol0003o
kQ7^onhAkP09onhAkP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooL8moog2?L04Oog2?L2o`00017oeB[E00?o0000ojm@[on_D:l0
4_n_D:l00ol0003oYUVVojIIYP07ojIIYP03o`000?o7><OoacS700ooacS700Co0000ol8m`_l0003o
00002ooE:]D00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04_og2?L00ol0003oj1OX
o`000002o`0000koeB[E00?o0000ojm@[on_D:l04on_D:l00ol0003oYUVVojIIYP05ojIIYP03o`00
0?o7><OoacS7017oacS700?o0000omDZeOoE:]D03?oE:]D00ol0003okQ7^onhAkP08onhAkP03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003om`SgooL8
m`0BooL8m`03o`000?oX5nSoj1OX00?oj1OX0_l0000;omDZe@;o00005_n_D:l7o`0001CoacS700?o
0000omDZeOoE:]D03?oE:]D00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?og2?L00ol0003oj1OXonPG
j006onPGj0?o00002?oE:]D00ol0003oaSW6o`000002o`0001;o[e2_00?o0000okQ7^?nhAkP00_nh
AkP00ol0003o/Tfbo`00000DolLha`03o`000?oE:]GoeB[E00coeB[E00?o0000onhAk_o^4Nh02?o^
4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooL8moog2?L04_og2?L00ol0003oj1OXonPGj009onPGj0;o00001OoE:]D00ol0003oaSW6olHiaP03
olHiaP;o00003on_D:l00ol0003o^4NhokQ7^003okQ7^004o`000?nbCK;o/Tfbo`0001?oacS700?o
0000omDZeOoE:]D03OoE:]D00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_oX5nP3o`000003omDZeOl0003o
aSW600OoaSW60ol0000;ojm@[`03o`000?nhAkSo^4Nh00Co^4Nh00Go0000ok9=/_nbCK;o/Tfbo`00
000BolLha`03o`000?oE:]GoeB[E00goeB[E00?o0000onhAk_o^4Nh01oo^4Nh?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04?og2?L0
0ol0003oj1OXonPGj00?onPGj003o`000?o6>LKoaSW600[oaSW60_l00008ojm@[`03o`000?nhAkSo
^4Nh00Go^4Nh00?o0000ok9=/_nbCK800_nbCK800ol0003oacS7olLha`0?olLha`03o`000?oE:]Go
eB[E00goeB[E00?o0000onhAk_o^4Nh01_o^4Nh00ol0003onPGjooX5nP0<ooX5nP03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?og2?Oom`Sg00oom`Sg00?o0000onPGj?oX5nP03ooX5nP00ol0003oaSW6olHiaP0<olHi
aP;o00001On_D:l00ol0003o^4NhokQ7^006okQ7^003o`000?nbCK;o/Tfb00?o/Tfb00?o0000olLh
aoo7><L03_o7><L00ol0003oeB[EomDZe@0>omDZe@03o`000?o^4NkokQ7^00CokQ7^00?o0000ooX5
n_oj1OX03Ooj1OX00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00kom`Sg00?o0000onPGj?oX5nP04?oX5nP00ol0003o
aSW6olHiaP0>olHiaP?o000000?o[e2_o`000?nhAkP02?nhAkP00ol0003o/Tfbok9=/P04ok9=/P03
o`000?o7><OoacS700goacS74_l00005onhAkP03o`000?oj1O[onPGj00gonPGj00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGj
o`00000?ooL8m`03o`000?oX5nSoj1OX00ooj1OX0_l0000ColHiaP03o`000?nhAkSo^4Nh00So^4Nh
00?o0000ok9=/_nbCK801OnbCK800ol0003oacS7olLha`0<olLha`03o`000?o_4>ooka3_00ooka3_
00Go0000onhAk_o^4NkokQ7^o`00000@ooX5nP03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?oj1O[onPGjo`0000ko
m`Sg00?o0000onPGj?oX5nP03_oX5nP00ol0003ogR7No`00000ColHiaP03o`000?nhAkSo^4Nh00So
^4Nh00?o0000ok9=/_nbCK801OnbCK800ol0003oacS7olLha`0;olLha`03o`000?o_4>ooka3_017o
ka3_00?o0000onhAk_l000004Ooj1OX00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oX5nSoj1OX00goj1OX0_l00003omhQgP03o`000?o6>LKoaSW6013o
aSW600?o0000okQ7^?nhAkP02?nhAkP00ol0003o/Tfbok9=/P06ok9=/P03o`000?o7><OoacS700[o
acS700?o0000onl@koo_4>l04_o_4>l00ol0003onPGjooX5nP0@ooX5nP03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX0
0ooj1OX00ol0003om`SgooL8m`09ooL8m`03o`000?oX5nSoj1OX00coj1OX00?o0000omhQg_oN8Mh0
0ooN8Mh00ol0003oaSW6olHiaP0?olHiaP03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000ok9=/_nbCK80
1onbCK800ol0003oacS7olLha`09olLha`03o`000?o_4>ooka3_01;oka3_00?o0000ooX5n_oj1OX0
4?oj1OX00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L00ol0003oj1OXonPG
j00:onPGj0;o00001_oN8Mh00ol0003oaSW6olHiaP0?olHiaP03o`000?nhAkSo^4Nh00Wo^4Nh00?o
0000ok9=/_nbCK802?nbCK800ol0003oacS7olLha`07olLha`03o`000?o_4>ooka3_01?oka3_00?o
0000ooX5n_oj1OX03ooj1OX00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L0
0ol0003oj1OXonPGj009onPGj003o`000?oN8MkogR7N00OogR7N00?o0000olHia_o6>LH03Oo6>LH2
o`0000_o^4Nh00?o0000ok9=/_nbCK802OnbCK800ol0003oacS7olLha`06olLha`03o`000?o_4>oo
ka3_01?oka3_4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5
n_oj1OX01ooj1OX00ol0003om`SgooL8m`06ooL8m`03o`000?oX5nSoj1OX00Woj1OX00?o0000omhQ
g_oN8Mh02?oN8Mh00ol0003oaSW6olHiaP0;olHiaP;o000000?oaC[5o`000?nhAkP02_nhAkP00ol0
003o/Tfbok9=/P09ok9=/PKo00000oo7><L00ol0003oka3_onl@k`0Conl@k`03o`000?ok1?_on`Ck
00oon`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000ooL8moog2?L01?og2?L3o`00
00Soj1OX0_l0000;omhQgP03o`000?o6>LKoaSW600WoaSW60_l00004olDja@03o`000?nhAkSo^4Nh
00So^4Nh00?o0000ok9=/_nbCK802?nbCK800ol0003oebSGomLXe`04omLXe`?o00005?o_4>l3o`00
017on`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003om`SgooL8m`03o`0000?o
m@[e00?o0000onPGj?oX5nP01?oX5nP00ol0003ogR7NomhQgP0<omhQgP03o`000?o6>LKoaSW600Go
aSW60ol00007olDja@03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ok9=/_nbCK801onbCK800ol0003o
ebSGomLXe`08omLXe`03o`000?o_4>ooka3_013oka3_00Go0000ooT6nOoi1_Won@Kio`00000@oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
nPGjooX5nP0;ooX5nP;o00001ooe2_D01?l0003oj1OXonPGj?oX5nP2o`0000oogR7N00?o0000olHi
a_o6>LH00oo6>LH2o`0000[oaC[500?o0000okQ7^?nhAkP01onhAkP00ol0003o/Tfbok9=/P05ok9=
/P;o00003?oG:=L00ol0003oka3_onl@k`0=onl@k`;o00001Ooi1_T00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000ooX5n_oj1OX03?oj1OX00ol0003om@[eooD:m@07ooD:m@03o`000?oX5nSo0000017o
gR7N00Co0000olHia_o6>LKoaSW60_l0000=olDja@03o`000?nhAkSo^4Nh00Ko^4Nh00?o0000ok9=
/_nbCK801?nbCK800ol0003oebSGomLXe`0=omLXe`Co00002_o_4>l00ol0003on@KiooT6n@06ooT6
n@03o`000?ok1?_on`Ck00con`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oe2_Gom@[e00Wo
m@[e00?o0000omhQg_oN8Mh04OoN8Mh3o`00013oaC[500?o0000okQ7^?nhAkP01OnhAkP00ol0003o
/Tfbok9=/P03ok9=/P03o`000?oG:=OoebSG00koebSG00Co0000oo<<looc3??ol`cc1_l00003onl@
k`03o`000?oi1_Won@Ki00Son@Ki00?o0000oo/4nook1?/02ook1?/00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooD:mOoe2_D02_oe2_D00ol0003ogR7NomhQgP0AomhQgP03o`000?o5>/GoaC[5013o
aC[500?o0000okQ7^?nhAkP01OnhAkP00ol0003o/Tfbok9=/P02ok9=/P03o`000?oG:=OoebSG00oo
ebSG00?o0000oo<<looc3?<01ooc3?<3o`0000con@Ki00?o0000oo/4nook1?/02_ok1?/00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003om@[eooD:m@0<ooD:m@03o`000?oN8MkogR7N013ogR7N00?o0000olDjaOo5>/D0
4Oo5>/D00ol0003o^4NhokQ7^004okQ7^003o`000?nbCK;o/Tfb00;o00004OoG:=L00ol0003ol`cc
oo<<l`0:oo<<l`03o`000?oi1_Won@Ki00_on@Ki3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oj1O[onPGj00[onPGj00?o0000ooD:mOoe2_D03_oe
2_D00ol0003ogR7NomhQgP0=omhQgP;o00005?o5>/D3o`0000Co^4Nh00?o0000ok9=/_l000004ooG
:=L00ol0003ol`ccoo<<l`0:oo<<l`03o`000?oi1_Won@Ki00_on@Ki00?o0000ood2oOom0_d02Oom
0_d00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oe2_Gom@[e00kom@[e00?o0000
omhQg_oN8Mh02_oN8Mh3o`000003omhQg_l0003oaC[5017oaC[50_l00003om0_d0;o00000_nhAkP2
o`0001CoebSG00?o0000oo<<looc3?<02_oc3?<00ol0003on@KiooT6n@0;ooT6n@03o`000?om0_go
o@;m00[oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ooj1OX00ol0003om@[eooD:m@0@ooD:m@03o`000?oN8MkogR7N00KogR7N0ol00005omhQ
gP03o`000?o5>/GoaC[500goaC[50_l00007om0_d0?o00005OoG:=L00ol0003ol`ccoo<<l`0;oo<<
l`03o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d03?om0_d3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?om0_goo@;m00Coo@;m1Ol00003ooX5nP03o`000?oe2_Gom@[e017o
m@[e00?o0000omhQg_oN8Mh01?oN8Mh2o`0000WogR7N00?o0000olDjaOo5>/D02_o5>/D2o`0000_o
d2o@00?o0000omLXeooG:=L04_oG:=L00ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Wo
n@Ki00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ood2oOom0_d02_om0_d3o`0001Gom@[e00?o0000omhQg_oN8Mh00ol0000<omhQgP03o`00
0?o5>/GoaC[500OoaC[50_l0000=om0_d003o`000?oG:=OoebSG01;oebSG00?o0000oo<<looc3?<0
3?oc3?<00ol0003on@KiooT6n@09ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00coo@;m00?o
0000ooD:mOoe2_D05?oe2_D2o`0000oogR7N00?o0000olDjaOo5>/D01Oo5>/D2o`0000ood2o@00?o
0000omLXeooG:=L04_oG:=L00ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Won@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00goo@;m00?o0000ooD:mOoe2_D04ooe2_D2
o`00013ogR7N00?o0000olDjaOo5>/D00_o5>/D2o`0001;od2o@00?o0000omLXeooG:=L04OoG:=L0
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m
00koo@;m00?o0000ooD:mOoe2_D04_oe2_D01?l0003oka3_onl@kol0000@omhQgP04o`000?o5>/Go
0000o`0001Cod2o@00?o0000omLXeooG:=L04?oG:=L00ol0003ol`ccoo<<l`0>oo<<l`03o`000?oi
1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oe2_Gom@[e017om@[e00?o0000
onl@koo_4>l00_o_4>l00ol0003ogR7NomhQgP0>omhQgP03o`000?o@;m3od2o@01Cod2o@00?o0000
omLXeooG:=L03OoG:=L4o`00013ol`cc00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m
013oo@;m00?o0000ooD:mOoe2_D04?oe2_D00ol0003oka3_onl@k`03onl@k`03o`000?oN8MkogR7N
00gogR7N00?o0000om0_d?o@;m005?o@;m000ol0003oebSGomLXe`07omLXe`Ko00000ooX5nP00ol0
003ol`ccoo<<l`0>oo<<l`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02?om0_d00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo@;mood2o@0@ood2o@03
o`000?oe2_Gom@[e00oom@[e00?o0000onl@koo_4>l01Oo_4>l00ol0003ogR7NomhQgP0<omhQgP03
o`000?o@;m3od2o@01God2o@00?o0000omLXeooG:=L01_l0000:onPGj003o`000?oc3??ol`cc00go
l`cc00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m013oo@;m00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oka3_onl@k`06onl@k`03o`000?oN8MkogR7N00_ogR7N00?o0000om0_d?o@;m00
5Oo@;m03o`00017oj1OX00?o0000oo<<looc3?<03?oc3?<00ol0003on@KiooT6n@07ooT6n@03o`00
0?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ood2oOom0_d04_om0_d9o`0000Oom@[e00?o0000onl@koo_4>l02?o_4>l00ol0003ogR7NomhQ
gP0:omhQgP03o`000?o@;m3od2o@01God2o@00?o0000onPGj?oX5nP04OoX5nP00ol0003ol`ccoo<<
l`0=oo<<l`03o`000?oi1_Won@Ki00Gon@Ki00?o0000ood2oOom0_d01oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo@;mood2o@0Bood2o@03o`000?oj1O[o
nPGj00KonPGj1ol0000<onl@k`03o`000?oN8MkogR7N00WogR7N00?o0000om0_d?o@;m005?o@;m00
0ol0003oj1OXonPGj00ConPGj003o`000?oc3??ol`cc00col`cc00Co0000ooT6nOoi1_Won@Ki1_l0
0007ood2o@03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d04Oom0_d0
0ol0003onPGjooX5nP0=ooX5nP03o`000?o_4>ooka3_00_oka3_00?o0000omhQg_oN8Mh02OoN8Mh0
0ol0003od2o@om0_d00Com0_d003o`000?oX5nSoj1OX01Coj1OX1?l0000:oo<<l`Co00001_om0_d2
o`0000Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_om0_d00ol0003onPGjooX5nP0=ooX5nP?o00003?o_4>l00ol0003ogR7NomhQgP08omhQ
gP03o`000?o@;m3od2o@00ood2o@1?l0000GonPGj004o`000?og2?Oom`SgooL8m`Ko00000ooc3?<0
0ol0003oo@;mood2o@0:ood2o@;o000000?oo@;mo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003ooP7nooh1oP02ooh1oP?o00003_om0_d00ol0003onPGjooX5nP0>ooX5nP03o`000?od2oCom0_d
00?o00002_o_4>l00ol0003ogR7NomhQgP07omhQgP03o`000?o@;m3od2o@00Sod2o@1ol00003onHI
iP03o`000?oX5nSoj1OX01Coj1OX00?o0000ooL8moog2?L02?og2?L3o`0000ooo@;m00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ooh1oP?o00002oom0_d00ol0003o
nPGjooX5nP0>ooX5nP03o`000?od2oCom0_d00?om0_d0ol00008onl@k`03o`000?oN8MkogR7N00Ko
gR7N00Co0000om0_d?o@;m3od2o@1ol0000:onHIiP03o`000?oX5nSoj1OX01Coj1OX00?o0000ooL8
moog2?L02_og2?L00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?on0OkooP7n00_ooP7n0ol00008ood2o@03o`000?oj1O[onPGj00ko
nPGj00?o0000oo@;m?od2o@01_od2o@3o`0000Koka3_00?o0000omhQg_oN8Mh01?oN8Mh5o`0001;o
iQWV00?o0000onPGj?oX5nP04_oX5nP00ol0003om`SgooL8m`0;ooL8m`03o`000?om0_goo@;m00ko
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Oon0Oh3o`0000Coo@;m
00?o0000ooX5n_oj1OX03ooj1OX00ol0003om0_doo@;m009oo@;m0?o00001?o_4>l00ol0003ogR7N
omhQgP03o`000003ooD:mOl0003oiQWV01CoiQWV00?o0000onPGj?oX5nP04_oX5nP00ol0003om`Sg
ooL8m`0;ooL8m`03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003ooP7nooh1oP0Booh1oP?o000000?oo@;mo`000?oj1OX04?oj1OX00ol0003om0_doo@;
m00<oo@;m0?o000000Coka3_o`000?l0003o00001?oe2_D00ol0003oiQWVonHIiP0BonHIiP;o0000
4ooX5nP00ol0003om`SgooL8m`0<ooL8m`03o`000?om0_goo@;m00ooo@;m00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003onPGjooX5
nP0@ooX5nP03o`000?od2oCom0_d00oom0_d00?o0000ooD:mOoe2_D01_oe2_D00ol0003oiQWVonHI
iP0@onHIiP04o`000?oY5^WojAKYo`0001;oj1OX00?o0000ooL8moog2?L03?og2?L00ol0003oo@;m
ood2o@0@ood2o@?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh04oon
0Oh00ol0003onPGjooX5nP0@ooX5nP03o`000?od2oCom0_d00oom0_d00?o0000ooD:mOoe2_D01_oe
2_D00ol0003oiQWVonHIiP0?onHIiP03o`000?oY5^WojAKY00;ojAKY00?o0000onPGj?oX5nP03_oX
5nP00ol0003om`SgooL8m`0=ooL8m`03o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?oj1O[o
nPGj013onPGj00?o0000oo@;m?od2o@03_od2o@00ol0003om@[eooD:m@07ooD:m@03o`000?oV6NKo
iQWV00koiQWV00?o0000onTFjOoY5^T01?oY5^T2o`0000koj1OX00?o0000ooL8moog2?L03Oog2?L0
0ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003onPGjooX5nP0@ooX5nP03o`000?od2oCom0_d
00gom0_d00?o0000ooD:mOoe2_D02?oe2_D00ol0003oiQWVonHIiP0=onHIiP03o`000?oY5^WojAKY
00GojAKY00?o0000ooH9m_l000000_l0000:onPGj003o`000?og2?Oom`Sg00kom`Sg00?o0000ood2
oOom0_d03_om0_d00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?oj1O[onPGj013onPGj00?o0000oo@;m?od2o@03?od2o@00ol0003o
m@[eooD:m@0:ooD:m@03o`000?oV6NKoiQWV00_oiQWV00?o0000onTFjOoY5^T01_oY5^T00ol0003o
mPWfooH9mP02ooH9mP?o00001ooX5nP00ol0003om`SgooL8m`0>ooL8m`03o`000?om0_goo@;m00go
o@;m00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh0
3oon0Oh3o`00013onPGj1?l0000:oo@;m003o`000?oe2_Gom@[e00_om@[e00?o0000onHIi_oV6NH0
2_oV6NH00ol0003ojAKYonTFj@06onTFj@03o`000?of2OKomPWf00KomPWf0_l00004onPGj003o`00
0?og2?Oom`Sg00oom`Sg00?o0000ood2oOom0_d03Oom0_d00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?om0_goo@;m00?o00003Ooj
1OX01?l0003on`Ckoo/4nook1?/6o`0000?om0_d00?o0000ooD:mOoe2_D03?oe2_D00ol0003oiQWV
onHIiP09onHIiP03o`000?oY5^WojAKY00OojAKY00?o0000ooH9m_of2OH02?of2OH3o`000003onPG
j?l0003om`Sg013om`Sg00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?om0_goo@;m00Coo@;m0ol0
0009ooX5nP03o`000?ok1?_on`Ck00Son`Ck0ol0000?ooD:m@03o`000?oV6NKoiQWV00SoiQWV00?o
0000onTFjOoY5^T02?oY5^T00ol0003omPWfooH9mP0;ooH9mP03o`000?og2?Oom`Sg013om`Sg00?o
0000ood2oOom0_d02oom0_d00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n00[ooP7n00?o0000ood2oOom0_d02?om0_d3o`0000GonPGj00?o0000oo/4nook1?/02ook1?/0
0ol0003om@[eooD:m@0=ooD:m@03o`000?oV6NKoiQWV00OoiQWV00?o0000onTFjOoY5^T02?oY5^T0
0ol0003omPWfooH9mP0<ooH9mP03o`000?og2?Oom`Sg00kom`Sg0ol0000=ood2o@03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?om0_goo@;m00coo@;m0ol00002ooX5nP03o`000?ok1?_on`Ck00_on`Ck00?o0000ooD:
mOoe2_D03_oe2_D00ol0003oiQWVonHIiP05onHIiP03o`000?oY5^WojAKY00WojAKY00?o0000ooH9
m_of2OH03Oof2OH00ol0003om`SgooL8m`0:ooL8m`?o00000oom0_d00ol0003oo@;mood2o@09ood2
o@03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003o
o@;mood2o@0?ood2o@;o00003ook1?/00ol0003om@[eooD:m@0=ooD:m@03o`000?oV6NKoiQWV00Co
iQWV00?o0000onTFjOoY5^T02_oY5^T00ol0003omPWfooH9mP0=ooH9mP03o`000?og2?Oom`Sg00Oo
m`Sg0ol00007ood2o@03o`000?om0_goo@;m00Ooo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh01Oon0Oh00ol0003oo@;mood2o@0Aood2o@03o`00
0?ok1?_on`Ck00gon`Ck00?o0000ooD:mOoe2_D03Ooe2_D00ol0003oiQWVonHIiP03onHIiP03o`00
0?oY5^WojAKY00[ojAKY00?o0000ooH9m_of2OH03oof2OH00ol0003om`SgooL8m`03ooL8m`?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00?ooP7n0_l0
000Cood2o@03o`000?ok1?_on`Ck00gon`Ck00?o0000ooD:mOoe2_D03Ooe2_D00ol0003oiQWVonHI
iP02onHIiP03o`000?oY5^WojAKY00_ojAKY00?o0000ooH9m_of2OH03oof2OH00ol0003om`SgooL8
m`03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003ooP7nooh1o_on0Oko000000;oo`3o0_l0000Aood2o@03o`000?ok
1?_on`Ck00kon`Ck00?o0000ooD:mOoe2_D03Ooe2_D01?l0003oiQWVonHIi_l0000>onTFj@03o`00
0?of2OKomPWf013omPWf0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_l000001Ooo0?l2o`0000ooo@;m00?o
0000oo/4nook1?/03_ok1?/00ol0003om@[eooD:m@0=ooD:m@Go00003?oY5^T00ol0003omPWfooH9
mP0AooH9mP03o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oom0_d0
0ol0003on`Ckoo/4n`0>oo/4n`03o`000?oe2_Gom@[e00gom@[e00?o0000ooH9m_of2OH00_of2OH3
o`0000WojAKY00?o0000ooH9m_of2OH04Oof2OH00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oom0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oe2_Gom@[e00_om@[e00?o0000ooH9
m_of2OH01_of2OH4o`0000GojAKY00?o0000ooH9m_of2OH04Oof2OH00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ok1?_on`Ck00oo
n`Ck00?o0000ooD:mOoe2_D02_oe2_D00ol0003omPWfooH9mP0;ooH9mP?o000000?ojAKYo`000?of
2OH04_of2OH00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oom0_d3o`00013on`Ck00?o0000ooD:mOoe2_D02Ooe2_D00ol0003omPWfooH9mP0?ooH9mP;o
00004oof2OH00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ood2o@04o`000?om0_goo@;mood2o@;o00003ook1?/00ol0003om@[eooD:m@06ooD:m@;o
00004oof2OH00ol0003omPWfooH9mP0AooH9mP;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo@;mo`000?om0_d01Oom0_d2o`0000gon`Ck00?o0000ooD:mOoe2_D0
1?oe2_D2o`0000;on`Ck00?o0000ooH9m_of2OH04Oof2OH00ol0003omPWfooH9mP0?ooH9mP04o`00
0?ol0ocoo0?lo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo@;m
ood2o@07ood2o@03o`000?ok1?_on`Ck00[on`Ck00?o0000ooD:mOoe2_D00ooe2_D00ol0003on`Ck
oo/4n`03oo/4n`03o`000?of2OKomPWf013omPWf4_l00004oo`3o0;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo@;mood2o@08ood2o@;o00002ook1?/00ol0003om@[eooD:m@02o`0000Oon`Ck00?o
0000ooH9m_of2OH03oof2OH00ol0003on0OhooP7n00>ooP7n003o`000?ol0ocoo0?l00Coo0?l00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2
o@0;ood2o@Ko00001?ok1?/4o`0000[on`Ck00?o0000ooH9m_of2OH03_of2OH00ol0003on0OhooP7
n00>ooP7n003o`000?ol0ocoo0?l00Goo0?l0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo@;mood2o@0;ood2o@03o`000?on0OkooP7n00?ooP7n1?l00003ood2o@03o`000?ok1?_o
n`Ck00Won`Ck00?o0000ooH9m_of2OH03?of2OH00ol0003on0OhooP7n00>ooP7n003o`000?ol0oco
o0?l00Soo0?l0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0;ood2
o@03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d00_om0_d00ol0003on`Ckoo/4n`09oo/4
n`03o`000?of2OKomPWf00_omPWf00?o0000ooP7n?oh1oP03_oh1oP00ol0003oo0?loo`3o00:oo`3
o003o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ood2oOom0_d02_om0_d00ol0003o
oP7nooh1oP08ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000oo/4nook1?/02_ok1?/00ol0003o
mPWfooH9mP0:ooH9mP03o`000?oh1oSon0Oh00kon0Oh00?o0000oo`3o?ol0o`02ool0o`2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d00ol0003ooP7nooh1oP07ooh1oP03o`00
0?om0_goo@;m00?oo@;m00?o0000oo/4nook1?/02ook1?/00ol0003omPWfooH9mP09ooH9mP03o`00
0?oh1oSon0Oh00kon0Oh00?o0000oo`3o?ol0o`03Ool0o`01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;m
ood2o@0:ood2o@03o`000?on0OkooP7n00SooP7n00?o0000ood2oOom0_d01?om0_d00ol0003on`Ck
oo/4n`0;oo/4n`03o`000?of2OKomPWf00OomPWf00?o0000ooP7n?oh1oP03ooh1oP00ol0003oo0?l
oo`3o00=oo`3o0Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000goo@;m00?o0000ooh1o_on0Oh02?on
0Oh00ol0003oo@;mood2o@04ood2o@03o`000?ok1?_on`Ck00con`Ck00?o0000ooH9m_of2OH01_of
2OH00ol0003on0OhooP7n00>ooP7n003o`000?ol0ocoo0?l00coo0?l0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ood2oOom0_d02_om0_d00ol0003ooP7nooh1oP08ooh1oP03o`000?om0_goo@;m00Koo@;m00?o0000
oo/4nook1?/03?ok1?/00ol0003omPWfooH9mP05ooH9mP03o`000?oh1oSon0Oh00kon0Oh00?o0000
oo`3o?ol0o`02_ol0o`2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@08ood2o@03o`000?on0OkooP7n
00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003on`Ckoo/4n`0=oo/4n`03o`000?of2OKomPWf
00ComPWf00?o0000ooP7n?oh1oP03_oh1oP00ol0003oo0?loo`3o008oo`3o0;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?om0_goo@;m00Ooo@;m00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?ok1?_on`Ck00gon`Ck00?o0000ooH9m_of
2OH00_of2OH00ol0003on0OhooP7n00?ooP7n003o`000?ol0ocoo0?l00Koo0?l0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ood2oOom0_d01_om0_d00ol0003ooP7nooh1oP09ooh1oP03o`000?om0_goo@;m00Soo@;m
00?o0000oo/4nook1?/03_ok1?/01?l0003omPWfooH9m_of2OH4o`0000kon0Oh00?o0000oo`3o?ol
0o`01?ol0o`2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo@;mood2o@04ood2o@03o`000?on0OkooP7n00[ooP7n
00?o0000ood2oOom0_d02?om0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?of2OKo000000Coo@;m
1_l00007ooP7n003o`000?ol0ocoo0?l00?oo0?l0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@03ood2o@03o`000?on
0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d3o`0000oon`Ck00?o0000ood2oOom0_d02Oom
0_d5o`0000;on0Oh00Co0000oo`3o?ol0ocoo0?l0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ood2oOom0_goo@;m
o`00000<ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ooh1o_on0Oh00ol0000<oo/4n`03o`00
0?om0_goo@;m00koo@;m0ol000000ool0oco0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ood2oOom0_goo@;m
o`00000<ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ooh1o_on0Oh01?on0Oh3o`0000Son`Ck
00?o0000ood2oOom0_d04_om0_d00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003oo@;mo`00000=ooh1oP03o`000?om
0_goo@;m00Woo@;m00?o0000ooh1o_on0Oh01oon0Oh3o`0000Con`Ck00?o0000ood2oOom0_d04oom
0_d00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d02Oom0_d0
0ol0003ooP7nooh1oP0;ooh1oP?o000000?on`Cko`000?om0_d05?om0_d00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ood2o@03o`000?on0OkooP7n00kooP7n00?o0000ood2oOom0_d05Oom0_d00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?on0OkooP7n
00oooP7n00?o0000ood2oOom0_d05Oom0_d00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
o@;mood2o@06ood2o@03o`000?on0OkooP7n00oooP7n00?o0000ood2oOom0_d05Oom0_d00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo@;mood2o@05ood2o@03o`000?on0OkooP7n00oo
oP7n00?o0000ood2oOom0_d05Oom0_d00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0@ooh1oP03o`000?om0_goo@;m01Koo@;m00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003oo@;mood2
o@02ood2o@03o`000?on0OkooP7n013ooP7n6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?om0_goo@;mo`0001?ooP7n00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo@;mo`00000Cooh1oP03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n017ooP7n00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh03?on0Oh6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003ooP7nooh1oP02ooh1oPWo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00__l00?l7oooo02;o003o1oooo`2Qo`00o`7ooooo002no`00o`;oool000?oMgN7o`00ool00?l0
:?l00?l00omgMhOoool0oooo002Qo`00o`7ooooo002no`00o`;oool0;?l00?l2oooo0:7o003o0Ooo
ool00;ko003o0_ooo`0/o`00o`;oool0XOl00?l1ooooo`00__l00?l2oooo02co003o0_ooo`2Qo`00
o`7ooooo002Uo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o00?o<S;<ojVYEOo^kQ000oooo`001?oMgB7oZJUEofIVV?l@4>h:o`00o`07ogMgQooMgB7oool0
oooo0?oMgB7oQhMgoa0@kP0:o`00o`;oool0XOl00?l1ooooo`00YOl00?l00onHV6Koool0ogMgQ`07
o`00o`03oiRHI_ooo`3oMgN700co003o0_ooo`07o`00o`Coool000Oo^[Y4ob4QgOl00?oo<S;<ojVY
EOooo`3oMgN700Oo003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?ooEEFYoooo0?oMgB7o413^2Ol0
0?l2oooo0:7o003o0Oooool00:Go003o00?ok^h@oooo0?oMgB401ol00?l00oo^kQ3oool0omgM8@0<
o`00o`;oool01ol00?l01?nj^TCoool0olc<<_m4A;X5o`00o`03ofIVV?ooo`3oZJUE00Ko003o00?o
gMdQoooo0?mgMhL01?l00?l00om4A;[oool0omgM8@09o`00o`;oool0XOl00?l1ooooo`00Y?l00?l0
1Olb</coool0oooo0?ooo`3o413^00Go003o00Go<S;<oooo0?ooo`3oool0ob4Qg@0;o`00o`;oool0
4Ol00?l00onYZEGoool0ojVYE@04o`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0
2?l00?l2oooo0:7o003o0Oooool00:Co003o00GoZJUEoooo0?ooo`3oool0ofIVV005o`00o`05oiRH
I_ooo`3oool0oooo0?mgMhL02ol00?l2oooo017o003o00Co<S;<oooo0?ooo`3oA4Bj0ol00?l2oooo
0003oiRHI_l00?oo003o00Co003o00?oQhMgoooo0?o^kQ002?l00?l2oooo0:7o003o0Oooool00:Co
003o0oooo`000omVIYSo^[Y4o`00o`04o`00o`05onk^4?ooo`3oool0ofIVV?oMgB402ol00?l2oooo
01;o003o0_ooo`001?nj^TCo003oo`00oomEEJT2oooo0003ofIVV?l00?oo003o00Co003o00CoEEFY
oooo0?ooo`3o<S;<1ol00?l2oooo0:7o003o0Oooool00:?o003o00OoEEFYoooo0?ooo`3ok^h@o`00
ooo^kQ3o413^00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o8B7M00[o003o0_ooo`0Bo`00
o`?oool00_l00?l01?nHV6Koool0oooo0?m4A;X6o`00o`04odA4^_ooo`3oool0ohN7M`Oo003o0_oo
o`2Qo`00o`7ooooo002So`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QVofIVV003o`00o`07ojVY
EOooo`3oool0oiRHI_l00?ooV9QVogMgQ`0:o`00o`;oool04Ol00?l01?mEEJWoool0oooo0?ooo`02
o`00o`04olc<<_ooo`3oool0oa0@kPOo003o0_ooo`000oo<c3;o003oo`00o`05o`00o`;oool0XOl0
0?l1ooooo`00Xol00?l3oooo0004ob4QgOl00?ooA4BjokZjA0?o003o0oooo`001?lb</co003oodA4
^_oMgB4:o`00o`;oool04Ol00?l01?nj^TCoool0oooo0?ooo`02o`00o`?oool02?l00?l2oooo0003
onk^4?l00?oo003o00Go003o0_ooo`2Qo`00o`7ooooo002Ro`00o`04oeEEZOooo`3oool0omgM8@?o
003o00Coool0o`00ool00?ooEEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0ob4Qg@Wo003o0_oo
o`0@o`00o`05ojVYEOooo`3oool0oooo0?nYZED00_l00?l3oooo00So003o0oooo`07o`00o`;oool0
XOl00?l1ooooo`00X_l00?l01?nYZEGoool0oooo0?mgMhL3o`00o`04ojVYEOmEEJWo003oojVYE@;o
ool000KoV9QVo`00ool00?oo003oojVYEOmgMhL9o`00o`;oool03_l00?l00olb</coc<`boooo0003
oooo0003ob4QgOl00?oo003o00?oool02?l00?l3oooo00Oo003o0_ooo`2Qo`00o`7ooooo002Ro`00
o`?oool000Oo8B7Mo`00ool00?oo003ooeEEZOnYZEGo003o00?oool000Ko<S;<o`00ool00?oo003o
oeEEZOoMgB49o`00o`;oool02ol00?l00om4A;[oMgN7omgM8@05oooo0004ofIVV?l00?oo003oo`00
o`?oool02?l00?l3oooo00Oo003o0_ooo`2Qo`00o`7ooooo002Qo`00o`04oeEEZOooo`3oool0omgM
8@Go003o00Gok^h@oeEEZOooo`3oool0onk^4005o`00o`03oooo0?lQ8Mgo003o00Oo003o0_ooo`08
o`00o`03oc8bc?ooo`3oool000Ooool000?oIVJHo`00ool00?l00_l00?l3oooo00So003o0oooo`07
o`00o`;oool0XOl00?l1ooooo`00XOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3o
ool0oooo0?n7QgL01Ol00?l00onYZEGoMgN7o`00o`07o`00o`;oool02?l00?l00olQ8Mgoool0oooo
0005oooo0003ojVYEOlQ8Mgo003o00Co003o00Coc<`boooo0?ooo`3o<S;<1_l00?l01?lQ8Mgoool0
oooo0?o<c387o`00o`;oool0XOl00?l1ooooo`00X?l00?l01Ol@4>koool0oooo0?ooo`3o8B7M00Go
003o00GoIVJHoooo0?ooo`3oool0ob4Qg@05o`00o`03oeEEZOoMgB7o003o00Oo003o0_ooo`09o`00
o`07ojVYEOooo`3ok^h@olc<<_n7QgOoEEFYoa0@kP07o`00o`04oiRHI_ooo`3oool0odA4^PKo003o
00CoA4Bjoooo0?ooo`3oV9QV1ol00?l2oooo0:7o003o0Oooool00:3o003o00CoIVJHoooo0?ooo`3o
gMdQ1_l00?l01?mVIYSoool0oooo0?oMgB47o`00o`03oooo0?lQ8Mgo003o00Ko003o0_ooo`09o`00
o`03ob4QgOo^kQ3o003o00_o003o00CoEEFYoooo0?ooo`3oMgN71_l00?l01?mVIYSoool0oooo0?mE
EJT7o`00o`;oool0XOl00?l1ooooo`00X?l00?l01?o<c3;oool0oooo0?mgMhL6o`00o`04okZjA?oo
o`3oool0ogMgQ`Oo003o00?oZJUEogMgQol00?l01_l00?l2oooo00[o003o00?oc<`boeEEZOl00?l0
2ol00?l2oooo0003ojVYEOl00?oo003o00Co003o00?oZJUEoooo0?o^kQ002?l00?l2oooo0:7o003o
0Oooool009oo003o00Go8B7Moooo0?ooo`3oool0ob4Qg@05o`00o`05oa0@k_ooo`3oool0oooo0?lQ
8Md01ol00?l00omEEJWogMdQo`00o`06o`00o`;oool02_l00?l00om4A;[oc<`bo`00o`0;o`00o`04
ohN7Moooo`3oool0oa0@kPCo003o00Co413^oooo0?ooo`3oIVJH2?l00?l2oooo0:7o003o0Oooool0
09oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oMgB49o`00o`03oooo0?lQ
8Mgo003o00Go003o0_ooo`0;o`00o`03olc<<_ooo`3oool000Goool000?oc<`bo`00ool00?l00ol0
0?l00ooMgB7oool0ohN7M`04o`00o`03ohN7Moooo`3oc<`b00Wo003o0_ooo`2Qo`00o`7ooooo002M
o`00o`03ob4QgOn7QgOoool000;oool000?ok^h@oc8bc?l00?l00ol00?l01_mEEJWoool0oooo0?oo
o`3ok^h@oc8bc0Ko003o00Ko8B7MohN7Moooo`3ok^h@oeEEZOl@4>h4o`00o`;oool02ol00?l00omV
IYSoool0oooo0006oooo0003ob4QgOl00?oo003o00;o003o00Co413^omgM8Oooo`3oMgN70_l@4>h0
1?mgMhOoool0omgM8Ol@4>h9o`00o`;oool0XOl00?l1ooooo`00W?l00?l00om4A;[oool0oooo0007
oooo0003ohN7Moooo`3oool000Ooool00_l00?l00on7QgOoool0oooo0005oooo0004odA4^_l00?oo
003oo`00o`;oool000?oMgN7o`00ool00?l02Ol00?l00oo^kQ3oool0oooo0005oooo0003ogMgQol0
0?oo003o00?o003o00?o413^ohN7MooMgB400_ooo`000ooMgB7oQhMgo`00o`09o`00o`03ogMgQooo
o`3oool00:7o003o0Oooool00;ko003o1oooo`0>o`00o`03ogMgQooMgB7o003o017o003o1oooo`2Q
o`00o`7ooooo003Do`00o`03ob4QgOl00?oo003o0;So003o0Oooool00?oo003oT?l00?l1ooooo`00
ool00?n@o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -43.7188 0 ]
[.5 1.04444 43.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -104.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(75) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
135.812 29.000 moveto
(D) show
146.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.995 .005 .995 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.992 .008 .992 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.991 .009 .991 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.982 .018 .982 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.955 .045 .955 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.991 .009 .991 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.985 .015 .985 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.984 .016 .984 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.987 .013 .987 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.994 .006 .994 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.978 .022 .978 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.991 .009 .991 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.962 .038 .962 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.994 .006 .994 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.992 .008 .992 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.988 .012 .988 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.977 .023 .977 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.994 .006 .994 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.979 .021 .979 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.967 .033 .967 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.876 .124 .876 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.891 .109 .891 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.998 .002 .998 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.992 .008 .992 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.966 .034 .966 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.967 .033 .967 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.912 .088 .912 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.889 .111 .889 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.793 .207 .793 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.961 .039 .961 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.983 .017 .983 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.984 .016 .984 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.96 .04 .96 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.854 .146 .854 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.994 .006 .994 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.993 .007 .993 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.924 .076 .924 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.792 .208 .792 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.923 .077 .923 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.617 .383 .617 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.613 .387 .613 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.754 .246 .754 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.87 .13 .87 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.896 .104 .896 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.699 .301 .699 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.66 .34 .66 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.985 .015 .985 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.731 .269 .731 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.846 .154 .846 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.958 .042 .958 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.981 .019 .981 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.788 .212 .788 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.934 .066 .934 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.568 .432 .568 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.949 .051 .949 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.853 .147 .853 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.477 .523 .477 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.539 .461 .539 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.543 .457 .543 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.481 .519 .481 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.963 .037 .963 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.746 .254 .746 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.452 .548 .452 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.493 .507 .493 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.932 .068 .932 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.558 .442 .558 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.713 .287 .713 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.529 .471 .529 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.412 .588 .412 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.442 .558 .442 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.395 .605 .395 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.591 .409 .591 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.71 .29 .71 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.986 .014 .986 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.775 .225 .775 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.862 .138 .862 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.425 .575 .425 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.39 .61 .39 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.399 .601 .399 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.433 .567 .433 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.45 .55 .45 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.893 .107 .893 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.966 .034 .966 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.987 .013 .987 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.728 .272 .728 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.432 .568 .432 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.911 .089 .911 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.515 .485 .515 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.638 .362 .638 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.471 .529 .471 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.547 .453 .547 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.964 .036 .964 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.605 .395 .605 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.445 .555 .445 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.993 .007 .993 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.966 .034 .966 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.975 .025 .975 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.598 .402 .598 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.408 .592 .408 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.387 .613 .387 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.811 .189 .811 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.87 .13 .87 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.47 .53 .47 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.52 .48 .52 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.716 .284 .716 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.906 .094 .906 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.47 .53 .47 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.425 .575 .425 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.512 .488 .512 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.603 .397 .603 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.988 .012 .988 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.682 .318 .682 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.754 .246 .754 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.642 .358 .642 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.552 .448 .552 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.971 .029 .971 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.983 .017 .983 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.955 .045 .955 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.516 .484 .516 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.685 .315 .685 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.793 .207 .793 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.934 .066 .934 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.991 .009 .991 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
.999 .001 .999 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.697 .303 .697 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.837 .163 .837 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.676 .324 .676 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.993 .007 .993 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.976 .024 .976 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.924 .076 .924 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.993 .007 .993 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.717 .283 .717 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.795 .205 .795 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.81 .19 .81 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.955 .045 .955 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.934 .066 .934 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.911 .089 .911 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.874 .126 .874 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.981 .019 .981 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.983 .017 .983 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.992 .008 .992 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.904 .096 .904 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.993 .007 .993 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.923 .077 .923 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.905 .095 .905 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.983 .017 .983 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.942 .058 .942 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.932 .068 .932 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.993 .007 .993 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.979 .021 .979 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.976 .024 .976 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.958 .042 .958 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.98 .02 .98 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.974 .026 .974 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.985 .015 .985 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.984 .016 .984 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.994 .006 .994 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.991 .009 .991 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.997 .003 .997 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.998 .002 .998 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.993 .007 .993 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.994 .006 .994 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000oof2OH00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooH9mP;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooH9mP03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Oof
2OH2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;omPWf00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooH9mP03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?of2OH2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ook1?/0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_of2OH00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ooh1o_on0OkooP7n1?l0000=oo/4n`03o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000KolPgbo`000?o^4Nko0000om`Sg?l0000JooH9mP;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?on0Oko000001;on`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?olPgb00Co0000onhAk_o^4Nko00000_oL8m`00ol0003omPWfooH9mP0IooH9
mP03o`000?on0Oko000001_on`Ck00?o0000oo/4nook1?/04_ok1?/00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005oo8=lP05o`000?o^4NkokQ7^onhA
k_l000000ooL8m`00ol0003omPWfooH9mP0IooH9mP03o`000?ok1?_on`Ck01[on`Ck00?o0000oo/4
nook1?/04ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?ob3O801Ol0003okQ7^onhAk_o^4Nko000000Cog2?L00?o0000ooH9
m_of2OH06?of2OH00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo/4n`?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[olPgb00?o0000onhAk_o^
4Nh00_o^4Nh00ol0003og2?Lom`Sg003om`Sg003o`000?of2OKomPWf01OomPWf00?o0000oo/4nook
1?/06Ook1?/00ol0003on`Ckoo/4n`0Foo/4n`05o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
n`Ck0_l0000:oo/4n`?o00003Oob3O800ol0003okQ7^onhAkP02onhAkP03o`000?oL8mcog2?L00Co
g2?L00?o0000ooH9m_of2OH05oof2OH00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?ok1?_on`Ck01Oo
n`Ck00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00Con`Ck0ol0000?oo8=lP03o`00
0?o^4NkokQ7^00?okQ7^00?o0000om`Sg?oL8m`01OoL8m`00ol0003omPWfooH9mP0FooH9mP03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000oo/4nook1?/06Ook1?/00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00ol0000Aoo8=lP03o`000?o^4NkokQ7^00CokQ7^00?o0000om`Sg?oL8m`01_oL
8m`2o`0001GomPWf0ol0000Hoo/4n`03o`000?ok1?_on`Ck01Won`Ck00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ok1?_on`Ck00gon`Ck0_l0000D
oo8=lP03o`000?o^4NkokQ7^00CokQ7^00?o0000om`Sg?oL8m`02?oL8m`00ol0003omPWfooH9mP0@
ooH9mP;o00000ooN8Mh00ol0003on`Ckoo/4n`0Doo/4n`03o`000?ok1?_on`Ck01[on`Ck00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo8=l_ob3O804_ob3O800ol0003okQ7^onhAkP05onhAkP03o`000?oL8mcog2?L
00Wog2?L00?o0000ooH9m_of2OH03Oof2OH2o`0000KogR7N0_l0000Doo/4n`03o`000?ok1?_on`Ck
01[on`Ck00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ob3O;olPgb01;olPgb00?o0000onhAk_o^
4Nh01Oo^4Nh00ol0003og2?Lom`Sg00:om`Sg003o`000?of2OKomPWf00[omPWf0_l0000:omhQgP03
o`000?ok1?_on`Ck017on`Ck00?o0000oo/4nook1?/06_ok1?/00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003olPgboo8=lP0@oo8=lP03o`000?o^4NkokQ7^00Ko
kQ7^00?o0000om`Sg?oL8m`02ooL8m`00ol0003omPWfooH9mP08ooH9mP03o`000?oN8MkogR7N00_o
gR7N0_l0000@oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003og2?Lom`Sg00<om`Sg003o`000?of2OKomPWf00GomPWf0_l0000@omhQgP03o`00
0?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/06ook1?/00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000onhAk_o^4Nh01oo^4Nh00ol0003og2?Lom`S
g00=om`Sg003o`000?of2OKomPWf00;omPWf0_l0000ComhQgP;o00003?ok1?/00ol0003on`Ckoo/4
n`0Loo/4n`?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ob3O;o
lPgb00kolPgb00?o0000onhAk_o^4Nh02?o^4Nh00ol0003og2?Lom`Sg00>om`Sg004o`000?of2OKo
0000o`0001OogR7N00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0Loo/4n`03o`000?oi
1_Won@Ki00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?ob3O;o
lPgb00colPgb00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003og2?Lom`Sg00?om`Sg003o`000?oN8Mko
gR7N01SogR7N0_l00009oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000ooT6nOoi1_T01?oi1_T4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck013on`Ck0_l0000>oo8=lP03o`000?o^4NkokQ7^
00WokQ7^00?o0000om`Sg?oL8m`03ooL8m`00ol0003ogR7NomhQgP0JomhQgP03o`000?ok1?_on`Ck
00Con`Ck0ol0000Loo/4n`03o`000?oi1_Won@Ki00Won@Ki0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003on`Ckoo/4n`0@oo/4n`04
o`000?o/4ncok1?/o`0000colPgb00?o0000onhAk_o^4Nh02_o^4Nh00ol0003og2?Lom`Sg00?om`S
g003o`000?oN8MkogR7N01_ogR7N0_l00003oo/4n`04o`000?o_4>ooka3_onl@k`?o00006?ok1?/0
0ol0003on@KiooT6n@0=ooT6n@?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?o/4ncok1?/
00;ok1?/00?o0000oo8=l_ob3O802Oob3O800ol0003okQ7^onhAkP0:onhAkP03o`000?oL8mcog2?L
00kog2?L00?o0000omhQg_oN8Mh07_oN8Mh00ol0003on`Cko`000007onl@k`?o00005?ok1?/00ol0
003on@KiooT6n@0AooT6n@;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003on`Ckoo/4n`0=oo/4n`;o00001_o/4n`00ol0003olPgboo8=lP07oo8=lP03
o`000?o^4NkokQ7^00_okQ7^00?o0000om`Sg?oL8m`03_oL8m`00ol0003ogR7NomhQgP0OomhQgP03
o`000?o_4>ooka3_00Woka3_0ol0000@oo/4n`03o`000?oi1_Won@Ki01?on@Ki00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo/4nook1?/03?ok1?/00ol0003ok1?/
on`Ck007on`Ck003o`000?ob3O;olPgb00GolPgb00?o0000onhAk_o^4Nh03?o^4Nh00ol0003og2?L
om`Sg00>om`Sg003o`000?oN8MkogR7N01oogR7N00?o0000onl@koo_4>l03?o_4>l3o`0000gon`Ck
00?o0000ooT6nOoi1_T05?oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo/4nook1?/02ook1?/2o`0000_ok1?/00?o0000oo8=l_ob3O801?ob
3O800ol0003okQ7^onhAkP0<onhAkP03o`000?oL8mcog2?L00kog2?L00?o0000omhQg_oN8Mh07_oN
8Mh00ol0003oka3_onl@k`0@onl@k`?o00002Ook1?/00ol0003on@KiooT6n@0FooT6n@Oo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ok
1?_on`Ck00[on`Ck00?o0000on`Ck?o/4n`03?o/4n`00ol0003olPgboo8=lP02oo8=lP03o`000?o^
4NkokQ7^00gokQ7^00?o0000om`Sg?oL8m`03_oL8m`00ol0003ogR7NomhQgP0NomhQgP03o`000?o_
4>ooka3_01?oka3_0ol00005oo/4n`03o`000?oi1_Won@Ki01Oon@Ki00?o0000oo/4nook1?/01?ok
1?/5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003on`Ckoo/4n`09oo/4n`03o`000?o/4ncok1?/00kok1?/00Go0000
oo8=l_ob3O;olPgbo`00000?onhAkP03o`000?oL8mcog2?L00gog2?L00?o0000omhQg_oN8Mh07ooN
8Mh00ol0003oka3_onl@k`0Fonl@k`?o000000?on`Cko`000?oi1_T06?oi1_T00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ok1?_o
n`Ck00Oon`Ck0_l0000Bon`Ck003o`000?ob3O;o0000013okQ7^00?o0000om`Sg?oL8m`02ooL8m`3
o`00023ogR7N00?o0000onl@koo_4>l06_o_4>l00ol0003on@KiooT6n@0HooT6n@03o`000?ok1?_o
n`Ck00Won`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003on`Ckoo/4n`07oo/4n`03o`000?o/4ncok1?/01?ok1?/00?o0000onhA
k_o^4Nh03oo^4Nh00ol0003og2?Lom`Sg007om`Sg0Co00000_njAKX00ol0003ogR7NomhQgP0NomhQ
gP03o`000?o_4>ooka3_01[oka3_00?o0000ooT6nOoi1_T05ooi1_T00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ok1?/2o`0001Ko
k1?/00?o0000onhAk_o^4Nh03oo^4Nh00ol0003og2?Lom`Sg003om`Sg0Co00001onjAKX00ol0003o
gR7NomhQgP0LomhQgP03o`000?o_4>ooka3_01coka3_00?o0000ooT6nOoi1_T05Ooi1_T00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?on`Ck00?o0000on`Ck?o/4n`05oo/4n`00ol0003okQ7^onhAkP0>onhAkP03o`00
0?oL8mco000000?o00003?njAKX00ol0003ogR7NomhQgP0KomhQgP03o`000?o_4>ooka3_01coka3_
00?o0000ooT6nOoi1_T05Ooi1_T00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo/4nol000006_o/
4n`5o`0000_okQ7^0ol0000AokY5^P03o`000?oN8MkogR7N01[ogR7N00?o0000onl@koo_4>l07Oo_
4>l00ol0003on@KiooT6n@0CooT6n@03o`000?ok1?_on`Ck00gon`Ck00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o/4ncok1?/01Wok1?/00?o0000
oki1__nn@Kh00_nn@Kh7o`0000?okQ7^00?o0000okY5^_njAKX04onjAKX3o`0001OogR7N0_l0000P
onl@k`03o`000?oi1_Won@Ki01?on@Ki00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000on`Ck?o/4n`06?o/4n`00ol0
003o_T6noki1_P0:oki1_P?o00005_njAKX00ol0003oVFJIoiUVV@05o`00013ogR7N0_l000000oo1
?/7o0000onl@k`0Oonl@k`03o`000?oi1_Won@Ki01;on@Ki00?o0000oo/4nook1?/03_ok1?/00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000on`Ck?o/4n`05_o/4n`00ol0003o_T6noki1_P0=oki1_P03
o`000?njAK[o^TFj01?o^TFj00?o0000oiUVVOnIIYT01_nIIYT4o`0000_ogR7N00?o0000ol4n`Oo1
?/400_o1?/400ol0003oka3_onl@k`0Nonl@k`03o`000?oi1_Won@Ki013on@Ki00?o0000oo/4nook
1?/03ook1?/00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ok1?/on`Ck00Don`Ck003o`000?nn@Kko_T6n00oo_T6n
00?o0000okY5^_njAKX04_njAKX00ol0003oVFJIoiUVV@0:oiUVV@Go00001?oN8Mh2o`0000Go`Ck1
00?o0000onl@koo_4>l07_o_4>l00ol0003on@KiooT6n@0@ooT6n@03o`000?ok1?_on`Ck00oon`Ck
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o/
4ncok1?/01Cok1?/00?o0000oki1__nn@Kh03onn@Kh00ol0003o^TFjokY5^P0BokY5^P03o`000?nI
IYWoVFJI00ooVFJI1?l00008ol4n`@03o`000?o_4>ooka3_01koka3_00?o0000ooT6nOoi1_T03_oi
1_T00ol0003on`Ckoo/4n`0@oo/4n`03o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oj1O[onPGj00konPGj00?o0000
on`Ck?o/4n`04_o/4n`00ol0003o_T6noki1_P0@oki1_P03o`000?njAK[o^TFj017o^TFj00?o0000
oiUVVOnIIYT04OnIIYT00ol0003oVVFJo`000009ol4n`@03o`000?o_4>ooka3_01goka3_00?o0000
ooT6nOoi1_T03_oi1_T00ol0003on`Ckoo/4n`0@oo/4n`03o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oj1O[onPGj
00oonPGj00?o0000on`Ck?o/4n`03_o/4n`3o`0001Co_T6n00?o0000okY5^_njAKX04?njAKX00ol0
003oVFJIoiUVV@0@oiUVV@04o`000?nJII[oVVFJo`0000Wo`Ck100?o0000onl@koo_4>l07_o_4>l0
0ol0003on@KiooT6n@0<ooT6n@03o`000?ok1?_on`Ck017on`Ck00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4
n`03o`000?oj1O[onPGj013onPGj00?o0000on`Ck?o/4n`02_o/4n`4o`0000;o`Ck100?o0000oki1
__nn@Kh04_nn@Kh00ol0003o^TFjokY5^P0@okY5^P03o`000?nIIYWoVFJI00ooVFJI00Go0000oiYU
V_nJII[oVVFJo`00000:ol4n`@03o`000?o_4>ooka3_01goka3_00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oj1O[onPGj017onPGj00?o0000on`C
k?o/4n`01Oo/4n`4o`0000Oo`Ck100?o0000oki1__nn@Kh04Onn@Kh00ol0003o^TFjokY5^P0?okY5
^P03o`000?nIIYWoVFJI013oVFJI00Go0000oiYUV_nJII[oVVFJo`00000:ol4n`@03o`000?o_4>oo
ka3_01goka3_00?o0000ooT6nOoi1_T02ooi1_T00ol0003on`Ckoo/4n`0Coo/4n`04o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo/4nook1?/03?ok1?/00ol0003onPGjooX5nP0BooX5nP03o`000?o/4nco
k1?/00Co00002oo1?/400ol0003o_T6noki1_P0Boki1_P03o`000?njAK[o^TFj00ko^TFj00?o0000
oiUVVOnIIYT03onIIYT00ol0003oVVFJoiYUVP02oiYUVP03o`000?o1?/7o`Ck100Wo`Ck100?o0000
onl@koo_4>l07?o_4>l3o`0000[on@Ki00?o0000oo/4nook1?/05?ok1?/01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?oj1O[o
nPGj01;onPGj00Co0000onTFjOl0003o00003oo1?/400ol0003o_T6noki1_P0Aoki1_P03o`000?n7
N8Oo000000oo^TFj00?o0000oiUVVOnIIYT03_nIIYT00ol0003oVVFJoiYUVP03oiYUVP03o`000?o1
?/7o`Ck100Wo`Ck100?o0000onl@koo_4>l06Oo_4>l3o`0000?ok1?/00?o0000ooT6nOoi1_T01ooi
1_T00ol0003on`Ckoo/4n`0Coo/4n`Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo/4nook1?/02ook1?/00ol0003onPGjooX5nP0AooX5nP04o`000?oY5^WojAKYo`00017o`Ck100?o
0000oki1__nn@Kh03onn@Kh01Ol0003oQgR7ohMhQon7N8Oo000000[o^TFj1?l0000AoiUVV@03o`00
0?nJII[oVVFJ00?oVVFJ00?o0000ol4n`Oo1?/402_o1?/400ol0003oka3_onl@k`0Fonl@k`;o0000
1oo/4n`00ol0003on@KiooT6n@05ooT6n@03o`000?ok1?_on`Ck01?on`Ck00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000con`Ck00?o
0000ooX5n_oj1OX04?oj1OX00ol0003ojAKYonTFj@02onTFj@03o`000?o1?/7o`Ck100ko`Ck100?o
0000oki1__nn@Kh03_nn@Kh00ol0003oQgR7ohMhQ`03ohMhQ`04o`000?njAK[o^TFjokY5^PKo0000
0on3O8<00ol0003oVFJIoiUVV@0>oiUVV@03o`000?nJII[oVVFJ00CoVVFJ00?o0000ol4n`Oo1?/40
2_o1?/400ol0003oka3_onl@k`0Conl@k`?o00002_o/4n`00ol0003on@KiooT6n@03ooT6n@03o`00
0?ok1?_on`Ck01?on`Ck00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?oo@;m00?o0000oo/4nook1?/02?ok1?/00ol0003onPGjooX5nP0@ooX5nP03o`000?oY
5^WojAKY00?ojAKY00?o0000ol4n`Oo1?/403_o1?/400ol0003o_T6noki1_P0=oki1_P03o`000?n7
N8OoQgR700GoQgR70ol0000:oh=lP`03o`000?nIIYWoVFJI00coVFJI00?o0000oiYUV_nJIIX01OnJ
IIX00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?o_4>ooka3_013oka3_0_l0000>on`Ck003o`000?oi
1_Won@Ki00;on@Ki00?o0000oo/4nook1?/04_ok1?/00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000Ooo@;m00?o0000oo/4nook1?/01ook1?/00ol0003onPGjooX5nP0?
ooX5nP03o`000?oY5^WojAKY00CojAKY00?o0000ol4n`Oo1?/403oo1?/400ol0003o_T6noki1_P0;
oki1_P03o`000?n7N8OoQgR700KoQgR700?o0000oh=lPon3O8<02on3O8<00ol0003oVFJIoiUVV@0;
oiUVV@03o`000?nJII[oVVFJ00GoVVFJ00?o0000ol4n`Oo1?/403?o1?/400ol0003oka3_onl@k`0<
onl@k`?o00004Oo/4n`5o`0001;on`Ck0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo@;mood2o@09ood2o@;o00001ook1?/00ol0003onPGjooX5nP0>ooX5nP03o`000?oY5^WojAKY
00KojAKY00?o0000ol4n`Oo1?/403_o1?/400ol0003o_T6noki1_P0:oki1_P03o`000?n7N8OoQgR7
00OoQgR700?o0000oh=lPon3O8<02on3O8<00ol0003oVFJIoiUVV@0:oiUVV@03o`000?nJII[oVVFJ
00KoVVFJ00?o0000ol4n`Oo1?/403?o1?/400ol0003oka3_onl@k`0:onl@k`;o00005?o/4n`00ol0
003onPGjooX5nP02ooX5nP;o00003ook1?/00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@0<ood2
o@03o`000?ok1?_on`Ck00?on`Ck00?o0000ooX5n_oj1OX03_oj1OX00ol0003ojAKYonTFj@07onTF
j@03o`000?o1?/7o`Ck100ko`Ck100?o0000oki1__nn@Kh02Onn@Kh00ol0003oQgR7ohMhQ`08ohMh
Q`03o`000?n3O8?oPgb300coPgb300?o0000oiUVVOnIIYT02?nIIYT00ol0003oVVFJoiYUVP07oiYU
VP03o`000?o1?/7o`Ck100go`Ck11Ol00004onl@k`?o00005Oo/4n`00ol0003onPGjooX5nP05ooX5
nP03o`000?ok1?_on`Ck00_on`Ck00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d03_om0_d2o`0000?on`Ck00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojAKYonTFj@08onTF
j@03o`000?o1?/7o`Ck100oo`Ck100?o0000oki1__nn@Kh01onn@Kh00ol0003oQgR7ohMhQ`09ohMh
Q`03o`000?n3O8?oPgb300coPgb30ol00008oiUVV@03o`000?nJII[oVVFJ00OoVVFJ00?o0000ol4n
`Oo1?/403Oo1?/400ol0003occ3?oll`c`02oll`c`Co00006?o/4n`00ol0003onPGjooX5nP06ooX5
nP;o00002Ook1?/2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ood2oOom0_d04Oom0_d01?l0003on`Ckoo/4nol0000>ooX5nP03o`000?oY5^WojAKY
00[ojAKY00?o0000ol4n`Oo1?/403_o1?/400ol0003o_T6noki1_P06oki1_P03o`000?n7N8OoQgR7
00[oQgR700?o0000oh=lPon3O8<02_n3O8<2o`0000?oN8Mh00?o0000oiUVVOnIIYT01?nIIYT00ol0
003oVVFJoiYUVP08oiYUVP03o`000?o1?/7o`Ck100co`Ck100?o0000oll`coo?<<l01_o?<<l00ol0
003ok1?/on`Ck00Eon`Ck003o`000?oj1O[onPGj00WonPGj0_l00006oo/4n`03o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ood2oOom0_d04oom0_d2o`0000konPGj00?o0000onTFjOoY5^T02ooY5^T00ol0003o
`Ck1ol4n`@0>ol4n`@03o`000?nn@Kko_T6n00Go_T6n00?o0000ohMhQon7N8L02on7N8L00ol0003o
Pgb3oh=lP`08oh=lP`;o00001_mhQgP00ol0003oVFJIoiUVV@02oiUVV@03o`000?nJII[oVVFJ00Wo
VVFJ00?o0000ol4n`Oo1?/403?o1?/400ol0003occ3?oll`c`07oll`c`03o`000?o/4ncok1?/01Co
k1?/00?o0000ooX5n_oj1OX02ooj1OX00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ood2oOom0_d05Oom0_d00ol0003onPGjooX5nP0;ooX5nP03o`00
0?oY5^WojAKY00gojAKY00?o0000ol4n`Oo1?/403_o1?/400ol0003o_T6noki1_P03oki1_P03o`00
0?n7N8OoQgR700coQgR700?o0000oh=lPon3O8<01_n3O8<2o`0000WoN8Mh00Go0000oiUVVOnIIYWo
VFJIo`00000;oiYUVP03o`000?o1?/7o`Ck100co`Ck100?o0000oll`coo?<<l01oo?<<l00ol0003o
k1?/on`Ck00Con`Ck003o`000?oj1O[onPGj00gonPGj0_l000000ook1?_o0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`000?oY5^WojAKY00ko
jAKY00?o0000ol4n`Oo1?/403_o1?/400ol0003o_T6noki1_P02oki1_P03o`000?n7N8OoQgR700go
QgR700?o0000oh=lPon3O8<01?n3O8<2o`0000coN8Mh00?o0000oiUVVOl000003?nJIIX00ol0003o
`Ck1ol4n`@0;ol4n`@03o`000?o?<<oocc3?00Wocc3?00?o0000on`Ck?o/4n`04Oo/4n`00ol0003o
nPGjooX5nP0@ooX5nP03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001Woo@;m00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003ojAKYonTFj@0?onTFj@03o`000?o1?/7o`Ck100ko`Ck100Go0000oki1__nn@Kko
_T6no`00000@ohMhQ`03o`000?n3O8?oPgb300;oPgb30_l0000?ogR7N003o`000?nJII[oVVFJ00_o
VVFJ00?o0000ol4n`Oo1?/402oo1?/400ol0003occ3?oll`c`09oll`c`03o`000?o/4ncok1?/017o
k1?/00?o0000ooX5n_oj1OX04?oj1OX2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ood2oOom0_d05_om0_d3o`0000OonPGj00?o0000onTFjOoY5^T04OoY5^T00ol0003o`Ck1
ol4n`@0>ol4n`@Co00004?n7N8L00ol0003oPgb3oh=lP`02o`00017oN8Mh00?o0000oiYUV_nJIIX0
2onJIIX00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o?<<oocc3?00_occ3?00?o0000on`Ck?o/4n`0
3oo/4n`00ol0003onPGjooX5nP0AooX5nP03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003oo@;mood2o@0Cood2o@;o00000ook1?/00ol0003onPGjooX5nP03ooX5nP03o`000?oY
5^WojAKY01;ojAKY00?o0000ol4n`Oo1?/403Oo1?/400ol0003oRgB;oh]dR`02oh]dR`;o00003_n7
N8L3o`0001?oN8Mh00?o0000oiYUV_nJIIX02onJIIX00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o?
<<oocc3?00_occ3?00?o0000on`Ck?o/4n`03oo/4n`00ol0003onPGjooX5nP0AooX5nP03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0A
ood2o@03o`000?ok1?_on`Ck00Con`Ck00Go0000ooX5n_oj1O[onPGjo`00000EonTFj@03o`000?o1
?/7o`Ck100co`Ck100?o0000oh]dRon;M8/01On;M8/2o`0000coQgR700?o0000ogR7N?mhQgP05?mh
QgP00ol0003oVVFJoiYUVP0:oiYUVP03o`000?o1?/7o`Ck100[o`Ck100?o0000oll`coo?<<l03?o?
<<l00ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj01;onPGj00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d03_om0_d2o`0000Son`Ck00?o0000
ooX5n_l000005ooY5^T00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?n;M8_oRgB;00SoRgB;00?o0000
ohMhQon7N8L02?n7N8L3o`0001GoN8Mh0_l0000;oiYUVP03o`000?o1?/7o`Ck100Wo`Ck100?o0000
oll`coo?<<l03_o?<<l00ol0003ok1?/on`Ck00<on`Ck003o`000?oj1O[onPGj01;onPGj00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?om0_d2o`00
00_on`Ck00?o0000onTFjOoY5^T05_oY5^T00ol0003o`Ck1ol4n`@09ol4n`@03o`000?n;M8_oRgB;
00[oRgB;0_l00005ohMhQ`?o00000om/Tf`00ol0003oN8MhogR7N00AogR7N003o`000?mhQgSoN8Mh
00;o00002OnJIIX00ol0003o`Ck1ol4n`@09ol4n`@03o`000?o?<<oocc3?00kocc3?00?o0000on`C
k?o/4n`02oo/4n`00ol0003onPGjooX5nP0CooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Ooo@;m0_l0000=oo/4n`03o`000?oY5^WojAKY01Ko
jAKY00?o0000ol4n`Oo1?/400oo1?/46o`0000ooRgB;0_l000000on7N8Oo0000o`000007ofbCK0;o
00004?mhQgP00ol0003oN8MhogR7N003ogR7N0?o00001_nJIIX00ol0003o`Ck1ol4n`@09ol4n`@03
o`000?o?<<oocc3?00oocc3?00?o0000on`Ck?o/4n`02_o/4n`00ol0003onPGjooX5nP0CooX5nP03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@04ood2o@;o00004?ok1?/00ol0003ojAKY
onTFj@0FonTFj@Go00001OnbCK800ol0003oRgB;oh]dR`0?oh]dR`03o`000?m/TfcoK9=/00WoK9=/
00?o0000ogR7N?mhQgP03?mhQgP00ol0003oN8MhogR7N007ogR7N0;o00000_nJIIX>o`0001;occ3?
00?o0000on`Ck?o/4n`02Oo/4n`00ol0003onPGjooX5nP0DooX5nP03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo@;mood2o@02ood2o@03o`000?ok1?_on`Ck013on`Ck00?o0000onTFjOoY5^T05OoY
5^T00ol0003o/Tfbok9=/P09ok9=/P03o`000?n;M8_oRgB;00koRgB;00?o0000ofbCK?m/Tf`02_m/
Tf`2o`0000_oN8Mh00?o0000ogR7N?mhQgP02_mhQgP2o`0000goY5^T00?o0000oll`coo?<<l04Oo?
<<l00ol0003ok1?/on`Ck007on`Ck003o`000?oj1O[onPGj01GonPGj0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ood2oOl0003o00005?ok1?/00ol0003ojAKYonTFj@0ConTFj@03o`000?nbCK;o/Tfb00[o/Tfb00?o
0000oh]dRon;M8/03_n;M8/00ol0003oK9=/ofbCK00<ofbCK003o`000?mhQgSoN8Mh00OoN8Mh00?o
0000ogR7N?mhQgP02omhQgP00ol0003oY5^TojAKY00=ojAKY003o`000?o?<<oocc3?013occ3?00?o
0000on`Ck?o/4n`01oo/4n`00ol0003onPGjooX5nP0EooX5nP04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?oY5^WojAKY01;ojAKY00?o0000ok9=/_nbCK802onb
CK800ol0003oRgB;oh]dR`0>oh]dR`03o`000?m/TfcoK9=/00goK9=/00?o0000ogR7N?mhQgP01?mh
QgP2o`0000koN8Mh00?o0000ojAKY?nTFj@03OnTFj@00ol0003occ3?oll`c`0@oll`c`Co00001Oo/
4n`00ol0003onPGjooX5nP0FooX5nP04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok
1?_on`Ck01Gon`Ck5?l0000?ok9=/P03o`000?n;M8_oRgB;00coRgB;00?o0000ofVFJOl000003om/
Tf`2o`0000?oN8Mh00Co0000ofRGJ?mXUfSo00003OmhQgP00ol0003oY5^TojAKY00>ojAKY003o`00
0?o?<<oocc3?00cocc3?0ol00004omlPg`?o00000_o/4n`00ol0003onPGjooX5nP0FooX5nP03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo/4nook1?/05Ook1?/00ol0003ohacSon<L
h`0@on<Lh`03o`000?nbCK;o/Tfb00go/Tfb00?o0000oh]dRon;M8/02on;M8/01?l0003oJIIYofVF
JOl0000AofbCK003o`000?mhQgSo000000CoJ9MX00?o0000ogR7N?mhQgP02_mhQgP00ol0003oY5^T
ojAKY00>ojAKY003o`000?o?<<oocc3?00Wocc3?0ol0000:omlPg`;o00006?oj1OX00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?oS7>?ohacS013ohacS00?o0000ok9=/_nbCK803Onb
CK800ol0003oRgB;oh]dR`0:oh]dR`03o`000?mYUVWoJIIY00;oJIIY00?o0000ofbCK?m/Tf`03om/
Tf`00ol0003oJ9MXofRGJ004ofRGJ003o`000?mhQgSoN8Mh00WoN8Mh00?o0000ojAKY?nTFj@03_nT
Fj@00ol0003occ3?oll`c`06oll`c`?o00003_oO8=l00ol0003onPGjooX5nP0FooX5nP03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ok1?_on`Ck01Gon`Ck00?o0000
on<LhooS7><04_oS7><00ol0003o/Tfbok9=/P0=ok9=/P03o`000?n;M8_oRgB;00WoRgB;00?o0000
ofVFJOmYUVT00_mYUVT00ol0003oK9=/ofbCK00?ofbCK003o`000?mXUfSoJ9MX00GoJ9MX00?o0000
ogR7N?mhQgP02?mhQgP00ol0003oY5^TojAKY00?ojAKY003o`000?o?<<oocc3?00;occ3?0ol0000B
omlPg`03o`000?oj1O[onPGj01GonPGj00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003on`Ckoo/4n`0Coo/4n`?o00005?oS7><00ol0003o/Tfbok9=/P0=ok9=/P03o`000?n;M8_oRgB;
00SoRgB;00?o0000ofVFJOmYUVT01?mYUVT00ol0003oK9=/ofbCK00>ofbCK003o`000?mXUfSoJ9MX
00KoJ9MX00?o0000ogR7N?mhQgP01omhQgP00ol0003oY5^TojAKY00?ojAKY003o`000?o?<<oo0000
00;o00005OoO8=l00ol0003onPGjooX5nP0EooX5nP03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ok1?_on`Ck00oon`Ck1?l00002oo@;m003o`000?oS7>?ohacS01;o
hacS00?o0000ok9=/_nbCK803OnbCK800ol0003oRgB;oh]dR`07oh]dR`03o`000?mYUVWoJIIY00Go
JIIY00?o0000ofbCK?m/Tf`03Om/Tf`00ol0003oJ9MXofRGJ008ofRGJ003o`000?mhQgSoN8Mh00Ko
N8Mh00?o0000ojAKY?nTFj@04?nTFj@00ol0003ogb3OomlPg`0FomlPg`03o`000?oj1O[onPGj01Go
nPGj00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/02ook1?/4o`0000Kom0_d
00?o0000on<LhooS7><04ooS7><00ol0003o/Tfbok9=/P0=ok9=/P03o`000?n;M8_oRgB;00GoRgB;
00?o0000ofVFJOmYUVT01omYUVT00ol0003oK9=/ofbCK00<ofbCK003o`000?mXUfSoJ9MX00WoJ9MX
00?o0000ogR7N?mhQgP01OmhQgP00ol0003oY5^TojAKY00@ojAKY003o`000?oO8=oogb3O01Oogb3O
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/01ook
1?/4o`0000[om0_d00?o0000on<LhooS7><04ooS7><00ol0003o/Tfbok9=/P0=ok9=/P03o`000?n;
M8_oRgB;00CoRgB;00?o0000ofVFJOmYUVT02?mYUVT00ol0003oK9=/ofbCK00<ofbCK003o`000?mX
UfSoJ9MX00[oJ9MX00?o0000ogR7N?mhQgP01?mhQgP00ol0003oY5^TojAKY00@ojAKY003o`000?oO
8=oogb3O01Oogb3O00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003on`Ckoo/4n`04oo/4n`Co00003_od2o@00ol0003ohacSon<Lh`0Con<Lh`03o`000?nbCK;o
/Tfb00go/Tfb00?o0000oh]dRon;M8/01?n;M8/00ol0003oJIIYofVFJ@09ofVFJ@03o`000?m/Tfco
K9=/00_oK9=/00?o0000ofRGJ?mXUfP02omXUfP00ol0003oN8MhogR7N003ogR7N003o`000?nTFjCo
Y5^T013oY5^T00?o0000omlPgooO8=l05ooO8=l00ol0003onPGjooX5nP0CooX5nP03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`04o`0001;om0_d00?o0000on<LhooS7><04ooS7><00ol0
003o/Tfbok9=/P0>ok9=/P03o`000?n;M8_oRgB;00;oRgB;00?o0000ofVFJOmYUVT02_mYUVT00ol0
003oK9=/ofbCK00:ofbCK003o`000?mXUfSoJ9MX00goJ9MX00?o0000ogR7N?mhQgP00_mhQgP00ol0
003oY5^TojAKY00@ojAKY003o`000?oO8=oogb3O01Sogb3O00?o0000ooX5n_oj1OX04_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000Goo@;m003
o`000?oS7>?ohacS01?ohacS00?o0000ok9=/_nbCK803?nbCK84o`000003oh]dRol0003oJIIY00go
JIIY00?o0000ofbCK?m/Tf`02Om/Tf`00ol0003oJ9MXofRGJ00>ofRGJ005o`000?mhQgSoN8MhogR7
N?l000004_nTFj@00ol0003ogb3OomlPg`0HomlPg`?o00004_oj1OX00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003om0_doo@;m00Foo@;m003o`000?oS7>?ohacS
01?ohacS00?o0000ok9=/_nbCK802onbCK800ol0003oNXEjogZ5NP02ogZ5NP;o00003_mYUVT00ol0
003oK9=/ofbCK009ofbCK003o`000?mXUfSoJ9MX00ooJ9MX00Co0000ogR7N?mhQgSo00004_nTFj@0
0ol0003ogb3OomlPg`0HomlPg`03o`000?o^4NkokQ7^00?o00003ooj1OX5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?od2oCom0_d01Gom0_d00?o0000on<LhooS7><04ooS7><00ol0003o/Tfbok9=/P0:
ok9=/P03o`000?mjQG[oNXEj00GoNXEj00?o0000ofVFJOmYUVT03?mYUVT00ol0003oK9=/ofbCK008
ofbCK003o`000?mXUfSoJ9MX00ooJ9MX1Ol0000AojAKY003o`000?oO8=oogb3O01Oogb3O00?o0000
onhAk_o^4Nh01?o^4Nh3o`0000conPGj00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003om0_doo@;m00Doo@;m003o`000?oS7>?ohacS01?ohacS00?o0000ok9=/_nbCK802?nbCK82o`00
00WoNXEj00?o0000ofVFJOmYUVT02omYUVT00ol0003oK9=/ofbCK007ofbCK003o`000?mXUfSoJ9MX
00goJ9MX0ol00005ogR7N003o`000?nTFjCoY5^T00koY5^T00?o0000omlPgooO8=l05_oO8=l00ol0
003okQ7^onhAkP08onhAkP?o00002?oj1OX00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?od2oCom0_d01?om0_d0_l0000Eon<Lh`03o`000?nbCK;o/Tfb00Ko/Tfb00?o0000ogZ5N_mj
QGX02_mjQGX00ol0003oJIIYofVFJ@0:ofVFJA[o00002OmhQgP00ol0003oY5^TojAKY00<ojAKY0?o
00005_oO8=l00ol0003okQ7^onhAkP0<onhAkP?o00001?oj1OX00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003om0_d
oo@;m00@oo@;m0;o00000_oP7n03o`0001;ohacS00?o0000ok9=/_nbCK801?nbCK82o`0000koNXEj
00?o0000ofVFJOmYUVT01omYUVT2o`0000[oHiaS00?o0000of>LHomSW6<03?mSW6<00ol0003oN8Mh
ogR7N008ogR7N0;o00002_nTFj@2o`0000?o[E:]0_l0000ComlPg`03o`000?o^4NkokQ7^013okQ7^
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000oo@;m?od2o@03_od2o@00ol0003omPWfo`000005on0Oh0;o00004?oS
7><00ol0003o/Tfbok9=/P03ok9=/P03o`000?mjQG[oNXEj00ooNXEj00?o0000ofVFJOmYUVT01?mY
UVT2o`0000coHiaS00?o0000of>LHomSW6<03?mSW6<00ol0003oN8MhogR7N00:ogR7N003o`000?nT
FjCoY5^T00GoY5^T0_l00007ojeB[@03o`000?oO8=oogb3O00oogb3O00?o0000onhAk_o^4Nh04Oo^
4Nh01?l0003on@KiooT6nOl0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@02ood2o@2o`0000;omPWf00?o
0000on0Oh?oP7n001OoP7n02o`0000oohacS00Go0000ok9=/_nbCK;o/Tfbo`00000CogZ5NP03o`00
0?mYUVWoJIIY00;oJIIY00?o0000of>LHomSW6<03OmSW6<00ol0003oHiaSof>LH`0;of>LH`03o`00
0?mhQgSoN8Mh00_oN8Mh00?o0000ojAKY?nTFj@00_nTFj@2o`0000[o[E:]0_l0000>omlPg`03o`00
0?o^4NkokQ7^017okQ7^00Go0000ooT6nOoi1_Won@Kio`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003om0_doo@;m009oo@;m003o`00
0?of2OKomPWf00?omPWf00?o0000on0Oh?oP7n001_oP7n03o`0000_ohacS1Ol0000EogZ5NP04o`00
0?mYUVWo0000o`00013oHiaS00?o0000of>LHomSW6<02omSW6<00ol0003oN8MhogR7N00<ogR7N004
o`000?nTFjCo0000o`0000ko[E:]0_l0000;omlPg`03o`000?o^4NkokQ7^017okQ7^00?o0000ooT6
nOoi1_T00ooi1_T00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Kom0_d0_l00006ooH9mP03
o`000?oP7n3oh1oP00Woh1oP0_l00008on<Lh`03o`000?nXEjSoZ5NX00;oZ5NX00?o0000ogZ5N_mj
QGX05?mjQGX00ol0003oHiaSof>LH`0@of>LH`03o`000?mSW6?oHiaS00_oHiaS00?o0000ogR7N?mh
QgP03OmhQgP00ol0003o[E:]ojeB[@0@ojeB[@03o`000?oO8=oogb3O00Oogb3O00?o0000onhAk_o^
4Nh04Oo^4Nh00ol0003on@KiooT6n@04ooT6n@03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000oo@;m?od2o@01?od2o@00ol0003omPWfooH9mP06ooH9mP03o`000?oP7n3oh1oP00_oh1oP
0_l00005on<Lh`03o`000?nXEjSoZ5NX00CoZ5NX00?o0000ogZ5N_mjQGX04omjQGX00ol0003oHiaS
of>LH`0@of>LH`03o`000?mSW6?oHiaS00_oHiaS00?o0000ogR7N?mhQgP03OmhQgP00ol0003o[E:]
ojeB[@0AojeB[@;o00000ooO8=l4o`0001?okQ7^00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000oo@;m?od2oCom0_d0_l00009ooH9mP03
o`000?oP7n3oh1oP00goh1oP0ol000000ooS7>?o0000ojQGZ007ojQGZ003o`000?mjQG[oNXEj01;o
NXEj00?o0000of>LHomSW6<04?mSW6<00ol0003oHiaSof>LH`0;of>LH`03o`000?mhQgSoN8Mh00go
N8Mh00?o0000ojeB[On]DZd04on]DZd3o`0000?oiaSW00?o0000onhAk_o^4Nh04?o^4Nh00ol0003o
n@KiooT6n@07ooT6n@03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003om0_do`00000;ooH9mP03o`000?oP7n3oh1oP013oh1oP00?o0000ojQGZ?nXEjP0
2?nXEjP00ol0003oNXEjogZ5NP0AogZ5NP03o`000?mSW6?oHiaS017oHiaS00?o0000of>LHomSW6<0
2_mSW6<00ol0003oN8MhogR7N00<ogR7N003o`000?n4NhCo000001Co[E:]00?o0000onLHiooW6>L0
1?oW6>L00ol0003okQ7^onhAkP0>onhAkP03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?of2OKomPWf00_omPWf00?o0000on0Oh?oP7n003ooP
7n000ol0003oZ5NXojQGZ009ojQGZ003o`000?mjQG[oNXEj013oNXEj00?o0000of>LHomSW6<04OmS
W6<00ol0003oHiaSof>LH`0:of>LH`03o`000?mhQgSoN8Mh00_oN8Mh00Co0000ohAkQ?n4NhCo0000
5?n]DZd00ol0003oiaSWonLHi`05onLHi`03o`000?o^4NkokQ7^00cokQ7^00?o0000ooT6nOoi1_T0
2Ooi1_T00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oof2OH00ol0003oh1oPon0O
h00?on0Oh003o`000?nXEjSoZ5NX00[oZ5NX00?o0000ogZ5N_mjQGX03_mjQGX00ol0003oIIYUo`00
000Bof>LH`03o`000?mSW6?oHiaS00[oHiaS00?o0000ogR7N?mhQgP02_mhQgP00ol0003oQ7^4ohAk
Q002ohAkQ003o`000?n]DZgo[E:]013o[E:]00?o0000onLHiooW6>L01ooW6>L00ol0003okQ7^onhA
kP0:onhAkP03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooH9mP03o`000?oP7n3oh1oP00ooh1oP00?o0000ojQGZ?nXEjP0
2onXEjP00ol0003oNXEjogZ5NP0<ogZ5NP05o`000?mUVVGoIIYUofFJIOl000004OmSW6<00ol0003o
HiaSof>LH`0:of>LH`03o`000?mhQgSoN8Mh00WoN8Mh00?o0000ohAkQ?n4Nh@00on4Nh@00ol0003o
[E:]ojeB[@0@ojeB[@03o`000?oW6>OoiaSW00SoiaSW00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o
n@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?of2OKomPWf00WomPWf00?o0000on0Oh?oP7n003_oP7n000ol0003oZ5NXojQGZ00=ojQGZ003o`00
0?mjQG[oNXEj00[oNXEj00?o0000ofFJIOmUVVD00omUVVD00ol0003oHiaSof>LH`0?of>LH`03o`00
0?mSW6?oHiaS00WoHiaS00?o0000ogR7N?mhQgP02?mhQgP00ol0003oQ7^4ohAkQ005ohAkQ003o`00
0?n]DZgo[E:]00oo[E:]00?o0000onLHiooW6>L02OoW6>L00ol0003okQ7^onhAkP06onhAkP03o`00
0?oi1_Won@Ki00gon@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooH9m_of2OH02?of2OH00ol0003oh1oPon0Oh00>on0Oh003o`000?nX
EjSoZ5NX00koZ5NX00?o0000ogZ5N_mjQGX02?mjQGX00ol0003oIIYUofFJI@05ofFJI@03o`000?mS
W6?oHiaS00koHiaS00?o0000of>LHomSW6<02OmSW6<00ol0003oN8MhogR7N007ogR7N003o`000?n4
NhCoQ7^400KoQ7^400?o0000ojeB[On]DZd03on]DZd00ol0003oiaSWonLHi`09onLHi`03o`000?o^
4NkokQ7^00GokQ7^00?o0000ooT6nOoi1_T03_oi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003oh1oPon0Oh00=
on0Oh003o`000?nXEjSoZ5NX00ooZ5NX00?o0000ogZ5N_mjQGX01_mjQGX00ol0003oIIYUofFJI@07
ofFJI@03o`000?mSW6?oHiaS00goHiaS00?o0000of>LHomSW6<02OmSW6<00ol0003oN8MhogR7N004
ogR7N0?o00002_n4Nh@00ol0003o[E:]ojeB[@0=ojeB[@03o`000?oW6>OoiaSW00_oiaSW00?o0000
onhAk_o^4Nh00oo^4Nh00ol0003on@KiooT6n@0@ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003omPWfooH9mP08ooH9mP03o`000?oP7n3oh1oP
00goh1oP00?o0000ojQGZ?nXEjP04?nXEjP00ol0003oNXEjogZ5NP05ogZ5NP03o`000?mUVVGoIIYU
00SoIIYU00?o0000of>LHomSW6<03?mSW6<00ol0003oHiaSof>LH`09of>LH`03o`000?mhQgSo0000
00Co00000_m/Tf`00ol0003oQ7^4ohAkQ008ohAkQ003o`000?n]DZgo[E:]00go[E:]00?o0000onLH
iooW6>L03?oW6>L01Ol0003okQ7^onhAk_o^4Nko000001;on@Ki0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?of2OKomPWf00OomPWf00?o0000on0Oh?oP7n003OoP7n000ol0
003oZ5NXojQGZ00AojQGZ003o`000?mjQG[oNXEj00?oNXEj00?o0000ofFJIOmUVVD02_mUVVD00ol0
003oHiaSof>LH`0;of>LH`03o`000?mSW6?oHiaS00SoHiaS0ol00008ofbCK003o`000?n4NhCoQ7^4
00SoQ7^400?o0000ojeB[On]DZd03?n]DZd00ol0003oiaSWonLHi`0=onLHi`03o`000?o^4Nko0000
01;on@Ki00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003omPWfooH9mP07ooH9mP03o`000?oP7n3oh1oP00goh1oP00?o0000ojQGZ?nXEjP04_nXEjP01Ol0
003oNXEjogZ5N_mjQG[o000000koIIYU00?o0000of>LHomSW6<02omSW6<00ol0003oHiaSof>LH`06
of>LH`03o`000?m/TfcoK9=/00WoK9=/00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o[E:]ojeB[@0:
ojeB[@03o`000?oW6>OoiaSW00ooiaSW00?o0000ooT6nOoi1_T04?oi1_T00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?of2OKomPWf
00KomPWf00?o0000on0Oh?oP7n003OoP7n000ol0003oZ5NXojQGZ00CojQGZ003o`000?mjQG[o0000
013oIIYU3_l00006of>LH`;o00003?m/Tf`00ol0003oQ7^4ohAkQ009ohAkQ003o`000?n]DZgo[E:]
00[o[E:]00?o0000onLHiooW6>L03ooW6>L00ol0003on@KiooT6n@0>ooT6n@;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?of2OKomPWf00KomPWf00?o0000on0Oh?oP7n002ooP7n000ol0003o
Z5NXojQGZ00DojQGZ0?o00003omUVVD00ol0003oIYUVofJIIP0<ofJIIP04o`000?mSW6?oHiaSof>L
H`;o00003om/Tf`00ol0003oQ7^4ohAkQ009ohAkQ003o`000?n]DZgo[E:]00Wo[E:]00?o0000onLH
iooW6>L04?oW6>L00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oP7n3oh1oP00_o
h1oP00?o0000ojQGZ?nXEjP04onXEjP01Ol0003oNhAkog^4NomkQ7_o000000goIIYU00?o0000ofJI
I_mVVFH03_mVVFH00ol0003oHiaSo`00000AofbCK003o`000?n4NhCoQ7^400WoQ7^400?o0000ojeB
[On]DZd02On]DZd00ol0003oiaSWonLHi`0@onLHi`03o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?of2OKomPWf00Go
mPWf4Ol0000BojQGZ003o`000?mkQ7_oNhAk00?oNhAk00?o0000ofFJIOmUVVD02OmUVVD00ol0003o
IYUVofJIIP0@ofJIIP03o`000?m/TfcoK9=/017oK9=/00?o0000ohAkQ?n4Nh@02On4Nh@00ol0003o
[E:]ojeB[@07ojeB[@03o`000?oW6>OoiaSW017oiaSW00?o0000ooT6nOoi1_T02_oi1_T00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH00oof2OH00ol0003o
i1_Ton@Ki00<on@Ki003o`000?nMHYgoWF:M00?o00003_nXEjP00ol0003oNhAkog^4N`05og^4N`03
o`000?mUVVGoIIYU00OoIIYU00?o0000ofJII_mVVFH04OmVVFH00ol0003oK9=/ofbCK00AofbCK003
o`000?n4NhCoQ7^400WoQ7^400?o0000ojeB[On]DZd01_n]DZd2o`0001CoiaSW00?o0000ooT6nOoi
1_T01ooi1_T2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooH9m_l0003oi1_T00koi1_T
00?o0000oieRWOnMHYd00onMHYd3o`0000[oZ5NX00?o0000og^4NomkQ7/01omkQ7/00ol0003oIIYU
ofFJI@05ofFJI@03o`000?mVVFKoIYUV01;oIYUV00?o0000ofbCK?m/Tf`04Om/Tf`00ol0003oQ7^4
ohAkQ00:ohAkQ003o`000?n]DZgo[E:]00;o[E:]0ol00002okM8]`03o`000?oW6>OoiaSW017oiaSW
00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004ooX5nP03o`000?oT6nCoi1_T00koi1_T00?o0000oieRWOnMHYd01_nM
HYd3o`0000KoZ5NX00?o0000og^4NomkQ7/02OmkQ7/00ol0003oIIYUofFJI@03ofFJI@03o`000?mV
VFKoIYUV01?oIYUV00?o0000ofbCK?m/Tf`04_m/Tf`00ol0003oQ7^4ohAkQ009ohAkQ003o`000?n]
DZgo000000;o00001_ngB;L00ol0003oiaSWonLHi`0@onLHi`03o`000?oi1_Won@Ki00Gon@Ki00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007ooX5nP03o`000?oT6nCo
i1_T00goi1_T00?o0000oieRWOnMHYd02_nMHYd3o`0000;oZ5NX00?o0000og^4NomkQ7/02omkQ7/0
1Ol0003oIIYUofFJIOmUVVGo000001KoIYUV00?o0000ofbCK?m/Tf`04_m/Tf`00ol0003oQ7^4ohAk
Q00:ohAkQ003o`000?ngB;Oo]dRg00So]dRg00?o0000onLHiooW6>L04?oW6>L00ol0003on@KiooT6
n@02ooT6n@?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:ooX5nP03o`00
0?oT6nCoi1_T00goi1_T00?o0000oieRWOnMHYd03OnMHYd2o`0000ooNhAk00?o0000ofFJIOl00000
5omVVFH00ol0003oK9=/ofbCK00CofbCK003o`000?n4NhCoQ7^400WoQ7^400?o0000okM8]ongB;L0
2OngB;L00ol0003oiaSWonLHi`0?onLHi`03o`000?oi1_Won@Ki00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000on@Ki?oT6n@03OoT
6n@00ol0003oWF:MoieRW@0>oieRW@03o`000?mkQ7_oNhAk00koNhAk00?o0000ofJII_mVVFH05_mV
VFH00ol0003oK9=/ofbCK00CofbCK003o`000?n4NhCoQ7^400SoQ7^400?o0000okM8]ongB;L02ong
B;L5o`0000coiaSW00?o0000ooT6nOl000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000on@Ki?oT6n@03OoT6n@00ol0003oWF:MoieRW@0>
oieRW@03o`000?mkQ7_oNhAk00koNhAk00?o0000ofJII_mVVFH05_mVVFH00ol0003oK9=/ofbCK00C
ofbCK003o`000?n4NhCoQ7^400OoQ7^400?o0000okM8]ongB;L03?ngB;L00ol0003oiaSWonLHi`02
onLHi`Wo00001?oW6>L00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003oi1_Ton@Ki00<on@Ki003o`000?nMHYgoWF:M
00koWF:M00?o0000og^4NomkQ7/03omkQ7/00ol0003oIYUVofJIIP0EofJIIP03o`000?m/TfcoK9=/
01?oK9=/1?l00005ohAkQ003o`000?ngB;Oo]dRg00go]dRg00?o0000onLHiooW6>L02ooW6>L4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03
o`000?oT6nCoi1_T00_oi1_T00?o0000oieRWOnMHYd03onMHYd00ol0003oNhAkog^4N`0?og^4N`03
o`000?mVVFKoIYUV01GoIYUV00?o0000ofbCK?m/Tf`04?m/Tf`3o`0000CoSG:=0ol000000on4NhCo
0000okM8]`0>okM8]`03o`000?oW6>OoiaSW00ooiaSW00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003oi1_Ton@Ki00;on@Ki003o`00
0?nMHYgoWF:M00ooWF:M00?o0000og^4NomkQ7/03omkQ7/2o`0001CoIYUV0ol0000@ofbCK0;o0000
2_n=LXd00ol0003o]dRgokM8]`0>okM8]`03o`000?oW6>OoiaSW013oiaSW0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oT6nCoi1_T00_oi1_T4ol0000>og^4N`?o0000
0_mcS7<00ol0003oIYUVofJIIP0<ofJIIPGo00000_m^TFh00ol0003oK9=/ofbCK00<ofbCK0;o0000
3?n=LXd00ol0003o]dRgokM8]`0>okM8]`03o`000?oW6>OoiaSW013oiaSW00?o0000ooD:mOl00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oT
6nCoi1_T00_oi1_T00?o0000oiaSW?nLHi`03onLHi`00ol0003oNhAkog^4N`09og^4N`?o00001_mc
S7<00ol0003oIYUVofJIIP06ofJIIPGo00002?m^TFh00ol0003oK9=/ofbCK008ofbCK0?o00003on=
LXd00ol0003o]dRgokM8]`0=okM8]`03o`000?oW6>OoiaSW00ooiaSW00Go0000ooD:mOoe2_Gom@[e
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oi1_Ton@K
i00;on@Ki003o`000?nLHicoW6>L00ooW6>L00?o0000og^4NomkQ7/01_mkQ7/3o`0000[oLhac00?o
0000ofJII_mVVFH01Ol0000>ofjAKP03o`000?m/TfcoK9=/00GoK9=/0_l0000BohebS@03o`000?ng
B;Oo]dRg00co]dRg00?o0000onLHiooW6>L04?oW6>L00ol0003om@[eooD:m@02ooD:m@03o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oi1_Ton@Ki00;
on@Ki003o`000?nLHicoW6>L013oW6>L00?o0000og^4NomkQ7/00_mkQ7/3o`0000goLhac0ol0000C
ofjAKP03o`000?m/TfcoK9=/00?oK9=/0_l0000EohebS@03o`000?ngB;Oo]dRg00_o]dRg00?o0000
onLHiooW6>L03ooW6>L00ol0003om@[eooD:m@04ooD:m@03o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oi1_Ton@Ki008on@Ki0Co00004OnLHi`00ol0003oNhAko`000002o`00
00ooLhac00?o0000og6>LOl000005Om^TFh00ol0003oK9=/o`000002o`0001OoSG:=00?o0000okM8
]ongB;L02ongB;L00ol0003oiaSWonLHi`0>onLHi`03o`000?oe2_Gom@[e00Kom@[e00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oT6nCoi1_T00Go
i1_T0ol00004ol/db`03o`000?nLHicoW6>L00koW6>L0_l0000Aog><L`04o`000?maSW7oLHiao`00
01KoKY5^00?o0000ohebSOn=LXd06?n=LXd00ol0003o]dRgokM8]`0;okM8]`03o`000?oW6>OoiaSW
00koiaSW00?o0000ooD:mOoe2_D01ooe2_D00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oT6nCoi1_T00;oi1_T0ol00008ol/db`03
o`000?nLHicoW6>L00coW6>L0ol0000?og><L`;o00000omaSW400ol0003oKY5^ofjAKP0DofjAKP03
o`000?n=LXgoSG:=01WoSG:=00?o0000okM8]ongB;L02_ngB;L00ol0003oiaSWonLHi`0=onLHi`03
o`000?oe2_Gom@[e00Wom@[e00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oj1O[onPGj00OonPGj1_l0000<ol/db`03o`000?nLHicoW6>L00[oW6>L00Go0000oi5^TOnAKY7o
TFjAo`00000=og><L`03o`000?maSW7oLHia00CoLHia00?o0000ofjAK_m^TFh04om^TFh00ol0003o
SG:=ohebS@0IohebS@03o`000?ngB;Oo]dRg00Wo]dRg00?o0000onLHiooW6>L03_oW6>L00ol0003o
m@[eooD:m@0:ooD:m@;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000GonPGj0_l00004ooL8m`03o`00
0?o;=<_obcC;00cobcC;0_l00008oiaSW0;o00001OnAKY400ol0003oLhacog><L`09og><L`03o`00
0?maSW7oLHia00GoLHia00?o0000ofjAK_m^TFh04om^TFh00ol0003oSG:=ohebS@0JohebS@go0000
3_oW6>L00ol0003om@[eooD:m@0;ooD:m@03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?onPGjo`000?og2?L01_og2?L00ol0003obcC;ol/db`0=ol/db`03o`000?nL
HicoW6>L00CoW6>L00?o0000oi5^TOnAKY401_nAKY42o`0000SoLhac00?o0000og6>LOmaSW401_ma
SW400ol0003oKY5^ofjAKP0DofjAKP03o`000?n=LXgoSG:=01WoSG:=00?o0000ol/dboo;=</02_o;
=</00ol0003oiaSWonLHi`0;onLHi`03o`000?oe2_Gom@[e00com@[e00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o0000ol/dboo;=</03_o;=</0
1?l0003oW6>LoiaSW?nLHi`2o`0000_oTFjA00?o0000og><LomcS7<00omcS7<2o`0000WoLHia00?o
0000ofjAK_m^TFh05?m^TFh00ol0003oSG:=ohebS@0HohebS@03o`000?o;=<_obcC;00cobcC;00?o
0000onLHiooW6>L02OoW6>L00ol0003om@[eooD:m@0=ooD:m@03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooL8moog2?L01oog2?L00ol0003obcC;ol/db`0>ol/db`03o`000?nLHico
000000koTFjA00Go0000og><LomcS7?oLhaco`00000;og6>L@03o`000?m^TFkoKY5^01CoKY5^0_l0
000IohebS@03o`000?o;=<_obcC;00gobcC;0_l00008onLHi`03o`000?oe2_Gom@[e00kom@[e00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooL8moog2?L01oog2?L00ol0003obcC;ol/db`0?
ol/db`03o`000?nAKY7oTFjA00koTFjA00?o0000og><Lol000003?maSW400ol0003oKY5^ofjAKP0D
ofjAKP03o`000?n3O8?o000000;o00005On=LXd00ol0003obcC;ol/db`0@ol/db`03o`000?oW6>Oo
iaSW00GoiaSW00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooL8
moog2?L02?og2?L00ol0003obcC;ol/db`0>ol/db`03o`000?nAKY7oTFjA00koTFjA0_l0000=og6>
L@03o`000?m^TFkoKY5^01?oKY5^00?o0000oh=lPon3O8<00on3O8<2o`0001;oSG:=00?o0000ol/d
boo;=</04_o;=</01?l0003oiaSWonLHiooW6>L3o`0001;om@[e00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?og2?Oom`Sg00Som`Sg00?o0000ol/dboo;=</03Oo;=</2o`0000ooTFjA00?o0000ohUf
ROl000003_maSW400ol0003oKY5^ofjAKP0BofjAKP03o`000?n3O8?oPgb300GoPgb30ol0000?oheb
S@03o`000?o;=<_obcC;01?obcC;0ol00002oo4>l@03o`000?oe2_Gom@[e013om@[e00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o0000ol/dboo;=</02oo;=</00ol0003o
bSG:o`00000>oi5^T@05o`000?n9MXWoRGJ9ohUfROl000003OmaSW400ol0003oKY5^ofjAKP0AofjA
KP03o`000?n3O8?oPgb300WoPgb30ol0000:ohebS@;o00005_o;=</00ol0003ol@kaoo4>l@03oo4>
l@03o`000?oe2_Gom@[e013om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000ol/dboo;=</02_o;=</01Ol0003obSG:olXeb_o:=L[o000000coTFjA00?o0000ohUf
ROn9MXT00_n9MXT00ol0003oLHiaog6>L@0;og6>L@03o`000?m^TFkoKY5^017oKY5^00?o0000oh=l
Pon3O8<03?n3O8<2o`0000KoSG:=0_l000000onbCK;o0000ol/db`0Dol/db`03o`000?oa3_7ol@ka
00Gol@ka00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooL8moog
2?L02_og2?L00ol0003obcC;ol/db`07ol/db`;o00001Oo:=LX00ol0003oTFjAoi5^T@08oi5^T@03
o`000?n9MXWoRGJ900CoRGJ900?o0000og6>LOmaSW402OmaSW44o`00013oKY5^00?o0000oh=lPon3
O8<03on3O8<3o`000003ohebSOl0003o000000Co/Tfb00?o0000ol/dboo;=</04Oo;=</00ol0003o
l@kaoo4>l@07oo4>l@03o`000?oe2_Gom@[e00oom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?og2?Oom`Sg00[om`Sg00?o0000ol/dboo;=</01_o;=</00ol0003obSG:olXebP05olXebP03o`00
0?nAKY7oTFjA00OoTFjA00?o0000ohUfROn9MXT01On9MXT00ol0003oLHiaog6>L@08og6>L@03o`00
0?m^TFkoKY5^00;oKY5^0ol0000=ofjAKP03o`000?n3O8?oPgb301;oPgb300?o0000ok9=/_nbCK80
1OnbCK800ol0003obcC;ol/db`0@ol/db`03o`000?oa3_7ol@ka00Ool@ka00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L02oog2?L00ol0003obcC;ol/d
b`04ol/db`03o`000?o:=L[obSG:00OobSG:00?o0000oi5^TOnAKY401OnAKY400ol0003oRGJ9ohUf
R@07ohUfR@03o`000?maSW7oLHia00KoLHia00?o0000ofjAK_m^TFh01_m^TFh3o`0000SoKY5^0_l0
000Eoh=lP`03o`000?nbCK;o/Tfb00Ko/Tfb00?o0000ol/dboo;=</03_o;=</00ol0003ol@kaoo4>
l@09oo4>l@03o`000?oe2_Gom@[e00kom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?og2?Oo
m`Sg00_om`Sg00?o0000ol/dboo;=</00_o;=</2o`0000[obSG:00?o0000oi5^TOnAKY401?nAKY40
0ol0003oRGJ9ohUfR@09ohUfR@03o`000?maSW7oLHia00?oLHia0_l0000<ofjAKP?o00000_m^TFh3
o`000003og6>LOl0003oPgb301CoPgb300?o0000ok9=/_nbCK801onbCK800ol0003obcC;ol/db`0<
ol/db`03o`000?oa3_7ol@ka00_ol@ka00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooL8moog2?L03?og2?L01?l0003obcC;ol/dbol0000=olXebP03o`000?nAKY7o
TFjA00;oTFjA00?o0000ohUfROn9MXT02_n9MXT00ol0003oLHiaog6>L@02og6>L@03o`000?m^TFko
KY5^00ooKY5^0_l00005og6>L@03o`000?n3O8?oPgb301;oPgb300?o0000ok9=/_nbCK802?nbCK80
0ol0003obcC;ol/db`0:ol/db`03o`000?oa3_7ol@ka00gol@ka1Ol0000;ooD:m@03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003om`SgooL8m`0<ooL8m`03o`000?o;=<_o000000oobSG:00Co0000oi5^
TOnAKY7o00003_n9MXT01?l0003oLHiaog6>LOl0000CofjAKP03o`000?maSW7oLHia00CoLHia00?o
0000oh=lPon3O8<04?n3O8<00ol0003o/Tfbok9=/P09ok9=/P03o`000?o;=<_obcC;00[obcC;00?o
0000oo4>lOoa3_403Ooa3_400ol0003onPGjooX5nP02ooX5nPWo00000_oe2_D00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooL8m`03o`000?o:=L[obSG:00kobSG:00?o0000oi5^TOl000003on9MXT0
0ol0003oLHiao`00000CofjAKP03o`000?maSW7oLHia00GoLHia00?o0000oh=lPon3O8<04?n3O8<0
0ol0003o/Tfbok9=/P0:ok9=/P03o`000?o;=<_obcC;00SobcC;00?o0000oo4>lOoa3_403Ooa3_40
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000olXe
b_o:=LX03oo:=LX00ol0003oRGJ9ohUfR@0>ohUfR@;o00005?m^TFh00ol0003oLHiaog6>L@06og6>
L@03o`000?n3O8?oPgb300ooPgb300?o0000ok9=/_nbCK802onbCK800ol0003obcC;ol/db`04ol/d
b`?o00004?oa3_400ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003o
bSG:olXebP0@olXebP03o`000?n9MXWoRGJ900_oRGJ90ol000000omnPGko0000ofjAKP0BofjAKP03
o`000?maSW7oLHia00OoLHia00?o0000oh=lPon3O8<03on3O8<00ol0003o/Tfbok9=/P0<ok9=/P03
o`000?o;=<_obcC;00?o00000ooY5^T00ol0003ol@kaoo4>l@0=oo4>l@03o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Wom`Sg00?o0000olXeb_o:=LX04?o:=LX3o`0000WoRGJ90_l00005ogj1OP03o`00
0?m^TFkoKY5^013oKY5^00?o0000og6>LOmaSW402?maSW400ol0003oPgb3oh=lP`0>oh=lP`03o`00
0?nbCK;o/Tfb00go/Tfb0_l00007onTFj@03o`000?oa3_7ol@ka00_ol@ka00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003om`SgooL8m`06ooL8m`03o`000?o:=L[obSG:00oobSG:00Co
0000ok]4^onkA;_o^dBk0_l00005ohUfR@;o00002?mnPGh00ol0003oKY5^ofjAKP0>ofjAKP03o`00
0?maSW7oLHia00[oLHia00?o0000oh=lPon3O8<03?n3O8<00ol0003o/Tfbok9=/P0>ok9=/P03o`00
0?oY5^WojAKY00OojAKY00?o0000oo4>lOoa3_402_oa3_400ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?og2?Oom`Sg00Com`Sg4ol00006ok]4^`03o`000?n9MXWo000000;o00002_mn
PGh00ol0003oKY5^ofjAKP0=ofjAKP03o`000?maSW7oLHia00_oLHia00?o0000oh=lPon3O8<03?n3
O8<00ol0003o/Tfbok9=/P0=ok9=/P03o`000?oY5^WojAKY00WojAKY00?o0000oo4>lOoa3_402?oa
3_400ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?o/4nco
k1?/00ook1?/00?o0000ok]4^onkA;/01OnkA;/00ol0003oOX5nogj1OP0<ogj1OP03o`000?m^TFko
KY5^00coKY5^00?o0000og6>LOmaSW403?maSW42o`0000coPgb300?o0000ok9=/_nbCK803OnbCK80
0ol0003ojAKYonTFj@0:onTFj@03o`000?oa3_7ol@ka00Ool@ka00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?om`Sgo`000?o/4n`04?o/4n`00ol0003o^dBkok]4^`06ok]4^`03o`000?mnPGko
OX5n00coOX5n00?o0000ofjAK_m^TFh02om^TFh00ol0003oLHiaog6>L@0=og6>L@04o`000?n5NXGo
0000o`0000[oPgb300?o0000ok9=/_nbCK803OnbCK800ol0003ojAKYonTFj@0;onTFj@03o`000?oa
3_7ol@ka00Kol@ka00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?ol0o`00ol0003ok1?/on`Ck00@
on`Ck003o`000?nkA;_o^dBk00Ko^dBk00?o0000ogj1O_mnPGh03OmnPGh00ol0003oKY5^ofjAKP0:
ofjAKP03o`000?maSW7oLHia00coLHia00?o0000ohEjQOn5NXD00_n5NXD2o`0000SoPgb300?o0000
ok9=/_nbCK803?nbCK800ol0003ojAKYonTFj@0=onTFj@03o`000?oa3_7ol@ka00Col@ka00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?ol0ocoo0?l00Coo0?l0_l0000@on`Ck003o`000?nkA;_o^dBk
00Oo^dBk00?o0000ogj1O_mnPGh03_mnPGh<o`0000ooLHia00?o0000ohEjQOn5NXD01?n5NXD2o`00
00KoPgb300?o0000ok9=/_nbCK803?nbCK800ol0003ojAKYonTFj@0>onTFj@03o`000?oa3_7ol@ka
00?ol@ka00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001ool0o`01?l0003omPWfo`000?l0000>on`C
k003o`000?nkA;_o^dBk00So^dBk00?o0000ogj1O_mnPGh03OmnPGh00ol0003oLhacog><L`08og><
L`03o`000?maSW7oLHia00coLHia00?o0000ohEjQOn5NXD01on5NXD2o`0000?oPgb300?o0000ok9=
/_nbCK803OnbCK800ol0003ojAKYonTFj@0?onTFj@05o`000?oa3_7ol@kaoo4>lOl000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009oo`3
o005o`000?of2OKomPWfooH9m_l000003Oo/4n`00ol0003o^dBkok]4^`08ok]4^`03o`000?mnPGko
OX5n00coOX5n00?o0000og><LomcS7<02_mcS7<00ol0003oLHiaog6>L@0;og6>L@03o`000?n5NXGo
QGZ500WoQGZ50_l000000on3O8?o0000ok9=/P08ok9=/PKo00004ooY5^T01?l0003ol@kaoo4>lOl0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:oo`3o003o`000?of2OKomPWf00?omPWf1?l00008on`Ck003o`000?nkA;_o
^dBk00Wo^dBk00?o0000ogj1O_mnPGh03?mnPGh00ol0003oLhacog><L`0:og><L`03o`000?maSW7o
LHia00[oLHia00?o0000ohEjQOn5NXD03?n5NXD;o`0000GoeRWF00?o0000onTFjOoY5^T04_oY5^T0
0ol0003ol@kao`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<oo`3o003o`000?of2OKomPWf00?omPWf00Co0000omXU
f_oJ9M[ofRGJ1Ol00003on`Ck003o`000?nkA;_o^dBk00Wo^dBk00?o0000ogj1O_mnPGh02omnPGh0
0ol0003oLhacog><L`0<og><L`03o`000?maSW7oLHia00WoLHia00?o0000ohEjQOn5NXD03?n5NXD0
0ol0003o[e2_ojm@[`02ojm@[`03o`000?oF:MKoeRWF00WoeRWF00?o0000onTFjOoY5^T04_oY5^T3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o00<oo`3o003o`000?of2OKomPWf00ComPWf00?o0000omXU
f_oJ9MX01OoJ9MX3o`0000co^dBk00?o0000ogj1O_mnPGh02omnPGh00ol0003oLhacog><L`0<og><
L`03o`000?maSW7oLHia00SoLHia00?o0000ohEjQOn5NXD03?n5NXD00ol0003o[e2_ojm@[`04ojm@
[`03o`000?oF:MKoeRWF00SoeRWF00?o0000onTFjOoY5^T04_oY5^T00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_ol0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oJ9M[ofRGJ00OofRGJ00?o0000ok]4
^onkA;/02_nkA;/00ol0003oOX5nogj1OP09ogj1OP;o00003omcS7<00ol0003oLHiaog6>L@08og6>
L@03o`000?n5NXGoQGZ500coQGZ500?o0000ojm@[on_D:l01?n_D:l00ol0003oeRWFomHYeP09omHY
ePCo00003ooY5^T00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00Go
mPWf00?o0000omXUf_oJ9MX02?oJ9MX00ol0003o^dBkok]4^`09ok]4^`03o`000?mnPGkoOX5n00Ko
OX5n0ol000000on>LHko0000og><L`0?og><L`03o`000?maSW7oLHia00KoLHia00?o0000ohEjQOn5
NXD03On5NXD00ol0003o[e2_ojm@[`05ojm@[`03o`000?oF:MKoeRWF00SoeRWF00Co0000oo@;m?od
2oCom0_d1Ol00009onTFj@03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00koo0?l00?o0000ooH9m_of
2OH01_of2OH00ol0003ofRGJomXUfP07omXUfP03o`000?nkA;_o^dBk00[o^dBk00?o0000ogj1O_mn
PGh00_mnPGh3o`0000GoSW6>00?o0000og><LomcS7<03OmcS7<00ol0003oLHiaog6>L@06og6>L@03
o`000?n5NXGoQGZ500coQGZ500?o0000ojm@[on_D:l01_n_D:l00ol0003oeRWFomHYeP08omHYeP03
o`000?od2oCom0_d00Kom0_d1Ol00003onTFj@03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00KomPWf
00?o0000omXUf_oJ9MX01ooJ9MX00ol0003o^dBkok]4^`0:ok]4^`03o`000?mnPGko000000;o0000
2?n>LHh00ol0003oLhacog><L`0=og><L`Co00001?maSW400ol0003oQGZ5ohEjQ@0=ohEjQ@03o`00
0?n_D:oo[e2_00Oo[e2_00?o0000omHYe_oF:MH01ooF:MH00ol0003om0_doo@;m00;oo@;m0?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo0?loo`3
o00<oo`3o003o`000?of2OKomPWf00OomPWf00?o0000omXUf_oJ9MX02?oJ9MX3o`0000Wo^dBk0_l0
000<ohiaSP03o`000?mcS7?oLhac00_oLhac00?o0000ohacS?n<Lh`00_n<Lh`3o`000003og6>LOl0
003oQGZ500koQGZ500?o0000ojm@[on_D:l01on_D:l00ol0003oeRWFomHYeP06omHYeP03o`000?od
2oCom0_d00kom0_d00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?of2OKomPWf00SomPWf00?o0000
omXUf_oJ9MX01_oJ9MX01?l0003ogR7NomhQg_oN8Mh3o`0000Ko^dBk00?o0000ohiaS_n>LHh03?n>
LHh00ol0003oLhacog><L`09og><L`03o`000?n<LhcoS7><00KoS7><00?o0000ohEjQOn5NXD03On5
NXD00ol0003o[e2_ojm@[`09ojm@[`03o`000?oF:MKoeRWF00GoeRWF00?o0000oo@;m?od2o@03_od
2o@00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?ol0ocoo0?l00coo0?l00?o0000ooH9m_of2OH02?of2OH00ol0003ofRGJomXUfP05
omXUfP03o`000?oN8MkogR7N00GogR7N0ol00002ok]4^`03o`000?n>LHkoSW6>00goSW6>00?o0000
og><LomcS7<02?mcS7<00ol0003oS7><ohacS007ohacS003o`000?n5NXGoQGZ500coQGZ50ol0000:
ojm@[`03o`000?oF:MKoeRWF00GoeRWF00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003ofRGJomXUfP04omXUfP03o`000?oN8MkogR7N
00WogR7N0_l0000AohiaSP03o`000?mcS7?oLhac00GoLhac0_l0000;ohacS003o`000?n5NXGoQGZ5
00[oQGZ500Go0000ojiA[_n^DJko[U6^o`00000:ojm@[`03o`000?oF:MKoeRWF00CoeRWF00?o0000
oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00Soo0?l1?l0000<ooH9mP03o`000?oJ9M[ofRGJ
00;ofRGJ00?o0000omhQg_oN8Mh02_oN8Mh2o`00017oSW6>00?o0000og><LomcS7<01?mcS7<00ol0
003oS7><ohacS00<ohacS003o`000?n5NXGoQGZ500OoQGZ50_l00005ojiA[P;o00002?n_D:l00ol0
003oeRWFomHYeP04omHYeP03o`000?od2oCom0_d00gom0_d00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o007o`0000?o
oP7n00?o0000ooH9m_of2OH02_of2OH01Ol0003ofRGJomXUf_oJ9M[o000000cogR7N00Co0000olTf
bOo9=/Wo00004On>LHh00ol0003oLhacog><L`02og><L`03o`000?n<LhcoS7><00koS7><00?o0000
ohEjQOn5NXD01On5NXD00ol0003o[U6^ojiA[P07ojiA[P03o`000?n_D:oo[e2_00Ko[e2_00?o0000
omHYe_oF:MH00ooF:MH00ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?of2OKomPWf
00WomPWf00Co0000omXUf_oJ9M[o00003?oN8Mh00ol0003obCK9olTfb@02olTfb@03o`000?n>LHko
SW6>00ooSW6>00Co0000og><LomcS7?o00004On<Lh`00ol0003oQGZ5ohEjQ@04ohEjQ@03o`000?n^
DJko[U6^00Wo[U6^00?o0000ojm@[on_D:l01On_D:l00ol0003oeRWFomHYeP03omHYeP03o`000?od
2oCom0_d00gom0_d00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?of2OKomPWf00WomPWf0_l0000<
omhQgP03o`000?o9=/WobCK900?obCK900?o0000ohiaS_n>LHh03on>LHh00ol0003oLhaco`00000C
ohacS004o`000?n5NXGoQGZ5ohEjQ@;o00003On^DJh2o`0000Ko[e2_00Go0000omHYe_oF:MKoeRWF
o`00000@oo@;m003o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?of2OKomPWf00SomPWf00?o0000omhQg_oN8Mh02_oN
8Mh00ol0003obCK9olTfb@05olTfb@03o`000?n>LHkoSW6>00ooSW6>00?o0000ohacS?n<Lh`04on<
Lh`00ol0003oQGZ5o`00000AojiA[P03o`000?n_D:oo[e2_00?o[e2_00Go0000omHYe_oF:MKoeRWF
o`00000>oo@;m0?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?of2OKomPWf00SomPWf00?o0000omhQg_oN8Mh02OoN
8Mh00ol0003obCK9olTfb@07olTfb@03o`000?n>LHkoSW6>00koSW6>00?o0000ohacS?n<Lh`05?n<
Lh`00ol0003o[U6^ojiA[P0AojiA[P;o00001?n_D:l01?l0003oeRWFomHYe_l0000:oo@;m0Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?of2OKomPWf00KomPWf00?o
0000omhQg_oN8Mh02OoN8Mh00ol0003obCK9olTfb@08olTfb@03o`000?n>LHkoSW6>00_oSW6>0ol0
000GohacS003o`000?n^DJko[U6^01?o[U6^00Ko0000ojm@[on_D:oo[e2_o`000?oF:MH5o`0000Co
m0_d0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003omPWfooH9mP05ooH9mP03o`00
0?oN8MkogR7N00SogR7N00?o0000olTfbOo9=/T02_o9=/T00ol0003oSW6>ohiaSP07ohiaSP?o0000
0_nGJ9L00ol0003oS7><ohacS00EohacS0;o00005On^DJh00ol0003o[e2_ojm@[`02o`0000Gok1?/
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?omPWf00?o0000omhQg_oN8Mh01ooN
8Mh00ol0003obCK9olTfb@0;olTfb@03o`000?n>LHkoSW6>00CoSW6>0ol00006oiMXU`03o`000?n<
LhcoS7><01?oS7><00Co0000okM8]ongB;Oo00005On^DJh2o`0000Wok1?/00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooL8moog2?L00oog2?L3o`0000WogR7N00?o0000olTfbOo9=/T03Oo9=/T00ol0003oSW6>ohia
SP03o`0000[oUfRG00?o0000ohacS?n<Lh`04On<Lh`00ol0003o]dRgokM8]`02okM8]`03o`000?n^
DJko[U6^01;o[U6^00?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooL8moog2?L01oog2?L00ol0003ogR7NomhQgP05omhQgP03o`000?o9=/WobCK900oobCK90_l0000>
oiMXU`03o`000?n<LhcoS7><00ooS7><00?o0000okM8]ongB;L01?ngB;L00ol0003o[U6^ojiA[P0@
ojiA[P;o00002oo/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00?o0000omhQg_oN8Mh00ooN8Mh00ol0003obCK9olTfb@0@olTfb@03o`000?nGJ9OoUfRG
00goUfRG00?o0000ohacS?n<Lh`03_n<Lh`00ol0003o]dRgokM8]`06okM8]`;o00003_n^DJh2o`00
0003ol/dbol0003ok1?/00[ok1?/00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02oog2?L01Ol0
003ogR7NomhQg_oN8Mko000001;obCK900?o0000oiMXUonGJ9L03onGJ9L00ol0003oS7><ohacS00<
ohacS003o`000?ngB;Oo]dRg00Wo]dRg00?o0000ojiA[_n^DJh02On^DJh2o`0000?obcC;00?o0000
on`Ck?o/4n`02Oo/4n`00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooL8moog2?L03Oog2?L00ol0003ogR7No`00000ColTf
b@03o`000?nGJ9OoUfRG013oUfRG00?o0000ohacS?n<Lh`02_n<Lh`00ol0003o]dRgokM8]`0;okM8
]`03o`000?n^DJko[U6^00Go[U6^0ol00006ol/db`03o`000?o/4ncok1?/00Sok1?/00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?og2?Oom`Sg00oo
m`Sg00?o0000olTfbOo9=/T04Oo9=/T00ol0003oUfRGoiMXU`0AoiMXU`03o`000?n<LhcoS7><00Wo
S7><00?o0000okM8]ongB;L03OngB;L00ol0003o[U6^ojiA[P02ojiA[P;o00002Oo;=</00ol0003o
k1?/on`Ck009on`Ck003o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooL8moog2?L04Oog2?L2o`00017obCK900?o0000oiMXUonGJ9L0
4_nGJ9L00ol0003oS7><ohacS007ohacS003o`000?ngB;Oo]dRg00oo]dRg00Co0000ojiA[_l0003o
00002oo;=</00ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04_og2?L00ol0003oiA[U
o`000002o`0000kobCK900?o0000oiMXUonGJ9L04onGJ9L00ol0003oS7><ohacS005ohacS003o`00
0?ngB;Oo]dRg017o]dRg00?o0000ol/dboo;=</03?o;=</00ol0003ok1?/on`Ck008on`Ck003o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003om`SgooL8
m`0BooL8m`03o`000?oU6^GoiA[U00?oiA[U0_l0000;olTfb@;o00005_nGJ9L7o`0001Co]dRg00?o
0000ol/dboo;=</03?o;=</00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?og2?L00ol0003oiA[UonDJ
i@06onDJi@?o00002?o9=/T00ol0003o]TVfo`000002o`0001;oUfRG00?o0000oj=LXonSG:<00_nS
G:<00ol0003oVVFJo`00000DokM8]`03o`000?o;=<_obcC;00cobcC;00?o0000on`Ck?o/4n`02?o/
4n`00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooL8moog2?L04_og2?L00ol0003oiA[UonDJi@09onDJi@;o00001Oo9=/T00ol0003o]TVfokI9]P03
okI9]P;o00003onGJ9L00ol0003oXebSoj=LX`03oj=LX`04o`000?nJII[oVVFJo`0001?o]dRg00?o
0000ol/dboo;=</03Oo;=</00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_oU6^D3o`000003olTfbOl0003o
]TVf00Oo]TVf0ol0000;oiMXU`03o`000?nSG:?oXebS00CoXebS00Go0000oiYUV_nJII[oVVFJo`00
000BokM8]`03o`000?o;=<_obcC;00gobcC;00?o0000on`Ck?o/4n`01oo/4n`?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04?og2?L0
0ol0003oiA[UonDJi@0?onDJi@03o`000?nfBKKo]TVf00[o]TVf0_l00008oiMXU`03o`000?nSG:?o
XebS00GoXebS00?o0000oiYUV_nJIIX00_nJIIX00ol0003o]dRgokM8]`0?okM8]`03o`000?o;=<_o
bcC;00gobcC;00?o0000on`Ck?o/4n`01_o/4n`00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?og2?Oom`Sg00oom`Sg00?o0000onDJiOoU6^D03ooU6^D00ol0003o]TVfokI9]P0<okI9
]P;o00001OnGJ9L00ol0003oXebSoj=LX`06oj=LX`03o`000?nJII[oVVFJ00?oVVFJ00?o0000okM8
]ongB;L03_ngB;L00ol0003obcC;ol/db`0>ol/db`03o`000?o/4ncok1?/00Cok1?/00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00kom`Sg00?o0000onDJiOoU6^D04?oU6^D00ol0003o
]TVfokI9]P0>okI9]P?o000000?oUfRGo`000?nSG:<02?nSG:<00ol0003oVVFJoiYUVP04oiYUVP03
o`000?ngB;Oo]dRg00go]dRg4_l00005on`Ck003o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGj
o`00000?ooL8m`03o`000?oU6^GoiA[U00ooiA[U0_l0000CokI9]P03o`000?nSG:?oXebS00SoXebS
00?o0000oiYUV_nJIIX01OnJIIX00ol0003o]dRgokM8]`0<okM8]`03o`000?o_4>ooka3_00ooka3_
00Go0000on`Ck?o/4ncok1?/o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?oj1O[onPGjo`0000ko
m`Sg00?o0000onDJiOoU6^D03_oU6^D00ol0003of2OHo`00000CokI9]P03o`000?nSG:?oXebS00So
XebS00?o0000oiYUV_nJIIX01OnJIIX00ol0003o]dRgokM8]`0;okM8]`03o`000?o_4>ooka3_017o
ka3_00?o0000on`Ck?l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oU6^GoiA[U00goiA[U0_l00003omPWf003o`000?nfBKKo]TVf013o
]TVf00?o0000oj=LXonSG:<02?nSG:<00ol0003oVVFJoiYUVP06oiYUVP03o`000?ngB;Oo]dRg00[o
]dRg00?o0000onl@koo_4>l04_o_4>l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX0
0ooj1OX00ol0003om`SgooL8m`09ooL8m`03o`000?oU6^GoiA[U00coiA[U00?o0000omPWf?oH9mP0
0ooH9mP00ol0003o]TVfokI9]P0?okI9]P03o`000?nSG:?oXebS00WoXebS00?o0000oiYUV_nJIIX0
1onJIIX00ol0003o]dRgokM8]`09okM8]`03o`000?o_4>ooka3_01;oka3_00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L00ol0003oiA[UonDJ
i@0:onDJi@;o00001_oH9mP00ol0003o]TVfokI9]P0?okI9]P03o`000?nSG:?oXebS00WoXebS00?o
0000oiYUV_nJIIX02?nJIIX00ol0003o]dRgokM8]`07okM8]`03o`000?o_4>ooka3_01?oka3_00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L0
0ol0003oiA[UonDJi@09onDJi@03o`000?oH9mSof2OH00Oof2OH00?o0000okI9]_nfBKH03OnfBKH2
o`0000_oXebS00?o0000oiYUV_nJIIX02OnJIIX00ol0003o]dRgokM8]`06okM8]`03o`000?o_4>oo
ka3_01?oka3_4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5
n_oj1OX01ooj1OX00ol0003om`SgooL8m`06ooL8m`03o`000?oU6^GoiA[U00WoiA[U00?o0000omPW
f?oH9mP02?oH9mP00ol0003o]TVfokI9]P0;okI9]P;o000000?o]DZeo`000?nSG:<02_nSG:<00ol0
003oVVFJoiYUVP09oiYUVPKo00000ongB;L00ol0003oka3_onl@k`0Conl@k`03o`000?ok1?_on`Ck
00oon`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000ooL8moog2?L01?og2?L3o`00
00SoiA[U0_l0000;omPWf003o`000?nfBKKo]TVf00Wo]TVf0_l00004okE:]@03o`000?nSG:?oXebS
00SoXebS00?o0000oiYUV_nJIIX02?nJIIX00ol0003occ3?oll`c`04oll`c`?o00005?o_4>l3o`00
017on`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003om`SgooL8m`03o`0000?o
m@[e00?o0000onDJiOoU6^D01?oU6^D00ol0003of2OHomPWf00<omPWf003o`000?nfBKKo]TVf00Go
]TVf0ol00007okE:]@03o`000?nSG:?oXebS00OoXebS00?o0000oiYUV_nJIIX01onJIIX00ol0003o
cc3?oll`c`08oll`c`03o`000?o_4>ooka3_013oka3_00Go0000ooT6nOoi1_Won@Kio`00000@oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
nPGjooX5nP0;ooX5nP;o00001ooe2_D01?l0003oiA[UonDJiOoU6^D2o`0000oof2OH00?o0000okI9
]_nfBKH00onfBKH2o`0000[o]DZe00?o0000oj=LXonSG:<01onSG:<00ol0003oVVFJoiYUVP05oiYU
VP;o00003?o?<<l00ol0003oka3_onl@k`0=onl@k`;o00001Ooi1_T00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000ooX5n_oj1OX03?oj1OX00ol0003om@[eooD:m@07ooD:m@03o`000?oU6^Go0000017o
f2OH00Co0000okI9]_nfBKKo]TVf0_l0000=okE:]@03o`000?nSG:?oXebS00KoXebS00?o0000oiYU
V_nJIIX01?nJIIX00ol0003occ3?oll`c`0=oll`c`Co00002_o_4>l00ol0003on@KiooT6n@06ooT6
n@03o`000?ok1?_on`Ck00con`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oe2_Gom@[e00Wo
m@[e00?o0000omPWf?oH9mP04OoH9mP3o`00013o]DZe00?o0000oj=LXonSG:<01OnSG:<00ol0003o
VVFJoiYUVP03oiYUVP03o`000?o?<<oocc3?00kocc3?00Co0000oo@;m?od2oCom0_d1_l00003onl@
k`03o`000?oi1_Won@Ki00Son@Ki00?o0000oo/4nook1?/02ook1?/00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooD:mOoe2_D02_oe2_D00ol0003of2OHomPWf00AomPWf003o`000?neB[Go]DZe013o
]DZe00?o0000oj=LXonSG:<01OnSG:<00ol0003oVVFJoiYUVP02oiYUVP03o`000?o?<<oocc3?00oo
cc3?00?o0000oo@;m?od2o@01ood2o@3o`0000con@Ki00?o0000oo/4nook1?/02_ok1?/00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003om@[eooD:m@0<ooD:m@03o`000?oH9mSof2OH013of2OH00?o0000okE:]OneB[D0
4OneB[D00ol0003oXebSoj=LX`04oj=LX`03o`000?nJII[oVVFJ00;o00004Oo?<<l00ol0003om0_d
oo@;m00:oo@;m003o`000?oi1_Won@Ki00_on@Ki3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oj1O[onPGj00[onPGj00?o0000ooD:mOoe2_D03_oe
2_D00ol0003of2OHomPWf00=omPWf0;o00005?neB[D3o`0000CoXebS00?o0000oiYUV_l000004oo?
<<l00ol0003om0_doo@;m00:oo@;m003o`000?oi1_Won@Ki00_on@Ki00?o0000ood2oOom0_d02Oom
0_d00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oe2_Gom@[e00kom@[e00?o0000
omPWf?oH9mP02_oH9mP3o`000003omXUf_l0003o]DZe017o]DZe0_l00003olHiaP;o00000_nSG:<2
o`0001Cocc3?00?o0000oo@;m?od2o@02_od2o@00ol0003on@KiooT6n@0;ooT6n@03o`000?om0_go
o@;m00[oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ooj1OX00ol0003om@[eooD:m@0@ooD:m@03o`000?oH9mSof2OH00Kof2OH0ol00005omXU
fP03o`000?neB[Go]DZe00go]DZe0_l00007olHiaP?o00005Oo?<<l00ol0003om0_doo@;m00;oo@;
m003o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d03?om0_d3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?om0_goo@;m00Coo@;m1Ol00003ooX5nP03o`000?oe2_Gom@[e017o
m@[e00?o0000omPWf?oH9mP01?oH9mP2o`0000WofRGJ00?o0000okE:]OneB[D02_neB[D2o`0000_o
aSW600?o0000oll`coo?<<l04_o?<<l00ol0003om0_doo@;m00<oo@;m003o`000?oi1_Won@Ki00Wo
n@Ki00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ood2oOom0_d02_om0_d3o`0001Gom@[e00?o0000omPWf?oH9mP00ol0000<omXUfP03o`00
0?neB[Go]DZe00Oo]DZe0_l0000=olHiaP03o`000?o?<<oocc3?01;occ3?00?o0000oo@;m?od2o@0
3?od2o@00ol0003on@KiooT6n@09ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00coo@;m00?o
0000ooD:mOoe2_D05?oe2_D2o`0000oofRGJ00?o0000okE:]OneB[D01OneB[D2o`0000ooaSW600?o
0000oll`coo?<<l04_o?<<l00ol0003om0_doo@;m00<oo@;m003o`000?oi1_Won@Ki00Won@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m00goo@;m00?o0000ooD:mOoe2_D04ooe2_D2
o`00013ofRGJ00?o0000okE:]OneB[D00_neB[D2o`0001;oaSW600?o0000oll`coo?<<l04Oo?<<l0
0ol0003om0_doo@;m00<oo@;m003o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?om0_goo@;m
00koo@;m00?o0000ooD:mOoe2_D04_oe2_D01?l0003oka3_onl@kol0000@omXUfP04o`000?neB[Go
0000o`0001CoaSW600?o0000oll`coo?<<l04?o?<<l00ol0003om0_doo@;m00>oo@;m003o`000?oi
1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?oe2_Gom@[e017om@[e00?o0000
onl@koo_4>l00_o_4>l00ol0003ofRGJomXUfP0>omXUfP03o`000?o6>LKoaSW601CoaSW600?o0000
oll`coo?<<l03Oo?<<l4o`00013om0_d00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m
013oo@;m00?o0000ooD:mOoe2_D04?oe2_D00ol0003oka3_onl@k`03onl@k`03o`000?oJ9M[ofRGJ
00gofRGJ00?o0000olHia_o6>LH05?o6>LH00ol0003occ3?oll`c`07oll`c`Ko00000ooW6>L00ol0
003om0_doo@;m00>oo@;m003o`000?oi1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02?om0_d00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo@;mood2o@0@ood2o@03
o`000?oe2_Gom@[e00oom@[e00?o0000onl@koo_4>l01Oo_4>l00ol0003ofRGJomXUfP0<omXUfP03
o`000?o6>LKoaSW601GoaSW600?o0000oll`coo?<<l01_l0000:onLHi`03o`000?od2oCom0_d00go
m0_d00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_goo@;m013oo@;m00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oka3_onl@k`06onl@k`03o`000?oJ9M[ofRGJ00_ofRGJ00?o0000olHia_o6>LH0
5Oo6>LH3o`00017oiaSW00?o0000oo@;m?od2o@03?od2o@00ol0003on@KiooT6n@07ooT6n@03o`00
0?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ood2oOom0_d04_om0_d9o`0000Oom@[e00?o0000onl@koo_4>l02?o_4>l00ol0003ofRGJomXU
fP0:omXUfP03o`000?o6>LKoaSW601GoaSW600?o0000onLHiooW6>L04OoW6>L00ol0003om0_doo@;
m00=oo@;m003o`000?oi1_Won@Ki00Gon@Ki00?o0000ood2oOom0_d01oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo@;mood2o@0Bood2o@03o`000?ok1?_o
n`Ck00Kon`Ck1ol0000<onl@k`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000olHia_o6>LH05?o6>LH0
0ol0003oiaSWonLHi`0ConLHi`03o`000?od2oCom0_d00com0_d00Co0000ooT6nOoi1_Won@Ki1_l0
0007ood2o@03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d04Oom0_d0
0ol0003on`Ckoo/4n`0=oo/4n`03o`000?o_4>ooka3_00_oka3_00?o0000omXUf_oJ9MX02OoJ9MX0
0ol0003oaSW6olHiaP0ColHiaP03o`000?oW6>OoiaSW01CoiaSW1?l0000:oo@;m0Co00001_on0Oh2
o`0000Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_om0_d00ol0003on`Ckoo/4n`0=oo/4n`?o00003?o_4>l00ol0003ofRGJomXUfP08omXU
fP03o`000?o6>LKoaSW600ooaSW61?l0000GonLHi`04o`000?oh1oSon0OhooP7n0Ko00000ood2o@0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?oo@;mo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_om0_d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?oe2_Gom@[e
00?o00002_o_4>l00ol0003ofRGJomXUfP07omXUfP03o`000?o6>LKoaSW600SoaSW61ol00003on@K
i003o`000?oW6>OoiaSW01CoiaSW00?o0000ooP7n?oh1oP02?oh1oP3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oom0_d00ol0003o
n`Ckoo/4n`0>oo/4n`03o`000?oe2_Gom@[e00?om@[e0ol00008onl@k`03o`000?oJ9M[ofRGJ00Ko
fRGJ00Co0000olHia_o6>LKoaSW61ol0000:on@Ki003o`000?oW6>OoiaSW01CoiaSW00?o0000ooP7
n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ood2o@03o`000?ok1?_on`Ck00ko
n`Ck00?o0000ooD:mOoe2_D01_oe2_D3o`0000Koka3_00?o0000omXUf_oJ9MX01?oJ9MX5o`0001;o
i1_T00?o0000onLHiooW6>L04_oW6>L00ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000Coo@;m
00?o0000oo/4nook1?/03ook1?/00ol0003om@[eooD:m@09ooD:m@?o00001?o_4>l00ol0003ofRGJ
omXUfP03o`000003ooH9m_l0003oi1_T01Coi1_T00?o0000onLHiooW6>L04_oW6>L00ol0003on0Oh
ooP7n00;ooP7n003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?oo@;mo`000?ok1?/04?ok1?/00ol0003om@[eooD:
m@0<ooD:m@?o000000Coka3_o`000?l0003o00001?of2OH00ol0003oi1_Ton@Ki00Bon@Ki0;o0000
4ooW6>L00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?oe2_Gom@[e00oom@[e00?o0000ooH9m_of2OH01_of2OH00ol0003oi1_Ton@K
i00@on@Ki004o`000?oY5^WojAKYo`0001;oiaSW00?o0000ooP7n?oh1oP03?oh1oP00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oe2_Gom@[e00oom@[e00?o0000ooH9m_of2OH01_of
2OH00ol0003oi1_Ton@Ki00?on@Ki003o`000?oY5^WojAKY00;ojAKY00?o0000onLHiooW6>L03_oW
6>L00ol0003on0OhooP7n00=ooP7n003o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ok1?_o
n`Ck013on`Ck00?o0000ooD:mOoe2_D03_oe2_D00ol0003omPWfooH9mP07ooH9mP03o`000?oT6nCo
i1_T00koi1_T00?o0000onTFjOoY5^T01?oY5^T2o`0000koiaSW00?o0000ooP7n?oh1oP03Ooh1oP0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oe2_Gom@[e
00gom@[e00?o0000ooH9m_of2OH02?of2OH00ol0003oi1_Ton@Ki00=on@Ki003o`000?oY5^WojAKY
00GojAKY00?o0000ooL8mol000000_l0000:onLHi`03o`000?oh1oSon0Oh00kon0Oh00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ok1?_on`Ck013on`Ck00?o0000ooD:mOoe2_D03?oe2_D00ol0003o
mPWfooH9mP0:ooH9mP03o`000?oT6nCoi1_T00_oi1_T00?o0000onTFjOoY5^T01_oY5^T00ol0003o
m`SgooL8m`02ooL8m`?o00001ooW6>L00ol0003on0OhooP7n00>ooP7n003o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013on`Ck1?l0000:ooD:m@03o`000?of2OKomPWf00_omPWf00?o0000on@Ki?oT6n@0
2_oT6n@00ol0003ojAKYonTFj@06onTFj@03o`000?og2?Oom`Sg00Kom`Sg0_l00004onLHi`03o`00
0?oh1oSon0Oh00oon0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_goo@;m00?o00003Ook
1?/01?l0003oo0?loo`3o?ol0o`6o`0000?om@[e00?o0000ooH9m_of2OH03?of2OH00ol0003oi1_T
on@Ki009on@Ki003o`000?oY5^WojAKY00OojAKY00?o0000ooL8moog2?L02?og2?L3o`000003onLH
iol0003on0Oh013on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Coo@;m0ol0
0009oo/4n`03o`000?ol0ocoo0?l00Soo0?l0ol0000?ooH9mP03o`000?oT6nCoi1_T00Soi1_T00?o
0000onTFjOoY5^T02?oY5^T00ol0003om`SgooL8m`0;ooL8m`03o`000?oh1oSon0Oh013on0Oh00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Gon`Ck00?o0000oo`3o?ol0o`02ool0o`0
0ol0003omPWfooH9mP0=ooH9mP03o`000?oT6nCoi1_T00Ooi1_T00?o0000onTFjOoY5^T02?oY5^T0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oh1oSon0Oh00kon0Oh0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?om0_goo@;m00coo@;m0ol00002oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooH9
m_of2OH03_of2OH00ol0003oi1_Ton@Ki005on@Ki003o`000?oY5^WojAKY00WojAKY00?o0000ooL8
moog2?L03Oog2?L00ol0003on0OhooP7n00:ooP7n0?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o@;mood2o@0?ood2o@;o00003ool0o`00ol0003omPWfooH9mP0=ooH9mP03o`000?oT6nCoi1_T00Co
i1_T00?o0000onTFjOoY5^T02_oY5^T00ol0003om`SgooL8m`0=ooL8m`03o`000?oh1oSon0Oh00Oo
n0Oh0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0Aood2o@03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH03Oof2OH00ol0003oi1_Ton@Ki003on@Ki003o`00
0?oY5^WojAKY00[ojAKY00?o0000ooL8moog2?L03oog2?L00ol0003on0OhooP7n003ooP7n0?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH03Oof2OH00ol0003oi1_Ton@K
i002on@Ki003o`000?oY5^WojAKY00_ojAKY00?o0000ooL8moog2?L03oog2?L00ol0003on0OhooP7
n003o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aood2o@03o`000?ol
0ocoo0?l00koo0?l00?o0000ooH9m_of2OH03Oof2OH01?l0003oi1_Ton@Ki?l0000>onTFj@03o`00
0?og2?Oom`Sg013om`Sg0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000ooo@;m00?o
0000oo`3o?ol0o`03_ol0o`00ol0003omPWfooH9mP0=ooH9mPGo00003?oY5^T00ol0003om`SgooL8
m`0AooL8m`03o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oom0_d0
0ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00gomPWf00?o0000ooL8moog2?L00_og2?L3
o`0000WojAKY00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?of2OKomPWf00_omPWf00?o0000ooL8
moog2?L01_og2?L4o`0000GojAKY00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooH9m_of2OH02_of2OH00ol0003om`SgooL8m`0;ooL8m`?o000000?ojAKYo`000?og
2?L04_og2?L00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oom0_d3o`00013oo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003om`SgooL8m`0?ooL8m`;o
00004oog2?L00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ood2o@04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003omPWfooH9mP06ooH9mP;o
00004oog2?L00ol0003om`SgooL8m`0AooL8m`;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo@;mo`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooH9m_of2OH0
1?of2OH2o`0000;oo0?l00?o0000ooL8moog2?L04Oog2?L00ol0003om`SgooL8m`0?ooL8m`04o`00
0?ol0ocoo0?lo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooH9m_of2OH00oof2OH00ol0003oo0?l
oo`3o003oo`3o003o`000?og2?Oom`Sg013om`Sg4_l00004oo`3o0;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003omPWfooH9mP02o`0000Ooo0?l00?o
0000ooL8moog2?L03oog2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0ocoo0?l00Coo0?l00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on@KiooT6
n@0>ooT6n@03o`000?ol0ocoo0?l00Goo0?l0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ood2o@03o`000?ol0oco
o0?l00Woo0?l00?o0000ooL8moog2?L03?og2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0oco
o0?l00Soo0?l0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d00_om0_d00ol0003oo0?loo`3o009oo`3
o003o`000?og2?Oom`Sg00_om`Sg00?o0000ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o00:oo`3
o003o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oi1_Won@Ki00kon@Ki00?o0000oo`3o?ol0o`02ool0o`2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?om0_goo@;m00?oo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003om`SgooL8m`09ooL8m`03o`00
0?oi1_Won@Ki00kon@Ki00?o0000oo`3o?ol0o`03Ool0o`01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo0?l
oo`3o00;oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooT6nOoi1_T03ooi1_T00ol0003oo0?l
oo`3o00=oo`3o0Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003oo@;mood2o@04ood2o@03o`000?ol0ocoo0?l00coo0?l00?o0000ooL8moog2?L01_og
2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0ocoo0?l00coo0?l0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?om0_goo@;m00Koo@;m00?o0000
oo`3o?ol0o`03?ol0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oi1_Won@Ki00kon@Ki00?o0000
oo`3o?ol0o`02_ol0o`2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg
00Com`Sg00?o0000ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o008oo`3o0;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog
2?L00_og2?L00ol0003on@KiooT6n@0?ooT6n@03o`000?ol0ocoo0?l00Koo0?l0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?om0_goo@;m00Soo@;m
00?o0000oo`3o?ol0o`03_ol0o`01?l0003om`SgooL8moog2?L4o`0000kon@Ki00?o0000oo`3o?ol
0o`01?ol0o`2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?og2?Oo000000CooP7n
1_l00007ooT6n@03o`000?ol0ocoo0?l00?oo0?l0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;on@Ki00Co0000oo`3o?ol0ocoo0?l0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000ool0oco0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ood2o@03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
o@;mood2o@06ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ood2oOom0_d0
0oom0_d00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003oo@;mood2
o@02ood2o@03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?om0_goo@;mo`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo@;mo`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00__l00?l7oooo02;o003o1oooo`2Qo`00o`7ooooo002no`00o`;oool000?oMgN7o`00ool00?l0
:?l00?l00omgMhOoool0oooo002Qo`00o`7ooooo002no`00o`;oool0;?l00?l2oooo0:7o003o0Ooo
ool00;ko003o0_ooo`0/o`00o`;oool0XOl00?l1ooooo`00__l00?l2oooo02co003o0_ooo`2Qo`00
o`7ooooo002Uo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00_o
003o00?oEEFYoooo0?oMgB402Ol00?l00olb</coZJUEonk^4003oooo0004omgM8OnYZEGoIVJHoa0@
kP_o003o0_ooo`2Qo`00o`7ooooo002Uo`00o`03oiRHI_ooo`3oMgN700Oo003o00?oV9QVoooo0?mg
MhL03?l00?l2oooo00co003o0_ooo`000olQ8Mgo003oo`00o`06o`00o`Coool000Oo^[Y4ob4QgOl0
0?oo<S;<ojVYEOooo`3oMgN700[o003o0_ooo`2Qo`00o`7ooooo002Uo`00o`03onk^4?ooo`3ogMdQ
00Oo003o00?ok^h@oooo0?oMgB403?l00?l2oooo00co003o00?oZJUEoooo0?nHV6H02?l00?l01?nj
^TCoool0olc<<_m4A;X5o`00o`03ofIVV?ooo`3oZJUE00Wo003o0_ooo`2Qo`00o`7ooooo002To`00
o`05oc8bc?ooo`3oool0oooo0?l@4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_oo
o`0<o`00o`03oc8bc?ooo`3ok^h@01;o003o00?oZJUEoooo0?nYZED02?l00?l2oooo0:7o003o0Ooo
ool00:Co003o00GoZJUEoooo0?ooo`3oool0ofIVV005o`00o`05oiRHI_ooo`3oool0oooo0?mgMhL0
2ol00?l2oooo00go003o00?ok^h@oooo0?m4A;X04Ol00?l01?lb</coool0oooo0?m4A;X7o`00o`;o
ool0XOl00?l1ooooo`00Y?l00?l3oooo0003ofIVV?nj^TCo003o00Co003o00Gok^h@oooo0?ooo`3o
IVJHomgM8@0;o`00o`;oool03Ol00?l00on7QgOoool0ojVYE@0Bo`00o`;oool000?o^[Y4o`00ool0
0?l01Ol00?l2oooo0:7o003o0Oooool00:?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o413^
00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o8B7M00[o003o0_ooo`0=o`00o`03ob4QgOoo
o`3oool001;o003o0oooo`07o`00o`;oool0XOl00?l1ooooo`00Xol00?l01onYZEGoool0oooo0?nH
V6Ko003ooiRHI_mVIYP00ol00?l01onYZEGoool0oooo0?nHV6Ko003ooiRHI_mgMhL02_l00?l2oooo
00ko003o00?ogMdQoooo0?mVIYP04?l00?l01?mEEJWoool0oooo0?ooo`07o`00o`;oool0XOl00?l1
ooooo`00Xol00?l3oooo0004ob4QgOl00?ooA4BjokZjA0?o003o0oooo`001?lb</co003oodA4^_oM
gB4:o`00o`;oool03_l00?l00omVIYSoool0okZjA00@o`00o`04okZjA?ooo`3oool0oooo00Oo003o
0_ooo`2Qo`00o`7ooooo002Ro`00o`04oeEEZOooo`3oool0omgM8@?o003o00Coool0o`00ool00?oo
EEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0ob4Qg@Wo003o0_ooo`0>o`00o`04oa0@k_ooo`3o
ool0oa0@kPko003o00GoZJUEoooo0?ooo`3oool0ojVYE@07o`00o`;oool0XOl00?l1ooooo`00X_l0
0?l01?nYZEGoool0oooo0?mgMhL3o`00o`04ojVYEOmEEJWo003oojVYE@;oool000KoV9QVo`00ool0
0?oo003oojVYEOmgMhL9o`00o`;oool03ol00?l00onj^TCoool0ogMgQ`0<o`00o`03oc8bc?o<c3;o
ool000?oool000?o8B7Mo`00ool00?l01Ol00?l2oooo0:7o003o0Oooool00:;o003o0oooo`001olQ
8Mgo003oo`00ool00?ooEEFYojVYEOl00?l00oooo`001_lb</co003oo`00ool00?ooEEFYomgM8@Wo
003o0_ooo`0?o`00o`03oeEEZOooo`3ogMdQ00Wo003o00?oA4BjogMgQooMgB401Oooo`000omVIYSo
003oo`00o`06o`00o`;oool0XOl00?l1ooooo`00XOl00?l01?mEEJWoool0oooo0?oMgB45o`00o`05
onk^4?mEEJWoool0oooo0?o^kQ001Ol00?l00oooo`3o8B7Mo`00o`07o`00o`;oool04?l00?l2oooo
0003ob4QgOl00?oo003o00?o003o00?o<S;<oooo0?ooo`001oooo`000omVIYSo003oo`00o`07o`00
o`;oool0XOl00?l1ooooo`00XOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3oool0
oooo0?n7QgL01Ol00?l00onYZEGoMgN7o`00o`07o`00o`;oool04?l00?l00onYZEGoool0ohN7M`05
o`00o`03ob4QgOooo`3oool000Goool000?oZJUEob4QgOl00?l02Ol00?l2oooo0:7o003o0Oooool0
0:3o003o00Go413^oooo0?ooo`3oool0ob4Qg@05o`00o`05ofIVV?ooo`3oool0oooo0?lQ8Md01Ol0
0?l00omEEJWogMdQo`00o`07o`00o`;oool04?l00?l00olb</coool0onk^4006o`00o`07ojVYEOoo
o`3ok^h@olc<<_n7QgOoEEFYoa0@kP0<o`00o`;oool0XOl00?l1ooooo`00X?l00?l01?mVIYSoool0
oooo0?oMgB46o`00o`04ofIVV?ooo`3oool0omgM8@Oo003o00?oool0ob4QgOl00?l01_l00?l2oooo
00Ko003o00?oEEFYoa0@k_l00?l02?l00?l00oo^kQ3oool0oc8bc005o`00o`03ob4QgOo^kQ3o003o
013o003o0_ooo`2Qo`00o`7ooooo002Po`00o`04olc<<_ooo`3oool0ogMgQ`Ko003o00Co^[Y4oooo
0?ooo`3oMgN71ol00?l00onYZEGoMgN7o`00o`06o`00o`;oool01_l00?l2okZjA0Wo003o00?oQhMg
oooo0?nYZED01_l00?l00oo<c3;oEEFYo`00o`0?o`00o`;oool0XOl00?l1ooooo`00Wol00?l01OlQ
8Mgoool0oooo0?ooo`3o8B7M00Go003o00Go413^oooo0?ooo`3oool0ob4Qg@07o`00o`03oeEEZOoM
gB7o003o00Ko003o0_ooo`06o`00o`04oeEEZOooo`3o^[Y4ob4Qg@Oo003o00?o8B7Moooo0?ooo`00
1_l00?l00om4A;[oc<`bo`00o`0?o`00o`;oool0XOl00?l1ooooo`00Wol00?l01?nYZEGoool0oooo
0?oMgB46o`00o`04ogMgQoooo`3oool0omgM8@Wo003o00?oool0ob4QgOl00?l01Ol00?l2oooo00Oo
003o00?ok^h@oooo0?ooo`002_ooo`000omEEJWo003oo`00o`04o`00o`03olc<<_ooo`3oool000Go
ool000?oc<`bo`00ool00?l01_l00?l2oooo0:7o003o0Oooool009go003o00?o8B7MohN7Moooo`00
0_ooo`000oo^kQ3o<S;<o`00o`03o`00o`06oeEEZOooo`3oool0oooo0?o^kQ3o<S;<1_l00?l01_lQ
8MgoQhMgoooo0?o^kQ3oEEFYoa0@kPCo003o0_ooo`07o`00o`03ohN7Moooo`3oool000[oool000?o
^[Y4o`00ool00?l01?l00?l00omVIYSoool0oooo0006oooo0003ob4QgOl00?oo003o00Go003o0_oo
o`2Qo`00o`7ooooo002Lo`00o`03odA4^_ooo`3oool000Ooool000?oQhMgoooo0?ooo`001oooo`02
o`00o`03ohN7Moooo`3oool000Goool000CoA4Bjo`00ool00?oo003o0_ooo`000omgMhOo003oo`00
o`04o`00o`03ob4QgOooo`3oool000_oool01ol00?l00oo^kQ3oool0oooo0005oooo0003ogMgQol0
0?oo003o00Co003o00?oMgN7oooo0?ooo`00XOl00?l1ooooo`00__l00?l7oooo01ko003o00CoMgN7
omgM8Ol00?oo003o1oooo`2Qo`00o`7ooooo003To`00o`03ob4QgOl00?oo003o0:So003o0Oooool0
0?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(100) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.995 .005 .995 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.992 .008 .992 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.983 .017 .983 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.955 .045 .955 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.991 .009 .991 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.986 .014 .986 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.985 .015 .985 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.987 .013 .987 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.994 .006 .994 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.978 .022 .978 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.962 .038 .962 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.994 .006 .994 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.988 .012 .988 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.977 .023 .977 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.994 .006 .994 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.979 .021 .979 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.966 .034 .966 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.869 .131 .869 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.884 .116 .884 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.992 .008 .992 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.965 .035 .965 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.966 .034 .966 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.904 .096 .904 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.879 .121 .879 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.769 .231 .769 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.96 .04 .96 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.983 .017 .983 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.984 .016 .984 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.958 .042 .958 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.84 .16 .84 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.994 .006 .994 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.993 .007 .993 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.917 .083 .917 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.764 .236 .764 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.919 .081 .919 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.558 .442 .558 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.553 .447 .553 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.693 .307 .693 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.855 .145 .855 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.88 .12 .88 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.631 .369 .631 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.597 .403 .597 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.986 .014 .986 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.998 .002 .998 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.682 .318 .682 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.812 .188 .812 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.957 .043 .957 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.981 .019 .981 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.741 .259 .741 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.928 .072 .928 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.499 .501 .499 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.947 .053 .947 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.819 .181 .819 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.361 .639 .361 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.458 .542 .458 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.992 .008 .992 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.416 .584 .416 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.391 .609 .391 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.962 .038 .962 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.666 .334 .666 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.36 .64 .36 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.397 .603 .397 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.924 .076 .924 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.457 .543 .457 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.629 .371 .629 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.375 .625 .375 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.282 .718 .282 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.351 .649 .351 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.286 .714 .286 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.479 .521 .479 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.616 .384 .616 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.987 .013 .987 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.708 .292 .708 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.825 .175 .825 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.28 .72 .28 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.267 .733 .267 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.288 .712 .288 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.333 .667 .333 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.341 .659 .341 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.876 .124 .876 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.965 .035 .965 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.987 .013 .987 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.621 .379 .621 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.326 .674 .326 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.9 .1 .9 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.343 .657 .343 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.526 .474 .526 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.305 .695 .305 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.432 .568 .432 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.962 .038 .962 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.486 .514 .486 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.335 .665 .335 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.993 .007 .993 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.965 .035 .965 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.975 .025 .975 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.434 .566 .434 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.257 .743 .257 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.258 .742 .258 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.761 .239 .761 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.83 .17 .83 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.305 .695 .305 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.409 .591 .409 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.636 .364 .636 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.893 .107 .893 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.324 .676 .324 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.302 .698 .302 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.406 .594 .406 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.442 .558 .442 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.988 .012 .988 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.599 .401 .599 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.655 .345 .655 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.507 .493 .507 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.447 .553 .447 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.971 .029 .971 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.983 .017 .983 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.952 .048 .952 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.391 .609 .391 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.61 .39 .61 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.747 .253 .747 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.928 .072 .928 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.991 .009 .991 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.631 .369 .631 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.81 .19 .81 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.574 .426 .574 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.976 .024 .976 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.916 .084 .916 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.993 .007 .993 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.647 .353 .647 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.757 .243 .757 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.748 .252 .748 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.952 .048 .952 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.924 .076 .924 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.902 .098 .902 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.847 .153 .847 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.981 .019 .981 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.984 .016 .984 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.992 .008 .992 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.895 .105 .895 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.993 .007 .993 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.913 .087 .913 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.892 .108 .892 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.983 .017 .983 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.939 .061 .939 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.926 .074 .926 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.993 .007 .993 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.979 .021 .979 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.976 .024 .976 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.958 .042 .958 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.98 .02 .98 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.973 .027 .973 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.986 .014 .986 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.984 .016 .984 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.991 .009 .991 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.998 .002 .998 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.994 .006 .994 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000oof2OH00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooH9mP;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooH9mP03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Oof
2OH2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;omPWf00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooH9mP03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?of2OH2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ook1?/0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_of2OH00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ooh1o_on0OkooP7n1?l0000=oo/4n`03o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000KolPgbo`000?o/4nco0000om</dol0000JooH9mP;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?on0Oko000001;on`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?olPgb00Co0000on`Ck?o/4nco00000_oC;=<00ol0003omPWfooH9mP0IooH9
mP03o`000?on0Oko000001_on`Ck00?o0000oo/4nook1?/04_ok1?/00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005oo8=lP05o`000?o/4ncok1?/on`C
k?l000000ooC;=<00ol0003omPWfooH9mP0IooH9mP03o`000?ok1?_on`Ck01[on`Ck00?o0000oo/4
nook1?/04ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?ob3O801Ol0003ok1?/on`Ck?o/4nco000000CodbcC00?o0000ooH9
m_of2OH06?of2OH00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo/4n`?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[olPgb00?o0000on`Ck?o/
4n`00_o/4n`00ol0003odbcCom</d`03om</d`03o`000?of2OKomPWf01OomPWf00?o0000oo/4nook
1?/06Ook1?/00ol0003on`Ckoo/4n`0Foo/4n`05o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
n`Ck0_l0000:oo/4n`?o00003Oob3O800ol0003ok1?/on`Ck002on`Ck003o`000?oC;=?odbcC00Co
dbcC00?o0000ooH9m_of2OH05oof2OH00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?ok1?_on`Ck01Oo
n`Ck00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003on`Ckoo/4n`0;oo/4n`03o`000?ok1?_on`Ck00Con`Ck0ol0000?oo8=lP03o`00
0?o/4ncok1?/00?ok1?/00?o0000om</dooC;=<01OoC;=<00ol0003omPWfooH9mP0FooH9mP03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000oo/4nook1?/06Ook1?/00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ok1?_on`Ck00con`Ck00?o
0000oo/4nook1?/00ol0000Aoo8=lP03o`000?o/4ncok1?/00Cok1?/00?o0000om</dooC;=<01_oC
;=<2o`0001GomPWf0ol0000Hoo/4n`03o`000?ok1?_on`Ck01Won`Ck00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ok1?_on`Ck00gon`Ck0_l0000D
oo8=lP03o`000?o/4ncok1?/00Cok1?/00?o0000om</dooC;=<02?oC;=<00ol0003omPWfooH9mP0@
ooH9mP;o00000ooD:m@00ol0003on`Ckoo/4n`0Doo/4n`03o`000?ok1?_on`Ck01[on`Ck00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ok1?_on`Ck
00kon`Ck00?o0000oo8=l_ob3O804_ob3O800ol0003ok1?/on`Ck005on`Ck003o`000?oC;=?odbcC
00WodbcC00?o0000ooH9m_of2OH03Oof2OH2o`0000Koe2_D0_l0000Doo/4n`03o`000?ok1?_on`Ck
01[on`Ck00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003on`Ckoo/4n`0>oo/4n`03o`000?ob3O;olPgb01;olPgb00?o0000on`Ck?o/
4n`01Oo/4n`00ol0003odbcCom</d`0:om</d`03o`000?of2OKomPWf00[omPWf0_l0000:om@[e003
o`000?ok1?_on`Ck017on`Ck00?o0000oo/4nook1?/06_ok1?/00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo/4nook1?/03ook1?/00ol0003olPgboo8=lP0@oo8=lP03o`000?o/4ncok1?/00Ko
k1?/00?o0000om</dooC;=<02ooC;=<00ol0003omPWfooH9mP08ooH9mP03o`000?oD:mCoe2_D00_o
e2_D0_l0000@oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000on`Ck?o/4n`0
1oo/4n`00ol0003odbcCom</d`0<om</d`03o`000?of2OKomPWf00GomPWf0_l0000@om@[e003o`00
0?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/06ook1?/00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?ob3O;olPgb00oolPgb00?o0000on`Ck?o/4n`01oo/4n`00ol0003odbcCom</
d`0=om</d`03o`000?of2OKomPWf00;omPWf0_l0000Com@[e0;o00003?ok1?/00ol0003on`Ckoo/4
n`0Loo/4n`?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4n`0@oo/4n`03o`000?ob3O;o
lPgb00kolPgb00?o0000on`Ck?o/4n`02?o/4n`00ol0003odbcCom</d`0>om</d`04o`000?of2OKo
0000o`0001Ooe2_D00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0Loo/4n`03o`000?oi
1_Won@Ki00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?ob3O;o
lPgb00colPgb00?o0000on`Ck?o/4n`02Oo/4n`00ol0003odbcCom</d`0?om</d`03o`000?oD:mCo
e2_D01Soe2_D0_l00009oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000ooT6nOoi1_T01?oi1_T4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ok1?_on`Ck013on`Ck0_l0000>oo8=lP03o`000?o/4ncok1?/
00Wok1?/00?o0000om</dooC;=<03ooC;=<00ol0003oe2_Dom@[e00Jom@[e003o`000?ok1?_on`Ck
00Con`Ck0ol0000Loo/4n`03o`000?oi1_Won@Ki00Won@Ki0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003on`Ckoo/4n`0@oo/4n`04
o`000?oZ5N[ojQGZo`0000colPgb00?o0000on`Ck?o/4n`02_o/4n`00ol0003odbcCom</d`0?om</
d`03o`000?oD:mCoe2_D01_oe2_D0_l00003oo/4n`04o`000?o/4ncok1?/on`Ck0?o00006?ok1?/0
0ol0003on@KiooT6n@0=ooT6n@?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003on`Ckoo/4n`0?oo/4n`03o`000?oZ5N[ojQGZ
00;ojQGZ00?o0000oo8=l_ob3O802Oob3O800ol0003ok1?/on`Ck00:on`Ck003o`000?oC;=?odbcC
00kodbcC00?o0000om@[e?oD:m@07_oD:m@00ol0003on`Cko`000007on`Ck0?o00005?ok1?/00ol0
003on@KiooT6n@0AooT6n@;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003on`Ckoo/4n`0=oo/4n`;o00001_oZ5NX00ol0003olPgboo8=lP07oo8=lP03
o`000?o/4ncok1?/00_ok1?/00?o0000om</dooC;=<03_oC;=<00ol0003oe2_Dom@[e00Oom@[e003
o`000?o/4ncok1?/00Wok1?/0ol0000@oo/4n`03o`000?oi1_Won@Ki01?on@Ki00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo/4nook1?/03?ok1?/00ol0003ojQGZ
onXEjP07onXEjP03o`000?ob3O;olPgb00GolPgb00?o0000on`Ck?o/4n`03?o/4n`00ol0003odbcC
om</d`0>om</d`03o`000?oD:mCoe2_D01ooe2_D00?o0000on`Ck?o/4n`03?o/4n`3o`0000gon`Ck
00?o0000ooT6nOoi1_T05?oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo/4nook1?/02ook1?/2o`0000_ojQGZ00?o0000oo8=l_ob3O801?ob
3O800ol0003ok1?/on`Ck00<on`Ck003o`000?oC;=?odbcC00kodbcC00?o0000om@[e?oD:m@07_oD
:m@00ol0003ok1?/on`Ck00@on`Ck0?o00002Ook1?/00ol0003on@KiooT6n@0FooT6n@Oo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ok
1?_on`Ck00[on`Ck00?o0000onXEj_oZ5NX03?oZ5NX00ol0003olPgboo8=lP02oo8=lP03o`000?o/
4ncok1?/00gok1?/00?o0000om</dooC;=<03_oC;=<00ol0003oe2_Dom@[e00Nom@[e003o`000?o/
4ncok1?/01?ok1?/0ol00005oo/4n`03o`000?oi1_Won@Ki01Oon@Ki00?o0000oo/4nook1?/01?ok
1?/5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003on`Ckoo/4n`09oo/4n`03o`000?oZ5N[ojQGZ00kojQGZ00Go0000
oo8=l_ob3O;olPgbo`00000?on`Ck003o`000?oC;=?odbcC00godbcC00?o0000om@[e?oD:m@07ooD
:m@00ol0003ok1?/on`Ck00Fon`Ck0?o000000?on`Cko`000?oi1_T06?oi1_T00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ok1?_o
n`Ck00Oon`Ck0_l0000BonXEjP03o`000?ob3O;o0000013ok1?/00?o0000om</dooC;=<02ooC;=<3
o`00023oe2_D00?o0000on`Ck?o/4n`06_o/4n`00ol0003on@KiooT6n@0HooT6n@03o`000?ok1?_o
n`Ck00Won`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003on`Ckoo/4n`07oo/4n`03o`000?oZ5N[ojQGZ01?ojQGZ00?o0000on`C
k?o/4n`03oo/4n`00ol0003odbcCom</d`07om</d`Co00000_nNHIh00ol0003oe2_Dom@[e00Nom@[
e003o`000?o/4ncok1?/01[ok1?/00?o0000ooT6nOoi1_T05ooi1_T00ol0003on`Ckoo/4n`0:oo/4
n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ok1?/2o`0001Ko
jQGZ00?o0000on`Ck?o/4n`03oo/4n`00ol0003odbcCom</d`03om</d`Co00001onNHIh00ol0003o
e2_Dom@[e00Lom@[e003o`000?o/4ncok1?/01cok1?/00?o0000ooT6nOoi1_T05Ooi1_T00ol0003o
n`Ckoo/4n`0;oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?on`Ck00?o0000onXEj_oZ5NX05ooZ5NX00ol0003ok1?/on`Ck00>on`Ck003o`00
0?oC;=?o000000?o00003?nNHIh00ol0003oe2_Dom@[e00Kom@[e003o`000?o/4ncok1?/01cok1?/
00?o0000ooT6nOoi1_T05Ooi1_T00ol0003on`Ckoo/4n`0<oo/4n`03o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo/4nol000006_oZ
5NX5o`0000_ok1?/0ol0000AoiiQWP03o`000?oD:mCoe2_D01[oe2_D00?o0000on`Ck?o/4n`07Oo/
4n`00ol0003on@KiooT6n@0CooT6n@03o`000?ok1?_on`Ck00gon`Ck00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?oZ5N[ojQGZ01WojQGZ00?o0000
ojYEZ_nZEJX00_nZEJX7o`0000?ok1?/00?o0000oiiQW_nNHIh04onNHIh3o`0001Ooe2_D0_l0000P
on`Ck003o`000?oi1_Won@Ki01?on@Ki00?o0000oo/4nook1?/03Ook1?/00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000onXEj_oZ5NX06?oZ5NX00ol0
003oZUFZojYEZP0:ojYEZP?o00005_nNHIh00ol0003oKi1_ofn@K`05o`00013oe2_D0_l000000onW
F:Oo0000on`Ck00Oon`Ck003o`000?oi1_Won@Ki01;on@Ki00?o0000oo/4nook1?/03_ok1?/00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000onXEj_oZ5NX05_oZ5NX00ol0003oZUFZojYEZP0=ojYEZP03
o`000?nNHIkoWV6N01?oWV6N00?o0000ofn@Kom_T6l01_m_T6l4o`0000_oe2_D00?o0000ojMHYonW
F:L00_nWF:L00ol0003ok1?/on`Ck00Non`Ck003o`000?oi1_Won@Ki013on@Ki00?o0000oo/4nook
1?/03ook1?/00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ojQGZonXEjP0DonXEjP03o`000?nZEJ[oZUFZ00ooZUFZ
00?o0000oiiQW_nNHIh04_nNHIh00ol0003oKi1_ofn@K`0:ofn@K`Go00001?oD:m@2o`0000GoYeRW
00?o0000on`Ck?o/4n`07_o/4n`00ol0003on@KiooT6n@0@ooT6n@03o`000?ok1?_on`Ck00oon`Ck
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?oZ
5N[ojQGZ01CojQGZ00?o0000ojYEZ_nZEJX03onZEJX00ol0003oWV6NoiiQWP0BoiiQWP03o`000?m_
T6ooKi1_00ooKi1_1?l00008ojMHY`03o`000?o/4ncok1?/01kok1?/00?o0000ooT6nOoi1_T03_oi
1_T00ol0003on`Ckoo/4n`0@oo/4n`03o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
onXEj_oZ5NX04_oZ5NX00ol0003oZUFZojYEZP0@ojYEZP03o`000?nNHIkoWV6N017oWV6N00?o0000
ofn@Kom_T6l04Om_T6l00ol0003oLHiao`000009ojMHY`03o`000?o/4ncok1?/01gok1?/00?o0000
ooT6nOoi1_T03_oi1_T00ol0003on`Ckoo/4n`0@oo/4n`03o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000onXEj_oZ5NX03_oZ5NX3o`0001CoZUFZ00?o0000oiiQW_nNHIh04?nNHIh00ol0
003oKi1_ofn@K`0@ofn@K`04o`000?maSW7oLHiao`0000WoYeRW00?o0000on`Ck?o/4n`07_o/4n`0
0ol0003on@KiooT6n@0<ooT6n@03o`000?ok1?_on`Ck017on`Ck00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000onXEj_oZ5NX02_oZ5NX4o`0000;o/Dja00?o0000ojYE
Z_nZEJX04_nZEJX00ol0003oWV6NoiiQWP0@oiiQWP03o`000?m_T6ooKi1_00ooKi1_00Go0000og6>
LOmaSW7oLHiao`00000:ojMHY`03o`000?o/4ncok1?/01gok1?/00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000onXE
j_oZ5NX01OoZ5NX4o`0000Oo/Dja00?o0000ojYEZ_nZEJX04OnZEJX00ol0003oWV6NoiiQWP0?oiiQ
WP03o`000?m_T6ooKi1_013oKi1_00Go0000og6>LOmaSW7oLHiao`00000:ojMHY`03o`000?o/4nco
k1?/01gok1?/00?o0000ooT6nOoi1_T02ooi1_T00ol0003on`Ckoo/4n`0Coo/4n`04o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?oZ5N[o
jQGZ00Co00002onaC[400ol0003oZUFZojYEZP0BojYEZP03o`000?nNHIkoWV6N00koWV6N00?o0000
ofn@Kom_T6l03om_T6l00ol0003oLHiaog6>L@02og6>L@03o`000?nWF:OoYeRW00WoYeRW00?o0000
on`Ck?o/4n`07?o/4n`3o`0000[on@Ki00?o0000oo/4nook1?/05?ok1?/01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000onLHiol0003o00003onaC[400ol0003oZUFZojYEZP0AojYEZP03o`000?mO
Weoo000000ooWV6N00?o0000ofn@Kom_T6l03_m_T6l00ol0003oLHiaog6>L@03og6>L@03o`000?nW
F:OoYeRW00WoYeRW00?o0000on`Ck?o/4n`06Oo/4n`3o`0000?ojAKY00?o0000ooT6nOoi1_T01ooi
1_T00ol0003on`Ckoo/4n`0Coo/4n`Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?oW6>OoiaSWo`00017o/Dja00?o
0000ojYEZ_nZEJX03onZEJX01Ol0003oGimOoenOGomOWeoo000000[oWV6N1?l0000Aofn@K`03o`00
0?maSW7oLHia00?oLHia00?o0000ojMHYonWF:L02_nWF:L00ol0003ok1?/on`Ck00Fon`Ck0;o0000
1ooY5^T00ol0003on@KiooT6n@05ooT6n@03o`000?ok1?_on`Ck01?on`Ck00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003oiaSWonLHi`02onLHi`03o`000?naC[7o/Dja00ko/Dja00?o
0000ojYEZ_nZEJX03_nZEJX00ol0003oGimOoenOG`03oenOG`04o`000?nNHIkoWV6NoiiQWPKo0000
0omGZ5L00ol0003oKi1_ofn@K`0>ofn@K`03o`000?maSW7oLHia00CoLHia00?o0000ojMHYonWF:L0
2_nWF:L00ol0003ok1?/on`Ck00Con`Ck0?o00002_oY5^T00ol0003on@KiooT6n@03ooT6n@03o`00
0?ok1?_on`Ck01?on`Ck00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?oo@;m00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?oW
6>OoiaSW00?oiaSW00?o0000ok5>/OnaC[403_naC[400ol0003oZUFZojYEZP0=ojYEZP03o`000?mO
WeooGimO00GoGimO0ol0000:oeNXE`03o`000?m_T6ooKi1_00coKi1_00?o0000og6>LOmaSW401Oma
SW400ol0003oYeRWojMHY`0;ojMHY`03o`000?o/4ncok1?/013ok1?/0_l0000>onTFj@03o`000?oi
1_Won@Ki00;on@Ki00?o0000oo/4nook1?/04_ok1?/00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000Ooo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?oW6>OoiaSW00CoiaSW00?o0000ok5>/OnaC[403onaC[400ol0003oZUFZojYEZP0;
ojYEZP03o`000?mOWeooGimO00KoGimO00?o0000oeNXEomGZ5L02omGZ5L00ol0003oKi1_ofn@K`0;
ofn@K`03o`000?maSW7oLHia00GoLHia00?o0000ojMHYonWF:L03?nWF:L00ol0003ok1?/on`Ck00<
on`Ck0?o00004OoY5^T5o`0001;on`Ck0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003oo@;mood2o@09ood2o@;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?oW6>OoiaSW
00KoiaSW00?o0000ok5>/OnaC[403_naC[400ol0003oZUFZojYEZP0:ojYEZP03o`000?mOWeooGimO
00OoGimO00?o0000oeNXEomGZ5L02omGZ5L00ol0003oKi1_ofn@K`0:ofn@K`03o`000?maSW7oLHia
00KoLHia00?o0000ojMHYonWF:L03?nWF:L00ol0003ok1?/on`Ck00:on`Ck0;o00005?oY5^T00ol0
003onPGjooX5nP02ooX5nP;o00003ook1?/00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo@;mood2o@0<ood2
o@03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003oiaSWonLHi`07onLH
i`03o`000?naC[7o/Dja00ko/Dja00?o0000ojYEZ_nZEJX02OnZEJX00ol0003oGimOoenOG`08oenO
G`03o`000?mGZ5OoEjQG00coEjQG00?o0000ofn@Kom_T6l02?m_T6l00ol0003oLHiaog6>L@07og6>
L@03o`000?nWF:OoYeRW00goYeRW1Ol00004on`Ck0?o00005OoY5^T00ol0003onPGjooX5nP05ooX5
nP03o`000?ok1?_on`Ck00_on`Ck00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2
oOom0_d03_om0_d2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oiaSWonLHi`08onLH
i`03o`000?naC[7o/Dja00oo/Dja00?o0000ojYEZ_nZEJX01onZEJX00ol0003oGimOoenOG`09oenO
G`03o`000?mGZ5OoEjQG00coEjQG0ol00008ofn@K`03o`000?maSW7oLHia00OoLHia00?o0000ojMH
YonWF:L03OnWF:L00ol0003o_d2ookm0_`02okm0_`Co00006?oY5^T00ol0003onPGjooX5nP06ooX5
nP;o00002Ook1?/2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ood2oOom0_d04Oom0_d01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?oW6>OoiaSW
00[oiaSW00?o0000ok5>/OnaC[403_naC[400ol0003oZUFZojYEZP06ojYEZP03o`000?mOWeooGimO
00[oGimO00?o0000oeNXEomGZ5L02_mGZ5L2o`0000?oC[5>00?o0000ofn@Kom_T6l01?m_T6l00ol0
003oLHiaog6>L@08og6>L@03o`000?nWF:OoYeRW00coYeRW00?o0000okm0_ono@;l01_no@;l00ol0
003ojAKYonTFj@0EonTFj@03o`000?oj1O[onPGj00WonPGj0_l00006oo/4n`03o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ood2oOom0_d04oom0_d2o`0000konPGj00?o0000onLHiooW6>L02ooW6>L00ol0003o
/Djaok5>/@0>ok5>/@03o`000?nZEJ[oZUFZ00GoZUFZ00?o0000oenOGomOWel02omOWel00ol0003o
EjQGoeNXE`08oeNXE`;o00001_m>/Dh00ol0003oKi1_ofn@K`02ofn@K`03o`000?maSW7oLHia00Wo
LHia00?o0000ojMHYonWF:L03?nWF:L00ol0003o_d2ookm0_`07okm0_`03o`000?oY5^WojAKY01Co
jAKY00?o0000ooX5n_oj1OX02ooj1OX00ol0003on`Ckoo/4n`02oo/4n`03o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ood2oOom0_d05Oom0_d00ol0003onPGjooX5nP0;ooX5nP03o`00
0?oW6>OoiaSW00goiaSW00?o0000ok5>/OnaC[403_naC[400ol0003oZUFZojYEZP03ojYEZP03o`00
0?mOWeooGimO00coGimO00?o0000oeNXEomGZ5L01_mGZ5L2o`0000WoC[5>00Go0000ofn@Kom_T6oo
Ki1_o`00000;og6>L@03o`000?nWF:OoYeRW00coYeRW00?o0000okm0_ono@;l01ono@;l00ol0003o
jAKYonTFj@0ConTFj@03o`000?oj1O[onPGj00gonPGj0_l000000ook1?_o0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?om0_d00ol0003onPGjooX5nP0:ooX5nP03o`000?oW6>OoiaSW00ko
iaSW00?o0000ok5>/OnaC[403_naC[400ol0003oZUFZojYEZP02ojYEZP03o`000?mOWeooGimO00go
GimO00?o0000oeNXEomGZ5L01?mGZ5L2o`0000coC[5>00?o0000ofn@Kol000003?maSW400ol0003o
YeRWojMHY`0;ojMHY`03o`000?no@;oo_d2o00Wo_d2o00?o0000onTFjOoY5^T04OoY5^T00ol0003o
nPGjooX5nP0@ooX5nP03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001Woo@;m00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003oiaSWonLHi`0?onLHi`03o`000?naC[7o/Dja00ko/Dja00Go0000ojYEZ_nZEJ[o
ZUFZo`00000@oenOG`03o`000?mGZ5OoEjQG00;oEjQG0_l0000?odjaCP03o`000?maSW7oLHia00_o
LHia00?o0000ojMHYonWF:L02onWF:L00ol0003o_d2ookm0_`09okm0_`03o`000?oY5^WojAKY017o
jAKY00?o0000ooX5n_oj1OX04?oj1OX2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ood2oOom0_d05_om0_d3o`0000OonPGj00?o0000onLHiooW6>L04OoW6>L00ol0003o/Dja
ok5>/@0>ok5>/@Co00004?mOWel00ol0003oEjQGoeNXE`02o`00017oC[5>00?o0000og6>LOmaSW40
2omaSW400ol0003oYeRWojMHY`0:ojMHY`03o`000?no@;oo_d2o00_o_d2o00?o0000onTFjOoY5^T0
3ooY5^T00ol0003onPGjooX5nP0AooX5nP03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003oo@;mood2o@0Cood2o@;o00000ook1?/00ol0003onPGjooX5nP03ooX5nP03o`000?oW
6>OoiaSW01;oiaSW00?o0000ok5>/OnaC[403OnaC[400ol0003oJYEZofZEJP02ofZEJP;o00003_mO
Wel3o`0001?oC[5>00?o0000og6>LOmaSW402omaSW400ol0003oYeRWojMHY`0:ojMHY`03o`000?no
@;oo_d2o00_o_d2o00?o0000onTFjOoY5^T03ooY5^T00ol0003onPGjooX5nP0AooX5nP03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0A
ood2o@03o`000?ok1?_on`Ck00Con`Ck00Go0000ooX5n_oj1O[onPGjo`00000EonLHi`03o`000?na
C[7o/Dja00co/Dja00?o0000ofZEJ_mZUFX01OmZUFX2o`0000coGimO00?o0000odjaC_m>/Dh05?m>
/Dh00ol0003oLHiaog6>L@0:og6>L@03o`000?nWF:OoYeRW00[oYeRW00?o0000okm0_ono@;l03?no
@;l00ol0003ojAKYonTFj@0=onTFj@03o`000?oj1O[onPGj01;onPGj00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d03_om0_d2o`0000Son`Ck00?o0000
ooX5n_l000005ooW6>L00ol0003o/Djaok5>/@0:ok5>/@03o`000?mZUF[oJYEZ00SoJYEZ00?o0000
oenOGomOWel02?mOWel3o`0001GoC[5>0_l0000;og6>L@03o`000?nWF:OoYeRW00WoYeRW00?o0000
okm0_ono@;l03_no@;l00ol0003ojAKYonTFj@0<onTFj@03o`000?oj1O[onPGj01;onPGj00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?om0_d2o`00
00_on`Ck00?o0000onLHiooW6>L05_oW6>L00ol0003o/Djaok5>/@09ok5>/@03o`000?mZUF[oJYEZ
00[oJYEZ0_l00005oenOG`?o00000om7^4L00ol0003oC[5>odjaCP0AodjaCP03o`000?m>/DkoC[5>
00;o00002OmaSW400ol0003oYeRWojMHY`09ojMHY`03o`000?no@;oo_d2o00ko_d2o00?o0000onTF
jOoY5^T02ooY5^T00ol0003onPGjooX5nP0CooX5nP03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?om0_goo@;m00Ooo@;m0_l0000=oo/4n`03o`000?oW6>OoiaSW01Ko
iaSW00?o0000ok5>/OnaC[400onaC[46o`0000ooJYEZ0_l000000omOWeoo0000o`000007odNhA`;o
00004?m>/Dh00ol0003oC[5>odjaCP03odjaCP?o00001_maSW400ol0003oYeRWojMHY`09ojMHY`03
o`000?no@;oo_d2o00oo_d2o00?o0000onTFjOoY5^T02_oY5^T00ol0003onPGjooX5nP0CooX5nP03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@04ood2o@;o00004?ok1?/00ol0003oiaSW
onLHi`0FonLHi`Go00001OnQGZ400ol0003oJYEZofZEJP0?ofZEJP03o`000?m7^4OoAkQ700WoAkQ7
00?o0000odjaC_m>/Dh03?m>/Dh00ol0003oC[5>odjaCP07odjaCP;o00000_maSW4>o`0001;o_d2o
00?o0000onTFjOoY5^T02OoY5^T00ol0003onPGjooX5nP0DooX5nP03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003oo@;mood2o@02ood2o@03o`000?ok1?_on`Ck013on`Ck00?o0000onLHiooW6>L05OoW
6>L00ol0003oXEjQoj5NX@09oj5NX@03o`000?mZUF[oJYEZ00koJYEZ00?o0000odNhAom7^4L02_m7
^4L2o`0000_oC[5>00?o0000odjaC_m>/Dh02_m>/Dh2o`0000goPGj100?o0000okm0_ono@;l04Ono
@;l00ol0003ojAKYonTFj@07onTFj@03o`000?oj1O[onPGj01GonPGj0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ood2oOl0003o00005?ok1?/00ol0003oiaSWonLHi`0ConLHi`03o`000?nQGZ7oXEjQ00[oXEjQ00?o
0000ofZEJ_mZUFX03_mZUFX00ol0003oAkQ7odNhA`0<odNhA`03o`000?m>/DkoC[5>00OoC[5>00?o
0000odjaC_m>/Dh02om>/Dh00ol0003oPGj1oh5nP@0=oh5nP@03o`000?no@;oo_d2o013o_d2o00?o
0000onTFjOoY5^T01ooY5^T00ol0003onPGjooX5nP0EooX5nP04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?oW6>OoiaSW01;oiaSW00?o0000oj5NXOnQGZ402onQ
GZ400ol0003oJYEZofZEJP0>ofZEJP03o`000?m7^4OoAkQ700goAkQ700?o0000odjaC_m>/Dh01?m>
/Dh2o`0000koC[5>00?o0000oh5nPOn1OX403On1OX400ol0003o_d2ookm0_`0@okm0_`Co00001OoY
5^T00ol0003onPGjooX5nP0FooX5nP04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok
1?_on`Ck01Gon`Ck5?l0000?oj5NX@03o`000?mZUF[oJYEZ00coJYEZ00?o0000odRgB?l000003om7
^4L2o`0000?oC[5>00Co0000od6n@Om1_T7o00003Om>/Dh00ol0003oPGj1oh5nP@0>oh5nP@03o`00
0?no@;oo_d2o00co_d2o0ol00004omPWf0?o00000_oY5^T00ol0003onPGjooX5nP0FooX5nP03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo/4nook1?/05Ook1?/00ol0003ohAkQon4N
h@0@on4Nh@03o`000?nQGZ7oXEjQ00goXEjQ00?o0000ofZEJ_mZUFX02omZUFX01?l0003oB;M8odRg
B?l0000AodNhA`03o`000?m>/Dko000000Co@Ki100?o0000odjaC_m>/Dh02_m>/Dh00ol0003oPGj1
oh5nP@0>oh5nP@03o`000?no@;oo_d2o00Wo_d2o0ol0000:omPWf0;o00006?oj1OX00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?oQ7^7ohAkQ013ohAkQ00?o0000oj5NXOnQGZ403OnQ
GZ400ol0003oJYEZofZEJP0:ofZEJP03o`000?m8]dSoB;M800;oB;M800?o0000odNhAom7^4L03om7
^4L00ol0003o@Ki1od6n@@04od6n@@03o`000?m>/DkoC[5>00WoC[5>00?o0000oh5nPOn1OX403_n1
OX400ol0003o_d2ookm0_`06okm0_`?o00003_oH9mP00ol0003onPGjooX5nP0FooX5nP03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ok1?_on`Ck01Gon`Ck00?o0000
on4NhOoQ7^404_oQ7^400ol0003oXEjQoj5NX@0=oj5NX@03o`000?mZUF[oJYEZ00WoJYEZ00?o0000
odRgB?m8]dP00_m8]dP00ol0003oAkQ7odNhA`0?odNhA`03o`000?m1_T7o@Ki100Go@Ki100?o0000
odjaC_m>/Dh02?m>/Dh00ol0003oPGj1oh5nP@0?oh5nP@03o`000?no@;oo_d2o00;o_d2o0ol0000B
omPWf003o`000?oj1O[onPGj01GonPGj00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003on`Ckoo/4n`0Coo/4n`?o00005?oQ7^400ol0003oXEjQoj5NX@0=oj5NX@03o`000?mZUF[oJYEZ
00SoJYEZ00?o0000odRgB?m8]dP01?m8]dP00ol0003oAkQ7odNhA`0>odNhA`03o`000?m1_T7o@Ki1
00Ko@Ki100?o0000odjaC_m>/Dh01om>/Dh00ol0003oPGj1oh5nP@0?oh5nP@03o`000?no@;oo0000
00;o00005OoH9mP00ol0003onPGjooX5nP0EooX5nP03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ok1?_on`Ck00oon`Ck1?l00002oo@;m003o`000?oQ7^7ohAkQ01;o
hAkQ00?o0000oj5NXOnQGZ403OnQGZ400ol0003oJYEZofZEJP07ofZEJP03o`000?m8]dSoB;M800Go
B;M800?o0000odNhAom7^4L03Om7^4L00ol0003o@Ki1od6n@@08od6n@@03o`000?m>/DkoC[5>00Ko
C[5>00?o0000oh5nPOn1OX404?n1OX400ol0003of2OHomPWf00FomPWf003o`000?oj1O[onPGj01Go
nPGj00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/02ook1?/4o`0000Kom0_d
00?o0000on4NhOoQ7^404ooQ7^400ol0003oXEjQoj5NX@0=oj5NX@03o`000?mZUF[oJYEZ00GoJYEZ
00?o0000odRgB?m8]dP01om8]dP00ol0003oAkQ7odNhA`0<odNhA`03o`000?m1_T7o@Ki100Wo@Ki1
00?o0000odjaC_m>/Dh01Om>/Dh00ol0003oPGj1oh5nP@0@oh5nP@03o`000?oH9mSof2OH01Oof2OH
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/01ook
1?/4o`0000[om0_d00?o0000on4NhOoQ7^404ooQ7^400ol0003oXEjQoj5NX@0=oj5NX@03o`000?mZ
UF[oJYEZ00CoJYEZ00?o0000odRgB?m8]dP02?m8]dP00ol0003oAkQ7odNhA`0<odNhA`03o`000?m1
_T7o@Ki100[o@Ki100?o0000odjaC_m>/Dh01?m>/Dh00ol0003oPGj1oh5nP@0@oh5nP@03o`000?oH
9mSof2OH01Oof2OH00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003on`Ckoo/4n`04oo/4n`Co00003_od2o@00ol0003ohAkQon4Nh@0Con4Nh@03o`000?nQGZ7o
XEjQ00goXEjQ00?o0000ofZEJ_mZUFX01?mZUFX00ol0003oB;M8odRgB009odRgB003o`000?m7^4Oo
AkQ700_oAkQ700?o0000od6n@Om1_T402om1_T400ol0003oC[5>odjaCP03odjaCP03o`000?n1OX7o
PGj1013oPGj100?o0000omPWf?oH9mP05ooH9mP00ol0003onPGjooX5nP0CooX5nP03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`04o`0001;om0_d00?o0000on4NhOoQ7^404ooQ7^400ol0
003oXEjQoj5NX@0>oj5NX@03o`000?mZUF[oJYEZ00;oJYEZ00?o0000odRgB?m8]dP02_m8]dP00ol0
003oAkQ7odNhA`0:odNhA`03o`000?m1_T7o@Ki100go@Ki100?o0000odjaC_m>/Dh00_m>/Dh00ol0
003oPGj1oh5nP@0@oh5nP@03o`000?oH9mSof2OH01Sof2OH00?o0000ooX5n_oj1OX04_oj1OX00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000Goo@;m003
o`000?oQ7^7ohAkQ01?ohAkQ00?o0000oj5NXOnQGZ403?nQGZ44o`000003ofZEJ_l0003oB;M800go
B;M800?o0000odNhAom7^4L02Om7^4L00ol0003o@Ki1od6n@@0>od6n@@05o`000?m>/DkoC[5>odja
C_l000004_n1OX400ol0003of2OHomPWf00HomPWf0?o00004_oj1OX00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003om0_doo@;m00Foo@;m003o`000?oQ7^7ohAkQ
01?ohAkQ00?o0000oj5NXOnQGZ402onQGZ400ol0003oG:=LoebSG002oebSG0;o00003_m8]dP00ol0
003oAkQ7odNhA`09odNhA`03o`000?m1_T7o@Ki100oo@Ki100Co0000odjaC_m>/Dko00004_n1OX40
0ol0003of2OHomPWf00HomPWf003o`000?o]4^gokA;]00?o00003ooj1OX5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?od2oCom0_d01Gom0_d00?o0000on4NhOoQ7^404ooQ7^400ol0003oXEjQoj5NX@0:
oj5NX@03o`000?mLXecoG:=L00GoG:=L00?o0000odRgB?m8]dP03?m8]dP00ol0003oAkQ7odNhA`08
odNhA`03o`000?m1_T7o@Ki100oo@Ki11Ol0000Aoh5nP@03o`000?oH9mSof2OH01Oof2OH00?o0000
ondBkOo]4^d01?o]4^d3o`0000conPGj00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003om0_doo@;m00Doo@;m003o`000?oQ7^7ohAkQ01?ohAkQ00?o0000oj5NXOnQGZ402?nQGZ42o`00
00WoG:=L00?o0000odRgB?m8]dP02om8]dP00ol0003oAkQ7odNhA`07odNhA`03o`000?m1_T7o@Ki1
00go@Ki10ol00005oe:]DP03o`000?n1OX7oPGj100koPGj100?o0000omPWf?oH9mP05_oH9mP00ol0
003okA;]ondBk@08ondBk@?o00002?oj1OX00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?od2oCom0_d01?om0_d0_l0000Eon4Nh@03o`000?nQGZ7oXEjQ00KoXEjQ00?o0000oebSG?mL
Xe`02_mLXe`00ol0003oB;M8odRgB00:odRgB1[o00002OmB[E800ol0003oPGj1oh5nP@0<oh5nP@?o
00005_oH9mP00ol0003okA;]ondBk@0<ondBk@?o00001?oj1OX00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003om0_d
oo@;m00@oo@;m0;o00000_oN8Mh3o`0001;ohAkQ00?o0000oj5NXOnQGZ401?nQGZ42o`0000koG:=L
00?o0000odRgB?m8]dP01om8]dP2o`0000[oA;]400?o0000od:m@_m2_D803?m2_D800ol0003oDZeB
oe:]DP08oe:]DP;o00002_n1OX42o`0000?oTVfB0_l0000ComPWf003o`000?o]4^gokA;]013okA;]
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000oo@;m?od2o@03_od2o@00ol0003omPWfo`000005omhQgP;o00004?oQ
7^400ol0003oXEjQoj5NX@03oj5NX@03o`000?mLXecoG:=L00ooG:=L00?o0000odRgB?m8]dP01?m8
]dP2o`0000coA;]400?o0000od:m@_m2_D803?m2_D800ol0003oDZeBoe:]DP0:oe:]DP03o`000?n1
OX7oPGj100GoPGj10_l00007oi9]TP03o`000?oH9mSof2OH00oof2OH00?o0000ondBkOo]4^d04Oo]
4^d01?l0003on@KiooT6nOl0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000oo@;m?od2o@02ood2o@2o`0000;omPWf00?o
0000omhQg_oN8Mh01OoN8Mh2o`0000oohAkQ00Go0000oj5NXOnQGZ7oXEjQo`00000CoebSG003o`00
0?m8]dSoB;M800;oB;M800?o0000odBkA?m4^d@03Om4^d@00ol0003o@[e2od:m@P0;od:m@P03o`00
0?mB[E;oDZeB00_oDZeB00?o0000oh5nPOn1OX400_n1OX42o`0000[oTVfB0_l0000>omPWf003o`00
0?o]4^gokA;]017okA;]00Go0000ooT6nOoi1_Won@Kio`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003om0_doo@;m009oo@;m003o`00
0?of2OKomPWf00?omPWf00?o0000omhQg_oN8Mh01_oN8Mh3o`0000_ohAkQ1Ol0000EoebSG004o`00
0?m8]dSo0000o`00013oA;]400?o0000od:m@_m2_D802om2_D800ol0003oDZeBoe:]DP0<oe:]DP04
o`000?n1OX7o0000o`0000koTVfB0_l0000;omPWf003o`000?o]4^gokA;]017okA;]00?o0000ooT6
nOoi1_T00ooi1_T00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?od2oCom0_d00Kom0_d0_l00006ooH9mP03
o`000?oN8MkogR7N00WogR7N0_l00008on4Nh@03o`000?nHIiSoV6NH00;oV6NH00?o0000oebSG?mL
Xe`05?mLXe`00ol0003oA;]4odBkA00@odBkA003o`000?m2_D;o@[e200_o@[e200?o0000oe:]D_mB
[E803OmB[E800ol0003oTVfBoi9]TP0@oi9]TP03o`000?oH9mSof2OH00Oof2OH00?o0000ondBkOo]
4^d04Oo]4^d00ol0003on@KiooT6n@04ooT6n@03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000oo@;m?od2o@01?od2o@00ol0003omPWfooH9mP06ooH9mP03o`000?oN8MkogR7N00_ogR7N
0_l00005on4Nh@03o`000?nHIiSoV6NH00CoV6NH00?o0000oebSG?mLXe`04omLXe`00ol0003oA;]4
odBkA00@odBkA003o`000?m2_D;o@[e200_o@[e200?o0000oe:]D_mB[E803OmB[E800ol0003oTVfB
oi9]TP0Aoi9]TP;o00000ooH9mP4o`0001?okA;]00?o0000ooT6nOoi1_T01Ooi1_T00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000oo@;m?od2oCom0_d0_l00009ooH9mP03
o`000?oN8MkogR7N00gogR7N0ol000000ooQ7^7o0000oiQWV007oiQWV003o`000?mLXecoG:=L01;o
G:=L00?o0000odBkA?m4^d@04?m4^d@00ol0003o@[e2od:m@P0;od:m@P03o`000?mB[E;oDZeB00go
DZeB00?o0000oi9]T_nBKI804onBKI83o`0000?oi1_T00?o0000ondBkOo]4^d04?o]4^d00ol0003o
n@KiooT6n@07ooT6n@03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003om0_do`00000;ooH9mP03o`000?oN8MkogR7N013ogR7N00?o0000oiQWV?nHIiP0
2?nHIiP00ol0003oG:=LoebSG00AoebSG003o`000?m4^dCoA;]4017oA;]400?o0000od:m@_m2_D80
2_m2_D800ol0003oDZeBoe:]DP0<oe:]DP03o`000?mTVfCo000001CoTVfB00?o0000on@Ki?oT6n@0
1?oT6n@00ol0003okA;]ondBk@0>ondBk@03o`000?oi1_Won@Ki00Son@Ki00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?of2OKomPWf00_omPWf00?o0000omhQg_oN8Mh03ooN
8Mh00ol0003oV6NHoiQWV009oiQWV003o`000?mLXecoG:=L013oG:=L00?o0000odBkA?m4^d@04Om4
^d@00ol0003o@[e2od:m@P0:od:m@P03o`000?mB[E;oDZeB00_oDZeB00Co0000ofBKI?mTVfCo0000
5?nBKI800ol0003oi1_Ton@Ki005on@Ki003o`000?o]4^gokA;]00cokA;]00?o0000ooT6nOoi1_T0
2Ooi1_T00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oof2OH00ol0003ogR7NomhQ
gP0?omhQgP03o`000?nHIiSoV6NH00[oV6NH00?o0000oebSG?mLXe`03_mLXe`00ol0003oBKI9o`00
000BodBkA003o`000?m2_D;o@[e200[o@[e200?o0000oe:]D_mB[E802_mB[E800ol0003oI9]TofBK
I002ofBKI003o`000?nBKI;oTVfB013oTVfB00?o0000on@Ki?oT6n@01ooT6n@00ol0003okA;]ondB
k@0:ondBk@03o`000?oi1_Won@Ki00[on@Ki00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooH9mP03o`000?oN8MkogR7N00oogR7N00?o0000oiQWV?nHIiP0
2onHIiP00ol0003oG:=LoebSG00<oebSG005o`000?m9]TWoBKI9odVfBOl000004Om4^d@00ol0003o
@[e2od:m@P0:od:m@P03o`000?mB[E;oDZeB00WoDZeB00?o0000ofBKI?mTVf@00omTVf@00ol0003o
TVfBoi9]TP0@oi9]TP03o`000?oT6nCoi1_T00Soi1_T00?o0000ondBkOo]4^d02?o]4^d00ol0003o
n@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?of2OKomPWf00WomPWf00?o0000omhQg_oN8Mh03_oN8Mh00ol0003oV6NHoiQWV00=oiQWV003o`00
0?mLXecoG:=L00[oG:=L00?o0000odVfBOm9]TT00om9]TT00ol0003oA;]4odBkA00?odBkA003o`00
0?m2_D;o@[e200Wo@[e200?o0000oe:]D_mB[E802?mB[E800ol0003oI9]TofBKI005ofBKI003o`00
0?nBKI;oTVfB00ooTVfB00?o0000on@Ki?oT6n@02OoT6n@00ol0003okA;]ondBk@06ondBk@03o`00
0?oi1_Won@Ki00gon@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooH9m_of2OH02?of2OH00ol0003ogR7NomhQgP0>omhQgP03o`000?nH
IiSoV6NH00koV6NH00?o0000oebSG?mLXe`02?mLXe`00ol0003oBKI9odVfB@05odVfB@03o`000?m4
^dCoA;]400koA;]400?o0000od:m@_m2_D802Om2_D800ol0003oDZeBoe:]DP07oe:]DP03o`000?mT
VfCoI9]T00KoI9]T00?o0000oi9]T_nBKI803onBKI800ol0003oi1_Ton@Ki009on@Ki003o`000?o]
4^gokA;]00GokA;]00?o0000ooT6nOoi1_T03_oi1_T00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003ogR7NomhQgP0=
omhQgP03o`000?nHIiSoV6NH00ooV6NH00?o0000oebSG?mLXe`01_mLXe`00ol0003oBKI9odVfB@07
odVfB@03o`000?m4^dCoA;]400goA;]400?o0000od:m@_m2_D802Om2_D800ol0003oDZeBoe:]DP04
oe:]DP?o00002_mTVf@00ol0003oTVfBoi9]TP0=oi9]TP03o`000?oT6nCoi1_T00_oi1_T00?o0000
ondBkOo]4^d00oo]4^d00ol0003on@KiooT6n@0@ooT6n@03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003omPWfooH9mP08ooH9mP03o`000?oN8MkogR7N
00gogR7N00?o0000oiQWV?nHIiP04?nHIiP00ol0003oG:=LoebSG005oebSG003o`000?m9]TWoBKI9
00SoBKI900?o0000odBkA?m4^d@03?m4^d@00ol0003o@[e2od:m@P09od:m@P03o`000?mB[E;o0000
00Co00000_m=/Td00ol0003oI9]TofBKI008ofBKI003o`000?nBKI;oTVfB00goTVfB00?o0000on@K
i?oT6n@03?oT6n@01Ol0003okA;]ondBkOo]4^go000001;on@Ki0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?of2OKomPWf00OomPWf00?o0000omhQg_oN8Mh03OoN8Mh00ol0
003oV6NHoiQWV00AoiQWV003o`000?mLXecoG:=L00?oG:=L00?o0000odVfBOm9]TT02_m9]TT00ol0
003oA;]4odBkA00;odBkA003o`000?m2_D;o@[e200So@[e20ol00008odfbC@03o`000?mTVfCoI9]T
00SoI9]T00?o0000oi9]T_nBKI803?nBKI800ol0003oi1_Ton@Ki00=on@Ki003o`000?o]4^go0000
01;on@Ki00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003omPWfooH9mP07ooH9mP03o`000?oN8MkogR7N00gogR7N00?o0000oiQWV?nHIiP04_nHIiP01Ol0
003oG:=LoebSG?mLXeco000000koBKI900?o0000odBkA?m4^d@02om4^d@00ol0003o@[e2od:m@P06
od:m@P03o`000?m=/TgoCK9=00WoCK9=00?o0000ofBKI?mTVf@02OmTVf@00ol0003oTVfBoi9]TP0:
oi9]TP03o`000?oT6nCoi1_T00ooi1_T00?o0000ooT6nOoi1_T04?oi1_T00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?of2OKomPWf
00KomPWf00?o0000omhQg_oN8Mh03OoN8Mh00ol0003oV6NHoiQWV00CoiQWV003o`000?mLXeco0000
013oBKI93_l00006od:m@P;o00003?m=/Td00ol0003oI9]TofBKI009ofBKI003o`000?nBKI;oTVfB
00[oTVfB00?o0000on@Ki?oT6n@03ooT6n@00ol0003on@KiooT6n@0>ooT6n@;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?of2OKomPWf00KomPWf00?o0000omhQg_oN8Mh02ooN8Mh00ol0003o
V6NHoiQWV00DoiQWV0?o00003om9]TT00ol0003oBKI9odVfB@0<odVfB@04o`000?m2_D;o@[e2od:m
@P;o00003om=/Td00ol0003oI9]TofBKI009ofBKI003o`000?nBKI;oTVfB00WoTVfB00?o0000on@K
i?oT6n@04?oT6n@00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003omPWfooH9mP05ooH9mP03o`000?oN8MkogR7N00_o
gR7N00?o0000oiQWV?nHIiP04onHIiP01Ol0003oI9]TofBKI?mTVfCo000000goBKI900?o0000odVf
BOm9]TT03_m9]TT00ol0003o@[e2o`00000AodfbC@03o`000?mTVfCoI9]T00WoI9]T00?o0000oi9]
T_nBKI802OnBKI800ol0003oi1_Ton@Ki00@on@Ki003o`000?oi1_Won@Ki00_on@Ki00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?of2OKomPWf00Go
mPWf4Ol0000BoiQWV003o`000?mTVfCoI9]T00?oI9]T00?o0000odVfBOm9]TT02Om9]TT00ol0003o
BKI9odVfB@0@odVfB@03o`000?m=/TgoCK9=017oCK9=00?o0000ofBKI?mTVf@02OmTVf@00ol0003o
TVfBoi9]TP07oi9]TP03o`000?oT6nCoi1_T017oi1_T00?o0000ooT6nOoi1_T02_oi1_T00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH00oof2OH00ol0003o
hQgRon8MhP0<on8MhP03o`000?n>LHkoSW6>00?o00003_nHIiP00ol0003oI9]TofBKI005ofBKI003
o`000?m9]TWoBKI900OoBKI900?o0000odVfBOm9]TT04Om9]TT00ol0003oCK9=odfbC@0AodfbC@03
o`000?mTVfCoI9]T00WoI9]T00?o0000oi9]T_nBKI801_nBKI82o`0001Coi1_T00?o0000ooT6nOoi
1_T01ooi1_T2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooH9m_l0003ohQgR00kohQgR
00?o0000ohiaS_n>LHh00on>LHh3o`0000[oV6NH00?o0000ofBKI?mTVf@01omTVf@00ol0003oBKI9
odVfB@05odVfB@03o`000?m9]TWoBKI901;oBKI900?o0000odfbCOm=/Td04Om=/Td00ol0003oI9]T
ofBKI00:ofBKI003o`000?nBKI;oTVfB00;oTVfB0ol00002ojEJY@03o`000?oT6nCoi1_T017oi1_T
00?o0000ooT6nOoi1_T01_oi1_T00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004ooX5nP03o`000?oR7N;ohQgR00kohQgR00?o0000ohiaS_n>LHh01_n>
LHh3o`0000KoV6NH00?o0000ofBKI?mTVf@02OmTVf@00ol0003oBKI9odVfB@03odVfB@03o`000?m9
]TWoBKI901?oBKI900?o0000odfbCOm=/Td04_m=/Td00ol0003oI9]TofBKI009ofBKI003o`000?nB
KI;o000000;o00001_nUFZD00ol0003oi1_Ton@Ki00@on@Ki003o`000?oi1_Won@Ki00Gon@Ki00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007ooX5nP03o`000?oR7N;o
hQgR00gohQgR00?o0000ohiaS_n>LHh02_n>LHh3o`0000;oV6NH00?o0000ofBKI?mTVf@02omTVf@0
1Ol0003oBKI9odVfBOm9]TWo000001KoBKI900?o0000odfbCOm=/Td04_m=/Td00ol0003oI9]TofBK
I00:ofBKI003o`000?nUFZGoYEZU00SoYEZU00?o0000on@Ki?oT6n@04?oT6n@00ol0003on@KiooT6
n@02ooT6n@?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:ooX5nP03o`00
0?oR7N;ohQgR00gohQgR00?o0000ohiaS_n>LHh03On>LHh2o`0000ooI9]T00?o0000odVfBOl00000
5om9]TT00ol0003oCK9=odfbC@0CodfbC@03o`000?mTVfCoI9]T00WoI9]T00?o0000ojEJYOnUFZD0
2OnUFZD00ol0003oi1_Ton@Ki00?on@Ki003o`000?oi1_Won@Ki00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000on8Mh_oR7N803OoR
7N800ol0003oSW6>ohiaSP0>ohiaSP03o`000?mTVfCoI9]T00koI9]T00?o0000odVfBOm9]TT05_m9
]TT00ol0003oCK9=odfbC@0CodfbC@03o`000?mTVfCoI9]T00SoI9]T00?o0000ojEJYOnUFZD02onU
FZD5o`0000coi1_T00?o0000ooT6nOl000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000on8Mh_oR7N803OoR7N800ol0003oSW6>ohiaSP0>
ohiaSP03o`000?mTVfCoI9]T00koI9]T00?o0000odVfBOm9]TT05_m9]TT00ol0003oCK9=odfbC@0C
odfbC@03o`000?mTVfCoI9]T00OoI9]T00?o0000ojEJYOnUFZD03?nUFZD00ol0003oiA[UonDJi@02
onDJi@Wo00001?oT6n@00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003ohQgRon8MhP0<on8MhP03o`000?n>LHkoSW6>
00koSW6>00?o0000ofBKI?mTVf@03omTVf@00ol0003oBKI9odVfB@0EodVfB@03o`000?m=/TgoCK9=
01?oCK9=1?l00005ofBKI003o`000?nUFZGoYEZU00goYEZU00?o0000onDJiOoU6^D02ooU6^D4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03
o`000?oR7N;ohQgR00_ohQgR00?o0000ohiaS_n>LHh03on>LHh00ol0003oI9]TofBKI00?ofBKI003
o`000?m9]TWoBKI901GoBKI900?o0000odfbCOm=/Td04?m=/Td3o`0000CoLXeb0ol000000omTVfCo
0000ojEJY@0>ojEJY@03o`000?oU6^GoiA[U00ooiA[U00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003ohQgRon8MhP0;on8MhP03o`00
0?n>LHkoSW6>00ooSW6>00?o0000ofBKI?mTVf@03omTVf@2o`0001CoBKI90ol0000@odfbC@;o0000
2_mbSG800ol0003oYEZUojEJY@0>ojEJY@03o`000?oU6^GoiA[U013oiA[U0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oR7N;ohQgR00_ohQgR4ol0000>ofBKI0?o0000
0_mLXe`00ol0003oBKI9odVfB@0<odVfB@Go00000_mC[5<00ol0003oCK9=odfbC@0<odfbC@;o0000
3?mbSG800ol0003oYEZUojEJY@0>ojEJY@03o`000?oU6^GoiA[U013oiA[U00?o0000ooD:mOl00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oR
7N;ohQgR00_ohQgR00?o0000ohebSOn=LXd03on=LXd00ol0003oI9]TofBKI009ofBKI0?o00001_mL
Xe`00ol0003oBKI9odVfB@06odVfB@Go00002?mC[5<00ol0003oCK9=odfbC@08odfbC@?o00003omb
SG800ol0003oYEZUojEJY@0=ojEJY@03o`000?oU6^GoiA[U00ooiA[U00Go0000ooD:mOoe2_Gom@[e
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ohQgRon8M
hP0;on8MhP03o`000?n=LXgoSG:=00ooSG:=00?o0000ofBKI?mTVf@01_mTVf@3o`0000[oG:=L00?o
0000odVfBOm9]TT01Ol0000>oe>/D`03o`000?m=/TgoCK9=00GoCK9=0_l0000Bog:=LP03o`000?nU
FZGoYEZU00coYEZU00?o0000onDJiOoU6^D04?oU6^D00ol0003om@[eooD:m@02ooD:m@03o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003ohQgRon8MhP0;
on8MhP03o`000?n=LXgoSG:=013oSG:=00?o0000ofBKI?mTVf@00_mTVf@3o`0000goG:=L0ol0000C
oe>/D`03o`000?m=/TgoCK9=00?oCK9=0_l0000Eog:=LP03o`000?nUFZGoYEZU00_oYEZU00?o0000
onDJiOoU6^D03ooU6^D00ol0003om@[eooD:m@04ooD:m@03o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003ohQgRon8MhP08on8MhPCo00004On=LXd00ol0003oI9]To`000002o`00
00ooG:=L00?o0000oeVVFOl000005OmC[5<00ol0003oCK9=o`000002o`0001OoLXeb00?o0000ojEJ
YOnUFZD02onUFZD00ol0003oiA[UonDJi@0>onDJi@03o`000?oe2_Gom@[e00Kom@[e00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oR7N;ohQgR00Go
hQgR0ol00004ol@ka003o`000?n=LXgoSG:=00koSG:=0_l0000AoebSG004o`000?mIYUWoFJIIo`00
01KoDjaC00?o0000og:=L_mbSG806?mbSG800ol0003oYEZUojEJY@0;ojEJY@03o`000?oU6^GoiA[U
00koiA[U00?o0000ooD:mOoe2_D01ooe2_D00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oR7N;ohQgR00;ohQgR0ol00008ol@ka003
o`000?n=LXgoSG:=00coSG:=0ol0000?oebSG0;o00000omIYUT00ol0003oDjaCoe>/D`0Doe>/D`03
o`000?mbSG;oLXeb01WoLXeb00?o0000ojEJYOnUFZD02_nUFZD00ol0003oiA[UonDJi@0=onDJi@03
o`000?oe2_Gom@[e00Wom@[e00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oj1O[onPGj00OonPGj1_l0000<ol@ka003o`000?n=LXgoSG:=00[oSG:=00Go0000ogn0OomoP7oo
Oh1oo`00000=oebSG003o`000?mIYUWoFJII00CoFJII00?o0000oe>/DomC[5<04omC[5<00ol0003o
LXebog:=LP0Iog:=LP03o`000?nUFZGoYEZU00WoYEZU00?o0000onDJiOoU6^D03_oU6^D00ol0003o
m@[eooD:m@0:ooD:m@;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000GonPGj0_l00004ooL8m`03o`00
0?o4>lCoa3_400coa3_40_l00008ohebS@;o00001OmoP7l00ol0003oG:=LoebSG009oebSG003o`00
0?mIYUWoFJII00GoFJII00?o0000oe>/DomC[5<04omC[5<00ol0003oLXebog:=LP0Jog:=LPgo0000
3_oU6^D00ol0003om@[eooD:m@0;ooD:m@03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?onPGjo`000?og2?L01_og2?L00ol0003oa3_4ol@ka00=ol@ka003o`000?n=
LXgoSG:=00CoSG:=00?o0000ogn0OomoP7l01_moP7l2o`0000SoG:=L00?o0000oeVVFOmIYUT01_mI
YUT00ol0003oDjaCoe>/D`0Doe>/D`03o`000?mbSG;oLXeb01WoLXeb00?o0000ol4n`Oo1?/402_o1
?/400ol0003oiA[UonDJi@0;onDJi@03o`000?oe2_Gom@[e00com@[e00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o0000ol@ka?o4>l@03_o4>l@0
1?l0003oSG:=ohebSOn=LXd2o`0000_oOh1o00?o0000oebSG?mLXe`00omLXe`2o`0000WoFJII00?o
0000oe>/DomC[5<05?mC[5<00ol0003oLXebog:=LP0Hog:=LP03o`000?o1?/7o`Ck100co`Ck100?o
0000onDJiOoU6^D02OoU6^D00ol0003om@[eooD:m@0=ooD:m@03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooL8moog2?L01oog2?L00ol0003oa3_4ol@ka00>ol@ka003o`000?n=LXgo
000000koOh1o00Go0000oebSG?mLXecoG:=Lo`00000;oeVVF@03o`000?mC[5?oDjaC01CoDjaC0_l0
000Iog:=LP03o`000?o1?/7o`Ck100go`Ck10_l00008onDJi@03o`000?oe2_Gom@[e00kom@[e00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooL8moog2?L01oog2?L00ol0003oa3_4ol@ka00?
ol@ka003o`000?moP7ooOh1o00koOh1o00?o0000oebSG?l000003?mIYUT00ol0003oDjaCoe>/D`0D
oe>/D`03o`000?mWV6Oo000000;o00005OmbSG800ol0003o`Ck1ol4n`@0@ol4n`@03o`000?oU6^Go
iA[U00GoiA[U00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooL8
moog2?L02?og2?L00ol0003oa3_4ol@ka00>ol@ka003o`000?moP7ooOh1o00koOh1o0_l0000=oeVV
F@03o`000?mC[5?oDjaC01?oDjaC00?o0000ofNHIomWV6L00omWV6L2o`0001;oLXeb00?o0000ol4n
`Oo1?/404_o1?/401?l0003oiA[UonDJiOoU6^D3o`0001;om@[e00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?og2?Oom`Sg00Som`Sg00?o0000ol@ka?o4>l@03Oo4>l@2o`0000ooOh1o00?o0000ogF:
MOl000003_mIYUT00ol0003oDjaCoe>/D`0Boe>/D`03o`000?mWV6OoIiQW00GoIiQW0ol0000?og:=
LP03o`000?o1?/7o`Ck101?o`Ck10ol00002oo0?l003o`000?oe2_Gom@[e013om@[e00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wom`Sg00?o0000ol@ka?o4>l@02oo4>l@00ol0003o
`cc3o`00000>ogn0O`05o`000?meRWGoMHYeogF:MOl000003OmIYUT00ol0003oDjaCoe>/D`0Aoe>/
D`03o`000?mWV6OoIiQW00WoIiQW0ol0000:og:=LP;o00005_o1?/400ol0003ol0o`oo0?l003oo0?
l003o`000?oe2_Gom@[e013om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000ol@ka?o4>l@02_o4>l@01Ol0003o`cc3ol<l`oo3?<?o000000coOh1o00?o0000ogF:
MOmeRWD00_meRWD00ol0003oFJIIoeVVF@0;oeVVF@03o`000?mC[5?oDjaC017oDjaC00?o0000ofNH
IomWV6L03?mWV6L2o`0000KoLXeb0_l000000onQGZ7o0000ol4n`@0Dol4n`@03o`000?o`3o3ol0o`
00Gol0o`00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooL8moog
2?L02_og2?L00ol0003oa3_4ol@ka007ol@ka0;o00001Oo3?<<00ol0003oOh1oogn0O`08ogn0O`03
o`000?meRWGoMHYe00CoMHYe00?o0000oeVVFOmIYUT02OmIYUT4o`00013oDjaC00?o0000ofNHIomW
V6L03omWV6L3o`000003og:=L_l0003o000000CoXEjQ00?o0000ol4n`Oo1?/404Oo1?/400ol0003o
l0o`oo0?l007oo0?l003o`000?oe2_Gom@[e00oom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?og2?Oom`Sg00[om`Sg00?o0000ol@ka?o4>l@01_o4>l@00ol0003o`cc3ol<l``05ol<l``03o`00
0?moP7ooOh1o00OoOh1o00?o0000ogF:MOmeRWD01OmeRWD00ol0003oFJIIoeVVF@08oeVVF@03o`00
0?mEZUGoEJYE00;oEJYE0ol0000=oe>/D`03o`000?mWV6OoIiQW01;oIiQW00?o0000oj5NXOnQGZ40
1OnQGZ400ol0003o`Ck1ol4n`@0@ol4n`@03o`000?o`3o3ol0o`00Ool0o`00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L02oog2?L00ol0003oa3_4ol@k
a004ol@ka003o`000?o3?<?o`cc300Oo`cc300?o0000ogn0OomoP7l01OmoP7l00ol0003oMHYeogF:
M@07ogF:M@03o`000?mIYUWoFJII00KoFJII00?o0000oeFZEOmEZUD01_mEZUD3o`0000SoDjaC0_l0
000EofNHI`03o`000?nQGZ7oXEjQ00KoXEjQ00?o0000ol4n`Oo1?/403_o1?/400ol0003ol0o`oo0?
l009oo0?l003o`000?oe2_Gom@[e00kom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?og2?Oo
m`Sg00_om`Sg00?o0000ol@ka?o4>l@00_o4>l@2o`0000[o`cc300?o0000ogn0OomoP7l01?moP7l0
0ol0003oMHYeogF:M@09ogF:M@03o`000?mIYUWoFJII00?oFJII0_l0000<oeFZE@?o00000_mC[5<3
o`000003oeFZEOl0003oIiQW01CoIiQW00?o0000oj5NXOnQGZ401onQGZ400ol0003o`Ck1ol4n`@0<
ol4n`@03o`000?o`3o3ol0o`00_ol0o`00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooL8moog2?L03?og2?L01?l0003oa3_4ol@ka?l0000=ol<l``03o`000?moP7oo
Oh1o00;oOh1o00?o0000ogF:MOmeRWD02_meRWD00ol0003oFJIIoeVVF@02oeVVF@03o`000?mEZUGo
EJYE00ooEJYE0_l00005oeFZE@03o`000?mWV6OoIiQW01;oIiQW00?o0000oj5NXOnQGZ402?nQGZ40
0ol0003o`Ck1ol4n`@0:ol4n`@03o`000?o`3o3ol0o`00gol0o`1Ol0000;ooD:m@03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003om`SgooL8m`0<ooL8m`03o`000?o4>lCo000000oo`cc300Co0000ogn0
OomoP7oo00003_meRWD01?l0003oFJIIoeVVFOl0000CoeFZE@03o`000?mEZUGoEJYE00CoEJYE00?o
0000ofNHIomWV6L04?mWV6L00ol0003oXEjQoj5NX@09oj5NX@03o`000?o1?/7o`Ck100[o`Ck100?o
0000oo0?l?o`3o003Oo`3o000ol0003onPGjooX5nP02ooX5nPWo00000_oe2_D00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooL8m`03o`000?o3?<?o`cc300ko`cc300?o0000ogn0Ool000003omeRWD0
0ol0003oFJIIo`00000CoeFZE@03o`000?mEZUGoEJYE00GoEJYE00?o0000ofNHIomWV6L04?mWV6L0
0ol0003oXEjQoj5NX@0:oj5NX@03o`000?o1?/7o`Ck100So`Ck100?o0000oo0?l?o`3o003Oo`3o00
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000ol<l
`oo3?<<03oo3?<<00ol0003oMHYeogF:M@0>ogF:M@;o00005?mEZUD00ol0003oEJYEoeFZE@06oeFZ
E@03o`000?mWV6OoIiQW00ooIiQW00?o0000oj5NXOnQGZ402onQGZ400ol0003o`Ck1ol4n`@04ol4n
`@?o00004?o`3o000ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003o
`cc3ol<l``0@ol<l``03o`000?meRWGoMHYe00_oMHYe0ol000000omUVVGo0000oeFZE@0BoeFZE@03
o`000?mEZUGoEJYE00OoEJYE00?o0000ofNHIomWV6L03omWV6L00ol0003oXEjQoj5NX@0<oj5NX@03
o`000?o1?/7o`Ck100?o00000ooV6NH00ol0003ol0o`oo0?l00=oo0?l003o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Wom`Sg00?o0000ol<l`oo3?<<04?o3?<<3o`0000WoMHYe0_l00005ofFJI@03o`00
0?mEZUGoEJYE013oEJYE00?o0000oeFZEOmEZUD02?mEZUD00ol0003oIiQWofNHI`0>ofNHI`03o`00
0?nQGZ7oXEjQ00goXEjQ0_l00007onHIiP03o`000?o`3o3ol0o`00_ol0o`00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003om`SgooL8m`06ooL8m`03o`000?o3?<?o`cc300oo`cc300Co
0000ojiA[_n^DJko[U6^0_l00005ogF:M@;o00002?mUVVD00ol0003oEJYEoeFZE@0>oeFZE@03o`00
0?mEZUGoEJYE00[oEJYE00?o0000ofNHIomWV6L03?mWV6L00ol0003oXEjQoj5NX@0>oj5NX@03o`00
0?oV6NKoiQWV00OoiQWV00?o0000oo0?l?o`3o002_o`3o000ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?og2?Oom`Sg00Com`Sg4ol00006ojiA[P03o`000?meRWGo000000;o00002_mU
VVD00ol0003oEJYEoeFZE@0=oeFZE@03o`000?mEZUGoEJYE00_oEJYE00?o0000ofNHIomWV6L03?mW
V6L00ol0003oXEjQoj5NX@0=oj5NX@03o`000?oV6NKoiQWV00WoiQWV00?o0000oo0?l?o`3o002?o`
3o000ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003om`SgooL8m`03ooL8m`03o`000?o[5>_o
jaC[00oojaC[00?o0000ojiA[_n^DJh01On^DJh00ol0003oIIYUofFJI@0<ofFJI@03o`000?mEZUGo
EJYE00coEJYE00?o0000oeFZEOmEZUD03?mEZUD2o`0000coIiQW00?o0000oj5NXOnQGZ403OnQGZ40
0ol0003oiQWVonHIiP0:onHIiP03o`000?o`3o3ol0o`00Ool0o`00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?om`Sgo`000?o[5>/04?o[5>/00ol0003o[U6^ojiA[P06ojiA[P03o`000?mUVVGo
IIYU00coIIYU00?o0000oeFZEOmEZUD02omEZUD00ol0003oEJYEoeFZE@0=oeFZE@04o`000?mXUfSo
0000o`0000[oIiQW00?o0000oj5NXOnQGZ403OnQGZ400ol0003oiQWVonHIiP0;onHIiP03o`000?o`
3o3ol0o`00Kol0o`00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?ol0o`00ol0003ojaC[on/Dj`0@
on/Dj`03o`000?n^DJko[U6^00Ko[U6^00?o0000ofFJIOmUVVD03OmUVVD00ol0003oEJYEoeFZE@0:
oeFZE@03o`000?mEZUGoEJYE00coEJYE00?o0000ofRGJ?mXUfP00_mXUfP2o`0000SoIiQW00?o0000
oj5NXOnQGZ403?nQGZ400ol0003oiQWVonHIiP0=onHIiP03o`000?o`3o3ol0o`00Col0o`00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?ol0ocoo0?l00Coo0?l0_l0000@on/Dj`03o`000?n^DJko[U6^
00Oo[U6^00?o0000ofFJIOmUVVD03_mUVVD<o`0000ooEJYE00?o0000ofRGJ?mXUfP01?mXUfP2o`00
00KoIiQW00?o0000oj5NXOnQGZ403?nQGZ400ol0003oiQWVonHIiP0>onHIiP03o`000?o`3o3ol0o`
00?ol0o`00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001ool0o`01?l0003om@[eo`000?l0000>on/D
j`03o`000?n^DJko[U6^00So[U6^00?o0000ofFJIOmUVVD03OmUVVD00ol0003oEjQGoeNXE`08oeNX
E`03o`000?mEZUGoEJYE00coEJYE00?o0000ofRGJ?mXUfP01omXUfP2o`0000?oIiQW00?o0000oj5N
XOnQGZ403OnQGZ400ol0003oiQWVonHIiP0?onHIiP05o`000?o`3o3ol0o`oo0?l?l000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009oo`3
o005o`000?oe2_Gom@[eooD:mOl000003Oo[5>/00ol0003o[U6^ojiA[P08ojiA[P03o`000?mUVVGo
IIYU00coIIYU00?o0000oeNXEomGZ5L02_mGZ5L00ol0003oEJYEoeFZE@0;oeFZE@03o`000?mXUfSo
J9MX00WoJ9MX0_l000000omWV6Oo0000oj5NX@08oj5NX@Ko00004ooV6NH01?l0003ol0o`oo0?l?l0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:oo`3o003o`000?oe2_Gom@[e00?om@[e1?l00008on/Dj`03o`000?n^DJko
[U6^00Wo[U6^00?o0000ofFJIOmUVVD03?mUVVD00ol0003oEjQGoeNXE`0:oeNXE`03o`000?mEZUGo
EJYE00[oEJYE00?o0000ofRGJ?mXUfP03?mXUfP;o`0000Gocc3?00?o0000onHIi_oV6NH04_oV6NH0
0ol0003ol0o`o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<oo`3o003o`000?oe2_Gom@[e00?om@[e00Co0000omLX
eooG:=OoebSG1Ol00003on/Dj`03o`000?n^DJko[U6^00Wo[U6^00?o0000ofFJIOmUVVD02omUVVD0
0ol0003oEjQGoeNXE`0<oeNXE`03o`000?mEZUGoEJYE00WoEJYE00?o0000ofRGJ?mXUfP03?mXUfP0
0ol0003oW6>LoiaSW002oiaSW003o`000?o?<<oocc3?00Wocc3?00?o0000onHIi_oV6NH04_oV6NH3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o00<oo`3o003o`000?oe2_Gom@[e00Com@[e00?o0000omLX
eooG:=L01OoG:=L3o`0000co[U6^00?o0000ofFJIOmUVVD02omUVVD00ol0003oEjQGoeNXE`0<oeNX
E`03o`000?mEZUGoEJYE00SoEJYE00?o0000ofRGJ?mXUfP03?mXUfP00ol0003oW6>LoiaSW004oiaS
W003o`000?o?<<oocc3?00Socc3?00?o0000onHIi_oV6NH04_oV6NH00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_ol0o`00ol0003om@[eooD:m@05ooD:m@03o`000?oG:=OoebSG00OoebSG00?o0000ojiA
[_n^DJh02_n^DJh00ol0003oIIYUofFJI@09ofFJI@;o00003omGZ5L00ol0003oEJYEoeFZE@08oeFZ
E@03o`000?mXUfSoJ9MX00coJ9MX00?o0000oiaSW?nLHi`01?nLHi`00ol0003occ3?oll`c`09oll`
c`Co00003ooV6NH00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e00Go
m@[e00?o0000omLXeooG:=L02?oG:=L00ol0003o[U6^ojiA[P09ojiA[P03o`000?mUVVGoIIYU00Ko
IIYU0ol000000omdRgCo0000oeNXE`0?oeNXE`03o`000?mEZUGoEJYE00KoEJYE00?o0000ofRGJ?mX
UfP03OmXUfP00ol0003oW6>LoiaSW005oiaSW003o`000?o?<<oocc3?00Socc3?00Co0000oo<<looc
3??ol`cc1Ol00009onHIiP03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00koo0?l00?o0000ooD:mOoe
2_D01_oe2_D00ol0003oebSGomLXe`07omLXe`03o`000?n^DJko[U6^00[o[U6^00?o0000ofFJIOmU
VVD00_mUVVD3o`0000GoM8]d00?o0000oeNXEomGZ5L03OmGZ5L00ol0003oEJYEoeFZE@06oeFZE@03
o`000?mXUfSoJ9MX00coJ9MX00?o0000oiaSW?nLHi`01_nLHi`00ol0003occ3?oll`c`08oll`c`03
o`000?oc3??ol`cc00Kol`cc1Ol00003onHIiP03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e00Kom@[e
00?o0000omLXeooG:=L01ooG:=L00ol0003o[U6^ojiA[P0:ojiA[P03o`000?mUVVGo000000;o0000
2?mdRg@00ol0003oEjQGoeNXE`0=oeNXE`Co00001?mEZUD00ol0003oJ9MXofRGJ00=ofRGJ003o`00
0?nLHicoW6>L00OoW6>L00?o0000oll`coo?<<l01oo?<<l00ol0003ol`ccoo<<l`0;oo<<l`?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo0?loo`3
o00<oo`3o003o`000?oe2_Gom@[e00Oom@[e00?o0000omLXeooG:=L02?oG:=L3o`0000Wo[U6^0_l0
000<ogB;M003o`000?mGZ5OoEjQG00_oEjQG00?o0000ofjAK_m^TFh00_m^TFh3o`000003oeFZEOl0
003oJ9MX00koJ9MX00?o0000oiaSW?nLHi`01onLHi`00ol0003occ3?oll`c`06oll`c`03o`000?oc
3??ol`cc00kol`cc00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo0?loo`3o00<oo`3o003o`000?oe2_Gom@[e00Som@[e00?o0000
omLXeooG:=L01_oG:=L01?l0003ofRGJomXUf_oJ9MX3o`0000Ko[U6^00?o0000ogB;M?mdRg@03?md
Rg@00ol0003oEjQGoeNXE`09oeNXE`03o`000?m^TFkoKY5^00KoKY5^00?o0000ofRGJ?mXUfP03OmX
UfP00ol0003oW6>LoiaSW009oiaSW003o`000?o?<<oocc3?00Gocc3?00?o0000oo<<looc3?<03_oc
3?<00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?ol0ocoo0?l00coo0?l00?o0000ooD:mOoe2_D02?oe2_D00ol0003oebSGomLXe`05
omLXe`03o`000?oJ9M[ofRGJ00GofRGJ0ol00002ojiA[P03o`000?mdRgCoM8]d00goM8]d00?o0000
oeNXEomGZ5L02?mGZ5L00ol0003oKY5^ofjAKP07ofjAKP03o`000?mXUfSoJ9MX00coJ9MX0ol0000:
oiaSW003o`000?o?<<oocc3?00Gocc3?00?o0000oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l
00_oo0?l00?o0000ooD:mOoe2_D02Ooe2_D00ol0003oebSGomLXe`04omLXe`03o`000?oJ9M[ofRGJ
00WofRGJ0_l0000AogB;M003o`000?mGZ5OoEjQG00GoEjQG0_l0000;ofjAKP03o`000?mXUfSoJ9MX
00[oJ9MX00Go0000oiUVVOnIIYWoVFJIo`00000:oiaSW003o`000?o?<<oocc3?00Cocc3?00?o0000
oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?ol0ocoo0?l00Soo0?l1?l0000<ooD:m@03o`000?oG:=OoebSG
00;oebSG00?o0000omXUf_oJ9MX02_oJ9MX2o`00017oM8]d00?o0000oeNXEomGZ5L01?mGZ5L00ol0
003oKY5^ofjAKP0<ofjAKP03o`000?mXUfSoJ9MX00OoJ9MX0_l00005oiUVV@;o00002?nLHi`00ol0
003occ3?oll`c`04oll`c`03o`000?oc3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo0?loo`3o007o`0000?o
oP7n00?o0000ooD:mOoe2_D02_oe2_D01Ol0003oebSGomLXeooG:=Oo000000cofRGJ00Co0000oke2
_Onm@[go00004OmdRg@00ol0003oEjQGoeNXE`02oeNXE`03o`000?m^TFkoKY5^00koKY5^00?o0000
ofRGJ?mXUfP01OmXUfP00ol0003oVFJIoiUVV@07oiUVV@03o`000?nLHicoW6>L00KoW6>L00?o0000
oll`coo?<<l00oo?<<l00ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?oe2_Gom@[e
00Wom@[e00Co0000omLXeooG:=Oo00003?oJ9MX00ol0003o_D:moke2_@02oke2_@03o`000?mdRgCo
M8]d00ooM8]d00Co0000oeNXEomGZ5Oo00004Om^TFh00ol0003oJ9MXofRGJ004ofRGJ003o`000?nI
IYWoVFJI00WoVFJI00?o0000oiaSW?nLHi`01OnLHi`00ol0003occ3?oll`c`03oll`c`03o`000?oc
3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?oe2_Gom@[e00Wom@[e0_l0000<
omXUfP03o`000?nm@[go_D:m00?o_D:m00?o0000ogB;M?mdRg@03omdRg@00ol0003oEjQGo`00000C
ofjAKP04o`000?mXUfSoJ9MXofRGJ0;o00003OnIIYT2o`0000KoW6>L00Go0000oll`coo?<<oocc3?
o`00000@oo<<l`03o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oe2_Gom@[e00Som@[e00?o0000omXUf_oJ9MX02_oJ
9MX00ol0003o_D:moke2_@05oke2_@03o`000?mdRgCoM8]d00ooM8]d00?o0000ofjAK_m^TFh04om^
TFh00ol0003oJ9MXo`00000AoiUVV@03o`000?nLHicoW6>L00?oW6>L00Go0000oll`coo?<<oocc3?
o`00000>oo<<l`?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oe2_Gom@[e00Som@[e00?o0000omXUf_oJ9MX02OoJ
9MX00ol0003o_D:moke2_@07oke2_@03o`000?mdRgCoM8]d00koM8]d00?o0000ofjAK_m^TFh05?m^
TFh00ol0003oVFJIoiUVV@0AoiUVV@;o00001?nLHi`01?l0003occ3?oll`col0000:oo<<l`Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?oe2_Gom@[e00Kom@[e00?o
0000omXUf_oJ9MX02OoJ9MX00ol0003o_D:moke2_@08oke2_@03o`000?mdRgCoM8]d00_oM8]d0ol0
000GofjAKP03o`000?nIIYWoVFJI01?oVFJI00Ko0000oiaSW?nLHicoW6>Lo`000?o?<<l5o`0000Co
l`cc0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om@[eooD:m@05ooD:m@03o`00
0?oJ9M[ofRGJ00SofRGJ00?o0000oke2_Onm@[d02_nm@[d00ol0003oM8]dogB;M007ogB;M0?o0000
0_mjQGX00ol0003oKY5^ofjAKP0EofjAKP;o00005OnIIYT00ol0003oW6>LoiaSW002o`0000GojQGZ
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om@[e00?o0000omXUf_oJ9MX01ooJ
9MX00ol0003o_D:moke2_@0;oke2_@03o`000?mdRgCoM8]d00CoM8]d0ol00006ogZ5NP03o`000?m^
TFkoKY5^01?oKY5^00Co0000oj9MX_nRGJ;o00005OnIIYT2o`0000WojQGZ00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooL8moog2?L00oog2?L3o`0000WofRGJ00?o0000oke2_Onm@[d03Onm@[d00ol0003oM8]dogB;
M003o`0000[oNXEj00?o0000ofjAK_m^TFh04Om^TFh00ol0003oXUfRoj9MXP02oj9MXP03o`000?nI
IYWoVFJI01;oVFJI00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooL8moog2?L01oog2?L00ol0003ofRGJomXUfP05omXUfP03o`000?nm@[go_D:m00oo_D:m0_l0000>
ogZ5NP03o`000?m^TFkoKY5^00ooKY5^00?o0000oj9MX_nRGJ801?nRGJ800ol0003oVFJIoiUVV@0@
oiUVV@;o00002ooZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00?o0000omXUf_oJ9MX00ooJ9MX00ol0003o_D:moke2_@0@oke2_@03o`000?mjQG[oNXEj
00goNXEj00?o0000ofjAK_m^TFh03_m^TFh00ol0003oXUfRoj9MXP06oj9MXP;o00003_nIIYT2o`00
0003okm0_ol0003ojQGZ00[ojQGZ00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooL8moog2?L02oog2?L01Ol0
003ofRGJomXUf_oJ9M[o000001;o_D:m00?o0000ogZ5N_mjQGX03omjQGX00ol0003oKY5^ofjAKP0<
ofjAKP03o`000?nRGJ;oXUfR00WoXUfR00?o0000oiUVVOnIIYT02OnIIYT2o`0000?o_d2o00?o0000
onXEj_oZ5NX02OoZ5NX00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooL8moog2?L03Oog2?L00ol0003ofRGJo`00000Coke2
_@03o`000?mjQG[oNXEj013oNXEj00?o0000ofjAK_m^TFh02_m^TFh00ol0003oXUfRoj9MXP0;oj9M
XP03o`000?nIIYWoVFJI00GoVFJI0ol00006okm0_`03o`000?oZ5N[ojQGZ00SojQGZ00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?og2?Oom`Sg00oo
m`Sg00?o0000oke2_Onm@[d04Onm@[d00ol0003oNXEjogZ5NP0AogZ5NP03o`000?m^TFkoKY5^00Wo
KY5^00?o0000oj9MX_nRGJ803OnRGJ800ol0003oVFJIoiUVV@02oiUVV@;o00002Ono@;l00ol0003o
jQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooL8moog2?L04Oog2?L2o`00017o_D:m00?o0000ogZ5N_mjQGX0
4_mjQGX00ol0003oKY5^ofjAKP07ofjAKP03o`000?nRGJ;oXUfR00ooXUfR00Co0000oiUVVOl0003o
00002ono@;l00ol0003ojQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04_og2?L00ol0003ohAkQ
o`000002o`0000ko_D:m00?o0000ogZ5N_mjQGX04omjQGX00ol0003oKY5^ofjAKP05ofjAKP03o`00
0?nRGJ;oXUfR017oXUfR00?o0000okm0_ono@;l03?no@;l00ol0003ojQGZonXEjP08onXEjP03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003om`SgooL8
m`0BooL8m`03o`000?oQ7^7ohAkQ00?ohAkQ0_l0000;oke2_@;o00005_mjQGX7o`0001CoXUfR00?o
0000okm0_ono@;l03?no@;l00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?og2?L00ol0003ohAkQon4N
h@06on4Nh@?o00002?nm@[d00ol0003oXEjQo`000002o`0001;oNXEj00?o0000ohIiQ_n6NHH00_n6
NHH00ol0003oO8=lo`00000Doj9MXP03o`000?no@;oo_d2o00co_d2o00?o0000onXEj_oZ5NX02?oZ
5NX00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooL8moog2?L04_og2?L00ol0003ohAkQon4Nh@09on4Nh@;o00001Onm@[d00ol0003oXEjQoj5NX@03
oj5NX@;o00003omjQGX00ol0003oQWV6ohIiQP03ohIiQP04o`000?mlPgcoO8=lo`0001?oXUfR00?o
0000okm0_ono@;l03Ono@;l00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_oQ7^43o`000003oke2_Ol0003o
XEjQ00OoXEjQ0ol0000;ogZ5NP03o`000?n6NHKoQWV600CoQWV600Go0000ogb3O?mlPgcoO8=lo`00
000Boj9MXP03o`000?no@;oo_d2o00go_d2o00?o0000onXEj_oZ5NX01ooZ5NX?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooL8moog2?L04?og2?L0
0ol0003ohAkQon4Nh@0?on4Nh@03o`000?nQGZ7oXEjQ00[oXEjQ0_l00008ogZ5NP03o`000?n6NHKo
QWV600GoQWV600?o0000ogb3O?mlPg`00_mlPg`00ol0003oXUfRoj9MXP0?oj9MXP03o`000?no@;oo
_d2o00go_d2o00?o0000onXEj_oZ5NX01_oZ5NX00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?og2?Oom`Sg00oom`Sg00?o0000on4NhOoQ7^403ooQ7^400ol0003oXEjQoj5NX@0<oj5N
X@;o00001OmjQGX00ol0003oQWV6ohIiQP06ohIiQP03o`000?mlPgcoO8=l00?oO8=l00?o0000oj9M
X_nRGJ803_nRGJ800ol0003o_d2ookm0_`0>okm0_`03o`000?oZ5N[ojQGZ00CojQGZ00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?og2?Oom`Sg00kom`Sg00?o0000on4NhOoQ7^404?oQ7^400ol0003o
XEjQoj5NX@0>oj5NX@?o000000?oNXEjo`000?n6NHH02?n6NHH00ol0003oO8=logb3O004ogb3O003
o`000?nRGJ;oXUfR00goXUfR4_l00005onXEjP03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGj
o`00000?ooL8m`03o`000?oQ7^7ohAkQ00oohAkQ0_l0000Coj5NX@03o`000?n6NHKoQWV600SoQWV6
00?o0000ogb3O?mlPg`01OmlPg`00ol0003oXUfRoj9MXP0<oj9MXP03o`000?o]4^gokA;]00ookA;]
00Go0000onXEj_oZ5N[ojQGZo`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?oj1O[onPGjo`0000ko
m`Sg00?o0000on4NhOoQ7^403_oQ7^400ol0003occ3?o`00000Coj5NX@03o`000?n6NHKoQWV600So
QWV600?o0000ogb3O?mlPg`01OmlPg`00ol0003oXUfRoj9MXP0;oj9MXP03o`000?o]4^gokA;]017o
kA;]00?o0000onXEj_l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000ooX5n_oj1OX00_oj1OX00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oQ7^7ohAkQ00gohAkQ0_l00003oll`c`03o`000?nQGZ7oXEjQ013o
XEjQ00?o0000ohIiQ_n6NHH02?n6NHH00ol0003oO8=logb3O006ogb3O003o`000?nRGJ;oXUfR00[o
XUfR00?o0000ondBkOo]4^d04_o]4^d00ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX0
0ooj1OX00ol0003om`SgooL8m`09ooL8m`03o`000?oQ7^7ohAkQ00cohAkQ00?o0000oll`coo?<<l0
0oo?<<l00ol0003oXEjQoj5NX@0?oj5NX@03o`000?n6NHKoQWV600WoQWV600?o0000ogb3O?mlPg`0
1omlPg`00ol0003oXUfRoj9MXP09oj9MXP03o`000?o]4^gokA;]01;okA;]00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L00ol0003ohAkQon4N
h@0:on4Nh@;o00001_o?<<l00ol0003oXEjQoj5NX@0?oj5NX@03o`000?n6NHKoQWV600WoQWV600?o
0000ogb3O?mlPg`02?mlPg`00ol0003oXUfRoj9MXP07oj9MXP03o`000?o]4^gokA;]01?okA;]00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00GonPGj00?o0000ooL8moog2?L02?og2?L0
0ol0003ohAkQon4Nh@09on4Nh@03o`000?o?<<oocc3?00Oocc3?00?o0000oj5NXOnQGZ403OnQGZ42
o`0000_oQWV600?o0000ogb3O?mlPg`02OmlPg`00ol0003oXUfRoj9MXP06oj9MXP03o`000?o]4^go
kA;]01?okA;]4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000ooX5
n_oj1OX01ooj1OX00ol0003om`SgooL8m`06ooL8m`03o`000?oQ7^7ohAkQ00WohAkQ00?o0000oll`
coo?<<l02?o?<<l00ol0003oXEjQoj5NX@0;oj5NX@;o000000?oWF:Mo`000?n6NHH02_n6NHH00ol0
003oO8=logb3O009ogb3O0Ko00000onRGJ800ol0003okA;]ondBk@0CondBk@03o`000?ok1?_on`Ck
00oon`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?oj1O[onPGj00SonPGj00?o0000ooL8moog2?L01?og2?L3o`00
00SohAkQ0_l0000;oll`c`03o`000?nQGZ7oXEjQ00WoXEjQ0_l00004oieRW@03o`000?n6NHKoQWV6
00SoQWV600?o0000ogb3O?mlPg`02?mlPg`00ol0003o`Sg2ol8m`P04ol8m`P?o00005?o]4^d3o`00
017on`Ck00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003om`SgooL8m`03o`0000?o
m@[e00?o0000on4NhOoQ7^401?oQ7^400ol0003occ3?oll`c`0<oll`c`03o`000?nQGZ7oXEjQ00Go
XEjQ0ol00007oieRW@03o`000?n6NHKoQWV600OoQWV600?o0000ogb3O?mlPg`01omlPg`00ol0003o
`Sg2ol8m`P08ol8m`P03o`000?o]4^gokA;]013okA;]00Go0000ooT6nOoi1_Won@Kio`00000@oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
nPGjooX5nP0;ooX5nP;o00001ooe2_D01?l0003ohAkQon4NhOoQ7^42o`0000oocc3?00?o0000oj5N
XOnQGZ400onQGZ42o`0000[oWF:M00?o0000ohIiQ_n6NHH01on6NHH00ol0003oO8=logb3O005ogb3
O0;o00003?o2?L800ol0003okA;]ondBk@0=ondBk@;o00001Ooi1_T00ol0003on`Ckoo/4n`0=oo/4
n`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000ooX5n_oj1OX03?oj1OX00ol0003om@[eooD:m@07ooD:m@03o`000?oQ7^7o0000017o
cc3?00Co0000oj5NXOnQGZ7oXEjQ0_l0000=oieRW@03o`000?n6NHKoQWV600KoQWV600?o0000ogb3
O?mlPg`01?mlPg`00ol0003o`Sg2ol8m`P0=ol8m`PCo00002_o]4^d00ol0003on@KiooT6n@06ooT6
n@03o`000?ok1?_on`Ck00con`Ck00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003onPGjooX5nP0;ooX5nP03o`000?oe2_Gom@[e00Wo
m@[e00?o0000oll`coo?<<l04Oo?<<l3o`00013oWF:M00?o0000ohIiQ_n6NHH01On6NHH00ol0003o
O8=logb3O003ogb3O003o`000?o2?L;o`Sg200ko`Sg200Co0000oo<<looc3??ol`cc1_l00003ondB
k@03o`000?oi1_Won@Ki00Son@Ki00?o0000oo/4nook1?/02ook1?/00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?oj1O[onPGj00_o
nPGj00?o0000ooD:mOoe2_D02_oe2_D00ol0003occ3?oll`c`0Aoll`c`03o`000?nMHYgoWF:M013o
WF:M00?o0000ohIiQ_n6NHH01On6NHH00ol0003oO8=logb3O002ogb3O003o`000?o2?L;o`Sg200oo
`Sg200?o0000oo<<looc3?<01ooc3?<3o`0000con@Ki00?o0000oo/4nook1?/02_ok1?/00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000ooX5n_oj1OX0
2_oj1OX00ol0003om@[eooD:m@0<ooD:m@03o`000?o?<<oocc3?013occ3?00?o0000oieRWOnMHYd0
4OnMHYd00ol0003oQWV6ohIiQP04ohIiQP03o`000?mlPgcoO8=l00;o00004Oo2?L800ol0003ol`cc
oo<<l`0:oo<<l`03o`000?oi1_Won@Ki00_on@Ki3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?oj1O[onPGj00[onPGj00?o0000ooD:mOoe2_D03_oe
2_D00ol0003occ3?oll`c`0=oll`c`;o00005?nMHYd3o`0000CoQWV600?o0000ogb3O?l000004oo2
?L800ol0003ol`ccoo<<l`0:oo<<l`03o`000?oi1_Won@Ki00_on@Ki00?o0000ood2oOom0_d02Oom
0_d00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oe2_Gom@[e00kom@[e00?o0000
oll`coo?<<l02_o?<<l3o`000003om4^dOl0003oWF:M017oWF:M0_l00003okE:]@;o00000_n6NHH2
o`0001Co`Sg200?o0000oo<<looc3?<02_oc3?<00ol0003on@KiooT6n@0;ooT6n@03o`000?om0_go
o@;m00[oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ooj1OX00ol0003om@[eooD:m@0@ooD:m@03o`000?o?<<oocc3?00Kocc3?0ol00005om4^
d@03o`000?nMHYgoWF:M00goWF:M0_l00007okE:]@?o00005Oo2?L800ol0003ol`ccoo<<l`0;oo<<
l`03o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d03?om0_d3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003ooX5nP03o`000?oe2_Gom@[e017o
m@[e00?o0000oll`coo?<<l01?o?<<l2o`0000WodBkA00?o0000oieRWOnMHYd02_nMHYd2o`0000_o
]DZe00?o0000ol8m`_o2?L804_o2?L800ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Wo
n@Ki00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom@[e00?o0000oll`coo?<<l00ol0000<om4^d@03o`00
0?nMHYgoWF:M00OoWF:M0_l0000=okE:]@03o`000?o2?L;o`Sg201;o`Sg200?o0000oo<<looc3?<0
3?oc3?<00ol0003on@KiooT6n@09ooT6n@03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooD:mOoe2_D05?oe2_D2o`0000oodBkA00?o0000oieRWOnMHYd01OnMHYd2o`0000oo]DZe00?o
0000ol8m`_o2?L804_o2?L800ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Won@Ki00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooD:mOoe2_D04ooe2_D2
o`00013odBkA00?o0000oieRWOnMHYd00_nMHYd2o`0001;o]DZe00?o0000ol8m`_o2?L804Oo2?L80
0ol0003ol`ccoo<<l`0<oo<<l`03o`000?oi1_Won@Ki00Won@Ki00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooD:mOoe2_D04_oe2_D01?l0003okA;]ondBkOl0000@om4^d@04o`000?nMHYgo
0000o`0001Co]DZe00?o0000ol8m`_o2?L804?o2?L800ol0003ol`ccoo<<l`0>oo<<l`03o`000?oi
1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oe2_Gom@[e017om@[e00?o0000
ondBkOo]4^d00_o]4^d00ol0003odBkAom4^d@0>om4^d@03o`000?neB[Go]DZe01Co]DZe00?o0000
ol8m`_o2?L803Oo2?L84o`00013ol`cc00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@09
ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooD:mOoe2_D04?oe2_D00ol0003okA;]ondBk@03ondBk@03o`000?oA;]7odBkA
00godBkA00?o0000okE:]OneB[D05?neB[D00ol0003o`Sg2ol8m`P07ol8m`PKo00000ooT6n@00ol0
003ol`ccoo<<l`0>oo<<l`03o`000?oi1_Won@Ki00Oon@Ki00?o0000ood2oOom0_d02?om0_d00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?oe2_Gom@[e00oom@[e00?o0000ondBkOo]4^d01Oo]4^d00ol0003odBkAom4^d@0<om4^d@03
o`000?neB[Go]DZe01Go]DZe00?o0000ol8m`_o2?L801_l0000:on@Ki003o`000?oc3??ol`cc00go
l`cc00?o0000ooT6nOoi1_T01ooi1_T00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003okA;]ondBk@06ondBk@03o`000?oA;]7odBkA00_odBkA00?o0000okE:]OneB[D0
5OneB[D3o`00017oi1_T00?o0000oo<<looc3?<03?oc3?<00ol0003on@KiooT6n@07ooT6n@03o`00
0?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom@[e00?o0000ondBkOo]4^d02?o]4^d00ol0003odBkAom4^
d@0:om4^d@03o`000?neB[Go]DZe01Go]DZe00?o0000on@Ki?oT6n@04OoT6n@00ol0003ol`ccoo<<
l`0=oo<<l`03o`000?oi1_Won@Ki00Gon@Ki00?o0000ood2oOom0_d01oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ok1?_o
n`Ck00Kon`Ck1ol0000<ondBk@03o`000?oA;]7odBkA00WodBkA00?o0000okE:]OneB[D05?neB[D0
0ol0003oi1_Ton@Ki00Con@Ki003o`000?oc3??ol`cc00col`cc00Co0000ooT6nOoi1_Won@Ki1_l0
0007ood2o@03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003on`Ckoo/4n`0=oo/4n`03o`000?o]4^gokA;]00_okA;]00?o0000om4^dOoA;]402OoA;]40
0ol0003o]DZeokE:]@0CokE:]@03o`000?oT6nCoi1_T01Coi1_T1?l0000:oo<<l`Co00001_on0Oh2
o`0000Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003on`Ckoo/4n`0=oo/4n`?o00003?o]4^d00ol0003odBkAom4^d@08om4^
d@03o`000?neB[Go]DZe00oo]DZe1?l0000Gon@Ki004o`000?oh1oSon0OhooP7n0Ko00000ooc3?<0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?oo@;mo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003on`Ckoo/4n`0>oo/4n`03o`000?od2oCom0_d
00?o00002_o]4^d00ol0003odBkAom4^d@07om4^d@03o`000?neB[Go]DZe00So]DZe1ol00003on0O
h003o`000?oT6nCoi1_T01Coi1_T00?o0000ooP7n?oh1oP02?oh1oP3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
n`Ckoo/4n`0>oo/4n`03o`000?od2oCom0_d00?om0_d0ol00008ondBk@03o`000?oA;]7odBkA00Ko
dBkA00Co0000okE:]OneB[Go]DZe1ol0000:on0Oh003o`000?oT6nCoi1_T01Coi1_T00?o0000ooP7
n?oh1oP02_oh1oP00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ok1?_on`Ck00ko
n`Ck00?o0000oo@;m?od2o@01_od2o@3o`0000KokA;]00?o0000om4^dOoA;]401?oA;]45o`0001;o
h1oP00?o0000on@Ki?oT6n@04_oT6n@00ol0003on0OhooP7n00;ooP7n003o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo/4nook1?/03ook1?/00ol0003om0_doo@;m009oo@;m0?o00001?o]4^d00ol0003odBkA
om4^d@03o`000003ooH9m_l0003oh1oP01Coh1oP00?o0000on@Ki?oT6n@04_oT6n@00ol0003on0Oh
ooP7n00;ooP7n003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ok1?/04?ok1?/00ol0003om0_doo@;
m00<oo@;m0?o000000CokA;]o`000?l0003o00001?of2OH00ol0003oh1oPon0Oh00Bon0Oh0;o0000
4ooT6n@00ol0003on0OhooP7n00<ooP7n003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?od2oCom0_d00oom0_d00?o0000ooH9m_of2OH01_of2OH00ol0003oh1oPon0O
h00@on0Oh004o`000?oV6NKoiQWVo`0001;oi1_T00?o0000ooP7n?oh1oP03?oh1oP00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?od2oCom0_d00oom0_d00?o0000ooH9m_of2OH01_of
2OH00ol0003oh1oPon0Oh00?on0Oh003o`000?oV6NKoiQWV00;oiQWV00?o0000on@Ki?oT6n@03_oT
6n@00ol0003on0OhooP7n00=ooP7n003o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ok1?_o
n`Ck013on`Ck00?o0000oo@;m?od2o@03_od2o@00ol0003omPWfooH9mP07ooH9mP03o`000?oP7n3o
h1oP00koh1oP00?o0000onHIi_oV6NH01?oV6NH2o`0000koi1_T00?o0000ooP7n?oh1oP03Ooh1oP0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?od2oCom0_d
00gom0_d00?o0000ooH9m_of2OH02?of2OH00ol0003oh1oPon0Oh00=on0Oh003o`000?oV6NKoiQWV
00GoiQWV00?o0000ooL8mol000000_l0000:on@Ki003o`000?oh1oSon0Oh00kon0Oh00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ok1?_on`Ck013on`Ck00?o0000oo@;m?od2o@03?od2o@00ol0003o
mPWfooH9mP0:ooH9mP03o`000?oP7n3oh1oP00_oh1oP00?o0000onHIi_oV6NH01_oV6NH00ol0003o
m`SgooL8m`02ooL8m`?o00001ooT6n@00ol0003on0OhooP7n00>ooP7n003o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013on`Ck1?l0000:oo@;m003o`000?of2OKomPWf00_omPWf00?o0000on0Oh?oP7n00
2_oP7n000ol0003oiQWVonHIiP06onHIiP03o`000?og2?Oom`Sg00Kom`Sg0_l00004on@Ki003o`00
0?oh1oSon0Oh00oon0Oh00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_goo@;m00?o00003Ook
1?/01?l0003oo0?loo`3o?ol0o`6o`0000?om0_d00?o0000ooH9m_of2OH03?of2OH00ol0003oh1oP
on0Oh009on0Oh003o`000?oV6NKoiQWV00OoiQWV00?o0000ooL8moog2?L02?og2?L3o`000003on@K
i?l0003on0Oh013on0Oh00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Coo@;m0ol0
0009oo/4n`03o`000?ol0ocoo0?l00Soo0?l0ol0000?ooH9mP03o`000?oP7n3oh1oP00Soh1oP00?o
0000onHIi_oV6NH02?oV6NH00ol0003om`SgooL8m`0;ooL8m`03o`000?oh1oSon0Oh013on0Oh00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Gon`Ck00?o0000oo`3o?ol0o`02ool0o`0
0ol0003omPWfooH9mP0=ooH9mP03o`000?oP7n3oh1oP00Ooh1oP00?o0000onHIi_oV6NH02?oV6NH0
0ol0003om`SgooL8m`0<ooL8m`03o`000?oh1oSon0Oh00kon0Oh0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?om0_goo@;m00coo@;m0ol00002oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooH9
m_of2OH03_of2OH00ol0003oh1oPon0Oh005on0Oh003o`000?oV6NKoiQWV00WoiQWV00?o0000ooL8
moog2?L03Oog2?L00ol0003on0OhooP7n00:ooP7n0?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o@;mood2o@0?ood2o@;o00003ool0o`00ol0003omPWfooH9mP0=ooH9mP03o`000?oP7n3oh1oP00Co
h1oP00?o0000onHIi_oV6NH02_oV6NH00ol0003om`SgooL8m`0=ooL8m`03o`000?oh1oSon0Oh00Oo
n0Oh0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0Aood2o@03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH03Oof2OH00ol0003oh1oPon0Oh003on0Oh003o`00
0?oV6NKoiQWV00[oiQWV00?o0000ooL8moog2?L03oog2?L00ol0003on0OhooP7n003ooP7n0?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooH9m_of2OH03Oof2OH00ol0003oh1oPon0O
h002on0Oh003o`000?oV6NKoiQWV00_oiQWV00?o0000ooL8moog2?L03oog2?L00ol0003on0OhooP7
n003o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aood2o@03o`000?ol
0ocoo0?l00koo0?l00?o0000ooH9m_of2OH03Oof2OH01?l0003oh1oPon0Oh?l0000>onHIiP03o`00
0?og2?Oom`Sg013om`Sg0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000ooo@;m00?o
0000oo`3o?ol0o`03_ol0o`00ol0003omPWfooH9mP0=ooH9mPGo00003?oV6NH00ol0003om`SgooL8
m`0AooL8m`03o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oom0_d0
0ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf00gomPWf00?o0000ooL8moog2?L00_og2?L3
o`0000WoiQWV00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?of2OKomPWf00_omPWf00?o0000ooL8
moog2?L01_og2?L4o`0000GoiQWV00?o0000ooL8moog2?L04Oog2?L00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooH9m_of2OH02_of2OH00ol0003om`SgooL8m`0;ooL8m`?o000000?oiQWVo`000?og
2?L04_og2?L00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oom0_d3o`00013oo0?l00?o0000ooH9m_of2OH02Oof2OH00ol0003om`SgooL8m`0?ooL8m`;o
00004oog2?L00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ood2o@04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003omPWfooH9mP06ooH9mP;o
00004oog2?L00ol0003om`SgooL8m`0AooL8m`;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo@;mo`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooH9m_of2OH0
1?of2OH2o`0000;oo0?l00?o0000ooL8moog2?L04Oog2?L00ol0003om`SgooL8m`0?ooL8m`04o`00
0?ol0ocoo0?lo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooH9m_of2OH00oof2OH00ol0003oo0?l
oo`3o003oo`3o003o`000?og2?Oom`Sg013om`Sg4_l00004oo`3o0;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003omPWfooH9mP02o`0000Ooo0?l00?o
0000ooL8moog2?L03oog2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0ocoo0?l00Coo0?l00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on@KiooT6
n@0>ooT6n@03o`000?ol0ocoo0?l00Goo0?l0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ood2o@03o`000?ol0oco
o0?l00Woo0?l00?o0000ooL8moog2?L03?og2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0oco
o0?l00Soo0?l0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ood2oOom0_d00_om0_d00ol0003oo0?loo`3o009oo`3
o003o`000?og2?Oom`Sg00_om`Sg00?o0000ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o00:oo`3
o003o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?om0_goo@;m00;oo@;m00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oi1_Won@Ki00kon@Ki00?o0000oo`3o?ol0o`02ool0o`2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?om0_goo@;m00?oo@;m00?o0000oo`3o?ol0o`02ool0o`00ol0003om`SgooL8m`09ooL8m`03o`00
0?oi1_Won@Ki00kon@Ki00?o0000oo`3o?ol0o`03Ool0o`01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ood2oOom0_d01?om0_d00ol0003oo0?l
oo`3o00;oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000ooT6nOoi1_T03ooi1_T00ol0003oo0?l
oo`3o00=oo`3o0Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003oo@;mood2o@04ood2o@03o`000?ol0ocoo0?l00coo0?l00?o0000ooL8moog2?L01_og
2?L00ol0003on@KiooT6n@0>ooT6n@03o`000?ol0ocoo0?l00coo0?l0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?om0_goo@;m00Koo@;m00?o0000
oo`3o?ol0o`03?ol0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oi1_Won@Ki00kon@Ki00?o0000
oo`3o?ol0o`02_ol0o`2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ood2oOom0_d01_om0_d00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg
00Com`Sg00?o0000ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o008oo`3o0;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003oo@;mood2o@07ood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog
2?L00_og2?L00ol0003on@KiooT6n@0?ooT6n@03o`000?ol0ocoo0?l00Koo0?l0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?om0_goo@;m00Soo@;m
00?o0000oo`3o?ol0o`03_ol0o`01?l0003om`SgooL8moog2?L4o`0000kon@Ki00?o0000oo`3o?ol
0o`01?ol0o`2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ood2oOom0_d02?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?og2?Oo000000CooP7n
1_l00007ooT6n@03o`000?ol0ocoo0?l00?oo0?l0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ood2oOom0_d02Oom0_d3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;on@Ki00Co0000oo`3o?ol0ocoo0?l0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?om0_goo@;m00[oo@;m00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000ool0oco0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?om0_goo@;m00Woo@;m00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?om
0_goo@;m00Woo@;m00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ood2o@03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
o@;mood2o@06ood2o@03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo@;mood2o@05ood2o@03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ood2oOom0_d0
0oom0_d00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003oo@;mood2
o@02ood2o@03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?om0_goo@;mo`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo@;mo`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00[o
003o2Oooo`08o`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP09o`00o`07ogMgQooMgB7o
ool0oooo0?oMgB7oQhMgoa0@kP0:o`00o`;oool0VOl00?l1ooooo`00WOl00?l00onHV6Koool0ogMg
Q`07o`00o`03oiRHI_ooo`3oMgN700co003o0_ooo`0;o`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l01_l00?l02_l@4>kogMdQoooo0?mgMhOo413^o`00oomEEJWoool0omgM8Ol@4>h6
o`00o`0:oa0@k_oMgB7oool0ogMgQol@4>ko003ooeEEZOooo`3ogMdQoa0@kPWo003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03onk^4?ooo`3ogMdQ00Oo003o00?ok^h@oooo0?oMgB403?l00?l2oooo00go
003o0oooo`09o`00o`03omgM8Oooo`3oMgN700Co003o00?oA4Bjoooo0?oMgB401_l00?l00ooMgB7o
ool0ogMgQ`04o`00o`03odA4^_ooo`3ogMdQ00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00o`05oc8b
c?ooo`3oool0oooo0?l@4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`0=o`00
o`?oool02?l00?l00on7QgOoool0oooo0006o`00o`03omgM8Oooo`3oIVJH00Co003o00?oQhMgoooo
0?ooo`001_l00?l00ooMgB7oool0ofIVV008o`00o`;oool0VOl00?l1ooooo`00W?l00?l01OnYZEGo
ool0oooo0?ooo`3oIVJH00Go003o00GoV9QVoooo0?ooo`3oool0ogMgQ`0;o`00o`;oool03Ol00?l3
oooo00So003o0_ooo`000onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@00Co003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@00So003o0_ooo`2Io`00o`7ooooo002Lo`00
o`?oool000?oIVJHokZjA?l00?l01?l00?l01Oo^kQ3oool0oooo0?mVIYSogMdQ00_o003o0_ooo`0=
o`00o`?oool01ol00?l01?mEEJWoool0oooo0?mVIYP6o`00o`04oeEEZOooo`3oool0oc8bc0;o003o
00CoEEFYoooo0?ooo`3oIVJH1_l00?l01?mEEJWoool0oooo0?lb</`7o`00o`;oool0VOl00?l1oooo
o`00Vol00?l01omEEJWoool0oooo0?o^kQ3o003oonk^4?l@4>h00ol00?l01omEEJWoool0oooo0?o^
kQ3o003oonk^4?lQ8Md02_l00?l2oooo00go003o0oooo`07o`00o`04oiRHI_ooo`3oool0odA4^PKo
003o00CoA4Bjoooo0?ooo`3oQhMg0_l00?l01?nHV6Koool0oooo0?m4A;X6o`00o`04odA4^_ooo`3o
ool0ohN7M`Oo003o0_ooo`2Io`00o`7ooooo002Ko`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QV
ofIVV003o`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QVogMgQ`0:o`00o`;oool03Ol00?l3oooo
00Oo003o00Coc<`boooo0?ooo`3o413^1ol00?l2oooo0004olc<<_l00?oo003oolc<<P;oool000?o
413^o`00ool00?l01Ol00?l2oooo0003olc<<_l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002K
o`00o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l00?ooA4BjomgM8@[o003o
0_ooo`0=o`00o`?oool01ol00?l3oooo00So003o0_ooo`000oo^kQ3o003oo`00o`03oooo00So003o
0_ooo`000oo^kQ3o003oo`00o`05o`00o`;oool0VOl00?l1ooooo`00V_l00?l01?mEEJWoool0oooo
0?oMgB43o`00o`04oooo0?l00?oo003ooeEEZ@;oool000Kok^h@o`00ool00?oo003ooooo0?lQ8Md9
o`00o`;oool03Ol00?l3oooo00Oo003o0oooo`08o`00o`?oool00_l00?l3oooo00So003o0oooo`07
o`00o`;oool0VOl00?l1ooooo`00V_l00?l01?nYZEGoool0oooo0?mgMhL3o`00o`04ojVYEOmEEJWo
003oojVYE@;oool000KoV9QVo`00ool00?oo003oojVYEOmgMhL9o`00o`;oool03Ol00?l3oooo00Oo
003o0oooo`08o`00o`?oool00_l00?l3oooo00So003o0oooo`07o`00o`;oool0VOl00?l1ooooo`00
V_l00?l3oooo0007ob4QgOl00?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l00?oo003o
o`00oomEEJWogMdQ2Ol00?l2oooo00go003o0oooo`07o`00o`?oool02?l00?l3oooo00;o003o0ooo
o`08o`00o`?oool01ol00?l2oooo09Wo003o0Oooool009Wo003o00CoEEFYoooo0?ooo`3ogMdQ1Ol0
0?l01Oo^kQ3oEEFYoooo0?ooo`3ok^h@00Go003o00?oool0ob4QgOl00?l01ol00?l2oooo00go003o
0oooo`07o`00o`?oool02?l00?l3oooo00;o003o0oooo`08o`00o`?oool01ol00?l2oooo09Wo003o
0Oooool009Wo003o00CoZJUEoooo0?ooo`3oMgN71Ol00?l01Onj^TCok^h@oooo0?ooo`3oQhMg00Go
003o00?oZJUEogMgQol00?l01ol00?l2oooo00go003o0oooo`07o`00o`04olc<<_ooo`3oool0oc8b
c0Ko003o00Co8B7Moooo0?ooo`3oc<`b0_l00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOoo
o`3oool0olc<<POo003o0_ooo`2Io`00o`7ooooo002Ho`00o`05oa0@k_ooo`3oool0oooo0?lQ8Md0
1Ol00?l01OmVIYSoool0oooo0?ooo`3o8B7M00Go003o00?oEEFYomgM8Ol00?l01ol00?l2oooo00go
003o0oooo`07o`00o`04oiRHI_ooo`3oool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oV9QV0_l00?l0
1?nHV6Koool0oooo0?m4A;X6o`00o`04odA4^_ooo`3oool0oiRHIPOo003o0_ooo`2Io`00o`7ooooo
002Ho`00o`04ofIVV?ooo`3oool0omgM8@Ko003o00CoIVJHoooo0?ooo`3ogMdQ1ol00?l00oooo`3o
8B7Mo`00o`06o`00o`;oool03Ol00?l3oooo00Oo003o00CoEEFYoooo0?ooo`3oMgN71_l00?l01?mV
IYSoool0oooo0?mEEJT2o`00o`04oeEEZOooo`3oool0ogMgQ`Ko003o00CoIVJHoooo0?ooo`3oEEFY
1ol00?l2oooo09Wo003o0Oooool009So003o00Coc<`boooo0?ooo`3oMgN71_l00?l01?nj^TCoool0
oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`0=o`00o`?oool02?l00?l2oooo0003
ojVYEOl00?oo003o00Co003o00?oZJUEoooo0?o^kQ001?l00?l2oooo0003ojVYEOl00?oo003o00Co
003o00?oZJUEoooo0?o^kQ002?l00?l2oooo09Wo003o0Oooool009Oo003o00Go8B7Moooo0?ooo`3o
ool0ob4Qg@05o`00o`05oa0@k_ooo`3oool0oooo0?lQ8Md01ol00?l00omEEJWogMdQo`00o`06o`00
o`;oool02_l00?l00oo<c3;oIVJHogMgQ`03oooo00So003o00CoQhMgoooo0?ooo`3o413^1?l00?l0
1?l@4>koool0oooo0?mVIYP4o`00o`04ohN7Moooo`3oool0oa0@kPCo003o00Co413^oooo0?ooo`3o
IVJH2?l00?l2oooo09Wo003o0Oooool009Oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l01?mgMhOo
ool0oooo0?oMgB49o`00o`03oooo0?lQ8Mgo003o00Go003o0_ooo`0:o`00o`03odA4^_o<c3;oool0
00?oool02Ol00?l00ooMgB7oool0ohN7M`04o`00o`03ohN7Moooo`3oc<`b00Ko003o00?ogMdQoooo
0?n7QgL01?l00?l00on7QgOoool0olc<<P09o`00o`;oool0VOl00?l1ooooo`00UOl00?l00olQ8Mgo
QhMgoooo0002oooo0003onk^4?lb</co003o00?o003o00KoEEFYoooo0?ooo`3oool0onk^4?lb</`6
o`00o`06ob4QgOn7QgOoool0onk^4?mEEJWo413^1?l00?l2oooo00co003o00CoA4Bjonk^4?ooo`3o
ool02Ol00?l01?l@4>kogMdQoooo0?mgMhL2oa0@kP04ogMgQoooo`3ogMdQoa0@kPKo003o00Co413^
omgM8Oooo`3oMgN70_l@4>h01?mgMhOoool0omgM8Ol@4>h9o`00o`;oool0VOl00?l1ooooo`00U?l0
0?l00om4A;[oool0oooo0007oooo0003ohN7Moooo`3oool000Ooool00_l00?l00on7QgOoool0oooo
0005oooo0004odA4^_l00?oo003oo`00o`;oool000?oMgN7o`00ool00?l02ol00?l00omVIYSok^h@
o`00o`09o`00o`03oa0@k_n7QgOogMdQ00;oool000?ogMdQohN7Mol00?l02?l00?l00ol@4>koQhMg
omgM8@02oooo0003omgM8On7QgOo003o00Wo003o00?oMgN7oooo0?ooo`00VOl00?l1ooooo`00]_l0
0?l7oooo03;o003o1oooo`2Io`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00ool00?n@o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(125) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.995 .005 .995 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.984 .016 .984 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.961 .039 .961 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.98 .02 .98 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.967 .033 .967 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.991 .009 .991 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.979 .021 .979 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.994 .006 .994 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.981 .019 .981 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.897 .103 .897 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.909 .091 .909 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.992 .008 .992 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.97 .03 .97 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.971 .029 .971 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.921 .079 .921 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.904 .096 .904 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.829 .171 .829 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.966 .034 .966 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.984 .016 .984 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.965 .035 .965 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.881 .119 .881 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.993 .007 .993 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.93 .07 .93 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.827 .173 .827 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.935 .065 .935 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.655 .345 .655 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.65 .35 .65 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.738 .262 .738 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.892 .108 .892 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.912 .088 .912 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.681 .319 .681 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.671 .329 .671 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.773 .227 .773 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.872 .128 .872 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.964 .036 .964 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.983 .017 .983 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.822 .178 .822 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.944 .056 .944 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.607 .393 .607 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.955 .045 .955 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.878 .122 .878 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.334 .666 .334 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.577 .423 .577 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.354 .646 .354 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.448 .552 .448 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.968 .032 .968 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.656 .344 .656 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.429 .571 .429 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.525 .475 .525 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.933 .067 .933 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.598 .402 .598 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.756 .244 .756 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.248 .752 .248 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.204 .796 .204 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.446 .554 .446 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.266 .734 .266 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.634 .366 .634 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.755 .245 .755 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.812 .188 .812 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.845 .155 .845 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.165 .835 .165 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.196 .804 .196 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.262 .738 .262 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.438 .562 .438 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.468 .532 .468 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.911 .089 .911 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.97 .03 .97 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.531 .469 .531 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.381 .619 .381 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.926 .074 .926 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.195 .805 .195 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.683 .317 .683 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.163 .837 .163 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.581 .419 .581 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.966 .034 .966 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.647 .353 .647 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.448 .552 .448 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.97 .03 .97 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.978 .022 .978 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.28 .72 .28 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.127 .873 .127 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.163 .837 .163 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.84 .16 .84 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.818 .182 .818 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.165 .835 .165 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.544 .456 .544 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.754 .246 .754 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.921 .079 .921 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.218 .782 .218 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.26 .74 .26 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.516 .484 .516 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.302 .698 .302 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.72 .28 .72 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.647 .353 .647 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.426 .574 .426 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.511 .489 .511 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.975 .025 .975 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.984 .016 .984 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.961 .039 .961 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.379 .621 .379 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.72 .28 .72 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.825 .175 .825 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.942 .058 .942 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.727 .273 .727 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.861 .139 .861 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.576 .424 .576 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.979 .021 .979 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.934 .066 .934 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.711 .289 .711 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.817 .183 .817 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.788 .212 .788 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.96 .04 .96 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.935 .065 .935 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.923 .077 .923 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.872 .128 .872 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.992 .008 .992 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.916 .084 .916 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.929 .071 .929 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.912 .088 .912 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.949 .051 .949 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.989 .011 .989 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.94 .06 .94 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.993 .007 .993 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.981 .019 .981 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.979 .021 .979 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.964 .036 .964 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.976 .024 .976 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.982 .018 .982 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.988 .012 .988 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.985 .015 .985 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.994 .006 .994 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000oog2?L00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooL8m`;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Oog
2?L2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;om`Sg00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooL8m`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?og2?L2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_og2?L00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom0_do`000?o^4Nko0000omPWf?l0000JooL8m`;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om0_d00Co0000onhAk_o^4Nko00000_oH9mP00ol0003om`SgooL8m`0IooL8
m`03o`000?on0Oko000001_on`Ck00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005oo@;m005o`000?o^4NkokQ7^onhA
k_l000000ooH9mP00ol0003om`SgooL8m`0IooL8m`03o`000?ok1?_on`Ck01[on`Ck00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?od2o@01Ol0003okQ7^onhAk_o^4Nko000000Cof2OH00?o0000ooL8
moog2?L06?og2?L00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om0_d00?o0000onhAk_o^
4Nh00_o^4Nh00ol0003of2OHomPWf003omPWf003o`000?og2?Oom`Sg01Oom`Sg00?o0000oo/4nook
1?/06Ook1?/00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ood2o@00ol0003okQ7^onhAkP02onhAkP03o`000?oH9mSof2OH00Co
f2OH00?o0000ooL8moog2?L05oog2?L00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?oo@;m003o`00
0?o^4NkokQ7^00?okQ7^00?o0000omPWf?oH9mP01OoH9mP00ol0003om`SgooL8m`0FooL8m`03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000Aoo@;m003o`000?o^4NkokQ7^00CokQ7^00?o0000omPWf?oH9mP01_oH
9mP2o`0001Gom`Sg0ol0000Hoo/4n`03o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
oo@;m003o`000?o^4NkokQ7^00CokQ7^00?o0000omPWf?oH9mP02?oH9mP00ol0003om`SgooL8m`0@
ooL8m`;o00000ooA;]400ol0003on`Ckoo/4n`0Doo/4n`03o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000oo@;m?od2o@04_od2o@00ol0003okQ7^onhAkP05onhAkP03o`000?oH9mSof2OH
00Wof2OH00?o0000ooL8moog2?L03Oog2?L2o`0000KodBkA0_l0000Doo/4n`03o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?od2oCom0_d01;om0_d00?o0000onhAk_o^
4Nh01Oo^4Nh00ol0003of2OHomPWf00:omPWf003o`000?og2?Oom`Sg00[om`Sg0_l0000:om4^d@03
o`000?ok1?_on`Ck017on`Ck00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om0_doo@;m00@oo@;m003o`000?o^4NkokQ7^00Ko
kQ7^00?o0000omPWf?oH9mP02ooH9mP00ol0003om`SgooL8m`08ooL8m`03o`000?oA;]7odBkA00_o
dBkA0_l0000@oo/4n`03o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?od2oCom0_d00oom0_d00?o0000onhAk_o^4Nh0
1oo^4Nh00ol0003of2OHomPWf00<omPWf003o`000?og2?Oom`Sg00Gom`Sg0_l0000@om4^d@03o`00
0?ok1?_on`Ck00gon`Ck00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?od2oCom0_d00oom0_d00?o0000onhAk_o^4Nh01oo^4Nh00ol0003of2OHomPW
f00=omPWf003o`000?og2?Oom`Sg00;om`Sg0_l0000Com4^d@;o00003?ok1?/00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?od2oCo
m0_d00kom0_d00?o0000onhAk_o^4Nh02?o^4Nh00ol0003of2OHomPWf00>omPWf004o`000?og2?Oo
0000o`0001OodBkA00?o0000oo/4nook1?/02Ook1?/00ol0003oo0?loo`3o00Loo`3o003o`000?oi
1_Won@Ki00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?od2oCo
m0_d00com0_d00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003of2OHomPWf00?omPWf003o`000?oA;]7o
dBkA01SodBkA0_l00009oo/4n`03o`000?ol0ocoo0?l01_oo0?l00?o0000ooT6nOoi1_T01?oi1_T4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>oo@;m003o`000?o^4NkokQ7^
00WokQ7^00?o0000omPWf?oH9mP03ooH9mP00ol0003odBkAom4^d@0Jom4^d@03o`000?ok1?_on`Ck
00Con`Ck0ol0000Loo`3o003o`000?oi1_Won@Ki00Won@Ki0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o^4NkokQ7^o`0000com0_d00?o0000onhAk_o^4Nh02_o^4Nh00ol0003of2OHomPWf00?omPW
f003o`000?oA;]7odBkA01_odBkA0_l00003oo/4n`04o`000?o_4>ooka3_onl@k`?o00006?ol0o`0
0ol0003on@KiooT6n@0=ooT6n@?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o^4NkokQ7^
00;okQ7^00?o0000oo@;m?od2o@02Ood2o@00ol0003okQ7^onhAkP0:onhAkP03o`000?oH9mSof2OH
00kof2OH00?o0000om4^dOoA;]407_oA;]400ol0003on`Cko`000007onl@k`?o00005?ol0o`00ol0
003on@KiooT6n@0AooT6n@;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o^4Nh00ol0003om0_doo@;m007oo@;m003
o`000?o^4NkokQ7^00_okQ7^00?o0000omPWf?oH9mP03_oH9mP00ol0003odBkAom4^d@0Oom4^d@03
o`000?o_4>ooka3_00Woka3_0ol0000@oo`3o003o`000?oi1_Won@Ki01?on@Ki00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003okQ7^
onhAkP07onhAkP03o`000?od2oCom0_d00Gom0_d00?o0000onhAk_o^4Nh03?o^4Nh00ol0003of2OH
omPWf00>omPWf003o`000?oA;]7odBkA01oodBkA00?o0000onl@koo_4>l03?o_4>l3o`0000goo0?l
00?o0000ooT6nOoi1_T05?oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_okQ7^00?o0000oo@;m?od2o@01?od
2o@00ol0003okQ7^onhAkP0<onhAkP03o`000?oH9mSof2OH00kof2OH00?o0000om4^dOoA;]407_oA
;]400ol0003oka3_onl@k`0@onl@k`?o00002Ool0o`00ol0003on@KiooT6n@0FooT6n@Oo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000onhAk_o^4Nh03?o^4Nh00ol0003om0_doo@;m002oo@;m003o`000?o^
4NkokQ7^00gokQ7^00?o0000omPWf?oH9mP03_oH9mP00ol0003odBkAom4^d@0Nom4^d@03o`000?o_
4>ooka3_01?oka3_0ol00005oo`3o003o`000?oi1_Won@Ki01Oon@Ki00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o^4NkokQ7^00kokQ7^00Go0000
oo@;m?od2oCom0_do`00000?onhAkP03o`000?oH9mSof2OH00gof2OH00?o0000om4^dOoA;]407ooA
;]400ol0003oka3_onl@k`0Fonl@k`?o000000?oo0?lo`000?oi1_T06?oi1_T00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000BonhAkP03o`000?od2oCo0000013okQ7^00?o0000omPWf?oH9mP02ooH9mP3
o`00023odBkA00?o0000onl@koo_4>l06_o_4>l00ol0003on@KiooT6n@0HooT6n@03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o^4NkokQ7^01?okQ7^00?o0000onhA
k_o^4Nh03oo^4Nh00ol0003of2OHomPWf007omPWf0Co00000_n7N8L00ol0003odBkAom4^d@0Nom4^
d@03o`000?o_4>ooka3_01[oka3_00?o0000ooT6nOoi1_T05ooi1_T00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
kQ7^00?o0000onhAk_o^4Nh03oo^4Nh00ol0003of2OHomPWf003omPWf0Co00001on7N8L00ol0003o
dBkAom4^d@0Lom4^d@03o`000?o_4>ooka3_01coka3_00?o0000ooT6nOoi1_T05Ooi1_T00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000onhAk_o^4Nh05oo^4Nh00ol0003okQ7^onhAkP0>onhAkP03o`00
0?oH9mSo000000?o00003?n7N8L00ol0003odBkAom4^d@0Kom4^d@03o`000?o_4>ooka3_01coka3_
00?o0000ooT6nOoi1_T05Ooi1_T00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o^
4Nh5o`0000_okQ7^0ol0000AohMhQ`03o`000?oA;]7odBkA01[odBkA00?o0000onl@koo_4>l07Oo_
4>l00ol0003on@KiooT6n@0CooT6n@03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o^4NkokQ7^01WokQ7^00?o0000
ojMHYonWF:L00_nWF:L7o`0000?okQ7^00?o0000ohMhQon7N8L04on7N8L3o`0001OodBkA0_l0000P
onl@k`03o`000?oi1_Won@Ki01?on@Ki00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000onhAk_o^4Nh06?o^4Nh00ol0
003oYeRWojMHY`0:ojMHY`?o00005_n7N8L00ol0003oAkQ7odNhA`05o`00013odBkA0_l000000onU
FZGo0000onl@k`0Oonl@k`03o`000?oi1_Won@Ki01;on@Ki00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000onhAk_o^4Nh05_o^4Nh00ol0003oYeRWojMHY`0=ojMHY`03
o`000?n7N8OoQgR701?oQgR700?o0000odNhAom7^4L01_m7^4L4o`0000_odBkA00?o0000ojEJYOnU
FZD00_nUFZD00ol0003oka3_onl@k`0Nonl@k`03o`000?oi1_Won@Ki013on@Ki00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003okQ7^onhAkP0DonhAkP03o`000?nWF:OoYeRW00ooYeRW
00?o0000ohMhQon7N8L04_n7N8L00ol0003oAkQ7odNhA`0:odNhA`Go00001?oA;]42o`0000GoYEZU
00?o0000onl@koo_4>l07_o_4>l00ol0003on@KiooT6n@0@ooT6n@03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o^
4NkokQ7^01CokQ7^00?o0000ojMHYonWF:L03onWF:L00ol0003oQgR7ohMhQ`0BohMhQ`03o`000?m7
^4OoAkQ700ooAkQ71?l00008ojEJY@03o`000?o_4>ooka3_01koka3_00?o0000ooT6nOoi1_T03_oi
1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
onhAk_o^4Nh04_o^4Nh00ol0003oYeRWojMHY`0@ojMHY`03o`000?n7N8OoQgR7017oQgR700?o0000
odNhAom7^4L04Om7^4L00ol0003oCK9=o`000009ojEJY@03o`000?o_4>ooka3_01goka3_00?o0000
ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000onhAk_o^4Nh03_o^4Nh3o`0001CoYeRW00?o0000ohMhQon7N8L04?n7N8L00ol0
003oAkQ7odNhA`0@odNhA`04o`000?m=/TgoCK9=o`0000WoYEZU00?o0000onl@koo_4>l07_o_4>l0
0ol0003on@KiooT6n@0<ooT6n@03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000onhAk_o^4Nh02_o^4Nh4o`0000;o_4>l00?o0000ojMH
YonWF:L04_nWF:L00ol0003oQgR7ohMhQ`0@ohMhQ`03o`000?m7^4OoAkQ700ooAkQ700Go0000odfb
COm=/TgoCK9=o`00000:ojEJY@03o`000?o_4>ooka3_01goka3_00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000onhA
k_o^4Nh01Oo^4Nh4o`0000Oo_4>l00?o0000ojMHYonWF:L04OnWF:L00ol0003oQgR7ohMhQ`0?ohMh
Q`03o`000?m7^4OoAkQ7013oAkQ700Go0000odfbCOm=/TgoCK9=o`00000:ojEJY@03o`000?o_4>oo
ka3_01goka3_00?o0000ooT6nOoi1_T02ooi1_T00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o^4Nko
kQ7^00Co00002onl@k`00ol0003oYeRWojMHY`0BojMHY`03o`000?n7N8OoQgR700koQgR700?o0000
odNhAom7^4L03om7^4L00ol0003oCK9=odfbC@02odfbC@03o`000?nUFZGoYEZU00WoYEZU00?o0000
onl@koo_4>l07?o_4>l3o`0000[on@Ki00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000on/Djol0003o00003onl@k`00ol0003oYeRWojMHY`0AojMHY`03o`000?lo
`3oo000000ooQgR700?o0000odNhAom7^4L03_m7^4L00ol0003oCK9=odfbC@03odfbC@03o`000?nU
FZGoYEZU00WoYEZU00?o0000onl@koo_4>l06Oo_4>l3o`0000?okA;]00?o0000ooT6nOoi1_T01ooi
1_T00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o[5>_ojaC[o`00017o_4>l00?o
0000ojMHYonWF:L03onWF:L01Ol0003o?l0ooco0?olo`3oo000000[oQgR71?l0000AodNhA`03o`00
0?m=/TgoCK9=00?oCK9=00?o0000ojEJYOnUFZD02_nUFZD00ol0003oka3_onl@k`0Fonl@k`;o0000
1oo]4^d00ol0003on@KiooT6n@05ooT6n@03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003ojaC[on/Dj`02on/Dj`03o`000?nl@kco_4>l00ko_4>l00?o
0000ojMHYonWF:L03_nWF:L00ol0003o?l0ooco0?`03oco0?`04o`000?n7N8OoQgR7ohMhQ`Ko0000
0olacS400ol0003oAkQ7odNhA`0>odNhA`03o`000?m=/TgoCK9=00CoCK9=00?o0000ojEJYOnUFZD0
2_nUFZD00ol0003oka3_onl@k`0Conl@k`?o00002_o]4^d00ol0003on@KiooT6n@03ooT6n@03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o[
5>_ojaC[00?ojaC[00?o0000oka3_?nl@k`03_nl@k`00ol0003oYeRWojMHY`0=ojMHY`03o`000?lo
`3oo?l0o00Go?l0o0ol0000:oc7><@03o`000?m7^4OoAkQ700coAkQ700?o0000odfbCOm=/Td01Om=
/Td00ol0003oYEZUojEJY@0;ojEJY@03o`000?o_4>ooka3_013oka3_0_l0000>ondBk@03o`000?oi
1_Won@Ki00;on@Ki00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o[5>_ojaC[00CojaC[00?o0000oka3_?nl@k`03onl@k`00ol0003oYeRWojMHY`0;
ojMHY`03o`000?lo`3oo?l0o00Ko?l0o00?o0000oc7><OlacS402olacS400ol0003oAkQ7odNhA`0;
odNhA`03o`000?m=/TgoCK9=00GoCK9=00?o0000ojEJYOnUFZD03?nUFZD00ol0003oka3_onl@k`0<
onl@k`?o00004Oo]4^d5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o[5>_ojaC[
00KojaC[00?o0000oka3_?nl@k`03_nl@k`00ol0003oYeRWojMHY`0:ojMHY`03o`000?lo`3oo?l0o
00Oo?l0o00?o0000oc7><OlacS402olacS400ol0003oAkQ7odNhA`0:odNhA`03o`000?m=/TgoCK9=
00KoCK9=00?o0000ojEJYOnUFZD03?nUFZD00ol0003oka3_onl@k`0:onl@k`;o00005?o]4^d00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003ojaC[on/Dj`07on/D
j`03o`000?nl@kco_4>l00ko_4>l00?o0000ojMHYonWF:L02OnWF:L00ol0003o?l0ooco0?`08oco0
?`03o`000?lacS7o<Lha00co<Lha00?o0000odNhAom7^4L02?m7^4L00ol0003oCK9=odfbC@07odfb
C@03o`000?nUFZGoYEZU00goYEZU1Ol00004onl@k`?o00005Oo]4^d00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ojaC[on/Dj`08on/D
j`03o`000?nl@kco_4>l00oo_4>l00?o0000ojMHYonWF:L01onWF:L00ol0003o?l0ooco0?`09oco0
?`03o`000?lacS7o<Lha00co<Lha0ol00008odNhA`03o`000?m=/TgoCK9=00OoCK9=00?o0000ojEJ
YOnUFZD03OnUFZD00ol0003obCK9olTfb@02olTfb@Co00006?o]4^d00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o[5>_ojaC[
00[ojaC[00?o0000oka3_?nl@k`03_nl@k`00ol0003oYeRWojMHY`06ojMHY`03o`000?lo`3oo?l0o
00[o?l0o00?o0000oc7><OlacS402_lacS42o`0000?o:MHY00?o0000odNhAom7^4L01?m7^4L00ol0
003oCK9=odfbC@08odfbC@03o`000?nUFZGoYEZU00coYEZU00?o0000olTfbOo9=/T01_o9=/T00ol0
003okA;]ondBk@0EondBk@03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000on/Djoo[5>/02oo[5>/00ol0003o
_4>loka3_00>oka3_003o`000?nWF:OoYeRW00GoYeRW00?o0000oco0?olo`3l02olo`3l00ol0003o
<Lhaoc7><@08oc7><@;o00001_lYeRT00ol0003oAkQ7odNhA`02odNhA`03o`000?m=/TgoCK9=00Wo
CK9=00?o0000ojEJYOnUFZD03?nUFZD00ol0003obCK9olTfb@07olTfb@03o`000?o]4^gokA;]01Co
kA;]00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o[5>_ojaC[00gojaC[00?o0000oka3_?nl@k`03_nl@k`00ol0003oYeRWojMHY`03ojMHY`03o`00
0?lo`3oo?l0o00co?l0o00?o0000oc7><OlacS401_lacS42o`0000Wo:MHY00Go0000odNhAom7^4Oo
AkQ7o`00000;odfbC@03o`000?nUFZGoYEZU00coYEZU00?o0000olTfbOo9=/T01oo9=/T00ol0003o
kA;]ondBk@0CondBk@03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o[5>_ojaC[00ko
jaC[00?o0000oka3_?nl@k`03_nl@k`00ol0003oYeRWojMHY`02ojMHY`03o`000?lo`3oo?l0o00go
?l0o00?o0000oc7><OlacS401?lacS42o`0000co:MHY00?o0000odNhAol000003?m=/Td00ol0003o
YEZUojEJY@0;ojEJY@03o`000?o9=/WobCK900WobCK900?o0000ondBkOo]4^d04Oo]4^d00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003ojaC[on/Dj`0?on/Dj`03o`000?nl@kco_4>l00ko_4>l00Go0000ojMHYonWF:Oo
YeRWo`00000@oco0?`03o`000?lacS7o<Lha00;o<Lha0_l0000?obWF:@03o`000?m=/TgoCK9=00_o
CK9=00?o0000ojEJYOnUFZD02onUFZD00ol0003obCK9olTfb@09olTfb@03o`000?o]4^gokA;]017o
kA;]00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000on/Djoo[5>/04Oo[5>/00ol0003o_4>l
oka3_00>oka3_0Co00004?lo`3l00ol0003o<Lhaoc7><@02o`00017o:MHY00?o0000odfbCOm=/Td0
2om=/Td00ol0003oYEZUojEJY@0:ojEJY@03o`000?o9=/WobCK900_obCK900?o0000ondBkOo]4^d0
3oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ook1?/00ol0003onPGjooX5nP03ooX5nP03o`000?o[
5>_ojaC[01;ojaC[00?o0000oka3_?nl@k`03Onl@k`00ol0003oFZEJoeZUFP02oeZUFP;o00003_lo
`3l3o`0001?o:MHY00?o0000odfbCOm=/Td02om=/Td00ol0003oYEZUojEJY@0:ojEJY@03o`000?o9
=/WobCK900_obCK900?o0000ondBkOo]4^d03oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ok1?_on`Ck00Con`Ck00Go0000ooX5n_oj1O[onPGjo`00000Eon/Dj`03o`000?nl
@kco_4>l00co_4>l00?o0000oeZUF_mJYEX01OmJYEX2o`0000co?l0o00?o0000obWF:OlYeRT05?lY
eRT00ol0003oCK9=odfbC@0:odfbC@03o`000?nUFZGoYEZU00[oYEZU00?o0000olTfbOo9=/T03?o9
=/T00ol0003okA;]ondBk@0=ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Son`Ck00?o0000
ooX5n_l000005oo[5>/00ol0003o_4>loka3_00:oka3_003o`000?mJYE[oFZEJ00SoFZEJ00?o0000
oco0?olo`3l02?lo`3l3o`0001Go:MHY0_l0000;odfbC@03o`000?nUFZGoYEZU00WoYEZU00?o0000
olTfbOo9=/T03_o9=/T00ol0003okA;]ondBk@0<ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_on`Ck00?o0000on/Djoo[5>/05_o[5>/00ol0003o_4>loka3_009oka3_003o`000?mJYE[oFZEJ
00[oFZEJ0_l00005oco0?`?o00000olZeBX00ol0003o:MHYobWF:@0AobWF:@03o`000?lZeB[o:]DZ
00;o00002Om=/Td00ol0003oYEZUojEJY@09ojEJY@03o`000?o9=/WobCK900kobCK900?o0000ondB
kOo]4^d02oo]4^d00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo/4n`03o`000?o[5>_ojaC[01Ko
jaC[00?o0000oka3_?nl@k`00onl@k`6o`0000ooFZEJ0_l000000olo`3oo0000o`000007ob[E:P;o
00004?lYeRT00ol0003o:]DZob[E:P03ob[E:P?o00001_m=/Td00ol0003oYEZUojEJY@09ojEJY@03
o`000?o9=/WobCK900oobCK900?o0000ondBkOo]4^d02_o]4^d00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ok1?/00ol0003ojaC[
on/Dj`0Fon/Dj`Go00001On^DJh00ol0003oFZEJoeZUFP0?oeZUFP03o`000?lZeB[o:]DZ00Wo:]DZ
00?o0000obWF:OlYeRT03?lYeRT00ol0003o:]DZob[E:P07ob[E:P;o00000_m=/Td>o`0001;obCK9
00?o0000ondBkOo]4^d02Oo]4^d00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ok1?_on`Ck013on`Ck00?o0000on/Djoo[5>/05Oo[
5>/00ol0003o[U6^ojiA[P09ojiA[P03o`000?mJYE[oFZEJ00koFZEJ00?o0000ob[E:_lZeBX02_lZ
eBX2o`0000_o:MHY00?o0000ob[E:_lZeBX02_lZeBX2o`0000goKI9]00?o0000olTfbOo9=/T04Oo9
=/T00ol0003okA;]ondBk@07ondBk@03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ok1?/00ol0003ojaC[on/Dj`0Con/Dj`03o`000?n^DJko[U6^00[o[U6^00?o
0000oeZUF_mJYEX03_mJYEX00ol0003o:]DZob[E:P0<ob[E:P03o`000?lYeRWo:MHY00Oo:MHY00?o
0000ob[E:_lZeBX02olZeBX00ol0003oKI9]offBK@0=offBK@03o`000?o9=/WobCK9013obCK900?o
0000ondBkOo]4^d01oo]4^d00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?o[5>_ojaC[01;ojaC[00?o0000ojiA[_n^DJh02on^
DJh00ol0003oFZEJoeZUFP0>oeZUFP03o`000?lZeB[o:]DZ00go:]DZ00?o0000obWF:OlYeRT01?lY
eRT2o`0000ko:]DZ00?o0000offBKOm]TVd03Om]TVd00ol0003obCK9olTfb@0@olTfb@Co00001Oo]
4^d00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok
1?_on`Ck01Gon`Ck5?l0000?ojiA[P03o`000?mJYE[oFZEJ00coFZEJ00?o0000ocC;=?l000003olZ
eBX2o`0000?o:MHY00Co0000ob3O8?lPgb3o00003OlZeBX00ol0003oKI9]offBK@0>offBK@03o`00
0?o9=/WobCK900cobCK90ol00004omlPg`?o00000_o]4^d00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo/4nook1?/05Ook1?/00ol0003oiaSWonLH
i`0@onLHi`03o`000?n^DJko[U6^00go[U6^00?o0000oeZUF_mJYEX02omJYEX01?l0003o=</docC;
=?l0000Aob[E:P03o`000?lYeRWo000000Co8=lP00?o0000ob[E:_lZeBX02_lZeBX00ol0003oKI9]
offBK@0>offBK@03o`000?o9=/WobCK900WobCK90ol0000:omlPg`;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?oW6>OoiaSW013oiaSW00?o0000ojiA[_n^DJh03On^
DJh00ol0003oFZEJoeZUFP0:oeZUFP03o`000?ldbcCo=</d00;o=</d00?o0000ob[E:_lZeBX03olZ
eBX00ol0003o8=lPob3O8004ob3O8003o`000?lZeB[o:]DZ00Wo:]DZ00?o0000offBKOm]TVd03_m]
TVd00ol0003obCK9olTfb@06olTfb@?o00003_oO8=l00ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ok1?_on`Ck01Gon`Ck00?o0000
onLHiooW6>L04_oW6>L00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mJYE[oFZEJ00WoFZEJ00?o0000
ocC;=?ldbc@00_ldbc@00ol0003o:]DZob[E:P0?ob[E:P03o`000?lPgb3o8=lP00Go8=lP00?o0000
ob[E:_lZeBX02?lZeBX00ol0003oKI9]offBK@0?offBK@03o`000?o9=/WobCK900;obCK90ol0000B
omlPg`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003on`Ckoo/4n`0Coo/4n`?o00005?oW6>L00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mJYE[oFZEJ
00SoFZEJ00?o0000ocC;=?ldbc@01?ldbc@00ol0003o:]DZob[E:P0>ob[E:P03o`000?lPgb3o8=lP
00Ko8=lP00?o0000ob[E:_lZeBX01olZeBX00ol0003oKI9]offBK@0?offBK@03o`000?o9=/Wo0000
00;o00005OoO8=l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ok1?_on`Ck00oon`Ck1?l00002ooH9mP03o`000?oW6>OoiaSW01;o
iaSW00?o0000ojiA[_n^DJh03On^DJh00ol0003oFZEJoeZUFP07oeZUFP03o`000?ldbcCo=</d00Go
=</d00?o0000ob[E:_lZeBX03OlZeBX00ol0003o8=lPob3O8008ob3O8003o`000?lZeB[o:]DZ00Ko
:]DZ00?o0000offBKOm]TVd04?m]TVd00ol0003ogb3OomlPg`0FomlPg`03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/02ook1?/4o`0000KomPWf
00?o0000onLHiooW6>L04ooW6>L00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mJYE[oFZEJ00GoFZEJ
00?o0000ocC;=?ldbc@01oldbc@00ol0003o:]DZob[E:P0<ob[E:P03o`000?lPgb3o8=lP00Wo8=lP
00?o0000ob[E:_lZeBX01OlZeBX00ol0003oKI9]offBK@0@offBK@03o`000?oO8=oogb3O01Oogb3O
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/01ook
1?/4o`0000[omPWf00?o0000onLHiooW6>L04ooW6>L00ol0003o[U6^ojiA[P0=ojiA[P03o`000?mJ
YE[oFZEJ00CoFZEJ00?o0000ocC;=?ldbc@02?ldbc@00ol0003o:]DZob[E:P0<ob[E:P03o`000?lP
gb3o8=lP00[o8=lP00?o0000ob[E:_lZeBX01?lZeBX00ol0003oKI9]offBK@0@offBK@03o`000?oO
8=oogb3O01Oogb3O00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003on`Ckoo/4n`04oo/4n`Co00003_of2OH00ol0003oiaSWonLHi`0ConLHi`03o`000?n^DJko
[U6^00go[U6^00?o0000oeZUF_mJYEX01?mJYEX00ol0003o=</docC;=009ocC;=003o`000?lZeB[o
:]DZ00_o:]DZ00?o0000ob3O8?lPgb002olPgb000ol0003o:]DZob[E:P03ob[E:P03o`000?m]TVgo
KI9]013oKI9]00?o0000omlPgooO8=l05ooO8=l00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`04o`0001;omPWf00?o0000onLHiooW6>L04ooW6>L00ol0
003o[U6^ojiA[P0>ojiA[P03o`000?mJYE[oFZEJ00;oFZEJ00?o0000ocC;=?ldbc@02_ldbc@00ol0
003o:]DZob[E:P0:ob[E:P03o`000?lPgb3o8=lP00go8=lP00?o0000ob[E:_lZeBX00_lZeBX00ol0
003oKI9]offBK@0@offBK@03o`000?oO8=oogb3O01Sogb3O00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oW6>OoiaSW01?oiaSW00?o0000ojiA[_n^DJh03?n^DJh4o`000003oeZUF_l0003o=</d00go
=</d00?o0000ob[E:_lZeBX02OlZeBX00ol0003o8=lPob3O800>ob3O8005o`000?lZeB[o:]DZob[E
:_l000004_m]TVd00ol0003ogb3OomlPg`0HomlPg`?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oW6>OoiaSW
01?oiaSW00?o0000ojiA[_n^DJh02on^DJh00ol0003oEJYEoeFZE@02oeFZE@;o00003_ldbc@00ol0
003o:]DZob[E:P09ob[E:P03o`000?lPgb3o8=lP00oo8=lP00Co0000ob[E:_lZeB[o00004_m]TVd0
0ol0003ogb3OomlPg`0HomlPg`03o`000?o`3o3ol0o`00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onLHiooW6>L04ooW6>L00ol0003o[U6^ojiA[P0:
ojiA[P03o`000?mEZUGoEJYE00GoEJYE00?o0000ocC;=?ldbc@03?ldbc@00ol0003o:]DZob[E:P08
ob[E:P03o`000?lPgb3o8=lP00oo8=lP1Ol0000AoffBK@03o`000?oO8=oogb3O01Oogb3O00?o0000
oo0?l?o`3o001?o`3o03o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oW6>OoiaSW01?oiaSW00?o0000ojiA[_n^DJh02?n^DJh2o`00
00WoEJYE00?o0000ocC;=?ldbc@02oldbc@00ol0003o:]DZob[E:P07ob[E:P03o`000?lPgb3o8=lP
00go8=lP0ol00005ocO8=`03o`000?m]TVgoKI9]00koKI9]00?o0000omlPgooO8=l05_oO8=l00ol0
003ol0o`oo0?l008oo0?l0?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonLHi`03o`000?n^DJko[U6^00Ko[U6^00?o0000oeFZEOmE
ZUD02_mEZUD00ol0003o=</docC;=00:ocC;=1[o00002Olgb3L00ol0003oKI9]offBK@0<offBK@?o
00005_oO8=l00ol0003ol0o`oo0?l00<oo0?l0?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oU6^D3o`0001;oiaSW00?o0000ojiA[_n^DJh01?n^DJh2o`0000koEJYE
00?o0000ocC;=?ldbc@01oldbc@2o`0000[o</db00?o0000obWF:OlYeRT03?lYeRT00ol0003o=lPg
ocO8=`08ocO8=`;o00002_m]TVd2o`0000?oTfbC0_l0000ComlPg`03o`000?o`3o3ol0o`013ol0o`
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onDJi@;o00004?oW
6>L00ol0003o[U6^ojiA[P03ojiA[P03o`000?mEZUGoEJYE00ooEJYE00?o0000ocC;=?ldbc@01?ld
bc@2o`0000co</db00?o0000obWF:OlYeRT03?lYeRT00ol0003o=lPgocO8=`0:ocO8=`03o`000?m]
TVgoKI9]00GoKI9]0_l00007oi=/T`03o`000?oO8=oogb3O00oogb3O00?o0000oo0?l?o`3o004Oo`
3o001?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onDJiOoU6^D01OoU6^D2o`0000ooiaSW00Go0000ojiA[_n^DJko[U6^o`00000CoeFZE@03o`00
0?ldbcCo=</d00;o=</d00?o0000oc;=<_lbcC803OlbcC800ol0003o:MHYobWF:@0;obWF:@03o`00
0?lgb3Oo=lPg00_o=lPg00?o0000offBKOm]TVd00_m]TVd2o`0000[oTfbC0_l0000>omlPg`03o`00
0?o`3o3ol0o`017ol0o`00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onDJiOoU6^D01_oU6^D3o`0000_oiaSW1Ol0000EoeFZE@04o`00
0?ldbcCo0000o`00013o</db00?o0000obWF:OlYeRT02olYeRT00ol0003o=lPgocO8=`0<ocO8=`04
o`000?m]TVgo0000o`0000koTfbC0_l0000;omlPg`03o`000?o`3o3ol0o`017ol0o`00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oU6^GoiA[U00WoiA[U0_l00008onLHi`03o`000?n[E:_oZeB[00;oZeB[00?o0000oeFZEOmE
ZUD05?mEZUD00ol0003o</dboc;=<P0@oc;=<P03o`000?lYeRWo:MHY00_o:MHY00?o0000ocO8=olg
b3L03Olgb3L00ol0003oTfbCoi=/T`0@oi=/T`03o`000?oO8=oogb3O00Oogb3O00?o0000oo0?l?o`
3o004Oo`3o000ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oU6^GoiA[U00_oiA[U
0_l00005onLHi`03o`000?n[E:_oZeB[00CoZeB[00?o0000oeFZEOmEZUD04omEZUD00ol0003o</db
oc;=<P0@oc;=<P03o`000?lYeRWo:MHY00_o:MHY00?o0000ocO8=olgb3L03Olgb3L00ol0003oTfbC
oi=/T`0Aoi=/T`;o00000ooO8=l4o`0001?ol0o`00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oU6^GoiA[U00goiA[U0ol000000ooW6>Oo0000oj]DZ`07oj]DZ`03o`000?mEZUGoEJYE01;o
EJYE00?o0000oc;=<_lbcC804?lbcC800ol0003o:MHYobWF:@0;obWF:@03o`000?lgb3Oo=lPg00go
=lPg00?o0000oi=/TonCK9<04onCK9<3o`0000?ojAKY00?o0000oo0?l?o`3o004?o`3o000ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oU6^GoiA[U013oiA[U00?o0000oj]DZon[E:/0
2?n[E:/00ol0003oEJYEoeFZE@0AoeFZE@03o`000?lbcC;o</db017o</db00?o0000obWF:OlYeRT0
2_lYeRT00ol0003o=lPgocO8=`0<ocO8=`03o`000?mQWV7o000001CoTfbC00?o0000onTFjOoY5^T0
1?oY5^T00ol0003ol0o`oo0?l00>oo0?l003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onDJiOoU6^D03ooU
6^D00ol0003oZeB[oj]DZ`09oj]DZ`03o`000?mEZUGoEJYE013oEJYE00?o0000oc;=<_lbcC804Olb
cC800ol0003o:MHYobWF:@0:obWF:@03o`000?lgb3Oo=lPg00_o=lPg00Co0000of6NHOmQWV7o0000
5?nCK9<00ol0003ojAKYonTFj@05onTFj@03o`000?o`3o3ol0o`00col0o`00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiA[UonDJ
i@0?onDJi@03o`000?n[E:_oZeB[00[oZeB[00?o0000oeFZEOmEZUD03_mEZUD00ol0003oA;]4o`00
000Boc;=<P03o`000?lYeRWo:MHY00[o:MHY00?o0000ocO8=olgb3L02_lgb3L00ol0003oHIiQof6N
H@02of6NH@03o`000?nCK9?oTfbC013oTfbC00?o0000onTFjOoY5^T01ooY5^T00ol0003ol0o`oo0?
l00:oo0?l003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oU6^GoiA[U00ooiA[U00?o0000oj]DZon[E:/0
2on[E:/00ol0003oEJYEoeFZE@0<oeFZE@05o`000?m4^dCoA;]4odBkA?l000004OlbcC800ol0003o
:MHYobWF:@0:obWF:@03o`000?lgb3Oo=lPg00Wo=lPg00?o0000of6NHOmQWV400omQWV400ol0003o
TfbCoi=/T`0@oi=/T`03o`000?oY5^WojAKY00SojAKY00?o0000oo0?l?o`3o002?o`3o000ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onDJiOoU6^D03_oU6^D00ol0003oZeB[oj]DZ`0=oj]DZ`03o`00
0?mEZUGoEJYE00[oEJYE00?o0000odBkA?m4^d@00om4^d@00ol0003o</dboc;=<P0?oc;=<P03o`00
0?lYeRWo:MHY00Wo:MHY00?o0000ocO8=olgb3L02?lgb3L00ol0003oHIiQof6NH@05of6NH@03o`00
0?nCK9?oTfbC00ooTfbC00?o0000onTFjOoY5^T02OoY5^T00ol0003ol0o`oo0?l006oo0?l003o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiA[UonDJi@0>onDJi@03o`000?n[
E:_oZeB[00koZeB[00?o0000oeFZEOmEZUD02?mEZUD00ol0003oA;]4odBkA005odBkA003o`000?lb
cC;o</db00ko</db00?o0000obWF:OlYeRT02OlYeRT00ol0003o=lPgocO8=`07ocO8=`03o`000?mQ
WV7oHIiQ00KoHIiQ00?o0000oi=/TonCK9<03onCK9<00ol0003ojAKYonTFj@09onTFj@03o`000?o`
3o3ol0o`00Gol0o`00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiA[UonDJi@0=
onDJi@03o`000?n[E:_oZeB[00ooZeB[00?o0000oeFZEOmEZUD01_mEZUD00ol0003oA;]4odBkA007
odBkA003o`000?lbcC;o</db00go</db00?o0000obWF:OlYeRT02OlYeRT00ol0003o=lPgocO8=`04
ocO8=`?o00002_mQWV400ol0003oTfbCoi=/T`0=oi=/T`03o`000?oY5^WojAKY00_ojAKY00?o0000
oo0?l?o`3o000oo`3o000ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oU6^GoiA[U
00goiA[U00?o0000oj]DZon[E:/04?n[E:/00ol0003oEJYEoeFZE@05oeFZE@03o`000?m4^dCoA;]4
00SoA;]400?o0000oc;=<_lbcC803?lbcC800ol0003o:MHYobWF:@09obWF:@03o`000?lgb3Oo0000
00Co00000_m2_D800ol0003oHIiQof6NH@08of6NH@03o`000?nCK9?oTfbC00goTfbC00?o0000onTF
jOoY5^T03?oY5^T01Ol0003ol0o`oo0?l?o`3o3o000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0
003oZeB[oj]DZ`0Aoj]DZ`03o`000?mEZUGoEJYE00?oEJYE00?o0000odBkA?m4^d@02_m4^d@00ol0
003o</dboc;=<P0;oc;=<P03o`000?lYeRWo:MHY00So:MHY0ol00008od:m@P03o`000?mQWV7oHIiQ
00SoHIiQ00?o0000oi=/TonCK9<03?nCK9<00ol0003ojAKYonTFj@0=onTFj@03o`000?o`3o3o0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oU6^GoiA[U00goiA[U00?o0000oj]DZon[E:/04_n[E:/01Ol0
003oEJYEoeFZEOmEZUGo000000koA;]400?o0000oc;=<_lbcC802olbcC800ol0003o:MHYobWF:@06
obWF:@03o`000?m2_D;o@[e200Wo@[e200?o0000of6NHOmQWV402OmQWV400ol0003oTfbCoi=/T`0:
oi=/T`03o`000?oY5^WojAKY00oojAKY00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0003oZeB[oj]DZ`0Coj]DZ`03o`000?mEZUGo0000
013oA;]43_l00006obWF:@;o00003?m2_D800ol0003oHIiQof6NH@09of6NH@03o`000?nCK9?oTfbC
00[oTfbC00?o0000onTFjOoY5^T03ooY5^T00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onDJiOoU6^D02ooU6^D00ol0003o
ZeB[oj]DZ`0Doj]DZ`?o00003om4^d@00ol0003o@ka3od>l@`0<od>l@`04o`000?lYeRWo:MHYobWF
:@;o00003om2_D800ol0003oHIiQof6NH@09of6NH@03o`000?nCK9?oTfbC00WoTfbC00?o0000onTF
jOoY5^T04?oY5^T00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oU6^GoiA[U00_o
iA[U00?o0000oj]DZon[E:/04on[E:/01Ol0003oLXebog:=L_mbSG;o000000goA;]400?o0000od>l
@om3_4<03_m3_4<00ol0003o:MHYo`00000Aod:m@P03o`000?mQWV7oHIiQ00WoHIiQ00?o0000oi=/
TonCK9<02OnCK9<00ol0003ojAKYonTFj@0@onTFj@03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000Boj]DZ`03o`000?mbSG;oLXeb00?oLXeb00?o0000odBkA?m4^d@02Om4^d@00ol0003o
@ka3od>l@`0@od>l@`03o`000?m2_D;o@[e2017o@[e200?o0000of6NHOmQWV402OmQWV400ol0003o
TfbCoi=/T`07oi=/T`03o`000?oY5^WojAKY017ojAKY00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
j1OXonPGj00<onPGj003o`000?nWF:OoYeRW00?o00003_n[E:/00ol0003oLXebog:=LP05og:=LP03
o`000?m4^dCoA;]400OoA;]400?o0000od>l@om3_4<04Om3_4<00ol0003o@[e2od:m@P0Aod:m@P03
o`000?mQWV7oHIiQ00WoHIiQ00?o0000oi=/TonCK9<01_nCK9<2o`0001CojAKY00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oj1OX00koj1OX
00?o0000ojMHYonWF:L00onWF:L3o`0000[oZeB[00?o0000og:=L_mbSG801ombSG800ol0003oA;]4
odBkA005odBkA003o`000?m3_4?o@ka301;o@ka300?o0000od:m@_m2_D804Om2_D800ol0003oHIiQ
of6NH@0:of6NH@03o`000?nCK9?oTfbC00;oTfbC0ol00002okI9]P03o`000?oY5^WojAKY017ojAKY
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004ooX5nP03o`000?oX5nSoj1OX00koj1OX00?o0000ojMHYonWF:L01_nW
F:L3o`0000KoZeB[00?o0000og:=L_mbSG802OmbSG800ol0003oA;]4odBkA003odBkA003o`000?m3
_4?o@ka301?o@ka300?o0000od:m@_m2_D804_m2_D800ol0003oHIiQof6NH@09of6NH@03o`000?nC
K9?o000000;o00001_nfBKH00ol0003ojAKYonTFj@0@onTFj@03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007ooX5nP03o`000?oX5nSo
j1OX00goj1OX00?o0000ojMHYonWF:L02_nWF:L3o`0000;oZeB[00?o0000og:=L_mbSG802ombSG80
1Ol0003oA;]4odBkA?m4^dCo000001Ko@ka300?o0000od:m@_m2_D804_m2_D800ol0003oHIiQof6N
H@0:of6NH@03o`000?nfBKKo]TVf00So]TVf00?o0000onTFjOoY5^T04?oY5^T00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:ooX5nP03o`00
0?oX5nSoj1OX00goj1OX00?o0000ojMHYonWF:L03OnWF:L2o`0000ooLXeb00?o0000odBkA?l00000
5om3_4<00ol0003o@[e2od:m@P0Cod:m@P03o`000?mQWV7oHIiQ00WoHIiQ00?o0000okI9]_nfBKH0
2OnfBKH00ol0003ojAKYonTFj@0?onTFj@03o`000?oj1O[onPGj00;o00000ook1?/2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000onPGj?oX5nP03OoX
5nP00ol0003oYeRWojMHY`0>ojMHY`03o`000?mbSG;oLXeb00koLXeb00?o0000od>l@om3_4<05_m3
_4<00ol0003o@[e2od:m@P0Cod:m@P03o`000?mQWV7oHIiQ00SoHIiQ00?o0000okI9]_nfBKH02onf
BKH5o`0000cojAKY00?o0000ooX5n_l000001ook1?/2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?oj1O[onPGj00_onPGj00?o0000onPGj?oX5nP03OoX5nP00ol0003oYeRWojMHY`0>
ojMHY`03o`000?mbSG;oLXeb00koLXeb00?o0000od>l@om3_4<05_m3_4<00ol0003o@[e2od:m@P0C
od:m@P03o`000?mQWV7oHIiQ00OoHIiQ00?o0000okI9]_nfBKH03?nfBKH00ol0003ojQGZonXEjP02
onXEjPWo00001?oY5^T00ol0003on`Ckoo/4n`08oo/4n`;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000ooX5n_oj1OX02ooj1OX00ol0003oj1OXonPGj00<onPGj003o`000?nWF:OoYeRW
00koYeRW00?o0000og:=L_mbSG803ombSG800ol0003o@ka3od>l@`0Eod>l@`03o`000?m2_D;o@[e2
01?o@[e21?l00005of6NH@03o`000?nfBKKo]TVf00go]TVf00?o0000onXEj_oZ5NX02ooZ5NX4o`00
00gon`Ck0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03
o`000?oX5nSoj1OX00_oj1OX00?o0000ojMHYonWF:L03onWF:L00ol0003oLXebog:=LP0?og:=LP03
o`000?m3_4?o@ka301Go@ka300?o0000od:m@_m2_D804?m2_D83o`0000CoPWf20ol000000omQWV7o
0000okI9]P0>okI9]P03o`000?oZ5N[ojQGZ00oojQGZ00?o0000oo/4nook1?/03Ook1?/2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000ooX5n_oj1OX02_oj1OX00ol0003oj1OXonPGj00;onPGj003o`00
0?nWF:OoYeRW00ooYeRW00?o0000og:=L_mbSG803ombSG82o`0001Co@ka30ol0000@od:m@P;o0000
2_n2OH800ol0003o]TVfokI9]P0>okI9]P03o`000?oZ5N[ojQGZ013ojQGZ0_l0000?oo/4n`;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oX5nSoj1OX00_oj1OX4ol0000>og:=LP?o0000
0_m]TVd00ol0003o@ka3od>l@`0<od>l@`Go00000_mQWV400ol0003o@[e2od:m@P0<od:m@P;o0000
3?n2OH800ol0003o]TVfokI9]P0>okI9]P03o`000?oZ5N[ojQGZ013ojQGZ00?o0000ooH9m_l00000
4?ok1?/2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oX
5nSoj1OX00_oj1OX00?o0000ojIIY_nVFJH03onVFJH00ol0003oLXebog:=LP09og:=LP?o00001_m]
TVd00ol0003o@ka3od>l@`06od>l@`Go00002?mQWV400ol0003o@[e2od:m@P08od:m@P?o00003on2
OH800ol0003o]TVfokI9]P0=okI9]P03o`000?oZ5N[ojQGZ00oojQGZ00Go0000ooH9m_of2OKomPWf
o`00000Aoo/4n`;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oj1OXonPG
j00;onPGj003o`000?nVFJKoYUVV00ooYUVV00?o0000og:=L_mbSG801_mbSG83o`0000[oKI9]00?o
0000od>l@om3_4<01Ol0000>of6NH@03o`000?m2_D;o@[e200Go@[e20_l0000Boh9mPP03o`000?nf
BKKo]TVf00co]TVf00?o0000onXEj_oZ5NX04?oZ5NX00ol0003omPWfooH9mP02ooH9mP03o`000?ok
1?_on`Ck013on`Ck00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5n_oj1OX02Ooj1OX00ol0003oj1OXonPGj00;
onPGj003o`000?nVFJKoYUVV013oYUVV00?o0000og:=L_mbSG800_mbSG83o`0000goKI9]0ol0000C
of6NH@03o`000?m2_D;o@[e200?o@[e20_l0000Eoh9mPP03o`000?nfBKKo]TVf00_o]TVf00?o0000
onXEj_oZ5NX03ooZ5NX00ol0003omPWfooH9mP04ooH9mP03o`000?ok1?_on`Ck00gon`Ck0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooX5
n_oj1OX02Ooj1OX00ol0003oj1OXonPGj008onPGj0Co00004OnVFJH00ol0003oLXebo`000002o`00
00ooKI9]00?o0000og:=L_l000005OmQWV400ol0003o@[e2o`000002o`0001OoPWf200?o0000okI9
]_nfBKH02onfBKH00ol0003ojQGZonXEjP0>onXEjP03o`000?of2OKomPWf00KomPWf00?o0000oo/4
nook1?/02Ook1?/3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003onPGjooX5nP09ooX5nP03o`000?oX5nSoj1OX00Go
j1OX0ol00004om@[e003o`000?nVFJKoYUVV00koYUVV0_l0000AoffBK@04o`000?mbSG;oLXebo`00
01KoHIiQ00?o0000oh9mP_n2OH806?n2OH800ol0003o]TVfokI9]P0;okI9]P03o`000?oZ5N[ojQGZ
00kojQGZ00?o0000ooH9m_of2OH01oof2OH00ol0003on`Ckoo/4n`04oo/4n`Co00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003onPGjooX5nP08ooX5nP03o`000?oX5nSoj1OX00;oj1OX0ol00008om@[e003
o`000?nVFJKoYUVV00coYUVV0ol0000?offBK@;o00000ombSG800ol0003oHIiQof6NH@0Dof6NH@03
o`000?n2OH;oPWf201WoPWf200?o0000okI9]_nfBKH02_nfBKH00ol0003ojQGZonXEjP0=onXEjP03
o`000?of2OKomPWf00WomPWf00?o0000oo/4nook1?/00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?oj1O[onPGj00OonPGj1_l0000<om@[e003o`000?nVFJKoYUVV00[oYUVV00Go0000oi]TVonKI9_o
VfBKo`00000=offBK@03o`000?mbSG;oLXeb00CoLXeb00?o0000of6NHOmQWV404omQWV400ol0003o
PWf2oh9mPP0Ioh9mPP03o`000?nfBKKo]TVf00Wo]TVf00?o0000onXEj_oZ5NX03_oZ5NX00ol0003o
mPWfooH9mP0:ooH9mP;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000GonPGj0_l00004ooP7n003o`00
0?oD:mCoe2_D00coe2_D0_l00008ojIIYP;o00001OnKI9/00ol0003oKI9]offBK@09offBK@03o`00
0?mbSG;oLXeb00GoLXeb00?o0000of6NHOmQWV404omQWV400ol0003oPWf2oh9mPP0Joh9mPPgo0000
3_oZ5NX00ol0003omPWfooH9mP0;ooH9mP03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?onPGjo`000?oh1oP01_oh1oP00ol0003oe2_Dom@[e00=om@[e003o`000?nV
FJKoYUVV00CoYUVV00?o0000oi]TVonKI9/01_nKI9/2o`0000SoKI9]00?o0000og:=L_mbSG801_mb
SG800ol0003oHIiQof6NH@0Dof6NH@03o`000?n2OH;oPWf201WoPWf200?o0000om4^dOoA;]402_oA
;]400ol0003ojQGZonXEjP0;onXEjP03o`000?of2OKomPWf00comPWf00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000om@[e?oD:m@03_oD:m@0
1?l0003oYUVVojIIY_nVFJH2o`0000_oVfBK00?o0000offBKOm]TVd00om]TVd2o`0000WoLXeb00?o
0000of6NHOmQWV405?mQWV400ol0003oPWf2oh9mPP0Hoh9mPP03o`000?oA;]7odBkA00codBkA00?o
0000onXEj_oZ5NX02OoZ5NX00ol0003omPWfooH9mP0=ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003oe2_Dom@[e00>om@[e003o`000?nVFJKo
000000koVfBK00Go0000offBKOm]TVgoKI9]o`00000;og:=LP03o`000?mQWV7oHIiQ01CoHIiQ0_l0
000Ioh9mPP03o`000?oA;]7odBkA00godBkA0_l00008onXEjP03o`000?of2OKomPWf00komPWf00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003oe2_Dom@[e00?
om@[e003o`000?nKI9_oVfBK00koVfBK00?o0000offBKOl000003?mbSG800ol0003oHIiQof6NH@0D
of6NH@03o`000?n4NhCo000000;o00005On2OH800ol0003odBkAom4^d@0@om4^d@03o`000?oZ5N[o
jQGZ00GojQGZ00?o0000ooH9m_of2OH03oof2OH00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003oe2_Dom@[e00>om@[e003o`000?nKI9_oVfBK00koVfBK0_l0000=og:=
LP03o`000?mQWV7oHIiQ01?oHIiQ00?o0000ohAkQ?n4Nh@00on4Nh@2o`0001;oPWf200?o0000om4^
dOoA;]404_oA;]401?l0003ojQGZonXEj_oZ5NX3o`0001;omPWf00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000om@[e?oD:m@03OoD:m@2o`0000ooVfBK00?o0000oi=/
Tol000003_mbSG800ol0003oHIiQof6NH@0Bof6NH@03o`000?n4NhCoQ7^400GoQ7^40ol0000?oh9m
PP03o`000?oA;]7odBkA01?odBkA0ol00002oo8=lP03o`000?of2OKomPWf013omPWf00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000om@[e?oD:m@02ooD:m@00ol0003o
dbcCo`00000>oi]TV`05o`000?nCK9?oTfbCoi=/Tol000003OmbSG800ol0003oHIiQof6NH@0Aof6N
H@03o`000?n4NhCoQ7^400WoQ7^40ol0000:oh9mPP;o00005_oA;]400ol0003olPgboo8=lP03oo8=
lP03o`000?of2OKomPWf013omPWf00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000om@[e?oD:m@02_oD:m@01Ol0003odbcCom</dooC;=?o000000coVfBK00?o0000oi=/
TonCK9<00_nCK9<00ol0003oLXebog:=LP0;og:=LP03o`000?mQWV7oHIiQ017oHIiQ00?o0000ohAk
Q?n4Nh@03?n4Nh@2o`0000KoPWf20_l000000onjAK[o0000om4^d@0Dom4^d@03o`000?ob3O;olPgb
00GolPgb00?o0000ooH9m_of2OH03oof2OH00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003oe2_Dom@[e007om@[e0;o00001OoC;=<00ol0003oVfBKoi]TV`08oi]TV`03
o`000?nCK9?oTfbC00CoTfbC00?o0000og:=L_mbSG802OmbSG84o`00013oHIiQ00?o0000ohAkQ?n4
Nh@03on4Nh@3o`000003oh9mP_l0003o000000Co^TFj00?o0000om4^dOoA;]404OoA;]400ol0003o
lPgboo8=lP07oo8=lP03o`000?of2OKomPWf00oomPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000om@[e?oD:m@01_oD:m@00ol0003odbcCom</d`05om</d`03o`00
0?nKI9_oVfBK00OoVfBK00?o0000oi=/TonCK9<01OnCK9<00ol0003oLXebog:=LP08og:=LP03o`00
0?m`Sg3oL8m`00;oL8m`0ol0000=of6NH@03o`000?n4NhCoQ7^401;oQ7^400?o0000okY5^_njAKX0
1OnjAKX00ol0003odBkAom4^d@0@om4^d@03o`000?ob3O;olPgb00OolPgb00?o0000ooH9m_of2OH0
3oof2OH00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003oe2_Dom@[
e004om@[e003o`000?oC;=?odbcC00OodbcC00?o0000oi]TVonKI9/01OnKI9/00ol0003oTfbCoi=/
T`07oi=/T`03o`000?mbSG;oLXeb00KoLXeb00?o0000og2?L?m`Sg001_m`Sg03o`0000SoHIiQ0_l0
000EohAkQ003o`000?njAK[o^TFj00Ko^TFj00?o0000om4^dOoA;]403_oA;]400ol0003olPgboo8=
lP09oo8=lP03o`000?of2OKomPWf00komPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000om@[e?oD:m@00_oD:m@2o`0000[odbcC00?o0000oi]TVonKI9/01?nKI9/0
0ol0003oTfbCoi=/T`09oi=/T`03o`000?mbSG;oLXeb00?oLXeb0_l0000<og2?L0?o00000_mQWV43
o`000003og:=L_l0003oQ7^401CoQ7^400?o0000okY5^_njAKX01onjAKX00ol0003odBkAom4^d@0<
om4^d@03o`000?ob3O;olPgb00_olPgb00?o0000ooH9m_of2OH03_of2OH00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003oe2_Dom@[e?l0000=om</d`03o`000?nKI9_o
VfBK00;oVfBK00?o0000oi=/TonCK9<02_nCK9<00ol0003oLXebog:=LP02og:=LP03o`000?m`Sg3o
L8m`00ooL8m`0_l00005og:=LP03o`000?n4NhCoQ7^401;oQ7^400?o0000okY5^_njAKX02?njAKX0
0ol0003odBkAom4^d@0:om4^d@03o`000?ob3O;olPgb00golPgb1Ol0000;ooH9mP03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?oD:mCo000000oodbcC00Co0000oi]T
VonKI9_o00003_nCK9<01?l0003oLXebog:=L_l0000Cog2?L003o`000?mbSG;oLXeb00CoLXeb00?o
0000ohAkQ?n4Nh@04?n4Nh@00ol0003o^TFjokY5^P09okY5^P03o`000?oA;]7odBkA00[odBkA00?o
0000oo8=l_ob3O803Oob3O800ol0003on`Ckoo/4n`02oo/4n`Wo00000_of2OH00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?oC;=?odbcC00kodbcC00?o0000oi]TVol000003onCK9<0
0ol0003oLXebo`00000Cog2?L003o`000?mbSG;oLXeb00GoLXeb00?o0000ohAkQ?n4Nh@04?n4Nh@0
0ol0003o^TFjokY5^P0:okY5^P03o`000?oA;]7odBkA00SodBkA00?o0000oo8=l_ob3O803Oob3O80
0ol0003on`Ckoo/4n`0<oo/4n`Co00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000om</
dooC;=<03ooC;=<00ol0003oTfbCoi=/T`0>oi=/T`;o00005?m`Sg000ol0003oLXebog:=LP06og:=
LP03o`000?n4NhCoQ7^400ooQ7^400?o0000okY5^_njAKX02onjAKX00ol0003odBkAom4^d@04om4^
d@?o00004?ob3O800ol0003on`Ckoo/4n`0?oo/4n`Co00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
dbcCom</d`0@om</d`03o`000?nCK9?oTfbC00_oTfbC0ol000000on6NHKo0000og2?L00Bog2?L003
o`000?mbSG;oLXeb00OoLXeb00?o0000ohAkQ?n4Nh@03on4Nh@00ol0003o^TFjokY5^P0<okY5^P03
o`000?oA;]7odBkA00?o00000oo/4n`00ol0003olPgboo8=lP0=oo8=lP03o`000?ok1?_on`Ck00oo
n`Ck00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000om</dooC;=<04?oC;=<3o`0000WoTfbC0_l00005ohIiQP03o`00
0?m`Sg3oL8m`013oL8m`00?o0000og:=L_mbSG802?mbSG800ol0003oQ7^4ohAkQ00>ohAkQ003o`00
0?njAK[o^TFj00go^TFj0_l00007on`Ck003o`000?ob3O;olPgb00_olPgb00?o0000oo/4nook1?/0
3ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?oC;=?odbcC00oodbcC00Co
0000olDjaOo5>/GoaC[50_l00005oi=/T`;o00002?n6NHH00ol0003oL8m`og2?L00>og2?L003o`00
0?mbSG;oLXeb00[oLXeb00?o0000ohAkQ?n4Nh@03?n4Nh@00ol0003o^TFjokY5^P0>okY5^P03o`00
0?o/4ncok1?/00Ook1?/00?o0000oo8=l_ob3O802_ob3O800ol0003on`Ckoo/4n`0?oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006olDja@03o`000?nCK9?o000000;o00002_n6
NHH00ol0003oL8m`og2?L00=og2?L003o`000?mbSG;oLXeb00_oLXeb00?o0000ohAkQ?n4Nh@03?n4
Nh@00ol0003o^TFjokY5^P0=okY5^P03o`000?o/4ncok1?/00Wok1?/00?o0000oo8=l_ob3O802?ob
3O800ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o_4>oo
ka3_00ooka3_00?o0000olDjaOo5>/D01Oo5>/D00ol0003oQWV6ohIiQP0<ohIiQP03o`000?m`Sg3o
L8m`00coL8m`00?o0000og:=L_mbSG803?mbSG82o`0000coQ7^400?o0000okY5^_njAKX03OnjAKX0
0ol0003ok1?/on`Ck00:on`Ck003o`000?ob3O;olPgb00OolPgb00?o0000oo/4nook1?/03ook1?/0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o_4>l04?o_4>l00ol0003oaC[5olDja@06olDja@03o`000?n6NHKo
QWV600coQWV600?o0000og2?L?m`Sg002om`Sg000ol0003oLXebog:=LP0=og:=LP04o`000?n;M8_o
0000o`0000[oQ7^400?o0000okY5^_njAKX03OnjAKX00ol0003ok1?/on`Ck00;on`Ck003o`000?ob
3O;olPgb00KolPgb00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003oka3_onl@k`0@
onl@k`03o`000?o5>/GoaC[500KoaC[500?o0000ohIiQ_n6NHH03On6NHH00ol0003oL8m`og2?L00:
og2?L003o`000?mbSG;oLXeb00coLXeb00?o0000oh]dRon;M8/00_n;M8/2o`0000SoQ7^400?o0000
okY5^_njAKX03?njAKX00ol0003ok1?/on`Ck00=on`Ck003o`000?ob3O;olPgb00ColPgb00?o0000
oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@onl@k`03o`000?o5>/GoaC[5
00OoaC[500?o0000ohIiQ_n6NHH03_n6NHH<o`0000ooLXeb00?o0000oh]dRon;M8/01?n;M8/2o`00
00KoQ7^400?o0000okY5^_njAKX03?njAKX00ol0003ok1?/on`Ck00>on`Ck003o`000?ob3O;olPgb
00?olPgb00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>onl@
k`03o`000?o5>/GoaC[500SoaC[500?o0000ohIiQ_n6NHH03On6NHH00ol0003oMhQgogN8M`08ogN8
M`03o`000?mbSG;oLXeb00coLXeb00?o0000oh]dRon;M8/01on;M8/2o`0000?oQ7^400?o0000okY5
^_njAKX03OnjAKX00ol0003ok1?/on`Ck00?on`Ck005o`000?ob3O;olPgboo8=l_l000004Ook1?/0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo_4>l00ol0003oaC[5olDja@08olDja@03o`000?n6NHKo
QWV600coQWV600?o0000ogN8MomgR7L02_mgR7L00ol0003oLXebog:=LP0;og:=LP03o`000?n;M8_o
RgB;00WoRgB;0_l000000on4NhCo0000okY5^P08okY5^PKo00004oo/4n`01?l0003olPgboo8=l_l0
000Aoo/4n`03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008onl@k`03o`000?o5>/Go
aC[500WoaC[500?o0000ohIiQ_n6NHH03?n6NHH00ol0003oMhQgogN8M`0:ogN8M`03o`000?mbSG;o
LXeb00[oLXeb00?o0000oh]dRon;M8/03?n;M8/;o`0000Gog2?L00?o0000on`Ck?o/4n`04_o/4n`0
0ol0003olPgbo`00000@oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on4N
hOoQ7^7ohAkQ1Ol00003onl@k`03o`000?o5>/GoaC[500WoaC[500?o0000ohIiQ_n6NHH02on6NHH0
0ol0003oMhQgogN8M`0<ogN8M`03o`000?mbSG;oLXeb00WoLXeb00?o0000oh]dRon;M8/03?n;M8/0
0ol0003o^4NhokQ7^002okQ7^003o`000?oL8mcog2?L00Wog2?L00?o0000on`Ck?o/4n`04_o/4n`3
o`0000oon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on4N
hOoQ7^401OoQ7^43o`0000coaC[500?o0000ohIiQ_n6NHH02on6NHH00ol0003oMhQgogN8M`0<ogN8
M`03o`000?mbSG;oLXeb00SoLXeb00?o0000oh]dRon;M8/03?n;M8/00ol0003o^4NhokQ7^004okQ7
^003o`000?oL8mcog2?L00Sog2?L00?o0000on`Ck?o/4n`04_o/4n`00ol0003oo@;mood2o@04o`00
00_on`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oQ7^7ohAkQ00OohAkQ00?o0000olDj
aOo5>/D02_o5>/D00ol0003oQWV6ohIiQP09ohIiQP;o00003omgR7L00ol0003oLXebog:=LP08og:=
LP03o`000?n;M8_oRgB;00coRgB;00?o0000okQ7^?nhAkP01?nhAkP00ol0003og2?Lom`Sg009om`S
g0Co00003oo/4n`00ol0003oo@;mood2o@05ood2o@Co00001_ok1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on4NhOoQ7^402?oQ7^400ol0003oaC[5olDja@09olDja@03o`000?n6NHKoQWV600Ko
QWV60ol000000onIIYWo0000ogN8M`0?ogN8M`03o`000?mbSG;oLXeb00KoLXeb00?o0000oh]dRon;
M8/03On;M8/00ol0003o^4NhokQ7^005okQ7^003o`000?oL8mcog2?L00Sog2?L00Co0000ooD:mOoe
2_Gom@[e1Ol00009on`Ck003o`000?om0_goo@;m00[oo@;m1?l00002oo/4n`03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003ohAkQon4Nh@07on4Nh@03o`000?o5>/GoaC[500[oaC[500?o0000ohIiQ_n6
NHH00_n6NHH3o`0000GoVFJI00?o0000ogN8MomgR7L03OmgR7L00ol0003oLXebog:=LP06og:=LP03
o`000?n;M8_oRgB;00coRgB;00?o0000okQ7^?nhAkP01_nhAkP00ol0003og2?Lom`Sg008om`Sg003
o`000?oe2_Gom@[e00Kom@[e1Ol00003on`Ck003o`000?om0_goo@;m00ooo@;m0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on4NhOoQ7^401ooQ7^400ol0003oaC[5olDja@0:olDja@03o`000?n6NHKo000000;o0000
2?nIIYT00ol0003oMhQgogN8M`0=ogN8M`Co00001?mbSG800ol0003oRgB;oh]dR`0=oh]dR`03o`00
0?nhAkSo^4Nh00Oo^4Nh00?o0000om`Sg?oL8m`01ooL8m`00ol0003om@[eooD:m@0;ooD:m@?o0000
4oom0_d00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on4NhOoQ7^402?oQ7^43o`0000WoaC[50_l0
000<oiUVV@03o`000?mgR7OoMhQg00_oMhQg00?o0000oiA[U?nDJi@00_nDJi@3o`000003og:=L_l0
003oRgB;00koRgB;00?o0000okQ7^?nhAkP01onhAkP00ol0003og2?Lom`Sg006om`Sg003o`000?oe
2_Gom@[e00kom@[e00?o0000ood2oOom0_d04_om0_d00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on4NhOoQ7^401_oQ7^401?l0003oi1_Ton@Ki?oT6n@3o`0000KoaC[500?o0000oiUVVOnIIYT03?nI
IYT00ol0003oMhQgogN8M`09ogN8M`03o`000?nDJiCoU6^D00KoU6^D00?o0000oh]dRon;M8/03On;
M8/00ol0003o^4NhokQ7^009okQ7^003o`000?oL8mcog2?L00Gog2?L00?o0000ooD:mOoe2_D03_oe
2_D00ol0003oo@;mood2o@0Bood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003ohAkQon4Nh@05
on4Nh@03o`000?oT6nCoi1_T00Goi1_T0ol00002olDja@03o`000?nIIYWoVFJI00goVFJI00?o0000
ogN8MomgR7L02?mgR7L00ol0003oU6^DoiA[U007oiA[U003o`000?n;M8_oRgB;00coRgB;0ol0000:
okQ7^003o`000?oL8mcog2?L00Gog2?L00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0B
ood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003ohAkQon4Nh@04on4Nh@03o`000?oT6nCoi1_T
00Woi1_T0_l0000AoiUVV@03o`000?mgR7OoMhQg00GoMhQg0_l0000;oiA[U003o`000?n;M8_oRgB;
00[oRgB;00Go0000okQ7^?nhAkSo^4Nho`00000:okQ7^003o`000?oL8mcog2?L00Cog2?L00?o0000
ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0Cood2o@03o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oQ7^7ohAkQ
00;ohAkQ00?o0000on@Ki?oT6n@02_oT6n@2o`00017oVFJI00?o0000ogN8MomgR7L01?mgR7L00ol0
003oU6^DoiA[U00<oiA[U003o`000?n;M8_oRgB;00OoRgB;0_l00005okQ7^0;o00002?nhAkP00ol0
003og2?Lom`Sg004om`Sg003o`000?oe2_Gom@[e00gom@[e00?o0000ood2oOom0_d05?om0_d00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003ohAkQon4NhOoQ7^7o000000coi1_T00Co0000om8]
d_oB;M;o00004OnIIYT00ol0003oMhQgogN8M`02ogN8M`03o`000?nDJiCoU6^D00koU6^D00?o0000
oh]dRon;M8/01On;M8/00ol0003o^4NhokQ7^007okQ7^003o`000?nhAkSo^4Nh00Ko^4Nh00?o0000
om`Sg?oL8m`00ooL8m`00ol0003om@[eooD:m@0=ooD:m@03o`000?om0_goo@;m01Coo@;m00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on4NhOoQ7^7o00003?oT6n@00ol0003odRgBom8]dP02om8]dP03o`000?nIIYWo
VFJI00ooVFJI00Co0000ogN8MomgR7Oo00004OnDJi@00ol0003oRgB;oh]dR`04oh]dR`03o`000?nh
AkSo^4Nh00Wo^4Nh00?o0000okQ7^?nhAkP01OnhAkP00ol0003og2?Lom`Sg003om`Sg003o`000?oe
2_Gom@[e00gom@[e00?o0000ood2oOom0_d05Oom0_d00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
on@Ki003o`000?oB;M;odRgB00?odRgB00?o0000oiUVVOnIIYT03onIIYT00ol0003oMhQgo`00000C
oiA[U004o`000?n;M8_oRgB;oh]dR`;o00003OnhAkP2o`0000Ko^4Nh00Go0000om`Sg?oL8mcog2?L
o`00000@ooD:m@03o`000?om0_goo@;m01Coo@;m0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000on@Ki?oT6n@02_oT
6n@00ol0003odRgBom8]dP05om8]dP03o`000?nIIYWoVFJI00ooVFJI00?o0000oiA[U?nDJi@04onD
Ji@00ol0003oRgB;o`00000AokQ7^003o`000?nhAkSo^4Nh00?o^4Nh00Go0000om`Sg?oL8mcog2?L
o`00000>ooD:m@?o00005?om0_d2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000on@Ki?oT6n@02OoT
6n@00ol0003odRgBom8]dP07om8]dP03o`000?nIIYWoVFJI00koVFJI00?o0000oiA[U?nDJi@05?nD
Ji@00ol0003o^4NhokQ7^00AokQ7^0;o00001?nhAkP01?l0003og2?Lom`Sg?l0000:ooD:m@Co0000
0oom0_d00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000on@Ki?oT6n@02OoT6n@00ol0003odRgBom8]dP08om8]dP03o`000?nIIYWoVFJI00_oVFJI0ol0
000GoiA[U003o`000?nhAkSo^4Nh01?o^4Nh00Ko0000okQ7^?nhAkSo^4Nho`000?oL8m`5o`0000Co
m@[e0ol00008ood2o@03o`000?om0_goo@;m00goo@;m0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oT6nCoi1_T00Soi1_T00?o0000om8]d_oB;M802_oB;M800ol0003oVFJIoiUVV@07oiUVV@?o0000
0_nRGJ800ol0003oU6^DoiA[U00EoiA[U0;o00005OnhAkP00ol0003o^4NhokQ7^002o`0000Goka3_
1?l0000<ood2o@03o`000?om0_goo@;m00[oo@;m0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000on@Ki?oT6n@01ooT
6n@00ol0003odRgBom8]dP0;om8]dP03o`000?nIIYWoVFJI00CoVFJI0ol00006oj9MXP03o`000?nD
JiCoU6^D01?oU6^D00Co0000ol4n`Oo1?/7o00005OnhAkP2o`0000Woka3_00?o0000ood2oOom0_d0
3?om0_d00ol0003oo@;mood2o@07ood2o@;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000Woi1_T00?o0000om8]d_oB;M803OoB;M800ol0003oVFJIoiUV
V@03o`0000[oXUfR00?o0000oiA[U?nDJi@04OnDJi@00ol0003o`Ck1ol4n`@02ol4n`@03o`000?nh
AkSo^4Nh01;o^4Nh00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om
0_goo@;m00Coo@;m0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oi1_Ton@Ki005on@Ki003o`000?oB;M;odRgB00oodRgB0_l0000>
oj9MXP03o`000?nDJiCoU6^D00ooU6^D00?o0000ol4n`Oo1?/401?o1?/400ol0003o^4NhokQ7^00@
okQ7^0;o00002oo_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000on@Ki?oT6n@00ooT6n@00ol0003odRgBom8]dP0@om8]dP03o`000?nRGJ;oXUfR
00goXUfR00?o0000oiA[U?nDJi@03_nDJi@00ol0003o`Ck1ol4n`@06ol4n`@;o00003_nhAkP2o`00
0003om</dol0003oka3_00[oka3_00?o0000ood2oOom0_d03_om0_d01?l0003oo@;mo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oi1_Ton@Ki?oT6nCo000001;odRgB00?o0000oj9MX_nRGJ803onRGJ800ol0003oU6^DoiA[U00<
oiA[U003o`000?o1?/7o`Ck100Wo`Ck100?o0000okQ7^?nhAkP02OnhAkP2o`0000?odbcC00?o0000
onl@koo_4>l02Oo_4>l00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oi1_To`00000Com8]
dP03o`000?nRGJ;oXUfR013oXUfR00?o0000oiA[U?nDJi@02_nDJi@00ol0003o`Ck1ol4n`@0;ol4n
`@03o`000?nhAkSo^4Nh00Go^4Nh0ol00006om</d`03o`000?o_4>ooka3_00Soka3_00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000om8]d_oB;M804OoB;M800ol0003oXUfRoj9MXP0Aoj9MXP03o`000?nDJiCoU6^D00Wo
U6^D00?o0000ol4n`Oo1?/403Oo1?/400ol0003o^4NhokQ7^002okQ7^0;o00002OoC;=<00ol0003o
ka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017odRgB00?o0000oj9MX_nRGJ80
4_nRGJ800ol0003oU6^DoiA[U007oiA[U003o`000?o1?/7o`Ck100oo`Ck100Co0000okQ7^?l0003o
00002ooC;=<00ol0003oka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ojAKY
o`000002o`0000kodRgB00?o0000oj9MX_nRGJ804onRGJ800ol0003oU6^DoiA[U005oiA[U003o`00
0?o1?/7o`Ck1017o`Ck100?o0000om</dooC;=<03?oC;=<00ol0003oka3_onl@k`08onl@k`03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?oY5^WojAKY00?ojAKY0_l0000;om8]dP;o00005_nRGJ87o`0001Co`Ck100?o
0000om</dooC;=<03?oC;=<00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ojAKYonTF
j@06onTFj@?o00002?oB;M800ol0003o`Ck1o`000002o`0001;oXUfR00?o0000ojiA[_n^DJh00_n^
DJh00ol0003oYEZUo`00000Dol4n`@03o`000?oC;=?odbcC00codbcC00?o0000onl@koo_4>l02?o_
4>l00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ojAKYonTFj@09onTFj@;o00001OoB;M800ol0003o`Ck1ol4n`@03
ol4n`@;o00003onRGJ800ol0003o[U6^ojiA[P03ojiA[P04o`000?nUFZGoYEZUo`0001?o`Ck100?o
0000om</dooC;=<03OoC;=<00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_oY5^T3o`000003om8]d_l0003o
`Ck100Oo`Ck10ol0000;oj9MXP03o`000?n^DJko[U6^00Co[U6^00Go0000ojEJYOnUFZGoYEZUo`00
000Bol4n`@03o`000?oC;=?odbcC00godbcC00?o0000onl@koo_4>l01oo_4>l?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04?oh1oP0
0ol0003ojAKYonTFj@0?onTFj@03o`000?o1?/7o`Ck100[o`Ck10_l00008oj9MXP03o`000?n^DJko
[U6^00Go[U6^00?o0000ojEJYOnUFZD00_nUFZD00ol0003o`Ck1ol4n`@0?ol4n`@03o`000?oC;=?o
dbcC00godbcC00?o0000onl@koo_4>l01_o_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oh1oSon0Oh00oon0Oh00?o0000onTFjOoY5^T03ooY5^T00ol0003o`Ck1ol4n`@0<ol4n
`@;o00001OnRGJ800ol0003o[U6^ojiA[P06ojiA[P03o`000?nUFZGoYEZU00?oYEZU00?o0000ol4n
`Oo1?/403_o1?/400ol0003odbcCom</d`0>om</d`03o`000?o_4>ooka3_00Coka3_00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00kon0Oh00?o0000onTFjOoY5^T04?oY5^T00ol0003o
`Ck1ol4n`@0>ol4n`@?o000000?oXUfRo`000?n^DJh02?n^DJh00ol0003oYEZUojEJY@04ojEJY@03
o`000?o1?/7o`Ck100go`Ck14_l00005onl@k`03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooP7n003o`000?oY5^WojAKY00oojAKY0_l0000Col4n`@03o`000?n^DJko[U6^00So[U6^
00?o0000ojEJYOnUFZD01OnUFZD00ol0003o`Ck1ol4n`@0<ol4n`@03o`000?oa3_7ol@ka00ool@ka
00Go0000onl@koo_4>ooka3_o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n0Oh00?o0000onTFjOoY5^T03_oY5^T00ol0003ogb3Oo`00000Col4n`@03o`000?n^DJko[U6^00So
[U6^00?o0000ojEJYOnUFZD01OnUFZD00ol0003o`Ck1ol4n`@0;ol4n`@03o`000?oa3_7ol@ka017o
l@ka00?o0000onl@kol000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n0OhooP7n00:ooP7n003o`000?oY5^WojAKY00gojAKY0_l00003omlPg`03o`000?o1?/7o`Ck1013o
`Ck100?o0000ojiA[_n^DJh02?n^DJh00ol0003oYEZUojEJY@06ojEJY@03o`000?o1?/7o`Ck100[o
`Ck100?o0000oo4>lOoa3_404_oa3_400ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on0OhooP7n009ooP7n003o`000?oY5^WojAKY00cojAKY00?o0000omlPgooO8=l0
0ooO8=l00ol0003o`Ck1ol4n`@0?ol4n`@03o`000?n^DJko[U6^00Wo[U6^00?o0000ojEJYOnUFZD0
1onUFZD00ol0003o`Ck1ol4n`@09ol4n`@03o`000?oa3_7ol@ka01;ol@ka00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003ojAKYonTF
j@0:onTFj@;o00001_oO8=l00ol0003o`Ck1ol4n`@0?ol4n`@03o`000?n^DJko[U6^00Wo[U6^00?o
0000ojEJYOnUFZD02?nUFZD00ol0003o`Ck1ol4n`@07ol4n`@03o`000?oa3_7ol@ka01?ol@ka00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ojAKYonTFj@09onTFj@03o`000?oO8=oogb3O00Oogb3O00?o0000ol4n`Oo1?/403Oo1?/42
o`0000_o[U6^00?o0000ojEJYOnUFZD02OnUFZD00ol0003o`Ck1ol4n`@06ol4n`@03o`000?oa3_7o
l@ka01?ol@ka4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on0OhooP7n006ooP7n003o`000?oY5^WojAKY00WojAKY00?o0000omlP
gooO8=l02?oO8=l00ol0003o`Ck1ol4n`@0;ol4n`@;o000000?o`Ck1o`000?n^DJh02_n^DJh00ol0
003oYEZUojEJY@09ojEJY@Ko00000oo1?/400ol0003ol@kaoo4>l@0Coo4>l@03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooP7n?oh1oP01?oh1oP3o`00
00SojAKY0_l0000;omlPg`03o`000?o1?/7o`Ck100Wo`Ck10_l00004ol4n`@03o`000?n^DJko[U6^
00So[U6^00?o0000ojEJYOnUFZD02?nUFZD00ol0003oebSGomLXe`04omLXe`?o00005?oa3_43o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on0OhooP7n003o`0000?o
m`Sg00?o0000onTFjOoY5^T01?oY5^T00ol0003ogb3OomlPg`0<omlPg`03o`000?o1?/7o`Ck100Go
`Ck10ol00007ol4n`@03o`000?n^DJko[U6^00Oo[U6^00?o0000ojEJYOnUFZD01onUFZD00ol0003o
ebSGomLXe`08omLXe`03o`000?oa3_7ol@ka013ol@ka00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ojAKYonTFjOoY5^T2o`0000oogb3O00?o0000ol4n
`Oo1?/400oo1?/42o`0000[o`Ck100?o0000ojiA[_n^DJh01on^DJh00ol0003oYEZUojEJY@05ojEJ
Y@;o00003?oG:=L00ol0003ol@kaoo4>l@0=oo4>l@;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?oY5^Wo0000017o
gb3O00Co0000ol4n`Oo1?/7o`Ck10_l0000=ol4n`@03o`000?n^DJko[U6^00Ko[U6^00?o0000ojEJ
YOnUFZD01?nUFZD00ol0003oebSGomLXe`0=omLXe`Co00002_oa3_400ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000omlPgooO8=l04OoO8=l3o`00013o`Ck100?o0000ojiA[_n^DJh01On^DJh00ol0003o
YEZUojEJY@03ojEJY@03o`000?oG:=OoebSG00koebSG00Co0000ooH9m_of2OKomPWf1_l00003oo4>
l@03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003ogb3OomlPg`0AomlPg`03o`000?o1?/7o`Ck1013o
`Ck100?o0000ojiA[_n^DJh01On^DJh00ol0003oYEZUojEJY@02ojEJY@03o`000?oG:=OoebSG00oo
ebSG00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oO8=oogb3O013ogb3O00?o0000ol4n`Oo1?/40
4Oo1?/400ol0003o[U6^ojiA[P04ojiA[P03o`000?nUFZGoYEZU00;o00004OoG:=L00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003ogb3OomlPg`0=omlPg`;o00005?o1?/43o`0000Co[U6^00?o0000ojEJYOl000004ooG
:=L00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ood2oOom0_d02Oom
0_d00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
omlPgooO8=l02_oO8=l3o`000003on0Oh?l0003o`Ck1017o`Ck10_l00003oll`c`;o00000_n^DJh2
o`0001CoebSG00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?om0_go
o@;m00[oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oO8=oogb3O00Kogb3O0ol00005on0O
h003o`000?o1?/7o`Ck100go`Ck10_l00007oll`c`?o00005OoG:=L00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ood2oOom0_d03?om0_d3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000omlPgooO8=l01?oO8=l2o`0000Woh1oP00?o0000ol4n`Oo1?/402_o1?/42o`0000_o
cc3?00?o0000omLXeooG:=L04_oG:=L00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000omlPgooO8=l00ol0000<on0Oh003o`00
0?o1?/7o`Ck100Oo`Ck10_l0000=oll`c`03o`000?oG:=OoebSG01;oebSG00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooh1oP00?o0000ol4n`Oo1?/401Oo1?/42o`0000oocc3?00?o
0000omLXeooG:=L04_oG:=L00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oh1oP00?o0000ol4n`Oo1?/400_o1?/42o`0001;occ3?00?o0000omLXeooG:=L04OoG:=L0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003ol@kaoo4>lOl0000@on0Oh004o`000?o1?/7o
0000o`0001Cocc3?00?o0000omLXeooG:=L04?oG:=L00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo4>lOoa3_400_oa3_400ol0003oh1oPon0Oh00>on0Oh003o`000?o?<<oocc3?01Cocc3?00?o0000
omLXeooG:=L03OoG:=L4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;mood2o@09
ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003ol@kaoo4>l@03oo4>l@03o`000?oP7n3oh1oP
00goh1oP00?o0000oll`coo?<<l05?o?<<l00ol0003oebSGomLXe`07omLXe`Ko00000oo[5>/00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ood2oOom0_d02?om0_d00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo4>lOoa3_401Ooa3_400ol0003oh1oPon0Oh00<on0Oh003
o`000?o?<<oocc3?01Gocc3?00?o0000omLXeooG:=L01_l0000:on/Dj`03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003ol@kaoo4>l@06oo4>l@03o`000?oP7n3oh1oP00_oh1oP00?o0000oll`coo?<<l0
5Oo?<<l3o`00017ojaC[00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo4>lOoa3_402?oa3_400ol0003oh1oPon0O
h00:on0Oh003o`000?o?<<oocc3?01Gocc3?00?o0000on/Djoo[5>/04Oo[5>/00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ood2oOom0_d01oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ok1?_o
n`Ck00Kon`Ck1ol0000<oo4>l@03o`000?oP7n3oh1oP00Woh1oP00?o0000oll`coo?<<l05?o?<<l0
0ol0003ojaC[on/Dj`0Con/Dj`03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ood2o@03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003on`Ckoo/4n`0=oo/4n`03o`000?oa3_7ol@ka00_ol@ka00?o0000on0Oh?oP7n002OoP7n00
0ol0003occ3?oll`c`0Coll`c`03o`000?o[5>_ojaC[01CojaC[1?l0000:ooH9mPCo00001_on0Oh2
o`0000Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003on`Ckoo/4n`0=oo/4n`?o00003?oa3_400ol0003oh1oPon0Oh008on0O
h003o`000?o?<<oocc3?00oocc3?1?l0000Gon/Dj`04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?oo@;mo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003on`Ckoo/4n`0>oo/4n`03o`000?of2OKomPWf
00?o00002_oa3_400ol0003oh1oPon0Oh007on0Oh003o`000?o?<<oocc3?00Socc3?1ol00003onTF
j@03o`000?o[5>_ojaC[01CojaC[00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
n`Ckoo/4n`0>oo/4n`03o`000?of2OKomPWf00?omPWf0ol00008oo4>l@03o`000?oP7n3oh1oP00Ko
h1oP00Co0000oll`coo?<<oocc3?1ol0000:onTFj@03o`000?o[5>_ojaC[01CojaC[00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ok1?_on`Ck00ko
n`Ck00?o0000ooH9m_of2OH01_of2OH3o`0000Kol@ka00?o0000on0Oh?oP7n001?oP7n05o`0001;o
jAKY00?o0000on/Djoo[5>/04_o[5>/00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo/4nook1?/03ook1?/00ol0003omPWfooH9mP09ooH9mP?o00001?oa3_400ol0003oh1oP
on0Oh003o`000003ooL8mol0003ojAKY01CojAKY00?o0000on/Djoo[5>/04_o[5>/00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ok1?/04?ok1?/00ol0003omPWfooH9
mP0<ooH9mP?o000000Col@kao`000?l0003o00001?og2?L00ol0003ojAKYonTFj@0BonTFj@;o0000
4oo[5>/00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003on`Ckoo/4
n`0@oo/4n`03o`000?of2OKomPWf00oomPWf00?o0000ooL8moog2?L01_og2?L00ol0003ojAKYonTF
j@0@onTFj@04o`000?o]4^gokA;]o`0001;ojaC[00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?of2OKomPWf00oomPWf00?o0000ooL8moog2?L01_og
2?L00ol0003ojAKYonTFj@0?onTFj@03o`000?o]4^gokA;]00;okA;]00?o0000on/Djoo[5>/03_o[
5>/00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ok1?_o
n`Ck013on`Ck00?o0000ooH9m_of2OH03_of2OH00ol0003om`SgooL8m`07ooL8m`03o`000?oY5^Wo
jAKY00kojAKY00?o0000ondBkOo]4^d01?o]4^d2o`0000kojaC[00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003on`Ckoo/4n`0@oo/4n`03o`000?of2OKomPWf
00gomPWf00?o0000ooL8moog2?L02?og2?L00ol0003ojAKYonTFj@0=onTFj@03o`000?o]4^gokA;]
00GokA;]00?o0000ooP7n?l000000_l0000:on/Dj`03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ok1?_on`Ck013on`Ck00?o0000ooH9m_of2OH03?of2OH00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oY5^WojAKY00_ojAKY00?o0000ondBkOo]4^d01_o]4^d00ol0003o
n0OhooP7n002ooP7n0?o00001oo[5>/00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013on`Ck1?l0000:ooH9mP03o`000?og2?Oom`Sg00_om`Sg00?o0000onTFjOoY5^T0
2_oY5^T00ol0003okA;]ondBk@06ondBk@03o`000?oh1oSon0Oh00Kon0Oh0_l00004on/Dj`03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_goo@;m00?o00003Ook
1?/01?l0003oo0?loo`3o?ol0o`6o`0000?omPWf00?o0000ooL8moog2?L03?og2?L00ol0003ojAKY
onTFj@09onTFj@03o`000?o]4^gokA;]00OokA;]00?o0000ooP7n?oh1oP02?oh1oP3o`000003on/D
jol0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Coo@;m0ol0
0009oo/4n`03o`000?ol0ocoo0?l00Soo0?l0ol0000?ooL8m`03o`000?oY5^WojAKY00SojAKY00?o
0000ondBkOo]4^d02?o]4^d00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Gon`Ck00?o0000oo`3o?ol0o`02ool0o`0
0ol0003om`SgooL8m`0=ooL8m`03o`000?oY5^WojAKY00OojAKY00?o0000ondBkOo]4^d02?o]4^d0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?om0_goo@;m00coo@;m0ol00002oo/4n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ooL8
moog2?L03_og2?L00ol0003ojAKYonTFj@05onTFj@03o`000?o]4^gokA;]00WokA;]00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o@;mood2o@0?ood2o@;o00003ool0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oY5^WojAKY00Co
jAKY00?o0000ondBkOo]4^d02_o]4^d00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0Aood2o@03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L03Oog2?L00ol0003ojAKYonTFj@03onTFj@03o`00
0?o]4^gokA;]00[okA;]00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L03Oog2?L00ol0003ojAKYonTF
j@02onTFj@03o`000?o]4^gokA;]00_okA;]00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aood2o@03o`000?ol
0ocoo0?l00koo0?l00?o0000ooL8moog2?L03Oog2?L01?l0003ojAKYonTFjOl0000>ondBk@03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000ooo@;m00?o
0000oo`3o?ol0o`03_ol0o`00ol0003om`SgooL8m`0=ooL8m`Go00003?o]4^d00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oom0_d0
0ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00gom`Sg00?o0000ooP7n?oh1oP00_oh1oP3
o`0000WokA;]00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?og2?Oom`Sg00_om`Sg00?o0000ooP7
n?oh1oP01_oh1oP4o`0000GokA;]00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooL8moog2?L02_og2?L00ol0003on0OhooP7n00;ooP7n0?o000000?okA;]o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oom0_d3o`00013oo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ood2o@04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003om`SgooL8m`06ooL8m`;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo@;mo`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooL8moog2?L0
1?og2?L2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooL8moog2?L00oog2?L00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003om`SgooL8m`02o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00[o
003o2Oooo`04o`00o`coool000Oo8B7Mo`00ool00?oo003ooc8bc?nYZEGok^h@00?oool000CogMdQ
ojVYEOmVIYSo413^2ol00?l2oooo09Wo003o0Oooool009go003o00?oV9QVoooo0?mgMhL01ol00?l0
0onHV6Koool0ogMgQ`0<o`00o`;oool02ol00?l00olQ8MgoV9QVoooo0002oooo0003oeEEZOl00?oo
003o00Co003o00?o<S;<oooo0?ooo`002Oooo`001?nHV6Ko003oo`00ool00?l4oooo0007okZjA?lQ
8Mgo003ooc8bc?nYZEGoool0ogMgQ`0:o`00o`;oool0VOl00?l1ooooo`00WOl00?l00oo^kQ3oool0
omgM8@07o`00o`03onk^4?ooo`3ogMdQ00co003o0_ooo`0=o`00o`?oool02?l00?l00om4A;[oool0
oooo0009oooo0007oa0@k_l00?oo003ookZjA?ooo`3oc<`bodA4^P05o`00o`03ofIVV?ooo`3oZJUE
00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00o`05oc8bc?ooo`3oool0oooo0?l@4>h01Ol00?l01Olb
</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`0=o`00o`?oool02Ol00?l00omVIYSok^h@oa0@kP06
o`00o`03odA4^_o^kQ3oQhMg00co003o00?oZJUEoooo0?nYZED02?l00?l2oooo09Wo003o0Oooool0
09co003o00GoZJUEoooo0?ooo`3oool0ofIVV005o`00o`05oiRHI_ooo`3oool0oooo0?mgMhL02ol0
0?l2oooo00go003o0oooo`0:o`00o`03oiRHI_oMgB7o413^00Ko003o00?oA4BjojVYEOl00?l02ol0
0?l01?lb</coool0oooo0?m4A;X7o`00o`;oool0VOl00?l1ooooo`00W?l00?l3oooo0003ofIVV?nj
^TCo003o00Co003o00Gok^h@oooo0?ooo`3oIVJHomgM8@0;o`00o`;oool03Ol00?l3oooo00_o003o
00?oZJUEomgM8Ol@4>h05?l00?l2oooo0003okZjA?l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo
002Ko`00o`07oeEEZOooo`3oool0onk^4?l00?ook^h@oa0@kP03o`00o`07oeEEZOooo`3oool0onk^
4?l00?ook^h@ob4Qg@0:o`00o`;oool03Ol00?l3oooo00_o003o00?o413^omgM8OnYZED05?l00?l3
oooo00Oo003o0_ooo`2Io`00o`7ooooo002Ko`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QVofIV
V003o`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QVogMgQ`0:o`00o`;oool03Ol00?l3oooo00co
003o00?o413^oooo0?nYZED04_l00?l01?mEEJWoool0oooo0?ooo`07o`00o`;oool0VOl00?l1oooo
o`00Vol00?l3oooo0004ob4QgOl00?ooA4BjokZjA0?o003o0oooo`001?lb</co003oodA4^_oMgB4:
o`00o`;oool03Ol00?l3oooo00go003o00?o<S;<oooo0?mgMhL04Ol00?l01?nj^TCoool0oooo0?oo
o`07o`00o`;oool0VOl00?l1ooooo`00V_l00?l01?mEEJWoool0oooo0?oMgB43o`00o`04oooo0?l0
0?oo003ooeEEZ@;oool000Kok^h@o`00ool00?oo003ooooo0?lQ8Md9o`00o`;oool03Ol00?l3oooo
00ko003o00?oQhMgoooo0?mEEJT03ol00?l01OnYZEGoool0oooo0?ooo`3oZJUE00Oo003o0_ooo`2I
o`00o`7ooooo002Jo`00o`04ojVYEOooo`3oool0ogMgQ`?o003o00CoZJUEoeEEZOl00?ooZJUE0_oo
o`001_nHV6Ko003oo`00ool00?ooZJUEogMgQ`Wo003o0_ooo`0=o`00o`?oool03ol00?l00oo^kQ3o
ool0ob4Qg@0<o`00o`03oc8bc?o<c3;oool000?oool000?o8B7Mo`00ool00?l01Ol00?l2oooo09Wo
003o0Oooool009[o003o0oooo`001olQ8Mgo003oo`00ool00?ooEEFYojVYEOl00?l00oooo`001_lb
</co003oo`00ool00?ooEEFYomgM8@Wo003o0_ooo`0=o`00o`?oool03ol00?l00omgMhOoool0olc<
<P09o`00o`03odA4^_mgMhOogMdQ00Goool000?oIVJHo`00ool00?l01_l00?l2oooo09Wo003o0Ooo
ool009Wo003o00CoEEFYoooo0?ooo`3ogMdQ1Ol00?l01Oo^kQ3oEEFYoooo0?ooo`3ok^h@00Go003o
00?oool0ob4QgOl00?l01ol00?l2oooo00go003o0oooo`0?o`00o`04ob4QgOooo`3oool0oeEEZ@Go
003o00?o<S;<oooo0?ooo`001oooo`000omVIYSo003oo`00o`07o`00o`;oool0VOl00?l1ooooo`00
VOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3oool0oooo0?n7QgL01Ol00?l00onY
ZEGoMgN7o`00o`07o`00o`;oool03Ol00?l3oooo013o003o0_ooo`000onj^TCo003oo`00o`03o`00
o`03ob4QgOooo`3oool000Goool000?oZJUEob4QgOl00?l02Ol00?l2oooo09Wo003o0Oooool009So
003o00Go413^oooo0?ooo`3oool0ob4Qg@05o`00o`05ofIVV?ooo`3oool0oooo0?lQ8Md01Ol00?l0
0omEEJWogMdQo`00o`07o`00o`;oool03Ol00?l3oooo00Oo003o00?o^[Y4ob4QgOl00?l01_l00?l3
oooo00Ko003o00OoZJUEoooo0?o^kQ3oc<`bohN7MomEEJWo413^00co003o0_ooo`2Io`00o`7ooooo
002Ho`00o`04ofIVV?ooo`3oool0omgM8@Ko003o00CoIVJHoooo0?ooo`3ogMdQ1ol00?l00oooo`3o
8B7Mo`00o`06o`00o`;oool03Ol00?l3oooo00Oo003o00?o^[Y4oiRHI_l00?l01Ol00?l01?mEEJWo
ool0oooo0?ooo`06o`00o`03ob4QgOo^kQ3o003o013o003o0_ooo`2Io`00o`7ooooo002Ho`00o`04
olc<<_ooo`3oool0ogMgQ`Ko003o00Co^[Y4oooo0?ooo`3oMgN71ol00?l00onYZEGoMgN7o`00o`06
o`00o`;oool03Ol00?l3oooo00Oo003o00?oIVJHoooo0?lb</`01Ol00?l01?o<c3;oool0oooo0?oo
o`07o`00o`03olc<<_mEEJWo003o00oo003o0_ooo`2Io`00o`7ooooo002Go`00o`05ob4QgOooo`3o
ool0oooo0?lQ8Md01Ol00?l01Ol@4>koool0oooo0?ooo`3o8B7M00Oo003o00?oEEFYomgM8Ol00?l0
1_l00?l2oooo00[o003o00?oc<`bofIVV?mgMhL00oooo`07o`00o`08oa0@k_ooo`3oool0ofIVV?l@
4>ko003ooc8bc?o<c383oooo0003okZjA?l00?oo003o00Go003o00?oA4Bjolc<<_l00?l03ol00?l2
oooo09Wo003o0Oooool009Oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oM
gB49o`00o`03oooo0?lQ8Mgo003o00Go003o0_ooo`0:o`00o`03odA4^_o<c3;oool000?oool02?l0
0?l00omVIYSoool0oooo0007oooo0003oc8bc?l00?oo003o00Ko003o00?oc<`boooo0?ooo`001Ooo
o`000oo<c3;o003oo`00o`06o`00o`;oool0VOl00?l1ooooo`00UOl00?l00olQ8MgoQhMgoooo0002
oooo0003onk^4?lb</co003o00?o003o00KoEEFYoooo0?ooo`3oool0onk^4?lb</`6o`00o`06ob4Q
gOn7QgOoool0onk^4?mEEJWo413^1?l00?l2oooo00co003o00CoA4Bjonk^4?ooo`3oool02Ol00?l0
0on7QgOoool0oooo0005oooo0003ofIVV?l00?oo003o00Oo003o00?oIVJHoooo0?ooo`001_ooo`00
0olQ8Mgo003oo`00o`05o`00o`;oool0VOl00?l1ooooo`00U?l00?l00om4A;[oool0oooo0007oooo
0003ohN7Moooo`3oool000Ooool00_l00?l00on7QgOoool0oooo0005oooo0004odA4^_l00?oo003o
o`00o`;oool000?oMgN7o`00ool00?l02ol00?l00omVIYSok^h@o`00o`09o`00o`03odA4^_nj^TCo
ool000;oool000?oZJUEoc8bc?l00?l02_l00?l00oo^kQ3oool0oooo0005oooo0003ogMgQol00?oo
003o00Co003o00?oMgN7oooo0?ooo`00VOl00?l1ooooo`00]_l00?l7oooo02ko003o00CoMgN7omgM
8Ol00?oo003o1oooo`2Io`00o`7ooooo003/o`00o`03ob4QgOl00?oo003o0:3o003o0Oooool00?oo
003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(150) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.984 .016 .984 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.961 .039 .961 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.967 .033 .967 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.979 .021 .979 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.891 .109 .891 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.905 .095 .905 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.992 .008 .992 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.972 .028 .972 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.909 .091 .909 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.891 .109 .891 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.821 .179 .821 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.967 .033 .967 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.985 .015 .985 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.966 .034 .966 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.89 .11 .89 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.993 .007 .993 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.918 .082 .918 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.829 .171 .829 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.938 .062 .938 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.548 .452 .548 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.542 .458 .542 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.598 .402 .598 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.901 .099 .901 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.919 .081 .919 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.513 .487 .513 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.522 .478 .522 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.79 .21 .79 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.884 .116 .884 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.964 .036 .964 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.982 .018 .982 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.841 .159 .841 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.946 .054 .946 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.531 .469 .531 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.952 .048 .952 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.888 .112 .888 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.142 .858 .142 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.549 .451 .549 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.171 .829 .171 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.222 .778 .222 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.968 .032 .968 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.446 .554 .446 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.222 .778 .222 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.536 .464 .536 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.915 .085 .915 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.635 .365 .635 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.787 .213 .787 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.117 .883 .117 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.087 .913 .087 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.308 .692 .308 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.092 .908 .092 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.68 .32 .68 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.786 .214 .786 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.832 .168 .832 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.73 .27 .73 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.075 .925 .075 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.071 .929 .071 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.082 .918 .082 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.353 .647 .353 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.468 .532 .468 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.916 .084 .916 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.97 .03 .97 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.987 .013 .987 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.297 .703 .297 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.158 .842 .158 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.929 .071 .929 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.095 .905 .095 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.723 .277 .723 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.075 .925 .075 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.604 .396 .604 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.959 .041 .959 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.693 .307 .693 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.354 .646 .354 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.971 .029 .971 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.978 .022 .978 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.123 .877 .123 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.055 .945 .055 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.052 .948 .052 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.857 .143 .857 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.632 .368 .632 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.065 .935 .065 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.507 .493 .507 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.782 .218 .782 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.926 .074 .926 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.063 .937 .063 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.064 .936 .064 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.325 .675 .325 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.114 .886 .114 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.737 .263 .737 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.277 .723 .277 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.135 .865 .135 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.17 .83 .17 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.975 .025 .975 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.982 .018 .982 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.962 .038 .962 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.085 .915 .085 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.686 .314 .686 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.842 .158 .842 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.946 .054 .946 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.584 .416 .584 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.853 .147 .853 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.165 .835 .165 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.979 .021 .979 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.936 .064 .936 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.294 .706 .294 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.662 .338 .662 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.484 .516 .484 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.96 .04 .96 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.901 .099 .901 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.914 .086 .914 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.71 .29 .71 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.992 .008 .992 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.992 .008 .992 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.88 .12 .88 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.896 .104 .896 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.84 .16 .84 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.984 .016 .984 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.944 .056 .944 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.989 .011 .989 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.921 .079 .921 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.993 .007 .993 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.981 .019 .981 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.962 .038 .962 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.981 .019 .981 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.975 .025 .975 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.981 .019 .981 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.988 .012 .988 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.985 .015 .985 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooe2_D00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooD:m@;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooD:m@03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooe
2_D2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;om@[e00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooD:m@03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oe2_D2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ook1?/0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oe2_D00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ooh1o_on0OkooP7n1?l0000=oo/4n`03o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kol`cco`000?oZ5N[o0000okY5^_l0000JooD:m@;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?on0Oko000001;on`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?ol`cc00Co0000onXEj_oZ5N[o00000_njAKX00ol0003om@[eooD:m@0IooD:
m@03o`000?on0Oko000001_on`Ck00?o0000oo/4nook1?/04_ok1?/00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005oo<<l`05o`000?oZ5N[ojQGZonXE
j_l000000onjAKX00ol0003om@[eooD:m@0IooD:m@03o`000?ok1?_on`Ck01[on`Ck00?o0000oo/4
nook1?/04ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oc3?<01Ol0003ojQGZonXEj_oZ5N[o000000Co^TFj00?o0000ooD:
mOoe2_D06?oe2_D00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[ol`cc00?o0000onXEj_oZ
5NX00_oZ5NX00ol0003o^TFjokY5^P03okY5^P03o`000?oe2_Gom@[e01Oom@[e00?o0000oo/4nook
1?/06Ook1?/00ol0003on`Ckoo/4n`0Foo/4n`05o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooc3?<00ol0003ojQGZonXEjP02onXEjP03o`000?njAK[o^TFj00Co
^TFj00?o0000ooD:mOoe2_D05ooe2_D00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?ok1?_on`Ck01Oo
n`Ck00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?oo<<l`03o`00
0?oZ5N[ojQGZ00?ojQGZ00?o0000okY5^_njAKX01OnjAKX00ol0003om@[eooD:m@0FooD:m@03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000oo/4nook1?/06Ook1?/00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000Aoo<<l`03o`000?oZ5N[ojQGZ00CojQGZ00?o0000okY5^_njAKX01_nj
AKX2o`0001Gom@[e0ol0000Hoo/4n`03o`000?ok1?_on`Ck01Won`Ck00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
oo<<l`03o`000?oZ5N[ojQGZ00CojQGZ00?o0000okY5^_njAKX02?njAKX00ol0003om@[eooD:m@0@
ooD:m@;o00000onQGZ400ol0003on`Ckoo/4n`0Doo/4n`03o`000?ok1?_on`Ck01[on`Ck00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000oo<<looc3?<04_oc3?<00ol0003ojQGZonXEjP05onXEjP03o`000?njAK[o^TFj
00Wo^TFj00?o0000ooD:mOoe2_D03Ooe2_D2o`0000KoXEjQ0_l0000Doo/4n`03o`000?ok1?_on`Ck
01[on`Ck00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oc3??ol`cc01;ol`cc00?o0000onXEj_oZ
5NX01OoZ5NX00ol0003o^TFjokY5^P0:okY5^P03o`000?oe2_Gom@[e00[om@[e0_l0000:oj5NX@03
o`000?ok1?_on`Ck017on`Ck00?o0000oo/4nook1?/06_ok1?/00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003ol`ccoo<<l`0@oo<<l`03o`000?oZ5N[ojQGZ00Ko
jQGZ00?o0000okY5^_njAKX02onjAKX00ol0003om@[eooD:m@08ooD:m@03o`000?nQGZ7oXEjQ00_o
XEjQ0_l0000@oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oc3??ol`cc00ool`cc00?o0000onXEj_oZ5NX0
1ooZ5NX00ol0003o^TFjokY5^P0<okY5^P03o`000?oe2_Gom@[e00Gom@[e0_l0000@oj5NX@03o`00
0?ok1?_on`Ck00gon`Ck00?o0000oo/4nook1?/06ook1?/00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oc3??ol`cc00ool`cc00?o0000onXEj_oZ5NX01ooZ5NX00ol0003o^TFjokY5
^P0=okY5^P03o`000?oe2_Gom@[e00;om@[e0_l0000Coj5NX@;o00003?ok1?/00ol0003on`Ckoo/4
n`0Loo/4n`?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oc3??o
l`cc00kol`cc00?o0000onXEj_oZ5NX02?oZ5NX00ol0003o^TFjokY5^P0>okY5^P04o`000?oe2_Go
0000o`0001OoXEjQ00?o0000oo/4nook1?/02Ook1?/00ol0003on`Ckoo/4n`0Loo/4n`03o`000?oi
1_Won@Ki00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oc3??o
l`cc00col`cc00?o0000onXEj_oZ5NX02OoZ5NX00ol0003o^TFjokY5^P0?okY5^P03o`000?nQGZ7o
XEjQ01SoXEjQ0_l00009oo/4n`03o`000?ok1?_on`Ck01_on`Ck00?o0000ooT6nOoi1_T01?oi1_T4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>oo<<l`03o`000?oZ5N[ojQGZ
00WojQGZ00?o0000okY5^_njAKX03onjAKX00ol0003oXEjQoj5NX@0Joj5NX@03o`000?ok1?_on`Ck
00Con`Ck0ol0000Loo/4n`03o`000?oi1_Won@Ki00Won@Ki0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o[5>_ojaC[o`0000col`cc00?o0000onXEj_oZ5NX02_oZ5NX00ol0003o^TFjokY5^P0?okY5
^P03o`000?nQGZ7oXEjQ01_oXEjQ0_l00003oo/4n`04o`000?oV6NKoiQWVonHIiP?o00006?ok1?/0
0ol0003on@KiooT6n@0=ooT6n@?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o[5>_ojaC[
00;ojaC[00?o0000oo<<looc3?<02Ooc3?<00ol0003ojQGZonXEjP0:onXEjP03o`000?njAK[o^TFj
00ko^TFj00?o0000oj5NXOnQGZ407_nQGZ400ol0003on`Cko`000007onHIiP?o00005?ok1?/00ol0
003on@KiooT6n@0AooT6n@;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o[5>/00ol0003ol`ccoo<<l`07oo<<l`03
o`000?oZ5N[ojQGZ00_ojQGZ00?o0000okY5^_njAKX03_njAKX00ol0003oXEjQoj5NX@0Ooj5NX@03
o`000?oV6NKoiQWV00WoiQWV0ol0000@oo/4n`03o`000?oi1_Won@Ki01?on@Ki00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ojaC[
on/Dj`07on/Dj`03o`000?oc3??ol`cc00Gol`cc00?o0000onXEj_oZ5NX03?oZ5NX00ol0003o^TFj
okY5^P0>okY5^P03o`000?nQGZ7oXEjQ01ooXEjQ00?o0000onHIi_oV6NH03?oV6NH3o`0000gon`Ck
00?o0000ooT6nOoi1_T05?oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ojaC[00?o0000oo<<looc3?<01?oc
3?<00ol0003ojQGZonXEjP0<onXEjP03o`000?njAK[o^TFj00ko^TFj00?o0000oj5NXOnQGZ407_nQ
GZ400ol0003oiQWVonHIiP0@onHIiP?o00002Ook1?/00ol0003on@KiooT6n@0FooT6n@Oo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000on/Djoo[5>/03?o[5>/00ol0003ol`ccoo<<l`02oo<<l`03o`000?oZ
5N[ojQGZ00gojQGZ00?o0000okY5^_njAKX03_njAKX00ol0003oXEjQoj5NX@0Noj5NX@03o`000?oV
6NKoiQWV01?oiQWV0ol00005oo/4n`03o`000?oi1_Won@Ki01Oon@Ki00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o[5>_ojaC[00kojaC[00Go0000
oo<<looc3??ol`cco`00000?onXEjP03o`000?njAK[o^TFj00go^TFj00?o0000oj5NXOnQGZ407onQ
GZ400ol0003oiQWVonHIiP0FonHIiP?o000000?on`Cko`000?oi1_T06?oi1_T00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Bon/Dj`03o`000?oc3??o0000013ojQGZ00?o0000okY5^_njAKX02onjAKX3
o`00023oXEjQ00?o0000onHIi_oV6NH06_oV6NH00ol0003on@KiooT6n@0HooT6n@03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o[5>_ojaC[01?ojaC[00?o0000onXE
j_oZ5NX03ooZ5NX00ol0003o^TFjokY5^P07okY5^PCo00000_m</d`00ol0003oXEjQoj5NX@0Noj5N
X@03o`000?oV6NKoiQWV01[oiQWV00?o0000ooT6nOoi1_T05ooi1_T00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
jaC[00?o0000onXEj_oZ5NX03ooZ5NX00ol0003o^TFjokY5^P03okY5^PCo00001om</d`00ol0003o
XEjQoj5NX@0Loj5NX@03o`000?oV6NKoiQWV01coiQWV00?o0000ooT6nOoi1_T05Ooi1_T00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000on/Djoo[5>/05oo[5>/00ol0003ojQGZonXEjP0>onXEjP03o`00
0?njAK[o000000?o00003?m</d`00ol0003oXEjQoj5NX@0Koj5NX@03o`000?oV6NKoiQWV01coiQWV
00?o0000ooT6nOoi1_T05Ooi1_T00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o[
5>/5o`0000_ojQGZ0ol0000AodbcC003o`000?nQGZ7oXEjQ01[oXEjQ00?o0000onHIi_oV6NH07OoV
6NH00ol0003on@KiooT6n@0CooT6n@03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o[5>_ojaC[01WojaC[00?o0000
og:=L_mbSG800_mbSG87o`0000?ojQGZ00?o0000odbcC?m</d`04om</d`3o`0001OoXEjQ0_l0000P
onHIiP03o`000?oi1_Won@Ki01?on@Ki00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000on/Djoo[5>/06?o[5>/00ol0
003oLXebog:=LP0:og:=LP?o00005_m</d`00ol0003o7n0OoaoP7`05o`00013oXEjQ0_l000000om6
^DKo0000onHIiP0OonHIiP03o`000?oi1_Won@Ki01;on@Ki00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000on/Djoo[5>/05_o[5>/00ol0003oLXebog:=LP0=og:=LP03
o`000?m</dcoC;=<01?oC;=<00?o0000oaoP7olOh1l01_lOh1l4o`0000_oXEjQ00?o0000odJiA_m6
^DH00_m6^DH00ol0003oiQWVonHIiP0NonHIiP03o`000?oi1_Won@Ki013on@Ki00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ojaC[on/Dj`0Don/Dj`03o`000?mbSG;oLXeb00ooLXeb
00?o0000odbcC?m</d`04_m</d`00ol0003o7n0OoaoP7`0:oaoP7`Go00001?nQGZ42o`0000GoA[U6
00?o0000onHIi_oV6NH07_oV6NH00ol0003on@KiooT6n@0@ooT6n@03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o[
5>_ojaC[01CojaC[00?o0000og:=L_mbSG803ombSG800ol0003oC;=<odbcC00BodbcC003o`000?lO
h1oo7n0O00oo7n0O1?l00008odJiAP03o`000?oV6NKoiQWV01koiQWV00?o0000ooT6nOoi1_T03_oi
1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
on/Djoo[5>/04_o[5>/00ol0003oLXebog:=LP0@og:=LP03o`000?m</dcoC;=<017oC;=<00?o0000
oaoP7olOh1l04OlOh1l00ol0003o7N8Mo`000009odJiAP03o`000?oV6NKoiQWV01goiQWV00?o0000
ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000on/Djoo[5>/03_o[5>/3o`0001CoLXeb00?o0000odbcC?m</d`04?m</d`00ol0
003o7n0OoaoP7`0@oaoP7`04o`000?lMhQgo7N8Mo`0000WoA[U600?o0000onHIi_oV6NH07_oV6NH0
0ol0003on@KiooT6n@0<ooT6n@03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000on/Djoo[5>/02_o[5>/4o`0000;oVFJI00?o0000og:=
L_mbSG804_mbSG800ol0003oC;=<odbcC00@odbcC003o`000?lOh1oo7n0O00oo7n0O00Go0000oagR
7OlMhQgo7N8Mo`00000:odJiAP03o`000?oV6NKoiQWV01goiQWV00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000on/D
joo[5>/01Oo[5>/4o`0000OoVFJI00?o0000og:=L_mbSG804OmbSG800ol0003oC;=<odbcC00?odbc
C003o`000?lOh1oo7n0O013o7n0O00Go0000oagR7OlMhQgo7N8Mo`00000:odJiAP03o`000?oV6NKo
iQWV01goiQWV00?o0000ooT6nOoi1_T02ooi1_T00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o[5>_o
jaC[00Co00002onIIYT00ol0003oLXebog:=LP0Bog:=LP03o`000?m</dcoC;=<00koC;=<00?o0000
oaoP7olOh1l03olOh1l00ol0003o7N8MoagR7@02oagR7@03o`000?m6^DKoA[U600WoA[U600?o0000
onHIi_oV6NH07?oV6NH3o`0000[on@Ki00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000onPGj?l0003o00003onIIYT00ol0003oLXebog:=LP0Aog:=LP03o`000?lM
hQgo000000ooC;=<00?o0000oaoP7olOh1l03_lOh1l00ol0003o7N8MoagR7@03oagR7@03o`000?m6
^DKoA[U600WoA[U600?o0000onHIi_oV6NH06OoV6NH3o`0000?oiA[U00?o0000ooT6nOoi1_T01ooi
1_T00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?oX5nSoj1OXo`00017oVFJI00?o
0000og:=L_mbSG803ombSG801Ol0003o7N8MoagR7OlMhQgo000000[oC;=<1?l0000AoaoP7`03o`00
0?lMhQgo7N8M00?o7N8M00?o0000odJiA_m6^DH02_m6^DH00ol0003oiQWVonHIiP0FonHIiP;o0000
1ooU6^D00ol0003on@KiooT6n@05ooT6n@03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003oj1OXonPGj002onPGj003o`000?nIIYWoVFJI00koVFJI00?o
0000og:=L_mbSG803_mbSG800ol0003o7N8MoagR7@03oagR7@04o`000?m</dcoC;=<odbcC0Ko0000
0olHiaP00ol0003o7n0OoaoP7`0>oaoP7`03o`000?lMhQgo7N8M00Co7N8M00?o0000odJiA_m6^DH0
2_m6^DH00ol0003oiQWVonHIiP0ConHIiP?o00002_oU6^D00ol0003on@KiooT6n@03ooT6n@03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?oX
5nSoj1OX00?oj1OX00?o0000oiUVVOnIIYT03_nIIYT00ol0003oLXebog:=LP0=og:=LP03o`000?lM
hQgo7N8M00Go7N8M0ol0000:oaSW6003o`000?lOh1oo7n0O00co7n0O00?o0000oagR7OlMhQd01OlM
hQd00ol0003oA[U6odJiAP0;odJiAP03o`000?oV6NKoiQWV013oiQWV0_l0000>onDJi@03o`000?oi
1_Won@Ki00;on@Ki00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?oX5nSoj1OX00Coj1OX00?o0000oiUVVOnIIYT03onIIYT00ol0003oLXebog:=LP0;
og:=LP03o`000?lMhQgo7N8M00Ko7N8M00?o0000oaSW6?lHiaP02olHiaP00ol0003o7n0OoaoP7`0;
oaoP7`03o`000?lMhQgo7N8M00Go7N8M00?o0000odJiA_m6^DH03?m6^DH00ol0003oiQWVonHIiP0<
onHIiP?o00004OoU6^D5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?oX5nSoj1OX
00Koj1OX00?o0000oiUVVOnIIYT03_nIIYT00ol0003oLXebog:=LP0:og:=LP03o`000?lMhQgo7N8M
00Oo7N8M00?o0000oaSW6?lHiaP02olHiaP00ol0003o7n0OoaoP7`0:oaoP7`03o`000?lMhQgo7N8M
00Ko7N8M00?o0000odJiA_m6^DH03?m6^DH00ol0003oiQWVonHIiP0:onHIiP;o00005?oU6^D00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003oj1OXonPGj007onPG
j003o`000?nIIYWoVFJI00koVFJI00?o0000og:=L_mbSG802OmbSG800ol0003o7N8MoagR7@08oagR
7@03o`000?lHiaSo6>LH00co6>LH00?o0000oaoP7olOh1l02?lOh1l00ol0003o7N8MoagR7@07oagR
7@03o`000?m6^DKoA[U600goA[U61Ol00004onHIiP?o00005OoU6^D00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003oj1OXonPGj008onPG
j003o`000?nIIYWoVFJI00ooVFJI00?o0000og:=L_mbSG801ombSG800ol0003o7N8MoagR7@09oagR
7@03o`000?lHiaSo6>LH00co6>LH0ol00008oaoP7`03o`000?lMhQgo7N8M00Oo7N8M00?o0000odJi
A_m6^DH03Om6^DH00ol0003oNhAkog^4N`02og^4N`Co00006?oU6^D00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?oX5nSoj1OX
00[oj1OX00?o0000oiUVVOnIIYT03_nIIYT00ol0003oLXebog:=LP06og:=LP03o`000?lMhQgo7N8M
00[o7N8M00?o0000oaSW6?lHiaP02_lHiaP2o`0000?o4n`C00?o0000oaoP7olOh1l01?lOh1l00ol0
003o7N8MoagR7@08oagR7@03o`000?m6^DKoA[U600coA[U600?o0000og^4NomkQ7/01_mkQ7/00ol0
003oiA[UonDJi@0EonDJi@03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000onPGj?oX5nP02ooX5nP00ol0003o
VFJIoiUVV@0>oiUVV@03o`000?mbSG;oLXeb00GoLXeb00?o0000oagR7OlMhQd02olMhQd00ol0003o
6>LHoaSW6008oaSW60;o00001_lCk1<00ol0003o7n0OoaoP7`02oaoP7`03o`000?lMhQgo7N8M00Wo
7N8M00?o0000odJiA_m6^DH03?m6^DH00ol0003oNhAkog^4N`07og^4N`03o`000?oU6^GoiA[U01Co
iA[U00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?oX5nSoj1OX00goj1OX00?o0000oiUVVOnIIYT03_nIIYT00ol0003oLXebog:=LP03og:=LP03o`00
0?lMhQgo7N8M00co7N8M00?o0000oaSW6?lHiaP01_lHiaP2o`0000Wo4n`C00Go0000oaoP7olOh1oo
7n0Oo`00000;oagR7@03o`000?m6^DKoA[U600coA[U600?o0000og^4NomkQ7/01omkQ7/00ol0003o
iA[UonDJi@0ConDJi@03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?oX5nSoj1OX00ko
j1OX00?o0000oiUVVOnIIYT03_nIIYT00ol0003oLXebog:=LP02og:=LP03o`000?lMhQgo7N8M00go
7N8M00?o0000oaSW6?lHiaP01?lHiaP2o`0000co4n`C00?o0000oaoP7ol000003?lMhQd00ol0003o
A[U6odJiAP0;odJiAP03o`000?mkQ7_oNhAk00WoNhAk00?o0000onDJiOoU6^D04OoU6^D00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003oj1OXonPGj00?onPGj003o`000?nIIYWoVFJI00koVFJI00Go0000og:=L_mbSG;o
LXebo`00000@oagR7@03o`000?lHiaSo6>LH00;o6>LH0_l0000?oa?/4`03o`000?lMhQgo7N8M00_o
7N8M00?o0000odJiA_m6^DH02om6^DH00ol0003oNhAkog^4N`09og^4N`03o`000?oU6^GoiA[U017o
iA[U00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000onPGj?oX5nP04OoX5nP00ol0003oVFJI
oiUVV@0>oiUVV@Co00004?lMhQd00ol0003o6>LHoaSW6002o`00017o4n`C00?o0000oagR7OlMhQd0
2olMhQd00ol0003oA[U6odJiAP0:odJiAP03o`000?mkQ7_oNhAk00_oNhAk00?o0000onDJiOoU6^D0
3ooU6^D00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ook1?/00ol0003onPGjooX5nP03ooX5nP03o`000?oX
5nSoj1OX01;oj1OX00?o0000oiUVVOnIIYT03OnIIYT00ol0003o:m@[ob_D:`02ob_D:`;o00003_lM
hQd3o`0001?o4n`C00?o0000oagR7OlMhQd02olMhQd00ol0003oA[U6odJiAP0:odJiAP03o`000?mk
Q7_oNhAk00_oNhAk00?o0000onDJiOoU6^D03ooU6^D00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ok1?_on`Ck00Con`Ck00Go0000ooX5n_oj1O[onPGjo`00000EonPGj003o`000?nI
IYWoVFJI00coVFJI00?o0000ob_D:ol[e2/01Ol[e2/2o`0000co7N8M00?o0000oa?/4olCk1<05?lC
k1<00ol0003o7N8MoagR7@0:oagR7@03o`000?m6^DKoA[U600[oA[U600?o0000og^4NomkQ7/03?mk
Q7/00ol0003oiA[UonDJi@0=onDJi@03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Son`Ck00?o0000
ooX5n_l000005ooX5nP00ol0003oVFJIoiUVV@0:oiUVV@03o`000?l[e2_o:m@[00So:m@[00?o0000
oagR7OlMhQd02?lMhQd3o`0001Go4n`C0_l0000;oagR7@03o`000?m6^DKoA[U600WoA[U600?o0000
og^4NomkQ7/03_mkQ7/00ol0003oiA[UonDJi@0<onDJi@03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_on`Ck00?o0000onPGj?oX5nP05_oX5nP00ol0003oVFJIoiUVV@09oiUVV@03o`000?l[e2_o:m@[
00[o:m@[0_l00005oagR7@?o00000olCk1<00ol0003o4n`Coa?/4`0Aoa?/4`03o`000?l@ka3o4>l@
00;o00002OlMhQd00ol0003oA[U6odJiAP09odJiAP03o`000?mkQ7_oNhAk00koNhAk00?o0000onDJ
iOoU6^D02ooU6^D00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo/4n`03o`000?oX5nSoj1OX01Ko
j1OX00?o0000oiUVVOnIIYT00onIIYT6o`0000oo:m@[0_l000000olMhQgo0000o`000007oa?/4`;o
00004?lCk1<00ol0003o4>l@oa3_4003oa3_40?o00001_lMhQd00ol0003oA[U6odJiAP09odJiAP03
o`000?mkQ7_oNhAk00ooNhAk00?o0000onDJiOoU6^D02_oU6^D00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ok1?/00ol0003oj1OX
onPGj00FonPGj0Go00001On3O8<00ol0003o:m@[ob_D:`0?ob_D:`03o`000?lCk1?o4n`C00Wo4n`C
00?o0000oa?/4olCk1<03?lCk1<00ol0003o4>l@oa3_4007oa3_40;o00000_lMhQd>o`0001;oNhAk
00?o0000onDJiOoU6^D02OoU6^D00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ok1?_on`Ck013on`Ck00?o0000onPGj?oX5nP05OoX
5nP00ol0003oPgb3oh=lP`09oh=lP`03o`000?l[e2_o:m@[00ko:m@[00?o0000oa?/4olCk1<02_lC
k1<2o`0000_o4n`C00?o0000oa3_4?l@ka002_l@ka02o`0000go8]dR00?o0000og^4NomkQ7/04Omk
Q7/00ol0003oiA[UonDJi@07onDJi@03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ok1?/00ol0003oj1OXonPGj00ConPGj003o`000?n3O8?oPgb300[oPgb300?o
0000ob_D:ol[e2/03_l[e2/00ol0003o4n`Coa?/4`0<oa?/4`03o`000?lCk1?o4n`C00Oo4n`C00?o
0000oa3_4?l@ka002ol@ka000ol0003o8]dRob;M8P0=ob;M8P03o`000?mkQ7_oNhAk013oNhAk00?o
0000onDJiOoU6^D01ooU6^D00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?oX5nSoj1OX01;oj1OX00?o0000oh=lPon3O8<02on3
O8<00ol0003o:m@[ob_D:`0>ob_D:`03o`000?lCk1?o4n`C00go4n`C00?o0000oa?/4olCk1<01?lC
k1<2o`0000ko4>l@00?o0000ob;M8_lRgB803OlRgB800ol0003oNhAkog^4N`0@og^4N`Co00001OoU
6^D00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok
1?_on`Ck01Gon`Ck5?l0000?oh=lP`03o`000?l[e2_o:m@[00co:m@[00?o0000oaKY5_l000003olC
k1<2o`0000?o4n`C00Co0000o`ka3_l>l@ko00003Ol@ka000ol0003o8]dRob;M8P0>ob;M8P03o`00
0?mkQ7_oNhAk00coNhAk0ol00004okE:]@?o00000_oU6^D00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo/4nook1?/05Ook1?/00ol0003oi1_Ton@K
i00@on@Ki003o`000?n3O8?oPgb300goPgb300?o0000ob_D:ol[e2/02ol[e2/01?l0003o5^TFoaKY
5_l0000Aoa?/4`03o`000?lCk1?o000000Co3_4>00?o0000oa3_4?l@ka002_l@ka000ol0003o8]dR
ob;M8P0>ob;M8P03o`000?mkQ7_oNhAk00WoNhAk0ol0000:okE:]@;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?oT6nCoi1_T013oi1_T00?o0000oh=lPon3O8<03On3
O8<00ol0003o:m@[ob_D:`0:ob_D:`03o`000?lFjAKo5^TF00;o5^TF00?o0000oa?/4olCk1<03olC
k1<00ol0003o3_4>o`ka3P04o`ka3P03o`000?l@ka3o4>l@00Wo4>l@00?o0000ob;M8_lRgB803_lR
gB800ol0003oNhAkog^4N`06og^4N`?o00003_neB[D00ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ok1?_on`Ck01Gon`Ck00?o0000
on@Ki?oT6n@04_oT6n@00ol0003oPgb3oh=lP`0=oh=lP`03o`000?l[e2_o:m@[00Wo:m@[00?o0000
oaKY5_lFjAH00_lFjAH00ol0003o4n`Coa?/4`0?oa?/4`03o`000?l>l@ko3_4>00Go3_4>00?o0000
oa3_4?l@ka002?l@ka000ol0003o8]dRob;M8P0?ob;M8P03o`000?mkQ7_oNhAk00;oNhAk0ol0000B
okE:]@03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003on`Ckoo/4n`0Coo/4n`?o00005?oT6n@00ol0003oPgb3oh=lP`0=oh=lP`03o`000?l[e2_o:m@[
00So:m@[00?o0000oaKY5_lFjAH01?lFjAH00ol0003o4n`Coa?/4`0>oa?/4`03o`000?l>l@ko3_4>
00Ko3_4>00?o0000oa3_4?l@ka001ol@ka000ol0003o8]dRob;M8P0?ob;M8P03o`000?mkQ7_o0000
00;o00005OneB[D00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ok1?_on`Ck00oon`Ck1?l00002ooH9mP03o`000?oT6nCoi1_T01;o
i1_T00?o0000oh=lPon3O8<03On3O8<00ol0003o:m@[ob_D:`07ob_D:`03o`000?lFjAKo5^TF00Go
5^TF00?o0000oa?/4olCk1<03OlCk1<00ol0003o3_4>o`ka3P08o`ka3P03o`000?l@ka3o4>l@00Ko
4>l@00?o0000ob;M8_lRgB804?lRgB800ol0003o]DZeokE:]@0FokE:]@03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/02ook1?/4o`0000KomPWf
00?o0000on@Ki?oT6n@04ooT6n@00ol0003oPgb3oh=lP`0=oh=lP`03o`000?l[e2_o:m@[00Go:m@[
00?o0000oaKY5_lFjAH01olFjAH00ol0003o4n`Coa?/4`0<oa?/4`03o`000?l>l@ko3_4>00Wo3_4>
00?o0000oa3_4?l@ka001Ol@ka000ol0003o8]dRob;M8P0@ob;M8P03o`000?neB[Go]DZe01Oo]DZe
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/01ook
1?/4o`0000[omPWf00?o0000on@Ki?oT6n@04ooT6n@00ol0003oPgb3oh=lP`0=oh=lP`03o`000?l[
e2_o:m@[00Co:m@[00?o0000oaKY5_lFjAH02?lFjAH00ol0003o4n`Coa?/4`0<oa?/4`03o`000?l>
l@ko3_4>00[o3_4>00?o0000oa3_4?l@ka001?l@ka000ol0003o8]dRob;M8P0@ob;M8P03o`000?ne
B[Go]DZe01Oo]DZe00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003on`Ckoo/4n`04oo/4n`Co00003_of2OH00ol0003oi1_Ton@Ki00Con@Ki003o`000?n3O8?o
Pgb300goPgb300?o0000ob_D:ol[e2/01?l[e2/00ol0003o5^TFoaKY5P09oaKY5P03o`000?lCk1?o
4n`C00_o4n`C00?o0000o`ka3_l>l@h02ol>l@h00ol0003o4>l@oa3_4003oa3_4003o`000?lRgB;o
8]dR013o8]dR00?o0000okE:]OneB[D05oneB[D00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`04o`0001;omPWf00?o0000on@Ki?oT6n@04ooT6n@00ol0
003oPgb3oh=lP`0>oh=lP`03o`000?l[e2_o:m@[00;o:m@[00?o0000oaKY5_lFjAH02_lFjAH00ol0
003o4n`Coa?/4`0:oa?/4`03o`000?l>l@ko3_4>00go3_4>00?o0000oa3_4?l@ka000_l@ka000ol0
003o8]dRob;M8P0@ob;M8P03o`000?neB[Go]DZe01So]DZe00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oT6nCoi1_T01?oi1_T00?o0000oh=lPon3O8<03?n3O8<4o`000003ob_D:ol0003o5^TF00go
5^TF00?o0000oa?/4olCk1<02OlCk1<00ol0003o3_4>o`ka3P0>o`ka3P05o`000?l@ka3o4>l@oa3_
4?l000004_lRgB800ol0003o]DZeokE:]@0HokE:]@?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oT6nCoi1_T
01?oi1_T00?o0000oh=lPon3O8<02on3O8<00ol0003o9=/TobCK9002obCK90;o00003_lFjAH00ol0
003o4n`Coa?/4`09oa?/4`03o`000?l>l@ko3_4>00oo3_4>00Co0000oa3_4?l@ka3o00004_lRgB80
0ol0003o]DZeokE:]@0HokE:]@03o`000?o[5>_ojaC[00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000on@Ki?oT6n@04ooT6n@00ol0003oPgb3oh=lP`0:
oh=lP`03o`000?lTfbCo9=/T00Go9=/T00?o0000oaKY5_lFjAH03?lFjAH00ol0003o4n`Coa?/4`08
oa?/4`03o`000?l>l@ko3_4>00oo3_4>1Ol0000Aob;M8P03o`000?neB[Go]DZe01Oo]DZe00?o0000
on/Djoo[5>/01?o[5>/3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oT6nCoi1_T01?oi1_T00?o0000oh=lPon3O8<02?n3O8<2o`00
00Wo9=/T00?o0000oaKY5_lFjAH02olFjAH00ol0003o4n`Coa?/4`07oa?/4`03o`000?l>l@ko3_4>
00go3_4>0ol00005oa3_4003o`000?lRgB;o8]dR00ko8]dR00?o0000okE:]OneB[D05_neB[D00ol0
003ojaC[on/Dj`08on/Dj`?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000Eon@Ki003o`000?n3O8?oPgb300KoPgb300?o0000obCK9?lT
fb@02_lTfb@00ol0003o5^TFoaKY5P0:oaKY5Q[o00002Ol@ka000ol0003o8]dRob;M8P0<ob;M8P?o
00005_neB[D00ol0003ojaC[on/Dj`0<on/Dj`?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oT6n@3o`0001;oi1_T00?o0000oh=lPon3O8<01?n3O8<2o`0000ko9=/T
00?o0000oaKY5_lFjAH01olFjAH2o`0000[o4^dB00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o4>l@
oa3_4008oa3_40;o00002_lRgB82o`0000?o:]DZ0_l0000CokE:]@03o`000?o[5>_ojaC[013ojaC[
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005on@Ki0;o00004?oT
6n@00ol0003oPgb3oh=lP`03oh=lP`03o`000?lTfbCo9=/T00oo9=/T00?o0000oaKY5_lFjAH01?lF
jAH2o`0000co4^dB00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o4>l@oa3_400:oa3_4003o`000?lR
gB;o8]dR00Go8]dR0_l00007ob[E:P03o`000?neB[Go]DZe00oo]DZe00?o0000on/Djoo[5>/04Oo[
5>/01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000on@Ki?oT6n@01OoT6n@2o`0000ooi1_T00Go0000oh=lPon3O8?oPgb3o`00000CobCK9003o`00
0?lFjAKo5^TF00;o5^TF00?o0000oa;]4_lBkA803OlBkA800ol0003o3O8=o`gb3@0;o`gb3@03o`00
0?l@ka3o4>l@00_o4>l@00?o0000ob;M8_lRgB800_lRgB82o`0000[o:]DZ0_l0000>okE:]@03o`00
0?o[5>_ojaC[017ojaC[00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000on@Ki?oT6n@01_oT6n@3o`0000_oi1_T1Ol0000EobCK9004o`00
0?lFjAKo0000o`00013o4^dB00?o0000o`gb3Ol=lPd02ol=lPd00ol0003o4>l@oa3_400<oa3_4004
o`000?lRgB;o0000o`0000ko:]DZ0_l0000;okE:]@03o`000?o[5>_ojaC[017ojaC[00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oT6nCoi1_T00Woi1_T0_l00008on@Ki003o`000?n5NXGoQGZ500;oQGZ500?o0000obCK9?lT
fb@05?lTfb@00ol0003o4^dBoa;]4P0@oa;]4P03o`000?l=lPgo3O8=00_o3O8=00?o0000oa3_4?l@
ka003Ol@ka000ol0003o:]DZob[E:P0@ob[E:P03o`000?neB[Go]DZe00Oo]DZe00?o0000on/Djoo[
5>/04Oo[5>/00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oT6nCoi1_T00_oi1_T
0_l00005on@Ki003o`000?n5NXGoQGZ500CoQGZ500?o0000obCK9?lTfb@04olTfb@00ol0003o4^dB
oa;]4P0@oa;]4P03o`000?l=lPgo3O8=00_o3O8=00?o0000oa3_4?l@ka003Ol@ka000ol0003o:]DZ
ob[E:P0Aob[E:P;o00000oneB[D4o`0001?ojaC[00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oT6nCoi1_T00goi1_T0ol000000ooT6nCo0000ohEjQ@07ohEjQ@03o`000?lTfbCo9=/T01;o
9=/T00?o0000oa;]4_lBkA804?lBkA800ol0003o3O8=o`gb3@0;o`gb3@03o`000?l@ka3o4>l@00go
4>l@00?o0000ob[E:_lZeBX04olZeBX3o`0000?oebSG00?o0000on/Djoo[5>/04?o[5>/00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000ohEjQOn5NXD0
2?n5NXD00ol0003o9=/TobCK900AobCK9003o`000?lBkA;o4^dB017o4^dB00?o0000o`gb3Ol=lPd0
2_l=lPd00ol0003o4>l@oa3_400<oa3_4003o`000?lEjQGo000001Co:]DZ00?o0000omLXeooG:=L0
1?oG:=L00ol0003ojaC[on/Dj`0>on/Dj`03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000on@Ki?oT6n@03ooT
6n@00ol0003oQGZ5ohEjQ@09ohEjQ@03o`000?lTfbCo9=/T013o9=/T00?o0000oa;]4_lBkA804OlB
kA800ol0003o3O8=o`gb3@0:o`gb3@03o`000?l@ka3o4>l@00_o4>l@00Co0000oaGZ5OlEjQGo0000
5?lZeBX00ol0003oebSGomLXe`05omLXe`03o`000?o[5>_ojaC[00cojaC[00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oi1_Ton@K
i00?on@Ki003o`000?n5NXGoQGZ500[oQGZ500?o0000obCK9?lTfb@03_lTfb@00ol0003o5nPGo`00
000Boa;]4P03o`000?l=lPgo3O8=00[o3O8=00?o0000oa3_4?l@ka002_l@ka000ol0003o5NXEoaGZ
5@02oaGZ5@03o`000?lZeB[o:]DZ013o:]DZ00?o0000omLXeooG:=L01ooG:=L00ol0003ojaC[on/D
j`0:on/Dj`03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oT6nCoi1_T00ooi1_T00?o0000ohEjQOn5NXD0
2on5NXD00ol0003o9=/TobCK900<obCK9005o`000?lGj1Oo5nPGoaOX5ol000004OlBkA800ol0003o
3O8=o`gb3@0:o`gb3@03o`000?l@ka3o4>l@00Wo4>l@00?o0000oaGZ5OlEjQD00olEjQD00ol0003o
:]DZob[E:P0@ob[E:P03o`000?oG:=OoebSG00SoebSG00?o0000on/Djoo[5>/02?o[5>/00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000on@Ki?oT6n@03_oT6n@00ol0003oQGZ5ohEjQ@0=ohEjQ@03o`00
0?lTfbCo9=/T00[o9=/T00?o0000oaOX5olGj1L00olGj1L00ol0003o4^dBoa;]4P0?oa;]4P03o`00
0?l=lPgo3O8=00Wo3O8=00?o0000oa3_4?l@ka002?l@ka000ol0003o5NXEoaGZ5@05oaGZ5@03o`00
0?lZeB[o:]DZ00oo:]DZ00?o0000omLXeooG:=L02OoG:=L00ol0003ojaC[on/Dj`06on/Dj`03o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oi1_Ton@Ki00>on@Ki003o`000?n5
NXGoQGZ500koQGZ500?o0000obCK9?lTfb@02?lTfb@00ol0003o5nPGoaOX5`05oaOX5`03o`000?lB
kA;o4^dB00ko4^dB00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o4>l@oa3_4007oa3_4003o`000?lE
jQGo5NXE00Ko5NXE00?o0000ob[E:_lZeBX03olZeBX00ol0003oebSGomLXe`09omLXe`03o`000?o[
5>_ojaC[00GojaC[00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki00=
on@Ki003o`000?n5NXGoQGZ500ooQGZ500?o0000obCK9?lTfb@01_lTfb@00ol0003o5nPGoaOX5`07
oaOX5`03o`000?lBkA;o4^dB00go4^dB00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o4>l@oa3_4004
oa3_40?o00002_lEjQD00ol0003o:]DZob[E:P0=ob[E:P03o`000?oG:=OoebSG00_oebSG00?o0000
on/Djoo[5>/00oo[5>/00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oT6nCoi1_T
00goi1_T00?o0000ohEjQOn5NXD04?n5NXD00ol0003o9=/TobCK9005obCK9003o`000?lGj1Oo5nPG
00So5nPG00?o0000oa;]4_lBkA803?lBkA800ol0003o3O8=o`gb3@09o`gb3@03o`000?l@ka3o0000
00Co00000_l@ka000ol0003o5NXEoaGZ5@08oaGZ5@03o`000?lZeB[o:]DZ00go:]DZ00?o0000omLX
eooG:=L03?oG:=L01Ol0003ojaC[on/Djoo[5>_o000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000on@Ki?oT6n@03OoT6n@00ol0
003oQGZ5ohEjQ@0AohEjQ@03o`000?lTfbCo9=/T00?o9=/T00?o0000oaOX5olGj1L02_lGj1L00ol0
003o4^dBoa;]4P0;oa;]4P03o`000?l=lPgo3O8=00So3O8=0ol00008oa3_4003o`000?lEjQGo5NXE
00So5NXE00?o0000ob[E:_lZeBX03?lZeBX00ol0003oebSGomLXe`0=omLXe`03o`000?o[5>_o0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oT6nCoi1_T00goi1_T00?o0000ohEjQOn5NXD04_n5NXD01Ol0
003o9=/TobCK9?lTfbCo000000ko5nPG00?o0000oa;]4_lBkA802olBkA800ol0003o3O8=o`gb3@06
o`gb3@03o`000?l@ka3o4>l@00Wo4>l@00?o0000oaGZ5OlEjQD02OlEjQD00ol0003o:]DZob[E:P0:
ob[E:P03o`000?oG:=OoebSG00ooebSG00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000on@Ki?oT6n@03OoT6n@00ol0003oQGZ5ohEjQ@0CohEjQ@03o`000?lTfbCo0000
013o5nPG3_l00006o`gb3@;o00003?l@ka000ol0003o5NXEoaGZ5@09oaGZ5@03o`000?lZeB[o:]DZ
00[o:]DZ00?o0000omLXeooG:=L03ooG:=L00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000on@Ki?oT6n@02ooT6n@00ol0003o
QGZ5ohEjQ@0DohEjQ@?o00003olGj1L00ol0003o5>/DoaC[500<oaC[5004o`000?l=lPgo3O8=o`gb
3@;o00003ol@ka000ol0003o5NXEoaGZ5@09oaGZ5@03o`000?lZeB[o:]DZ00Wo:]DZ00?o0000omLX
eooG:=L04?oG:=L00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oT6nCoi1_T00_o
i1_T00?o0000ohEjQOn5NXD04on5NXD01Ol0003o><LhocS7>?lhacSo000000go5nPG00?o0000oaC[
5?lDja@03_lDja@00ol0003o3O8=o`00000Aoa3_4003o`000?lEjQGo5NXE00Wo5NXE00?o0000ob[E
:_lZeBX02OlZeBX00ol0003oebSGomLXe`0@omLXe`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000BohEjQ@03o`000?lhacSo><Lh00?o><Lh00?o0000oaOX5olGj1L02OlGj1L00ol0003o
5>/DoaC[500@oaC[5003o`000?l@ka3o4>l@017o4>l@00?o0000oaGZ5OlEjQD02OlEjQD00ol0003o
:]DZob[E:P07ob[E:P03o`000?oG:=OoebSG017oebSG00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iaSWonLHi`0<onLHi`03o`000?n<LhcoS7><00?o00003_n5NXD00ol0003o><LhocS7>005ocS7>003
o`000?lGj1Oo5nPG00Oo5nPG00?o0000oaC[5?lDja@04OlDja@00ol0003o4>l@oa3_400Aoa3_4003
o`000?lEjQGo5NXE00Wo5NXE00?o0000ob[E:_lZeBX01_lZeBX2o`0001CoebSG00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiaSW00koiaSW
00?o0000ohacS?n<Lh`00on<Lh`3o`0000[oQGZ500?o0000ocS7>?lhacP01olhacP00ol0003o5nPG
oaOX5`05oaOX5`03o`000?lDjaCo5>/D01;o5>/D00?o0000oa3_4?l@ka004Ol@ka000ol0003o5NXE
oaGZ5@0:oaGZ5@03o`000?lZeB[o:]DZ00;o:]DZ0ol00002od^dB`03o`000?oG:=OoebSG017oebSG
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oW6>OoiaSW00koiaSW00?o0000ohacS?n<Lh`01_n<
Lh`3o`0000KoQGZ500?o0000ocS7>?lhacP02OlhacP00ol0003o5nPGoaOX5`03oaOX5`03o`000?lD
jaCo5>/D01?o5>/D00?o0000oa3_4?l@ka004_l@ka000ol0003o5NXEoaGZ5@09oaGZ5@03o`000?lZ
eB[o000000;o00001_m;]4/00ol0003oebSGomLXe`0@omLXe`03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oW6>Oo
iaSW00goiaSW00?o0000ohacS?n<Lh`02_n<Lh`3o`0000;oQGZ500?o0000ocS7>?lhacP02olhacP0
1Ol0003o5nPGoaOX5olGj1Oo000001Ko5>/D00?o0000oa3_4?l@ka004_l@ka000ol0003o5NXEoaGZ
5@0:oaGZ5@03o`000?m;]4_oBkA;00SoBkA;00?o0000omLXeooG:=L04?oG:=L00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oW6>OoiaSW00goiaSW00?o0000ohacS?n<Lh`03On<Lh`2o`0000oo><Lh00?o0000oaOX5ol00000
5olDja@00ol0003o4>l@oa3_400Coa3_4003o`000?lEjQGo5NXE00Wo5NXE00?o0000od^dBom;]4/0
2Om;]4/00ol0003oebSGomLXe`0?omLXe`03o`000?oj1O[onPGj00;o00000ook1?/2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW
6>L00ol0003oS7><ohacS00>ohacS003o`000?lhacSo><Lh00ko><Lh00?o0000oaC[5?lDja@05_lD
ja@00ol0003o4>l@oa3_400Coa3_4003o`000?lEjQGo5NXE00So5NXE00?o0000od^dBom;]4/02om;
]4/5o`0000coebSG00?o0000ooX5n_l000001ook1?/2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW6>L00ol0003oS7><ohacS00>
ohacS003o`000?lhacSo><Lh00ko><Lh00?o0000oaC[5?lDja@05_lDja@00ol0003o4>l@oa3_400C
oa3_4003o`000?lEjQGo5NXE00Oo5NXE00?o0000od^dBom;]4/03?m;]4/00ol0003ohAkQon4Nh@02
on4Nh@Wo00001?oG:=L00ol0003on`Ckoo/4n`08oo/4n`;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiaSWonLHi`0<onLHi`03o`000?n<LhcoS7><
00koS7><00?o0000ocS7>?lhacP03olhacP00ol0003o5>/DoaC[500EoaC[5003o`000?l@ka3o4>l@
01?o4>l@1?l00005oaGZ5@03o`000?m;]4_oBkA;00goBkA;00?o0000on4NhOoQ7^402ooQ7^44o`00
00gon`Ck0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oW6>OoiaSW00_oiaSW00?o0000ohacS?n<Lh`03on<Lh`00ol0003o><LhocS7>00?ocS7>003
o`000?lDjaCo5>/D01Go5>/D00?o0000oa3_4?l@ka004?l@ka03o`0000Co:m@[0ol000000olEjQGo
0000od^dB`0>od^dB`03o`000?oQ7^7ohAkQ00oohAkQ00?o0000oo/4nook1?/03Ook1?/2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiaSWonLHi`0;onLHi`03o`00
0?n<LhcoS7><00ooS7><00?o0000ocS7>?lhacP03olhacP2o`0001Co5>/D0ol0000@oa3_40;o0000
2_l[e2/00ol0003oBkA;od^dB`0>od^dB`03o`000?oQ7^7ohAkQ013ohAkQ0_l0000?oo/4n`;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oW6>OoiaSW00_oiaSW4ol0000>ocS7>0?o0000
0_lhacP00ol0003o5>/DoaC[500<oaC[50Go00000_lXebP00ol0003o4>l@oa3_400<oa3_40;o0000
3?l[e2/00ol0003oBkA;od^dB`0>od^dB`03o`000?oQ7^7ohAkQ013ohAkQ00?o0000ooH9m_l00000
4?ok1?/2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW
6>OoiaSW00_oiaSW00?o0000ohYeR_n:MHX03on:MHX00ol0003o><LhocS7>009ocS7>0?o00001_lh
acP00ol0003o5>/DoaC[5006oaC[50Go00002?lXebP00ol0003o4>l@oa3_4008oa3_40?o00003ol[
e2/00ol0003oBkA;od^dB`0=od^dB`03o`000?oQ7^7ohAkQ00oohAkQ00Go0000ooH9m_of2OKomPWf
o`00000Aoo/4n`;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLH
i`0;onLHi`03o`000?n:MH[oRWF:00ooRWF:00?o0000ocS7>?lhacP01_lhacP3o`0000[o><Lh00?o
0000oaC[5?lDja@01Ol0000>obSG:003o`000?l@ka3o4>l@00Go4>l@0_l0000Bob_D:`03o`000?m;
]4_oBkA;00coBkA;00?o0000on4NhOoQ7^404?oQ7^400ol0003omPWfooH9mP02ooH9mP03o`000?ok
1?_on`Ck013on`Ck00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLHi`0;
onLHi`03o`000?n:MH[oRWF:013oRWF:00?o0000ocS7>?lhacP00_lhacP3o`0000go><Lh0ol0000C
obSG:003o`000?l@ka3o4>l@00?o4>l@0_l0000Eob_D:`03o`000?m;]4_oBkA;00_oBkA;00?o0000
on4NhOoQ7^403ooQ7^400ol0003omPWfooH9mP04ooH9mP03o`000?ok1?_on`Ck00gon`Ck0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiaSWonLHi`08onLHi`Co00004On:MHX00ol0003o><Lho`000002o`00
00oo><Lh00?o0000odjaC_l000005OlXebP00ol0003o4>l@o`000002o`0001Oo:m@[00?o0000od^d
Bom;]4/02om;]4/00ol0003ohAkQon4Nh@0>on4Nh@03o`000?of2OKomPWf00KomPWf00?o0000oo/4
nook1?/02Ook1?/3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW6>OoiaSW00Go
iaSW0ol00004om8]dP03o`000?n:MH[oRWF:00koRWF:0_l0000AocS7>004o`000?m>/DkoC[5>o`00
01Ko:=LX00?o0000ob_D:ol[e2/06?l[e2/00ol0003oBkA;od^dB`0;od^dB`03o`000?oQ7^7ohAkQ
00kohAkQ00?o0000ooH9m_of2OH01oof2OH00ol0003on`Ckoo/4n`04oo/4n`Co00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oW6>OoiaSW00;oiaSW0ol00008om8]dP03
o`000?n:MH[oRWF:00coRWF:0ol0000?ocS7>0;o00000om>/Dh00ol0003o:=LXobSG:00DobSG:003
o`000?l[e2_o:m@[01Wo:m@[00?o0000od^dBom;]4/02_m;]4/00ol0003ohAkQon4Nh@0=on4Nh@03
o`000?of2OKomPWf00WomPWf00?o0000oo/4nook1?/00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<om8]dP03o`000?n:MH[oRWF:00[oRWF:00Go0000ohMhQon7N8Oo
QgR7o`00000=ocS7>003o`000?m>/DkoC[5>00CoC[5>00?o0000obSG:?lXebP04olXebP00ol0003o
:m@[ob_D:`0Iob_D:`03o`000?m;]4_oBkA;00WoBkA;00?o0000on4NhOoQ7^403_oQ7^400ol0003o
mPWfooH9mP0:ooH9mP;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?oB;M;odRgB00codRgB0_l00008ohYeRP;o00001On7N8L00ol0003o><LhocS7>009ocS7>003o`00
0?m>/DkoC[5>00GoC[5>00?o0000obSG:?lXebP04olXebP00ol0003o:m@[ob_D:`0Job_D:`go0000
3_oQ7^400ol0003omPWfooH9mP0;ooH9mP03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003odRgBom8]dP0=om8]dP03o`000?n:
MH[oRWF:00CoRWF:00?o0000ohMhQon7N8L01_n7N8L2o`0000So><Lh00?o0000odjaC_m>/Dh01_m>
/Dh00ol0003o:=LXobSG:00DobSG:003o`000?l[e2_o:m@[01Wo:m@[00?o0000ojUFZOnYEZT02_nY
EZT00ol0003ohAkQon4Nh@0;on4Nh@03o`000?of2OKomPWf00comPWf00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000om8]d_oB;M803_oB;M80
1?l0003oRWF:ohYeR_n:MHX2o`0000_oQgR700?o0000ocS7>?lhacP00olhacP2o`0000WoC[5>00?o
0000obSG:?lXebP05?lXebP00ol0003o:m@[ob_D:`0Hob_D:`03o`000?nYEZWoZEJY00coZEJY00?o
0000on4NhOoQ7^402OoQ7^400ol0003omPWfooH9mP0=ooH9mP03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003odRgBom8]dP0>om8]dP03o`000?n:MH[o
000000koQgR700Go0000ocS7>?lhacSo><Lho`00000;odjaCP03o`000?lXebSo:=LX01Co:=LX0_l0
000Iob_D:`03o`000?nYEZWoZEJY00goZEJY0_l00008on4Nh@03o`000?of2OKomPWf00komPWf00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003odRgBom8]dP0?
om8]dP03o`000?n7N8OoQgR700koQgR700?o0000ocS7>?l000003?m>/Dh00ol0003o:=LXobSG:00D
obSG:003o`000?mC[5?o000000;o00005Ol[e2/00ol0003oZEJYojUFZ@0@ojUFZ@03o`000?oQ7^7o
hAkQ00GohAkQ00?o0000ooH9m_of2OH03oof2OH00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003odRgBom8]dP0>om8]dP03o`000?n7N8OoQgR700koQgR70_l0000=odja
CP03o`000?lXebSo:=LX01?o:=LX00?o0000oe>/DomC[5<00omC[5<2o`0001;o:m@[00?o0000ojUF
ZOnYEZT04_nYEZT01?l0003ohAkQon4NhOoQ7^43o`0001;omPWf00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000om8]d_oB;M803OoB;M82o`0000ooQgR700?o0000ohac
S?l000003_m>/Dh00ol0003o:=LXobSG:00BobSG:003o`000?mC[5?oDjaC00GoDjaC0ol0000?ob_D
:`03o`000?nYEZWoZEJY01?oZEJY0ol00002oo4>l@03o`000?of2OKomPWf013omPWf00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000om8]d_oB;M802ooB;M800ol0003o
e2_Do`00000>ohMhQ`05o`000?n<LhcoS7><ohacS?l000003Om>/Dh00ol0003o:=LXobSG:00AobSG
:003o`000?mC[5?oDjaC00WoDjaC0ol0000:ob_D:`;o00005_nYEZT00ol0003ol@kaoo4>l@03oo4>
l@03o`000?of2OKomPWf013omPWf00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000om8]d_oB;M802_oB;M801Ol0003oe2_Dom@[e?oD:mCo000000coQgR700?o0000ohac
S?n<Lh`00_n<Lh`00ol0003oC[5>odjaCP0;odjaCP03o`000?lXebSo:=LX017o:=LX00?o0000oe>/
DomC[5<03?mC[5<2o`0000Ko:m@[0_l000000onEJYGo0000ojUFZ@0DojUFZ@03o`000?oa3_7ol@ka
00Gol@ka00?o0000ooH9m_of2OH03oof2OH00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003odRgBom8]dP07om8]dP;o00001OoD:m@00ol0003oQgR7ohMhQ`08ohMhQ`03
o`000?n<LhcoS7><00CoS7><00?o0000odjaC_m>/Dh02Om>/Dh4o`00013o:=LX00?o0000oe>/DomC
[5<03omC[5<3o`000003ob_D:ol0003o000000CoUFZE00?o0000ojUFZOnYEZT04OnYEZT00ol0003o
l@kaoo4>l@07oo4>l@03o`000?of2OKomPWf00oomPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000om8]d_oB;M801_oB;M800ol0003oe2_Dom@[e005om@[e003o`00
0?n7N8OoQgR700OoQgR700?o0000ohacS?n<Lh`01On<Lh`00ol0003oC[5>odjaCP08odjaCP03o`00
0?mJYE[oFZEJ00;oFZEJ0ol0000=obSG:003o`000?mC[5?oDjaC01;oDjaC00?o0000oiEZUOnEJYD0
1OnEJYD00ol0003oZEJYojUFZ@0@ojUFZ@03o`000?oa3_7ol@ka00Ool@ka00?o0000ooH9m_of2OH0
3oof2OH00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003odRgBom8]
dP04om8]dP03o`000?oD:mCoe2_D00Ooe2_D00?o0000ohMhQon7N8L01On7N8L00ol0003oS7><ohac
S007ohacS003o`000?m>/DkoC[5>00KoC[5>00?o0000oeZUF_mJYEX01_mJYEX3o`0000So:=LX0_l0
000Eoe>/D`03o`000?nEJYGoUFZE00KoUFZE00?o0000ojUFZOnYEZT03_nYEZT00ol0003ol@kaoo4>
l@09oo4>l@03o`000?of2OKomPWf00komPWf00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000om8]d_oB;M800_oB;M82o`0000[oe2_D00?o0000ohMhQon7N8L01?n7N8L0
0ol0003oS7><ohacS009ohacS003o`000?m>/DkoC[5>00?oC[5>0_l0000<oeZUFP?o00000_lXebP3
o`000003oeZUF_l0003oDjaC01CoDjaC00?o0000oiEZUOnEJYD01onEJYD00ol0003oZEJYojUFZ@0<
ojUFZ@03o`000?oa3_7ol@ka00_ol@ka00?o0000ooH9m_of2OH03_of2OH00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003odRgBom8]d_l0000=om@[e003o`000?n7N8Oo
QgR700;oQgR700?o0000ohacS?n<Lh`02_n<Lh`00ol0003oC[5>odjaCP02odjaCP03o`000?mJYE[o
FZEJ00ooFZEJ0_l00005oeZUFP03o`000?mC[5?oDjaC01;oDjaC00?o0000oiEZUOnEJYD02?nEJYD0
0ol0003oZEJYojUFZ@0:ojUFZ@03o`000?oa3_7ol@ka00gol@ka1Ol0000;ooH9mP03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?oB;M;o000000ooe2_D00Co0000ohMh
Qon7N8Oo00003_n<Lh`01?l0003oC[5>odjaC_l0000CoeZUFP03o`000?mJYE[oFZEJ00CoFZEJ00?o
0000oe>/DomC[5<04?mC[5<00ol0003oUFZEoiEZU@09oiEZU@03o`000?nYEZWoZEJY00[oZEJY00?o
0000oo4>lOoa3_403Ooa3_400ol0003on`Ckoo/4n`02oo/4n`Wo00000_of2OH00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?oD:mCoe2_D00koe2_D00?o0000ohMhQol000003on<Lh`0
0ol0003oC[5>o`00000CoeZUFP03o`000?mJYE[oFZEJ00GoFZEJ00?o0000oe>/DomC[5<04?mC[5<0
0ol0003oUFZEoiEZU@0:oiEZU@03o`000?nYEZWoZEJY00SoZEJY00?o0000oo4>lOoa3_403Ooa3_40
0ol0003on`Ckoo/4n`0<oo/4n`Co00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000om@[
e?oD:m@03ooD:m@00ol0003oS7><ohacS00>ohacS0;o00005?mJYEX00ol0003oFZEJoeZUFP06oeZU
FP03o`000?mC[5?oDjaC00ooDjaC00?o0000oiEZUOnEJYD02onEJYD00ol0003oZEJYojUFZ@04ojUF
Z@?o00004?oa3_400ol0003on`Ckoo/4n`0?oo/4n`Co00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
e2_Dom@[e00@om@[e003o`000?n<LhcoS7><00_oS7><0ol000000on9MXWo0000oeZUFP0BoeZUFP03
o`000?mJYE[oFZEJ00OoFZEJ00?o0000oe>/DomC[5<03omC[5<00ol0003oUFZEoiEZU@0<oiEZU@03
o`000?nYEZWoZEJY00?o00000ooY5^T00ol0003ol@kaoo4>l@0=oo4>l@03o`000?ok1?_on`Ck00oo
n`Ck00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000om@[e?oD:m@04?oD:m@3o`0000WoS7><0_l00005ohUfR@03o`00
0?mJYE[oFZEJ013oFZEJ00?o0000oeZUF_mJYEX02?mJYEX00ol0003oDjaCoe>/D`0>oe>/D`03o`00
0?nEJYGoUFZE00goUFZE0_l00007onTFj@03o`000?oa3_7ol@ka00_ol@ka00?o0000oo/4nook1?/0
3ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?oD:mCoe2_D00ooe2_D00Co
0000olXeb_o:=L[obSG:0_l00005ohacS0;o00002?n9MXT00ol0003oFZEJoeZUFP0>oeZUFP03o`00
0?mJYE[oFZEJ00[oFZEJ00?o0000oe>/DomC[5<03?mC[5<00ol0003oUFZEoiEZU@0>oiEZU@03o`00
0?oY5^WojAKY00OojAKY00?o0000oo4>lOoa3_402_oa3_400ol0003on`Ckoo/4n`0?oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006olXebP03o`000?n<Lhco000000;o00002_n9
MXT00ol0003oFZEJoeZUFP0=oeZUFP03o`000?mJYE[oFZEJ00_oFZEJ00?o0000oe>/DomC[5<03?mC
[5<00ol0003oUFZEoiEZU@0=oiEZU@03o`000?oY5^WojAKY00WojAKY00?o0000oo4>lOoa3_402?oa
3_400ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o`3o3o
l0o`00ool0o`00?o0000olXeb_o:=LX01Oo:=LX00ol0003oRGJ9ohUfR@0<ohUfR@03o`000?mJYE[o
FZEJ00coFZEJ00?o0000oeZUF_mJYEX03?mJYEX2o`0000coDjaC00?o0000oiEZUOnEJYD03OnEJYD0
0ol0003ojAKYonTFj@0:onTFj@03o`000?oa3_7ol@ka00Ool@ka00?o0000oo/4nook1?/03ook1?/0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o`3o004?o`3o000ol0003obSG:olXebP06olXebP03o`000?n9MXWo
RGJ900coRGJ900?o0000oeZUF_mJYEX02omJYEX00ol0003oFZEJoeZUFP0=oeZUFP04o`000?n1OX7o
0000o`0000[oDjaC00?o0000oiEZUOnEJYD03OnEJYD00ol0003ojAKYonTFj@0;onTFj@03o`000?oa
3_7ol@ka00Kol@ka00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003ol0o`oo0?l00@
oo0?l003o`000?o:=L[obSG:00KobSG:00?o0000ohUfROn9MXT03On9MXT00ol0003oFZEJoeZUFP0:
oeZUFP03o`000?mJYE[oFZEJ00coFZEJ00?o0000oh5nPOn1OX400_n1OX42o`0000SoDjaC00?o0000
oiEZUOnEJYD03?nEJYD00ol0003ojAKYonTFj@0=onTFj@03o`000?oa3_7ol@ka00Col@ka00?o0000
oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@oo0?l003o`000?o:=L[obSG:
00OobSG:00?o0000ohUfROn9MXT03_n9MXT<o`0000ooFZEJ00?o0000oh5nPOn1OX401?n1OX42o`00
00KoDjaC00?o0000oiEZUOnEJYD03?nEJYD00ol0003ojAKYonTFj@0>onTFj@03o`000?oa3_7ol@ka
00?ol@ka00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>oo0?
l003o`000?o:=L[obSG:00SobSG:00?o0000ohUfROn9MXT03On9MXT00ol0003oMhQgogN8M`08ogN8
M`03o`000?mJYE[oFZEJ00coFZEJ00?o0000oh5nPOn1OX401on1OX42o`0000?oDjaC00?o0000oiEZ
UOnEJYD03OnEJYD00ol0003ojAKYonTFj@0?onTFj@05o`000?oa3_7ol@kaoo4>lOl000004Ook1?/0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo`3o000ol0003obSG:olXebP08olXebP03o`000?n9MXWo
RGJ900coRGJ900?o0000ogN8MomgR7L02_mgR7L00ol0003oFZEJoeZUFP0;oeZUFP03o`000?n1OX7o
PGj100WoPGj10_l000000omC[5?o0000oiEZU@08oiEZU@Ko00004ooY5^T01?l0003ol@kaoo4>lOl0
000Aoo/4n`03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008oo0?l003o`000?o:=L[o
bSG:00WobSG:00?o0000ohUfROn9MXT03?n9MXT00ol0003oMhQgogN8M`0:ogN8M`03o`000?mJYE[o
FZEJ00[oFZEJ00?o0000oh5nPOn1OX403?n1OX4;o`0000GofRGJ00?o0000onTFjOoY5^T04_oY5^T0
0ol0003ol@kao`00000@oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on<L
hooS7>?ohacS1Ol00003oo0?l003o`000?o:=L[obSG:00WobSG:00?o0000ohUfROn9MXT02on9MXT0
0ol0003oMhQgogN8M`0<ogN8M`03o`000?mJYE[oFZEJ00WoFZEJ00?o0000oh5nPOn1OX403?n1OX40
0ol0003o[e2_ojm@[`02ojm@[`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000onTFjOoY5^T04_oY5^T3
o`0000oon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on<L
hooS7><01OoS7><3o`0000cobSG:00?o0000ohUfROn9MXT02on9MXT00ol0003oMhQgogN8M`0<ogN8
M`03o`000?mJYE[oFZEJ00SoFZEJ00?o0000oh5nPOn1OX403?n1OX400ol0003o[e2_ojm@[`04ojm@
[`03o`000?oJ9M[ofRGJ00SofRGJ00?o0000onTFjOoY5^T04_oY5^T00ol0003oo@;mood2o@04o`00
00_on`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oS7>?ohacS00OohacS00?o0000olXe
b_o:=LX02_o:=LX00ol0003oRGJ9ohUfR@09ohUfR@;o00003omgR7L00ol0003oFZEJoeZUFP08oeZU
FP03o`000?n1OX7oPGj100coPGj100?o0000ojm@[on_D:l01?n_D:l00ol0003ofRGJomXUfP09omXU
fPCo00003ooY5^T00ol0003oo@;mood2o@05ood2o@Co00001_ok1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on<LhooS7><02?oS7><00ol0003obSG:olXebP09olXebP03o`000?n9MXWoRGJ900Ko
RGJ90ol000000onRGJ;o0000ogN8M`0?ogN8M`03o`000?mJYE[oFZEJ00KoFZEJ00?o0000oh5nPOn1
OX403On1OX400ol0003o[e2_ojm@[`05ojm@[`03o`000?oJ9M[ofRGJ00SofRGJ00Co0000ooD:mOoe
2_Gom@[e1Ol00009onTFj@03o`000?om0_goo@;m00[oo@;m1?l00002oo/4n`03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003ohacSon<Lh`07on<Lh`03o`000?o:=L[obSG:00[obSG:00?o0000ohUfROn9
MXT00_n9MXT3o`0000GoXUfR00?o0000ogN8MomgR7L03OmgR7L00ol0003oFZEJoeZUFP06oeZUFP03
o`000?n1OX7oPGj100coPGj100?o0000ojm@[on_D:l01_n_D:l00ol0003ofRGJomXUfP08omXUfP03
o`000?oe2_Gom@[e00Kom@[e1Ol00003onTFj@03o`000?om0_goo@;m00ooo@;m0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on<LhooS7><01ooS7><00ol0003obSG:olXebP0:olXebP03o`000?n9MXWo000000;o0000
2?nRGJ800ol0003oMhQgogN8M`0=ogN8M`Co00001?mJYEX00ol0003oPGj1oh5nP@0=oh5nP@03o`00
0?n_D:oo[e2_00Oo[e2_00?o0000omXUf_oJ9MX01ooJ9MX00ol0003om@[eooD:m@0;ooD:m@?o0000
4oom0_d00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on<LhooS7><02?oS7><3o`0000WobSG:0_l0
000<oj9MXP03o`000?mgR7OoMhQg00_oMhQg00?o0000oiYUV_nJIIX00_nJIIX3o`000003oeZUF_l0
003oPGj100koPGj100?o0000ojm@[on_D:l01on_D:l00ol0003ofRGJomXUfP06omXUfP03o`000?oe
2_Gom@[e00kom@[e00?o0000ood2oOom0_d04_om0_d00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on<LhooS7><01_oS7><01?l0003oiQWVonHIi_oV6NH3o`0000KobSG:00?o0000oj9MX_nRGJ803?nR
GJ800ol0003oMhQgogN8M`09ogN8M`03o`000?nJII[oVVFJ00KoVVFJ00?o0000oh5nPOn1OX403On1
OX400ol0003o[e2_ojm@[`09ojm@[`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000ooD:mOoe2_D03_oe
2_D00ol0003oo@;mood2o@0Bood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003ohacSon<Lh`05
on<Lh`03o`000?oV6NKoiQWV00GoiQWV0ol00002olXebP03o`000?nRGJ;oXUfR00goXUfR00?o0000
ogN8MomgR7L02?mgR7L00ol0003oVVFJoiYUVP07oiYUVP03o`000?n1OX7oPGj100coPGj10ol0000:
ojm@[`03o`000?oJ9M[ofRGJ00GofRGJ00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0B
ood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003ohacSon<Lh`04on<Lh`03o`000?oV6NKoiQWV
00WoiQWV0_l0000Aoj9MXP03o`000?mgR7OoMhQg00GoMhQg0_l0000;oiYUVP03o`000?n1OX7oPGj1
00[oPGj100Go0000oka3_?nl@kco_4>lo`00000:ojm@[`03o`000?oJ9M[ofRGJ00CofRGJ00?o0000
ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0Cood2o@03o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oS7>?ohacS
00;ohacS00?o0000onHIi_oV6NH02_oV6NH2o`00017oXUfR00?o0000ogN8MomgR7L01?mgR7L00ol0
003oVVFJoiYUVP0<oiYUVP03o`000?n1OX7oPGj100OoPGj10_l00005oka3_0;o00002?n_D:l00ol0
003ofRGJomXUfP04omXUfP03o`000?oe2_Gom@[e00gom@[e00?o0000ood2oOom0_d05?om0_d00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003ohacSon<LhooS7>?o000000coiQWV00Co0000omLX
eooG:=Oo00004OnRGJ800ol0003oMhQgogN8M`02ogN8M`03o`000?nJII[oVVFJ00koVVFJ00?o0000
oh5nPOn1OX401On1OX400ol0003o_4>loka3_007oka3_003o`000?n_D:oo[e2_00Ko[e2_00?o0000
omXUf_oJ9MX00ooJ9MX00ol0003om@[eooD:m@0=ooD:m@03o`000?om0_goo@;m01Coo@;m00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on<LhooS7>?o00003?oV6NH00ol0003oebSGomLXe`02omLXe`03o`000?nRGJ;o
XUfR00ooXUfR00Co0000ogN8MomgR7Oo00004OnJIIX00ol0003oPGj1oh5nP@04oh5nP@03o`000?nl
@kco_4>l00Wo_4>l00?o0000ojm@[on_D:l01On_D:l00ol0003ofRGJomXUfP03omXUfP03o`000?oe
2_Gom@[e00gom@[e00?o0000ood2oOom0_d05Oom0_d00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onHIiP03o`000?oG:=OoebSG00?oebSG00?o0000oj9MX_nRGJ803onRGJ800ol0003oMhQgo`00000C
oiYUVP04o`000?n1OX7oPGj1oh5nP@;o00003Onl@k`2o`0000Ko[e2_00Go0000omXUf_oJ9M[ofRGJ
o`00000@ooD:m@03o`000?om0_goo@;m01Coo@;m0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02_oV
6NH00ol0003oebSGomLXe`05omLXe`03o`000?nRGJ;oXUfR00ooXUfR00?o0000oiYUV_nJIIX04onJ
IIX00ol0003oPGj1o`00000Aoka3_003o`000?n_D:oo[e2_00?o[e2_00Go0000omXUf_oJ9M[ofRGJ
o`00000>ooD:m@?o00005?om0_d2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02OoV
6NH00ol0003oebSGomLXe`07omLXe`03o`000?nRGJ;oXUfR00koXUfR00?o0000oiYUV_nJIIX05?nJ
IIX00ol0003o_4>loka3_00Aoka3_0;o00001?n_D:l01?l0003ofRGJomXUf_l0000:ooD:m@Co0000
0oom0_d00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onHIi_oV6NH02OoV6NH00ol0003oebSGomLXe`08omLXe`03o`000?nRGJ;oXUfR00_oXUfR0ol0
000GoiYUVP03o`000?nl@kco_4>l01?o_4>l00Ko0000ojm@[on_D:oo[e2_o`000?oJ9MX5o`0000Co
m@[e0ol00008ood2o@03o`000?om0_goo@;m00goo@;m0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oV6NKoiQWV00SoiQWV00?o0000omLXeooG:=L02_oG:=L00ol0003oXUfRoj9MXP07oj9MXP?o0000
0_n^DJh00ol0003oVVFJoiYUVP0EoiYUVP;o00005Onl@k`00ol0003o[e2_ojm@[`02o`0000Goka3_
1?l0000<ood2o@03o`000?om0_goo@;m00[oo@;m0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onHIi_oV6NH01ooV
6NH00ol0003oebSGomLXe`0;omLXe`03o`000?nRGJ;oXUfR00CoXUfR0ol00006ojiA[P03o`000?nJ
II[oVVFJ01?oVVFJ00Co0000olPgb?o8=lSo00005Onl@k`2o`0000Woka3_00?o0000ood2oOom0_d0
3?om0_d00ol0003oo@;mood2o@07ood2o@;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiQWV00?o0000omLXeooG:=L03OoG:=L00ol0003oXUfRoj9M
XP03o`0000[o[U6^00?o0000oiYUV_nJIIX04OnJIIX00ol0003ob3O8olPgb002olPgb003o`000?nl
@kco_4>l01;o_4>l00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om
0_goo@;m00Coo@;m0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiQWVonHIiP05onHIiP03o`000?oG:=OoebSG00ooebSG0_l0000>
ojiA[P03o`000?nJII[oVVFJ00ooVVFJ00?o0000olPgb?o8=lP01?o8=lP00ol0003o_4>loka3_00@
oka3_0;o00002oo_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onHIi_oV6NH00ooV6NH00ol0003oebSGomLXe`0@omLXe`03o`000?n^DJko[U6^
00go[U6^00?o0000oiYUV_nJIIX03_nJIIX00ol0003ob3O8olPgb006olPgb0;o00003_nl@k`2o`00
0003omLXeol0003oka3_00[oka3_00?o0000ood2oOom0_d03_om0_d01?l0003oo@;mo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiQWVonHIi_oV6NKo000001;oebSG00?o0000ojiA[_n^DJh03on^DJh00ol0003oVVFJoiYUVP0<
oiYUVP03o`000?o8=lSob3O800Wob3O800?o0000oka3_?nl@k`02Onl@k`2o`0000?oebSG00?o0000
onl@koo_4>l02Oo_4>l00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiQWVo`00000ComLX
e`03o`000?n^DJko[U6^013o[U6^00?o0000oiYUV_nJIIX02_nJIIX00ol0003ob3O8olPgb00;olPg
b003o`000?nl@kco_4>l00Go_4>l0ol00006omLXe`03o`000?o_4>ooka3_00Soka3_00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omLXeooG:=L04OoG:=L00ol0003o[U6^ojiA[P0AojiA[P03o`000?nJII[oVVFJ00Wo
VVFJ00?o0000olPgb?o8=lP03Oo8=lP00ol0003o_4>loka3_002oka3_0;o00002OoG:=L00ol0003o
ka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017oebSG00?o0000ojiA[_n^DJh0
4_n^DJh00ol0003oVVFJoiYUVP07oiYUVP03o`000?o8=lSob3O800oob3O800Co0000oka3_?l0003o
00002ooG:=L00ol0003oka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ojaC[
o`000002o`0000koebSG00?o0000ojiA[_n^DJh04on^DJh00ol0003oVVFJoiYUVP05oiYUVP03o`00
0?o8=lSob3O8017ob3O800?o0000omLXeooG:=L03?oG:=L00ol0003oka3_onl@k`08onl@k`03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o[5>_ojaC[00?ojaC[0_l0000;omLXe`;o00005_n^DJh7o`0001Cob3O800?o
0000omLXeooG:=L03?oG:=L00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ojaC[on/D
j`06on/Dj`?o00002?oG:=L00ol0003obCK9o`000002o`0001;o[U6^00?o0000okU6^OniA[T00_ni
A[T00ol0003o/Djao`00000DolPgb003o`000?oG:=OoebSG00coebSG00?o0000onl@koo_4>l02?o_
4>l00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ojaC[on/Dj`09on/Dj`;o00001OoG:=L00ol0003obCK9olTfb@03
olTfb@;o00003on^DJh00ol0003o^DJiokU6^@03okU6^@04o`000?naC[7o/Djao`0001?ob3O800?o
0000omLXeooG:=L03OoG:=L00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o[5>/3o`000003omLXeol0003o
bCK900OobCK90ol0000;ojiA[P03o`000?niA[Wo^DJi00Co^DJi00Go0000ok5>/OnaC[7o/Djao`00
000BolPgb003o`000?oG:=OoebSG00goebSG00?o0000onl@koo_4>l01oo_4>l?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04?oh1oP0
0ol0003ojaC[on/Dj`0?on/Dj`03o`000?o9=/WobCK900[obCK90_l00008ojiA[P03o`000?niA[Wo
^DJi00Go^DJi00?o0000ok5>/OnaC[400_naC[400ol0003ob3O8olPgb00?olPgb003o`000?oG:=Oo
ebSG00goebSG00?o0000onl@koo_4>l01_o_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oh1oSon0Oh00oon0Oh00?o0000on/Djoo[5>/03oo[5>/00ol0003obCK9olTfb@0<olTf
b@;o00001On^DJh00ol0003o^DJiokU6^@06okU6^@03o`000?naC[7o/Dja00?o/Dja00?o0000olPg
b?o8=lP03_o8=lP00ol0003oebSGomLXe`0>omLXe`03o`000?o_4>ooka3_00Coka3_00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00kon0Oh00?o0000on/Djoo[5>/04?o[5>/00ol0003o
bCK9olTfb@0>olTfb@?o000000?o[U6^o`000?niA[T02?niA[T00ol0003o/Djaok5>/@04ok5>/@03
o`000?o8=lSob3O800gob3O84_l00005onl@k`03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooP7n003o`000?o[5>_ojaC[00oojaC[0_l0000ColTfb@03o`000?niA[Wo^DJi00So^DJi
00?o0000ok5>/OnaC[401OnaC[400ol0003ob3O8olPgb00<olPgb003o`000?ob3O;olPgb00oolPgb
00Go0000onl@koo_4>ooka3_o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n0Oh00?o0000on/Djoo[5>/03_o[5>/00ol0003ohQgRo`00000ColTfb@03o`000?niA[Wo^DJi00So
^DJi00?o0000ok5>/OnaC[401OnaC[400ol0003ob3O8olPgb00;olPgb003o`000?ob3O;olPgb017o
lPgb00?o0000onl@kol000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n0OhooP7n00:ooP7n003o`000?o[5>_ojaC[00gojaC[0_l00003on8MhP03o`000?o9=/WobCK9013o
bCK900?o0000okU6^OniA[T02?niA[T00ol0003o/Djaok5>/@06ok5>/@03o`000?o8=lSob3O800[o
b3O800?o0000oo8=l_ob3O804_ob3O800ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on0OhooP7n009ooP7n003o`000?o[5>_ojaC[00cojaC[00?o0000on8Mh_oR7N80
0ooR7N800ol0003obCK9olTfb@0?olTfb@03o`000?niA[Wo^DJi00Wo^DJi00?o0000ok5>/OnaC[40
1onaC[400ol0003ob3O8olPgb009olPgb003o`000?ob3O;olPgb01;olPgb00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003ojaC[on/D
j`0:on/Dj`;o00001_oR7N800ol0003obCK9olTfb@0?olTfb@03o`000?niA[Wo^DJi00Wo^DJi00?o
0000ok5>/OnaC[402?naC[400ol0003ob3O8olPgb007olPgb003o`000?ob3O;olPgb01?olPgb00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ojaC[on/Dj`09on/Dj`03o`000?oR7N;ohQgR00OohQgR00?o0000olTfbOo9=/T03Oo9=/T2
o`0000_o^DJi00?o0000ok5>/OnaC[402OnaC[400ol0003ob3O8olPgb006olPgb003o`000?ob3O;o
lPgb01?olPgb4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on0OhooP7n006ooP7n003o`000?o[5>_ojaC[00WojaC[00?o0000on8M
h_oR7N802?oR7N800ol0003obCK9olTfb@0;olTfb@;o000000?obCK9o`000?niA[T02_niA[T00ol0
003o/Djaok5>/@09ok5>/@Ko00000oo8=lP00ol0003olPgboo8=lP0Coo8=lP03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooP7n?oh1oP01?oh1oP3o`00
00SojaC[0_l0000;on8MhP03o`000?o9=/WobCK900WobCK90_l00004olTfb@03o`000?niA[Wo^DJi
00So^DJi00?o0000ok5>/OnaC[402?naC[400ol0003ofbCKom/Tf`04om/Tf`?o00005?ob3O83o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on0OhooP7n003o`0000?o
m`Sg00?o0000on/Djoo[5>/01?o[5>/00ol0003ohQgRon8MhP0<on8MhP03o`000?o9=/WobCK900Go
bCK90ol00007olTfb@03o`000?niA[Wo^DJi00Oo^DJi00?o0000ok5>/OnaC[401onaC[400ol0003o
fbCKom/Tf`08om/Tf`03o`000?ob3O;olPgb013olPgb00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ojaC[on/Djoo[5>/2o`0000oohQgR00?o0000olTf
bOo9=/T00oo9=/T2o`0000[obCK900?o0000okU6^OniA[T01oniA[T00ol0003o/Djaok5>/@05ok5>
/@;o00003?oK9=/00ol0003olPgboo8=lP0=oo8=lP;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o[5>_o0000017o
hQgR00Co0000olTfbOo9=/WobCK90_l0000=olTfb@03o`000?niA[Wo^DJi00Ko^DJi00?o0000ok5>
/OnaC[401?naC[400ol0003ofbCKom/Tf`0=om/Tf`Co00002_ob3O800ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on8Mh_oR7N804OoR7N83o`00013obCK900?o0000okU6^OniA[T01OniA[T00ol0003o
/Djaok5>/@03ok5>/@03o`000?oK9=_ofbCK00kofbCK00Co0000ooH9m_of2OKomPWf1_l00003oo8=
lP03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003ohQgRon8MhP0Aon8MhP03o`000?o9=/WobCK9013o
bCK900?o0000okU6^OniA[T01OniA[T00ol0003o/Djaok5>/@02ok5>/@03o`000?oK9=_ofbCK00oo
fbCK00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oR7N;ohQgR013ohQgR00?o0000olTfbOo9=/T0
4Oo9=/T00ol0003o^DJiokU6^@04okU6^@03o`000?naC[7o/Dja00;o00004OoK9=/00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003ohQgRon8MhP0=on8MhP;o00005?o9=/T3o`0000Co^DJi00?o0000ok5>/Ol000004ooK
9=/00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ood2oOom0_d02Oom
0_d00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on8Mh_oR7N802_oR7N83o`000003on<Lhol0003obCK9017obCK90_l00003om@[e0;o00000_niA[T2
o`0001CofbCK00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?om0_go
o@;m00[oo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oR7N;ohQgR00KohQgR0ol00005on<L
h`03o`000?o9=/WobCK900gobCK90_l00007om@[e0?o00005OoK9=/00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ood2oOom0_d03?om0_d3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on8Mh_oR7N801?oR7N82o`0000WohacS00?o0000olTfbOo9=/T02_o9=/T2o`0000_o
e2_D00?o0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ood2oOom0_d03?om0_d00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on8Mh_oR7N800ol0000<on<Lh`03o`00
0?o9=/WobCK900OobCK90_l0000=om@[e003o`000?oK9=_ofbCK01;ofbCK00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?om0_goo@;m00_oo@;m00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000oohacS00?o0000olTfbOo9=/T01Oo9=/T2o`0000ooe2_D00?o
0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013ohacS00?o0000olTfbOo9=/T00_o9=/T2o`0001;oe2_D00?o0000om/TfooK9=/04OoK9=/0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ood2oOom0_d02Oom0_d0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003olPgboo8=l_l0000@on<Lh`04o`000?o9=/Wo
0000o`0001Coe2_D00?o0000om/TfooK9=/04?oK9=/00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ood2oOom0_d02Oom0_d00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo8=l_ob3O800_ob3O800ol0003ohacSon<Lh`0>on<Lh`03o`000?oD:mCoe2_D01Coe2_D00?o0000
om/TfooK9=/03OoK9=/4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;mood2o@09
ood2o@03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003olPgboo8=lP03oo8=lP03o`000?oS7>?ohacS
00gohacS00?o0000om@[e?oD:m@05?oD:m@00ol0003ofbCKom/Tf`07om/Tf`Ko00000oo]4^d00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ood2oOom0_d02?om0_d00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo8=l_ob3O801Oob3O800ol0003ohacSon<Lh`0<on<Lh`03
o`000?oD:mCoe2_D01Goe2_D00?o0000om/TfooK9=/01_l0000:ondBk@03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003oo@;mood2o@07ood2o@03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003olPgboo8=lP06oo8=lP03o`000?oS7>?ohacS00_ohacS00?o0000om@[e?oD:m@0
5OoD:m@3o`00017okA;]00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?om0_goo@;m00Koo@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo8=l_ob3O802?ob3O800ol0003ohacSon<L
h`0:on<Lh`03o`000?oD:mCoe2_D01Goe2_D00?o0000ondBkOo]4^d04Oo]4^d00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ood2oOom0_d01oom0_d00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo8=lP03o`000?oS7>?ohacS00WohacS00?o0000om@[e?oD:m@05?oD:m@0
0ol0003okA;]ondBk@0CondBk@03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ood2o@03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_olPgb00?o0000on<LhooS7><02OoS7><0
0ol0003oe2_Dom@[e00Com@[e003o`000?o]4^gokA;]01CokA;]1?l0000:ooH9mPCo00001_on0Oh2
o`0000Coo@;m00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?ob3O800ol0003ohacSon<Lh`08on<L
h`03o`000?oD:mCoe2_D00ooe2_D1?l0000GondBk@04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?oo@;mo`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?of2OKomPWf
00?o00002_ob3O800ol0003ohacSon<Lh`07on<Lh`03o`000?oD:mCoe2_D00Soe2_D1ol00003onXE
jP03o`000?o]4^gokA;]01CokA;]00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?of2OKomPWf00?omPWf0ol00008oo8=lP03o`000?oS7>?ohacS00Ko
hacS00Co0000om@[e?oD:mCoe2_D1ol0000:onXEjP03o`000?o]4^gokA;]01CokA;]00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooH9m_of2OH01_of2OH3o`0000KolPgb00?o0000on<LhooS7><01?oS7><5o`0001;o
jQGZ00?o0000ondBkOo]4^d04_o]4^d00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003omPWfooH9mP09ooH9mP?o00001?ob3O800ol0003ohacS
on<Lh`03o`000003ooL8mol0003ojQGZ01CojQGZ00?o0000ondBkOo]4^d04_o]4^d00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003omPWfooH9
mP0<ooH9mP?o000000ColPgbo`000?l0003o00001?og2?L00ol0003ojQGZonXEjP0BonXEjP;o0000
4oo]4^d00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?of2OKomPWf00oomPWf00?o0000ooL8moog2?L01_og2?L00ol0003ojQGZonXE
jP0@onXEjP04o`000?o]4^gokA;]o`0001;okA;]00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?of2OKomPWf00oomPWf00?o0000ooL8moog2?L01_og
2?L00ol0003ojQGZonXEjP0?onXEjP03o`000?o]4^gokA;]00;okA;]00?o0000ondBkOo]4^d03_o]
4^d00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooH9m_of2OH03_of2OH00ol0003om`SgooL8m`07ooL8m`03o`000?oZ5N[o
jQGZ00kojQGZ00?o0000ondBkOo]4^d01?o]4^d2o`0000kokA;]00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?of2OKomPWf
00gomPWf00?o0000ooL8moog2?L02?og2?L00ol0003ojQGZonXEjP0=onXEjP03o`000?o]4^gokA;]
00GokA;]00?o0000ooP7n?l000000_l0000:ondBk@03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooH9m_of2OH03?of2OH00ol0003o
m`SgooL8m`0:ooL8m`03o`000?oZ5N[ojQGZ00_ojQGZ00?o0000ondBkOo]4^d01_o]4^d00ol0003o
n0OhooP7n002ooP7n0?o00001oo]4^d00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooH9mP03o`000?og2?Oom`Sg00_om`Sg00?o0000onXEj_oZ5NX0
2_oZ5NX00ol0003okA;]ondBk@06ondBk@03o`000?oh1oSon0Oh00Kon0Oh0_l00004ondBk@03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?om0_goo@;m00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?omPWf00?o0000ooL8moog2?L03?og2?L00ol0003ojQGZ
onXEjP09onXEjP03o`000?o]4^gokA;]00OokA;]00?o0000ooP7n?oh1oP02?oh1oP3o`000003ondB
kOl0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00Coo@;m0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooL8m`03o`000?oZ5N[ojQGZ00SojQGZ00?o
0000ondBkOo]4^d02?o]4^d00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003om`SgooL8m`0=ooL8m`03o`000?oZ5N[ojQGZ00OojQGZ00?o0000ondBkOo]4^d02?o]4^d0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?om0_goo@;m00coo@;m0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooL8
moog2?L03_og2?L00ol0003ojQGZonXEjP05onXEjP03o`000?o]4^gokA;]00WokA;]00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
o@;mood2o@0?ood2o@;o00003ool0o`00ol0003om`SgooL8m`0=ooL8m`03o`000?oZ5N[ojQGZ00Co
jQGZ00?o0000ondBkOo]4^d02_o]4^d00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo@;mood2o@0Aood2o@03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L03Oog2?L00ol0003ojQGZonXEjP03onXEjP03o`00
0?o]4^gokA;]00[okA;]00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cood2o@03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L03Oog2?L00ol0003ojQGZonXE
jP02onXEjP03o`000?o]4^gokA;]00_okA;]00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aood2o@03o`000?ol
0ocoo0?l00koo0?l00?o0000ooL8moog2?L03Oog2?L01?l0003ojQGZonXEj_l0000>ondBk@03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000ooo@;m00?o
0000oo`3o?ol0o`03_ol0o`00ol0003om`SgooL8m`0=ooL8m`Go00003?o]4^d00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oom0_d0
0ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00gom`Sg00?o0000ooP7n?oh1oP00_oh1oP3
o`0000WokA;]00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?og2?Oom`Sg00_om`Sg00?o0000ooP7
n?oh1oP01_oh1oP4o`0000GokA;]00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003oo@;mood2o@08ood2o@03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooL8moog2?L02_og2?L00ol0003on0OhooP7n00;ooP7n0?o000000?okA;]o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oom0_d3o`00013oo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ood2o@04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003om`SgooL8m`06ooL8m`;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?oo@;mo`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooL8moog2?L0
1?og2?L2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooL8moog2?L00oog2?L00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003om`SgooL8m`02o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00[o
003o2Oooo`04o`00o`03oc8bc?nYZEGok^h@00?oool000CogMdQojVYEOmVIYSo413^2_l00?l01omg
MhOogMdQoooo0?ooo`3ogMdQohN7Mol@4>h02_l00?l2oooo09Wo003o0Oooool009go003o00?oV9QV
oooo0?mgMhL01ol00?l00onHV6Koool0ogMgQ`0<o`00o`;oool02ol00?l00olQ8MgoV9QVoooo0002
oooo0003oeEEZOl00?oo003o00Co003o1?ooo`001onj^TCo8B7Mo`00oolb</coZJUEoooo0?mgMhL0
1ol00?l02_l@4>kogMdQoooo0?mgMhOo413^o`00oomEEJWoool0omgM8Ol@4>h9o`00o`;oool0VOl0
0?l1ooooo`00WOl00?l00oo^kQ3oool0omgM8@07o`00o`03onk^4?ooo`3ogMdQ00co003o0_ooo`0=
o`00o`?oool01ol00?l01?nj^TCoool0olc<<_m4A;X5o`00o`03ofIVV?ooo`3oZJUE00Ko003o00?o
gMdQoooo0?mgMhL01?l00?l00om4A;[oool0omgM8@09o`00o`;oool0VOl00?l1ooooo`00W?l00?l0
1Olb</coool0oooo0?ooo`3o413^00Go003o00Go<S;<oooo0?ooo`3oool0ob4Qg@0;o`00o`;oool0
3Ol00?l3oooo017o003o00?oZJUEoooo0?nYZED01?l00?l00on7QgOoool0oooo0006o`00o`03omgM
8Oooo`3oIVJH00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`05ojVYEOooo`3oool0oooo0?mVIYP0
1Ol00?l01OnHV6Koool0oooo0?ooo`3oMgN700_o003o0_ooo`0=o`00o`?oool04Ol00?l01?lb</co
ool0oooo0?m4A;X3o`00o`;oool000?oV9QVo`00ool00?l01?l00?l00on7QgOoool0onk^4008o`00
o`;oool0VOl00?l1ooooo`00W?l00?l3oooo0003ofIVV?nj^TCo003o00Co003o00Gok^h@oooo0?oo
o`3oIVJHomgM8@0;o`00o`;oool03Ol00?l3oooo01;o003o0_ooo`001?nj^TCo003oo`00oomEEJT2
oooo0003ofIVV?l00?oo003o00Co003o00CoEEFYoooo0?ooo`3o<S;<1ol00?l2oooo09Wo003o0Ooo
ool009_o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o413^00?o003o00OoEEFYoooo0?ooo`3o
k^h@o`00ooo^kQ3o8B7M00[o003o0_ooo`0=o`00o`?oool04_l00?l3oooo00;o003o00CoV9QVoooo
0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?n7QgL7o`00o`;oool0VOl00?l1ooooo`00Vol00?l0
1onYZEGoool0oooo0?nHV6Ko003ooiRHI_mVIYP00ol00?l01onYZEGoool0oooo0?nHV6Ko003ooiRH
I_mgMhL02_l00?l2oooo00go003o0oooo`0Ao`00o`04oeEEZOooo`3oool0oooo00;o003o00Coc<`b
oooo0?ooo`3o413^1ol00?l2oooo0003olc<<_l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002K
o`00o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l00?ooA4BjomgM8@[o003o
0_ooo`0=o`00o`?oool04Ol00?l01?nj^TCoool0oooo0?ooo`02o`00o`?oool02?l00?l2oooo0003
onk^4?l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Jo`00o`04oeEEZOooo`3oool0omgM8@?o
003o00Coool0o`00ool00?ooEEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0ob4Qg@Wo003o0_oo
o`0=o`00o`?oool04?l00?l01OnYZEGoool0oooo0?ooo`3oZJUE00;o003o0oooo`08o`00o`?oool0
1ol00?l2oooo09Wo003o0Oooool009[o003o00CoZJUEoooo0?ooo`3oMgN70ol00?l01?nYZEGoEEFY
o`00oonYZED2oooo0006oiRHI_l00?oo003oo`00oonYZEGoMgN72Ol00?l2oooo00go003o0oooo`0>
o`00o`03oc8bc?o<c3;oool000?oool000?o8B7Mo`00ool00?l00oooo`08o`00o`?oool01ol00?l2
oooo09Wo003o0Oooool009[o003o0oooo`001olQ8Mgo003oo`00ool00?ooEEFYojVYEOl00?l00ooo
o`001_lb</co003oo`00ool00?ooEEFYomgM8@Wo003o0_ooo`0=o`00o`?oool02ol00?l00om4A;[o
MgN7omgM8@05oooo0004ofIVV?l00?oo003oo`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00
o`7ooooo002Io`00o`04oeEEZOooo`3oool0omgM8@Go003o00Gok^h@oeEEZOooo`3oool0onk^4005
o`00o`03oooo0?lQ8Mgo003o00Oo003o0_ooo`0=o`00o`?oool02?l00?l00olb</coool0oooo0007
oooo0003ofIVV?l00?oo003o00;o003o0oooo`08o`00o`?oool01ol00?l2oooo09Wo003o0Oooool0
09Wo003o00CoZJUEoooo0?ooo`3oMgN71Ol00?l01Onj^TCok^h@oooo0?ooo`3oQhMg00Go003o00?o
ZJUEogMgQol00?l01ol00?l2oooo00go003o0oooo`08o`00o`03ob4QgOooo`3oool000Goool000?o
ZJUEob4QgOl00?l01?l00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<POo
003o0_ooo`2Io`00o`7ooooo002Ho`00o`05oa0@k_ooo`3oool0oooo0?lQ8Md01Ol00?l01OmVIYSo
ool0oooo0?ooo`3o8B7M00Go003o00?oEEFYomgM8Ol00?l01ol00?l2oooo00go003o0oooo`09o`00
o`07ojVYEOooo`3ok^h@olc<<_n7QgOoEEFYoa0@kP07o`00o`04oiRHI_ooo`3oool0odA4^PKo003o
00CoA4Bjoooo0?ooo`3oV9QV1ol00?l2oooo09Wo003o0Oooool009So003o00CoIVJHoooo0?ooo`3o
gMdQ1_l00?l01?mVIYSoool0oooo0?oMgB47o`00o`03oooo0?lQ8Mgo003o00Ko003o0_ooo`0=o`00
o`?oool02Ol00?l00olQ8Mgok^h@o`00o`0;o`00o`04oeEEZOooo`3oool0ogMgQ`Ko003o00CoIVJH
oooo0?ooo`3oEEFY1ol00?l2oooo09Wo003o0Oooool009So003o00Coc<`boooo0?ooo`3oMgN71_l0
0?l01?nj^TCoool0oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`0=o`00o`?oool0
2_l00?l00oo<c3;oEEFYo`00o`0;o`00o`;oool000?oZJUEo`00ool00?l01?l00?l00onYZEGoool0
onk^4008o`00o`;oool0VOl00?l1ooooo`00Uol00?l01OlQ8Mgoool0oooo0?ooo`3o8B7M00Go003o
00Go413^oooo0?ooo`3oool0ob4Qg@07o`00o`03oeEEZOoMgB7o003o00Ko003o0_ooo`0:o`00o`03
olc<<_mVIYSoMgN700?oool02_l00?l00om4A;[oc<`bo`00o`0;o`00o`04ohN7Moooo`3oool0oa0@
kPCo003o00Co413^oooo0?ooo`3oIVJH2?l00?l2oooo09Wo003o0Oooool009Oo003o00CoZJUEoooo
0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oMgB49o`00o`03oooo0?lQ8Mgo003o00Go003o0_oo
o`0:o`00o`03odA4^_o<c3;oool000?oool02ol00?l00oo<c3;oool0oooo0005oooo0003olc<<_l0
0?oo003o00?o003o00?ogMdQoooo0?n7QgL01?l00?l00on7QgOoool0olc<<P09o`00o`;oool0VOl0
0?l1ooooo`00UOl00?l00olQ8MgoQhMgoooo0002oooo0003onk^4?lb</co003o00?o003o00KoEEFY
oooo0?ooo`3oool0onk^4?lb</`6o`00o`06ob4QgOn7QgOoool0onk^4?mEEJWo413^1?l00?l2oooo
00co003o00CoA4Bjonk^4?ooo`3oool02ol00?l00omVIYSoool0oooo0006oooo0003ob4QgOl00?oo
003o00;o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOoool0omgM8Ol@4>h9o`00o`;oool0
VOl00?l1ooooo`00U?l00?l00om4A;[oool0oooo0007oooo0003ohN7Moooo`3oool000Ooool00_l0
0?l00on7QgOoool0oooo0005oooo0004odA4^_l00?oo003oo`00o`;oool000?oMgN7o`00ool00?l0
2ol00?l00omVIYSok^h@o`00o`0;o`00o`03onk^4?ooo`3oool000Goool000?oMgN7o`00ool00?l0
0ol00?l00ol@4>koQhMgomgM8@02oooo0003omgM8On7QgOo003o00Wo003o00?oMgN7oooo0?ooo`00
VOl00?l1ooooo`00]_l00?l7oooo01ko003o00?oMgN7omgM8Ol00?l04Ol00?l7oooo09Wo003o0Ooo
ool00=co003o00?o8B7Mo`00ool00?l0/?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(175) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.984 .016 .984 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.962 .038 .962 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.896 .104 .896 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.904 .096 .904 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.972 .028 .972 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.922 .078 .922 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.901 .099 .901 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.815 .185 .815 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.894 .106 .894 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.933 .067 .933 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.826 .174 .826 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.939 .061 .939 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.541 .459 .541 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.513 .487 .513 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.729 .271 .729 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.905 .095 .905 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.923 .077 .923 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.629 .371 .629 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.57 .43 .57 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.793 .207 .793 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.892 .108 .892 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.983 .017 .983 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.849 .151 .849 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.948 .052 .948 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.491 .509 .491 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.957 .043 .957 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.895 .105 .895 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.188 .812 .188 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.519 .481 .519 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.302 .698 .302 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.202 .798 .202 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.673 .327 .673 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.178 .822 .178 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.521 .479 .521 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.936 .064 .936 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.64 .36 .64 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.803 .197 .803 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.258 .742 .258 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.124 .876 .124 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.248 .752 .248 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.086 .914 .086 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.696 .304 .696 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.803 .197 .803 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.845 .155 .845 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.848 .152 .848 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.115 .885 .115 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.078 .922 .078 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.07 .93 .07 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.302 .698 .302 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.444 .556 .444 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.921 .079 .921 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.971 .029 .971 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.589 .411 .589 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.113 .887 .113 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.933 .067 .933 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.236 .764 .236 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.741 .259 .741 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.133 .867 .133 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.598 .402 .598 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.966 .034 .966 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.71 .29 .71 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.29 .71 .29 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.978 .022 .978 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.302 .698 .302 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.065 .935 .065 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.049 .951 .049 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.866 .134 .866 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.809 .191 .809 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.085 .915 .085 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.444 .556 .444 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.79 .21 .79 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.93 .07 .93 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.058 .942 .058 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.047 .953 .047 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.219 .781 .219 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.221 .779 .221 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.726 .274 .726 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.504 .496 .504 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.184 .816 .184 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.098 .902 .098 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.984 .016 .984 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.963 .037 .963 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.053 .947 .053 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.622 .378 .622 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.845 .155 .845 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.947 .053 .947 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.445 .555 .445 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.829 .171 .829 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.136 .864 .136 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.98 .02 .98 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.935 .065 .935 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.182 .818 .182 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.522 .478 .522 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.65 .35 .65 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.959 .041 .959 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.926 .074 .926 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.899 .101 .899 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.759 .241 .759 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.992 .008 .992 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.986 .014 .986 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.852 .148 .852 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.914 .086 .914 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.826 .174 .826 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.938 .062 .938 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.989 .011 .989 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.922 .078 .922 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.981 .019 .981 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.96 .04 .96 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.981 .019 .981 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.976 .024 .976 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.988 .012 .988 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo/4nol000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003on`Ckoo/4nook1?_o
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/01?ok1?/0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ok1?_on`Ck00Ko
n`Ck00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo/4nook1?/02?ok1?/00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003on`Ckoo/4
n`09oo/4n`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ok1?_o
n`Ck00_on`Ck00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000oog2?L00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ok1?_on`Ck00con`Ck00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooL8m`;o00003oon0Oh00ol0003on`Ckoo/4n`0>oo/4n`03
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooL8m`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/03ook1?/00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Oog
2?L2o`0000_ooP7n00?o0000oo/4nook1?/04Ook1?/00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;om`Sg00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Boo/4n`03o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooL8m`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?og2?L2o`0000KooP7n00?o0000oo/4
nook1?/05Ook1?/00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_og2?L00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_o
n`Ck01Kon`Ck00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom0_do`000?o_4>oo0000omTVfOl0000JooL8m`;o00000_on0Oh00ol0003on`Ck
oo/4n`0Hoo/4n`03o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om0_d00Co0000onl@koo_4>oo00000_oI9]T00ol0003om`SgooL8m`0IooL8
m`03o`000?on0Oko000001_on`Ck00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005oo@;m005o`000?o_4>ooka3_onl@
kol000000ooI9]T00ol0003om`SgooL8m`0IooL8m`03o`000?ok1?_on`Ck01[on`Ck00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?od2o@01Ol0003oka3_onl@koo_4>oo000000CofBKI00?o0000ooL8
moog2?L06?og2?L00ol0003on`Ckoo/4n`0Ioo/4n`03o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om0_d00?o0000onl@koo_
4>l00_o_4>l00ol0003ofBKIomTVf@03omTVf@03o`000?og2?Oom`Sg01Oom`Sg00?o0000oo/4nook
1?/06Ook1?/00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ood2o@00ol0003oka3_onl@k`02onl@k`03o`000?oI9]WofBKI00Co
fBKI00?o0000ooL8moog2?L05oog2?L00ol0003on`Ckoo/4n`0Hoo/4n`03o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?oo@;m003o`00
0?o_4>ooka3_00?oka3_00?o0000omTVfOoI9]T01OoI9]T00ol0003om`SgooL8m`0FooL8m`03o`00
0?ok1?_on`Ck01Oon`Ck00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000Aoo@;m003o`000?o_4>ooka3_00Coka3_00?o0000omTVfOoI9]T01_oI
9]T2o`0001Gom`Sg0ol0000Hoo/4n`03o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
oo@;m003o`000?o_4>ooka3_00Coka3_00?o0000omTVfOoI9]T02?oI9]T00ol0003om`SgooL8m`0@
ooL8m`;o00000oo?<<l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000oo@;m?od2o@04_od2o@00ol0003oka3_onl@k`05onl@k`03o`000?oI9]WofBKI
00WofBKI00?o0000ooL8moog2?L03Oog2?L2o`0000Kocc3?0_l0000Doo/4n`03o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?od2oCom0_d01;om0_d00?o0000onl@koo_
4>l01Oo_4>l00ol0003ofBKIomTVf@0:omTVf@03o`000?og2?Oom`Sg00[om`Sg0_l0000:oll`c`03
o`000?ok1?_on`Ck017on`Ck00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om0_doo@;m00@oo@;m003o`000?o_4>ooka3_00Ko
ka3_00?o0000omTVfOoI9]T02ooI9]T00ol0003om`SgooL8m`08ooL8m`03o`000?o?<<oocc3?00_o
cc3?0_l0000@oo/4n`03o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?od2oCom0_d00oom0_d00?o0000onl@koo_4>l0
1oo_4>l00ol0003ofBKIomTVf@0<omTVf@03o`000?og2?Oom`Sg00Gom`Sg0_l0000@oll`c`03o`00
0?ok1?_on`Ck00gon`Ck00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?od2oCom0_d00oom0_d00?o0000onl@koo_4>l01oo_4>l00ol0003ofBKIomTV
f@0=omTVf@03o`000?og2?Oom`Sg00;om`Sg0_l0000Coll`c`;o00003?ok1?/00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?od2oCo
m0_d00kom0_d00?o0000onl@koo_4>l02?o_4>l00ol0003ofBKIomTVf@0>omTVf@04o`000?og2?Oo
0000o`0001Oocc3?00?o0000oo/4nook1?/02Ook1?/00ol0003oo0?loo`3o00Loo`3o003o`000?oi
1_Won@Ki00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?od2oCo
m0_d00com0_d00?o0000onl@koo_4>l02Oo_4>l00ol0003ofBKIomTVf@0?omTVf@03o`000?o?<<oo
cc3?01Socc3?0_l00009oo/4n`03o`000?ol0ocoo0?l01_oo0?l00?o0000ooT6nOoi1_T01?oi1_T4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>oo@;m003o`000?o_4>ooka3_
00Woka3_00?o0000omTVfOoI9]T03ooI9]T00ol0003occ3?oll`c`0Joll`c`03o`000?ok1?_on`Ck
00Con`Ck0ol0000Loo`3o003o`000?oi1_Won@Ki00Won@Ki0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o^4NkokQ7^o`0000com0_d00?o0000onl@koo_4>l02_o_4>l00ol0003ofBKIomTVf@0?omTV
f@03o`000?o?<<oocc3?01_occ3?0_l00003oo/4n`04o`000?o]4^gokA;]ondBk@?o00006?ol0o`0
0ol0003on@KiooT6n@0=ooT6n@?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o^4NkokQ7^
00;okQ7^00?o0000oo@;m?od2o@02Ood2o@00ol0003oka3_onl@k`0:onl@k`03o`000?oI9]WofBKI
00kofBKI00?o0000oll`coo?<<l07_o?<<l00ol0003on`Cko`000007ondBk@?o00005?ol0o`00ol0
003on@KiooT6n@0AooT6n@;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o^4Nh00ol0003om0_doo@;m007oo@;m003
o`000?o_4>ooka3_00_oka3_00?o0000omTVfOoI9]T03_oI9]T00ol0003occ3?oll`c`0Ooll`c`03
o`000?o]4^gokA;]00WokA;]0ol0000@oo`3o003o`000?oi1_Won@Ki01?on@Ki00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003okQ7^
onhAkP07onhAkP03o`000?od2oCom0_d00Gom0_d00?o0000onl@koo_4>l03?o_4>l00ol0003ofBKI
omTVf@0>omTVf@03o`000?o?<<oocc3?01oocc3?00?o0000ondBkOo]4^d03?o]4^d3o`0000goo0?l
00?o0000ooT6nOoi1_T05?oi1_T00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_okQ7^00?o0000oo@;m?od2o@01?od
2o@00ol0003oka3_onl@k`0<onl@k`03o`000?oI9]WofBKI00kofBKI00?o0000oll`coo?<<l07_o?
<<l00ol0003okA;]ondBk@0@ondBk@?o00002Ool0o`00ol0003on@KiooT6n@0FooT6n@Oo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000onhAk_o^4Nh03?o^4Nh00ol0003om0_doo@;m002oo@;m003o`000?o_
4>ooka3_00goka3_00?o0000omTVfOoI9]T03_oI9]T00ol0003occ3?oll`c`0Noll`c`03o`000?o]
4^gokA;]01?okA;]0ol00005oo`3o003o`000?oi1_Won@Ki01Oon@Ki00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o^4NkokQ7^00kokQ7^00Go0000
oo@;m?od2oCom0_do`00000?onl@k`03o`000?oI9]WofBKI00gofBKI00?o0000oll`coo?<<l07oo?
<<l00ol0003okA;]ondBk@0FondBk@?o000000?oo0?lo`000?oi1_T06?oi1_T00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000BonhAkP03o`000?od2oCo0000013oka3_00?o0000omTVfOoI9]T02ooI9]T3
o`00023occ3?00?o0000ondBkOo]4^d06_o]4^d00ol0003on@KiooT6n@0HooT6n@03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o^4NkokQ7^01?okQ7^00?o0000onl@
koo_4>l03oo_4>l00ol0003ofBKIomTVf@07omTVf@Co00000_nFJIH00ol0003occ3?oll`c`0Noll`
c`03o`000?o]4^gokA;]01[okA;]00?o0000ooT6nOoi1_T05ooi1_T00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
kQ7^00?o0000onl@koo_4>l03oo_4>l00ol0003ofBKIomTVf@03omTVf@Co00001onFJIH00ol0003o
cc3?oll`c`0Loll`c`03o`000?o]4^gokA;]01cokA;]00?o0000ooT6nOoi1_T05Ooi1_T00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000onhAk_o^4Nh05oo^4Nh00ol0003oka3_onl@k`0>onl@k`03o`00
0?oI9]Wo000000?o00003?nFJIH00ol0003occ3?oll`c`0Koll`c`03o`000?o]4^gokA;]01cokA;]
00?o0000ooT6nOoi1_T05Ooi1_T00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o^
4Nh5o`0000_oka3_0ol0000AoiIYUP03o`000?o?<<oocc3?01[occ3?00?o0000ondBkOo]4^d07Oo]
4^d00ol0003on@KiooT6n@0CooT6n@03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o^4NkokQ7^01WokQ7^00?o0000
ojaC[?n/Dj`00_n/Dj`7o`0000?oka3_00?o0000oiIYU_nFJIH04onFJIH3o`0001Oocc3?0_l0000P
ondBk@03o`000?oi1_Won@Ki01?on@Ki00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000onhAk_o^4Nh06?o^4Nh00ol0
003o[5>/ojaC[00:ojaC[0?o00005_nFJIH00ol0003oCK9=odfbC@05o`00013occ3?0_l000000on1
OX7o0000ondBk@0OondBk@03o`000?oi1_Won@Ki01;on@Ki00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000onhAk_o^4Nh05_o^4Nh00ol0003o[5>/ojaC[00=ojaC[003
o`000?nFJIKoUVVF01?oUVVF00?o0000odfbCOm=/Td01_m=/Td4o`0000_occ3?00?o0000oh5nPOn1
OX400_n1OX400ol0003okA;]ondBk@0NondBk@03o`000?oi1_Won@Ki013on@Ki00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003okQ7^onhAkP0DonhAkP03o`000?n/Djco[5>/00oo[5>/
00?o0000oiIYU_nFJIH04_nFJIH00ol0003oCK9=odfbC@0:odfbC@Go00001?o?<<l2o`0000GoPGj1
00?o0000ondBkOo]4^d07_o]4^d00ol0003on@KiooT6n@0@ooT6n@03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o^
4NkokQ7^01CokQ7^00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oUVVFoiIYUP0BoiIYUP03o`000?m=
/TgoCK9=00ooCK9=1?l00008oh5nP@03o`000?o]4^gokA;]01kokA;]00?o0000ooT6nOoi1_T03_oi
1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
onhAk_o^4Nh04_o^4Nh00ol0003o[5>/ojaC[00@ojaC[003o`000?nFJIKoUVVF017oUVVF00?o0000
odfbCOm=/Td04Om=/Td00ol0003o><Lho`000009oh5nP@03o`000?o]4^gokA;]01gokA;]00?o0000
ooT6nOoi1_T03_oi1_T00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000onhAk_o^4Nh03_o^4Nh3o`0001Co[5>/00?o0000oiIYU_nFJIH04?nFJIH00ol0
003oCK9=odfbC@0@odfbC@04o`000?lhacSo><Lho`0000WoPGj100?o0000ondBkOo]4^d07_o]4^d0
0ol0003on@KiooT6n@0<ooT6n@03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000onhAk_o^4Nh02_o^4Nh4o`0000;o^TFj00?o0000ojaC
[?n/Dj`04_n/Dj`00ol0003oUVVFoiIYUP0@oiIYUP03o`000?m=/TgoCK9=00ooCK9=00Go0000ocS7
>?lhacSo><Lho`00000:oh5nP@03o`000?o]4^gokA;]01gokA;]00?o0000ooT6nOoi1_T02ooi1_T0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000onhA
k_o^4Nh01Oo^4Nh4o`0000Oo^TFj00?o0000ojaC[?n/Dj`04On/Dj`00ol0003oUVVFoiIYUP0?oiIY
UP03o`000?m=/TgoCK9=013oCK9=00Go0000ocS7>?lhacSo><Lho`00000:oh5nP@03o`000?o]4^go
kA;]01gokA;]00?o0000ooT6nOoi1_T02ooi1_T00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o^4Nko
kQ7^00Co00002onjAKX00ol0003o[5>/ojaC[00BojaC[003o`000?nFJIKoUVVF00koUVVF00?o0000
odfbCOm=/Td03om=/Td00ol0003o><LhocS7>002ocS7>003o`000?n1OX7oPGj100WoPGj100?o0000
ondBkOo]4^d07?o]4^d3o`0000[on@Ki00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000on`Ck?l0003o00003onjAKX00ol0003o[5>/ojaC[00AojaC[003o`000?m2
_D;o000000ooUVVF00?o0000odfbCOm=/Td03_m=/Td00ol0003o><LhocS7>003ocS7>003o`000?n1
OX7oPGj100WoPGj100?o0000ondBkOo]4^d06Oo]4^d3o`0000?ojAKY00?o0000ooT6nOoi1_T01ooi
1_T00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o/4ncok1?/o`00017o^TFj00?o
0000ojaC[?n/Dj`03on/Dj`01Ol0003o@[e2od:m@_m2_D;o000000[oUVVF1?l0000AodfbC@03o`00
0?lhacSo><Lh00?o><Lh00?o0000oh5nPOn1OX402_n1OX400ol0003okA;]ondBk@0FondBk@;o0000
1ooY5^T00ol0003on@KiooT6n@05ooT6n@03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003ok1?/on`Ck002on`Ck003o`000?njAK[o^TFj00ko^TFj00?o
0000ojaC[?n/Dj`03_n/Dj`00ol0003o@[e2od:m@P03od:m@P04o`000?nFJIKoUVVFoiIYUPKo0000
0oll`c`00ol0003oCK9=odfbC@0>odfbC@03o`000?lhacSo><Lh00Co><Lh00?o0000oh5nPOn1OX40
2_n1OX400ol0003okA;]ondBk@0CondBk@?o00002_oY5^T00ol0003on@KiooT6n@03ooT6n@03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o/
4ncok1?/00?ok1?/00?o0000okY5^_njAKX03_njAKX00ol0003o[5>/ojaC[00=ojaC[003o`000?m2
_D;o@[e200Go@[e20ol0000:occ3?003o`000?m=/TgoCK9=00coCK9=00?o0000ocS7>?lhacP01Olh
acP00ol0003oPGj1oh5nP@0;oh5nP@03o`000?o]4^gokA;]013okA;]0_l0000>onTFj@03o`000?oi
1_Won@Ki00;on@Ki00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o/4ncok1?/00Cok1?/00?o0000okY5^_njAKX03onjAKX00ol0003o[5>/ojaC[00;
ojaC[003o`000?m2_D;o@[e200Ko@[e200?o0000occ3??ll`c`02oll`c`00ol0003oCK9=odfbC@0;
odfbC@03o`000?lhacSo><Lh00Go><Lh00?o0000oh5nPOn1OX403?n1OX400ol0003okA;]ondBk@0<
ondBk@?o00004OoY5^T5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o/4ncok1?/
00Kok1?/00?o0000okY5^_njAKX03_njAKX00ol0003o[5>/ojaC[00:ojaC[003o`000?m2_D;o@[e2
00Oo@[e200?o0000occ3??ll`c`02oll`c`00ol0003oCK9=odfbC@0:odfbC@03o`000?lhacSo><Lh
00Ko><Lh00?o0000oh5nPOn1OX403?n1OX400ol0003okA;]ondBk@0:ondBk@;o00005?oY5^T00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003ok1?/on`Ck007on`C
k003o`000?njAK[o^TFj00ko^TFj00?o0000ojaC[?n/Dj`02On/Dj`00ol0003o@[e2od:m@P08od:m
@P03o`000?ll`cco?<<l00co?<<l00?o0000odfbCOm=/Td02?m=/Td00ol0003o><LhocS7>007ocS7
>003o`000?n1OX7oPGj100goPGj11Ol00004ondBk@?o00005OoY5^T00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003ok1?/on`Ck008on`C
k003o`000?njAK[o^TFj00oo^TFj00?o0000ojaC[?n/Dj`01on/Dj`00ol0003o@[e2od:m@P09od:m
@P03o`000?ll`cco?<<l00co?<<l0ol00008odfbC@03o`000?lhacSo><Lh00Oo><Lh00?o0000oh5n
POn1OX403On1OX400ol0003oYUVVojIIYP02ojIIYPCo00006?oY5^T00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o/4ncok1?/
00[ok1?/00?o0000okY5^_njAKX03_njAKX00ol0003o[5>/ojaC[006ojaC[003o`000?m2_D;o@[e2
00[o@[e200?o0000occ3??ll`c`02_ll`c`2o`0000?o8]dR00?o0000odfbCOm=/Td01?m=/Td00ol0
003o><LhocS7>008ocS7>003o`000?n1OX7oPGj100coPGj100?o0000ojIIY_nVFJH01_nVFJH00ol0
003ojAKYonTFj@0EonTFj@03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000on`Ck?o/4n`02oo/4n`00ol0003o
^TFjokY5^P0>okY5^P03o`000?n/Djco[5>/00Go[5>/00?o0000od:m@_m2_D802om2_D800ol0003o
?<<locc3?008occ3?0;o00001_lRgB800ol0003oCK9=odfbC@02odfbC@03o`000?lhacSo><Lh00Wo
><Lh00?o0000oh5nPOn1OX403?n1OX400ol0003oYUVVojIIYP07ojIIYP03o`000?oY5^WojAKY01Co
jAKY00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o/4ncok1?/00gok1?/00?o0000okY5^_njAKX03_njAKX00ol0003o[5>/ojaC[003ojaC[003o`00
0?m2_D;o@[e200co@[e200?o0000occ3??ll`c`01_ll`c`2o`0000Wo8]dR00Go0000odfbCOm=/Tgo
CK9=o`00000;ocS7>003o`000?n1OX7oPGj100coPGj100?o0000ojIIY_nVFJH01onVFJH00ol0003o
jAKYonTFj@0ConTFj@03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o/4ncok1?/00ko
k1?/00?o0000okY5^_njAKX03_njAKX00ol0003o[5>/ojaC[002ojaC[003o`000?m2_D;o@[e200go
@[e200?o0000occ3??ll`c`01?ll`c`2o`0000co8]dR00?o0000odfbCOl000003?lhacP00ol0003o
PGj1oh5nP@0;oh5nP@03o`000?nVFJKoYUVV00WoYUVV00?o0000onTFjOoY5^T04OoY5^T00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003ok1?/on`Ck00?on`Ck003o`000?njAK[o^TFj00ko^TFj00Go0000ojaC[?n/Djco
[5>/o`00000@od:m@P03o`000?ll`cco?<<l00;o?<<l0_l0000?ob;M8P03o`000?lhacSo><Lh00_o
><Lh00?o0000oh5nPOn1OX402on1OX400ol0003oYUVVojIIYP09ojIIYP03o`000?oY5^WojAKY017o
jAKY00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000on`Ck?o/4n`04Oo/4n`00ol0003o^TFj
okY5^P0>okY5^PCo00004?m2_D800ol0003o?<<locc3?002o`00017o8]dR00?o0000ocS7>?lhacP0
2olhacP00ol0003oPGj1oh5nP@0:oh5nP@03o`000?nVFJKoYUVV00_oYUVV00?o0000onTFjOoY5^T0
3ooY5^T00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ook1?/00ol0003onPGjooX5nP03ooX5nP03o`000?o/
4ncok1?/01;ok1?/00?o0000okY5^_njAKX03OnjAKX00ol0003oCK9=odfbC@02odfbC@;o00003_m2
_D83o`0001?o8]dR00?o0000ocS7>?lhacP02olhacP00ol0003oPGj1oh5nP@0:oh5nP@03o`000?nV
FJKoYUVV00_oYUVV00?o0000onTFjOoY5^T03ooY5^T00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ok1?_on`Ck00Con`Ck00Go0000ooX5n_oj1O[onPGjo`00000Eon`Ck003o`000?nj
AK[o^TFj00co^TFj00?o0000odfbCOm=/Td01Om=/Td2o`0000co@[e200?o0000ob;M8_lRgB805?lR
gB800ol0003o><LhocS7>00:ocS7>003o`000?n1OX7oPGj100[oPGj100?o0000ojIIY_nVFJH03?nV
FJH00ol0003ojAKYonTFj@0=onTFj@03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Son`Ck00?o0000
ooX5n_l000005oo/4n`00ol0003o^TFjokY5^P0:okY5^P03o`000?m=/TgoCK9=00SoCK9=00?o0000
od:m@_m2_D802?m2_D83o`0001Go8]dR0_l0000;ocS7>003o`000?n1OX7oPGj100WoPGj100?o0000
ojIIY_nVFJH03_nVFJH00ol0003ojAKYonTFj@0<onTFj@03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_on`Ck00?o0000on`Ck?o/4n`05_o/4n`00ol0003o^TFjokY5^P09okY5^P03o`000?m=/TgoCK9=
00[oCK9=0_l00005od:m@P?o00000olMhQd00ol0003o8]dRob;M8P0Aob;M8P03o`000?lEjQGo5NXE
00;o00002OlhacP00ol0003oPGj1oh5nP@09oh5nP@03o`000?nVFJKoYUVV00koYUVV00?o0000onTF
jOoY5^T02ooY5^T00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo/4n`03o`000?o/4ncok1?/01Ko
k1?/00?o0000okY5^_njAKX00onjAKX6o`0000ooCK9=0_l000000om2_D;o0000o`000007oagR7@;o
00004?lRgB800ol0003o5NXEoaGZ5@03oaGZ5@?o00001_lhacP00ol0003oPGj1oh5nP@09oh5nP@03
o`000?nVFJKoYUVV00ooYUVV00?o0000onTFjOoY5^T02_oY5^T00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ok1?/00ol0003ok1?/
on`Ck00Fon`Ck0Go00001OnQGZ400ol0003oCK9=odfbC@0?odfbC@03o`000?lMhQgo7N8M00Wo7N8M
00?o0000ob;M8_lRgB803?lRgB800ol0003o5NXEoaGZ5@07oaGZ5@;o00000_lhacP>o`0001;oYUVV
00?o0000onTFjOoY5^T02OoY5^T00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ok1?_on`Ck013on`Ck00?o0000on`Ck?o/4n`05Oo/
4n`00ol0003oXEjQoj5NX@09oj5NX@03o`000?m=/TgoCK9=00koCK9=00?o0000oagR7OlMhQd02_lM
hQd2o`0000_o8]dR00?o0000oaGZ5OlEjQD02_lEjQD2o`0000go;m0_00?o0000ojIIY_nVFJH04OnV
FJH00ol0003ojAKYonTFj@07onTFj@03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ok1?/00ol0003ok1?/on`Ck00Con`Ck003o`000?nQGZ7oXEjQ00[oXEjQ00?o
0000odfbCOm=/Td03_m=/Td00ol0003o7N8MoagR7@0<oagR7@03o`000?lRgB;o8]dR00Oo8]dR00?o
0000oaGZ5OlEjQD02olEjQD00ol0003o;m0_obo@;`0=obo@;`03o`000?nVFJKoYUVV013oYUVV00?o
0000onTFjOoY5^T01ooY5^T00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003on`Ckoo/4n`0Doo/4n`03o`000?o/4ncok1?/01;ok1?/00?o0000oj5NXOnQGZ402onQ
GZ400ol0003oCK9=odfbC@0>odfbC@03o`000?lMhQgo7N8M00go7N8M00?o0000ob;M8_lRgB801?lR
gB82o`0000ko5NXE00?o0000obo@;ol_d2l03Ol_d2l00ol0003oYUVVojIIYP0@ojIIYPCo00001OoY
5^T00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ok
1?_on`Ck01Gon`Ck5?l0000?oj5NX@03o`000?m=/TgoCK9=00coCK9=00?o0000oaoP7ol000003olM
hQd2o`0000?o8]dR00Co0000oa3_4?l@ka3o00003OlEjQD00ol0003o;m0_obo@;`0>obo@;`03o`00
0?nVFJKoYUVV00coYUVV0ol00004ol8m`P?o00000_oY5^T00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo/4nook1?/05Ook1?/00ol0003oiQWVonHI
iP0@onHIiP03o`000?nQGZ7oXEjQ00goXEjQ00?o0000odfbCOm=/Td02om=/Td01?l0003o7n0OoaoP
7ol0000AoagR7@03o`000?lRgB;o000000Co4>l@00?o0000oaGZ5OlEjQD02_lEjQD00ol0003o;m0_
obo@;`0>obo@;`03o`000?nVFJKoYUVV00WoYUVV0ol0000:ol8m`P;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?oV6NKoiQWV013oiQWV00?o0000oj5NXOnQGZ403OnQ
GZ400ol0003oCK9=odfbC@0:odfbC@03o`000?lOh1oo7n0O00;o7n0O00?o0000oagR7OlMhQd03olM
hQd00ol0003o4>l@oa3_4004oa3_4003o`000?lEjQGo5NXE00Wo5NXE00?o0000obo@;ol_d2l03_l_
d2l00ol0003oYUVVojIIYP06ojIIYP?o00003_o2?L800ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ok1?_on`Ck01Gon`Ck00?o0000
onHIi_oV6NH04_oV6NH00ol0003oXEjQoj5NX@0=oj5NX@03o`000?m=/TgoCK9=00WoCK9=00?o0000
oaoP7olOh1l00_lOh1l00ol0003o7N8MoagR7@0?oagR7@03o`000?l@ka3o4>l@00Go4>l@00?o0000
oaGZ5OlEjQD02?lEjQD00ol0003o;m0_obo@;`0?obo@;`03o`000?nVFJKoYUVV00;oYUVV0ol0000B
ol8m`P03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003on`Ckoo/4n`0Coo/4n`?o00005?oV6NH00ol0003oXEjQoj5NX@0=oj5NX@03o`000?m=/TgoCK9=
00SoCK9=00?o0000oaoP7olOh1l01?lOh1l00ol0003o7N8MoagR7@0>oagR7@03o`000?l@ka3o4>l@
00Ko4>l@00?o0000oaGZ5OlEjQD01olEjQD00ol0003o;m0_obo@;`0?obo@;`03o`000?nVFJKo0000
00;o00005Oo2?L800ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ok1?_on`Ck00oon`Ck1?l00002ooH9mP03o`000?oV6NKoiQWV01;o
iQWV00?o0000oj5NXOnQGZ403OnQGZ400ol0003oCK9=odfbC@07odfbC@03o`000?lOh1oo7n0O00Go
7n0O00?o0000oagR7OlMhQd03OlMhQd00ol0003o4>l@oa3_4008oa3_4003o`000?lEjQGo5NXE00Ko
5NXE00?o0000obo@;ol_d2l04?l_d2l00ol0003o`Sg2ol8m`P0Fol8m`P03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/02ook1?/4o`0000KomPWf
00?o0000onHIi_oV6NH04ooV6NH00ol0003oXEjQoj5NX@0=oj5NX@03o`000?m=/TgoCK9=00GoCK9=
00?o0000oaoP7olOh1l01olOh1l00ol0003o7N8MoagR7@0<oagR7@03o`000?l@ka3o4>l@00Wo4>l@
00?o0000oaGZ5OlEjQD01OlEjQD00ol0003o;m0_obo@;`0@obo@;`03o`000?o2?L;o`Sg201Oo`Sg2
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo/4nook1?/01ook
1?/4o`0000[omPWf00?o0000onHIi_oV6NH04ooV6NH00ol0003oXEjQoj5NX@0=oj5NX@03o`000?m=
/TgoCK9=00CoCK9=00?o0000oaoP7olOh1l02?lOh1l00ol0003o7N8MoagR7@0<oagR7@03o`000?l@
ka3o4>l@00[o4>l@00?o0000oaGZ5OlEjQD01?lEjQD00ol0003o;m0_obo@;`0@obo@;`03o`000?o2
?L;o`Sg201Oo`Sg200?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003on`Ckoo/4n`04oo/4n`Co00003_of2OH00ol0003oiQWVonHIiP0ConHIiP03o`000?nQGZ7o
XEjQ00goXEjQ00?o0000odfbCOm=/Td01?m=/Td00ol0003o7n0OoaoP7`09oaoP7`03o`000?lMhQgo
7N8M00_o7N8M00?o0000oa3_4?l@ka002ol@ka000ol0003o5NXEoaGZ5@03oaGZ5@03o`000?l_d2oo
;m0_013o;m0_00?o0000ol8m`_o2?L805oo2?L800ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003on`Ckoo/4n`04o`0001;omPWf00?o0000onHIi_oV6NH04ooV6NH00ol0
003oXEjQoj5NX@0>oj5NX@03o`000?m=/TgoCK9=00;oCK9=00?o0000oaoP7olOh1l02_lOh1l00ol0
003o7N8MoagR7@0:oagR7@03o`000?l@ka3o4>l@00go4>l@00?o0000oaGZ5OlEjQD00_lEjQD00ol0
003o;m0_obo@;`0@obo@;`03o`000?o2?L;o`Sg201So`Sg200?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oV6NKoiQWV01?oiQWV00?o0000oj5NXOnQGZ403?nQGZ44o`000003odfbCOl0003o7n0O00go
7n0O00?o0000oagR7OlMhQd02OlMhQd00ol0003o4>l@oa3_400>oa3_4005o`000?lEjQGo5NXEoaGZ
5Ol000004_l_d2l00ol0003o`Sg2ol8m`P0Hol8m`P?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oV6NKoiQWV
01?oiQWV00?o0000oj5NXOnQGZ402onQGZ400ol0003o<<l`oc3?<002oc3?<0;o00003_lOh1l00ol0
003o7N8MoagR7@09oagR7@03o`000?l@ka3o4>l@00oo4>l@00Co0000oaGZ5OlEjQGo00004_l_d2l0
0ol0003o`Sg2ol8m`P0Hol8m`P03o`000?o/4ncok1?/00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onHIi_oV6NH04ooV6NH00ol0003oXEjQoj5NX@0:
oj5NX@03o`000?l`cc3o<<l`00Go<<l`00?o0000oaoP7olOh1l03?lOh1l00ol0003o7N8MoagR7@08
oagR7@03o`000?l@ka3o4>l@00oo4>l@1Ol0000Aobo@;`03o`000?o2?L;o`Sg201Oo`Sg200?o0000
on`Ck?o/4n`01?o/4n`3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oV6NKoiQWV01?oiQWV00?o0000oj5NXOnQGZ402?nQGZ42o`00
00Wo<<l`00?o0000oaoP7olOh1l02olOh1l00ol0003o7N8MoagR7@07oagR7@03o`000?l@ka3o4>l@
00go4>l@0ol00005o`ka3P03o`000?l_d2oo;m0_00ko;m0_00?o0000ol8m`_o2?L805_o2?L800ol0
003ok1?/on`Ck008on`Ck0?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonHIiP03o`000?nQGZ7oXEjQ00KoXEjQ00?o0000oc3?<?l`
cc002_l`cc000ol0003o7n0OoaoP7`0:oaoP7a[o00002Ol>l@h00ol0003o;m0_obo@;`0<obo@;`?o
00005_o2?L800ol0003ok1?/on`Ck00<on`Ck0?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oU6^D3o`0001;oiQWV00?o0000oj5NXOnQGZ401?nQGZ42o`0000ko<<l`
00?o0000oaoP7olOh1l01olOh1l2o`0000[o4n`C00?o0000o`cc3?l<l``03?l<l``00ol0003o3_4>
o`ka3P08o`ka3P;o00002_l_d2l2o`0000?o8]dR0_l0000Col8m`P03o`000?o/4ncok1?/013ok1?/
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onDJi@;o00004?oV
6NH00ol0003oXEjQoj5NX@03oj5NX@03o`000?l`cc3o<<l`00oo<<l`00?o0000oaoP7olOh1l01?lO
h1l2o`0000co4n`C00?o0000o`cc3?l<l``03?l<l``00ol0003o3_4>o`ka3P0:o`ka3P03o`000?l_
d2oo;m0_00Go;m0_0_l00007ob;M8P03o`000?o2?L;o`Sg200oo`Sg200?o0000on`Ck?o/4n`04Oo/
4n`01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onDJiOoU6^D01OoU6^D2o`0000ooiQWV00Go0000oj5NXOnQGZ7oXEjQo`00000Coc3?<003o`00
0?lOh1oo7n0O00;o7n0O00?o0000oa?/4olCk1<03OlCk1<00ol0003o3?<<o`cc300;o`cc3003o`00
0?l>l@ko3_4>00_o3_4>00?o0000obo@;ol_d2l00_l_d2l2o`0000[o8]dR0_l0000>ol8m`P03o`00
0?o/4ncok1?/017ok1?/00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onDJiOoU6^D01_oU6^D3o`0000_oiQWV1Ol0000Eoc3?<004o`00
0?lOh1oo0000o`00013o4n`C00?o0000o`cc3?l<l``02ol<l``00ol0003o3_4>o`ka3P0<o`ka3P04
o`000?l_d2oo0000o`0000ko8]dR0_l0000;ol8m`P03o`000?o/4ncok1?/017ok1?/00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oU6^GoiA[U00WoiA[U0_l00008onHIiP03o`000?nAKY7oTFjA00;oTFjA00?o0000oc3?<?l`
cc005?l`cc000ol0003o4n`Coa?/4`0@oa?/4`03o`000?l<l`co3?<<00_o3?<<00?o0000o`ka3_l>
l@h03Ol>l@h00ol0003o8]dRob;M8P0@ob;M8P03o`000?o2?L;o`Sg200Oo`Sg200?o0000on`Ck?o/
4n`04Oo/4n`00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oU6^GoiA[U00_oiA[U
0_l00005onHIiP03o`000?nAKY7oTFjA00CoTFjA00?o0000oc3?<?l`cc004ol`cc000ol0003o4n`C
oa?/4`0@oa?/4`03o`000?l<l`co3?<<00_o3?<<00?o0000o`ka3_l>l@h03Ol>l@h00ol0003o8]dR
ob;M8P0Aob;M8P;o00000oo2?L84o`0001?ok1?/00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oU6^GoiA[U00goiA[U0ol000000ooV6NKo0000oi5^T@07oi5^T@03o`000?l`cc3o<<l`01;o
<<l`00?o0000oa?/4olCk1<04?lCk1<00ol0003o3?<<o`cc300;o`cc3003o`000?l>l@ko3_4>00go
3_4>00?o0000ob;M8_lRgB804olRgB83o`0000?odbcC00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oU6^GoiA[U013oiA[U00?o0000oi5^TOnAKY40
2?nAKY400ol0003o<<l`oc3?<00Aoc3?<003o`000?lCk1?o4n`C017o4n`C00?o0000o`cc3?l<l``0
2_l<l``00ol0003o3_4>o`ka3P0<o`ka3P03o`000?l=lPgo000001Co8]dR00?o0000om</dooC;=<0
1?oC;=<00ol0003ok1?/on`Ck00>on`Ck003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onDJiOoU6^D03ooU
6^D00ol0003oTFjAoi5^T@09oi5^T@03o`000?l`cc3o<<l`013o<<l`00?o0000oa?/4olCk1<04OlC
k1<00ol0003o3?<<o`cc300:o`cc3003o`000?l>l@ko3_4>00_o3_4>00Co0000o`gb3Ol=lPgo0000
5?lRgB800ol0003odbcCom</d`05om</d`03o`000?o/4ncok1?/00cok1?/00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiA[UonDJ
i@0?onDJi@03o`000?nAKY7oTFjA00[oTFjA00?o0000oc3?<?l`cc003_l`cc000ol0003o5^TFo`00
000Boa?/4`03o`000?l<l`co3?<<00[o3?<<00?o0000o`ka3_l>l@h02_l>l@h00ol0003o3O8=o`gb
3@02o`gb3@03o`000?lRgB;o8]dR013o8]dR00?o0000om</dooC;=<01ooC;=<00ol0003ok1?/on`C
k00:on`Ck003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oU6^GoiA[U00ooiA[U00?o0000oi5^TOnAKY40
2onAKY400ol0003o<<l`oc3?<00<oc3?<005o`000?lFjAKo5^TFoaKY5_l000004OlCk1<00ol0003o
3?<<o`cc300:o`cc3003o`000?l>l@ko3_4>00Wo3_4>00?o0000o`gb3Ol=lPd00ol=lPd00ol0003o
8]dRob;M8P0@ob;M8P03o`000?oC;=?odbcC00SodbcC00?o0000on`Ck?o/4n`02?o/4n`00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onDJiOoU6^D03_oU6^D00ol0003oTFjAoi5^T@0=oi5^T@03o`00
0?l`cc3o<<l`00[o<<l`00?o0000oaKY5_lFjAH00olFjAH00ol0003o4n`Coa?/4`0?oa?/4`03o`00
0?l<l`co3?<<00Wo3?<<00?o0000o`ka3_l>l@h02?l>l@h00ol0003o3O8=o`gb3@05o`gb3@03o`00
0?lRgB;o8]dR00oo8]dR00?o0000om</dooC;=<02OoC;=<00ol0003ok1?/on`Ck006on`Ck003o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiA[UonDJi@0>onDJi@03o`000?nA
KY7oTFjA00koTFjA00?o0000oc3?<?l`cc002?l`cc000ol0003o5^TFoaKY5P05oaKY5P03o`000?lC
k1?o4n`C00ko4n`C00?o0000o`cc3?l<l``02Ol<l``00ol0003o3_4>o`ka3P07o`ka3P03o`000?l=
lPgo3O8=00Ko3O8=00?o0000ob;M8_lRgB803olRgB800ol0003odbcCom</d`09om</d`03o`000?o/
4ncok1?/00Gok1?/00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiA[UonDJi@0=
onDJi@03o`000?nAKY7oTFjA00ooTFjA00?o0000oc3?<?l`cc001_l`cc000ol0003o5^TFoaKY5P07
oaKY5P03o`000?lCk1?o4n`C00go4n`C00?o0000o`cc3?l<l``02Ol<l``00ol0003o3_4>o`ka3P04
o`ka3P?o00002_l=lPd00ol0003o8]dRob;M8P0=ob;M8P03o`000?oC;=?odbcC00_odbcC00?o0000
on`Ck?o/4n`00oo/4n`00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oU6^GoiA[U
00goiA[U00?o0000oi5^TOnAKY404?nAKY400ol0003o<<l`oc3?<005oc3?<003o`000?lFjAKo5^TF
00So5^TF00?o0000oa?/4olCk1<03?lCk1<00ol0003o3?<<o`cc3009o`cc3003o`000?l>l@ko0000
00Co00000_l<l``00ol0003o3O8=o`gb3@08o`gb3@03o`000?lRgB;o8]dR00go8]dR00?o0000om</
dooC;=<03?oC;=<01Ol0003ok1?/on`Ck?o/4nco000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0
003oTFjAoi5^T@0Aoi5^T@03o`000?l`cc3o<<l`00?o<<l`00?o0000oaKY5_lFjAH02_lFjAH00ol0
003o4n`Coa?/4`0;oa?/4`03o`000?l<l`co3?<<00So3?<<0ol00008o`cc3003o`000?l=lPgo3O8=
00So3O8=00?o0000ob;M8_lRgB803?lRgB800ol0003odbcCom</d`0=om</d`03o`000?o/4nco0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oU6^GoiA[U00goiA[U00?o0000oi5^TOnAKY404_nAKY401Ol0
003o<<l`oc3?<?l`cc3o000000ko5^TF00?o0000oa?/4olCk1<02olCk1<00ol0003o3?<<o`cc3006
o`cc3003o`000?l<l`co3?<<00Wo3?<<00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o8]dRob;M8P0:
ob;M8P03o`000?oC;=?odbcC00oodbcC00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0003oTFjAoi5^T@0Coi5^T@03o`000?l`cc3o0000
013o5^TF3_l00006o`cc30;o00003?l<l``00ol0003o3O8=o`gb3@09o`gb3@03o`000?lRgB;o8]dR
00[o8]dR00?o0000om</dooC;=<03ooC;=<00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onDJiOoU6^D02ooU6^D00ol0003o
TFjAoi5^T@0Doi5^T@?o00003olFjAH00ol0003o4NhAoa7^4@0<oa7^4@04o`000?l<l`co3?<<o`cc
30;o00003ol<l``00ol0003o3O8=o`gb3@09o`gb3@03o`000?lRgB;o8]dR00Wo8]dR00?o0000om</
dooC;=<04?oC;=<00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oU6^GoiA[U00_o
iA[U00?o0000oi5^TOnAKY404onAKY401Ol0003o<l`coc?<<olcc3?o000000go5^TF00?o0000oa7^
4OlAkQ403_lAkQ400ol0003o3?<<o`00000Ao`cc3003o`000?l=lPgo3O8=00Wo3O8=00?o0000ob;M
8_lRgB802OlRgB800ol0003odbcCom</d`0@om</d`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000Boi5^T@03o`000?lcc3?o<l`c00?o<l`c00?o0000oaKY5_lFjAH02OlFjAH00ol0003o
4NhAoa7^4@0@oa7^4@03o`000?l<l`co3?<<017o3?<<00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o
8]dRob;M8P07ob;M8P03o`000?oC;=?odbcC017odbcC00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iaSWonLHi`0<onLHi`03o`000?n:MH[oRWF:00?o00003_nAKY400ol0003o<l`coc?<<`05oc?<<`03
o`000?lFjAKo5^TF00Oo5^TF00?o0000oa7^4OlAkQ404OlAkQ400ol0003o3?<<o`cc300Ao`cc3003
o`000?l=lPgo3O8=00Wo3O8=00?o0000ob;M8_lRgB801_lRgB82o`0001CodbcC00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiaSW00koiaSW
00?o0000ohYeR_n:MHX00on:MHX3o`0000[oTFjA00?o0000oc?<<olcc3<01olcc3<00ol0003o5^TF
oaKY5P05oaKY5P03o`000?lAkQ7o4NhA01;o4NhA00?o0000o`cc3?l<l``04Ol<l``00ol0003o3O8=
o`gb3@0:o`gb3@03o`000?lRgB;o8]dR00;o8]dR0ol00002obkA;P03o`000?oC;=?odbcC017odbcC
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oW6>OoiaSW00koiaSW00?o0000ohYeR_n:MHX01_n:
MHX3o`0000KoTFjA00?o0000oc?<<olcc3<02Olcc3<00ol0003o5^TFoaKY5P03oaKY5P03o`000?lA
kQ7o4NhA01?o4NhA00?o0000o`cc3?l<l``04_l<l``00ol0003o3O8=o`gb3@09o`gb3@03o`000?lR
gB;o000000;o00001_l^dBh00ol0003odbcCom</d`0@om</d`03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oW6>Oo
iaSW00goiaSW00?o0000ohYeR_n:MHX02_n:MHX3o`0000;oTFjA00?o0000oc?<<olcc3<02olcc3<0
1Ol0003o5^TFoaKY5_lFjAKo000001Ko4NhA00?o0000o`cc3?l<l``04_l<l``00ol0003o3O8=o`gb
3@0:o`gb3@03o`000?l^dBko;]4^00So;]4^00?o0000om</dooC;=<04?oC;=<00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oW6>OoiaSW00goiaSW00?o0000ohYeR_n:MHX03On:MHX2o`0000oo<l`c00?o0000oaKY5_l00000
5olAkQ400ol0003o3?<<o`cc300Co`cc3003o`000?l=lPgo3O8=00Wo3O8=00?o0000obkA;_l^dBh0
2Ol^dBh00ol0003odbcCom</d`0?om</d`03o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW
6>L00ol0003oRWF:ohYeRP0>ohYeRP03o`000?lcc3?o<l`c00ko<l`c00?o0000oa7^4OlAkQ405_lA
kQ400ol0003o3?<<o`cc300Co`cc3003o`000?l=lPgo3O8=00So3O8=00?o0000obkA;_l^dBh02ol^
dBh5o`0000codbcC00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW6>L00ol0003oRWF:ohYeRP0>
ohYeRP03o`000?lcc3?o<l`c00ko<l`c00?o0000oa7^4OlAkQ405_lAkQ400ol0003o3?<<o`cc300C
o`cc3003o`000?l=lPgo3O8=00Oo3O8=00?o0000obkA;_l^dBh03?l^dBh00ol0003ofRGJomXUfP02
omXUfPWo00001?oC;=<00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiaSWonLHi`0<onLHi`03o`000?n:MH[oRWF:
00koRWF:00?o0000oc?<<olcc3<03olcc3<00ol0003o4NhAoa7^4@0Eoa7^4@03o`000?l<l`co3?<<
01?o3?<<1?l00005o`gb3@03o`000?l^dBko;]4^00go;]4^00?o0000omXUf_oJ9MX02ooJ9MX4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oW6>OoiaSW00_oiaSW00?o0000ohYeR_n:MHX03on:MHX00ol0003o<l`coc?<<`0?oc?<<`03
o`000?lAkQ7o4NhA01Go4NhA00?o0000o`cc3?l<l``04?l<l``3o`0000Co6NHI0ol000000ol=lPgo
0000obkA;P0>obkA;P03o`000?oJ9M[ofRGJ00oofRGJ00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiaSWonLHi`0;onLHi`03o`00
0?n:MH[oRWF:00ooRWF:00?o0000oc?<<olcc3<03olcc3<2o`0001Co4NhA0ol0000@o`cc30;o0000
2_lIiQT00ol0003o;]4^obkA;P0>obkA;P03o`000?oJ9M[ofRGJ013ofRGJ0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oW6>OoiaSW00_oiaSW4ol0000>oc?<<`?o0000
0_l]dRd00ol0003o4NhAoa7^4@0<oa7^4@Go00000_lLha`00ol0003o3?<<o`cc300<o`cc30;o0000
3?lIiQT00ol0003o;]4^obkA;P0>obkA;P03o`000?oJ9M[ofRGJ013ofRGJ00?o0000ooD:mOl00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW
6>OoiaSW00_oiaSW00?o0000oh=lPon3O8<03on3O8<00ol0003o<l`coc?<<`09oc?<<`?o00001_l]
dRd00ol0003o4NhAoa7^4@06oa7^4@Go00002?lLha`00ol0003o3?<<o`cc3008o`cc30?o00003olI
iQT00ol0003o;]4^obkA;P0=obkA;P03o`000?oJ9M[ofRGJ00oofRGJ00Go0000ooD:mOoe2_Gom@[e
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLH
i`0;onLHi`03o`000?n3O8?oPgb300ooPgb300?o0000oc?<<olcc3<01_lcc3<3o`0000[o;M8]00?o
0000oa7^4OlAkQ401Ol0000>oacS7003o`000?l<l`co3?<<00Go3?<<0_l0000BoaWV6@03o`000?l^
dBko;]4^00co;]4^00?o0000omXUf_oJ9MX04?oJ9MX00ol0003om@[eooD:m@02ooD:m@03o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLHi`0;
onLHi`03o`000?n3O8?oPgb3013oPgb300?o0000oc?<<olcc3<00_lcc3<3o`0000go;M8]0ol0000C
oacS7003o`000?l<l`co3?<<00?o3?<<0_l0000EoaWV6@03o`000?l^dBko;]4^00_o;]4^00?o0000
omXUf_oJ9MX03ooJ9MX00ol0003om@[eooD:m@04ooD:m@03o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiaSWonLHi`08onLHi`Co00004On3O8<00ol0003o<l`co`000002o`00
00oo;M8]00?o0000oco0?ol000005OlLha`00ol0003o3?<<o`000002o`0001Oo6NHI00?o0000obkA
;_l^dBh02ol^dBh00ol0003ofRGJomXUfP0>omXUfP03o`000?oe2_Gom@[e00Kom@[e00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW6>OoiaSW00Go
iaSW0ol00004om0_d003o`000?n3O8?oPgb300koPgb30_l0000AobgB;@04o`000?lo`3oo?l0oo`00
01Ko7><L00?o0000oaWV6OlIiQT06?lIiQT00ol0003o;]4^obkA;P0;obkA;P03o`000?oJ9M[ofRGJ
00kofRGJ00?o0000ooD:mOoe2_D01ooe2_D00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oW6>OoiaSW00;oiaSW0ol00008om0_d003
o`000?n3O8?oPgb300coPgb30ol0000?obgB;@;o00000olo`3l00ol0003o7><LoacS700DoacS7003
o`000?lIiQWo6NHI01Wo6NHI00?o0000obkA;_l^dBh02_l^dBh00ol0003ofRGJomXUfP0=omXUfP03
o`000?oe2_Gom@[e00Wom@[e00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<om0_d003o`000?n3O8?oPgb300[oPgb300Go0000ogf2OOmmPWgo
OH9mo`00000=obgB;@03o`000?lo`3oo?l0o00Co?l0o00?o0000oacS7?lLha`04olLha`00ol0003o
6NHIoaWV6@0IoaWV6@03o`000?l^dBko;]4^00Wo;]4^00?o0000omXUf_oJ9MX03_oJ9MX00ol0003o
m@[eooD:m@0:ooD:m@;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o@;m3od2o@00cod2o@0_l00008oh=lP`;o00001OmmPWd00ol0003o;M8]obgB;@09obgB;@03o`00
0?lo`3oo?l0o00Go?l0o00?o0000oacS7?lLha`04olLha`00ol0003o6NHIoaWV6@0JoaWV6@go0000
3_oJ9MX00ol0003om@[eooD:m@0;ooD:m@03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003od2o@om0_d00=om0_d003o`000?n3
O8?oPgb300CoPgb300?o0000ogf2OOmmPWd01_mmPWd2o`0000So;M8]00?o0000oco0?olo`3l01_lo
`3l00ol0003o7><LoacS700DoacS7003o`000?lIiQWo6NHI01Wo6NHI00?o0000ohEjQOn5NXD02_n5
NXD00ol0003ofRGJomXUfP0;omXUfP03o`000?oe2_Gom@[e00com@[e00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000om0_d?o@;m003_o@;m00
1?l0003oPgb3oh=lPon3O8<2o`0000_oOH9m00?o0000obgB;Ol]dRd00ol]dRd2o`0000Wo?l0o00?o
0000oacS7?lLha`05?lLha`00ol0003o6NHIoaWV6@0HoaWV6@03o`000?n5NXGoQGZ500coQGZ500?o
0000omXUf_oJ9MX02OoJ9MX00ol0003om@[eooD:m@0=ooD:m@03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003od2o@om0_d00>om0_d003o`000?n3O8?o
000000koOH9m00Go0000obgB;Ol]dRgo;M8]o`00000;oco0?`03o`000?lLhaco7><L01Co7><L0_l0
000IoaWV6@03o`000?n5NXGoQGZ500goQGZ50_l00008omXUfP03o`000?oe2_Gom@[e00kom@[e00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003od2o@om0_d00?
om0_d003o`000?mmPWgoOH9m00koOH9m00?o0000obgB;Ol000003?lo`3l00ol0003o7><LoacS700D
oacS7003o`000?lhacSo000000;o00005OlIiQT00ol0003oQGZ5ohEjQ@0@ohEjQ@03o`000?oJ9M[o
fRGJ00GofRGJ00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003od2o@om0_d00>om0_d003o`000?mmPWgoOH9m00koOH9m0_l0000=oco0
?`03o`000?lLhaco7><L01?o7><L00?o0000ocS7>?lhacP00olhacP2o`0001;o6NHI00?o0000ohEj
QOn5NXD04_n5NXD01?l0003ofRGJomXUf_oJ9MX3o`0001;om@[e00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000om0_d?o@;m003Oo@;m02o`0000ooOH9m00?o0000ohAk
Q?l000003_lo`3l00ol0003o7><LoacS700BoacS7003o`000?lhacSo><Lh00Go><Lh0ol0000?oaWV
6@03o`000?n5NXGoQGZ501?oQGZ50ol00002oo0?l003o`000?oe2_Gom@[e013om@[e00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000om0_d?o@;m002oo@;m000ol0003o
dbcCo`00000>ogf2O@05o`000?n4NhCoQ7^4ohAkQ?l000003Olo`3l00ol0003o7><LoacS700AoacS
7003o`000?lhacSo><Lh00Wo><Lh0ol0000:oaWV6@;o00005_n5NXD00ol0003ol0o`oo0?l003oo0?
l003o`000?oe2_Gom@[e013om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000om0_d?o@;m002_o@;m001Ol0003odbcCom</dooC;=?o000000coOH9m00?o0000ohAk
Q?n4Nh@00_n4Nh@00ol0003o?l0ooco0?`0;oco0?`03o`000?lLhaco7><L017o7><L00?o0000ocS7
>?lhacP03?lhacP2o`0000Ko6NHI0_l000000omaSW7o0000ohEjQ@0DohEjQ@03o`000?o`3o3ol0o`
00Gol0o`00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003od2o@om0_d007om0_d0;o00001OoC;=<00ol0003oOH9mogf2O@08ogf2O@03
o`000?n4NhCoQ7^400CoQ7^400?o0000oco0?olo`3l02Olo`3l4o`00013o7><L00?o0000ocS7>?lh
acP03olhacP3o`000003oaWV6Ol0003o000000CoLHia00?o0000ohEjQOn5NXD04On5NXD00ol0003o
l0o`oo0?l007oo0?l003o`000?oe2_Gom@[e00oom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000om0_d?o@;m001_o@;m000ol0003odbcCom</d`05om</d`03o`00
0?mmPWgoOH9m00OoOH9m00?o0000ohAkQ?n4Nh@01On4Nh@00ol0003o?l0ooco0?`08oco0?`03o`00
0?m=/TgoCK9=00;oCK9=0ol0000=oacS7003o`000?lhacSo><Lh01;o><Lh00?o0000og6>LOmaSW40
1OmaSW400ol0003oQGZ5ohEjQ@0@ohEjQ@03o`000?o`3o3ol0o`00Ool0o`00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003od2o@om0_
d004om0_d003o`000?oC;=?odbcC00OodbcC00?o0000ogf2OOmmPWd01OmmPWd00ol0003oQ7^4ohAk
Q007ohAkQ003o`000?lo`3oo?l0o00Ko?l0o00?o0000odfbCOm=/Td01_m=/Td3o`0000So7><L0_l0
000EocS7>003o`000?maSW7oLHia00KoLHia00?o0000ohEjQOn5NXD03_n5NXD00ol0003ol0o`oo0?
l009oo0?l003o`000?oe2_Gom@[e00kom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000om0_d?o@;m000_o@;m02o`0000[odbcC00?o0000ogf2OOmmPWd01?mmPWd0
0ol0003oQ7^4ohAkQ009ohAkQ003o`000?lo`3oo?l0o00?o?l0o0_l0000<odfbC@?o00000_lLha`3
o`000003odZeB_l0003o><Lh01Co><Lh00?o0000og6>LOmaSW401omaSW400ol0003oQGZ5ohEjQ@0<
ohEjQ@03o`000?o`3o3ol0o`00_ol0o`00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003od2o@om0_d?l0000=om</d`03o`000?mmPWgo
OH9m00;oOH9m00?o0000ohAkQ?n4Nh@02_n4Nh@00ol0003o?l0ooco0?`02oco0?`03o`000?m=/Tgo
CK9=00ooCK9=0_l00005odZeBP03o`000?lhacSo><Lh01;o><Lh00?o0000og6>LOmaSW402?maSW40
0ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?o`3o3ol0o`00gol0o`1Ol0000;ooD:m@03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o@;m3o000000oodbcC00Co0000ogf2
OOmmPWgo00003_n4Nh@01?l0003o?l0ooco0?ol0000CodfbC@03o`000?m:]D[oB[E:00CoB[E:00?o
0000ocS7>?lhacP04?lhacP00ol0003oLHiaog6>L@09og6>L@03o`000?n5NXGoQGZ500[oQGZ500?o
0000oo0?l?o`3o003Oo`3o000ol0003on`Ckoo/4n`02oo/4n`Wo00000_oe2_D00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?oC;=?odbcC00kodbcC00?o0000ogf2OOl000003on4Nh@0
0ol0003o?l0oo`00000CodfbC@03o`000?m:]D[oB[E:00GoB[E:00?o0000ocS7>?lhacP04?lhacP0
0ol0003oLHiaog6>L@0:og6>L@03o`000?n5NXGoQGZ500SoQGZ500?o0000oo0?l?o`3o003Oo`3o00
0ol0003on`Ckoo/4n`0<oo/4n`Co00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000om</
dooC;=<03ooC;=<00ol0003oQ7^4ohAkQ00>ohAkQ0;o00005?m=/Td00ol0003oB[E:odZeBP06odZe
BP03o`000?lhacSo><Lh00oo><Lh00?o0000og6>LOmaSW402omaSW400ol0003oQGZ5ohEjQ@04ohEj
Q@?o00004?o`3o000ol0003on`Ckoo/4n`0?oo/4n`Co00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
dbcCom</d`0@om</d`03o`000?n4NhCoQ7^400_oQ7^40ol000000on5NXGo0000odfbC@0BodfbC@03
o`000?m:]D[oB[E:00OoB[E:00?o0000ocS7>?lhacP03olhacP00ol0003oLHiaog6>L@0<og6>L@03
o`000?n5NXGoQGZ500?o00000ooV6NH00ol0003ol0o`oo0?l00=oo0?l003o`000?ok1?_on`Ck00oo
n`Ck00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000om</dooC;=<04?oC;=<3o`0000WoQ7^40_l00005ohEjQ@03o`00
0?m=/TgoCK9=013oCK9=00?o0000odZeB_m:]DX02?m:]DX00ol0003o><LhocS7>00>ocS7>003o`00
0?maSW7oLHia00goLHia0_l00007onHIiP03o`000?o`3o3ol0o`00_ol0o`00?o0000oo/4nook1?/0
3ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?oC;=?odbcC00oodbcC00Co
0000ol/dboo;=<_obcC;0_l00005ohAkQ0;o00002?n5NXD00ol0003oCK9=odfbC@0>odfbC@03o`00
0?m:]D[oB[E:00[oB[E:00?o0000ocS7>?lhacP03?lhacP00ol0003oLHiaog6>L@0>og6>L@03o`00
0?oV6NKoiQWV00OoiQWV00?o0000oo0?l?o`3o002_o`3o000ol0003on`Ckoo/4n`0?oo/4n`03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006ol/db`03o`000?n4NhCo000000;o00002_n5
NXD00ol0003oCK9=odfbC@0=odfbC@03o`000?m:]D[oB[E:00_oB[E:00?o0000ocS7>?lhacP03?lh
acP00ol0003oLHiaog6>L@0=og6>L@03o`000?oV6NKoiQWV00WoiQWV00?o0000oo0?l?o`3o002?o`
3o000ol0003on`Ckoo/4n`0?oo/4n`03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o`3o3o
l0o`00ool0o`00?o0000ol/dboo;=</01Oo;=</00ol0003oQGZ5ohEjQ@0<ohEjQ@03o`000?m=/Tgo
CK9=00coCK9=00?o0000odZeB_m:]DX03?m:]DX2o`0000co><Lh00?o0000og6>LOmaSW403OmaSW40
0ol0003oiQWVonHIiP0:onHIiP03o`000?o`3o3ol0o`00Ool0o`00?o0000oo/4nook1?/03ook1?/0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o`3o004?o`3o000ol0003obcC;ol/db`06ol/db`03o`000?n5NXGo
QGZ500coQGZ500?o0000odfbCOm=/Td02om=/Td00ol0003oB[E:odZeBP0=odZeBP04o`000?maSW7o
0000o`0000[o><Lh00?o0000og6>LOmaSW403OmaSW400ol0003oiQWVonHIiP0;onHIiP03o`000?o`
3o3ol0o`00Kol0o`00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003ol0o`oo0?l00@
oo0?l003o`000?o;=<_obcC;00KobcC;00?o0000ohEjQOn5NXD03On5NXD00ol0003oCK9=odfbC@0:
odfbC@03o`000?m:]D[oB[E:00coB[E:00?o0000og6>LOmaSW400_maSW42o`0000So><Lh00?o0000
og6>LOmaSW403?maSW400ol0003oiQWVonHIiP0=onHIiP03o`000?o`3o3ol0o`00Col0o`00?o0000
oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@oo0?l003o`000?o;=<_obcC;
00OobcC;00?o0000ohEjQOn5NXD03_n5NXD<o`0000ooB[E:00?o0000og6>LOmaSW401?maSW42o`00
00Ko><Lh00?o0000og6>LOmaSW403?maSW400ol0003oiQWVonHIiP0>onHIiP03o`000?o`3o3ol0o`
00?ol0o`00?o0000oo/4nook1?/03ook1?/00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>oo0?
l003o`000?o;=<_obcC;00SobcC;00?o0000ohEjQOn5NXD03On5NXD00ol0003oLHiaog6>L@08og6>
L@03o`000?m:]D[oB[E:00coB[E:00?o0000og6>LOmaSW401omaSW42o`0000?o><Lh00?o0000og6>
LOmaSW403OmaSW400ol0003oiQWVonHIiP0?onHIiP05o`000?o`3o3ol0o`oo0?l?l000004Ook1?/0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo`3o000ol0003obcC;ol/db`08ol/db`03o`000?n5NXGo
QGZ500coQGZ500?o0000og6>LOmaSW402_maSW400ol0003oB[E:odZeBP0;odZeBP03o`000?maSW7o
LHia00WoLHia0_l000000olhacSo0000og6>L@08og6>L@Ko00004ooV6NH01?l0003ol0o`oo0?l?l0
000Aoo/4n`03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008oo0?l003o`000?o;=<_o
bcC;00WobcC;00?o0000ohEjQOn5NXD03?n5NXD00ol0003oLHiaog6>L@0:og6>L@03o`000?m:]D[o
B[E:00[oB[E:00?o0000og6>LOmaSW403?maSW4;o`0000Goe2_D00?o0000onHIi_oV6NH04_oV6NH0
0ol0003ol0o`o`00000@oo/4n`03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on@K
i?oT6nCoi1_T1Ol00003oo0?l003o`000?o;=<_obcC;00WobcC;00?o0000ohEjQOn5NXD02on5NXD0
0ol0003oLHiaog6>L@0<og6>L@03o`000?m:]D[oB[E:00WoB[E:00?o0000og6>LOmaSW403?maSW40
0ol0003oWf2OoimPW`02oimPW`03o`000?oD:mCoe2_D00Woe2_D00?o0000onHIi_oV6NH04_oV6NH3
o`0000oon`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on@K
i?oT6n@01OoT6n@3o`0000cobcC;00?o0000ohEjQOn5NXD02on5NXD00ol0003oLHiaog6>L@0<og6>
L@03o`000?m:]D[oB[E:00SoB[E:00?o0000og6>LOmaSW403?maSW400ol0003oWf2OoimPW`04oimP
W`03o`000?oD:mCoe2_D00Soe2_D00?o0000onHIi_oV6NH04_oV6NH00ol0003oo@;mood2o@04o`00
00_on`Ck00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oT6nCoi1_T00Ooi1_T00?o0000ol/d
boo;=</02_o;=</00ol0003oQGZ5ohEjQ@09ohEjQ@;o00003omaSW400ol0003oB[E:odZeBP08odZe
BP03o`000?maSW7oLHia00coLHia00?o0000oimPWonOH9l01?nOH9l00ol0003oe2_Dom@[e009om@[
e0Co00003ooV6NH00ol0003oo@;mood2o@05ood2o@Co00001_ok1?/00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on@Ki?oT6n@02?oT6n@00ol0003obcC;ol/db`09ol/db`03o`000?n5NXGoQGZ500Ko
QGZ50ol000000onSG:?o0000og6>L@0?og6>L@03o`000?m:]D[oB[E:00KoB[E:00?o0000og6>LOma
SW403OmaSW400ol0003oWf2OoimPW`05oimPW`03o`000?oD:mCoe2_D00Soe2_D00Co0000ooD:mOoe
2_Gom@[e1Ol00009onHIiP03o`000?om0_goo@;m00[oo@;m1?l00002oo/4n`03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003oi1_Ton@Ki007on@Ki003o`000?o;=<_obcC;00[obcC;00?o0000ohEjQOn5
NXD00_n5NXD3o`0000GoXebS00?o0000og6>LOmaSW403OmaSW400ol0003oB[E:odZeBP06odZeBP03
o`000?maSW7oLHia00coLHia00?o0000oimPWonOH9l01_nOH9l00ol0003oe2_Dom@[e008om@[e003
o`000?oe2_Gom@[e00Kom@[e1Ol00003onHIiP03o`000?om0_goo@;m00ooo@;m0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on@Ki?oT6n@01ooT6n@00ol0003obcC;ol/db`0:ol/db`03o`000?n5NXGo000000;o0000
2?nSG:<00ol0003oLHiaog6>L@0=og6>L@Co00001?m:]DX00ol0003oLHiaog6>L@0=og6>L@03o`00
0?nOH9ooWf2O00OoWf2O00?o0000om@[e?oD:m@01ooD:m@00ol0003om@[eooD:m@0;ooD:m@?o0000
4oom0_d00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on@Ki?oT6n@02?oT6n@3o`0000WobcC;0_l0
000<oj=LX`03o`000?maSW7oLHia00_oLHia00?o0000oiUVVOnIIYT00_nIIYT3o`000003odZeB_l0
003oLHia00koLHia00?o0000oimPWonOH9l01onOH9l00ol0003oe2_Dom@[e006om@[e003o`000?oe
2_Gom@[e00kom@[e00?o0000ood2oOom0_d04_om0_d00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on@Ki?oT6n@01_oT6n@01?l0003oiaSWonLHiooW6>L3o`0000KobcC;00?o0000oj=LXonSG:<03?nS
G:<00ol0003oLHiaog6>L@09og6>L@03o`000?nIIYWoVFJI00KoVFJI00?o0000og6>LOmaSW403Oma
SW400ol0003oWf2OoimPW`09oimPW`03o`000?oD:mCoe2_D00Goe2_D00?o0000ooD:mOoe2_D03_oe
2_D00ol0003oo@;mood2o@0Bood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003oi1_Ton@Ki005
on@Ki003o`000?oW6>OoiaSW00GoiaSW0ol00002ol/db`03o`000?nSG:?oXebS00goXebS00?o0000
og6>LOmaSW402?maSW400ol0003oVFJIoiUVV@07oiUVV@03o`000?maSW7oLHia00coLHia0ol0000:
oimPW`03o`000?oD:mCoe2_D00Goe2_D00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0B
ood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki004on@Ki003o`000?oW6>OoiaSW
00WoiaSW0_l0000Aoj=LX`03o`000?maSW7oLHia00GoLHia0_l0000;oiUVV@03o`000?maSW7oLHia
00[oLHia00Go0000okU6^OniA[Wo^DJio`00000:oimPW`03o`000?oD:mCoe2_D00Coe2_D00?o0000
ooD:mOoe2_D03_oe2_D00ol0003oo@;mood2o@0Cood2o@03o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oT6nCoi1_T
00;oi1_T00?o0000onLHiooW6>L02_oW6>L2o`00017oXebS00?o0000og6>LOmaSW401?maSW400ol0
003oVFJIoiUVV@0<oiUVV@03o`000?maSW7oLHia00OoLHia0_l00005okU6^@;o00002?nOH9l00ol0
003oe2_Dom@[e004om@[e003o`000?oe2_Gom@[e00gom@[e00?o0000ood2oOom0_d05?om0_d00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003oi1_Ton@Ki?oT6nCo000000coiaSW00Co0000omTV
fOoI9]Wo00004OnSG:<00ol0003oLHiaog6>L@02og6>L@03o`000?nIIYWoVFJI00koVFJI00?o0000
og6>LOmaSW401OmaSW400ol0003o^DJiokU6^@07okU6^@03o`000?nOH9ooWf2O00KoWf2O00?o0000
om@[e?oD:m@00ooD:m@00ol0003om@[eooD:m@0=ooD:m@03o`000?om0_goo@;m01Coo@;m00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on@Ki?oT6nCo00003?oW6>L00ol0003ofBKIomTVf@02omTVf@03o`000?nSG:?o
XebS00ooXebS00Co0000og6>LOmaSW7o00004OnIIYT00ol0003oLHiaog6>L@04og6>L@03o`000?ni
A[Wo^DJi00Wo^DJi00?o0000oimPWonOH9l01OnOH9l00ol0003oe2_Dom@[e003om@[e003o`000?oe
2_Gom@[e00gom@[e00?o0000ood2oOom0_d05Oom0_d00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onLHi`03o`000?oI9]WofBKI00?ofBKI00?o0000oj=LXonSG:<03onSG:<00ol0003oLHiao`00000C
oiUVV@04o`000?maSW7oLHiaog6>L@;o00003OniA[T2o`0000KoWf2O00Go0000om@[e?oD:mCoe2_D
o`00000@ooD:m@03o`000?om0_goo@;m01Coo@;m0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02_oW
6>L00ol0003ofBKIomTVf@05omTVf@03o`000?nSG:?oXebS00ooXebS00?o0000oiUVVOnIIYT04onI
IYT00ol0003oLHiao`00000AokU6^@03o`000?nOH9ooWf2O00?oWf2O00Go0000om@[e?oD:mCoe2_D
o`00000>ooD:m@?o00005?om0_d2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02OoW
6>L00ol0003ofBKIomTVf@07omTVf@03o`000?nSG:?oXebS00koXebS00?o0000oiUVVOnIIYT05?nI
IYT00ol0003o^DJiokU6^@0AokU6^@;o00001?nOH9l01?l0003oe2_Dom@[e?l0000:ooD:m@Co0000
0oom0_d00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onLHiooW6>L02OoW6>L00ol0003ofBKIomTVf@08omTVf@03o`000?nSG:?oXebS00_oXebS0ol0
000GoiUVV@03o`000?niA[Wo^DJi01?o^DJi00Ko0000oimPWonOH9ooWf2Oo`000?oD:m@5o`0000Co
m@[e0ol00008ood2o@03o`000?om0_goo@;m00goo@;m0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oW6>OoiaSW00SoiaSW00?o0000omTVfOoI9]T02_oI9]T00ol0003oXebSoj=LX`07oj=LX`?o0000
0_nbCK800ol0003oVFJIoiUVV@0EoiUVV@;o00005OniA[T00ol0003oWf2OoimPW`02o`0000Goka3_
1?l0000<ood2o@03o`000?om0_goo@;m00[oo@;m0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onLHiooW6>L01ooW
6>L00ol0003ofBKIomTVf@0;omTVf@03o`000?nSG:?oXebS00CoXebS0ol00006ok9=/P03o`000?nI
IYWoVFJI01?oVFJI00Co0000olXeb_o:=L[o00005OniA[T2o`0000Woka3_00?o0000ood2oOom0_d0
3?om0_d00ol0003oo@;mood2o@07ood2o@;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiaSW00?o0000omTVfOoI9]T03OoI9]T00ol0003oXebSoj=L
X`03o`0000[o/Tfb00?o0000oiUVVOnIIYT04OnIIYT00ol0003obSG:olXebP02olXebP03o`000?ni
A[Wo^DJi01;o^DJi00?o0000onl@koo_4>l02?o_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om
0_goo@;m00Coo@;m0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiaSWonLHi`05onLHi`03o`000?oI9]WofBKI00oofBKI0_l0000>
ok9=/P03o`000?nIIYWoVFJI00ooVFJI00?o0000olXeb_o:=LX01?o:=LX00ol0003o^DJiokU6^@0@
okU6^@;o00002oo_4>l00ol0003oo@;mood2o@0=ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onLHiooW6>L00ooW6>L00ol0003ofBKIomTVf@0@omTVf@03o`000?nbCK;o/Tfb
00go/Tfb00?o0000oiUVVOnIIYT03_nIIYT00ol0003obSG:olXebP06olXebP;o00003_niA[T2o`00
0003omPWf?l0003oka3_00[oka3_00?o0000ood2oOom0_d03_om0_d01?l0003oo@;mo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiaSWonLHiooW6>Oo000001;ofBKI00?o0000ok9=/_nbCK803onbCK800ol0003oVFJIoiUVV@0<
oiUVV@03o`000?o:=L[obSG:00WobSG:00?o0000okU6^OniA[T02OniA[T2o`0000?of2OH00?o0000
onl@koo_4>l02Oo_4>l00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiaSWo`00000ComTV
f@03o`000?nbCK;o/Tfb013o/Tfb00?o0000oiUVVOnIIYT02_nIIYT00ol0003obSG:olXebP0;olXe
bP03o`000?niA[Wo^DJi00Go^DJi0ol00006omPWf003o`000?o_4>ooka3_00Soka3_00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omTVfOoI9]T04OoI9]T00ol0003o/Tfbok9=/P0Aok9=/P03o`000?nIIYWoVFJI00Wo
VFJI00?o0000olXeb_o:=LX03Oo:=LX00ol0003o^DJiokU6^@02okU6^@;o00002OoH9mP00ol0003o
ka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017ofBKI00?o0000ok9=/_nbCK80
4_nbCK800ol0003oVFJIoiUVV@07oiUVV@03o`000?o:=L[obSG:00oobSG:00Co0000okU6^Ol0003o
00002ooH9mP00ol0003oka3_onl@k`09onl@k`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000kofBKI00?o0000ok9=/_nbCK804onbCK800ol0003oVFJIoiUVV@05oiUVV@03o`00
0?o:=L[obSG:017obSG:00?o0000omPWf?oH9mP03?oH9mP00ol0003oka3_onl@k`08onl@k`03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;omTVf@;o00005_nbCK87o`0001CobSG:00?o
0000omPWf?oH9mP03?oH9mP00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oI9]T00ol0003ocC;=o`000002o`0001;o/Tfb00?o0000oke2_Onm@[d00_nm
@[d00ol0003o]DZeo`00000DolXebP03o`000?oH9mSof2OH00cof2OH00?o0000onl@koo_4>l02?o_
4>l00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoI9]T00ol0003ocC;=oldbc@03
oldbc@;o00003onbCK800ol0003o_D:moke2_@03oke2_@04o`000?neB[Go]DZeo`0001?obSG:00?o
0000omPWf?oH9mP03OoH9mP00ol0003oka3_onl@k`08onl@k`03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003omTVfOl0003o
cC;=00OocC;=0ol0000;ok9=/P03o`000?nm@[go_D:m00Co_D:m00Go0000okE:]OneB[Go]DZeo`00
000BolXebP03o`000?oH9mSof2OH00gof2OH00?o0000onl@koo_4>l01oo_4>l?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04?oh1oP0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o=</gocC;=00[ocC;=0_l00008ok9=/P03o`000?nm@[go
_D:m00Go_D:m00?o0000okE:]OneB[D00_neB[D00ol0003obSG:olXebP0?olXebP03o`000?oH9mSo
f2OH00gof2OH00?o0000onl@koo_4>l01_o_4>l00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oh1oSon0Oh00oon0Oh00?o0000on`Ck?o/4n`03oo/4n`00ol0003ocC;=oldbc@0<oldb
c@;o00001OnbCK800ol0003o_D:moke2_@06oke2_@03o`000?neB[Go]DZe00?o]DZe00?o0000olXe
b_o:=LX03_o:=LX00ol0003of2OHomPWf00>omPWf003o`000?o_4>ooka3_00Coka3_00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oh1oSon0Oh00kon0Oh00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
cC;=oldbc@0>oldbc@?o000000?o/Tfbo`000?nm@[d02?nm@[d00ol0003o]DZeokE:]@04okE:]@03
o`000?o:=L[obSG:00gobSG:4_l00005onl@k`03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooP7n003o`000?o/4ncok1?/00ook1?/0_l0000Coldbc@03o`000?nm@[go_D:m00So_D:m
00?o0000okE:]OneB[D01OneB[D00ol0003obSG:olXebP0<olXebP03o`000?ob3O;olPgb00oolPgb
00Go0000onl@koo_4>ooka3_o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n0Oh00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000Coldbc@03o`000?nm@[go_D:m00So
_D:m00?o0000okE:]OneB[D01OneB[D00ol0003obSG:olXebP0;olXebP03o`000?ob3O;olPgb017o
lPgb00?o0000onl@kol000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o=</gocC;=013o
cC;=00?o0000oke2_Onm@[d02?nm@[d00ol0003o]DZeokE:]@06okE:]@03o`000?o:=L[obSG:00[o
bSG:00?o0000oo8=l_ob3O804_ob3O800ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on0OhooP7n009ooP7n003o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?nm@[go_D:m00Wo_D:m00?o0000okE:]OneB[D0
1oneB[D00ol0003obSG:olXebP09olXebP03o`000?ob3O;olPgb01;olPgb00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?nm@[go_D:m00Wo_D:m00?o
0000okE:]OneB[D02?neB[D00ol0003obSG:olXebP07olXebP03o`000?ob3O;olPgb01?olPgb00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooP7n?oh1oP02?oh1oP0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000oldbcOo=</d03Oo=</d2
o`0000_o_D:m00?o0000okE:]OneB[D02OneB[D00ol0003obSG:olXebP06olXebP03o`000?ob3O;o
lPgb01?olPgb4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on0OhooP7n006ooP7n003o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003ocC;=oldbc@0;oldbc@;o000000?ocC;=o`000?nm@[d02_nm@[d00ol0
003o]DZeokE:]@09okE:]@Ko00000oo:=LX00ol0003olPgboo8=lP0Coo8=lP03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooP7n?oh1oP01?oh1oP3o`00
00Sok1?/0_l0000;on@Ki003o`000?o=</gocC;=00WocC;=0_l00004oldbc@03o`000?nm@[go_D:m
00So_D:m00?o0000okE:]OneB[D02?neB[D00ol0003ogB;MomdRg@04omdRg@?o00005?ob3O83o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on0OhooP7n003o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o=</gocC;=00Go
cC;=0ol00007oldbc@03o`000?nm@[go_D:m00Oo_D:m00?o0000okE:]OneB[D01oneB[D00ol0003o
gB;MomdRg@08omdRg@03o`000?ob3O;olPgb013olPgb00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000oldb
cOo=</d00oo=</d2o`0000[ocC;=00?o0000oke2_Onm@[d01onm@[d00ol0003o]DZeokE:]@05okE:
]@;o00003?oM8]d00ol0003olPgboo8=lP0=oo8=lP;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000oldbcOo=</gocC;=0_l0000=oldbc@03o`000?nm@[go_D:m00Ko_D:m00?o0000okE:
]OneB[D01?neB[D00ol0003ogB;MomdRg@0=omdRg@Co00002_ob3O800ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013ocC;=00?o0000oke2_Onm@[d01Onm@[d00ol0003o
]DZeokE:]@03okE:]@03o`000?oM8]gogB;M00kogB;M00Co0000ooH9m_of2OKomPWf1_l00003oo8=
lP03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o=</gocC;=013o
cC;=00?o0000oke2_Onm@[d01Onm@[d00ol0003o]DZeokE:]@02okE:]@03o`000?oM8]gogB;M00oo
gB;M00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000oldbcOo=</d0
4Oo=</d00ol0003o_D:moke2_@04oke2_@03o`000?neB[Go]DZe00;o00004OoM8]d00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o=</d3o`0000Co_D:m00?o0000okE:]Ol000004ooM
8]d00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003ocC;=017ocC;=0_l00003omPWf0;o00000_nm@[d2
o`0001CogB;M00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o=</gocC;=00gocC;=0_l00007omPWf0?o00005OoM8]d00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000oldbcOo=</d02_o=</d2o`0000_o
f2OH00?o0000omdRgOoM8]d04_oM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o=</gocC;=00OocC;=0_l0000=omPWf003o`000?oM8]gogB;M01;ogB;M00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000oldbcOo=</d01Oo=</d2o`0000oof2OH00?o
0000omdRgOoM8]d04_oM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000oldbcOo=</d00_o=</d2o`0001;of2OH00?o0000omdRgOoM8]d04OoM8]d0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003olPgboo8=l_l0000@onDJi@04o`000?o=</go
0000o`0001Cof2OH00?o0000omdRgOoM8]d04?oM8]d00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo8=l_ob3O800_ob3O800ol0003oiA[UonDJi@0>onDJi@03o`000?oH9mSof2OH01Cof2OH00?o0000
omdRgOoM8]d03OoM8]d4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003olPgboo8=lP03oo8=lP03o`000?oU6^GoiA[U
00goiA[U00?o0000omPWf?oH9mP05?oH9mP00ol0003ogB;MomdRg@07omdRg@Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo8=l_ob3O801Oob3O800ol0003oiA[UonDJi@0<onDJi@03
o`000?oH9mSof2OH01Gof2OH00?o0000omdRgOoM8]d01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003olPgboo8=lP06oo8=lP03o`000?oU6^GoiA[U00_oiA[U00?o0000omPWf?oH9mP0
5OoH9mP3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJ
i@0:onDJi@03o`000?oH9mSof2OH01Gof2OH00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo8=lP03o`000?oU6^GoiA[U00WoiA[U00?o0000omPWf?oH9mP05?oH9mP0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D02OoU6^D0
0ol0003of2OHomPWf00ComPWf003o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?ob3O800ol0003oiA[UonDJi@08onDJ
i@03o`000?oH9mSof2OH00oof2OH1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_ob3O800ol0003oiA[UonDJi@07onDJi@03o`000?oH9mSof2OH00Sof2OH1ol00003on/D
j`03o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo8=lP03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omPWf?oH9mSof2OH1ol0000:on/Dj`03o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000KolPgb00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
jaC[00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?ob3O800ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ojaC[01CojaC[00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000ColPgbo`000?l0003o00001?oh1oP00ol0003ojaC[on/Dj`0Bon/Dj`;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ojaC[on/D
j`0@on/Dj`04o`000?o^4NkokQ7^o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ojaC[on/Dj`0?on/Dj`03o`000?o^4NkokQ7^00;okQ7^00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o[5>_o
jaC[00kojaC[00?o0000onhAk_o^4Nh01?o^4Nh2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ojaC[on/Dj`0=on/Dj`03o`000?o^4NkokQ7^
00GokQ7^00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o[5>_ojaC[00_ojaC[00?o0000onhAk_o^4Nh01_o^4Nh00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on/Djoo[5>/0
2_o[5>/00ol0003okQ7^onhAkP06onhAkP03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ojaC[
on/Dj`09on/Dj`03o`000?o^4NkokQ7^00OokQ7^00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o[5>_ojaC[00SojaC[00?o
0000onhAk_o^4Nh02?o^4Nh00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o[5>_ojaC[00OojaC[00?o0000onhAk_o^4Nh02?o^4Nh0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ojaC[on/Dj`05on/Dj`03o`000?o^4NkokQ7^00WokQ7^00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o[5>_ojaC[00Co
jaC[00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ojaC[on/Dj`03on/Dj`03o`00
0?o^4NkokQ7^00[okQ7^00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ojaC[on/D
j`02on/Dj`03o`000?o^4NkokQ7^00_okQ7^00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ojaC[on/Djol0000>onhAkP03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o^4Nh00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000WokQ7^00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000GokQ7^00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?okQ7^o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00[o
003o2Oooo`08o`00o`03oeEEZOooo`3ogMdQ00Wo003o00?o<S;<ojVYEOo^kQ000oooo`001?oMgB7o
ZJUEofIVV?l@4>h;o`00o`;oool0VOl00?l1ooooo`00WOl00?l00onHV6Koool0ogMgQ`07o`00o`03
oiRHI_ooo`3oMgN700co003o0_ooo`0;o`00o`03ob4QgOnHV6Koool000;oool000?oEEFYo`00ool0
0?l02Ol00?l2oooo0003ob4QgOl00?oo003o00Ko003o1?ooo`001onj^TCo8B7Mo`00oolb</coZJUE
oooo0?mgMhL02_l00?l2oooo09Wo003o0Oooool009go003o00?ok^h@oooo0?oMgB401ol00?l00oo^
kQ3oool0omgM8@0<o`00o`;oool03Ol00?l3oooo00co003o00?oZJUEoooo0?nHV6H02?l00?l01?nj
^TCoool0olc<<_m4A;X5o`00o`03ofIVV?ooo`3oZJUE00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00
o`05oc8bc?ooo`3oool0oooo0?l@4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_oo
o`0=o`00o`?oool03?l00?l00olb</coool0onk^400Bo`00o`03ojVYEOooo`3oZJUE00So003o0_oo
o`2Io`00o`7ooooo002Lo`00o`05ojVYEOooo`3oool0oooo0?mVIYP01Ol00?l01OnHV6Koool0oooo
0?ooo`3oMgN700_o003o0_ooo`0=o`00o`?oool03Ol00?l00oo^kQ3oool0odA4^P0Ao`00o`04oc8b
c?ooo`3oool0odA4^POo003o0_ooo`2Io`00o`7ooooo002Lo`00o`?oool000?oIVJHokZjA?l00?l0
1?l00?l01Oo^kQ3oool0oooo0?mVIYSogMdQ00_o003o0_ooo`0=o`00o`?oool03Ol00?l00on7QgOo
ool0ojVYE@0Bo`00o`;oool000?o^[Y4o`00ool00?l01Ol00?l2oooo09Wo003o0Oooool009_o003o
00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o413^00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^
kQ3o8B7M00[o003o0_ooo`0=o`00o`?oool03Ol00?l00olQ8Mgoool0oooo000Bo`00o`?oool01ol0
0?l2oooo09Wo003o0Oooool009_o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoIVJH00?o003o
00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN700[o003o0_ooo`0=o`00o`?oool03_l00?l00ooM
gB7oool0ofIVV00@o`00o`04oeEEZOooo`3oool0oooo00Oo003o0_ooo`2Io`00o`7ooooo002Ko`00
o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l00?ooA4BjomgM8@[o003o0_oo
o`0=o`00o`?oool03_l00?l00omVIYSoool0okZjA00@o`00o`04okZjA?ooo`3oool0oooo00Oo003o
0_ooo`2Io`00o`7ooooo002Jo`00o`04oeEEZOooo`3oool0omgM8@?o003o00Coool0o`00ool00?oo
EEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0ob4Qg@Wo003o0_ooo`0=o`00o`?oool03_l00?l0
1?l@4>koool0oooo0?l@4>h>o`00o`05ojVYEOooo`3oool0oooo0?nYZED01ol00?l2oooo09Wo003o
0Oooool009[o003o00CoZJUEoooo0?ooo`3oMgN70ol00?l01?nYZEGoEEFYo`00oonYZED2oooo0006
oiRHI_l00?oo003oo`00oonYZEGoMgN72Ol00?l2oooo00go003o0oooo`0?o`00o`03okZjA?ooo`3o
MgN700co003o00?o<S;<olc<<_ooo`000oooo`000olQ8Mgo003oo`00o`05o`00o`;oool0VOl00?l1
ooooo`00V_l00?l3oooo0007ob4QgOl00?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l0
0?oo003oo`00oomEEJWogMdQ2Ol00?l2oooo00go003o0oooo`0?o`00o`03oeEEZOooo`3ogMdQ00Wo
003o00?oA4BjogMgQooMgB401Oooo`000omVIYSo003oo`00o`06o`00o`;oool0VOl00?l1ooooo`00
VOl00?l01?mEEJWoool0oooo0?oMgB45o`00o`05onk^4?mEEJWoool0oooo0?o^kQ001Ol00?l00ooo
o`3o8B7Mo`00o`07o`00o`;oool03Ol00?l3oooo013o003o0_ooo`000olQ8Mgo003oo`00o`03o`00
o`03oc8bc?ooo`3oool000Ooool000?oIVJHo`00ool00?l01ol00?l2oooo09Wo003o0Oooool009Wo
003o00CoZJUEoooo0?ooo`3oMgN71Ol00?l01Onj^TCok^h@oooo0?ooo`3oQhMg00Go003o00?oZJUE
ogMgQol00?l01ol00?l2oooo00go003o0oooo`0@o`00o`03ojVYEOooo`3oQhMg00Go003o00?o8B7M
oooo0?ooo`001Oooo`000onYZEGo8B7Mo`00o`09o`00o`;oool0VOl00?l1ooooo`00V?l00?l01Ol@
4>koool0oooo0?ooo`3o8B7M00Go003o00GoIVJHoooo0?ooo`3oool0ob4Qg@05o`00o`03oeEEZOoM
gB7o003o00Oo003o0_ooo`0=o`00o`?oool04?l00?l00olb</coool0onk^4006o`00o`07ojVYEOoo
o`3ok^h@olc<<_n7QgOoEEFYoa0@kP0<o`00o`;oool0VOl00?l1ooooo`00V?l00?l01?mVIYSoool0
oooo0?oMgB46o`00o`04ofIVV?ooo`3oool0omgM8@Oo003o00?oool0ob4QgOl00?l01_l00?l2oooo
00go003o0oooo`06o`00o`03oeEEZOl@4>ko003o00So003o00?ok^h@oooo0?lb</`01Ol00?l00olQ
8Mgok^h@o`00o`0@o`00o`;oool0VOl00?l1ooooo`00V?l00?l01?o<c3;oool0oooo0?mgMhL6o`00
o`04okZjA?ooo`3oool0ogMgQ`Oo003o00?oZJUEogMgQol00?l01_l00?l2oooo00go003o0oooo`06
o`00o`;o^[Y42Ol00?l00on7QgOoool0ojVYE@06o`00o`03olc<<_mEEJWo003o00oo003o0_ooo`2I
o`00o`7ooooo002Go`00o`05ob4QgOooo`3oool0oooo0?lQ8Md01Ol00?l01Ol@4>koool0oooo0?oo
o`3o8B7M00Oo003o00?oEEFYomgM8Ol00?l01_l00?l2oooo00[o003o00?oc<`bofIVV?mgMhL00ooo
o`06o`00o`04oeEEZOooo`3o^[Y4ob4Qg@Oo003o00?o8B7Moooo0?ooo`001_l00?l00om4A;[oc<`b
o`00o`0?o`00o`;oool0VOl00?l1ooooo`00Uol00?l01?nYZEGoool0oooo0?oMgB46o`00o`04ogMg
Qoooo`3oool0omgM8@Wo003o00?oool0ob4QgOl00?l01Ol00?l2oooo00[o003o00?oA4Bjolc<<_oo
o`000oooo`07o`00o`03onk^4?ooo`3oool000[oool000?oEEFYo`00ool00?l01?l00?l00oo<c3;o
ool0oooo0005oooo0003olc<<_l00?oo003o00Ko003o0_ooo`2Io`00o`7ooooo002Eo`00o`03ob4Q
gOn7QgOoool000;oool000?ok^h@oc8bc?l00?l00ol00?l01_mEEJWoool0oooo0?ooo`3ok^h@oc8b
c0Ko003o00Ko8B7MohN7Moooo`3ok^h@oeEEZOl@4>h4o`00o`;oool03?l00?l01?m4A;[ok^h@oooo
0?ooo`07o`00o`03ohN7Moooo`3oool000[oool000?o^[Y4o`00ool00?l01?l00?l00omVIYSoool0
oooo0006oooo0003ob4QgOl00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Do`00o`03odA4^_oo
o`3oool000Ooool000?oQhMgoooo0?ooo`001oooo`02o`00o`03ohN7Moooo`3oool000Goool000Co
A4Bjo`00ool00?oo003o0_ooo`000omgMhOo003oo`00o`0;o`00o`03ofIVV?o^kQ3o003o00Ko003o
00?o8B7Moooo0?ooo`002oooo`07o`00o`03onk^4?ooo`3oool000Goool000?oMgN7o`00ool00?l0
1?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`Ooool0;_l00?l01?mgMhOogMdQo`00
ool00?l7oooo09Wo003o0Oooool00>co003o00?o8B7Mo`00ool00?l0X?l00?l1ooooo`00ool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(200) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.985 .015 .985 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.963 .037 .963 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.897 .103 .897 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.903 .097 .903 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.973 .027 .973 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.927 .073 .927 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.905 .095 .905 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.805 .195 .805 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.894 .106 .894 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.938 .062 .938 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.817 .183 .817 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.939 .061 .939 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.525 .475 .525 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.473 .527 .473 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.776 .224 .776 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.905 .095 .905 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.924 .076 .924 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.676 .324 .676 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.584 .416 .584 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.785 .215 .785 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.893 .107 .893 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.984 .016 .984 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.848 .152 .848 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.949 .051 .949 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.436 .564 .436 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.959 .041 .959 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.21 .79 .21 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.467 .533 .467 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.385 .615 .385 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.179 .821 .179 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.755 .245 .755 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.141 .859 .141 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.48 .52 .48 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.943 .057 .943 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.62 .38 .62 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.804 .196 .804 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.382 .618 .382 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.15 .85 .15 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.189 .811 .189 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.08 .92 .08 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.69 .31 .69 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.805 .195 .805 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.847 .153 .847 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.884 .116 .884 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.144 .856 .144 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.078 .922 .078 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.06 .94 .06 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.236 .764 .236 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.388 .612 .388 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.923 .077 .923 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.972 .028 .972 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.72 .28 .72 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.083 .917 .083 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.934 .066 .934 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.396 .604 .396 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.739 .261 .739 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.191 .809 .191 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.56 .44 .56 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.969 .031 .969 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.704 .296 .704 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.212 .788 .212 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.979 .021 .979 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.472 .528 .472 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.067 .933 .067 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.044 .956 .044 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.866 .134 .866 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.865 .135 .865 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.096 .904 .096 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.344 .656 .344 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.782 .218 .782 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.931 .069 .931 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.054 .946 .054 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.04 .96 .04 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.14 .86 .14 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.325 .675 .325 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.689 .311 .689 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.633 .367 .633 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.216 .784 .216 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.069 .931 .069 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.985 .015 .985 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.964 .036 .964 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.044 .956 .044 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.514 .486 .514 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.838 .162 .838 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.947 .053 .947 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.301 .699 .301 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.786 .214 .786 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.119 .881 .119 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.98 .02 .98 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.93 .07 .93 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.132 .868 .132 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.379 .621 .379 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.725 .275 .725 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.956 .044 .956 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.936 .064 .936 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.876 .124 .876 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.774 .226 .774 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.986 .014 .986 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.817 .183 .817 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.922 .078 .922 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.805 .195 .805 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.929 .071 .929 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.989 .011 .989 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.922 .078 .922 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.98 .02 .98 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.957 .043 .957 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.977 .023 .977 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.979 .021 .979 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?l000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003oo0?loo`3o?ol0oco
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ol0ocoo0?l00Ko
o0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ol0oco
o0?l00_oo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooh1oP00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooP7n0;o00003oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooh
1oP2o`0000_ooP7n00?o0000oo`3o?ol0o`04Ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;on0Oh00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooP7n003o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`05?ol0o`00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oh1oP2o`0000KooP7n00?o0000oo`3
o?ol0o`05Ool0o`00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oh1oP00ol0003ooP7nooh1oP03ooh1oP03o`000?ol0oco
o0?l01Koo0?l00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom@[eo`000?oa3_7o0000on8Mh_l0000JooP7n0;o00000_on0Oh00ol0003oo0?l
oo`3o00Hoo`3o003o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om@[e00Co0000oo4>lOoa3_7o00000_oR7N800ol0003on0OhooP7n00IooP7
n003o`000?on0Oko000001_oo0?l00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005ooD:m@05o`000?oa3_7ol@kaoo4>
lOl000000ooR7N800ol0003on0OhooP7n00IooP7n003o`000?ol0ocoo0?l01[oo0?l00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oe2_D01Ol0003ol@kaoo4>lOoa3_7o000000CohQgR00?o0000ooP7
n?oh1oP06?oh1oP00ol0003oo0?loo`3o00Ioo`3o003o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om@[e00?o0000oo4>lOoa
3_400_oa3_400ol0003ohQgRon8MhP03on8MhP03o`000?oh1oSon0Oh01Oon0Oh00?o0000oo`3o?ol
0o`06Ool0o`00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooe2_D00ol0003ol@kaoo4>l@02oo4>l@03o`000?oR7N;ohQgR00Co
hQgR00?o0000ooP7n?oh1oP05ooh1oP00ol0003oo0?loo`3o00Hoo`3o003o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?ooD:m@03o`00
0?oa3_7ol@ka00?ol@ka00?o0000on8Mh_oR7N801OoR7N800ol0003on0OhooP7n00FooP7n003o`00
0?ol0ocoo0?l01Ooo0?l00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000AooD:m@03o`000?oa3_7ol@ka00Col@ka00?o0000on8Mh_oR7N801_oR
7N82o`0001Gon0Oh0ol0000Hoo`3o003o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
ooD:m@03o`000?oa3_7ol@ka00Col@ka00?o0000on8Mh_oR7N802?oR7N800ol0003on0OhooP7n00@
ooP7n0;o00000ooM8]d00ol0003oo0?loo`3o00Doo`3o003o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000ooD:mOoe2_D04_oe2_D00ol0003ol@kaoo4>l@05oo4>l@03o`000?oR7N;ohQgR
00WohQgR00?o0000ooP7n?oh1oP03Ooh1oP2o`0000KogB;M0_l0000Doo`3o003o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e01;om@[e00?o0000oo4>lOoa
3_401Ooa3_400ol0003ohQgRon8MhP0:on8MhP03o`000?oh1oSon0Oh00[on0Oh0_l0000:omdRg@03
o`000?ol0ocoo0?l017oo0?l00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om@[eooD:m@0@ooD:m@03o`000?oa3_7ol@ka00Ko
l@ka00?o0000on8Mh_oR7N802ooR7N800ol0003on0OhooP7n008ooP7n003o`000?oM8]gogB;M00_o
gB;M0_l0000@oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo4>lOoa3_40
1ooa3_400ol0003ohQgRon8MhP0<on8MhP03o`000?oh1oSon0Oh00Gon0Oh0_l0000@omdRg@03o`00
0?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo4>lOoa3_401ooa3_400ol0003ohQgRon8M
hP0=on8MhP03o`000?oh1oSon0Oh00;on0Oh0_l0000ComdRg@;o00003?ol0o`00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oe2_Go
m@[e00kom@[e00?o0000oo4>lOoa3_402?oa3_400ol0003ohQgRon8MhP0>on8MhP04o`000?oh1oSo
0000o`0001OogB;M00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00Loo`3o003o`000?oj
1O[onPGj00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oe2_Go
m@[e00com@[e00?o0000oo4>lOoa3_402Ooa3_400ol0003ohQgRon8MhP0?on8MhP03o`000?oM8]go
gB;M01SogB;M0_l00009oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000ooX5n_oj1OX01?oj1OX4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>ooD:m@03o`000?oa3_7ol@ka
00Wol@ka00?o0000on8Mh_oR7N803ooR7N800ol0003ogB;MomdRg@0JomdRg@03o`000?ol0ocoo0?l
00Coo0?l0ol0000Loo`3o003o`000?oj1O[onPGj00WonPGj0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o`3o3ol0o`o`0000com@[e00?o0000oo4>lOoa3_402_oa3_400ol0003ohQgRon8MhP0?on8M
hP03o`000?oM8]gogB;M01_ogB;M0_l00003oo`3o004o`000?o_4>ooka3_onl@k`?o00006?ol0o`0
0ol0003onPGjooX5nP0=ooX5nP?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00;ol0o`00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ol@kaoo4>l@0:oo4>l@03o`000?oR7N;ohQgR
00kohQgR00?o0000omdRgOoM8]d07_oM8]d00ol0003oo0?lo`000007onl@k`?o00005?ol0o`00ol0
003onPGjooX5nP0AooX5nP;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o`3o000ol0003om@[eooD:m@07ooD:m@03
o`000?oa3_7ol@ka00_ol@ka00?o0000on8Mh_oR7N803_oR7N800ol0003ogB;MomdRg@0OomdRg@03
o`000?o_4>ooka3_00Woka3_0ol0000@oo`3o003o`000?oj1O[onPGj01?onPGj00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol0o`
oo0?l007oo0?l003o`000?oe2_Gom@[e00Gom@[e00?o0000oo4>lOoa3_403?oa3_400ol0003ohQgR
on8MhP0>on8MhP03o`000?oM8]gogB;M01oogB;M00?o0000onl@koo_4>l03?o_4>l3o`0000goo0?l
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ol0o`00?o0000ooD:mOoe2_D01?oe
2_D00ol0003ol@kaoo4>l@0<oo4>l@03o`000?oR7N;ohQgR00kohQgR00?o0000omdRgOoM8]d07_oM
8]d00ol0003oka3_onl@k`0@onl@k`?o00002Ool0o`00ol0003onPGjooX5nP0FooX5nPOo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000oo0?l?o`3o003?o`3o000ol0003om@[eooD:m@02ooD:m@03o`000?oa
3_7ol@ka00gol@ka00?o0000on8Mh_oR7N803_oR7N800ol0003ogB;MomdRg@0NomdRg@03o`000?o_
4>ooka3_01?oka3_0ol00005oo`3o003o`000?oj1O[onPGj01OonPGj00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00kol0o`00Go0000
ooD:mOoe2_Gom@[eo`00000?oo4>l@03o`000?oR7N;ohQgR00gohQgR00?o0000omdRgOoM8]d07ooM
8]d00ol0003oka3_onl@k`0Fonl@k`?o000000?oo0?lo`000?oj1OX06?oj1OX00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Boo0?l003o`000?oe2_Go0000013ol@ka00?o0000on8Mh_oR7N802ooR7N83
o`00023ogB;M00?o0000onl@koo_4>l06_o_4>l00ol0003onPGjooX5nP0HooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`01?ol0o`00?o0000oo4>
lOoa3_403ooa3_400ol0003ohQgRon8MhP07on8MhPCo00000_nhAkP00ol0003ogB;MomdRg@0NomdR
g@03o`000?o_4>ooka3_01[oka3_00?o0000ooX5n_oj1OX05ooj1OX00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
l0o`00?o0000oo4>lOoa3_403ooa3_400ol0003ohQgRon8MhP03on8MhPCo00001onhAkP00ol0003o
gB;MomdRg@0LomdRg@03o`000?o_4>ooka3_01coka3_00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000oo0?l?o`3o005oo`3o000ol0003ol@kaoo4>l@0>oo4>l@03o`00
0?oR7N;o000000?o00003?nhAkP00ol0003ogB;MomdRg@0KomdRg@03o`000?o_4>ooka3_01coka3_
00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o`
3o05o`0000_ol@ka0ol0000AokQ7^003o`000?oM8]gogB;M01[ogB;M00?o0000onl@koo_4>l07Oo_
4>l00ol0003onPGjooX5nP0CooX5nP03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o`3o3ol0o`01Wol0o`00?o0000
ol4n`Oo1?/400_o1?/47o`0000?ol@ka00?o0000okQ7^?nhAkP04onhAkP3o`0001OogB;M0_l0000P
onl@k`03o`000?oj1O[onPGj01?onPGj00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000oo0?l?o`3o006?o`3o000ol0
003o`Ck1ol4n`@0:ol4n`@?o00005_nhAkP00ol0003oN8MhogR7N005o`00013ogB;M0_l000000onR
GJ;o0000onl@k`0Oonl@k`03o`000?oj1O[onPGj01;onPGj00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000oo0?l?o`3o005_o`3o000ol0003o`Ck1ol4n`@0=ol4n`@03
o`000?nhAkSo^4Nh01?o^4Nh00?o0000ogR7N?mhQgP01_mhQgP4o`0000_ogB;M00?o0000oj9MX_nR
GJ800_nRGJ800ol0003oka3_onl@k`0Nonl@k`03o`000?oj1O[onPGj013onPGj00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ol0o`oo0?l00Doo0?l003o`000?o1?/7o`Ck100oo`Ck1
00?o0000okQ7^?nhAkP04_nhAkP00ol0003oN8MhogR7N00:ogR7N0Go00001?oM8]d2o`0000GoXUfR
00?o0000onl@koo_4>l07_o_4>l00ol0003onPGjooX5nP0@ooX5nP03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o`
3o3ol0o`01Col0o`00?o0000ol4n`Oo1?/403oo1?/400ol0003o^4NhokQ7^00BokQ7^003o`000?mh
QgSoN8Mh00ooN8Mh1?l00008oj9MXP03o`000?o_4>ooka3_01koka3_00?o0000ooX5n_oj1OX03_oj
1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
oo0?l?o`3o004_o`3o000ol0003o`Ck1ol4n`@0@ol4n`@03o`000?nhAkSo^4Nh017o^4Nh00?o0000
ogR7N?mhQgP04OmhQgP00ol0003oDjaCo`000009oj9MXP03o`000?o_4>ooka3_01goka3_00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000oo0?l?o`3o003_o`3o03o`0001Co`Ck100?o0000okQ7^?nhAkP04?nhAkP00ol0
003oN8MhogR7N00@ogR7N004o`000?mC[5?oDjaCo`0000WoXUfR00?o0000onl@koo_4>l07_o_4>l0
0ol0003onPGjooX5nP0<ooX5nP03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000oo0?l?o`3o002_o`3o04o`0000;oaSW600?o0000ol4n
`Oo1?/404_o1?/400ol0003o^4NhokQ7^00@okQ7^003o`000?mhQgSoN8Mh00ooN8Mh00Go0000oe>/
DomC[5?oDjaCo`00000:oj9MXP03o`000?o_4>ooka3_01goka3_00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000oo0?
l?o`3o001Oo`3o04o`0000OoaSW600?o0000ol4n`Oo1?/404Oo1?/400ol0003o^4NhokQ7^00?okQ7
^003o`000?mhQgSoN8Mh013oN8Mh00Go0000oe>/DomC[5?oDjaCo`00000:oj9MXP03o`000?o_4>oo
ka3_01goka3_00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o`3o3o
l0o`00Co00002oo6>LH00ol0003o`Ck1ol4n`@0Bol4n`@03o`000?nhAkSo^4Nh00ko^4Nh00?o0000
ogR7N?mhQgP03omhQgP00ol0003oDjaCoe>/D`02oe>/D`03o`000?nRGJ;oXUfR00WoXUfR00?o0000
onl@koo_4>l07?o_4>l3o`0000[onPGj00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000ondBkOl0003o00003oo6>LH00ol0003o`Ck1ol4n`@0Aol4n`@03o`000?mQ
WV7o000000oo^4Nh00?o0000ogR7N?mhQgP03_mhQgP00ol0003oDjaCoe>/D`03oe>/D`03o`000?nR
GJ;oXUfR00WoXUfR00?o0000onl@koo_4>l06Oo_4>l3o`0000?ok1?/00?o0000ooX5n_oj1OX01ooj
1OX00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o]4^gokA;]o`00017oaSW600?o
0000ol4n`Oo1?/403oo1?/401Ol0003oHIiQof6NHOmQWV7o000000[o^4Nh1?l0000AogR7N003o`00
0?mC[5?oDjaC00?oDjaC00?o0000oj9MX_nRGJ802_nRGJ800ol0003oka3_onl@k`0Fonl@k`;o0000
1oo/4n`00ol0003onPGjooX5nP05ooX5nP03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003okA;]ondBk@02ondBk@03o`000?o6>LKoaSW600koaSW600?o
0000ol4n`Oo1?/403_o1?/400ol0003oHIiQof6NH@03of6NH@04o`000?nhAkSo^4NhokQ7^0Ko0000
0omUVVD00ol0003oN8MhogR7N00>ogR7N003o`000?mC[5?oDjaC00CoDjaC00?o0000oj9MX_nRGJ80
2_nRGJ800ol0003oka3_onl@k`0Conl@k`?o00002_o/4n`00ol0003onPGjooX5nP03ooX5nP03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o]
4^gokA;]00?okA;]00?o0000olHia_o6>LH03_o6>LH00ol0003o`Ck1ol4n`@0=ol4n`@03o`000?mQ
WV7oHIiQ00GoHIiQ0ol0000:ofFJI@03o`000?mhQgSoN8Mh00coN8Mh00?o0000oe>/DomC[5<01OmC
[5<00ol0003oXUfRoj9MXP0;oj9MXP03o`000?o_4>ooka3_013oka3_0_l0000>on`Ck003o`000?oj
1O[onPGj00;onPGj00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o]4^gokA;]00CokA;]00?o0000olHia_o6>LH03oo6>LH00ol0003o`Ck1ol4n`@0;
ol4n`@03o`000?mQWV7oHIiQ00KoHIiQ00?o0000ofFJIOmUVVD02omUVVD00ol0003oN8MhogR7N00;
ogR7N003o`000?mC[5?oDjaC00GoDjaC00?o0000oj9MX_nRGJ803?nRGJ800ol0003oka3_onl@k`0<
onl@k`?o00004Oo/4n`5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o]4^gokA;]
00KokA;]00?o0000olHia_o6>LH03_o6>LH00ol0003o`Ck1ol4n`@0:ol4n`@03o`000?mQWV7oHIiQ
00OoHIiQ00?o0000ofFJIOmUVVD02omUVVD00ol0003oN8MhogR7N00:ogR7N003o`000?mC[5?oDjaC
00KoDjaC00?o0000oj9MX_nRGJ803?nRGJ800ol0003oka3_onl@k`0:onl@k`;o00005?o/4n`00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003okA;]ondBk@07ondB
k@03o`000?o6>LKoaSW600koaSW600?o0000ol4n`Oo1?/402Oo1?/400ol0003oHIiQof6NH@08of6N
H@03o`000?mUVVGoIIYU00coIIYU00?o0000ogR7N?mhQgP02?mhQgP00ol0003oDjaCoe>/D`07oe>/
D`03o`000?nRGJ;oXUfR00goXUfR1Ol00004onl@k`?o00005Oo/4n`00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okA;]ondBk@08ondB
k@03o`000?o6>LKoaSW600ooaSW600?o0000ol4n`Oo1?/401oo1?/400ol0003oHIiQof6NH@09of6N
H@03o`000?mUVVGoIIYU00coIIYU0ol00008ogR7N003o`000?mC[5?oDjaC00OoDjaC00?o0000oj9M
X_nRGJ803OnRGJ800ol0003o^DJiokU6^@02okU6^@Co00006?o/4n`00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o]4^gokA;]
00[okA;]00?o0000olHia_o6>LH03_o6>LH00ol0003o`Ck1ol4n`@06ol4n`@03o`000?mQWV7oHIiQ
00[oHIiQ00?o0000ofFJIOmUVVD02_mUVVD2o`0000?o<<l`00?o0000ogR7N?mhQgP01?mhQgP00ol0
003oDjaCoe>/D`08oe>/D`03o`000?nRGJ;oXUfR00coXUfR00?o0000okU6^OniA[T01_niA[T00ol0
003ok1?/on`Ck00Eon`Ck003o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000ondBkOo]4^d02oo]4^d00ol0003o
aSW6olHiaP0>olHiaP03o`000?o1?/7o`Ck100Go`Ck100?o0000of6NHOmQWV402omQWV400ol0003o
IIYUofFJI@08ofFJI@;o00001_l`cc000ol0003oN8MhogR7N002ogR7N003o`000?mC[5?oDjaC00Wo
DjaC00?o0000oj9MX_nRGJ803?nRGJ800ol0003o^DJiokU6^@07okU6^@03o`000?o/4ncok1?/01Co
k1?/00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o]4^gokA;]00gokA;]00?o0000olHia_o6>LH03_o6>LH00ol0003o`Ck1ol4n`@03ol4n`@03o`00
0?mQWV7oHIiQ00coHIiQ00?o0000ofFJIOmUVVD01_mUVVD2o`0000Wo<<l`00Go0000ogR7N?mhQgSo
N8Mho`00000;oe>/D`03o`000?nRGJ;oXUfR00coXUfR00?o0000okU6^OniA[T01oniA[T00ol0003o
k1?/on`Ck00Con`Ck003o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o]4^gokA;]00ko
kA;]00?o0000olHia_o6>LH03_o6>LH00ol0003o`Ck1ol4n`@02ol4n`@03o`000?mQWV7oHIiQ00go
HIiQ00?o0000ofFJIOmUVVD01?mUVVD2o`0000co<<l`00?o0000ogR7N?l000003?mC[5<00ol0003o
XUfRoj9MXP0;oj9MXP03o`000?niA[Wo^DJi00Wo^DJi00?o0000on`Ck?o/4n`04Oo/4n`00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003okA;]ondBk@0?ondBk@03o`000?o6>LKoaSW600koaSW600Go0000ol4n`Oo1?/7o
`Ck1o`00000@of6NH@03o`000?mUVVGoIIYU00;oIIYU0_l0000?oc3?<003o`000?mC[5?oDjaC00_o
DjaC00?o0000oj9MX_nRGJ802onRGJ800ol0003o^DJiokU6^@09okU6^@03o`000?o/4ncok1?/017o
k1?/00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000ondBkOo]4^d04Oo]4^d00ol0003oaSW6
olHiaP0>olHiaPCo00004?mQWV400ol0003oIIYUofFJI@02o`00017o<<l`00?o0000oe>/DomC[5<0
2omC[5<00ol0003oXUfRoj9MXP0:oj9MXP03o`000?niA[Wo^DJi00_o^DJi00?o0000on`Ck?o/4n`0
3oo/4n`00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ool0o`00ol0003onPGjooX5nP03ooX5nP03o`000?o]
4^gokA;]01;okA;]00?o0000olHia_o6>LH03Oo6>LH00ol0003oHYeRof:MHP02of:MHP;o00003_mQ
WV43o`0001?o<<l`00?o0000oe>/DomC[5<02omC[5<00ol0003oXUfRoj9MXP0:oj9MXP03o`000?ni
A[Wo^DJi00_o^DJi00?o0000on`Ck?o/4n`03oo/4n`00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ol0ocoo0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`00000EondBk@03o`000?o6
>LKoaSW600coaSW600?o0000of:MH_mRWF801OmRWF82o`0000coHIiQ00?o0000oc3?<?l`cc005?l`
cc000ol0003oDjaCoe>/D`0:oe>/D`03o`000?nRGJ;oXUfR00[oXUfR00?o0000okU6^OniA[T03?ni
A[T00ol0003ok1?/on`Ck00=on`Ck003o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Soo0?l00?o0000
ooX5n_l000005oo]4^d00ol0003oaSW6olHiaP0:olHiaP03o`000?mRWF;oHYeR00SoHYeR00?o0000
of6NHOmQWV402?mQWV43o`0001Go<<l`0_l0000;oe>/D`03o`000?nRGJ;oXUfR00WoXUfR00?o0000
okU6^OniA[T03_niA[T00ol0003ok1?/on`Ck00<on`Ck003o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_oo0?l00?o0000ondBkOo]4^d05_o]4^d00ol0003oaSW6olHiaP09olHiaP03o`000?mRWF;oHYeR
00[oHYeR0_l00005of6NH@?o00000olTfb@00ol0003o<<l`oc3?<00Aoc3?<003o`000?lHiaSo6>LH
00;o00002OmC[5<00ol0003oXUfRoj9MXP09oj9MXP03o`000?niA[Wo^DJi00ko^DJi00?o0000on`C
k?o/4n`02oo/4n`00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo`3o003o`000?o]4^gokA;]01Ko
kA;]00?o0000olHia_o6>LH00oo6>LH6o`0000ooHYeR0_l000000omQWV7o0000o`000007obCK90;o
00004?l`cc000ol0003o6>LHoaSW6003oaSW60?o00001_mC[5<00ol0003oXUfRoj9MXP09oj9MXP03
o`000?niA[Wo^DJi00oo^DJi00?o0000on`Ck?o/4n`02_o/4n`00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ol0o`00ol0003okA;]
ondBk@0FondBk@Go00001On]DZd00ol0003oHYeRof:MHP0?of:MHP03o`000?lTfbCo9=/T00Wo9=/T
00?o0000oc3?<?l`cc003?l`cc000ol0003o6>LHoaSW6007oaSW60;o00000_mC[5<>o`0001;o^DJi
00?o0000on`Ck?o/4n`02Oo/4n`00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ol0ocoo0?l013oo0?l00?o0000ondBkOo]4^d05Oo]
4^d00ol0003o[E:]ojeB[@09ojeB[@03o`000?mRWF;oHYeR00koHYeR00?o0000obCK9?lTfb@02_lT
fb@2o`0000_o<<l`00?o0000oaSW6?lHiaP02_lHiaP2o`0000go=lPg00?o0000okU6^OniA[T04Oni
A[T00ol0003ok1?/on`Ck007on`Ck003o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ol0o`00ol0003okA;]ondBk@0CondBk@03o`000?n]DZgo[E:]00[o[E:]00?o
0000of:MH_mRWF803_mRWF800ol0003o9=/TobCK900<obCK9003o`000?l`cc3o<<l`00Oo<<l`00?o
0000oaSW6?lHiaP02olHiaP00ol0003o=lPgocO8=`0=ocO8=`03o`000?niA[Wo^DJi013o^DJi00?o
0000on`Ck?o/4n`01oo/4n`00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo0?loo`3o00Doo`3o003o`000?o]4^gokA;]01;okA;]00?o0000ojeB[On]DZd02on]
DZd00ol0003oHYeRof:MHP0>of:MHP03o`000?lTfbCo9=/T00go9=/T00?o0000oc3?<?l`cc001?l`
cc02o`0000ko6>LH00?o0000ocO8=olgb3L03Olgb3L00ol0003o^DJiokU6^@0@okU6^@Co00001Oo/
4n`00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l01Goo0?l5?l0000?ojeB[@03o`000?mRWF;oHYeR00coHYeR00?o0000obKI9_l000003olT
fb@2o`0000?o<<l`00Co0000oa7^4OlAkQ7o00003OlHiaP00ol0003o=lPgocO8=`0>ocO8=`03o`00
0?niA[Wo^DJi00co^DJi0ol00004olHiaP?o00000_o/4n`00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`05Ool0o`00ol0003oiaSWonLH
i`0@onLHi`03o`000?n]DZgo[E:]00go[E:]00?o0000of:MH_mRWF802omRWF801?l0003o9]TVobKI
9_l0000AobCK9003o`000?l`cc3o000000Co4NhA00?o0000oaSW6?lHiaP02_lHiaP00ol0003o=lPg
ocO8=`0>ocO8=`03o`000?niA[Wo^DJi00Wo^DJi0ol0000:olHiaP;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo0?loo`3o00Eoo`3o003o`000?oW6>OoiaSW013oiaSW00?o0000ojeB[On]DZd03On]
DZd00ol0003oHYeRof:MHP0:of:MHP03o`000?lVfBKo9]TV00;o9]TV00?o0000obCK9?lTfb@03olT
fb@00ol0003o4NhAoa7^4@04oa7^4@03o`000?lHiaSo6>LH00Wo6>LH00?o0000ocO8=olgb3L03_lg
b3L00ol0003o^DJiokU6^@06okU6^@?o00003_o6>LH00ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ol0ocoo0?l01Goo0?l00?o0000
onLHiooW6>L04_oW6>L00ol0003o[E:]ojeB[@0=ojeB[@03o`000?mRWF;oHYeR00WoHYeR00?o0000
obKI9_lVfBH00_lVfBH00ol0003o9=/TobCK900?obCK9003o`000?lAkQ7o4NhA00Go4NhA00?o0000
oaSW6?lHiaP02?lHiaP00ol0003o=lPgocO8=`0?ocO8=`03o`000?niA[Wo^DJi00;o^DJi0ol0000B
olHiaP03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo0?loo`3o00Coo`3o0?o00005?oW6>L00ol0003o[E:]ojeB[@0=ojeB[@03o`000?mRWF;oHYeR
00SoHYeR00?o0000obKI9_lVfBH01?lVfBH00ol0003o9=/TobCK900>obCK9003o`000?lAkQ7o4NhA
00Ko4NhA00?o0000oaSW6?lHiaP01olHiaP00ol0003o=lPgocO8=`0?ocO8=`03o`000?niA[Wo0000
00;o00005Oo6>LH00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00ooo0?l1?l00002ooH9mP03o`000?oW6>OoiaSW01;o
iaSW00?o0000ojeB[On]DZd03On]DZd00ol0003oHYeRof:MHP07of:MHP03o`000?lVfBKo9]TV00Go
9]TV00?o0000obCK9?lTfb@03OlTfb@00ol0003o4NhAoa7^4@08oa7^4@03o`000?lHiaSo6>LH00Ko
6>LH00?o0000ocO8=olgb3L04?lgb3L00ol0003oaSW6olHiaP0FolHiaP03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02ool0o`4o`0000KomPWf
00?o0000onLHiooW6>L04ooW6>L00ol0003o[E:]ojeB[@0=ojeB[@03o`000?mRWF;oHYeR00GoHYeR
00?o0000obKI9_lVfBH01olVfBH00ol0003o9=/TobCK900<obCK9003o`000?lAkQ7o4NhA00Wo4NhA
00?o0000oaSW6?lHiaP01OlHiaP00ol0003o=lPgocO8=`0@ocO8=`03o`000?o6>LKoaSW601OoaSW6
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01ool
0o`4o`0000[omPWf00?o0000onLHiooW6>L04ooW6>L00ol0003o[E:]ojeB[@0=ojeB[@03o`000?mR
WF;oHYeR00CoHYeR00?o0000obKI9_lVfBH02?lVfBH00ol0003o9=/TobCK900<obCK9003o`000?lA
kQ7o4NhA00[o4NhA00?o0000oaSW6?lHiaP01?lHiaP00ol0003o=lPgocO8=`0@ocO8=`03o`000?o6
>LKoaSW601OoaSW600?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo0?loo`3o004oo`3o0Co00003_of2OH00ol0003oiaSWonLHi`0ConLHi`03o`000?n]DZgo
[E:]00go[E:]00?o0000of:MH_mRWF801?mRWF800ol0003o9]TVobKI9P09obKI9P03o`000?lTfbCo
9=/T00_o9=/T00?o0000oa7^4OlAkQ402olAkQ400ol0003o6>LHoaSW6003oaSW6003o`000?lgb3Oo
=lPg013o=lPg00?o0000olHia_o6>LH05oo6>LH00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo0?loo`3o004o`0001;omPWf00?o0000onLHiooW6>L04ooW6>L00ol0
003o[E:]ojeB[@0>ojeB[@03o`000?mRWF;oHYeR00;oHYeR00?o0000obKI9_lVfBH02_lVfBH00ol0
003o9=/TobCK900:obCK9003o`000?lAkQ7o4NhA00go4NhA00?o0000oaSW6?lHiaP00_lHiaP00ol0
003o=lPgocO8=`0@ocO8=`03o`000?o6>LKoaSW601SoaSW600?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oW6>OoiaSW01?oiaSW00?o0000ojeB[On]DZd03?n]DZd4o`000003of:MH_l0003o9]TV00go
9]TV00?o0000obCK9?lTfb@02OlTfb@00ol0003o4NhAoa7^4@0>oa7^4@05o`000?lHiaSo6>LHoaSW
6?l000004_lgb3L00ol0003oaSW6olHiaP0HolHiaP?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oW6>OoiaSW
01?oiaSW00?o0000ojeB[On]DZd02on]DZd00ol0003o=LXeocG:=@02ocG:=@;o00003_lVfBH00ol0
003o9=/TobCK9009obCK9003o`000?lAkQ7o4NhA00oo4NhA00Co0000oaSW6?lHiaSo00004_lgb3L0
0ol0003oaSW6olHiaP0HolHiaP03o`000?o/4ncok1?/00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onLHiooW6>L04ooW6>L00ol0003o[E:]ojeB[@0:
ojeB[@03o`000?lebSGo=LXe00Go=LXe00?o0000obKI9_lVfBH03?lVfBH00ol0003o9=/TobCK9008
obCK9003o`000?lAkQ7o4NhA00oo4NhA1Ol0000AocO8=`03o`000?o6>LKoaSW601OoaSW600?o0000
on`Ck?o/4n`01?o/4n`3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oW6>OoiaSW01?oiaSW00?o0000ojeB[On]DZd02?n]DZd2o`00
00Wo=LXe00?o0000obKI9_lVfBH02olVfBH00ol0003o9=/TobCK9007obCK9003o`000?lAkQ7o4NhA
00go4NhA0ol00005o`gb3@03o`000?lgb3Oo=lPg00ko=lPg00?o0000olHia_o6>LH05_o6>LH00ol0
003ok1?/on`Ck008on`Ck0?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonLHi`03o`000?n]DZgo[E:]00Ko[E:]00?o0000ocG:=Ole
bSD02_lebSD00ol0003o9]TVobKI9P0:obKI9Q[o00002Ol=lPd00ol0003o=lPgocO8=`0<ocO8=`?o
00005_o6>LH00ol0003ok1?/on`Ck00<on`Ck0?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oU6^D3o`0001;oiaSW00?o0000ojeB[On]DZd01?n]DZd2o`0000ko=LXe
00?o0000obKI9_lVfBH01olVfBH2o`0000[o4n`C00?o0000o`_d2ol;m0/03?l;m0/00ol0003o3O8=
o`gb3@08o`gb3@;o00002_lgb3L2o`0000?o7^4N0_l0000ColHiaP03o`000?o/4ncok1?/013ok1?/
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onDJi@;o00004?oW
6>L00ol0003o[E:]ojeB[@03ojeB[@03o`000?lebSGo=LXe00oo=LXe00?o0000obKI9_lVfBH01?lV
fBH2o`0000co4n`C00?o0000o`_d2ol;m0/03?l;m0/00ol0003o3O8=o`gb3@0:o`gb3@03o`000?lg
b3Oo=lPg00Go=lPg0_l00007oakQ7P03o`000?o6>LKoaSW600ooaSW600?o0000on`Ck?o/4n`04Oo/
4n`01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onDJiOoU6^D01OoU6^D2o`0000ooiaSW00Go0000ojeB[On]DZgo[E:]o`00000CocG:=@03o`00
0?lVfBKo9]TV00;o9]TV00?o0000oa?/4olCk1<03OlCk1<00ol0003o2o@;o`_d2`0;o`_d2`03o`00
0?l=lPgo3O8=00_o3O8=00?o0000ocO8=olgb3L00_lgb3L2o`0000[o7^4N0_l0000>olHiaP03o`00
0?o/4ncok1?/017ok1?/00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onDJiOoU6^D01_oU6^D3o`0000_oiaSW1Ol0000EocG:=@04o`00
0?lVfBKo0000o`00013o4n`C00?o0000o`_d2ol;m0/02ol;m0/00ol0003o3O8=o`gb3@0<o`gb3@04
o`000?lgb3Oo0000o`0000ko7^4N0_l0000;olHiaP03o`000?o/4ncok1?/017ok1?/00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oU6^GoiA[U00WoiA[U0_l00008onLHi`03o`000?nEJYGoUFZE00;oUFZE00?o0000ocG:=Ole
bSD05?lebSD00ol0003o4n`Coa?/4`0@oa?/4`03o`000?l;m0_o2o@;00_o2o@;00?o0000o`gb3Ol=
lPd03Ol=lPd00ol0003o7^4NoakQ7P0@oakQ7P03o`000?o6>LKoaSW600OoaSW600?o0000on`Ck?o/
4n`04Oo/4n`00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oU6^GoiA[U00_oiA[U
0_l00005onLHi`03o`000?nEJYGoUFZE00CoUFZE00?o0000ocG:=OlebSD04olebSD00ol0003o4n`C
oa?/4`0@oa?/4`03o`000?l;m0_o2o@;00_o2o@;00?o0000o`gb3Ol=lPd03Ol=lPd00ol0003o7^4N
oakQ7P0AoakQ7P;o00000oo6>LH4o`0001?ok1?/00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oU6^GoiA[U00goiA[U0ol000000ooW6>Oo0000oiEZU@07oiEZU@03o`000?lebSGo=LXe01;o
=LXe00?o0000oa?/4olCk1<04?lCk1<00ol0003o2o@;o`_d2`0;o`_d2`03o`000?l=lPgo3O8=00go
3O8=00?o0000oakQ7_lNhAh04olNhAh3o`0000?ocS7>00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oU6^GoiA[U013oiA[U00?o0000oiEZUOnEJYD0
2?nEJYD00ol0003o=LXeocG:=@0AocG:=@03o`000?lCk1?o4n`C017o4n`C00?o0000o`_d2ol;m0/0
2_l;m0/00ol0003o3O8=o`gb3@0<o`gb3@03o`000?l;m0_o000001Co7^4N00?o0000olhac_o><Lh0
1?o><Lh00ol0003ok1?/on`Ck00>on`Ck003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onDJiOoU6^D03ooU
6^D00ol0003oUFZEoiEZU@09oiEZU@03o`000?lebSGo=LXe013o=LXe00?o0000oa?/4olCk1<04OlC
k1<00ol0003o2o@;o`_d2`0:o`_d2`03o`000?l=lPgo3O8=00_o3O8=00Co0000o`_d2ol;m0_o0000
5?lNhAh00ol0003ocS7>olhacP05olhacP03o`000?o/4ncok1?/00cok1?/00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiA[UonDJ
i@0?onDJi@03o`000?nEJYGoUFZE00[oUFZE00?o0000ocG:=OlebSD03_lebSD00ol0003o5>/Do`00
000Boa?/4`03o`000?l;m0_o2o@;00[o2o@;00?o0000o`gb3Ol=lPd02_l=lPd00ol0003o2o@;o`_d
2`02o`_d2`03o`000?lNhAko7^4N013o7^4N00?o0000olhac_o><Lh01oo><Lh00ol0003ok1?/on`C
k00:on`Ck003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oU6^GoiA[U00ooiA[U00?o0000oiEZUOnEJYD0
2onEJYD00ol0003o=LXeocG:=@0<ocG:=@05o`000?lDjaCo5>/DoaC[5?l000004OlCk1<00ol0003o
2o@;o`_d2`0:o`_d2`03o`000?l=lPgo3O8=00Wo3O8=00?o0000o`_d2ol;m0/00ol;m0/00ol0003o
7^4NoakQ7P0@oakQ7P03o`000?o><LkocS7>00SocS7>00?o0000on`Ck?o/4n`02?o/4n`00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onDJiOoU6^D03_oU6^D00ol0003oUFZEoiEZU@0=oiEZU@03o`00
0?lebSGo=LXe00[o=LXe00?o0000oaC[5?lDja@00olDja@00ol0003o4n`Coa?/4`0?oa?/4`03o`00
0?l;m0_o2o@;00Wo2o@;00?o0000o`gb3Ol=lPd02?l=lPd00ol0003o2o@;o`_d2`05o`_d2`03o`00
0?lNhAko7^4N00oo7^4N00?o0000olhac_o><Lh02Oo><Lh00ol0003ok1?/on`Ck006on`Ck003o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiA[UonDJi@0>onDJi@03o`000?nE
JYGoUFZE00koUFZE00?o0000ocG:=OlebSD02?lebSD00ol0003o5>/DoaC[5005oaC[5003o`000?lC
k1?o4n`C00ko4n`C00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o3O8=o`gb3@07o`gb3@03o`000?l;
m0_o2o@;00Ko2o@;00?o0000oakQ7_lNhAh03olNhAh00ol0003ocS7>olhacP09olhacP03o`000?o/
4ncok1?/00Gok1?/00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiA[UonDJi@0=
onDJi@03o`000?nEJYGoUFZE00ooUFZE00?o0000ocG:=OlebSD01_lebSD00ol0003o5>/DoaC[5007
oaC[5003o`000?lCk1?o4n`C00go4n`C00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o3O8=o`gb3@04
o`gb3@?o00002_l;m0/00ol0003o7^4NoakQ7P0=oakQ7P03o`000?o><LkocS7>00_ocS7>00?o0000
on`Ck?o/4n`00oo/4n`00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oU6^GoiA[U
00goiA[U00?o0000oiEZUOnEJYD04?nEJYD00ol0003o=LXeocG:=@05ocG:=@03o`000?lDjaCo5>/D
00So5>/D00?o0000oa?/4olCk1<03?lCk1<00ol0003o2o@;o`_d2`09o`_d2`03o`000?l=lPgo0000
00Co00000_l:m@X00ol0003o2o@;o`_d2`08o`_d2`03o`000?lNhAko7^4N00go7^4N00?o0000olha
c_o><Lh03?o><Lh01Ol0003ok1?/on`Ck?o/4nco000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0
003oUFZEoiEZU@0AoiEZU@03o`000?lebSGo=LXe00?o=LXe00?o0000oaC[5?lDja@02_lDja@00ol0
003o4n`Coa?/4`0;oa?/4`03o`000?l;m0_o2o@;00So2o@;0ol00008o`[e2P03o`000?l;m0_o2o@;
00So2o@;00?o0000oakQ7_lNhAh03?lNhAh00ol0003ocS7>olhacP0=olhacP03o`000?o/4nco0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oU6^GoiA[U00goiA[U00?o0000oiEZUOnEJYD04_nEJYD01Ol0
003o=LXeocG:=OlebSGo000000ko5>/D00?o0000oa?/4olCk1<02olCk1<00ol0003o2o@;o`_d2`06
o`_d2`03o`000?l:m@[o2_D:00Wo2_D:00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o7^4NoakQ7P0:
oakQ7P03o`000?o><LkocS7>00oocS7>00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0003oUFZEoiEZU@0CoiEZU@03o`000?lebSGo0000
013o5>/D3_l00006o`_d2`;o00003?l:m@X00ol0003o2o@;o`_d2`09o`_d2`03o`000?lNhAko7^4N
00[o7^4N00?o0000olhac_o><Lh03oo><Lh00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onDJiOoU6^D02ooU6^D00ol0003o
UFZEoiEZU@0DoiEZU@?o00003olDja@00ol0003o3o0?o`o`3`0<o`o`3`04o`000?l;m0_o2o@;o`_d
2`;o00003ol:m@X00ol0003o2o@;o`_d2`09o`_d2`03o`000?lNhAko7^4N00Wo7^4N00?o0000olha
c_o><Lh04?o><Lh00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oU6^GoiA[U00_o
iA[U00?o0000oiEZUOnEJYD04onEJYD01Ol0003o;M8]obgB;Ol]dRgo000000go5>/D00?o0000o`o`
3ol?l0l03_l?l0l00ol0003o2o@;o`00000Ao`[e2P03o`000?l;m0_o2o@;00Wo2o@;00?o0000oakQ
7_lNhAh02OlNhAh00ol0003ocS7>olhacP0@olhacP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000BoiEZU@03o`000?l]dRgo;M8]00?o;M8]00?o0000oaC[5?lDja@02OlDja@00ol0003o
3o0?o`o`3`0@o`o`3`03o`000?l:m@[o2_D:017o2_D:00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o
7^4NoakQ7P07oakQ7P03o`000?o><LkocS7>017ocS7>00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iaSWonLHi`0<onLHi`03o`000?n6NHKoQWV600?o00003_nEJYD00ol0003o;M8]obgB;@05obgB;@03
o`000?lDjaCo5>/D00Oo5>/D00?o0000o`o`3ol?l0l04Ol?l0l00ol0003o2_D:o`[e2P0Ao`[e2P03
o`000?l;m0_o2o@;00Wo2o@;00?o0000oakQ7_lNhAh01_lNhAh2o`0001CocS7>00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiaSW00koiaSW
00?o0000ohIiQ_n6NHH00on6NHH3o`0000[oUFZE00?o0000obgB;Ol]dRd01ol]dRd00ol0003o5>/D
oaC[5005oaC[5003o`000?l?l0oo3o0?01;o3o0?00?o0000o`[e2_l:m@X04Ol:m@X00ol0003o2o@;
o`_d2`0:o`_d2`03o`000?lNhAko7^4N00;o7^4N0ol00002ob7N8@03o`000?o><LkocS7>017ocS7>
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oW6>OoiaSW00koiaSW00?o0000ohIiQ_n6NHH01_n6
NHH3o`0000KoUFZE00?o0000obgB;Ol]dRd02Ol]dRd00ol0003o5>/DoaC[5003oaC[5003o`000?l?
l0oo3o0?01?o3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o2o@;o`_d2`09o`_d2`03o`000?lN
hAko000000;o00001_lQgR400ol0003ocS7>olhacP0@olhacP03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oW6>Oo
iaSW00goiaSW00?o0000ohIiQ_n6NHH02_n6NHH3o`0000;oUFZE00?o0000obgB;Ol]dRd02ol]dRd0
1Ol0003o5>/DoaC[5?lDjaCo000001Ko3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o2o@;o`_d
2`0:o`_d2`03o`000?lQgR7o8MhQ00So8MhQ00?o0000olhac_o><Lh04?o><Lh00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oW6>OoiaSW00goiaSW00?o0000ohIiQ_n6NHH03On6NHH2o`0000oo;M8]00?o0000oaC[5?l00000
5ol?l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l;m0_o2o@;00Wo2o@;00?o0000ob7N8OlQgR40
2OlQgR400ol0003ocS7>olhacP0?olhacP03o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW
6>L00ol0003oQWV6ohIiQP0>ohIiQP03o`000?l]dRgo;M8]00ko;M8]00?o0000o`o`3ol?l0l05_l?
l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l;m0_o2o@;00So2o@;00?o0000ob7N8OlQgR402olQ
gR45o`0000cocS7>00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onLHiooW6>L03OoW6>L00ol0003oQWV6ohIiQP0>
ohIiQP03o`000?l]dRgo;M8]00ko;M8]00?o0000o`o`3ol?l0l05_l?l0l00ol0003o2_D:o`[e2P0C
o`[e2P03o`000?l;m0_o2o@;00Oo2o@;00?o0000ob7N8OlQgR403?lQgR400ol0003odBkAom4^d@02
om4^d@Wo00001?o><Lh00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiaSWonLHi`0<onLHi`03o`000?n6NHKoQWV6
00koQWV600?o0000obgB;Ol]dRd03ol]dRd00ol0003o3o0?o`o`3`0Eo`o`3`03o`000?l:m@[o2_D:
01?o2_D:1?l00005o`_d2`03o`000?lQgR7o8MhQ00go8MhQ00?o0000om4^dOoA;]402ooA;]44o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oW6>OoiaSW00_oiaSW00?o0000ohIiQ_n6NHH03on6NHH00ol0003o;M8]obgB;@0?obgB;@03
o`000?l?l0oo3o0?01Go3o0?00?o0000o`[e2_l:m@X04?l:m@X3o`0000Co4NhA0ol000000ol;m0_o
0000ob7N8@0>ob7N8@03o`000?oA;]7odBkA00oodBkA00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiaSWonLHi`0;onLHi`03o`00
0?n6NHKoQWV600ooQWV600?o0000obgB;Ol]dRd03ol]dRd2o`0001Co3o0?0ol0000@o`[e2P;o0000
2_lAkQ400ol0003o8MhQob7N8@0>ob7N8@03o`000?oA;]7odBkA013odBkA0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oW6>OoiaSW00_oiaSW4ol0000>obgB;@?o0000
0_lTfb@00ol0003o3o0?o`o`3`0<o`o`3`Go00000_lEjQD00ol0003o2_D:o`[e2P0<o`[e2P;o0000
3?lAkQ400ol0003o8MhQob7N8@0>ob7N8@03o`000?oA;]7odBkA013odBkA00?o0000oo@;m?l00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW
6>OoiaSW00_oiaSW00?o0000ogV6NOmiQWT03omiQWT00ol0003o;M8]obgB;@09obgB;@?o00001_lT
fb@00ol0003o3o0?o`o`3`06o`o`3`Go00002?lEjQD00ol0003o2_D:o`[e2P08o`[e2P?o00003olA
kQ400ol0003o8MhQob7N8@0=ob7N8@03o`000?oA;]7odBkA00oodBkA00Go0000oo@;m?od2oCom0_d
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLH
i`0;onLHi`03o`000?miQWWoNHIi00ooNHIi00?o0000obgB;Ol]dRd01_l]dRd3o`0000[o9=/T00?o
0000o`o`3ol?l0l01Ol0000>oaGZ5@03o`000?l:m@[o2_D:00Go2_D:0_l0000Boa7^4@03o`000?lQ
gR7o8MhQ00co8MhQ00?o0000om4^dOoA;]404?oA;]400ol0003om0_doo@;m002oo@;m003o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiaSWonLHi`0;
onLHi`03o`000?miQWWoNHIi013oNHIi00?o0000obgB;Ol]dRd00_l]dRd3o`0000go9=/T0ol0000C
oaGZ5@03o`000?l:m@[o2_D:00?o2_D:0_l0000Eoa7^4@03o`000?lQgR7o8MhQ00_o8MhQ00?o0000
om4^dOoA;]403ooA;]400ol0003om0_doo@;m004oo@;m003o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiaSWonLHi`08onLHi`Co00004OmiQWT00ol0003o;M8]o`000002o`00
00oo9=/T00?o0000oc3?<?l000005OlEjQD00ol0003o2_D:o`000002o`0001Oo4NhA00?o0000ob7N
8OlQgR402olQgR400ol0003odBkAom4^d@0>om4^d@03o`000?od2oCom0_d00Kom0_d00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oW6>OoiaSW00Go
iaSW0ol00004olhacP03o`000?miQWWoNHIi00koNHIi0_l0000AobCK9004o`000?l`cc3o<<l`o`00
01Ko5NXE00?o0000oa7^4OlAkQ406?lAkQ400ol0003o8MhQob7N8@0;ob7N8@03o`000?oA;]7odBkA
00kodBkA00?o0000oo@;m?od2o@01ood2o@00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oW6>OoiaSW00;oiaSW0ol00008olhacP03
o`000?miQWWoNHIi00coNHIi0ol0000?obCK90;o00000ol`cc000ol0003o5NXEoaGZ5@0DoaGZ5@03
o`000?lAkQ7o4NhA01Wo4NhA00?o0000ob7N8OlQgR402_lQgR400ol0003odBkAom4^d@0=om4^d@03
o`000?od2oCom0_d00Wom0_d00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<olhacP03o`000?miQWWoNHIi00[oNHIi00Go0000ofn@Kom_T6oo
Ki1_o`00000=obCK9003o`000?l`cc3o<<l`00Co<<l`00?o0000oaGZ5OlEjQD04olEjQD00ol0003o
4NhAoa7^4@0Ioa7^4@03o`000?lQgR7o8MhQ00Wo8MhQ00?o0000om4^dOoA;]403_oA;]400ol0003o
m0_doo@;m00:oo@;m0;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o><LkocS7>00cocS7>0_l00008ogV6N@;o00001Om_T6l00ol0003o9=/TobCK9009obCK9003o`00
0?l`cc3o<<l`00Go<<l`00?o0000oaGZ5OlEjQD04olEjQD00ol0003o4NhAoa7^4@0Joa7^4@go0000
3_oA;]400ol0003om0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003ocS7>olhacP0=olhacP03o`000?mi
QWWoNHIi00CoNHIi00?o0000ofn@Kom_T6l01_m_T6l2o`0000So9=/T00?o0000oc3?<?l`cc001_l`
cc000ol0003o5NXEoaGZ5@0DoaGZ5@03o`000?lAkQ7o4NhA01Wo4NhA00?o0000of6NHOmQWV402_mQ
WV400ol0003odBkAom4^d@0;om4^d@03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000olhac_o><Lh03_o><Lh0
1?l0003oNHIiogV6NOmiQWT2o`0000_oKi1_00?o0000obCK9?lTfb@00olTfb@2o`0000Wo<<l`00?o
0000oaGZ5OlEjQD05?lEjQD00ol0003o4NhAoa7^4@0Hoa7^4@03o`000?mQWV7oHIiQ00coHIiQ00?o
0000om4^dOoA;]402OoA;]400ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ocS7>olhacP0>olhacP03o`000?miQWWo
000000koKi1_00Go0000obCK9?lTfbCo9=/To`00000;oc3?<003o`000?lEjQGo5NXE01Co5NXE0_l0
000Ioa7^4@03o`000?mQWV7oHIiQ00goHIiQ0_l00008om4^d@03o`000?od2oCom0_d00kom0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ocS7>olhacP0?
olhacP03o`000?m_T6ooKi1_00koKi1_00?o0000obCK9?l000003?l`cc000ol0003o5NXEoaGZ5@0D
oaGZ5@03o`000?lSg2?o000000;o00005OlAkQ400ol0003oHIiQof6NH@0@of6NH@03o`000?oA;]7o
dBkA00GodBkA00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003ocS7>olhacP0>olhacP03o`000?m_T6ooKi1_00koKi1_0_l0000=oc3?
<003o`000?lEjQGo5NXE01?o5NXE00?o0000ob?L8olSg2<00olSg2<2o`0001;o4NhA00?o0000of6N
HOmQWV404_mQWV401?l0003odBkAom4^dOoA;]43o`0001;om0_d00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000olhac_o><Lh03Oo><Lh2o`0000ooKi1_00?o0000ogN8
Mol000003_l`cc000ol0003o5NXEoaGZ5@0BoaGZ5@03o`000?lSg2?o8m`S00Go8m`S0ol0000?oa7^
4@03o`000?mQWV7oHIiQ01?oHIiQ0ol00002ondBk@03o`000?od2oCom0_d013om0_d00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000olhac_o><Lh02oo><Lh00ol0003o
dBkAo`00000>ofn@K`05o`000?mgR7OoMhQgogN8Mol000003Ol`cc000ol0003o5NXEoaGZ5@0AoaGZ
5@03o`000?lSg2?o8m`S00Wo8m`S0ol0000:oa7^4@;o00005_mQWV400ol0003okA;]ondBk@03ondB
k@03o`000?od2oCom0_d013om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000olhac_o><Lh02_o><Lh01Ol0003odBkAom4^dOoA;]7o000000coKi1_00?o0000ogN8
MomgR7L00_mgR7L00ol0003o<<l`oc3?<00;oc3?<003o`000?lEjQGo5NXE017o5NXE00?o0000ob?L
8olSg2<03?lSg2<2o`0000Ko4NhA0_l000000om=/Tgo0000of6NH@0Dof6NH@03o`000?o]4^gokA;]
00GokA;]00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003ocS7>olhacP07olhacP;o00001OoA;]400ol0003oKi1_ofn@K`08ofn@K`03
o`000?mgR7OoMhQg00CoMhQg00?o0000oc3?<?l`cc002Ol`cc04o`00013o5NXE00?o0000ob?L8olS
g2<03olSg2<3o`000003oa7^4Ol0003o000000CoCK9=00?o0000of6NHOmQWV404OmQWV400ol0003o
kA;]ondBk@07ondBk@03o`000?od2oCom0_d00oom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000olhac_o><Lh01_o><Lh00ol0003odBkAom4^d@05om4^d@03o`00
0?m_T6ooKi1_00OoKi1_00?o0000ogN8MomgR7L01OmgR7L00ol0003o<<l`oc3?<008oc3?<003o`00
0?ll`cco?<<l00;o?<<l0ol0000=oaGZ5@03o`000?lSg2?o8m`S01;o8m`S00?o0000odfbCOm=/Td0
1Om=/Td00ol0003oHIiQof6NH@0@of6NH@03o`000?o]4^gokA;]00OokA;]00?o0000oo@;m?od2o@0
3ood2o@00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003ocS7>olha
cP04olhacP03o`000?oA;]7odBkA00OodBkA00?o0000ofn@Kom_T6l01Om_T6l00ol0003oMhQgogN8
M`07ogN8M`03o`000?l`cc3o<<l`00Ko<<l`00?o0000occ3??ll`c`01_ll`c`3o`0000So5NXE0_l0
000Eob?L8`03o`000?m=/TgoCK9=00KoCK9=00?o0000of6NHOmQWV403_mQWV400ol0003okA;]ondB
k@09ondBk@03o`000?od2oCom0_d00kom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000olhac_o><Lh00_o><Lh2o`0000[odBkA00?o0000ofn@Kom_T6l01?m_T6l0
0ol0003oMhQgogN8M`09ogN8M`03o`000?l`cc3o<<l`00?o<<l`0_l0000<occ3?0?o00000_lEjQD3
o`000003ocK9=_l0003o8m`S01Co8m`S00?o0000odfbCOm=/Td01om=/Td00ol0003oHIiQof6NH@0<
of6NH@03o`000?o]4^gokA;]00_okA;]00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003ocS7>olhac_l0000=om4^d@03o`000?m_T6oo
Ki1_00;oKi1_00?o0000ogN8MomgR7L02_mgR7L00ol0003o<<l`oc3?<002oc3?<003o`000?ll`cco
?<<l00oo?<<l0_l00005ocK9=P03o`000?lSg2?o8m`S01;o8m`S00?o0000odfbCOm=/Td02?m=/Td0
0ol0003oHIiQof6NH@0:of6NH@03o`000?o]4^gokA;]00gokA;]1Ol0000;oo@;m003o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o><Lko000000oodBkA00Co0000ofn@
Kom_T6oo00003_mgR7L01?l0003o<<l`oc3?<?l0000Cocc3?003o`000?lfbCKo=/Tf00Co=/Tf00?o
0000ob?L8olSg2<04?lSg2<00ol0003oCK9=odfbC@09odfbC@03o`000?mQWV7oHIiQ00[oHIiQ00?o
0000ondBkOo]4^d03Oo]4^d00ol0003onPGjooX5nP02ooX5nPWo00000_od2o@00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?oA;]7odBkA00kodBkA00?o0000ofn@Kol000003omgR7L0
0ol0003o<<l`o`00000Cocc3?003o`000?lfbCKo=/Tf00Go=/Tf00?o0000ob?L8olSg2<04?lSg2<0
0ol0003oCK9=odfbC@0:odfbC@03o`000?mQWV7oHIiQ00SoHIiQ00?o0000ondBkOo]4^d03Oo]4^d0
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000om4^
dOoA;]403ooA;]400ol0003oMhQgogN8M`0>ogN8M`;o00005?ll`c`00ol0003o=/TfocK9=P06ocK9
=P03o`000?lSg2?o8m`S00oo8m`S00?o0000odfbCOm=/Td02om=/Td00ol0003oHIiQof6NH@04of6N
H@?o00004?o]4^d00ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
dBkAom4^d@0@om4^d@03o`000?mgR7OoMhQg00_oMhQg0ol000000omjQG[o0000occ3?00Bocc3?003
o`000?lfbCKo=/Tf00Oo=/Tf00?o0000ob?L8olSg2<03olSg2<00ol0003oCK9=odfbC@0<odfbC@03
o`000?mQWV7oHIiQ00?o00000ooP7n000ol0003okA;]ondBk@0=ondBk@03o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000om4^dOoA;]404?oA;]43o`0000WoMhQg0_l00005ogZ5NP03o`00
0?ll`cco?<<l013o?<<l00?o0000ocK9=_lfbCH02?lfbCH00ol0003o8m`Sob?L8`0>ob?L8`03o`00
0?m=/TgoCK9=00goCK9=0_l00007on0Oh003o`000?o]4^gokA;]00_okA;]00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?oA;]7odBkA00oodBkA00Co
0000olPgb?o8=lSob3O80_l00005ogN8M`;o00002?mjQGX00ol0003o?<<locc3?00>occ3?003o`00
0?lfbCKo=/Tf00[o=/Tf00?o0000ob?L8olSg2<03?lSg2<00ol0003oCK9=odfbC@0>odfbC@03o`00
0?oP7n3oh1oP00Ooh1oP00?o0000ondBkOo]4^d02_o]4^d00ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006olPgb003o`000?mgR7Oo000000;o00002_mj
QGX00ol0003o?<<locc3?00=occ3?003o`000?lfbCKo=/Tf00_o=/Tf00?o0000ob?L8olSg2<03?lS
g2<00ol0003oCK9=odfbC@0=odfbC@03o`000?oP7n3oh1oP00Woh1oP00?o0000ondBkOo]4^d02?o]
4^d00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o`3o3o
l0o`00ool0o`00?o0000olPgb?o8=lP01Oo8=lP00ol0003oNXEjogZ5NP0<ogZ5NP03o`000?ll`cco
?<<l00co?<<l00?o0000ocK9=_lfbCH03?lfbCH2o`0000co8m`S00?o0000odfbCOm=/Td03Om=/Td0
0ol0003oh1oPon0Oh00:on0Oh003o`000?o]4^gokA;]00OokA;]00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o`3o004?o`3o000ol0003ob3O8olPgb006olPgb003o`000?mjQG[o
NXEj00coNXEj00?o0000occ3??ll`c`02oll`c`00ol0003o=/TfocK9=P0=ocK9=P04o`000?mHYeSo
0000o`0000[o8m`S00?o0000odfbCOm=/Td03Om=/Td00ol0003oh1oPon0Oh00;on0Oh003o`000?o]
4^gokA;]00KokA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003ol0o`oo0?l00@
oo0?l003o`000?o8=lSob3O800Kob3O800?o0000ogZ5N_mjQGX03OmjQGX00ol0003o?<<locc3?00:
occ3?003o`000?lfbCKo=/Tf00co=/Tf00?o0000oeRWF?mHYeP00_mHYeP2o`0000So8m`S00?o0000
odfbCOm=/Td03?m=/Td00ol0003oh1oPon0Oh00=on0Oh003o`000?o]4^gokA;]00CokA;]00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@oo0?l003o`000?o8=lSob3O8
00Oob3O800?o0000ogZ5N_mjQGX03_mjQGX<o`0000oo=/Tf00?o0000oeRWF?mHYeP01?mHYeP2o`00
00Ko8m`S00?o0000odfbCOm=/Td03?m=/Td00ol0003oh1oPon0Oh00>on0Oh003o`000?o]4^gokA;]
00?okA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>oo0?
l003o`000?o8=lSob3O800Sob3O800?o0000ogZ5N_mjQGX03OmjQGX00ol0003oHiaSof>LH`08of>L
H`03o`000?lfbCKo=/Tf00co=/Tf00?o0000oeRWF?mHYeP01omHYeP2o`0000?o8m`S00?o0000odfb
COm=/Td03Om=/Td00ol0003oh1oPon0Oh00?on0Oh005o`000?o]4^gokA;]ondBkOl000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo`3o000ol0003ob3O8olPgb008olPgb003o`000?mjQG[o
NXEj00coNXEj00?o0000of>LHomSW6<02_mSW6<00ol0003o=/TfocK9=P0;ocK9=P03o`000?mHYeSo
F:MH00WoF:MH0_l000000olSg2?o0000odfbC@08odfbC@Ko00004ooP7n001?l0003okA;]ondBkOl0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008oo0?l003o`000?o8=lSo
b3O800Wob3O800?o0000ogZ5N_mjQGX03?mjQGX00ol0003oHiaSof>LH`0:of>LH`03o`000?lfbCKo
=/Tf00[o=/Tf00?o0000oeRWF?mHYeP03?mHYeP;o`0000GobCK900?o0000on0Oh?oP7n004_oP7n00
0ol0003okA;]o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on@K
i?oT6nCoi1_T1Ol00003oo0?l003o`000?o8=lSob3O800Wob3O800?o0000ogZ5N_mjQGX02omjQGX0
0ol0003oHiaSof>LH`0<of>LH`03o`000?lfbCKo=/Tf00Wo=/Tf00?o0000oeRWF?mHYeP03?mHYeP0
0ol0003oPgb3oh=lP`02oh=lP`03o`000?o9=/WobCK900WobCK900?o0000on0Oh?oP7n004_oP7n03
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on@K
i?oT6n@01OoT6n@3o`0000cob3O800?o0000ogZ5N_mjQGX02omjQGX00ol0003oHiaSof>LH`0<of>L
H`03o`000?lfbCKo=/Tf00So=/Tf00?o0000oeRWF?mHYeP03?mHYeP00ol0003oPgb3oh=lP`04oh=l
P`03o`000?o9=/WobCK900SobCK900?o0000on0Oh?oP7n004_oP7n000ol0003oo@;mood2o@04o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oT6nCoi1_T00Ooi1_T00?o0000olPg
b?o8=lP02_o8=lP00ol0003oNXEjogZ5NP09ogZ5NP;o00003omSW6<00ol0003o=/TfocK9=P08ocK9
=P03o`000?mHYeSoF:MH00coF:MH00?o0000oh=lPon3O8<01?n3O8<00ol0003obCK9olTfb@09olTf
b@Co00003ooP7n000ol0003oo@;mood2o@05ood2o@Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on@Ki?oT6n@02?oT6n@00ol0003ob3O8olPgb009olPgb003o`000?mjQG[oNXEj00Ko
NXEj0ol000000onNHIko0000of>LH`0?of>LH`03o`000?lfbCKo=/Tf00Ko=/Tf00?o0000oeRWF?mH
YeP03OmHYeP00ol0003oPgb3oh=lP`05oh=lP`03o`000?o9=/WobCK900SobCK900Co0000oo@;m?od
2oCom0_d1Ol00009on0Oh003o`000?om0_goo@;m00[oo@;m1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003oi1_Ton@Ki007on@Ki003o`000?o8=lSob3O800[ob3O800?o0000ogZ5N_mj
QGX00_mjQGX3o`0000GoWV6N00?o0000of>LHomSW6<03OmSW6<00ol0003o=/TfocK9=P06ocK9=P03
o`000?mHYeSoF:MH00coF:MH00?o0000oh=lPon3O8<01_n3O8<00ol0003obCK9olTfb@08olTfb@03
o`000?od2oCom0_d00Kom0_d1Ol00003on0Oh003o`000?om0_goo@;m00ooo@;m0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on@Ki?oT6n@01ooT6n@00ol0003ob3O8olPgb00:olPgb003o`000?mjQG[o000000;o0000
2?nNHIh00ol0003oHiaSof>LH`0=of>LH`Co00001?lfbCH00ol0003oF:MHoeRWF00=oeRWF003o`00
0?n3O8?oPgb300OoPgb300?o0000olTfbOo9=/T01oo9=/T00ol0003om0_doo@;m00;oo@;m0?o0000
4oom0_d00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on@Ki?oT6n@02?oT6n@3o`0000Wob3O80_l0
000<oiiQWP03o`000?mSW6?oHiaS00_oHiaS00?o0000ohm`Son?L8l00_n?L8l3o`000003ocK9=_l0
003oF:MH00koF:MH00?o0000oh=lPon3O8<01on3O8<00ol0003obCK9olTfb@06olTfb@03o`000?od
2oCom0_d00kom0_d00?o0000ood2oOom0_d04_om0_d00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on@Ki?oT6n@01_oT6n@01?l0003oiaSWonLHiooW6>L3o`0000Kob3O800?o0000oiiQW_nNHIh03?nN
HIh00ol0003oHiaSof>LH`09of>LH`03o`000?n?L8ooSg2?00KoSg2?00?o0000oeRWF?mHYeP03OmH
YeP00ol0003oPgb3oh=lP`09oh=lP`03o`000?o9=/WobCK900GobCK900?o0000oo@;m?od2o@03_od
2o@00ol0003oo@;mood2o@0Bood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003oi1_Ton@Ki005
on@Ki003o`000?oW6>OoiaSW00GoiaSW0ol00002olPgb003o`000?nNHIkoWV6N00goWV6N00?o0000
of>LHomSW6<02?mSW6<00ol0003oSg2?ohm`S`07ohm`S`03o`000?mHYeSoF:MH00coF:MH0ol0000:
oh=lP`03o`000?o9=/WobCK900GobCK900?o0000oo@;m?od2o@03_od2o@00ol0003oo@;mood2o@0B
ood2o@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki004on@Ki003o`000?oW6>OoiaSW
00WoiaSW0_l0000AoiiQWP03o`000?mSW6?oHiaS00GoHiaS0_l0000;ohm`S`03o`000?mHYeSoF:MH
00[oF:MH00Go0000ok1?/?n`Ck3o/4n`o`00000:oh=lP`03o`000?o9=/WobCK900CobCK900?o0000
oo@;m?od2o@03_od2o@00ol0003oo@;mood2o@0Cood2o@03o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oT6nCoi1_T
00;oi1_T00?o0000onLHiooW6>L02_oW6>L2o`00017oWV6N00?o0000of>LHomSW6<01?mSW6<00ol0
003oSg2?ohm`S`0<ohm`S`03o`000?mHYeSoF:MH00OoF:MH0_l00005ok1?/0;o00002?n3O8<00ol0
003obCK9olTfb@04olTfb@03o`000?od2oCom0_d00gom0_d00?o0000ood2oOom0_d05?om0_d00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003oi1_Ton@Ki?oT6nCo000000coiaSW00Co0000omTV
fOoI9]Wo00004OnNHIh00ol0003oHiaSof>LH`02of>LH`03o`000?n?L8ooSg2?00koSg2?00?o0000
oeRWF?mHYeP01OmHYeP00ol0003o/4n`ok1?/007ok1?/003o`000?n3O8?oPgb300KoPgb300?o0000
olTfbOo9=/T00oo9=/T00ol0003om0_doo@;m00=oo@;m003o`000?om0_goo@;m01Coo@;m00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on@Ki?oT6nCo00003?oW6>L00ol0003ofBKIomTVf@02omTVf@03o`000?nNHIko
WV6N00ooWV6N00Co0000of>LHomSW6?o00004On?L8l00ol0003oF:MHoeRWF004oeRWF003o`000?n`
Ck3o/4n`00Wo/4n`00?o0000oh=lPon3O8<01On3O8<00ol0003obCK9olTfb@03olTfb@03o`000?od
2oCom0_d00gom0_d00?o0000ood2oOom0_d05Oom0_d00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onLHi`03o`000?oI9]WofBKI00?ofBKI00?o0000oiiQW_nNHIh03onNHIh00ol0003oHiaSo`00000C
ohm`S`04o`000?mHYeSoF:MHoeRWF0;o00003On`Ck02o`0000KoPgb300Go0000olTfbOo9=/WobCK9
o`00000@oo@;m003o`000?om0_goo@;m01Coo@;m0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02_oW
6>L00ol0003ofBKIomTVf@05omTVf@03o`000?nNHIkoWV6N00ooWV6N00?o0000ohm`Son?L8l04on?
L8l00ol0003oF:MHo`00000Aok1?/003o`000?n3O8?oPgb300?oPgb300Go0000olTfbOo9=/WobCK9
o`00000>oo@;m0?o00005?om0_d2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02OoW
6>L00ol0003ofBKIomTVf@07omTVf@03o`000?nNHIkoWV6N00koWV6N00?o0000ohm`Son?L8l05?n?
L8l00ol0003o/4n`ok1?/00Aok1?/0;o00001?n3O8<01?l0003obCK9olTfbOl0000:oo@;m0Co0000
0oom0_d00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onLHiooW6>L02OoW6>L00ol0003ofBKIomTVf@08omTVf@03o`000?nNHIkoWV6N00_oWV6N0ol0
000Gohm`S`03o`000?n`Ck3o/4n`01?o/4n`00Ko0000oh=lPon3O8?oPgb3o`000?o9=/T5o`0000Co
m0_d0ol00008ood2o@03o`000?om0_goo@;m00goo@;m0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oW6>OoiaSW00SoiaSW00?o0000omTVfOoI9]T02_oI9]T00ol0003oWV6NoiiQWP07oiiQWP?o0000
0_n`Ck000ol0003oSg2?ohm`S`0Eohm`S`;o00005On`Ck000ol0003oPgb3oh=lP`02o`0000GokQ7^
1?l0000<ood2o@03o`000?om0_goo@;m00[oo@;m0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onLHiooW6>L01ooW
6>L00ol0003ofBKIomTVf@0;omTVf@03o`000?nNHIkoWV6N00CoWV6N0ol00006ok1?/003o`000?n?
L8ooSg2?01?oSg2?00Co0000olPgb?o8=lSo00005On`Ck02o`0000WokQ7^00?o0000ood2oOom0_d0
3?om0_d00ol0003oo@;mood2o@07ood2o@;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiaSW00?o0000omTVfOoI9]T03OoI9]T00ol0003oWV6NoiiQ
WP03o`0000[o/4n`00?o0000ohm`Son?L8l04On?L8l00ol0003ob3O8olPgb002olPgb003o`000?n`
Ck3o/4n`01;o/4n`00?o0000onhAk_o^4Nh02?o^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?om
0_goo@;m00Coo@;m0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiaSWonLHi`05onLHi`03o`000?oI9]WofBKI00oofBKI0_l0000>
ok1?/003o`000?n?L8ooSg2?00ooSg2?00?o0000olPgb?o8=lP01?o8=lP00ol0003o/4n`ok1?/00@
ok1?/0;o00002oo^4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?om0_goo@;m00;oo@;m00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onLHiooW6>L00ooW6>L00ol0003ofBKIomTVf@0@omTVf@03o`000?n`Ck3o/4n`
00go/4n`00?o0000ohm`Son?L8l03_n?L8l00ol0003ob3O8olPgb006olPgb0;o00003_n`Ck02o`00
0003omHYe_l0003okQ7^00[okQ7^00?o0000ood2oOom0_d03_om0_d01?l0003oo@;mo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiaSWonLHiooW6>Oo000001;ofBKI00?o0000ok1?/?n`Ck003on`Ck000ol0003oSg2?ohm`S`0<
ohm`S`03o`000?o8=lSob3O800Wob3O800?o0000ok1?/?n`Ck002On`Ck02o`0000?oeRWF00?o0000
onhAk_o^4Nh02Oo^4Nh00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiaSWo`00000ComTV
f@03o`000?n`Ck3o/4n`013o/4n`00?o0000ohm`Son?L8l02_n?L8l00ol0003ob3O8olPgb00;olPg
b003o`000?n`Ck3o/4n`00Go/4n`0ol00006omHYeP03o`000?o^4NkokQ7^00SokQ7^00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omTVfOoI9]T04OoI9]T00ol0003o/4n`ok1?/00Aok1?/003o`000?n?L8ooSg2?00Wo
Sg2?00?o0000olPgb?o8=lP03Oo8=lP00ol0003o/4n`ok1?/002ok1?/0;o00002OoF:MH00ol0003o
kQ7^onhAkP09onhAkP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017ofBKI00?o0000ok1?/?n`Ck00
4_n`Ck000ol0003oSg2?ohm`S`07ohm`S`03o`000?o8=lSob3O800oob3O800Co0000ok1?/?l0003o
00002ooF:MH00ol0003okQ7^onhAkP09onhAkP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000kofBKI00?o0000ok1?/?n`Ck004on`Ck000ol0003oSg2?ohm`S`05ohm`S`03o`00
0?o8=lSob3O8017ob3O800?o0000omHYe_oF:MH03?oF:MH00ol0003okQ7^onhAkP08onhAkP03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;omTVf@;o00005_n`Ck07o`0001Cob3O800?o
0000omHYe_oF:MH03?oF:MH00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oI9]T00ol0003ocC;=o`000002o`0001;o/4n`00?o0000oke2_Onm@[d00_nm
@[d00ol0003o]4^do`00000DolPgb003o`000?oF:MKoeRWF00coeRWF00?o0000onhAk_o^4Nh02?o^
4Nh00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoI9]T00ol0003ocC;=oldbc@03
oldbc@;o00003on`Ck000ol0003o_D:moke2_@03oke2_@04o`000?ndBkCo]4^do`0001?ob3O800?o
0000omHYe_oF:MH03OoF:MH00ol0003okQ7^onhAkP08onhAkP03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003omTVfOl0003o
cC;=00OocC;=0ol0000;ok1?/003o`000?nm@[go_D:m00Co_D:m00Go0000okA;]?ndBkCo]4^do`00
000BolPgb003o`000?oF:MKoeRWF00goeRWF00?o0000onhAk_o^4Nh01oo^4Nh?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T04?oi1_T0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o=</gocC;=00[ocC;=0_l00008ok1?/003o`000?nm@[go
_D:m00Go_D:m00?o0000okA;]?ndBk@00_ndBk@00ol0003ob3O8olPgb00?olPgb003o`000?oF:MKo
eRWF00goeRWF00?o0000onhAk_o^4Nh01_o^4Nh00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oi1_Won@Ki00oon@Ki00?o0000on`Ck?o/4n`03oo/4n`00ol0003ocC;=oldbc@0<oldb
c@;o00001On`Ck000ol0003o_D:moke2_@06oke2_@03o`000?ndBkCo]4^d00?o]4^d00?o0000olPg
b?o8=lP03_o8=lP00ol0003oeRWFomHYeP0>omHYeP03o`000?o^4NkokQ7^00CokQ7^00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00kon@Ki00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
cC;=oldbc@0>oldbc@?o000000?o/4n`o`000?nm@[d02?nm@[d00ol0003o]4^dokA;]004okA;]003
o`000?o8=lSob3O800gob3O84_l00005onhAkP03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooT6n@03o`000?o/4ncok1?/00ook1?/0_l0000Coldbc@03o`000?nm@[go_D:m00So_D:m
00?o0000okA;]?ndBk@01OndBk@00ol0003ob3O8olPgb00<olPgb003o`000?ob3O;olPgb00oolPgb
00Go0000onhAk_o^4NkokQ7^o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n@Ki00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000Coldbc@03o`000?nm@[go_D:m00So
_D:m00?o0000okA;]?ndBk@01OndBk@00ol0003ob3O8olPgb00;olPgb003o`000?ob3O;olPgb017o
lPgb00?o0000onhAk_l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n@KiooT6n@0:ooT6n@03o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o=</gocC;=013o
cC;=00?o0000oke2_Onm@[d02?nm@[d00ol0003o]4^dokA;]006okA;]003o`000?o8=lSob3O800[o
b3O800?o0000oo8=l_ob3O804_ob3O800ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on@KiooT6n@09ooT6n@03o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?nm@[go_D:m00Wo_D:m00?o0000okA;]?ndBk@0
1ondBk@00ol0003ob3O8olPgb009olPgb003o`000?ob3O;olPgb01;olPgb00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?nm@[go_D:m00Wo_D:m00?o
0000okA;]?ndBk@02?ndBk@00ol0003ob3O8olPgb007olPgb003o`000?ob3O;olPgb01?olPgb00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000oldbcOo=</d03Oo=</d2
o`0000_o_D:m00?o0000okA;]?ndBk@02OndBk@00ol0003ob3O8olPgb006olPgb003o`000?ob3O;o
lPgb01?olPgb4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003ocC;=oldbc@0;oldbc@;o000000?ocS7>o`000?nm@[d02_nm@[d00ol0
003o]4^dokA;]009okA;]0Ko00000oo8=lP00ol0003olPgboo8=lP0Coo8=lP03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01?oi1_T3o`00
00Sok1?/0_l0000;on@Ki003o`000?o=</gocC;=00WocC;=0_l00004olhacP03o`000?nm@[go_D:m
00So_D:m00?o0000okA;]?ndBk@02?ndBk@00ol0003ogB;MomdRg@04omdRg@?o00005?ob3O83o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on@KiooT6n@03o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o=</gocC;=00Go
cC;=0ol00007olhacP03o`000?nm@[go_D:m00Oo_D:m00?o0000okA;]?ndBk@01ondBk@00ol0003o
gB;MomdRg@08omdRg@03o`000?ob3O;olPgb013olPgb00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000oldb
cOo=</d00oo=</d2o`0000[ocS7>00?o0000oke2_Onm@[d01onm@[d00ol0003o]4^dokA;]005okA;
]0;o00003?oM8]d00ol0003olPgboo8=lP0=oo8=lP;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000oldbcOo=</gocC;=0_l0000=olhacP03o`000?nm@[go_D:m00Ko_D:m00?o0000okA;
]?ndBk@01?ndBk@00ol0003ogB;MomdRg@0=omdRg@Co00002_ob3O800ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013ocS7>00?o0000oke2_Onm@[d01Onm@[d00ol0003o
]4^dokA;]003okA;]003o`000?oM8]gogB;M00kogB;M00Co0000ooH9m_of2OKomPWf1_l00003oo8=
lP03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o><LkocS7>013o
cS7>00?o0000oke2_Onm@[d01Onm@[d00ol0003o]4^dokA;]002okA;]003o`000?oM8]gogB;M00oo
gB;M00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000olhac_o><Lh0
4Oo><Lh00ol0003o_D:moke2_@04oke2_@03o`000?ndBkCo]4^d00;o00004OoM8]d00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o><Lh3o`0000Co_D:m00?o0000okA;]?l000004ooM
8]d00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003ocS7>017ocS7>0_l00003omPWf0;o00000_nm@[d2
o`0001CogB;M00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o><LkocS7>00gocS7>0_l00007omPWf0?o00005OoM8]d00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000olhac_o><Lh02_o><Lh2o`0000_o
f2OH00?o0000omdRgOoM8]d04_oM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o><LkocS7>00OocS7>0_l0000=omPWf003o`000?oM8]gogB;M01;ogB;M00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000olhac_o><Lh01Oo><Lh2o`0000oof2OH00?o
0000omdRgOoM8]d04_oM8]d00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000olhac_o><Lh00_o><Lh2o`0001;of2OH00?o0000omdRgOoM8]d04OoM8]d0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003olPgboo8=l_l0000@onDJi@04o`000?o><Lko
0000o`0001Cof2OH00?o0000omdRgOoM8]d04?oM8]d00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo8=l_ob3O800_ob3O800ol0003oiA[UonDJi@0>onDJi@03o`000?oH9mSof2OH01Cof2OH00?o0000
omdRgOoM8]d03OoM8]d4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003olPgboo8=lP03oo8=lP03o`000?oU6^GoiA[U
00goiA[U00?o0000omPWf?oH9mP05?oH9mP00ol0003ogB;MomdRg@07omdRg@Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo8=l_ob3O801Oob3O800ol0003oiA[UonDJi@0<onDJi@03
o`000?oH9mSof2OH01Gof2OH00?o0000omdRgOoM8]d01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003olPgboo8=lP06oo8=lP03o`000?oU6^GoiA[U00_oiA[U00?o0000omPWf?oH9mP0
5OoH9mP3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJ
i@0:onDJi@03o`000?oH9mSof2OH01Gof2OH00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo8=lP03o`000?oU6^GoiA[U00WoiA[U00?o0000omPWf?oH9mP05?oH9mP0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D02OoU6^D0
0ol0003of2OHomPWf00ComPWf003o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?ob3O800ol0003oiA[UonDJi@08onDJ
i@03o`000?oH9mSof2OH00oof2OH1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_ob3O800ol0003oiA[UonDJi@07onDJi@03o`000?oH9mSof2OH00Sof2OH1ol00003on`C
k003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo8=lP03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omPWf?oH9mSof2OH1ol0000:on`Ck003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000KolPgb00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
k1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?ob3O800ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ok1?/01Cok1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000ColPgbo`000?l0003o00001?oh1oP00ol0003ok1?/on`Ck00Bon`Ck0;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k00@on`Ck004o`000?o_4>ooka3_o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ok1?/on`Ck00?on`Ck003o`000?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o/4nco
k1?/00kok1?/00?o0000onl@koo_4>l01?o_4>l2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00=on`Ck003o`000?o_4>ooka3_
00Goka3_00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000onl@koo_4>l01_o_4>l00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ok1?/
on`Ck009on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o/4ncok1?/00Sok1?/00?o
0000onl@koo_4>l02?o_4>l00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000onl@koo_4>l02?o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ok1?/on`Ck005on`Ck003o`000?o_4>ooka3_00Woka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Co
k1?/00?o0000onl@koo_4>l02_o_4>l00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`Ck003on`Ck003o`00
0?o_4>ooka3_00[oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`C
k002on`Ck003o`000?o_4>ooka3_00_oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ok1?/on`Ck?l0000>onl@k`03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o_4>l00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000Woka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000Goka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?oka3_o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o3?ooo`000olQ8Mgo003oo`00o`05o`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP09
o`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0:o`00o`;oool0VOl00?l1ooooo`00WOl0
0?l00onHV6Koool0ogMgQ`07o`00o`03oiRHI_ooo`3oMgN700co003o0_ooo`07o`00o`03oc8bc?oo
o`3oool000Woool000?oV9QVo`00ool00?l00ol00?l02_l@4>kogMdQoooo0?mgMhOo413^o`00oomE
EJWoool0omgM8Ol@4>h6o`00o`0:oa0@k_oMgB7oool0ogMgQol@4>ko003ooeEEZOooo`3ogMdQoa0@
kPWo003o0_ooo`2Io`00o`7ooooo002Mo`00o`03onk^4?ooo`3ogMdQ00Oo003o00?ok^h@oooo0?oM
gB403?l00?l2oooo00So003o00?oA4Bjoooo0?ooo`002Oooo`000ol@4>ko003oo`00o`02o`00o`03
omgM8Oooo`3oMgN700Co003o00?oA4Bjoooo0?oMgB401_l00?l00ooMgB7oool0ogMgQ`04o`00o`03
odA4^_ooo`3ogMdQ00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00o`05oc8bc?ooo`3oool0oooo0?l@
4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`09o`00o`03ofIVV?o^kQ3o413^
00Ko003o00?oA4Bjonk^4?n7QgL00ol00?l00on7QgOoool0oooo0006o`00o`03omgM8Oooo`3oIVJH
00Co003o00?oQhMgoooo0?ooo`001_l00?l00ooMgB7oool0ofIVV008o`00o`;oool0VOl00?l1oooo
o`00W?l00?l01OnYZEGoool0oooo0?ooo`3oIVJH00Go003o00GoV9QVoooo0?ooo`3oool0ogMgQ`0;
o`00o`;oool02_l00?l00onHV6KogMdQoa0@kP06o`00o`03odA4^_nYZEGo003o00;o003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@00Co003o0_ooo`000onHV6Ko003oo`00o`04
o`00o`03ohN7Moooo`3ok^h@00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`?oool000?oIVJHokZj
A?l00?l01?l00?l01Oo^kQ3oool0oooo0?mVIYSogMdQ00_o003o0_ooo`0;o`00o`03ojVYEOoMgB7o
413^00Wo003o00CoEEFYoooo0?ooo`3oIVJH1_l00?l01?mEEJWoool0oooo0?lb</`2o`00o`04oeEE
ZOooo`3oool0ofIVV0Ko003o00CoEEFYoooo0?ooo`3o<S;<1ol00?l2oooo09Wo003o0Oooool009_o
003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o413^00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00
ooo^kQ3o8B7M00[o003o0_ooo`0;o`00o`03oa0@k_oMgB7oZJUE00Wo003o00CoV9QVoooo0?ooo`3o
A4Bj1_l00?l01?m4A;[oool0oooo0?n7QgL2o`00o`04oiRHI_ooo`3oool0odA4^PKo003o00CoA4Bj
oooo0?ooo`3oQhMg1ol00?l2oooo09Wo003o0Oooool009_o003o00OoZJUEoooo0?ooo`3oV9QVo`00
oonHV6KoIVJH00?o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN700[o003o0_ooo`0<o`00
o`03oa0@k_ooo`3oZJUE00So003o00Coc<`boooo0?ooo`3o413^1ol00?l2oooo0004olc<<_l00?oo
003oolc<<P;oool000?o413^o`00ool00?l01Ol00?l2oooo0003olc<<_l00?oo003o00Go003o0_oo
o`2Io`00o`7ooooo002Ko`00o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l0
0?ooA4BjomgM8@[o003o0_ooo`0=o`00o`03oc8bc?ooo`3oMgN700Oo003o0oooo`08o`00o`;oool0
00?ok^h@o`00ool00?l00oooo`08o`00o`;oool000?ok^h@o`00ool00?l01Ol00?l2oooo09Wo003o
0Oooool009[o003o00CoEEFYoooo0?ooo`3ogMdQ0ol00?l01?ooo`3o003oo`00oomEEJT2oooo0006
onk^4?l00?oo003oo`00ooooo`3o8B7M2Ol00?l2oooo00ko003o00?oQhMgoooo0?mEEJT01_l00?l3
oooo00So003o0oooo`02o`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00o`7ooooo002Jo`00
o`04ojVYEOooo`3oool0ogMgQ`?o003o00CoZJUEoeEEZOl00?ooZJUE0_ooo`001_nHV6Ko003oo`00
ool00?ooZJUEogMgQ`Wo003o0_ooo`0?o`00o`03onk^4?ooo`3o8B7M00Go003o0oooo`08o`00o`?o
ool00_l00?l3oooo00So003o0oooo`07o`00o`;oool0VOl00?l1ooooo`00V_l00?l3oooo0007ob4Q
gOl00?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l00?oo003oo`00oomEEJWogMdQ2Ol0
0?l2oooo00oo003o00?oMgN7oooo0?o<c3801Ol00?l3oooo00So003o0oooo`02o`00o`?oool02?l0
0?l3oooo00Oo003o0_ooo`2Io`00o`7ooooo002Io`00o`04oeEEZOooo`3oool0omgM8@Go003o00Go
k^h@oeEEZOooo`3oool0onk^4005o`00o`03oooo0?lQ8Mgo003o00Oo003o0_ooo`0?o`00o`04ob4Q
gOooo`3oool0oeEEZ@Co003o0oooo`08o`00o`?oool00_l00?l3oooo00So003o0oooo`07o`00o`;o
ool0VOl00?l1ooooo`00VOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3oool0oooo
0?n7QgL01Ol00?l00onYZEGoMgN7o`00o`07o`00o`;oool04?l00?l2oooo0003okZjA?l00?oo003o
00;o003o00Coc<`boooo0?ooo`3o<S;<1_l00?l01?lQ8Mgoool0oooo0?o<c382o`00o`04olc<<_oo
o`3oool0oc8bc0Ko003o00Co8B7Moooo0?ooo`3oc<`b1ol00?l2oooo09Wo003o0Oooool009So003o
00Go413^oooo0?ooo`3oool0ob4Qg@05o`00o`05ofIVV?ooo`3oool0oooo0?lQ8Md01Ol00?l00omE
EJWogMdQo`00o`07o`00o`;oool01ol00?l00onj^TCo8B7Mo`00o`06o`00o`?oool01?l00?l01?nH
V6Koool0oooo0?m4A;X6o`00o`04odA4^_ooo`3oool0oiRHIP;o003o00CoV9QVoooo0?ooo`3oA4Bj
1_l00?l01?m4A;[oool0oooo0?nHV6H7o`00o`;oool0VOl00?l1ooooo`00V?l00?l01?mVIYSoool0
oooo0?oMgB46o`00o`04ofIVV?ooo`3oool0omgM8@Oo003o00?oool0ob4QgOl00?l01_l00?l2oooo
00Oo003o00?o^[Y4oiRHI_l00?l01Ol00?l01?mEEJWoool0oooo0?ooo`04o`00o`04oeEEZOooo`3o
ool0ogMgQ`Ko003o00CoIVJHoooo0?ooo`3oEEFY0_l00?l01?mEEJWoool0oooo0?mgMhL6o`00o`04
ofIVV?ooo`3oool0oeEEZ@Oo003o0_ooo`2Io`00o`7ooooo002Ho`00o`04olc<<_ooo`3oool0ogMg
Q`Ko003o00Co^[Y4oooo0?ooo`3oMgN71ol00?l00onYZEGoMgN7o`00o`06o`00o`;oool01ol00?l0
0omVIYSoool0oc8bc005o`00o`04olc<<_ooo`3oool0oooo00Go003o0_ooo`000onYZEGo003oo`00
o`04o`00o`03ojVYEOooo`3ok^h@00Co003o0_ooo`000onYZEGo003oo`00o`04o`00o`03ojVYEOoo
o`3ok^h@00So003o0_ooo`2Io`00o`7ooooo002Go`00o`05ob4QgOooo`3oool0oooo0?lQ8Md01Ol0
0?l01Ol@4>koool0oooo0?ooo`3o8B7M00Oo003o00?oEEFYomgM8Ol00?l01_l00?l2oooo00Oo003o
00So413^oooo0?ooo`3oIVJHoa0@k_l00?oo<S;<olc<<P?oool000?o^[Y4o`00ool00?l00ol00?l0
1?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV0Co003o00CoQhMgoooo0?ooo`3o
413^1?l00?l01?l@4>koool0oooo0?mVIYP8o`00o`;oool0VOl00?l1ooooo`00Uol00?l01?nYZEGo
ool0oooo0?oMgB46o`00o`04ogMgQoooo`3oool0omgM8@Wo003o00?oool0ob4QgOl00?l01Ol00?l2
oooo00So003o00?oIVJHoooo0?ooo`001oooo`000olb</co003oo`00o`04o`00o`03omgM8Oooo`3o
QhMg00Co003o00?oQhMgoooo0?o<c3801_l00?l00ooMgB7oool0ohN7M`04o`00o`03ohN7Moooo`3o
c<`b00Wo003o0_ooo`2Io`00o`7ooooo002Eo`00o`03ob4QgOn7QgOoool000;oool000?ok^h@oc8b
c?l00?l00ol00?l01_mEEJWoool0oooo0?ooo`3ok^h@oc8bc0Ko003o00Ko8B7MohN7Moooo`3ok^h@
oeEEZOl@4>h4o`00o`;oool02Ol00?l00on7QgOoool0oooo0005oooo0003ofIVV?l00?oo003o00Go
003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOoool0omgM8Ol@4>h6o`00o`04oa0@k_oMgB7o
ool0ogMgQ`;o413^00CoMgN7oooo0?oMgB7o413^2Ol00?l2oooo09Wo003o0Oooool009Co003o00?o
A4Bjoooo0?ooo`001oooo`000on7QgOoool0oooo0007oooo00;o003o00?oQhMgoooo0?ooo`001Ooo
o`001?m4A;[o003oo`00ool00?l2oooo0003ogMgQol00?oo003o00Oo003o00?oA4BjokZjA?ooo`00
0_ooo`000onYZEGo<S;<o`00o`08o`00o`03oa0@k_n7QgOogMdQ00;oool000?ogMdQohN7Mol00?l0
2?l00?l00ol@4>koQhMgomgM8@02oooo0003omgM8On7QgOo003o00Wo003o00?oMgN7oooo0?ooo`00
VOl00?l1ooooo`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo003oo`00oi3o003o0Oooool0
0?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(225) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.985 .015 .985 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.963 .037 .963 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.898 .102 .898 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.901 .099 .901 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.973 .027 .973 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.928 .072 .928 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.907 .093 .907 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.794 .206 .794 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.892 .108 .892 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.94 .06 .94 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.805 .195 .805 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.938 .062 .938 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.515 .485 .515 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.446 .554 .446 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.793 .207 .793 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.904 .096 .904 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.924 .076 .924 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.698 .302 .698 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.595 .405 .595 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.772 .228 .772 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.893 .107 .893 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.984 .016 .984 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.845 .155 .845 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.949 .051 .949 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.39 .61 .39 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.959 .041 .959 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.24 .76 .24 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.411 .589 .411 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.441 .559 .441 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.175 .825 .175 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.781 .219 .781 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.125 .875 .125 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.426 .574 .426 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.945 .055 .945 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.588 .412 .588 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.801 .199 .801 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.454 .546 .454 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.182 .818 .182 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.153 .847 .153 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.085 .915 .085 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.675 .325 .675 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.804 .196 .804 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.846 .154 .846 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.893 .107 .893 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.179 .821 .179 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.087 .913 .087 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.061 .939 .061 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.186 .814 .186 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.322 .678 .322 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.923 .077 .923 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.972 .028 .972 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.76 .24 .76 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.073 .927 .073 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.934 .066 .934 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.478 .522 .478 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.73 .27 .73 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.247 .753 .247 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.508 .492 .508 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.97 .03 .97 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.689 .311 .689 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.158 .842 .158 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.979 .021 .979 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.555 .445 .555 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.078 .922 .078 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.046 .954 .046 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.863 .137 .863 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.881 .119 .881 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.12 .88 .12 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.254 .746 .254 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.767 .233 .767 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.931 .069 .931 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.06 .94 .06 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.042 .958 .042 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.105 .895 .105 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.408 .592 .408 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.638 .362 .638 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.692 .308 .692 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.266 .734 .266 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.066 .934 .066 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.985 .015 .985 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.964 .036 .964 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.047 .953 .047 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.41 .59 .41 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.827 .173 .827 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.945 .055 .945 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.232 .768 .232 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.739 .261 .739 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.134 .866 .134 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.98 .02 .98 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.924 .076 .924 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.136 .864 .136 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.338 .662 .338 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.761 .239 .761 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.953 .047 .953 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.94 .06 .94 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.857 .143 .857 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.796 .204 .796 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.811 .189 .811 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.926 .074 .926 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.813 .187 .813 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.925 .075 .925 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.924 .076 .924 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.98 .02 .98 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.956 .044 .956 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.977 .023 .977 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.979 .021 .979 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?l000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003oo0?loo`3o?ol0oco
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ol0ocoo0?l00Ko
o0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ol0oco
o0?l00_oo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooh1oP00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooP7n0;o00003oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooh
1oP2o`0000_ooP7n00?o0000oo`3o?ol0o`04Ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;on0Oh00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooP7n003o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`05?ol0o`00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oh1oP2o`0000KooP7n00?o0000oo`3
o?ol0o`05Ool0o`00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oh1oP00ol0003ooP7nooh1oP03ooh1oP03o`000?ol0oco
o0?l01Koo0?l00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom@[eo`000?oa3_7o0000on@Ki?l0000JooP7n0;o00000_on0Oh00ol0003oo0?l
oo`3o00Hoo`3o003o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om@[e00Co0000oo4>lOoa3_7o00000_oT6n@00ol0003on0OhooP7n00IooP7
n003o`000?on0Oko000001_oo0?l00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005ooD:m@05o`000?oa3_7ol@kaoo4>
lOl000000ooT6n@00ol0003on0OhooP7n00IooP7n003o`000?ol0ocoo0?l01[oo0?l00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oe2_D01Ol0003ol@kaoo4>lOoa3_7o000000Coi1_T00?o0000ooP7
n?oh1oP06?oh1oP00ol0003oo0?loo`3o00Ioo`3o003o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om@[e00?o0000oo4>lOoa
3_400_oa3_400ol0003oi1_Ton@Ki003on@Ki003o`000?oh1oSon0Oh01Oon0Oh00?o0000oo`3o?ol
0o`06Ool0o`00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooe2_D00ol0003ol@kaoo4>l@02oo4>l@03o`000?oT6nCoi1_T00Co
i1_T00?o0000ooP7n?oh1oP05ooh1oP00ol0003oo0?loo`3o00Hoo`3o003o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?ooD:m@03o`00
0?oa3_7ol@ka00?ol@ka00?o0000on@Ki?oT6n@01OoT6n@00ol0003on0OhooP7n00FooP7n003o`00
0?ol0ocoo0?l01Ooo0?l00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000AooD:m@03o`000?oa3_7ol@ka00Col@ka00?o0000on@Ki?oT6n@01_oT
6n@2o`0001Gon0Oh0ol0000Hoo`3o003o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
ooD:m@03o`000?oa3_7ol@ka00Col@ka00?o0000on@Ki?oT6n@02?oT6n@00ol0003on0OhooP7n00@
ooP7n0;o00000ooQ7^400ol0003oo0?loo`3o00Doo`3o003o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000ooD:mOoe2_D04_oe2_D00ol0003ol@kaoo4>l@05oo4>l@03o`000?oT6nCoi1_T
00Woi1_T00?o0000ooP7n?oh1oP03Ooh1oP2o`0000KohAkQ0_l0000Doo`3o003o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e01;om@[e00?o0000oo4>lOoa
3_401Ooa3_400ol0003oi1_Ton@Ki00:on@Ki003o`000?oh1oSon0Oh00[on0Oh0_l0000:on4Nh@03
o`000?ol0ocoo0?l017oo0?l00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om@[eooD:m@0@ooD:m@03o`000?oa3_7ol@ka00Ko
l@ka00?o0000on@Ki?oT6n@02ooT6n@00ol0003on0OhooP7n008ooP7n003o`000?oQ7^7ohAkQ00_o
hAkQ0_l0000@oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo4>lOoa3_40
1ooa3_400ol0003oi1_Ton@Ki00<on@Ki003o`000?oh1oSon0Oh00Gon0Oh0_l0000@on4Nh@03o`00
0?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo4>lOoa3_401ooa3_400ol0003oi1_Ton@K
i00=on@Ki003o`000?oh1oSon0Oh00;on0Oh0_l0000Con4Nh@;o00003?ol0o`00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oe2_Go
m@[e00kom@[e00?o0000oo4>lOoa3_402?oa3_400ol0003oi1_Ton@Ki00>on@Ki004o`000?oh1oSo
0000o`0001OohAkQ00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00Loo`3o003o`000?oj
1O[onPGj00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oe2_Go
m@[e00com@[e00?o0000oo4>lOoa3_402Ooa3_400ol0003oi1_Ton@Ki00?on@Ki003o`000?oQ7^7o
hAkQ01SohAkQ0_l00009oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000ooX5n_oj1OX01?oj1OX4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>ooD:m@03o`000?oa3_7ol@ka
00Wol@ka00?o0000on@Ki?oT6n@03ooT6n@00ol0003ohAkQon4Nh@0Jon4Nh@03o`000?ol0ocoo0?l
00Coo0?l0ol0000Loo`3o003o`000?oj1O[onPGj00WonPGj0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o`3o3ol0o`o`0000com@[e00?o0000oo4>lOoa3_402_oa3_400ol0003oi1_Ton@Ki00?on@K
i003o`000?oQ7^7ohAkQ01_ohAkQ0_l00003oo`3o004o`000?o`3o3ol0o`oo0?l0?o00006?ol0o`0
0ol0003onPGjooX5nP0=ooX5nP?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00;ol0o`00?o0000ooD:mOoe2_D02Ooe2_D00ol0003ol@kaoo4>l@0:oo4>l@03o`000?oT6nCoi1_T
00koi1_T00?o0000on4NhOoQ7^407_oQ7^400ol0003oo0?lo`000007oo0?l0?o00005?ol0o`00ol0
003onPGjooX5nP0AooX5nP;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o`3o000ol0003om@[eooD:m@07ooD:m@03
o`000?oa3_7ol@ka00_ol@ka00?o0000on@Ki?oT6n@03_oT6n@00ol0003ohAkQon4Nh@0Oon4Nh@03
o`000?o`3o3ol0o`00Wol0o`0ol0000@oo`3o003o`000?oj1O[onPGj01?onPGj00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol0o`
oo0?l007oo0?l003o`000?oe2_Gom@[e00Gom@[e00?o0000oo4>lOoa3_403?oa3_400ol0003oi1_T
on@Ki00>on@Ki003o`000?oQ7^7ohAkQ01oohAkQ00?o0000oo0?l?o`3o003?o`3o03o`0000goo0?l
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ol0o`00?o0000ooD:mOoe2_D01?oe
2_D00ol0003ol@kaoo4>l@0<oo4>l@03o`000?oT6nCoi1_T00koi1_T00?o0000on4NhOoQ7^407_oQ
7^400ol0003ol0o`oo0?l00@oo0?l0?o00002Ool0o`00ol0003onPGjooX5nP0FooX5nPOo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000oo0?l?o`3o003?o`3o000ol0003om@[eooD:m@02ooD:m@03o`000?oa
3_7ol@ka00gol@ka00?o0000on@Ki?oT6n@03_oT6n@00ol0003ohAkQon4Nh@0Non4Nh@03o`000?o`
3o3ol0o`01?ol0o`0ol00005oo`3o003o`000?oj1O[onPGj01OonPGj00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00kol0o`00Go0000
ooD:mOoe2_Gom@[eo`00000?oo4>l@03o`000?oT6nCoi1_T00goi1_T00?o0000on4NhOoQ7^407ooQ
7^400ol0003ol0o`oo0?l00Foo0?l0?o000000?oo0?lo`000?oj1OX06?oj1OX00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Boo0?l003o`000?oe2_Go0000013ol@ka00?o0000on@Ki?oT6n@02ooT6n@3
o`00023ohAkQ00?o0000oo0?l?o`3o006_o`3o000ol0003onPGjooX5nP0HooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`01?ol0o`00?o0000oo4>
lOoa3_403ooa3_400ol0003oi1_Ton@Ki007on@Ki0Co00000_o2?L800ol0003ohAkQon4Nh@0Non4N
h@03o`000?o`3o3ol0o`01[ol0o`00?o0000ooX5n_oj1OX05ooj1OX00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
l0o`00?o0000oo4>lOoa3_403ooa3_400ol0003oi1_Ton@Ki003on@Ki0Co00001oo2?L800ol0003o
hAkQon4Nh@0Lon4Nh@03o`000?o`3o3ol0o`01col0o`00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000oo0?l?o`3o005oo`3o000ol0003ol@kaoo4>l@0>oo4>l@03o`00
0?oT6nCo000000?o00003?o2?L800ol0003ohAkQon4Nh@0Kon4Nh@03o`000?o`3o3ol0o`01col0o`
00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o`
3o05o`0000_ol@ka0ol0000Aol8m`P03o`000?oQ7^7ohAkQ01[ohAkQ00?o0000oo0?l?o`3o007Oo`
3o000ol0003onPGjooX5nP0CooX5nP03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o`3o3ol0o`01Wol0o`00?o0000
olLhaoo7><L00_o7><L7o`0000?ol@ka00?o0000ol8m`_o2?L804oo2?L83o`0001OohAkQ0_l0000P
oo0?l003o`000?oj1O[onPGj01?onPGj00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000oo0?l?o`3o006?o`3o000ol0
003oacS7olLha`0:olLha`?o00005_o2?L800ol0003oSW6>ohiaSP05o`00013ohAkQ0_l000000ona
C[7o0000oo0?l00Ooo0?l003o`000?oj1O[onPGj01;onPGj00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000oo0?l?o`3o005_o`3o000ol0003oacS7olLha`0=olLha`03
o`000?o2?L;o`Sg201?o`Sg200?o0000ohiaS_n>LHh01_n>LHh4o`0000_ohAkQ00?o0000ok5>/Ona
C[400_naC[400ol0003ol0o`oo0?l00Noo0?l003o`000?oj1O[onPGj013onPGj00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ol0o`oo0?l00Doo0?l003o`000?o7><OoacS700ooacS7
00?o0000ol8m`_o2?L804_o2?L800ol0003oSW6>ohiaSP0:ohiaSPGo00001?oQ7^42o`0000Go/Dja
00?o0000oo0?l?o`3o007_o`3o000ol0003onPGjooX5nP0@ooX5nP03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o`
3o3ol0o`01Col0o`00?o0000olLhaoo7><L03oo7><L00ol0003o`Sg2ol8m`P0Bol8m`P03o`000?n>
LHkoSW6>00ooSW6>1?l00008ok5>/@03o`000?o`3o3ol0o`01kol0o`00?o0000ooX5n_oj1OX03_oj
1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
oo0?l?o`3o004_o`3o000ol0003oacS7olLha`0@olLha`03o`000?o2?L;o`Sg2017o`Sg200?o0000
ohiaS_n>LHh04On>LHh00ol0003oJ9MXo`000009ok5>/@03o`000?o`3o3ol0o`01gol0o`00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000oo0?l?o`3o003_o`3o03o`0001CoacS700?o0000ol8m`_o2?L804?o2?L800ol0
003oSW6>ohiaSP0@ohiaSP04o`000?mXUfSoJ9MXo`0000Wo/Dja00?o0000oo0?l?o`3o007_o`3o00
0ol0003onPGjooX5nP0<ooX5nP03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000oo0?l?o`3o002_o`3o04o`0000;obcC;00?o0000olLh
aoo7><L04_o7><L00ol0003o`Sg2ol8m`P0@ol8m`P03o`000?n>LHkoSW6>00ooSW6>00Go0000ofRG
J?mXUfSoJ9MXo`00000:ok5>/@03o`000?o`3o3ol0o`01gol0o`00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000oo0?
l?o`3o001Oo`3o04o`0000OobcC;00?o0000olLhaoo7><L04Oo7><L00ol0003o`Sg2ol8m`P0?ol8m
`P03o`000?n>LHkoSW6>013oSW6>00Go0000ofRGJ?mXUfSoJ9MXo`00000:ok5>/@03o`000?o`3o3o
l0o`01gol0o`00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o`3o3o
l0o`00Co00002oo;=</00ol0003oacS7olLha`0BolLha`03o`000?o2?L;o`Sg200ko`Sg200?o0000
ohiaS_n>LHh03on>LHh00ol0003oJ9MXofRGJ002ofRGJ003o`000?naC[7o/Dja00Wo/Dja00?o0000
oo0?l?o`3o007?o`3o03o`0000[onPGj00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000ondBkOl0003o00003oo;=</00ol0003oacS7olLha`0AolLha`03o`000?md
RgCo000000oo`Sg200?o0000ohiaS_n>LHh03_n>LHh00ol0003oJ9MXofRGJ003ofRGJ003o`000?na
C[7o/Dja00Wo/Dja00?o0000oo0?l?o`3o006Oo`3o03o`0000?okA;]00?o0000ooX5n_oj1OX01ooj
1OX00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o]4^gokA;]o`00017obcC;00?o
0000olLhaoo7><L03oo7><L01Ol0003oM8]dogB;M?mdRgCo000000[o`Sg21?l0000AohiaSP03o`00
0?mXUfSoJ9MX00?oJ9MX00?o0000ok5>/OnaC[402_naC[400ol0003ol0o`oo0?l00Foo0?l0;o0000
1oo]4^d00ol0003onPGjooX5nP05ooX5nP03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003okA;]ondBk@02ondBk@03o`000?o;=<_obcC;00kobcC;00?o
0000olLhaoo7><L03_o7><L00ol0003oM8]dogB;M003ogB;M004o`000?o2?L;o`Sg2ol8m`PKo0000
0omjQGX00ol0003oSW6>ohiaSP0>ohiaSP03o`000?mXUfSoJ9MX00CoJ9MX00?o0000ok5>/OnaC[40
2_naC[400ol0003ol0o`oo0?l00Coo0?l0?o00002_o]4^d00ol0003onPGjooX5nP03ooX5nP03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o]
4^gokA;]00?okA;]00?o0000ol/dboo;=</03_o;=</00ol0003oacS7olLha`0=olLha`03o`000?md
RgCoM8]d00GoM8]d0ol0000:ogZ5NP03o`000?n>LHkoSW6>00coSW6>00?o0000ofRGJ?mXUfP01OmX
UfP00ol0003o/Djaok5>/@0;ok5>/@03o`000?o`3o3ol0o`013ol0o`0_l0000>ondBk@03o`000?oj
1O[onPGj00;onPGj00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o]4^gokA;]00CokA;]00?o0000ol/dboo;=</03oo;=</00ol0003oacS7olLha`0;
olLha`03o`000?mdRgCoM8]d00KoM8]d00?o0000ogZ5N_mjQGX02omjQGX00ol0003oSW6>ohiaSP0;
ohiaSP03o`000?mXUfSoJ9MX00GoJ9MX00?o0000ok5>/OnaC[403?naC[400ol0003ol0o`oo0?l00<
oo0?l0?o00004Oo]4^d5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o]4^gokA;]
00KokA;]00?o0000ol/dboo;=</03_o;=</00ol0003oacS7olLha`0:olLha`03o`000?mdRgCoM8]d
00OoM8]d00?o0000ogZ5N_mjQGX02omjQGX00ol0003oSW6>ohiaSP0:ohiaSP03o`000?mXUfSoJ9MX
00KoJ9MX00?o0000ok5>/OnaC[403?naC[400ol0003ol0o`oo0?l00:oo0?l0;o00005?o]4^d00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003okA;]ondBk@07ondB
k@03o`000?o;=<_obcC;00kobcC;00?o0000olLhaoo7><L02Oo7><L00ol0003oM8]dogB;M008ogB;
M003o`000?mjQG[oNXEj00coNXEj00?o0000ohiaS_n>LHh02?n>LHh00ol0003oJ9MXofRGJ007ofRG
J003o`000?naC[7o/Dja00go/Dja1Ol00004oo0?l0?o00005Oo]4^d00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okA;]ondBk@08ondB
k@03o`000?o;=<_obcC;00oobcC;00?o0000olLhaoo7><L01oo7><L00ol0003oM8]dogB;M009ogB;
M003o`000?mjQG[oNXEj00coNXEj0ol00008ohiaSP03o`000?mXUfSoJ9MX00OoJ9MX00?o0000ok5>
/OnaC[403OnaC[400ol0003o`Sg2ol8m`P02ol8m`PCo00006?o]4^d00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o]4^gokA;]
00[okA;]00?o0000ol/dboo;=</03_o;=</00ol0003oacS7olLha`06olLha`03o`000?mdRgCoM8]d
00[oM8]d00?o0000ogZ5N_mjQGX02_mjQGX2o`0000?o?l0o00?o0000ohiaS_n>LHh01?n>LHh00ol0
003oJ9MXofRGJ008ofRGJ003o`000?naC[7o/Dja00co/Dja00?o0000ol8m`_o2?L801_o2?L800ol0
003okA;]ondBk@0EondBk@03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000ondBkOo]4^d02oo]4^d00ol0003o
bcC;ol/db`0>ol/db`03o`000?o7><OoacS700GoacS700?o0000ogB;M?mdRg@02omdRg@00ol0003o
NXEjogZ5NP08ogZ5NP;o00001_lo`3l00ol0003oSW6>ohiaSP02ohiaSP03o`000?mXUfSoJ9MX00Wo
J9MX00?o0000ok5>/OnaC[403?naC[400ol0003o`Sg2ol8m`P07ol8m`P03o`000?o]4^gokA;]01Co
kA;]00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o]4^gokA;]00gokA;]00?o0000ol/dboo;=</03_o;=</00ol0003oacS7olLha`03olLha`03o`00
0?mdRgCoM8]d00coM8]d00?o0000ogZ5N_mjQGX01_mjQGX2o`0000Wo?l0o00Go0000ohiaS_n>LHko
SW6>o`00000;ofRGJ003o`000?naC[7o/Dja00co/Dja00?o0000ol8m`_o2?L801oo2?L800ol0003o
kA;]ondBk@0CondBk@03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o]4^gokA;]00ko
kA;]00?o0000ol/dboo;=</03_o;=</00ol0003oacS7olLha`02olLha`03o`000?mdRgCoM8]d00go
M8]d00?o0000ogZ5N_mjQGX01?mjQGX2o`0000co?l0o00?o0000ohiaS_l000003?mXUfP00ol0003o
/Djaok5>/@0;ok5>/@03o`000?o2?L;o`Sg200Wo`Sg200?o0000ondBkOo]4^d04Oo]4^d00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003okA;]ondBk@0?ondBk@03o`000?o;=<_obcC;00kobcC;00Go0000olLhaoo7><Oo
acS7o`00000@ogB;M003o`000?mjQG[oNXEj00;oNXEj0_l0000?oco0?`03o`000?mXUfSoJ9MX00_o
J9MX00?o0000ok5>/OnaC[402onaC[400ol0003o`Sg2ol8m`P09ol8m`P03o`000?o]4^gokA;]017o
kA;]00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000ondBkOo]4^d04Oo]4^d00ol0003obcC;
ol/db`0>ol/db`Co00004?mdRg@00ol0003oNXEjogZ5NP02o`00017o?l0o00?o0000ofRGJ?mXUfP0
2omXUfP00ol0003o/Djaok5>/@0:ok5>/@03o`000?o2?L;o`Sg200_o`Sg200?o0000ondBkOo]4^d0
3oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ool0o`00ol0003onPGjooX5nP03ooX5nP03o`000?o]
4^gokA;]01;okA;]00?o0000ol/dboo;=</03Oo;=</00ol0003oL8m`og2?L002og2?L0;o00003_md
Rg@3o`0001?o?l0o00?o0000ofRGJ?mXUfP02omXUfP00ol0003o/Djaok5>/@0:ok5>/@03o`000?o2
?L;o`Sg200_o`Sg200?o0000ondBkOo]4^d03oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ol0ocoo0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`00000EondBk@03o`000?o;
=<_obcC;00cobcC;00?o0000og2?L?m`Sg001Om`Sg02o`0000coM8]d00?o0000oco0?olo`3l05?lo
`3l00ol0003oJ9MXofRGJ00:ofRGJ003o`000?naC[7o/Dja00[o/Dja00?o0000ol8m`_o2?L803?o2
?L800ol0003okA;]ondBk@0=ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Soo0?l00?o0000
ooX5n_l000005oo]4^d00ol0003obcC;ol/db`0:ol/db`03o`000?m`Sg3oL8m`00SoL8m`00?o0000
ogB;M?mdRg@02?mdRg@3o`0001Go?l0o0_l0000;ofRGJ003o`000?naC[7o/Dja00Wo/Dja00?o0000
ol8m`_o2?L803_o2?L800ol0003okA;]ondBk@0<ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_oo0?l00?o0000ondBkOo]4^d05_o]4^d00ol0003obcC;ol/db`09ol/db`03o`000?m`Sg3oL8m`
00[oL8m`0_l00005ogB;M0?o00000ol]dRd00ol0003o?l0ooco0?`0Aoco0?`03o`000?lNhAko7^4N
00;o00002OmXUfP00ol0003o/Djaok5>/@09ok5>/@03o`000?o2?L;o`Sg200ko`Sg200?o0000ondB
kOo]4^d02oo]4^d00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo`3o003o`000?o]4^gokA;]01Ko
kA;]00?o0000ol/dboo;=</00oo;=</6o`0000ooL8m`0_l000000omdRgCo0000o`000007obgB;@;o
00004?lo`3l00ol0003o7^4NoakQ7P03oakQ7P?o00001_mXUfP00ol0003o/Djaok5>/@09ok5>/@03
o`000?o2?L;o`Sg200oo`Sg200?o0000ondBkOo]4^d02_o]4^d00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ol0o`00ol0003okA;]
ondBk@0FondBk@Go00001OnbCK800ol0003oL8m`og2?L00?og2?L003o`000?l]dRgo;M8]00Wo;M8]
00?o0000oco0?olo`3l03?lo`3l00ol0003o7^4NoakQ7P07oakQ7P;o00000_mXUfP>o`0001;o`Sg2
00?o0000ondBkOo]4^d02Oo]4^d00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ol0ocoo0?l013oo0?l00?o0000ondBkOo]4^d05Oo]
4^d00ol0003o/Tfbok9=/P09ok9=/P03o`000?m`Sg3oL8m`00koL8m`00?o0000obgB;Ol]dRd02_l]
dRd2o`0000_o?l0o00?o0000oakQ7_lNhAh02_lNhAh2o`0000goA;]400?o0000ol8m`_o2?L804Oo2
?L800ol0003okA;]ondBk@07ondBk@03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ol0o`00ol0003okA;]ondBk@0CondBk@03o`000?nbCK;o/Tfb00[o/Tfb00?o
0000og2?L?m`Sg003_m`Sg000ol0003o;M8]obgB;@0<obgB;@03o`000?lo`3oo?l0o00Oo?l0o00?o
0000oakQ7_lNhAh02olNhAh00ol0003oA;]4odBkA00=odBkA003o`000?o2?L;o`Sg2013o`Sg200?o
0000ondBkOo]4^d01oo]4^d00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo0?loo`3o00Doo`3o003o`000?o]4^gokA;]01;okA;]00?o0000ok9=/_nbCK802onb
CK800ol0003oL8m`og2?L00>og2?L003o`000?l]dRgo;M8]00go;M8]00?o0000oco0?olo`3l01?lo
`3l2o`0000ko7^4N00?o0000odBkA?m4^d@03Om4^d@00ol0003o`Sg2ol8m`P0@ol8m`PCo00001Oo]
4^d00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l01Goo0?l5?l0000?ok9=/P03o`000?m`Sg3oL8m`00coL8m`00?o0000obkA;_l000003ol]
dRd2o`0000?o?l0o00Co0000oa?/4olCk1?o00003OlNhAh00ol0003oA;]4odBkA00>odBkA003o`00
0?o2?L;o`Sg200co`Sg20ol00004ol/db`?o00000_o]4^d00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`05Ool0o`00ol0003oj1OXonPG
j00@onPGj003o`000?nbCK;o/Tfb00go/Tfb00?o0000og2?L?m`Sg002om`Sg001?l0003o;]4^obkA
;_l0000AobgB;@03o`000?lo`3oo000000Co4n`C00?o0000oakQ7_lNhAh02_lNhAh00ol0003oA;]4
odBkA00>odBkA003o`000?o2?L;o`Sg200Wo`Sg20ol0000:ol/db`;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo0?loo`3o00Eoo`3o003o`000?oX5nSoj1OX013oj1OX00?o0000ok9=/_nbCK803Onb
CK800ol0003oL8m`og2?L00:og2?L003o`000?l^dBko;]4^00;o;]4^00?o0000obgB;Ol]dRd03ol]
dRd00ol0003o4n`Coa?/4`04oa?/4`03o`000?lNhAko7^4N00Wo7^4N00?o0000odBkA?m4^d@03_m4
^d@00ol0003o`Sg2ol8m`P06ol8m`P?o00003_o;=</00ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ol0ocoo0?l01Goo0?l00?o0000
onPGj?oX5nP04_oX5nP00ol0003o/Tfbok9=/P0=ok9=/P03o`000?m`Sg3oL8m`00WoL8m`00?o0000
obkA;_l^dBh00_l^dBh00ol0003o;M8]obgB;@0?obgB;@03o`000?lCk1?o4n`C00Go4n`C00?o0000
oakQ7_lNhAh02?lNhAh00ol0003oA;]4odBkA00?odBkA003o`000?o2?L;o`Sg200;o`Sg20ol0000B
ol/db`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo0?loo`3o00Coo`3o0?o00005?oX5nP00ol0003o/Tfbok9=/P0=ok9=/P03o`000?m`Sg3oL8m`
00SoL8m`00?o0000obkA;_l^dBh01?l^dBh00ol0003o;M8]obgB;@0>obgB;@03o`000?lCk1?o4n`C
00Ko4n`C00?o0000oakQ7_lNhAh01olNhAh00ol0003oA;]4odBkA00?odBkA003o`000?o2?L;o0000
00;o00005Oo;=</00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00ooo0?l1?l00002ooH9mP03o`000?oX5nSoj1OX01;o
j1OX00?o0000ok9=/_nbCK803OnbCK800ol0003oL8m`og2?L007og2?L003o`000?l^dBko;]4^00Go
;]4^00?o0000obgB;Ol]dRd03Ol]dRd00ol0003o4n`Coa?/4`08oa?/4`03o`000?lNhAko7^4N00Ko
7^4N00?o0000odBkA?m4^d@04?m4^d@00ol0003obcC;ol/db`0Fol/db`03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02ool0o`4o`0000KomPWf
00?o0000onPGj?oX5nP04ooX5nP00ol0003o/Tfbok9=/P0=ok9=/P03o`000?m`Sg3oL8m`00GoL8m`
00?o0000obkA;_l^dBh01ol^dBh00ol0003o;M8]obgB;@0<obgB;@03o`000?lCk1?o4n`C00Wo4n`C
00?o0000oakQ7_lNhAh01OlNhAh00ol0003oA;]4odBkA00@odBkA003o`000?o;=<_obcC;01OobcC;
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01ool
0o`4o`0000[omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o/Tfbok9=/P0=ok9=/P03o`000?m`
Sg3oL8m`00CoL8m`00?o0000obkA;_l^dBh02?l^dBh00ol0003o;M8]obgB;@0<obgB;@03o`000?lC
k1?o4n`C00[o4n`C00?o0000oakQ7_lNhAh01?lNhAh00ol0003oA;]4odBkA00@odBkA003o`000?o;
=<_obcC;01OobcC;00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo0?loo`3o004oo`3o0Co00003_of2OH00ol0003oj1OXonPGj00ConPGj003o`000?nbCK;o
/Tfb00go/Tfb00?o0000og2?L?m`Sg001?m`Sg000ol0003o;]4^obkA;P09obkA;P03o`000?l]dRgo
;M8]00_o;M8]00?o0000oa?/4olCk1<02olCk1<00ol0003o7^4NoakQ7P03oakQ7P03o`000?m4^dCo
A;]4013oA;]400?o0000ol/dboo;=</05oo;=</00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo0?loo`3o004o`0001;omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0
003o/Tfbok9=/P0>ok9=/P03o`000?m`Sg3oL8m`00;oL8m`00?o0000obkA;_l^dBh02_l^dBh00ol0
003o;M8]obgB;@0:obgB;@03o`000?lCk1?o4n`C00go4n`C00?o0000oakQ7_lNhAh00_lNhAh00ol0
003oA;]4odBkA00@odBkA003o`000?o;=<_obcC;01SobcC;00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oX5nSoj1OX01?oj1OX00?o0000ok9=/_nbCK803?nbCK84o`000003og2?L?l0003o;]4^00go
;]4^00?o0000obgB;Ol]dRd02Ol]dRd00ol0003o4n`Coa?/4`0>oa?/4`05o`000?lNhAko7^4NoakQ
7_l000004_m4^d@00ol0003obcC;ol/db`0Hol/db`?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oX5nSoj1OX
01?oj1OX00?o0000ok9=/_nbCK802onbCK800ol0003o?L8mocg2?@02ocg2?@;o00003_l^dBh00ol0
003o;M8]obgB;@09obgB;@03o`000?lCk1?o4n`C00oo4n`C00Co0000oakQ7_lNhAko00004_m4^d@0
0ol0003obcC;ol/db`0Hol/db`03o`000?o/4ncok1?/00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o/Tfbok9=/P0:
ok9=/P03o`000?lm`Sgo?L8m00Go?L8m00?o0000obkA;_l^dBh03?l^dBh00ol0003o;M8]obgB;@08
obgB;@03o`000?lCk1?o4n`C00oo4n`C1Ol0000AodBkA003o`000?o;=<_obcC;01OobcC;00?o0000
on`Ck?o/4n`01?o/4n`3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oX5nSoj1OX01?oj1OX00?o0000ok9=/_nbCK802?nbCK82o`00
00Wo?L8m00?o0000obkA;_l^dBh02ol^dBh00ol0003o;M8]obgB;@07obgB;@03o`000?lCk1?o4n`C
00go4n`C0ol00005o`o`3`03o`000?m4^dCoA;]400koA;]400?o0000ol/dboo;=</05_o;=</00ol0
003ok1?/on`Ck008on`Ck0?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonPGj003o`000?nbCK;o/Tfb00Ko/Tfb00?o0000ocg2?Olm
`Sd02_lm`Sd00ol0003o;]4^obkA;P0:obkA;Q[o00002Ol?l0l00ol0003oA;]4odBkA00<odBkA0?o
00005_o;=</00ol0003ok1?/on`Ck00<on`Ck0?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oU6^D3o`0001;oj1OX00?o0000ok9=/_nbCK801?nbCK82o`0000ko?L8m
00?o0000obkA;_l^dBh01ol^dBh2o`0000[o5^TF00?o0000o`_d2ol;m0/03?l;m0/00ol0003o3o0?
o`o`3`08o`o`3`;o00002_m4^d@2o`0000?o8]dR0_l0000Col/db`03o`000?o/4ncok1?/013ok1?/
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onDJi@;o00004?oX
5nP00ol0003o/Tfbok9=/P03ok9=/P03o`000?lm`Sgo?L8m00oo?L8m00?o0000obkA;_l^dBh01?l^
dBh2o`0000co5^TF00?o0000o`_d2ol;m0/03?l;m0/00ol0003o3o0?o`o`3`0:o`o`3`03o`000?m4
^dCoA;]400GoA;]40_l00007ob;M8P03o`000?o;=<_obcC;00oobcC;00?o0000on`Ck?o/4n`04Oo/
4n`01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onDJiOoU6^D01OoU6^D2o`0000ooj1OX00Go0000ok9=/_nbCK;o/Tfbo`00000Cocg2?@03o`00
0?l^dBko;]4^00;o;]4^00?o0000oaKY5_lFjAH03OlFjAH00ol0003o2o@;o`_d2`0;o`_d2`03o`00
0?l?l0oo3o0?00_o3o0?00?o0000odBkA?m4^d@00_m4^d@2o`0000[o8]dR0_l0000>ol/db`03o`00
0?o/4ncok1?/017ok1?/00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onDJiOoU6^D01_oU6^D3o`0000_oj1OX1Ol0000Eocg2?@04o`00
0?l^dBko0000o`00013o5^TF00?o0000o`_d2ol;m0/02ol;m0/00ol0003o3o0?o`o`3`0<o`o`3`04
o`000?m4^dCo0000o`0000ko8]dR0_l0000;ol/db`03o`000?o/4ncok1?/017ok1?/00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oU6^GoiA[U00WoiA[U0_l00008onPGj003o`000?nHIiSoV6NH00;oV6NH00?o0000ocg2?Olm
`Sd05?lm`Sd00ol0003o5^TFoaKY5P0@oaKY5P03o`000?l;m0_o2o@;00_o2o@;00?o0000o`o`3ol?
l0l03Ol?l0l00ol0003o8]dRob;M8P0@ob;M8P03o`000?o;=<_obcC;00OobcC;00?o0000on`Ck?o/
4n`04Oo/4n`00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oU6^GoiA[U00_oiA[U
0_l00005onPGj003o`000?nHIiSoV6NH00CoV6NH00?o0000ocg2?Olm`Sd04olm`Sd00ol0003o5^TF
oaKY5P0@oaKY5P03o`000?l;m0_o2o@;00_o2o@;00?o0000o`o`3ol?l0l03Ol?l0l00ol0003o8]dR
ob;M8P0Aob;M8P;o00000oo;=</4o`0001?ok1?/00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oU6^GoiA[U00goiA[U0ol000000ooX5nSo0000oiQWV007oiQWV003o`000?lm`Sgo?L8m01;o
?L8m00?o0000oaKY5_lFjAH04?lFjAH00ol0003o2o@;o`_d2`0;o`_d2`03o`000?l?l0oo3o0?00go
3o0?00?o0000ob;M8_lRgB804olRgB83o`0000?od2o@00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oU6^GoiA[U013oiA[U00?o0000oiQWV?nHIiP0
2?nHIiP00ol0003o?L8mocg2?@0Aocg2?@03o`000?lFjAKo5^TF017o5^TF00?o0000o`_d2ol;m0/0
2_l;m0/00ol0003o3o0?o`o`3`0<o`o`3`03o`000?l<l`co000001Co8]dR00?o0000om0_d?o@;m00
1?o@;m000ol0003ok1?/on`Ck00>on`Ck003o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onDJiOoU6^D03ooU
6^D00ol0003oV6NHoiQWV009oiQWV003o`000?lm`Sgo?L8m013o?L8m00?o0000oaKY5_lFjAH04OlF
jAH00ol0003o2o@;o`_d2`0:o`_d2`03o`000?l?l0oo3o0?00_o3o0?00Co0000o`cc3?l<l`co0000
5?lRgB800ol0003od2o@om0_d005om0_d003o`000?o/4ncok1?/00cok1?/00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiA[UonDJ
i@0?onDJi@03o`000?nHIiSoV6NH00[oV6NH00?o0000ocg2?Olm`Sd03_lm`Sd00ol0003o5NXEo`00
000BoaKY5P03o`000?l;m0_o2o@;00[o2o@;00?o0000o`o`3ol?l0l02_l?l0l00ol0003o3?<<o`cc
3002o`cc3003o`000?lRgB;o8]dR013o8]dR00?o0000om0_d?o@;m001oo@;m000ol0003ok1?/on`C
k00:on`Ck003o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oU6^GoiA[U00ooiA[U00?o0000oiQWV?nHIiP0
2onHIiP00ol0003o?L8mocg2?@0<ocg2?@05o`000?lEjQGo5NXEoaGZ5Ol000004OlFjAH00ol0003o
2o@;o`_d2`0:o`_d2`03o`000?l?l0oo3o0?00Wo3o0?00?o0000o`cc3?l<l``00ol<l``00ol0003o
8]dRob;M8P0@ob;M8P03o`000?o@;m3od2o@00Sod2o@00?o0000on`Ck?o/4n`02?o/4n`00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onDJiOoU6^D03_oU6^D00ol0003oV6NHoiQWV00=oiQWV003o`00
0?lm`Sgo?L8m00[o?L8m00?o0000oaGZ5OlEjQD00olEjQD00ol0003o5^TFoaKY5P0?oaKY5P03o`00
0?l;m0_o2o@;00Wo2o@;00?o0000o`o`3ol?l0l02?l?l0l00ol0003o3?<<o`cc3005o`cc3003o`00
0?lRgB;o8]dR00oo8]dR00?o0000om0_d?o@;m002Oo@;m000ol0003ok1?/on`Ck006on`Ck003o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiA[UonDJi@0>onDJi@03o`000?nH
IiSoV6NH00koV6NH00?o0000ocg2?Olm`Sd02?lm`Sd00ol0003o5NXEoaGZ5@05oaGZ5@03o`000?lF
jAKo5^TF00ko5^TF00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o3o0?o`o`3`07o`o`3`03o`000?l<
l`co3?<<00Ko3?<<00?o0000ob;M8_lRgB803olRgB800ol0003od2o@om0_d009om0_d003o`000?o/
4ncok1?/00Gok1?/00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiA[UonDJi@0=
onDJi@03o`000?nHIiSoV6NH00ooV6NH00?o0000ocg2?Olm`Sd01_lm`Sd00ol0003o5NXEoaGZ5@07
oaGZ5@03o`000?lFjAKo5^TF00go5^TF00?o0000o`_d2ol;m0/02Ol;m0/00ol0003o3o0?o`o`3`04
o`o`3`?o00002_l<l``00ol0003o8]dRob;M8P0=ob;M8P03o`000?o@;m3od2o@00_od2o@00?o0000
on`Ck?o/4n`00oo/4n`00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oU6^GoiA[U
00goiA[U00?o0000oiQWV?nHIiP04?nHIiP00ol0003o?L8mocg2?@05ocg2?@03o`000?lEjQGo5NXE
00So5NXE00?o0000oaKY5_lFjAH03?lFjAH00ol0003o2o@;o`_d2`09o`_d2`03o`000?l?l0oo0000
00Co00000_l:m@X00ol0003o3?<<o`cc3008o`cc3003o`000?lRgB;o8]dR00go8]dR00?o0000om0_
d?o@;m003?o@;m001Ol0003ok1?/on`Ck?o/4nco000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0
003oV6NHoiQWV00AoiQWV003o`000?lm`Sgo?L8m00?o?L8m00?o0000oaGZ5OlEjQD02_lEjQD00ol0
003o5^TFoaKY5P0;oaKY5P03o`000?l;m0_o2o@;00So2o@;0ol00008o`[e2P03o`000?l<l`co3?<<
00So3?<<00?o0000ob;M8_lRgB803?lRgB800ol0003od2o@om0_d00=om0_d003o`000?o/4nco0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oU6^GoiA[U00goiA[U00?o0000oiQWV?nHIiP04_nHIiP01Ol0
003o?L8mocg2?Olm`Sgo000000ko5NXE00?o0000oaKY5_lFjAH02olFjAH00ol0003o2o@;o`_d2`06
o`_d2`03o`000?l:m@[o2_D:00Wo2_D:00?o0000o`cc3?l<l``02Ol<l``00ol0003o8]dRob;M8P0:
ob;M8P03o`000?o@;m3od2o@00ood2o@00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onDJiOoU6^D03OoU6^D00ol0003oV6NHoiQWV00CoiQWV003o`000?lm`Sgo0000
013o5NXE3_l00006o`_d2`;o00003?l:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lRgB;o8]dR
00[o8]dR00?o0000om0_d?o@;m003oo@;m000ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onDJiOoU6^D02ooU6^D00ol0003o
V6NHoiQWV00DoiQWV0?o00003olEjQD00ol0003o3o0?o`o`3`0<o`o`3`04o`000?l;m0_o2o@;o`_d
2`;o00003ol:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lRgB;o8]dR00Wo8]dR00?o0000om0_
d?o@;m004?o@;m000ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oU6^GoiA[U00_o
iA[U00?o0000oiQWV?nHIiP04onHIiP01Ol0003o;=</obcC;?l/dbco000000go5NXE00?o0000o`o`
3ol?l0l03_l?l0l00ol0003o2o@;o`00000Ao`[e2P03o`000?l<l`co3?<<00Wo3?<<00?o0000ob;M
8_lRgB802OlRgB800ol0003od2o@om0_d00@om0_d003o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000BoiQWV003o`000?l/dbco;=</00?o;=</00?o0000oaGZ5OlEjQD02OlEjQD00ol0003o
3o0?o`o`3`0@o`o`3`03o`000?l:m@[o2_D:017o2_D:00?o0000o`cc3?l<l``02Ol<l``00ol0003o
8]dRob;M8P07ob;M8P03o`000?o@;m3od2o@017od2o@00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iQWVonHIiP0<onHIiP03o`000?n3O8?oPgb300?o00003_nHIiP00ol0003o;=</obcC;005obcC;003
o`000?lEjQGo5NXE00Oo5NXE00?o0000o`o`3ol?l0l04Ol?l0l00ol0003o2_D:o`[e2P0Ao`[e2P03
o`000?l<l`co3?<<00Wo3?<<00?o0000ob;M8_lRgB801_lRgB82o`0001Cod2o@00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiQWV00koiQWV
00?o0000oh=lPon3O8<00on3O8<3o`0000[oV6NH00?o0000obcC;?l/db`01ol/db`00ol0003o5NXE
oaGZ5@05oaGZ5@03o`000?l?l0oo3o0?01;o3o0?00?o0000o`[e2_l:m@X04Ol:m@X00ol0003o3?<<
o`cc300:o`cc3003o`000?lRgB;o8]dR00;o8]dR0ol00002ob;M8P03o`000?o@;m3od2o@017od2o@
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oV6NKoiQWV00koiQWV00?o0000oh=lPon3O8<01_n3
O8<3o`0000KoV6NH00?o0000obcC;?l/db`02Ol/db`00ol0003o5NXEoaGZ5@03oaGZ5@03o`000?l?
l0oo3o0?01?o3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lR
gB;o000000;o00001_lRgB800ol0003od2o@om0_d00@om0_d003o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oV6NKo
iQWV00goiQWV00?o0000oh=lPon3O8<02_n3O8<3o`0000;oV6NH00?o0000obcC;?l/db`02ol/db`0
1Ol0003o5NXEoaGZ5OlEjQGo000001Ko3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o3?<<o`cc
300:o`cc3003o`000?lRgB;o8]dR00So8]dR00?o0000om0_d?o@;m004?o@;m000ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oV6NKoiQWV00goiQWV00?o0000oh=lPon3O8<03On3O8<2o`0000oo;=</00?o0000oaGZ5Ol00000
5ol?l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l<l`co3?<<00Wo3?<<00?o0000ob;M8_lRgB80
2OlRgB800ol0003od2o@om0_d00?om0_d003o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV
6NH00ol0003oPgb3oh=lP`0>oh=lP`03o`000?l/dbco;=</00ko;=</00?o0000o`o`3ol?l0l05_l?
l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l<l`co3?<<00So3?<<00?o0000ob;M8_lRgB802olR
gB85o`0000cod2o@00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV6NH00ol0003oPgb3oh=lP`0>
oh=lP`03o`000?l/dbco;=</00ko;=</00?o0000o`o`3ol?l0l05_l?l0l00ol0003o2_D:o`[e2P0C
o`[e2P03o`000?l<l`co3?<<00Oo3?<<00?o0000ob;M8_lRgB803?lRgB800ol0003occ3?oll`c`02
oll`c`Wo00001?o@;m000ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiQWVonHIiP0<onHIiP03o`000?n3O8?oPgb3
00koPgb300?o0000obcC;?l/db`03ol/db`00ol0003o3o0?o`o`3`0Eo`o`3`03o`000?l:m@[o2_D:
01?o2_D:1?l00005o`cc3003o`000?lRgB;o8]dR00go8]dR00?o0000oll`coo?<<l02oo?<<l4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oV6NKoiQWV00_oiQWV00?o0000oh=lPon3O8<03on3O8<00ol0003o;=</obcC;00?obcC;003
o`000?l?l0oo3o0?01Go3o0?00?o0000o`[e2_l:m@X04?l:m@X3o`0000Co4>l@0ol000000ol<l`co
0000ob;M8P0>ob;M8P03o`000?o?<<oocc3?00oocc3?00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiQWVonHIiP0;onHIiP03o`00
0?n3O8?oPgb300ooPgb300?o0000obcC;?l/db`03ol/db`2o`0001Co3o0?0ol0000@o`[e2P;o0000
2_l@ka000ol0003o8]dRob;M8P0>ob;M8P03o`000?o?<<oocc3?013occ3?0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oV6NKoiQWV00_oiQWV4ol0000>obcC;0?o0000
0_lOgal00ol0003o3o0?o`o`3`0<o`o`3`Go00000_lBkA800ol0003o2_D:o`[e2P0<o`[e2P;o0000
3?l@ka000ol0003o8]dRob;M8P0>ob;M8P03o`000?o?<<oocc3?013occ3?00?o0000oo@;m?l00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV
6NKoiQWV00_oiQWV00?o0000og:=L_mbSG803ombSG800ol0003o;=</obcC;009obcC;0?o00001_lO
gal00ol0003o3o0?o`o`3`06o`o`3`Go00002?lBkA800ol0003o2_D:o`[e2P08o`[e2P?o00003ol@
ka000ol0003o8]dRob;M8P0=ob;M8P03o`000?o?<<oocc3?00oocc3?00Go0000oo@;m?od2oCom0_d
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHI
iP0;onHIiP03o`000?mbSG;oLXeb00ooLXeb00?o0000obcC;?l/db`01_l/db`3o`0000[o7mlO00?o
0000o`o`3ol?l0l01Ol0000>oa;]4P03o`000?l:m@[o2_D:00Go2_D:0_l0000Boa3_4003o`000?lR
gB;o8]dR00co8]dR00?o0000oll`coo?<<l04?o?<<l00ol0003om0_doo@;m002oo@;m003o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHIiP0;
onHIiP03o`000?mbSG;oLXeb013oLXeb00?o0000obcC;?l/db`00_l/db`3o`0000go7mlO0ol0000C
oa;]4P03o`000?l:m@[o2_D:00?o2_D:0_l0000Eoa3_4003o`000?lRgB;o8]dR00_o8]dR00?o0000
oll`coo?<<l03oo?<<l00ol0003om0_doo@;m004oo@;m003o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiQWVonHIiP08onHIiPCo00004OmbSG800ol0003o;=</o`000002o`00
00oo7mlO00?o0000obOH9ol000005OlBkA800ol0003o2_D:o`000002o`0001Oo4>l@00?o0000ob;M
8_lRgB802olRgB800ol0003occ3?oll`c`0>oll`c`03o`000?od2oCom0_d00Kom0_d00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV6NKoiQWV00Go
iQWV0ol00004ol/db`03o`000?mbSG;oLXeb00koLXeb0_l0000AoaoO7`04o`000?lWf2Oo9mPWo`00
01Ko4^dB00?o0000oa3_4?l@ka006?l@ka000ol0003o8]dRob;M8P0;ob;M8P03o`000?o?<<oocc3?
00kocc3?00?o0000oo@;m?od2o@01ood2o@00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oV6NKoiQWV00;oiQWV0ol00008ol/db`03
o`000?mbSG;oLXeb00coLXeb0ol0000?oaoO7`;o00000olWf2L00ol0003o4^dBoa;]4P0Doa;]4P03
o`000?l@ka3o4>l@01Wo4>l@00?o0000ob;M8_lRgB802_lRgB800ol0003occ3?oll`c`0=oll`c`03
o`000?od2oCom0_d00Wom0_d00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<ol/db`03o`000?mbSG;oLXeb00[oLXeb00Go0000of>LHomSW6?o
HiaSo`00000=oaoO7`03o`000?lWf2Oo9mPW00Co9mPW00?o0000oa;]4_lBkA804olBkA800ol0003o
4>l@oa3_400Ioa3_4003o`000?lRgB;o8]dR00Wo8]dR00?o0000oll`coo?<<l03_o?<<l00ol0003o
m0_doo@;m00:oo@;m0;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o;=<_obcC;00cobcC;0_l00008og:=LP;o00001OmSW6<00ol0003o7mlOoaoO7`09oaoO7`03o`00
0?lWf2Oo9mPW00Go9mPW00?o0000oa;]4_lBkA804olBkA800ol0003o4>l@oa3_400Joa3_40go0000
3_o?<<l00ol0003om0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003obcC;ol/db`0=ol/db`03o`000?mb
SG;oLXeb00CoLXeb00?o0000of>LHomSW6<01_mSW6<2o`0000So7mlO00?o0000obOH9olWf2L01_lW
f2L00ol0003o4^dBoa;]4P0Doa;]4P03o`000?l@ka3o4>l@01Wo4>l@00?o0000oeJYE_mFZEH02_mF
ZEH00ol0003occ3?oll`c`0;oll`c`03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000ol/dboo;=</03_o;=</0
1?l0003oLXebog:=L_mbSG82o`0000_oHiaS00?o0000oaoO7olOgal00olOgal2o`0000Wo9mPW00?o
0000oa;]4_lBkA805?lBkA800ol0003o4>l@oa3_400Hoa3_4003o`000?mFZEKoEZUF00coEZUF00?o
0000oll`coo?<<l02Oo?<<l00ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obcC;ol/db`0>ol/db`03o`000?mbSG;o
000000koHiaS00Go0000oaoO7olOgaoo7mlOo`00000;obOH9`03o`000?lBkA;o4^dB01Co4^dB0_l0
000Ioa3_4003o`000?mFZEKoEZUF00goEZUF0_l00008oll`c`03o`000?od2oCom0_d00kom0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obcC;ol/db`0?
ol/db`03o`000?mSW6?oHiaS00koHiaS00?o0000oaoO7ol000003?lWf2L00ol0003o4^dBoa;]4P0D
oa;]4P03o`000?lJiA[o000000;o00005Ol@ka000ol0003oEZUFoeJYEP0@oeJYEP03o`000?o?<<oo
cc3?00Gocc3?00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003obcC;ol/db`0>ol/db`03o`000?mSW6?oHiaS00koHiaS0_l0000=obOH
9`03o`000?lBkA;o4^dB01?o4^dB00?o0000oa[U6_lJiAX00olJiAX2o`0001;o4>l@00?o0000oeJY
E_mFZEH04_mFZEH01?l0003occ3?oll`coo?<<l3o`0001;om0_d00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000ol/dboo;=</03Oo;=</2o`0000ooHiaS00?o0000ofVF
JOl000003_lWf2L00ol0003o4^dBoa;]4P0Boa;]4P03o`000?lJiA[o6^DJ00Go6^DJ0ol0000?oa3_
4003o`000?mFZEKoEZUF01?oEZUF0ol00002on`Ck003o`000?od2oCom0_d013om0_d00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000ol/dboo;=</02oo;=</00ol0003o
cS7>o`00000>of>LH`05o`000?mYUVWoJIIYofVFJOl000003OlWf2L00ol0003o4^dBoa;]4P0Aoa;]
4P03o`000?lJiA[o6^DJ00Wo6^DJ0ol0000:oa3_40;o00005_mFZEH00ol0003ok1?/on`Ck003on`C
k003o`000?od2oCom0_d013om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000ol/dboo;=</02_o;=</01Ol0003ocS7>olhac_o><Lko000000coHiaS00?o0000ofVF
JOmYUVT00_mYUVT00ol0003o9mPWobOH9`0;obOH9`03o`000?lBkA;o4^dB017o4^dB00?o0000oa[U
6_lJiAX03?lJiAX2o`0000Ko4>l@0_l000000olka3_o0000oeJYEP0DoeJYEP03o`000?o/4ncok1?/
00Gok1?/00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003obcC;ol/db`07ol/db`;o00001Oo><Lh00ol0003oHiaSof>LH`08of>LH`03
o`000?mYUVWoJIIY00CoJIIY00?o0000obOH9olWf2L02OlWf2L4o`00013o4^dB00?o0000oa[U6_lJ
iAX03olJiAX3o`000003oa3_4?l0003o000000Co>l@k00?o0000oeJYE_mFZEH04OmFZEH00ol0003o
k1?/on`Ck007on`Ck003o`000?od2oCom0_d00oom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000ol/dboo;=</01_o;=</00ol0003ocS7>olhacP05olhacP03o`00
0?mSW6?oHiaS00OoHiaS00?o0000ofVFJOmYUVT01OmYUVT00ol0003o9mPWobOH9`08obOH9`03o`00
0?l_d2oo;m0_00;o;m0_0ol0000=oa;]4P03o`000?lJiA[o6^DJ01;o6^DJ00?o0000oc_4>olka3/0
1Olka3/00ol0003oEZUFoeJYEP0@oeJYEP03o`000?o/4ncok1?/00Ook1?/00?o0000oo@;m?od2o@0
3ood2o@00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003obcC;ol/d
b`04ol/db`03o`000?o><LkocS7>00OocS7>00?o0000of>LHomSW6<01OmSW6<00ol0003oJIIYofVF
J@07ofVFJ@03o`000?lWf2Oo9mPW00Ko9mPW00?o0000obo@;ol_d2l01_l_d2l3o`0000So4^dB0_l0
000Eoa[U6P03o`000?lka3_o>l@k00Ko>l@k00?o0000oeJYE_mFZEH03_mFZEH00ol0003ok1?/on`C
k009on`Ck003o`000?od2oCom0_d00kom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000ol/dboo;=</00_o;=</2o`0000[ocS7>00?o0000of>LHomSW6<01?mSW6<0
0ol0003oJIIYofVFJ@09ofVFJ@03o`000?lWf2Oo9mPW00?o9mPW0_l0000<obo@;`?o00000_lBkA83
o`000003obSG:?l0003o6^DJ01Co6^DJ00?o0000oc_4>olka3/01olka3/00ol0003oEZUFoeJYEP0<
oeJYEP03o`000?o/4ncok1?/00_ok1?/00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003obcC;ol/dbol0000=olhacP03o`000?mSW6?o
HiaS00;oHiaS00?o0000ofVFJOmYUVT02_mYUVT00ol0003o9mPWobOH9`02obOH9`03o`000?l_d2oo
;m0_00oo;m0_0_l00005obSG:003o`000?lJiA[o6^DJ01;o6^DJ00?o0000oc_4>olka3/02?lka3/0
0ol0003oEZUFoeJYEP0:oeJYEP03o`000?o/4ncok1?/00gok1?/1Ol0000;oo@;m003o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o;=<_o000000oocS7>00Co0000of>L
HomSW6?o00003_mYUVT01?l0003o9mPWobOH9ol0000Cobo@;`03o`000?lXebSo:=LX00Co:=LX00?o
0000oa[U6_lJiAX04?lJiAX00ol0003o>l@koc_4>`09oc_4>`03o`000?mFZEKoEZUF00[oEZUF00?o
0000on`Ck?o/4n`03Oo/4n`00ol0003onPGjooX5nP02ooX5nPWo00000_od2o@00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?o><LkocS7>00kocS7>00?o0000of>LHol000003omYUVT0
0ol0003o9mPWo`00000Cobo@;`03o`000?lXebSo:=LX00Go:=LX00?o0000oa[U6_lJiAX04?lJiAX0
0ol0003o>l@koc_4>`0:oc_4>`03o`000?mFZEKoEZUF00SoEZUF00?o0000on`Ck?o/4n`03Oo/4n`0
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000olha
c_o><Lh03oo><Lh00ol0003oJIIYofVFJ@0>ofVFJ@;o00005?l_d2l00ol0003o:=LXobSG:006obSG
:003o`000?lJiA[o6^DJ00oo6^DJ00?o0000oc_4>olka3/02olka3/00ol0003oEZUFoeJYEP04oeJY
EP?o00004?o/4n`00ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
cS7>olhacP0@olhacP03o`000?mYUVWoJIIY00_oJIIY0ol000000om]TVgo0000obo@;`0Bobo@;`03
o`000?lXebSo:=LX00Oo:=LX00?o0000oa[U6_lJiAX03olJiAX00ol0003o>l@koc_4>`0<oc_4>`03
o`000?mFZEKoEZUF00?o00000ooK9=/00ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000olhac_o><Lh04?o><Lh3o`0000WoJIIY0_l00005offBK@03o`00
0?l_d2oo;m0_013o;m0_00?o0000obSG:?lXebP02?lXebP00ol0003o6^DJoa[U6P0>oa[U6P03o`00
0?lka3_o>l@k00go>l@k0_l00007om/Tf`03o`000?o/4ncok1?/00_ok1?/00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o><LkocS7>00oocS7>00Co
0000olDjaOo5>/GoaC[50_l00005ofVFJ@;o00002?m]TVd00ol0003o;m0_obo@;`0>obo@;`03o`00
0?lXebSo:=LX00[o:=LX00?o0000oa[U6_lJiAX03?lJiAX00ol0003o>l@koc_4>`0>oc_4>`03o`00
0?oK9=_ofbCK00OofbCK00?o0000on`Ck?o/4n`02_o/4n`00ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006olDja@03o`000?mYUVWo000000;o00002_m]
TVd00ol0003o;m0_obo@;`0=obo@;`03o`000?lXebSo:=LX00_o:=LX00?o0000oa[U6_lJiAX03?lJ
iAX00ol0003o>l@koc_4>`0=oc_4>`03o`000?oK9=_ofbCK00WofbCK00?o0000on`Ck?o/4n`02?o/
4n`00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o`3o3o
l0o`00ool0o`00?o0000olDjaOo5>/D01Oo5>/D00ol0003oKI9]offBK@0<offBK@03o`000?l_d2oo
;m0_00co;m0_00?o0000obSG:?lXebP03?lXebP2o`0000co6^DJ00?o0000oc_4>olka3/03Olka3/0
0ol0003ofbCKom/Tf`0:om/Tf`03o`000?o/4ncok1?/00Ook1?/00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o`3o004?o`3o000ol0003oaC[5olDja@06olDja@03o`000?m]TVgo
KI9]00coKI9]00?o0000obo@;ol_d2l02ol_d2l00ol0003o:=LXobSG:00=obSG:004o`000?m1_T7o
0000o`0000[o6^DJ00?o0000oc_4>olka3/03Olka3/00ol0003ofbCKom/Tf`0;om/Tf`03o`000?o/
4ncok1?/00Kok1?/00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003ol0o`oo0?l00@
oo0?l003o`000?o5>/GoaC[500KoaC[500?o0000offBKOm]TVd03Om]TVd00ol0003o;m0_obo@;`0:
obo@;`03o`000?lXebSo:=LX00co:=LX00?o0000od6n@Om1_T400_m1_T42o`0000So6^DJ00?o0000
oc_4>olka3/03?lka3/00ol0003ofbCKom/Tf`0=om/Tf`03o`000?o/4ncok1?/00Cok1?/00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@oo0?l003o`000?o5>/GoaC[5
00OoaC[500?o0000offBKOm]TVd03_m]TVd<o`0000oo:=LX00?o0000od6n@Om1_T401?m1_T42o`00
00Ko6^DJ00?o0000oc_4>olka3/03?lka3/00ol0003ofbCKom/Tf`0>om/Tf`03o`000?o/4ncok1?/
00?ok1?/00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>oo0?
l003o`000?o5>/GoaC[500SoaC[500?o0000offBKOm]TVd03Om]TVd00ol0003oDZeBoe:]DP08oe:]
DP03o`000?lXebSo:=LX00co:=LX00?o0000od6n@Om1_T401om1_T42o`0000?o6^DJ00?o0000oc_4
>olka3/03Olka3/00ol0003ofbCKom/Tf`0?om/Tf`05o`000?o/4ncok1?/on`Ck?l000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo`3o000ol0003oaC[5olDja@08olDja@03o`000?m]TVgo
KI9]00coKI9]00?o0000oe:]D_mB[E802_mB[E800ol0003o:=LXobSG:00;obSG:003o`000?m1_T7o
@Ki100Wo@Ki10_l000000olJiA[o0000oc_4>`08oc_4>`Ko00004ooK9=/01?l0003ok1?/on`Ck?l0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008oo0?l003o`000?o5>/Go
aC[500WoaC[500?o0000offBKOm]TVd03?m]TVd00ol0003oDZeBoe:]DP0:oe:]DP03o`000?lXebSo
:=LX00[o:=LX00?o0000od6n@Om1_T403?m1_T4;o`0000Go_D:m00?o0000om/TfooK9=/04_oK9=/0
0ol0003ok1?/o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on@K
i?oT6nCoi1_T1Ol00003oo0?l003o`000?o5>/GoaC[500WoaC[500?o0000offBKOm]TVd02om]TVd0
0ol0003oDZeBoe:]DP0<oe:]DP03o`000?lXebSo:=LX00Wo:=LX00?o0000od6n@Om1_T403?m1_T40
0ol0003oJ9MXofRGJ002ofRGJ003o`000?nm@[go_D:m00Wo_D:m00?o0000om/TfooK9=/04_oK9=/3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on@K
i?oT6n@01OoT6n@3o`0000coaC[500?o0000offBKOm]TVd02om]TVd00ol0003oDZeBoe:]DP0<oe:]
DP03o`000?lXebSo:=LX00So:=LX00?o0000od6n@Om1_T403?m1_T400ol0003oJ9MXofRGJ004ofRG
J003o`000?nm@[go_D:m00So_D:m00?o0000om/TfooK9=/04_oK9=/00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oT6nCoi1_T00Ooi1_T00?o0000olDj
aOo5>/D02_o5>/D00ol0003oKI9]offBK@09offBK@;o00003omB[E800ol0003o:=LXobSG:008obSG
:003o`000?m1_T7o@Ki100co@Ki100?o0000ofRGJ?mXUfP01?mXUfP00ol0003o_D:moke2_@09oke2
_@Co00003ooK9=/00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on@Ki?oT6n@02?oT6n@00ol0003oaC[5olDja@09olDja@03o`000?m]TVgoKI9]00Ko
KI9]0ol000000onFJIKo0000oe:]DP0?oe:]DP03o`000?lXebSo:=LX00Ko:=LX00?o0000od6n@Om1
_T403Om1_T400ol0003oJ9MXofRGJ005ofRGJ003o`000?nm@[go_D:m00So_D:m00Co0000oo<<looc
3??ol`cc1Ol00009om/Tf`03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003oi1_Ton@Ki007on@Ki003o`000?o5>/GoaC[500[oaC[500?o0000offBKOm]
TVd00_m]TVd3o`0000GoUVVF00?o0000oe:]D_mB[E803OmB[E800ol0003o:=LXobSG:006obSG:003
o`000?m1_T7o@Ki100co@Ki100?o0000ofRGJ?mXUfP01_mXUfP00ol0003o_D:moke2_@08oke2_@03
o`000?oc3??ol`cc00Kol`cc1Ol00003om/Tf`03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on@Ki?oT6n@01ooT6n@00ol0003oaC[5olDja@0:olDja@03o`000?m]TVgo000000;o0000
2?nFJIH00ol0003oDZeBoe:]DP0=oe:]DPCo00001?lXebP00ol0003o@Ki1od6n@@0=od6n@@03o`00
0?mXUfSoJ9MX00OoJ9MX00?o0000oke2_Onm@[d01onm@[d00ol0003ol`ccoo<<l`0;oo<<l`?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on@Ki?oT6n@02?oT6n@3o`0000WoaC[50_l0
000<oiIYUP03o`000?mB[E;oDZeB00_oDZeB00?o0000oh9mP_n2OH800_n2OH83o`000003obSG:?l0
003o@Ki100ko@Ki100?o0000ofRGJ?mXUfP01omXUfP00ol0003o_D:moke2_@06oke2_@03o`000?oc
3??ol`cc00kol`cc00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on@Ki?oT6n@01_oT6n@01?l0003oiaSWonLHiooW6>L3o`0000KoaC[500?o0000oiIYU_nFJIH03?nF
JIH00ol0003oDZeBoe:]DP09oe:]DP03o`000?n2OH;oPWf200KoPWf200?o0000od6n@Om1_T403Om1
_T400ol0003oJ9MXofRGJ009ofRGJ003o`000?nm@[go_D:m00Go_D:m00?o0000oo<<looc3?<03_oc
3?<00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003oi1_Ton@Ki005
on@Ki003o`000?oW6>OoiaSW00GoiaSW0ol00002olDja@03o`000?nFJIKoUVVF00goUVVF00?o0000
oe:]D_mB[E802?mB[E800ol0003oPWf2oh9mPP07oh9mPP03o`000?m1_T7o@Ki100co@Ki10ol0000:
ofRGJ003o`000?nm@[go_D:m00Go_D:m00?o0000oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki004on@Ki003o`000?oW6>OoiaSW
00WoiaSW0_l0000AoiIYUP03o`000?mB[E;oDZeB00GoDZeB0_l0000;oh9mPP03o`000?m1_T7o@Ki1
00[o@Ki100Go0000oj=LXonSG:?oXebSo`00000:ofRGJ003o`000?nm@[go_D:m00Co_D:m00?o0000
oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oT6nCoi1_T
00;oi1_T00?o0000onLHiooW6>L02_oW6>L2o`00017oUVVF00?o0000oe:]D_mB[E801?mB[E800ol0
003oPWf2oh9mPP0<oh9mPP03o`000?m1_T7o@Ki100Oo@Ki10_l00005oj=LX`;o00002?mXUfP00ol0
003o_D:moke2_@04oke2_@03o`000?oc3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003oi1_Ton@Ki?oT6nCo000000coiaSW00Co0000omPW
f?oH9mSo00004OnFJIH00ol0003oDZeBoe:]DP02oe:]DP03o`000?n2OH;oPWf200koPWf200?o0000
od6n@Om1_T401Om1_T400ol0003oXebSoj=LX`07oj=LX`03o`000?mXUfSoJ9MX00KoJ9MX00?o0000
oke2_Onm@[d00onm@[d00ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on@Ki?oT6nCo00003?oW6>L00ol0003of2OHomPWf002omPWf003o`000?nFJIKo
UVVF00ooUVVF00Co0000oe:]D_mB[E;o00004On2OH800ol0003o@Ki1od6n@@04od6n@@03o`000?nS
G:?oXebS00WoXebS00?o0000ofRGJ?mXUfP01OmXUfP00ol0003o_D:moke2_@03oke2_@03o`000?oc
3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onLHi`03o`000?oH9mSof2OH00?of2OH00?o0000oiIYU_nFJIH03onFJIH00ol0003oDZeBo`00000C
oh9mPP04o`000?m1_T7o@Ki1od6n@@;o00003OnSG:<2o`0000KoJ9MX00Go0000oke2_Onm@[go_D:m
o`00000@oo<<l`03o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02_oW
6>L00ol0003of2OHomPWf005omPWf003o`000?nFJIKoUVVF00ooUVVF00?o0000oh9mP_n2OH804on2
OH800ol0003o@Ki1o`00000Aoj=LX`03o`000?mXUfSoJ9MX00?oJ9MX00Go0000oke2_Onm@[go_D:m
o`00000>oo<<l`?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onLHiooW6>L02OoW
6>L00ol0003of2OHomPWf007omPWf003o`000?nFJIKoUVVF00koUVVF00?o0000oh9mP_n2OH805?n2
OH800ol0003oXebSoj=LX`0Aoj=LX`;o00001?mXUfP01?l0003o_D:moke2_Ol0000:oo<<l`Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onLHiooW6>L02OoW6>L00ol0003of2OHomPWf008omPWf003o`000?nFJIKoUVVF00_oUVVF0ol0
000Goh9mPP03o`000?nSG:?oXebS01?oXebS00Ko0000ofRGJ?mXUfSoJ9MXo`000?nm@[d5o`0000Co
l`cc0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oW6>OoiaSW00SoiaSW00?o0000omPWf?oH9mP02_oH9mP00ol0003oUVVFoiIYUP07oiIYUP?o0000
0_n/Dj`00ol0003oPWf2oh9mPP0Eoh9mPP;o00005OnSG:<00ol0003oJ9MXofRGJ002o`0000Gok1?/
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onLHiooW6>L01ooW
6>L00ol0003of2OHomPWf00;omPWf003o`000?nFJIKoUVVF00CoUVVF0ol00006ojaC[003o`000?n2
OH;oPWf201?oPWf200Co0000ol@ka?o4>lCo00005OnSG:<2o`0000Wok1?/00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiaSW00?o0000omPWf?oH9mP03OoH9mP00ol0003oUVVFoiIY
UP03o`0000[o[5>/00?o0000oh9mP_n2OH804On2OH800ol0003oa3_4ol@ka002ol@ka003o`000?nS
G:?oXebS01;oXebS00?o0000on`Ck?o/4n`02?o/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiaSWonLHi`05onLHi`03o`000?oH9mSof2OH00oof2OH0_l0000>
ojaC[003o`000?n2OH;oPWf200ooPWf200?o0000ol@ka?o4>l@01?o4>l@00ol0003oXebSoj=LX`0@
oj=LX`;o00002oo/4n`00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onLHiooW6>L00ooW6>L00ol0003of2OHomPWf00@omPWf003o`000?n/Djco[5>/
00go[5>/00?o0000oh9mP_n2OH803_n2OH800ol0003oa3_4ol@ka006ol@ka0;o00003_nSG:<2o`00
0003om</dol0003ok1?/00[ok1?/00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiaSWonLHiooW6>Oo000001;of2OH00?o0000ojaC[?n/Dj`03on/Dj`00ol0003oPWf2oh9mPP0<
oh9mPP03o`000?o4>lCoa3_400Woa3_400?o0000oj=LXonSG:<02OnSG:<2o`0000?odbcC00?o0000
on`Ck?o/4n`02Oo/4n`00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiaSWo`00000ComPW
f003o`000?n/Djco[5>/013o[5>/00?o0000oh9mP_n2OH802_n2OH800ol0003oa3_4ol@ka00;ol@k
a003o`000?nSG:?oXebS00GoXebS0ol00006om</d`03o`000?o/4ncok1?/00Sok1?/00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omPWf?oH9mP04OoH9mP00ol0003o[5>/ojaC[00AojaC[003o`000?n2OH;oPWf200Wo
PWf200?o0000ol@ka?o4>l@03Oo4>l@00ol0003oXebSoj=LX`02oj=LX`;o00002OoC;=<00ol0003o
k1?/on`Ck009on`Ck003o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017of2OH00?o0000ojaC[?n/Dj`0
4_n/Dj`00ol0003oPWf2oh9mPP07oh9mPP03o`000?o4>lCoa3_400ooa3_400Co0000oj=LXol0003o
00002ooC;=<00ol0003ok1?/on`Ck009on`Ck003o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000kof2OH00?o0000ojaC[?n/Dj`04on/Dj`00ol0003oPWf2oh9mPP05oh9mPP03o`00
0?o4>lCoa3_4017oa3_400?o0000om</dooC;=<03?oC;=<00ol0003ok1?/on`Ck008on`Ck003o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;omPWf0;o00005_n/Dj`7o`0001Coa3_400?o
0000om</dooC;=<03?oC;=<00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oH9mP00ol0003ocC;=o`000002o`0001;o[5>/00?o0000okY5^_njAKX00_nj
AKX00ol0003o/4n`o`00000Dol@ka003o`000?oC;=?odbcC00codbcC00?o0000on`Ck?o/4n`02?o/
4n`00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoH9mP00ol0003ocC;=oldbc@03
oldbc@;o00003on/Dj`00ol0003o^TFjokY5^P03okY5^P04o`000?n`Ck3o/4n`o`0001?oa3_400?o
0000om</dooC;=<03OoC;=<00ol0003ok1?/on`Ck008on`Ck003o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003omPWf?l0003o
cC;=00OocC;=0ol0000;ojaC[003o`000?njAK[o^TFj00Co^TFj00Go0000ok1?/?n`Ck3o/4n`o`00
000Bol@ka003o`000?oC;=?odbcC00godbcC00?o0000on`Ck?o/4n`01oo/4n`?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T04?oi1_T0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o=</gocC;=00[ocC;=0_l00008ojaC[003o`000?njAK[o
^TFj00Go^TFj00?o0000ok1?/?n`Ck000_n`Ck000ol0003oa3_4ol@ka00?ol@ka003o`000?oC;=?o
dbcC00godbcC00?o0000on`Ck?o/4n`01_o/4n`00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oi1_Won@Ki00oon@Ki00?o0000on`Ck?o/4n`03oo/4n`00ol0003ocC;=oldbc@0<oldb
c@;o00001On/Dj`00ol0003o^TFjokY5^P06okY5^P03o`000?n`Ck3o/4n`00?o/4n`00?o0000ol@k
a?o4>l@03_o4>l@00ol0003odbcCom</d`0>om</d`03o`000?o/4ncok1?/00Cok1?/00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00kon@Ki00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
cC;=oldbc@0>oldbc@?o000000?o[5>/o`000?njAKX02?njAKX00ol0003o/4n`ok1?/004ok1?/003
o`000?o4>lCoa3_400goa3_44_l00005on`Ck003o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooT6n@03o`000?o/4ncok1?/00ook1?/0_l0000Coldbc@03o`000?njAK[o^TFj00So^TFj
00?o0000ok1?/?n`Ck001On`Ck000ol0003oa3_4ol@ka00<ol@ka003o`000?oa3_7ol@ka00ool@ka
00Go0000on`Ck?o/4ncok1?/o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n@Ki00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000Coldbc@03o`000?njAK[o^TFj00So
^TFj00?o0000ok1?/?n`Ck001On`Ck000ol0003oa3_4ol@ka00;ol@ka003o`000?oa3_7ol@ka017o
l@ka00?o0000on`Ck?l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n@KiooT6n@0:ooT6n@03o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o=</gocC;=013o
cC;=00?o0000okY5^_njAKX02?njAKX00ol0003o/4n`ok1?/006ok1?/003o`000?o4>lCoa3_400[o
a3_400?o0000oo4>lOoa3_404_oa3_400ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on@KiooT6n@09ooT6n@03o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?njAK[o^TFj00Wo^TFj00?o0000ok1?/?n`Ck00
1on`Ck000ol0003oa3_4ol@ka009ol@ka003o`000?oa3_7ol@ka01;ol@ka00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003ocC;=oldbc@0?oldbc@03o`000?njAK[o^TFj00Wo^TFj00?o
0000ok1?/?n`Ck002?n`Ck000ol0003oa3_4ol@ka007ol@ka003o`000?oa3_7ol@ka01?ol@ka00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000oldbcOo=</d03Oo=</d2
o`0000_o^TFj00?o0000ok1?/?n`Ck002On`Ck000ol0003oa3_4ol@ka006ol@ka003o`000?oa3_7o
l@ka01?ol@ka4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003ocC;=oldbc@0;oldbc@;o000000?ocC;=o`000?njAKX02_njAKX00ol0
003o/4n`ok1?/009ok1?/0Ko00000oo4>l@00ol0003ol@kaoo4>l@0Coo4>l@03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01?oi1_T3o`00
00Sok1?/0_l0000;on@Ki003o`000?o=</gocC;=00WocC;=0_l00004oldbc@03o`000?njAK[o^TFj
00So^TFj00?o0000ok1?/?n`Ck002?n`Ck000ol0003og2?Lom`Sg004om`Sg0?o00005?oa3_43o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on@KiooT6n@03o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o=</gocC;=00Go
cC;=0ol00007oldbc@03o`000?njAK[o^TFj00Oo^TFj00?o0000ok1?/?n`Ck001on`Ck000ol0003o
g2?Lom`Sg008om`Sg003o`000?oa3_7ol@ka013ol@ka00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000oldb
cOo=</d00oo=</d2o`0000[ocC;=00?o0000okY5^_njAKX01onjAKX00ol0003o/4n`ok1?/005ok1?
/0;o00003?oL8m`00ol0003ol@kaoo4>l@0=oo4>l@;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000oldbcOo=</gocC;=0_l0000=oldbc@03o`000?njAK[o^TFj00Ko^TFj00?o0000ok1?
/?n`Ck001?n`Ck000ol0003og2?Lom`Sg00=om`Sg0Co00002_oa3_400ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013ocC;=00?o0000okY5^_njAKX01OnjAKX00ol0003o
/4n`ok1?/003ok1?/003o`000?oL8mcog2?L00kog2?L00Co0000ooH9m_of2OKomPWf1_l00003oo4>
l@03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o=</gocC;=013o
cC;=00?o0000okY5^_njAKX01OnjAKX00ol0003o/4n`ok1?/002ok1?/003o`000?oL8mcog2?L00oo
g2?L00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000oldbcOo=</d0
4Oo=</d00ol0003o^TFjokY5^P04okY5^P03o`000?n`Ck3o/4n`00;o00004OoL8m`00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o=</d3o`0000Co^TFj00?o0000ok1?/?l000004ooL
8m`00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003ocC;=017ocC;=0_l00003omPWf0;o00000_njAKX2
o`0001Cog2?L00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o=</gocC;=00gocC;=0_l00007omPWf0?o00005OoL8m`00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000oldbcOo=</d02_o=</d2o`0000_o
f2OH00?o0000om`Sg?oL8m`04_oL8m`00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o=</gocC;=00OocC;=0_l0000=omPWf003o`000?oL8mcog2?L01;og2?L00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000oldbcOo=</d01Oo=</d2o`0000oof2OH00?o
0000om`Sg?oL8m`04_oL8m`00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000oldbcOo=</d00_o=</d2o`0001;of2OH00?o0000om`Sg?oL8m`04OoL8m`0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003olPgboo8=l_l0000@onDJi@04o`000?o=</go
0000o`0001Cof2OH00?o0000om`Sg?oL8m`04?oL8m`00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo8=l_ob3O800_ob3O800ol0003oiA[UonDJi@0>onDJi@03o`000?oH9mSof2OH01Cof2OH00?o0000
om`Sg?oL8m`03OoL8m`4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003olPgboo8=lP03oo8=lP03o`000?oU6^GoiA[U
00goiA[U00?o0000omPWf?oH9mP05?oH9mP00ol0003og2?Lom`Sg007om`Sg0Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo8=l_ob3O801Oob3O800ol0003oiA[UonDJi@0<onDJi@03
o`000?oH9mSof2OH01Gof2OH00?o0000om`Sg?oL8m`01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003olPgboo8=lP06oo8=lP03o`000?oU6^GoiA[U00_oiA[U00?o0000omPWf?oH9mP0
5OoH9mP3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJ
i@0:onDJi@03o`000?oH9mSof2OH01Gof2OH00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo8=lP03o`000?oU6^GoiA[U00WoiA[U00?o0000omPWf?oH9mP05?oH9mP0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D02OoU6^D0
0ol0003of2OHomPWf00ComPWf003o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?ob3O800ol0003oiA[UonDJi@08onDJ
i@03o`000?oH9mSof2OH00oof2OH1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_ob3O800ol0003oiA[UonDJi@07onDJi@03o`000?oH9mSof2OH00Sof2OH1ol00003on`C
k003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo8=lP03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omPWf?oH9mSof2OH1ol0000:on`Ck003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000KolPgb00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
k1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?ob3O800ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ok1?/01Cok1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000ColPgbo`000?l0003o00001?oh1oP00ol0003ok1?/on`Ck00Bon`Ck0;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k00@on`Ck004o`000?o_4>ooka3_o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ok1?/on`Ck00?on`Ck003o`000?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o/4nco
k1?/00kok1?/00?o0000onl@koo_4>l01?o_4>l2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00=on`Ck003o`000?o_4>ooka3_
00Goka3_00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000onl@koo_4>l01_o_4>l00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ok1?/
on`Ck009on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o/4ncok1?/00Sok1?/00?o
0000onl@koo_4>l02?o_4>l00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000onl@koo_4>l02?o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ok1?/on`Ck005on`Ck003o`000?o_4>ooka3_00Woka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Co
k1?/00?o0000onl@koo_4>l02_o_4>l00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`Ck003on`Ck003o`00
0?o_4>ooka3_00[oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`C
k002on`Ck003o`000?o_4>ooka3_00_oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ok1?/on`Ck?l0000>onl@k`03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o_4>l00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000Woka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000Goka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?oka3_o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o3?ooo`001?lQ8Mgo003oo`00ool00?l<oooo0007ob4QgOl00?oo003oo`00oolb</coZJUEonk^
4003oooo0004omgM8OnYZEGoIVJHoa0@kP_o003o0_ooo`2Io`00o`7ooooo002Mo`00o`03oiRHI_oo
o`3oMgN700Oo003o00?oV9QVoooo0?mgMhL03?l00?l2oooo00Oo003o00?o<S;<oooo0?ooo`002Ooo
o`001OnHV6Ko003oo`00ool00?oo<S;<00_oool000CoV9QVo`00ool00?oo003o1?ooo`001onj^TCo
8B7Mo`00oolb</coZJUEoooo0?mgMhL02_l00?l2oooo09Wo003o0Oooool009go003o00?ok^h@oooo
0?oMgB401ol00?l00oo^kQ3oool0omgM8@0<o`00o`;oool02?l00?l00om4A;[oool0oooo0009oooo
0005oa0@k_l00?oo003oo`00oom4A;X02oooo`001ol@4>ko003oo`00oonj^TCoool0olc<<_m4A;X0
1Ol00?l00omVIYSoool0ojVYE@09o`00o`;oool0VOl00?l1ooooo`00W?l00?l01Olb</coool0oooo
0?ooo`3o413^00Go003o00Go<S;<oooo0?ooo`3oool0ob4Qg@0;o`00o`;oool02Ol00?l00omVIYSo
k^h@oa0@kP06o`00o`03odA4^_o^kQ3oQhMg00Co003o00?oIVJHonk^4?l@4>h01_l00?l00om4A;[o
k^h@ohN7M`0<o`00o`03ojVYEOooo`3oZJUE00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`05ojVY
EOooo`3oool0oooo0?mVIYP01Ol00?l01OnHV6Koool0oooo0?ooo`3oMgN700_o003o0_ooo`0:o`00
o`03oiRHI_oMgB7o413^00Ko003o00?oA4BjojVYEOl00?l01?l00?l00onHV6KogMdQoa0@kP06o`00
o`03odA4^_nYZEGo003o00_o003o00Co<S;<oooo0?ooo`3oA4Bj1ol00?l2oooo09Wo003o0Oooool0
09co003o0oooo`000omVIYSo^[Y4o`00o`04o`00o`05onk^4?ooo`3oool0ofIVV?oMgB402ol00?l2
oooo00_o003o00?oZJUEomgM8Ol@4>h03Ol00?l00onYZEGogMdQoa0@kP0Do`00o`;oool000?o^[Y4
o`00ool00?l01Ol00?l2oooo09Wo003o0Oooool009_o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^
kQ3o413^00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o8B7M00[o003o0_ooo`0;o`00o`03
oa0@k_oMgB7oZJUE00go003o00?o413^omgM8OnYZED05?l00?l3oooo00Oo003o0_ooo`2Io`00o`7o
oooo002Ko`00o`07ojVYEOooo`3oool0oiRHI_l00?ooV9QVofIVV003o`00o`07ojVYEOooo`3oool0
oiRHI_l00?ooV9QVogMgQ`0:o`00o`;oool03?l00?l00ol@4>koool0ojVYE@0=o`00o`03oa0@k_oo
o`3oZJUE01;o003o00CoEEFYoooo0?ooo`3oool01ol00?l2oooo09Wo003o0Oooool009_o003o0ooo
o`001?lQ8Mgo003oodA4^_nj^T@3o`00o`?oool000Co<S;<o`00oom4A;[ogMdQ2_l00?l2oooo00go
003o00?o<S;<oooo0?mgMhL03Ol00?l00olb</coool0ogMgQ`0Ao`00o`04okZjA?ooo`3oool0oooo
00Oo003o0_ooo`2Io`00o`7ooooo002Jo`00o`04oeEEZOooo`3oool0omgM8@?o003o00Coool0o`00
ool00?ooEEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0ob4Qg@Wo003o0_ooo`0>o`00o`03ohN7
Moooo`3oEEFY00go003o00?oQhMgoooo0?mEEJT03ol00?l01OnYZEGoool0oooo0?ooo`3oZJUE00Oo
003o0_ooo`2Io`00o`7ooooo002Jo`00o`04ojVYEOooo`3oool0ogMgQ`?o003o00CoZJUEoeEEZOl0
0?ooZJUE0_ooo`001_nHV6Ko003oo`00ool00?ooZJUEogMgQ`Wo003o0_ooo`0?o`00o`03onk^4?oo
o`3o8B7M00go003o00?ok^h@oooo0?lQ8Md03?l00?l00olb</coc<`boooo0003oooo0003ob4QgOl0
0?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Jo`00o`?oool000Oo8B7Mo`00ool00?oo003ooeEE
ZOnYZEGo003o00?oool000Ko<S;<o`00ool00?oo003ooeEEZOoMgB49o`00o`;oool03ol00?l00omg
MhOoool0olc<<P0=o`00o`03ogMgQoooo`3oc<`b00Wo003o00?oA4BjogMgQooMgB401Oooo`000omV
IYSo003oo`00o`06o`00o`;oool0VOl00?l1ooooo`00VOl00?l01?mEEJWoool0oooo0?oMgB45o`00
o`05onk^4?mEEJWoool0oooo0?o^kQ001Ol00?l00oooo`3o8B7Mo`00o`07o`00o`;oool03ol00?l0
1?lQ8Mgoool0oooo0?mEEJT<o`00o`04ob4QgOooo`3oool0oeEEZ@Go003o00?o<S;<oooo0?ooo`00
1oooo`000omVIYSo003oo`00o`07o`00o`;oool0VOl00?l1ooooo`00VOl00?l01?nYZEGoool0oooo
0?mgMhL5o`00o`05okZjA?o^kQ3oool0oooo0?n7QgL01Ol00?l00onYZEGoMgN7o`00o`07o`00o`;o
ool04?l00?l2oooo0003okZjA?l00?oo003o00_o003o0_ooo`000onj^TCo003oo`00o`03o`00o`03
ob4QgOooo`3oool000Goool000?oZJUEob4QgOl00?l02Ol00?l2oooo09Wo003o0Oooool009So003o
00Go413^oooo0?ooo`3oool0ob4Qg@05o`00o`05ofIVV?ooo`3oool0oooo0?lQ8Md01Ol00?l00omE
EJWogMdQo`00o`07o`00o`;oool01ol00?l00onj^TCo8B7Mo`00o`06o`00o`?oool01?l00?l00onj
^TCo8B7Mo`00o`06o`00o`?oool01_l00?l01onYZEGoool0onk^4?o<c3;oQhMgoeEEZOl@4>h03?l0
0?l2oooo09Wo003o0Oooool009So003o00CoIVJHoooo0?ooo`3ogMdQ1_l00?l01?mVIYSoool0oooo
0?oMgB47o`00o`03oooo0?lQ8Mgo003o00Ko003o0_ooo`07o`00o`03okZjA?nHV6Ko003o00Go003o
00CoEEFYoooo0?ooo`3oool01?l00?l00onj^TCoV9QVo`00o`05o`00o`04oeEEZOooo`3oool0oooo
00Ko003o00?o8B7Monk^4?l00?l04?l00?l2oooo09Wo003o0Oooool009So003o00Coc<`boooo0?oo
o`3oMgN71_l00?l01?nj^TCoool0oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`07
o`00o`03ofIVV?ooo`3o<S;<00Go003o00Coc<`boooo0?ooo`3oool01?l00?l00omVIYSoool0oc8b
c005o`00o`04olc<<_ooo`3oool0oooo00Oo003o00?oc<`boeEEZOl00?l03ol00?l2oooo09Wo003o
0Oooool009Oo003o00Go8B7Moooo0?ooo`3oool0ob4Qg@05o`00o`05oa0@k_ooo`3oool0oooo0?lQ
8Md01ol00?l00omEEJWogMdQo`00o`06o`00o`;oool01ol00?l02?l@4>koool0oooo0?mVIYSo413^
o`00oolb</coc<`b0oooo`000onj^TCo003oo`00o`02o`00o`08oa0@k_ooo`3oool0ofIVV?l@4>ko
003ooc8bc?o<c383oooo0003okZjA?l00?oo003o00Go003o00?oA4Bjolc<<_l00?l03ol00?l2oooo
09Wo003o0Oooool009Oo003o00CoZJUEoooo0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oMgB49
o`00o`03oooo0?lQ8Mgo003o00Go003o0_ooo`08o`00o`03ofIVV?ooo`3oool000Ooool000?o<S;<
o`00ool00?l00ol00?l00omVIYSoool0oooo0007oooo0003oc8bc?l00?oo003o00Ko003o00?oc<`b
oooo0?ooo`001Oooo`000oo<c3;o003oo`00o`06o`00o`;oool0VOl00?l1ooooo`00UOl00?l00olQ
8MgoQhMgoooo0002oooo0003onk^4?lb</co003o00?o003o00KoEEFYoooo0?ooo`3oool0onk^4?lb
</`6o`00o`06ob4QgOn7QgOoool0onk^4?mEEJWo413^1?l00?l2oooo00Wo003o00?oQhMgoooo0?oo
o`001Oooo`000omVIYSo003oo`00o`05o`00o`03ohN7Moooo`3oool000Goool000?oIVJHo`00ool0
0?l01ol00?l00omVIYSoool0oooo0006oooo0003ob4QgOl00?oo003o00Go003o0_ooo`2Io`00o`7o
oooo002Do`00o`03odA4^_ooo`3oool000Ooool000?oQhMgoooo0?ooo`001oooo`02o`00o`03ohN7
Moooo`3oool000Goool000CoA4Bjo`00ool00?oo003o0_ooo`000omgMhOo003oo`00o`07o`00o`03
odA4^_nj^TCoool000;oool000?oZJUEoc8bc?l00?l02?l00?l00om4A;[o^[Y4oooo0002oooo0003
ojVYEOlb</co003o00[o003o00?ok^h@oooo0?ooo`001Oooo`000omgMhOo003oo`00o`04o`00o`03
ogMgQoooo`3oool009Wo003o0Oooool00;Ko003o1oooo`0^o`00o`04ogMgQooMgB7o003oo`00o`Oo
ool0VOl00?l1ooooo`00k?l00?l00olQ8Mgo003oo`00o`2Po`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(250) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.985 .015 .985 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.963 .037 .963 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.899 .101 .899 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.901 .099 .901 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.973 .027 .973 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.93 .07 .93 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.909 .091 .909 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.789 .211 .789 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.891 .109 .891 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.941 .059 .941 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.796 .204 .796 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.937 .063 .937 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.522 .478 .522 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.441 .559 .441 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.802 .198 .802 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.902 .098 .902 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.924 .076 .924 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.715 .285 .715 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.611 .389 .611 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.76 .24 .76 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.893 .107 .893 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.984 .016 .984 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.841 .159 .841 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.95 .05 .95 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.366 .634 .366 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.96 .04 .96 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.27 .73 .27 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.372 .628 .372 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.48 .52 .48 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.182 .818 .182 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.793 .207 .793 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.121 .879 .121 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.38 .62 .38 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.946 .054 .946 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.557 .443 .557 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.798 .202 .798 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.494 .506 .494 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.213 .787 .213 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.134 .866 .134 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.094 .906 .094 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.66 .34 .66 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.803 .197 .803 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.845 .155 .845 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.896 .104 .896 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.208 .792 .208 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.097 .903 .097 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.062 .938 .062 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.155 .845 .155 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.272 .728 .272 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.923 .077 .923 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.972 .028 .972 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.775 .225 .775 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.068 .932 .068 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.934 .066 .934 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.516 .484 .516 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.722 .278 .722 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.284 .716 .284 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.462 .538 .462 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.97 .03 .97 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.675 .325 .675 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.127 .873 .127 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.979 .021 .979 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.593 .407 .593 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.086 .914 .086 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.048 .952 .048 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.861 .139 .861 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.887 .113 .887 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.14 .86 .14 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.199 .801 .199 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.753 .247 .753 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.931 .069 .931 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.064 .936 .064 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.042 .958 .042 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.089 .911 .089 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.458 .542 .458 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.593 .407 .593 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.722 .278 .722 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.306 .694 .306 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.065 .935 .065 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.985 .015 .985 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.963 .037 .963 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.049 .951 .049 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.347 .653 .347 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.816 .184 .816 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.944 .056 .944 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.208 .792 .208 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.709 .291 .709 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.15 .85 .15 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.979 .021 .979 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.92 .08 .92 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.147 .853 .147 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.341 .659 .341 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.782 .218 .782 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.951 .049 .951 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.942 .058 .942 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.851 .149 .851 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.813 .187 .813 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.82 .18 .82 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.929 .071 .929 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.827 .173 .827 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.925 .075 .925 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.927 .073 .927 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.98 .02 .98 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.957 .043 .957 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.977 .023 .977 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?l000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003oo0?loo`3o?ol0oco
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ol0ocoo0?l00Ko
o0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ol0oco
o0?l00_oo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooh1oP00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooP7n0;o00003oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooh
1oP2o`0000_ooP7n00?o0000oo`3o?ol0o`04Ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;on0Oh00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooP7n003o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`05?ol0o`00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oh1oP2o`0000KooP7n00?o0000oo`3
o?ol0o`05Ool0o`00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oh1oP00ol0003ooP7nooh1oP03ooh1oP03o`000?ol0oco
o0?l01Koo0?l00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom@[eo`000?ob3O;o0000onDJiOl0000JooP7n0;o00000_on0Oh00ol0003oo0?l
oo`3o00Hoo`3o003o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om@[e00Co0000oo8=l_ob3O;o00000_oU6^D00ol0003on0OhooP7n00IooP7
n003o`000?on0Oko000001_oo0?l00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005ooD:m@05o`000?ob3O;olPgboo8=
l_l000000ooU6^D00ol0003on0OhooP7n00IooP7n003o`000?ol0ocoo0?l01[oo0?l00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oe2_D01Ol0003olPgboo8=l_ob3O;o000000CoiA[U00?o0000ooP7
n?oh1oP06?oh1oP00ol0003oo0?loo`3o00Ioo`3o003o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om@[e00?o0000oo8=l_ob
3O800_ob3O800ol0003oiA[UonDJi@03onDJi@03o`000?oh1oSon0Oh01Oon0Oh00?o0000oo`3o?ol
0o`06Ool0o`00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooe2_D00ol0003olPgboo8=lP02oo8=lP03o`000?oU6^GoiA[U00Co
iA[U00?o0000ooP7n?oh1oP05ooh1oP00ol0003oo0?loo`3o00Hoo`3o003o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?ooD:m@03o`00
0?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D01OoU6^D00ol0003on0OhooP7n00FooP7n003o`00
0?ol0ocoo0?l01Ooo0?l00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000AooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D01_oU
6^D2o`0001Gon0Oh0ol0000Hoo`3o003o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
ooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D02?oU6^D00ol0003on0OhooP7n00@
ooP7n0;o00000ooS7><00ol0003oo0?loo`3o00Doo`3o003o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000ooD:mOoe2_D04_oe2_D00ol0003olPgboo8=lP05oo8=lP03o`000?oU6^GoiA[U
00WoiA[U00?o0000ooP7n?oh1oP03Ooh1oP2o`0000KohacS0_l0000Doo`3o003o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e01;om@[e00?o0000oo8=l_ob
3O801Oob3O800ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00[on0Oh0_l0000:on<Lh`03
o`000?ol0ocoo0?l017oo0?l00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om@[eooD:m@0@ooD:m@03o`000?ob3O;olPgb00Ko
lPgb00?o0000onDJiOoU6^D02ooU6^D00ol0003on0OhooP7n008ooP7n003o`000?oS7>?ohacS00_o
hacS0_l0000@oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O80
1oob3O800ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l0000@on<Lh`03o`00
0?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O801oob3O800ol0003oiA[UonDJ
i@0=onDJi@03o`000?oh1oSon0Oh00;on0Oh0_l0000Con<Lh`;o00003?ol0o`00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oe2_Go
m@[e00kom@[e00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJi@0>onDJi@04o`000?oh1oSo
0000o`0001OohacS00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00Loo`3o003o`000?oj
1O[onPGj00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oe2_Go
m@[e00com@[e00?o0000oo8=l_ob3O802Oob3O800ol0003oiA[UonDJi@0?onDJi@03o`000?oS7>?o
hacS01SohacS0_l00009oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000ooX5n_oj1OX01?oj1OX4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>ooD:m@03o`000?ob3O;olPgb
00WolPgb00?o0000onDJiOoU6^D03ooU6^D00ol0003ohacSon<Lh`0Jon<Lh`03o`000?ol0ocoo0?l
00Coo0?l0ol0000Loo`3o003o`000?oj1O[onPGj00WonPGj0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o`3o3ol0o`o`0000com@[e00?o0000oo8=l_ob3O802_ob3O800ol0003oiA[UonDJi@0?onDJ
i@03o`000?oS7>?ohacS01_ohacS0_l00003oo`3o004o`000?oa3_7ol@kaoo4>l@?o00006?ol0o`0
0ol0003onPGjooX5nP0=ooX5nP?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00;ol0o`00?o0000ooD:mOoe2_D02Ooe2_D00ol0003olPgboo8=lP0:oo8=lP03o`000?oU6^GoiA[U
00koiA[U00?o0000on<LhooS7><07_oS7><00ol0003oo0?lo`000007oo4>l@?o00005?ol0o`00ol0
003onPGjooX5nP0AooX5nP;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o`3o000ol0003om@[eooD:m@07ooD:m@03
o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003ohacSon<Lh`0Oon<Lh`03
o`000?oa3_7ol@ka00Wol@ka0ol0000@oo`3o003o`000?oj1O[onPGj01?onPGj00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol0o`
oo0?l007oo0?l003o`000?oe2_Gom@[e00Gom@[e00?o0000oo8=l_ob3O803?ob3O800ol0003oiA[U
onDJi@0>onDJi@03o`000?oS7>?ohacS01oohacS00?o0000oo4>lOoa3_403?oa3_43o`0000goo0?l
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ol0o`00?o0000ooD:mOoe2_D01?oe
2_D00ol0003olPgboo8=lP0<oo8=lP03o`000?oU6^GoiA[U00koiA[U00?o0000on<LhooS7><07_oS
7><00ol0003ol@kaoo4>l@0@oo4>l@?o00002Ool0o`00ol0003onPGjooX5nP0FooX5nPOo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000oo0?l?o`3o003?o`3o000ol0003om@[eooD:m@02ooD:m@03o`000?ob
3O;olPgb00golPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003ohacSon<Lh`0Non<Lh`03o`000?oa
3_7ol@ka01?ol@ka0ol00005oo`3o003o`000?oj1O[onPGj01OonPGj00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00kol0o`00Go0000
ooD:mOoe2_Gom@[eo`00000?oo8=lP03o`000?oU6^GoiA[U00goiA[U00?o0000on<LhooS7><07ooS
7><00ol0003ol@kaoo4>l@0Foo4>l@?o000000?oo0?lo`000?oj1OX06?oj1OX00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Boo0?l003o`000?oe2_Go0000013olPgb00?o0000onDJiOoU6^D02ooU6^D3
o`00023ohacS00?o0000oo4>lOoa3_406_oa3_400ol0003onPGjooX5nP0HooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`01?ol0o`00?o0000oo8=
l_ob3O803oob3O800ol0003oiA[UonDJi@07onDJi@Co00000_o6>LH00ol0003ohacSon<Lh`0Non<L
h`03o`000?oa3_7ol@ka01[ol@ka00?o0000ooX5n_oj1OX05ooj1OX00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
l0o`00?o0000oo8=l_ob3O803oob3O800ol0003oiA[UonDJi@03onDJi@Co00001oo6>LH00ol0003o
hacSon<Lh`0Lon<Lh`03o`000?oa3_7ol@ka01col@ka00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000oo0?l?o`3o005oo`3o000ol0003olPgboo8=lP0>oo8=lP03o`00
0?oU6^Go000000?o00003?o6>LH00ol0003ohacSon<Lh`0Kon<Lh`03o`000?oa3_7ol@ka01col@ka
00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o`
3o05o`0000_olPgb0ol0000AolHiaP03o`000?oS7>?ohacS01[ohacS00?o0000oo4>lOoa3_407Ooa
3_400ol0003onPGjooX5nP0CooX5nP03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o`3o3ol0o`01Wol0o`00?o0000
ol/dboo;=</00_o;=</7o`0000?olPgb00?o0000olHia_o6>LH04oo6>LH3o`0001OohacS0_l0000P
oo4>l@03o`000?oj1O[onPGj01?onPGj00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000oo0?l?o`3o006?o`3o000ol0
003obcC;ol/db`0:ol/db`?o00005_o6>LH00ol0003oUfRGoiMXU`05o`00013ohacS0_l000000onh
AkSo0000oo4>l@0Ooo4>l@03o`000?oj1O[onPGj01;onPGj00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000oo0?l?o`3o005_o`3o000ol0003obcC;ol/db`0=ol/db`03
o`000?o6>LKoaSW601?oaSW600?o0000oiMXUonGJ9L01_nGJ9L4o`0000_ohacS00?o0000okQ7^?nh
AkP00_nhAkP00ol0003ol@kaoo4>l@0Noo4>l@03o`000?oj1O[onPGj013onPGj00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ol0o`oo0?l00Doo0?l003o`000?o;=<_obcC;00oobcC;
00?o0000olHia_o6>LH04_o6>LH00ol0003oUfRGoiMXU`0:oiMXU`Go00001?oS7><2o`0000Go^4Nh
00?o0000oo4>lOoa3_407_oa3_400ol0003onPGjooX5nP0@ooX5nP03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o`
3o3ol0o`01Col0o`00?o0000ol/dboo;=</03oo;=</00ol0003oaSW6olHiaP0BolHiaP03o`000?nG
J9OoUfRG00ooUfRG1?l00008okQ7^003o`000?oa3_7ol@ka01kol@ka00?o0000ooX5n_oj1OX03_oj
1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
oo0?l?o`3o004_o`3o000ol0003obcC;ol/db`0@ol/db`03o`000?o6>LKoaSW6017oaSW600?o0000
oiMXUonGJ9L04OnGJ9L00ol0003oMHYeo`000009okQ7^003o`000?oa3_7ol@ka01gol@ka00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000oo0?l?o`3o003_o`3o03o`0001CobcC;00?o0000olHia_o6>LH04?o6>LH00ol0
003oUfRGoiMXU`0@oiMXU`04o`000?meRWGoMHYeo`0000Wo^4Nh00?o0000oo4>lOoa3_407_oa3_40
0ol0003onPGjooX5nP0<ooX5nP03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000oo0?l?o`3o002_o`3o04o`0000;ocC;=00?o0000ol/d
boo;=</04_o;=</00ol0003oaSW6olHiaP0@olHiaP03o`000?nGJ9OoUfRG00ooUfRG00Go0000ogF:
MOmeRWGoMHYeo`00000:okQ7^003o`000?oa3_7ol@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000oo0?
l?o`3o001Oo`3o04o`0000OocC;=00?o0000ol/dboo;=</04Oo;=</00ol0003oaSW6olHiaP0?olHi
aP03o`000?nGJ9OoUfRG013oUfRG00Go0000ogF:MOmeRWGoMHYeo`00000:okQ7^003o`000?oa3_7o
l@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o`3o3o
l0o`00Co00002oo=</d00ol0003obcC;ol/db`0Bol/db`03o`000?o6>LKoaSW600koaSW600?o0000
oiMXUonGJ9L03onGJ9L00ol0003oMHYeogF:M@02ogF:M@03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000
oo4>lOoa3_407?oa3_43o`0000[onPGj00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000onhAk_l0003o00003oo=</d00ol0003obcC;ol/db`0Aol/db`03o`000?mn
PGko000000ooaSW600?o0000oiMXUonGJ9L03_nGJ9L00ol0003oMHYeogF:M@03ogF:M@03o`000?nh
AkSo^4Nh00Wo^4Nh00?o0000oo4>lOoa3_406Ooa3_43o`0000?okA;]00?o0000ooX5n_oj1OX01ooj
1OX00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o^4NkokQ7^o`00017ocC;=00?o
0000ol/dboo;=</03oo;=</01Ol0003oOX5nogj1O_mnPGko000000[oaSW61?l0000AoiMXU`03o`00
0?meRWGoMHYe00?oMHYe00?o0000okQ7^?nhAkP02_nhAkP00ol0003ol@kaoo4>l@0Foo4>l@;o0000
1oo]4^d00ol0003onPGjooX5nP05ooX5nP03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003okQ7^onhAkP02onhAkP03o`000?o=</gocC;=00kocC;=00?o
0000ol/dboo;=</03_o;=</00ol0003oOX5nogj1OP03ogj1OP04o`000?o6>LKoaSW6olHiaPKo0000
0on4Nh@00ol0003oUfRGoiMXU`0>oiMXU`03o`000?meRWGoMHYe00CoMHYe00?o0000okQ7^?nhAkP0
2_nhAkP00ol0003ol@kaoo4>l@0Coo4>l@?o00002_o]4^d00ol0003onPGjooX5nP03ooX5nP03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o^
4NkokQ7^00?okQ7^00?o0000oldbcOo=</d03_o=</d00ol0003obcC;ol/db`0=ol/db`03o`000?mn
PGkoOX5n00GoOX5n0ol0000:ohAkQ003o`000?nGJ9OoUfRG00coUfRG00?o0000ogF:MOmeRWD01Ome
RWD00ol0003o^4NhokQ7^00;okQ7^003o`000?oa3_7ol@ka013ol@ka0_l0000>ondBk@03o`000?oj
1O[onPGj00;onPGj00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o^4NkokQ7^00CokQ7^00?o0000oldbcOo=</d03oo=</d00ol0003obcC;ol/db`0;
ol/db`03o`000?mnPGkoOX5n00KoOX5n00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003oUfRGoiMXU`0;
oiMXU`03o`000?meRWGoMHYe00GoMHYe00?o0000okQ7^?nhAkP03?nhAkP00ol0003ol@kaoo4>l@0<
oo4>l@?o00004Oo]4^d5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o^4NkokQ7^
00KokQ7^00?o0000oldbcOo=</d03_o=</d00ol0003obcC;ol/db`0:ol/db`03o`000?mnPGkoOX5n
00OoOX5n00?o0000ohAkQ?n4Nh@02on4Nh@00ol0003oUfRGoiMXU`0:oiMXU`03o`000?meRWGoMHYe
00KoMHYe00?o0000okQ7^?nhAkP03?nhAkP00ol0003ol@kaoo4>l@0:oo4>l@;o00005?o]4^d00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003okQ7^onhAkP07onhA
kP03o`000?o=</gocC;=00kocC;=00?o0000ol/dboo;=</02Oo;=</00ol0003oOX5nogj1OP08ogj1
OP03o`000?n4NhCoQ7^400coQ7^400?o0000oiMXUonGJ9L02?nGJ9L00ol0003oMHYeogF:M@07ogF:
M@03o`000?nhAkSo^4Nh00go^4Nh1Ol00004oo4>l@?o00005Oo]4^d00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okQ7^onhAkP08onhA
kP03o`000?o=</gocC;=00oocC;=00?o0000ol/dboo;=</01oo;=</00ol0003oOX5nogj1OP09ogj1
OP03o`000?n4NhCoQ7^400coQ7^40ol00008oiMXU`03o`000?meRWGoMHYe00OoMHYe00?o0000okQ7
^?nhAkP03OnhAkP00ol0003ob3O8olPgb002olPgb0Co00006?o]4^d00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o^4NkokQ7^
00[okQ7^00?o0000oldbcOo=</d03_o=</d00ol0003obcC;ol/db`06ol/db`03o`000?mnPGkoOX5n
00[oOX5n00?o0000ohAkQ?n4Nh@02_n4Nh@2o`0000?oB;M800?o0000oiMXUonGJ9L01?nGJ9L00ol0
003oMHYeogF:M@08ogF:M@03o`000?nhAkSo^4Nh00co^4Nh00?o0000olPgb?o8=lP01_o8=lP00ol0
003okA;]ondBk@0EondBk@03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000onhAk_o^4Nh02oo^4Nh00ol0003o
cC;=oldbc@0>oldbc@03o`000?o;=<_obcC;00GobcC;00?o0000ogj1O_mnPGh02omnPGh00ol0003o
Q7^4ohAkQ008ohAkQ0;o00001_m8]dP00ol0003oUfRGoiMXU`02oiMXU`03o`000?meRWGoMHYe00Wo
MHYe00?o0000okQ7^?nhAkP03?nhAkP00ol0003ob3O8olPgb007olPgb003o`000?o]4^gokA;]01Co
kA;]00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o^4NkokQ7^00gokQ7^00?o0000oldbcOo=</d03_o=</d00ol0003obcC;ol/db`03ol/db`03o`00
0?mnPGkoOX5n00coOX5n00?o0000ohAkQ?n4Nh@01_n4Nh@2o`0000WoB;M800Go0000oiMXUonGJ9Oo
UfRGo`00000;ogF:M@03o`000?nhAkSo^4Nh00co^4Nh00?o0000olPgb?o8=lP01oo8=lP00ol0003o
kA;]ondBk@0CondBk@03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o^4NkokQ7^00ko
kQ7^00?o0000oldbcOo=</d03_o=</d00ol0003obcC;ol/db`02ol/db`03o`000?mnPGkoOX5n00go
OX5n00?o0000ohAkQ?n4Nh@01?n4Nh@2o`0000coB;M800?o0000oiMXUol000003?meRWD00ol0003o
^4NhokQ7^00;okQ7^003o`000?o8=lSob3O800Wob3O800?o0000ondBkOo]4^d04Oo]4^d00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003okQ7^onhAkP0?onhAkP03o`000?o=</gocC;=00kocC;=00Go0000ol/dboo;=<_o
bcC;o`00000@ogj1OP03o`000?n4NhCoQ7^400;oQ7^40_l0000?odRgB003o`000?meRWGoMHYe00_o
MHYe00?o0000okQ7^?nhAkP02onhAkP00ol0003ob3O8olPgb009olPgb003o`000?o]4^gokA;]017o
kA;]00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003ocC;=
oldbc@0>oldbc@Co00004?mnPGh00ol0003oQ7^4ohAkQ002o`00017oB;M800?o0000ogF:MOmeRWD0
2omeRWD00ol0003o^4NhokQ7^00:okQ7^003o`000?o8=lSob3O800_ob3O800?o0000ondBkOo]4^d0
3oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ool0o`00ol0003onPGjooX5nP03ooX5nP03o`000?o^
4NkokQ7^01;okQ7^00?o0000oldbcOo=</d03Oo=</d00ol0003oNXEjogZ5NP02ogZ5NP;o00003_mn
PGh3o`0001?oB;M800?o0000ogF:MOmeRWD02omeRWD00ol0003o^4NhokQ7^00:okQ7^003o`000?o8
=lSob3O800_ob3O800?o0000ondBkOo]4^d03oo]4^d00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ol0ocoo0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`00000EonhAkP03o`000?o=
</gocC;=00cocC;=00?o0000ogZ5N_mjQGX01OmjQGX2o`0000coOX5n00?o0000odRgB?m8]dP05?m8
]dP00ol0003oMHYeogF:M@0:ogF:M@03o`000?nhAkSo^4Nh00[o^4Nh00?o0000olPgb?o8=lP03?o8
=lP00ol0003okA;]ondBk@0=ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Soo0?l00?o0000
ooX5n_l000005oo^4Nh00ol0003ocC;=oldbc@0:oldbc@03o`000?mjQG[oNXEj00SoNXEj00?o0000
ogj1O_mnPGh02?mnPGh3o`0001GoB;M80_l0000;ogF:M@03o`000?nhAkSo^4Nh00Wo^4Nh00?o0000
olPgb?o8=lP03_o8=lP00ol0003okA;]ondBk@0<ondBk@03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_oo0?l00?o0000onhAk_o^4Nh05_o^4Nh00ol0003ocC;=oldbc@09oldbc@03o`000?mjQG[oNXEj
00[oNXEj0_l00005ogj1OP?o00000olebSD00ol0003oB;M8odRgB00AodRgB003o`000?lSg2?o8m`S
00;o00002OmeRWD00ol0003o^4NhokQ7^009okQ7^003o`000?o8=lSob3O800kob3O800?o0000ondB
kOo]4^d02oo]4^d00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo`3o003o`000?o^4NkokQ7^01Ko
kQ7^00?o0000oldbcOo=</d00oo=</d6o`0000ooNXEj0_l000000omnPGko0000o`000007ocG:=@;o
00004?m8]dP00ol0003o8m`Sob?L8`03ob?L8`?o00001_meRWD00ol0003o^4NhokQ7^009okQ7^003
o`000?o8=lSob3O800oob3O800?o0000ondBkOo]4^d02_o]4^d00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ol0o`00ol0003okQ7^
onhAkP0FonhAkPGo00001OngB;L00ol0003oNXEjogZ5NP0?ogZ5NP03o`000?lebSGo=LXe00Wo=LXe
00?o0000odRgB?m8]dP03?m8]dP00ol0003o8m`Sob?L8`07ob?L8`;o00000_meRWD>o`0001;ob3O8
00?o0000ondBkOo]4^d02Oo]4^d00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh05Oo^
4Nh00ol0003o]dRgokM8]`09okM8]`03o`000?mjQG[oNXEj00koNXEj00?o0000ocG:=OlebSD02_le
bSD2o`0000_oB;M800?o0000ob?L8olSg2<02_lSg2<2o`0000goC[5>00?o0000olPgb?o8=lP04Oo8
=lP00ol0003okA;]ondBk@07ondBk@03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ol0o`00ol0003okQ7^onhAkP0ConhAkP03o`000?ngB;Oo]dRg00[o]dRg00?o
0000ogZ5N_mjQGX03_mjQGX00ol0003o=LXeocG:=@0<ocG:=@03o`000?m8]dSoB;M800OoB;M800?o
0000ob?L8olSg2<02olSg2<00ol0003oC[5>odjaCP0=odjaCP03o`000?o8=lSob3O8013ob3O800?o
0000ondBkOo]4^d01oo]4^d00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo0?loo`3o00Doo`3o003o`000?o^4NkokQ7^01;okQ7^00?o0000okM8]ongB;L02ong
B;L00ol0003oNXEjogZ5NP0>ogZ5NP03o`000?lebSGo=LXe00go=LXe00?o0000odRgB?m8]dP01?m8
]dP2o`0000ko8m`S00?o0000odjaC_m>/Dh03Om>/Dh00ol0003ob3O8olPgb00@olPgb0Co00001Oo]
4^d00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l01Goo0?l5?l0000?okM8]`03o`000?mjQG[oNXEj00coNXEj00?o0000ocK9=_l000003ole
bSD2o`0000?oB;M800Co0000oaKY5_lFjAKo00003OlSg2<00ol0003oC[5>odjaCP0>odjaCP03o`00
0?o8=lSob3O800cob3O80ol00004om0_d0?o00000_o]4^d00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`05Ool0o`00ol0003oj1OXonPG
j00@onPGj003o`000?ngB;Oo]dRg00go]dRg00?o0000ogZ5N_mjQGX02omjQGX01?l0003o=/TfocK9
=_l0000AocG:=@03o`000?m8]dSo000000Co5^TF00?o0000ob?L8olSg2<02_lSg2<00ol0003oC[5>
odjaCP0>odjaCP03o`000?o8=lSob3O800Wob3O80ol0000:om0_d0;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo0?loo`3o00Eoo`3o003o`000?oX5nSoj1OX013oj1OX00?o0000okM8]ongB;L03Ong
B;L00ol0003oNXEjogZ5NP0:ogZ5NP03o`000?lfbCKo=/Tf00;o=/Tf00?o0000ocG:=OlebSD03ole
bSD00ol0003o5^TFoaKY5P04oaKY5P03o`000?lSg2?o8m`S00Wo8m`S00?o0000odjaC_m>/Dh03_m>
/Dh00ol0003ob3O8olPgb006olPgb0?o00003_o@;m000ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ol0ocoo0?l01Goo0?l00?o0000
onPGj?oX5nP04_oX5nP00ol0003o]dRgokM8]`0=okM8]`03o`000?mjQG[oNXEj00WoNXEj00?o0000
ocK9=_lfbCH00_lfbCH00ol0003o=LXeocG:=@0?ocG:=@03o`000?lFjAKo5^TF00Go5^TF00?o0000
ob?L8olSg2<02?lSg2<00ol0003oC[5>odjaCP0?odjaCP03o`000?o8=lSob3O800;ob3O80ol0000B
om0_d003o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo0?loo`3o00Coo`3o0?o00005?oX5nP00ol0003o]dRgokM8]`0=okM8]`03o`000?mjQG[oNXEj
00SoNXEj00?o0000ocK9=_lfbCH01?lfbCH00ol0003o=LXeocG:=@0>ocG:=@03o`000?lFjAKo5^TF
00Ko5^TF00?o0000ob?L8olSg2<01olSg2<00ol0003oC[5>odjaCP0?odjaCP03o`000?o8=lSo0000
00;o00005Oo@;m000ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00ooo0?l1?l00002ooH9mP03o`000?oX5nSoj1OX01;o
j1OX00?o0000okM8]ongB;L03OngB;L00ol0003oNXEjogZ5NP07ogZ5NP03o`000?lfbCKo=/Tf00Go
=/Tf00?o0000ocG:=OlebSD03OlebSD00ol0003o5^TFoaKY5P08oaKY5P03o`000?lSg2?o8m`S00Ko
8m`S00?o0000odjaC_m>/Dh04?m>/Dh00ol0003od2o@om0_d00Fom0_d003o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02ool0o`4o`0000KomPWf
00?o0000onPGj?oX5nP04ooX5nP00ol0003o]dRgokM8]`0=okM8]`03o`000?mjQG[oNXEj00GoNXEj
00?o0000ocK9=_lfbCH01olfbCH00ol0003o=LXeocG:=@0<ocG:=@03o`000?lFjAKo5^TF00Wo5^TF
00?o0000ob?L8olSg2<01OlSg2<00ol0003oC[5>odjaCP0@odjaCP03o`000?o@;m3od2o@01Ood2o@
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01ool
0o`4o`0000[omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o]dRgokM8]`0=okM8]`03o`000?mj
QG[oNXEj00CoNXEj00?o0000ocK9=_lfbCH02?lfbCH00ol0003o=LXeocG:=@0<ocG:=@03o`000?lF
jAKo5^TF00[o5^TF00?o0000ob?L8olSg2<01?lSg2<00ol0003oC[5>odjaCP0@odjaCP03o`000?o@
;m3od2o@01Ood2o@00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo0?loo`3o004oo`3o0Co00003_of2OH00ol0003oj1OXonPGj00ConPGj003o`000?ngB;Oo
]dRg00go]dRg00?o0000ogZ5N_mjQGX01?mjQGX00ol0003o=/TfocK9=P09ocK9=P03o`000?lebSGo
=LXe00_o=LXe00?o0000oaKY5_lFjAH02olFjAH00ol0003o8m`Sob?L8`03ob?L8`03o`000?m>/Dko
C[5>013oC[5>00?o0000om0_d?o@;m005oo@;m000ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo0?loo`3o004o`0001;omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0
003o]dRgokM8]`0>okM8]`03o`000?mjQG[oNXEj00;oNXEj00?o0000ocK9=_lfbCH02_lfbCH00ol0
003o=LXeocG:=@0:ocG:=@03o`000?lFjAKo5^TF00go5^TF00?o0000ob?L8olSg2<00_lSg2<00ol0
003oC[5>odjaCP0@odjaCP03o`000?o@;m3od2o@01Sod2o@00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oX5nSoj1OX01?oj1OX00?o0000okM8]ongB;L03?ngB;L4o`000003ogZ5N_l0003o=/Tf00go
=/Tf00?o0000ocG:=OlebSD02OlebSD00ol0003o5^TFoaKY5P0>oaKY5P05o`000?lSg2?o8m`Sob?L
8ol000004_m>/Dh00ol0003od2o@om0_d00Hom0_d0?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oX5nSoj1OX
01?oj1OX00?o0000okM8]ongB;L02ongB;L00ol0003oAKY5odFjA@02odFjA@;o00003_lfbCH00ol0
003o=LXeocG:=@09ocG:=@03o`000?lFjAKo5^TF00oo5^TF00Co0000ob?L8olSg2?o00004_m>/Dh0
0ol0003od2o@om0_d00Hom0_d003o`000?o]4^gokA;]00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o]dRgokM8]`0:
okM8]`03o`000?m5^TGoAKY500GoAKY500?o0000ocK9=_lfbCH03?lfbCH00ol0003o=LXeocG:=@08
ocG:=@03o`000?lFjAKo5^TF00oo5^TF1Ol0000AodjaCP03o`000?o@;m3od2o@01Ood2o@00?o0000
ondBkOo]4^d01?o]4^d3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oX5nSoj1OX01?oj1OX00?o0000okM8]ongB;L02?ngB;L2o`00
00WoAKY500?o0000ocK9=_lfbCH02olfbCH00ol0003o=LXeocG:=@07ocG:=@03o`000?lFjAKo5^TF
00go5^TF0ol00005oa3_4003o`000?m>/DkoC[5>00koC[5>00?o0000om0_d?o@;m005_o@;m000ol0
003okA;]ondBk@08ondBk@?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonPGj003o`000?ngB;Oo]dRg00Ko]dRg00?o0000odFjAOm5
^TD02_m5^TD00ol0003o=/TfocK9=P0:ocK9=Q[o00002Ol@ka000ol0003oC[5>odjaCP0<odjaCP?o
00005_o@;m000ol0003okA;]ondBk@0<ondBk@?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oV6NH3o`0001;oj1OX00?o0000okM8]ongB;L01?ngB;L2o`0000koAKY5
00?o0000ocK9=_lfbCH01olfbCH2o`0000[o6>LH00?o0000o`cc3?l<l``03?l<l``00ol0003o4>l@
oa3_4008oa3_40;o00002_m>/Dh2o`0000?o9]TV0_l0000Com0_d003o`000?o]4^gokA;]013okA;]
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onHIiP;o00004?oX
5nP00ol0003o]dRgokM8]`03okM8]`03o`000?m5^TGoAKY500ooAKY500?o0000ocK9=_lfbCH01?lf
bCH2o`0000co6>LH00?o0000o`cc3?l<l``03?l<l``00ol0003o4>l@oa3_400:oa3_4003o`000?m>
/DkoC[5>00GoC[5>0_l00007obKI9P03o`000?o@;m3od2o@00ood2o@00?o0000ondBkOo]4^d04Oo]
4^d01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onHIi_oV6NH01OoV6NH2o`0000ooj1OX00Go0000okM8]ongB;Oo]dRgo`00000CodFjA@03o`00
0?lfbCKo=/Tf00;o=/Tf00?o0000oaSW6?lHiaP03OlHiaP00ol0003o3?<<o`cc300;o`cc3003o`00
0?l@ka3o4>l@00_o4>l@00?o0000odjaC_m>/Dh00_m>/Dh2o`0000[o9]TV0_l0000>om0_d003o`00
0?o]4^gokA;]017okA;]00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onHIi_oV6NH01_oV6NH3o`0000_oj1OX1Ol0000EodFjA@04o`00
0?lfbCKo0000o`00013o6>LH00?o0000o`cc3?l<l``02ol<l``00ol0003o4>l@oa3_400<oa3_4004
o`000?m>/Dko0000o`0000ko9]TV0_l0000;om0_d003o`000?o]4^gokA;]017okA;]00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oV6NKoiQWV00WoiQWV0_l00008onPGj003o`000?nLHicoW6>L00;oW6>L00?o0000odFjAOm5
^TD05?m5^TD00ol0003o6>LHoaSW600@oaSW6003o`000?l<l`co3?<<00_o3?<<00?o0000oa3_4?l@
ka003Ol@ka000ol0003o9]TVobKI9P0@obKI9P03o`000?o@;m3od2o@00Ood2o@00?o0000ondBkOo]
4^d04Oo]4^d00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oV6NKoiQWV00_oiQWV
0_l00005onPGj003o`000?nLHicoW6>L00CoW6>L00?o0000odFjAOm5^TD04om5^TD00ol0003o6>LH
oaSW600@oaSW6003o`000?l<l`co3?<<00_o3?<<00?o0000oa3_4?l@ka003Ol@ka000ol0003o9]TV
obKI9P0AobKI9P;o00000oo@;m04o`0001?okA;]00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oV6NKoiQWV00goiQWV0ol000000ooX5nSo0000oiaSW007oiaSW003o`000?m5^TGoAKY501;o
AKY500?o0000oaSW6?lHiaP04?lHiaP00ol0003o3?<<o`cc300;o`cc3003o`000?l@ka3o4>l@00go
4>l@00?o0000obKI9_lVfBH04olVfBH3o`0000?odbcC00?o0000ondBkOo]4^d04?o]4^d00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oV6NKoiQWV013oiQWV00?o0000oiaSW?nLHi`0
2?nLHi`00ol0003oAKY5odFjA@0AodFjA@03o`000?lHiaSo6>LH017o6>LH00?o0000o`cc3?l<l``0
2_l<l``00ol0003o4>l@oa3_400<oa3_4003o`000?l<l`co000001Co9]TV00?o0000om</dooC;=<0
1?oC;=<00ol0003okA;]ondBk@0>ondBk@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onHIi_oV6NH03ooV
6NH00ol0003oW6>LoiaSW009oiaSW003o`000?m5^TGoAKY5013oAKY500?o0000oaSW6?lHiaP04OlH
iaP00ol0003o3?<<o`cc300:o`cc3003o`000?l@ka3o4>l@00_o4>l@00Co0000o`cc3?l<l`co0000
5?lVfBH00ol0003odbcCom</d`05om</d`03o`000?o]4^gokA;]00cokA;]00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiQWVonHI
iP0?onHIiP03o`000?nLHicoW6>L00[oW6>L00?o0000odFjAOm5^TD03_m5^TD00ol0003o6>LHo`00
000BoaSW6003o`000?l<l`co3?<<00[o3?<<00?o0000oa3_4?l@ka002_l@ka000ol0003o3?<<o`cc
3002o`cc3003o`000?lVfBKo9]TV013o9]TV00?o0000om</dooC;=<01ooC;=<00ol0003okA;]ondB
k@0:ondBk@03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oV6NKoiQWV00ooiQWV00?o0000oiaSW?nLHi`0
2onLHi`00ol0003oAKY5odFjA@0<odFjA@05o`000?lHiaSo6>LHoaSW6?l000004OlHiaP00ol0003o
3?<<o`cc300:o`cc3003o`000?l@ka3o4>l@00Wo4>l@00?o0000o`cc3?l<l``00ol<l``00ol0003o
9]TVobKI9P0@obKI9P03o`000?oC;=?odbcC00SodbcC00?o0000ondBkOo]4^d02?o]4^d00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onHIi_oV6NH03_oV6NH00ol0003oW6>LoiaSW00=oiaSW003o`00
0?m5^TGoAKY500[oAKY500?o0000oaSW6?lHiaP00olHiaP00ol0003o6>LHoaSW600?oaSW6003o`00
0?l<l`co3?<<00Wo3?<<00?o0000oa3_4?l@ka002?l@ka000ol0003o3?<<o`cc3005o`cc3003o`00
0?lVfBKo9]TV00oo9]TV00?o0000om</dooC;=<02OoC;=<00ol0003okA;]ondBk@06ondBk@03o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiQWVonHIiP0>onHIiP03o`000?nL
HicoW6>L00koW6>L00?o0000odFjAOm5^TD02?m5^TD00ol0003o6>LHoaSW6005oaSW6003o`000?lH
iaSo6>LH00ko6>LH00?o0000o`cc3?l<l``02Ol<l``00ol0003o4>l@oa3_4007oa3_4003o`000?l<
l`co3?<<00Ko3?<<00?o0000obKI9_lVfBH03olVfBH00ol0003odbcCom</d`09om</d`03o`000?o]
4^gokA;]00GokA;]00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiQWVonHIiP0=
onHIiP03o`000?nLHicoW6>L00ooW6>L00?o0000odFjAOm5^TD01_m5^TD00ol0003o6>LHoaSW6007
oaSW6003o`000?lHiaSo6>LH00go6>LH00?o0000o`cc3?l<l``02Ol<l``00ol0003o4>l@oa3_4004
oa3_40?o00002_l<l``00ol0003o9]TVobKI9P0=obKI9P03o`000?oC;=?odbcC00_odbcC00?o0000
ondBkOo]4^d00oo]4^d00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oV6NKoiQWV
00goiQWV00?o0000oiaSW?nLHi`04?nLHi`00ol0003oAKY5odFjA@05odFjA@03o`000?lHiaSo6>LH
00So6>LH00?o0000oaSW6?lHiaP03?lHiaP00ol0003o3?<<o`cc3009o`cc3003o`000?l@ka3o0000
00Co00000_l:m@X00ol0003o3?<<o`cc3008o`cc3003o`000?lVfBKo9]TV00go9]TV00?o0000om</
dooC;=<03?oC;=<01Ol0003okA;]ondBkOo]4^go000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0
003oW6>LoiaSW00AoiaSW003o`000?m5^TGoAKY500?oAKY500?o0000oaSW6?lHiaP02_lHiaP00ol0
003o6>LHoaSW600;oaSW6003o`000?l<l`co3?<<00So3?<<0ol00008o`[e2P03o`000?l<l`co3?<<
00So3?<<00?o0000obKI9_lVfBH03?lVfBH00ol0003odbcCom</d`0=om</d`03o`000?o]4^go0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oV6NKoiQWV00goiQWV00?o0000oiaSW?nLHi`04_nLHi`01Ol0
003oAKY5odFjAOm5^TGo000000ko6>LH00?o0000oaSW6?lHiaP02olHiaP00ol0003o3?<<o`cc3006
o`cc3003o`000?l:m@[o2_D:00Wo2_D:00?o0000o`cc3?l<l``02Ol<l``00ol0003o9]TVobKI9P0:
obKI9P03o`000?oC;=?odbcC00oodbcC00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0003oW6>LoiaSW00CoiaSW003o`000?m5^TGo0000
013o6>LH3_l00006o`cc30;o00003?l:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lVfBKo9]TV
00[o9]TV00?o0000om</dooC;=<03ooC;=<00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onHIi_oV6NH02ooV6NH00ol0003o
W6>LoiaSW00DoiaSW0?o00003olHiaP00ol0003o3o0?o`o`3`0<o`o`3`04o`000?l<l`co3?<<o`cc
30;o00003ol:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lVfBKo9]TV00Wo9]TV00?o0000om</
dooC;=<04?oC;=<00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oV6NKoiQWV00_o
iQWV00?o0000oiaSW?nLHi`04onLHi`01Ol0003o;]4^obkA;_l^dBko000000go6>LH00?o0000o`o`
3ol?l0l03_l?l0l00ol0003o3?<<o`00000Ao`[e2P03o`000?l<l`co3?<<00Wo3?<<00?o0000obKI
9_lVfBH02OlVfBH00ol0003odbcCom</d`0@om</d`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000BoiaSW003o`000?l^dBko;]4^00?o;]4^00?o0000oaSW6?lHiaP02OlHiaP00ol0003o
3o0?o`o`3`0@o`o`3`03o`000?l:m@[o2_D:017o2_D:00?o0000o`cc3?l<l``02Ol<l``00ol0003o
9]TVobKI9P07obKI9P03o`000?oC;=?odbcC017odbcC00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iQWVonHIiP0<onHIiP03o`000?n5NXGoQGZ500?o00003_nLHi`00ol0003o;]4^obkA;P05obkA;P03
o`000?lHiaSo6>LH00Oo6>LH00?o0000o`o`3ol?l0l04Ol?l0l00ol0003o2_D:o`[e2P0Ao`[e2P03
o`000?l<l`co3?<<00Wo3?<<00?o0000obKI9_lVfBH01_lVfBH2o`0001CodbcC00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiQWV00koiQWV
00?o0000ohEjQOn5NXD00on5NXD3o`0000[oW6>L00?o0000obkA;_l^dBh01ol^dBh00ol0003o6>LH
oaSW6005oaSW6003o`000?l?l0oo3o0?01;o3o0?00?o0000o`[e2_l:m@X04Ol:m@X00ol0003o3?<<
o`cc300:o`cc3003o`000?lVfBKo9]TV00;o9]TV0ol00002obGJ9@03o`000?oC;=?odbcC017odbcC
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oV6NKoiQWV00koiQWV00?o0000ohEjQOn5NXD01_n5
NXD3o`0000KoW6>L00?o0000obkA;_l^dBh02Ol^dBh00ol0003o6>LHoaSW6003oaSW6003o`000?l?
l0oo3o0?01?o3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o3?<<o`cc3009o`cc3003o`000?lV
fBKo000000;o00001_lUfRD00ol0003odbcCom</d`0@om</d`03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oV6NKo
iQWV00goiQWV00?o0000ohEjQOn5NXD02_n5NXD3o`0000;oW6>L00?o0000obkA;_l^dBh02ol^dBh0
1Ol0003o6>LHoaSW6?lHiaSo000001Ko3o0?00?o0000o`[e2_l:m@X04_l:m@X00ol0003o3?<<o`cc
300:o`cc3003o`000?lUfRGo9MXU00So9MXU00?o0000om</dooC;=<04?oC;=<00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oV6NKoiQWV00goiQWV00?o0000ohEjQOn5NXD03On5NXD2o`0000oo;]4^00?o0000oaSW6?l00000
5ol?l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l<l`co3?<<00Wo3?<<00?o0000obGJ9OlUfRD0
2OlUfRD00ol0003odbcCom</d`0?om</d`03o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV
6NH00ol0003oQGZ5ohEjQ@0>ohEjQ@03o`000?l^dBko;]4^00ko;]4^00?o0000o`o`3ol?l0l05_l?
l0l00ol0003o2_D:o`[e2P0Co`[e2P03o`000?l<l`co3?<<00So3?<<00?o0000obGJ9OlUfRD02olU
fRD5o`0000codbcC00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV6NH00ol0003oQGZ5ohEjQ@0>
ohEjQ@03o`000?l^dBko;]4^00ko;]4^00?o0000o`o`3ol?l0l05_l?l0l00ol0003o2_D:o`[e2P0C
o`[e2P03o`000?l<l`co3?<<00Oo3?<<00?o0000obGJ9OlUfRD03?lUfRD00ol0003odBkAom4^d@02
om4^d@Wo00001?oC;=<00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiQWVonHIiP0<onHIiP03o`000?n5NXGoQGZ5
00koQGZ500?o0000obkA;_l^dBh03ol^dBh00ol0003o3o0?o`o`3`0Eo`o`3`03o`000?l:m@[o2_D:
01?o2_D:1?l00005o`cc3003o`000?lUfRGo9MXU00go9MXU00?o0000om4^dOoA;]402ooA;]44o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oV6NKoiQWV00_oiQWV00?o0000ohEjQOn5NXD03on5NXD00ol0003o;]4^obkA;P0?obkA;P03
o`000?l?l0oo3o0?01Go3o0?00?o0000o`[e2_l:m@X04?l:m@X3o`0000Co4>l@0ol000000ol<l`co
0000obGJ9@0>obGJ9@03o`000?oA;]7odBkA00oodBkA00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiQWVonHIiP0;onHIiP03o`00
0?n5NXGoQGZ500ooQGZ500?o0000obkA;_l^dBh03ol^dBh2o`0001Co3o0?0ol0000@o`[e2P;o0000
2_l@ka000ol0003o9MXUobGJ9@0>obGJ9@03o`000?oA;]7odBkA013odBkA0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oV6NKoiQWV00_oiQWV4ol0000>obkA;P?o0000
0_lNhAh00ol0003o3o0?o`o`3`0<o`o`3`Go00000_lAkQ400ol0003o2_D:o`[e2P0<o`[e2P;o0000
3?l@ka000ol0003o9MXUobGJ9@0>obGJ9@03o`000?oA;]7odBkA013odBkA00?o0000oo@;m?l00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV
6NKoiQWV00_oiQWV00?o0000og2?L?m`Sg003om`Sg000ol0003o;]4^obkA;P09obkA;P?o00001_lN
hAh00ol0003o3o0?o`o`3`06o`o`3`Go00002?lAkQ400ol0003o2_D:o`[e2P08o`[e2P?o00003ol@
ka000ol0003o9MXUobGJ9@0=obGJ9@03o`000?oA;]7odBkA00oodBkA00Go0000oo@;m?od2oCom0_d
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHI
iP0;onHIiP03o`000?m`Sg3oL8m`00ooL8m`00?o0000obkA;_l^dBh01_l^dBh3o`0000[o7^4N00?o
0000o`o`3ol?l0l01Ol0000>oa7^4@03o`000?l:m@[o2_D:00Go2_D:0_l0000Boa3_4003o`000?lU
fRGo9MXU00co9MXU00?o0000om4^dOoA;]404?oA;]400ol0003om0_doo@;m002oo@;m003o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHIiP0;
onHIiP03o`000?m`Sg3oL8m`013oL8m`00?o0000obkA;_l^dBh00_l^dBh3o`0000go7^4N0ol0000C
oa7^4@03o`000?l:m@[o2_D:00?o2_D:0_l0000Eoa3_4003o`000?lUfRGo9MXU00_o9MXU00?o0000
om4^dOoA;]403ooA;]400ol0003om0_doo@;m004oo@;m003o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiQWVonHIiP08onHIiPCo00004Om`Sg000ol0003o;]4^o`000002o`00
00oo7^4N00?o0000ob;M8_l000005OlAkQ400ol0003o2_D:o`000002o`0001Oo4>l@00?o0000obGJ
9OlUfRD02olUfRD00ol0003odBkAom4^d@0>om4^d@03o`000?od2oCom0_d00Kom0_d00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV6NKoiQWV00Go
iQWV0ol00004olTfb@03o`000?m`Sg3oL8m`00koL8m`0_l0000AoakQ7P04o`000?lRgB;o8]dRo`00
01Ko4NhA00?o0000oa3_4?l@ka006?l@ka000ol0003o9MXUobGJ9@0;obGJ9@03o`000?oA;]7odBkA
00kodBkA00?o0000oo@;m?od2o@01ood2o@00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oV6NKoiQWV00;oiQWV0ol00008olTfb@03
o`000?m`Sg3oL8m`00coL8m`0ol0000?oakQ7P;o00000olRgB800ol0003o4NhAoa7^4@0Doa7^4@03
o`000?l@ka3o4>l@01Wo4>l@00?o0000obGJ9OlUfRD02_lUfRD00ol0003odBkAom4^d@0=om4^d@03
o`000?od2oCom0_d00Wom0_d00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<olTfb@03o`000?m`Sg3oL8m`00[oL8m`00Go0000oefRGOmMXUgo
GJ9Mo`00000=oakQ7P03o`000?lRgB;o8]dR00Co8]dR00?o0000oa7^4OlAkQ404olAkQ400ol0003o
4>l@oa3_400Ioa3_4003o`000?lUfRGo9MXU00Wo9MXU00?o0000om4^dOoA;]403_oA;]400ol0003o
m0_doo@;m00:oo@;m0;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o9=/WobCK900cobCK90_l00008og2?L0;o00001OmMXUd00ol0003o7^4NoakQ7P09oakQ7P03o`00
0?lRgB;o8]dR00Go8]dR00?o0000oa7^4OlAkQ404olAkQ400ol0003o4>l@oa3_400Joa3_40go0000
3_oA;]400ol0003om0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003obCK9olTfb@0=olTfb@03o`000?m`
Sg3oL8m`00CoL8m`00?o0000oefRGOmMXUd01_mMXUd2o`0000So7^4N00?o0000ob;M8_lRgB801_lR
gB800ol0003o4NhAoa7^4@0Doa7^4@03o`000?l@ka3o4>l@01Wo4>l@00?o0000oeNXEomGZ5L02_mG
Z5L00ol0003odBkAom4^d@0;om4^d@03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000olTfbOo9=/T03_o9=/T0
1?l0003oL8m`og2?L?m`Sg02o`0000_oGJ9M00?o0000oakQ7_lNhAh00olNhAh2o`0000Wo8]dR00?o
0000oa7^4OlAkQ405?lAkQ400ol0003o4>l@oa3_400Hoa3_4003o`000?mGZ5OoEjQG00coEjQG00?o
0000om4^dOoA;]402OoA;]400ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obCK9olTfb@0>olTfb@03o`000?m`Sg3o
000000koGJ9M00Go0000oakQ7_lNhAko7^4No`00000;ob;M8P03o`000?lAkQ7o4NhA01Co4NhA0_l0
000Ioa3_4003o`000?mGZ5OoEjQG00goEjQG0_l00008om4^d@03o`000?od2oCom0_d00kom0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obCK9olTfb@0?
olTfb@03o`000?mMXUgoGJ9M00koGJ9M00?o0000oakQ7_l000003?lRgB800ol0003o4NhAoa7^4@0D
oa7^4@03o`000?lFjAKo000000;o00005Ol@ka000ol0003oEjQGoeNXE`0@oeNXE`03o`000?oA;]7o
dBkA00GodBkA00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003obCK9olTfb@0>olTfb@03o`000?mMXUgoGJ9M00koGJ9M0_l0000=ob;M
8P03o`000?lAkQ7o4NhA01?o4NhA00?o0000oaKY5_lFjAH00olFjAH2o`0001;o4>l@00?o0000oeNX
EomGZ5L04_mGZ5L01?l0003odBkAom4^dOoA;]43o`0001;om0_d00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000olTfbOo9=/T03Oo9=/T2o`0000ooGJ9M00?o0000oenP
Gol000003_lRgB800ol0003o4NhAoa7^4@0Boa7^4@03o`000?lFjAKo5^TF00Go5^TF0ol0000?oa3_
4003o`000?mGZ5OoEjQG01?oEjQG0ol00002on`Ck003o`000?od2oCom0_d013om0_d00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000olTfbOo9=/T02oo9=/T00ol0003o
bcC;o`00000>oefRG@05o`000?mOX5ooGj1OoenPGol000003OlRgB800ol0003o4NhAoa7^4@0Aoa7^
4@03o`000?lFjAKo5^TF00Wo5^TF0ol0000:oa3_40;o00005_mGZ5L00ol0003ok1?/on`Ck003on`C
k003o`000?od2oCom0_d013om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000olTfbOo9=/T02_o9=/T01Ol0003obcC;ol/dboo;=<_o000000coGJ9M00?o0000oenP
GomOX5l00_mOX5l00ol0003o8]dRob;M8P0;ob;M8P03o`000?lAkQ7o4NhA017o4NhA00?o0000oaKY
5_lFjAH03?lFjAH2o`0000Ko4>l@0_l000000olebSGo0000oeNXE`0DoeNXE`03o`000?o/4ncok1?/
00Gok1?/00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003obCK9olTfb@07olTfb@;o00001Oo;=</00ol0003oGJ9MoefRG@08oefRG@03
o`000?mOX5ooGj1O00CoGj1O00?o0000ob;M8_lRgB802OlRgB84o`00013o4NhA00?o0000oaKY5_lF
jAH03olFjAH3o`000003oa3_4?l0003o000000Co=LXe00?o0000oeNXEomGZ5L04OmGZ5L00ol0003o
k1?/on`Ck007on`Ck003o`000?od2oCom0_d00oom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000olTfbOo9=/T01_o9=/T00ol0003obcC;ol/db`05ol/db`03o`00
0?mMXUgoGJ9M00OoGJ9M00?o0000oenPGomOX5l01OmOX5l00ol0003o8]dRob;M8P08ob;M8P03o`00
0?lWf2Oo9mPW00;o9mPW0ol0000=oa7^4@03o`000?lFjAKo5^TF01;o5^TF00?o0000ocG:=OlebSD0
1OlebSD00ol0003oEjQGoeNXE`0@oeNXE`03o`000?o/4ncok1?/00Ook1?/00?o0000oo@;m?od2o@0
3ood2o@00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003obCK9olTf
b@04olTfb@03o`000?o;=<_obcC;00OobcC;00?o0000oefRGOmMXUd01OmMXUd00ol0003oGj1OoenP
G`07oenPG`03o`000?lRgB;o8]dR00Ko8]dR00?o0000obOH9olWf2L01_lWf2L3o`0000So4NhA0_l0
000EoaKY5P03o`000?lebSGo=LXe00Ko=LXe00?o0000oeNXEomGZ5L03_mGZ5L00ol0003ok1?/on`C
k009on`Ck003o`000?od2oCom0_d00kom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000olTfbOo9=/T00_o9=/T2o`0000[obcC;00?o0000oefRGOmMXUd01?mMXUd0
0ol0003oGj1OoenPG`09oenPG`03o`000?lRgB;o8]dR00?o8]dR0_l0000<obOH9`?o00000_lAkQ43
o`000003ob3O8?l0003o5^TF01Co5^TF00?o0000ocG:=OlebSD01olebSD00ol0003oEjQGoeNXE`0<
oeNXE`03o`000?o/4ncok1?/00_ok1?/00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003obCK9olTfbOl0000=ol/db`03o`000?mMXUgo
GJ9M00;oGJ9M00?o0000oenPGomOX5l02_mOX5l00ol0003o8]dRob;M8P02ob;M8P03o`000?lWf2Oo
9mPW00oo9mPW0_l00005ob3O8003o`000?lFjAKo5^TF01;o5^TF00?o0000ocG:=OlebSD02?lebSD0
0ol0003oEjQGoeNXE`0:oeNXE`03o`000?o/4ncok1?/00gok1?/1Ol0000;oo@;m003o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o9=/Wo000000oobcC;00Co0000oefR
GOmMXUgo00003_mOX5l01?l0003o8]dRob;M8_l0000CobOH9`03o`000?lPgb3o8=lP00Co8=lP00?o
0000oaKY5_lFjAH04?lFjAH00ol0003o=LXeocG:=@09ocG:=@03o`000?mGZ5OoEjQG00[oEjQG00?o
0000on`Ck?o/4n`03Oo/4n`00ol0003onPGjooX5nP02ooX5nPWo00000_od2o@00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?o;=<_obcC;00kobcC;00?o0000oefRGOl000003omOX5l0
0ol0003o8]dRo`00000CobOH9`03o`000?lPgb3o8=lP00Go8=lP00?o0000oaKY5_lFjAH04?lFjAH0
0ol0003o=LXeocG:=@0:ocG:=@03o`000?mGZ5OoEjQG00SoEjQG00?o0000on`Ck?o/4n`03Oo/4n`0
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000ol/d
boo;=</03oo;=</00ol0003oGj1OoenPG`0>oenPG`;o00005?lWf2L00ol0003o8=lPob3O8006ob3O
8003o`000?lFjAKo5^TF00oo5^TF00?o0000ocG:=OlebSD02olebSD00ol0003oEjQGoeNXE`04oeNX
E`?o00004?o/4n`00ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
bcC;ol/db`0@ol/db`03o`000?mOX5ooGj1O00_oGj1O0ol000000omQWV7o0000obOH9`0BobOH9`03
o`000?lPgb3o8=lP00Oo8=lP00?o0000oaKY5_lFjAH03olFjAH00ol0003o=LXeocG:=@0<ocG:=@03
o`000?mGZ5OoEjQG00?o00000ooI9]T00ol0003ok1?/on`Ck00=on`Ck003o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000ol/dboo;=</04?o;=</3o`0000WoGj1O0_l00005of6NH@03o`00
0?lWf2Oo9mPW013o9mPW00?o0000ob3O8?lPgb002?lPgb000ol0003o5^TFoaKY5P0>oaKY5P03o`00
0?lebSGo=LXe00go=LXe0_l00007omTVf@03o`000?o/4ncok1?/00_ok1?/00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o;=<_obcC;00oobcC;00Co
0000ol8m`_o2?L;o`Sg20_l00005oenPG`;o00002?mQWV400ol0003o9mPWobOH9`0>obOH9`03o`00
0?lPgb3o8=lP00[o8=lP00?o0000oaKY5_lFjAH03?lFjAH00ol0003o=LXeocG:=@0>ocG:=@03o`00
0?oI9]WofBKI00OofBKI00?o0000on`Ck?o/4n`02_o/4n`00ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006ol8m`P03o`000?mOX5oo000000;o00002_mQ
WV400ol0003o9mPWobOH9`0=obOH9`03o`000?lPgb3o8=lP00_o8=lP00?o0000oaKY5_lFjAH03?lF
jAH00ol0003o=LXeocG:=@0=ocG:=@03o`000?oI9]WofBKI00WofBKI00?o0000on`Ck?o/4n`02?o/
4n`00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o_4>oo
ka3_00ooka3_00?o0000ol8m`_o2?L801Oo2?L800ol0003oHIiQof6NH@0<of6NH@03o`000?lWf2Oo
9mPW00co9mPW00?o0000ob3O8?lPgb003?lPgb02o`0000co5^TF00?o0000ocG:=OlebSD03OlebSD0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o/4ncok1?/00Ook1?/00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o_4>l04?o_4>l00ol0003o`Sg2ol8m`P06ol8m`P03o`000?mQWV7o
HIiQ00coHIiQ00?o0000obOH9olWf2L02olWf2L00ol0003o8=lPob3O800=ob3O8004o`000?lbcC;o
0000o`0000[o5^TF00?o0000ocG:=OlebSD03OlebSD00ol0003ofBKIomTVf@0;omTVf@03o`000?o/
4ncok1?/00Kok1?/00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003oka3_onl@k`0@
onl@k`03o`000?o2?L;o`Sg200Ko`Sg200?o0000of6NHOmQWV403OmQWV400ol0003o9mPWobOH9`0:
obOH9`03o`000?lPgb3o8=lP00co8=lP00?o0000oc;=<_lbcC800_lbcC82o`0000So5^TF00?o0000
ocG:=OlebSD03?lebSD00ol0003ofBKIomTVf@0=omTVf@03o`000?o/4ncok1?/00Cok1?/00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@onl@k`03o`000?o2?L;o`Sg2
00Oo`Sg200?o0000of6NHOmQWV403_mQWV4<o`0000oo8=lP00?o0000oc;=<_lbcC801?lbcC82o`00
00Ko5^TF00?o0000ocG:=OlebSD03?lebSD00ol0003ofBKIomTVf@0>omTVf@03o`000?o/4ncok1?/
00?ok1?/00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>onl@
k`03o`000?o2?L;o`Sg200So`Sg200?o0000of6NHOmQWV403OmQWV400ol0003oAKY5odFjA@08odFj
A@03o`000?lPgb3o8=lP00co8=lP00?o0000oc;=<_lbcC801olbcC82o`0000?o5^TF00?o0000ocG:
=OlebSD03OlebSD00ol0003ofBKIomTVf@0?omTVf@05o`000?o/4ncok1?/on`Ck?l000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo_4>l00ol0003o`Sg2ol8m`P08ol8m`P03o`000?mQWV7o
HIiQ00coHIiQ00?o0000odFjAOm5^TD02_m5^TD00ol0003o8=lPob3O800;ob3O8003o`000?lbcC;o
</db00Wo</db0_l000000olFjAKo0000ocG:=@08ocG:=@Ko00004ooI9]T01?l0003ok1?/on`Ck?l0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008onl@k`03o`000?o2?L;o
`Sg200Wo`Sg200?o0000of6NHOmQWV403?mQWV400ol0003oAKY5odFjA@0:odFjA@03o`000?lPgb3o
8=lP00[o8=lP00?o0000oc;=<_lbcC803?lbcC8;o`0000Go]DZe00?o0000omTVfOoI9]T04_oI9]T0
0ol0003ok1?/o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on@K
i?oT6nCoi1_T1Ol00003onl@k`03o`000?o2?L;o`Sg200Wo`Sg200?o0000of6NHOmQWV402omQWV40
0ol0003oAKY5odFjA@0<odFjA@03o`000?lPgb3o8=lP00Wo8=lP00?o0000oc;=<_lbcC803?lbcC80
0ol0003oF:MHoeRWF002oeRWF003o`000?neB[Go]DZe00Wo]DZe00?o0000omTVfOoI9]T04_oI9]T3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on@K
i?oT6n@01OoT6n@3o`0000co`Sg200?o0000of6NHOmQWV402omQWV400ol0003oAKY5odFjA@0<odFj
A@03o`000?lPgb3o8=lP00So8=lP00?o0000oc;=<_lbcC803?lbcC800ol0003oF:MHoeRWF004oeRW
F003o`000?neB[Go]DZe00So]DZe00?o0000omTVfOoI9]T04_oI9]T00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oT6nCoi1_T00Ooi1_T00?o0000ol8m
`_o2?L802_o2?L800ol0003oHIiQof6NH@09of6NH@;o00003om5^TD00ol0003o8=lPob3O8008ob3O
8003o`000?lbcC;o</db00co</db00?o0000oeRWF?mHYeP01?mHYeP00ol0003o]DZeokE:]@09okE:
]@Co00003ooI9]T00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on@Ki?oT6n@02?oT6n@00ol0003o`Sg2ol8m`P09ol8m`P03o`000?mQWV7oHIiQ00Ko
HIiQ0ol000000on>LHko0000odFjA@0?odFjA@03o`000?lPgb3o8=lP00Ko8=lP00?o0000oc;=<_lb
cC803OlbcC800ol0003oF:MHoeRWF005oeRWF003o`000?neB[Go]DZe00So]DZe00Co0000oo<<looc
3??ol`cc1Ol00009omTVf@03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003oi1_Ton@Ki007on@Ki003o`000?o2?L;o`Sg200[o`Sg200?o0000of6NHOmQ
WV400_mQWV43o`0000GoSW6>00?o0000odFjAOm5^TD03Om5^TD00ol0003o8=lPob3O8006ob3O8003
o`000?lbcC;o</db00co</db00?o0000oeRWF?mHYeP01_mHYeP00ol0003o]DZeokE:]@08okE:]@03
o`000?oc3??ol`cc00Kol`cc1Ol00003omTVf@03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on@Ki?oT6n@01ooT6n@00ol0003o`Sg2ol8m`P0:ol8m`P03o`000?mQWV7o000000;o0000
2?n>LHh00ol0003oAKY5odFjA@0=odFjA@Co00001?lPgb000ol0003o</dboc;=<P0=oc;=<P03o`00
0?mHYeSoF:MH00OoF:MH00?o0000okE:]OneB[D01oneB[D00ol0003ol`ccoo<<l`0;oo<<l`?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on@Ki?oT6n@02?oT6n@3o`0000Wo`Sg20_l0
000<ohiaSP03o`000?m5^TGoAKY500_oAKY500?o0000ogJ9M_mfRGH00_mfRGH3o`000003ob3O8?l0
003o</db00ko</db00?o0000oeRWF?mHYeP01omHYeP00ol0003o]DZeokE:]@06okE:]@03o`000?oc
3??ol`cc00kol`cc00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on@Ki?oT6n@01_oT6n@01?l0003oiQWVonHIi_oV6NH3o`0000Ko`Sg200?o0000ohiaS_n>LHh03?n>
LHh00ol0003oAKY5odFjA@09odFjA@03o`000?mfRGKoMXUf00KoMXUf00?o0000oc;=<_lbcC803Olb
cC800ol0003oF:MHoeRWF009oeRWF003o`000?neB[Go]DZe00Go]DZe00?o0000oo<<looc3?<03_oc
3?<00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003oi1_Ton@Ki005
on@Ki003o`000?oV6NKoiQWV00GoiQWV0ol00002ol8m`P03o`000?n>LHkoSW6>00goSW6>00?o0000
odFjAOm5^TD02?m5^TD00ol0003oMXUfogJ9MP07ogJ9MP03o`000?lbcC;o</db00co</db0ol0000:
oeRWF003o`000?neB[Go]DZe00Go]DZe00?o0000oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003oi1_Ton@Ki004on@Ki003o`000?oV6NKoiQWV
00WoiQWV0_l0000AohiaSP03o`000?m5^TGoAKY500GoAKY50_l0000;ogJ9MP03o`000?lbcC;o</db
00[o</db00Go0000oiMXUonGJ9OoUfRGo`00000:oeRWF003o`000?neB[Go]DZe00Co]DZe00?o0000
oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oT6nCoi1_T
00;oi1_T00?o0000onHIi_oV6NH02_oV6NH2o`00017oSW6>00?o0000odFjAOm5^TD01?m5^TD00ol0
003oMXUfogJ9MP0<ogJ9MP03o`000?lbcC;o</db00Oo</db0_l00005oiMXU`;o00002?mHYeP00ol0
003o]DZeokE:]@04okE:]@03o`000?oc3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003oi1_Ton@Ki?oT6nCo000000coiQWV00Co0000omLX
eooG:=Oo00004On>LHh00ol0003oAKY5odFjA@02odFjA@03o`000?mfRGKoMXUf00koMXUf00?o0000
oc;=<_lbcC801OlbcC800ol0003oUfRGoiMXU`07oiMXU`03o`000?mHYeSoF:MH00KoF:MH00?o0000
okE:]OneB[D00oneB[D00ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on@Ki?oT6nCo00003?oV6NH00ol0003oebSGomLXe`02omLXe`03o`000?n>LHko
SW6>00ooSW6>00Co0000odFjAOm5^TGo00004OmfRGH00ol0003o</dboc;=<P04oc;=<P03o`000?nG
J9OoUfRG00WoUfRG00?o0000oeRWF?mHYeP01OmHYeP00ol0003o]DZeokE:]@03okE:]@03o`000?oc
3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onHIiP03o`000?oG:=OoebSG00?oebSG00?o0000ohiaS_n>LHh03on>LHh00ol0003oAKY5o`00000C
ogJ9MP04o`000?lbcC;o</dboc;=<P;o00003OnGJ9L2o`0000KoF:MH00Go0000okE:]OneB[Go]DZe
o`00000@oo<<l`03o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02_oV
6NH00ol0003oebSGomLXe`05omLXe`03o`000?n>LHkoSW6>00ooSW6>00?o0000ogJ9M_mfRGH04omf
RGH00ol0003o</dbo`00000AoiMXU`03o`000?mHYeSoF:MH00?oF:MH00Go0000okE:]OneB[Go]DZe
o`00000>oo<<l`?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02OoV
6NH00ol0003oebSGomLXe`07omLXe`03o`000?n>LHkoSW6>00koSW6>00?o0000ogJ9M_mfRGH05?mf
RGH00ol0003oUfRGoiMXU`0AoiMXU`;o00001?mHYeP01?l0003o]DZeokE:]Ol0000:oo<<l`Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onHIi_oV6NH02OoV6NH00ol0003oebSGomLXe`08omLXe`03o`000?n>LHkoSW6>00_oSW6>0ol0
000GogJ9MP03o`000?nGJ9OoUfRG01?oUfRG00Ko0000oeRWF?mHYeSoF:MHo`000?neB[D5o`0000Co
l`cc0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oV6NKoiQWV00SoiQWV00?o0000omLXeooG:=L02_oG:=L00ol0003oSW6>ohiaSP07ohiaSP?o0000
0_nXEjP00ol0003oMXUfogJ9MP0EogJ9MP;o00005OnGJ9L00ol0003oF:MHoeRWF002o`0000GojaC[
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onHIi_oV6NH01ooV
6NH00ol0003oebSGomLXe`0;omLXe`03o`000?n>LHkoSW6>00CoSW6>0ol00006ojQGZ003o`000?mf
RGKoMXUf01?oMXUf00Co0000ol0o`?o0?l3o00005OnGJ9L2o`0000WojaC[00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiQWV00?o0000omLXeooG:=L03OoG:=L00ol0003oSW6>ohia
SP03o`0000[oZ5NX00?o0000ogJ9M_mfRGH04OmfRGH00ol0003o`3o0ol0o`002ol0o`003o`000?nG
J9OoUfRG01;oUfRG00?o0000on/Djoo[5>/02?o[5>/00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiQWVonHIiP05onHIiP03o`000?oG:=OoebSG00ooebSG0_l0000>
ojQGZ003o`000?mfRGKoMXUf00ooMXUf00?o0000ol0o`?o0?l001?o0?l000ol0003oUfRGoiMXU`0@
oiMXU`;o00002oo[5>/00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onHIi_oV6NH00ooV6NH00ol0003oebSGomLXe`0@omLXe`03o`000?nXEjSoZ5NX
00goZ5NX00?o0000ogJ9M_mfRGH03_mfRGH00ol0003o`3o0ol0o`006ol0o`0;o00003_nGJ9L2o`00
0003om0_d?l0003ojaC[00[ojaC[00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiQWVonHIi_oV6NKo000001;oebSG00?o0000ojQGZ?nXEjP03onXEjP00ol0003oMXUfogJ9MP0<
ogJ9MP03o`000?o0?l3o`3o000Wo`3o000?o0000oiMXUonGJ9L02OnGJ9L2o`0000?od2o@00?o0000
on/Djoo[5>/02Oo[5>/00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiQWVo`00000ComLX
e`03o`000?nXEjSoZ5NX013oZ5NX00?o0000ogJ9M_mfRGH02_mfRGH00ol0003o`3o0ol0o`00;ol0o
`003o`000?nGJ9OoUfRG00GoUfRG0ol00006om0_d003o`000?o[5>_ojaC[00SojaC[00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omLXeooG:=L04OoG:=L00ol0003oZ5NXojQGZ00AojQGZ003o`000?mfRGKoMXUf00Wo
MXUf00?o0000ol0o`?o0?l003Oo0?l000ol0003oUfRGoiMXU`02oiMXU`;o00002Oo@;m000ol0003o
jaC[on/Dj`09on/Dj`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017oebSG00?o0000ojQGZ?nXEjP0
4_nXEjP00ol0003oMXUfogJ9MP07ogJ9MP03o`000?o0?l3o`3o000oo`3o000Co0000oiMXUol0003o
00002oo@;m000ol0003ojaC[on/Dj`09on/Dj`03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000koebSG00?o0000ojQGZ?nXEjP04onXEjP00ol0003oMXUfogJ9MP05ogJ9MP03o`00
0?o0?l3o`3o0017o`3o000?o0000om0_d?o@;m003?o@;m000ol0003ojaC[on/Dj`08on/Dj`03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;omLXe`;o00005_nXEjP7o`0001Co`3o000?o
0000om0_d?o@;m003?o@;m000ol0003ojaC[on/Dj`08on/Dj`03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oG:=L00ol0003oc3?<o`000002o`0001;oZ5NX00?o0000okQ7^?nhAkP00_nh
AkP00ol0003o[5>/o`00000Dol0o`003o`000?o@;m3od2o@00cod2o@00?o0000on/Djoo[5>/02?o[
5>/00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoG:=L00ol0003oc3?<ol`cc003
ol`cc0;o00003onXEjP00ol0003o^4NhokQ7^003okQ7^004o`000?n/Djco[5>/o`0001?o`3o000?o
0000om0_d?o@;m003Oo@;m000ol0003ojaC[on/Dj`08on/Dj`03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003omLXeol0003o
c3?<00Ooc3?<0ol0000;ojQGZ003o`000?nhAkSo^4Nh00Co^4Nh00Go0000ojaC[?n/Djco[5>/o`00
000Bol0o`003o`000?o@;m3od2o@00god2o@00?o0000on/Djoo[5>/01oo[5>/?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T04?oi1_T0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o<<lcoc3?<00[oc3?<0_l00008ojQGZ003o`000?nhAkSo
^4Nh00Go^4Nh00?o0000ojaC[?n/Dj`00_n/Dj`00ol0003o`3o0ol0o`00?ol0o`003o`000?o@;m3o
d2o@00god2o@00?o0000on/Djoo[5>/01_o[5>/00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oi1_Won@Ki00oon@Ki00?o0000on`Ck?o/4n`03oo/4n`00ol0003oc3?<ol`cc00<ol`c
c0;o00001OnXEjP00ol0003o^4NhokQ7^006okQ7^003o`000?n/Djco[5>/00?o[5>/00?o0000ol0o
`?o0?l003_o0?l000ol0003od2o@om0_d00>om0_d003o`000?o[5>_ojaC[00CojaC[00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00kon@Ki00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
c3?<ol`cc00>ol`cc0?o000000?oZ5NXo`000?nhAkP02?nhAkP00ol0003o[5>/ojaC[004ojaC[003
o`000?o0?l3o`3o000go`3o04_l00005on/Dj`03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooT6n@03o`000?o/4ncok1?/00ook1?/0_l0000Col`cc003o`000?nhAkSo^4Nh00So^4Nh
00?o0000ojaC[?n/Dj`01On/Dj`00ol0003o`3o0ol0o`00<ol0o`003o`000?oa3_7ol@ka00ool@ka
00Go0000on/Djoo[5>_ojaC[o`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n@Ki00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000Col`cc003o`000?nhAkSo^4Nh00So
^4Nh00?o0000ojaC[?n/Dj`01On/Dj`00ol0003o`3o0ol0o`00;ol0o`003o`000?oa3_7ol@ka017o
l@ka00?o0000on/Djol000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n@KiooT6n@0:ooT6n@03o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o<<lcoc3?<013o
c3?<00?o0000okQ7^?nhAkP02?nhAkP00ol0003o[5>/ojaC[006ojaC[003o`000?o0?l3o`3o000[o
`3o000?o0000oo4>lOoa3_404_oa3_400ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on@KiooT6n@09ooT6n@03o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003oc3?<ol`cc00?ol`cc003o`000?nhAkSo^4Nh00Wo^4Nh00?o0000ojaC[?n/Dj`0
1on/Dj`00ol0003o`3o0ol0o`009ol0o`003o`000?oa3_7ol@ka01;ol@ka00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003oc3?<ol`cc00?ol`cc003o`000?nhAkSo^4Nh00Wo^4Nh00?o
0000ojaC[?n/Dj`02?n/Dj`00ol0003o`3o0ol0o`007ol0o`003o`000?oa3_7ol@ka01?ol@ka00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000ol`cc?o<<l`03Oo<<l`2
o`0000_o^4Nh00?o0000ojaC[?n/Dj`02On/Dj`00ol0003o`3o0ol0o`006ol0o`003o`000?oa3_7o
l@ka01?ol@ka4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003oc3?<ol`cc00;ol`cc0;o000000?ocC;=o`000?nhAkP02_nhAkP00ol0
003o[5>/ojaC[009ojaC[0Ko00000oo0?l000ol0003ol@kaoo4>l@0Coo4>l@03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01?oi1_T3o`00
00Sok1?/0_l0000;on@Ki003o`000?o<<lcoc3?<00Woc3?<0_l00004oldbc@03o`000?nhAkSo^4Nh
00So^4Nh00?o0000ojaC[?n/Dj`02?n/Dj`00ol0003og2?Lom`Sg004om`Sg0?o00005?oa3_43o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on@KiooT6n@03o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o<<lcoc3?<00Go
c3?<0ol00007oldbc@03o`000?nhAkSo^4Nh00Oo^4Nh00?o0000ojaC[?n/Dj`01on/Dj`00ol0003o
g2?Lom`Sg008om`Sg003o`000?oa3_7ol@ka013ol@ka00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000ol`c
c?o<<l`00oo<<l`2o`0000[ocC;=00?o0000okQ7^?nhAkP01onhAkP00ol0003o[5>/ojaC[005ojaC
[0;o00003?oL8m`00ol0003ol@kaoo4>l@0=oo4>l@;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000ol`cc?o<<lcoc3?<0_l0000=oldbc@03o`000?nhAkSo^4Nh00Ko^4Nh00?o0000ojaC
[?n/Dj`01?n/Dj`00ol0003og2?Lom`Sg00=om`Sg0Co00002_oa3_400ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013ocC;=00?o0000okQ7^?nhAkP01OnhAkP00ol0003o
[5>/ojaC[003ojaC[003o`000?oL8mcog2?L00kog2?L00Co0000ooH9m_of2OKomPWf1_l00003oo4>
l@03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o=</gocC;=013o
cC;=00?o0000okQ7^?nhAkP01OnhAkP00ol0003o[5>/ojaC[002ojaC[003o`000?oL8mcog2?L00oo
g2?L00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000oldbcOo=</d0
4Oo=</d00ol0003o^4NhokQ7^004okQ7^003o`000?n/Djco[5>/00;o00004OoL8m`00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o=</d3o`0000Co^4Nh00?o0000ojaC[?l000004ooL
8m`00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003ocC;=017ocC;=0_l00003omPWf0;o00000_nhAkP2
o`0001Cog2?L00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o=</gocC;=00gocC;=0_l00007omPWf0?o00005OoL8m`00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000oldbcOo=</d02_o=</d2o`0000_o
f2OH00?o0000om`Sg?oL8m`04_oL8m`00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o=</gocC;=00OocC;=0_l0000=omPWf003o`000?oL8mcog2?L01;og2?L00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000oldbcOo=</d01Oo=</d2o`0000oof2OH00?o
0000om`Sg?oL8m`04_oL8m`00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000oldbcOo=</d00_o=</d2o`0001;of2OH00?o0000om`Sg?oL8m`04OoL8m`0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003ol`ccoo<<lol0000@onDJi@04o`000?o=</go
0000o`0001Cof2OH00?o0000om`Sg?oL8m`04?oL8m`00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo<<looc3?<00_oc3?<00ol0003oiA[UonDJi@0>onDJi@03o`000?oH9mSof2OH01Cof2OH00?o0000
om`Sg?oL8m`03OoL8m`4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003ol`ccoo<<l`03oo<<l`03o`000?oU6^GoiA[U
00goiA[U00?o0000omPWf?oH9mP05?oH9mP00ol0003og2?Lom`Sg007om`Sg0Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo<<looc3?<01Ooc3?<00ol0003oiA[UonDJi@0<onDJi@03
o`000?oH9mSof2OH01Gof2OH00?o0000om`Sg?oL8m`01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003ol`ccoo<<l`06oo<<l`03o`000?oU6^GoiA[U00_oiA[U00?o0000omPWf?oH9mP0
5OoH9mP3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo<<looc3?<02?oc3?<00ol0003oiA[UonDJ
i@0:onDJi@03o`000?oH9mSof2OH01Gof2OH00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo<<l`03o`000?oU6^GoiA[U00WoiA[U00?o0000omPWf?oH9mP05?oH9mP0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?oc3??ol`cc00_ol`cc00?o0000onDJiOoU6^D02OoU6^D0
0ol0003of2OHomPWf00ComPWf003o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?oc3?<00ol0003oiA[UonDJi@08onDJ
i@03o`000?oH9mSof2OH00oof2OH1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_oc3?<00ol0003oiA[UonDJi@07onDJi@03o`000?oH9mSof2OH00Sof2OH1ol00003on`C
k003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo<<l`03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omPWf?oH9mSof2OH1ol0000:on`Ck003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000Kol`cc00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
k1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?oc3?<00ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ok1?/01Cok1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000Col`cco`000?l0003o00001?oh1oP00ol0003ok1?/on`Ck00Bon`Ck0;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k00@on`Ck004o`000?o_4>ooka3_o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ok1?/on`Ck00?on`Ck003o`000?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o/4nco
k1?/00kok1?/00?o0000onl@koo_4>l01?o_4>l2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00=on`Ck003o`000?o_4>ooka3_
00Goka3_00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000onl@koo_4>l01_o_4>l00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ok1?/
on`Ck009on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o/4ncok1?/00Sok1?/00?o
0000onl@koo_4>l02?o_4>l00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000onl@koo_4>l02?o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ok1?/on`Ck005on`Ck003o`000?o_4>ooka3_00Woka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Co
k1?/00?o0000onl@koo_4>l02_o_4>l00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`Ck003on`Ck003o`00
0?o_4>ooka3_00[oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`C
k002on`Ck003o`000?o_4>ooka3_00_oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ok1?/on`Ck?l0000>onl@k`03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o_4>l00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000Woka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000Goka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?oka3_o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o3?ooo`001olQ8Mgo003oo`00ool00?oo<S;<ojVYEOo^kQ000oooo`001?oMgB7oZJUEofIVV?l@
4>h:o`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0:o`00o`;oool0VOl00?l1ooooo`00
WOl00?l00onHV6Koool0ogMgQ`07o`00o`03oiRHI_ooo`3oMgN700co003o0_ooo`07o`00o`03oc8b
c?ooo`3oool000Woool000CoV9QVo`00ool00?oo003o1?ooo`001onj^TCo8B7Mo`00oolb</coZJUE
oooo0?mgMhL01ol00?l02_l@4>kogMdQoooo0?mgMhOo413^o`00oomEEJWoool0omgM8Ol@4>h9o`00
o`;oool0VOl00?l1ooooo`00WOl00?l00oo^kQ3oool0omgM8@07o`00o`03onk^4?ooo`3ogMdQ00co
003o0_ooo`08o`00o`03odA4^_ooo`3oool000Woool000Oo413^o`00ool00?oo^[Y4oooo0?o<c3;o
A4Bj00Go003o00?oIVJHoooo0?nYZED01_l00?l00ooMgB7oool0ogMgQ`04o`00o`03odA4^_ooo`3o
gMdQ00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00o`05oc8bc?ooo`3oool0oooo0?l@4>h01Ol00?l0
1Olb</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`09o`00o`03ofIVV?o^kQ3o413^00Ko003o00?o
A4Bjonk^4?n7QgL03?l00?l00onYZEGoool0ojVYE@04o`00o`03ohN7Moooo`3oool000Ko003o00?o
gMdQoooo0?mVIYP02?l00?l2oooo09Wo003o0Oooool009co003o00GoZJUEoooo0?ooo`3oool0ofIV
V005o`00o`05oiRHI_ooo`3oool0oooo0?mgMhL02ol00?l2oooo00[o003o00?oV9QVomgM8Ol@4>h0
1_l00?l00om4A;[oZJUEo`00o`0;o`00o`04oc8bc?ooo`3oool0odA4^P?o003o0_ooo`000onHV6Ko
003oo`00o`04o`00o`03ohN7Moooo`3ok^h@00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`?oool0
00?oIVJHokZjA?l00?l01?l00?l01Oo^kQ3oool0oooo0?mVIYSogMdQ00_o003o0_ooo`0;o`00o`03
ojVYEOoMgB7o413^01Co003o0_ooo`001?nj^TCo003oo`00oomEEJT2oooo0003ofIVV?l00?oo003o
00Co003o00CoEEFYoooo0?ooo`3o<S;<1ol00?l2oooo09Wo003o0Oooool009_o003o00OoEEFYoooo
0?ooo`3ok^h@o`00ooo^kQ3o413^00?o003o00OoEEFYoooo0?ooo`3ok^h@o`00ooo^kQ3o8B7M00[o
003o0_ooo`0;o`00o`03oa0@k_oMgB7oZJUE01Co003o0oooo`02o`00o`04oiRHI_ooo`3oool0odA4
^PKo003o00CoA4Bjoooo0?ooo`3oQhMg1ol00?l2oooo09Wo003o0Oooool009_o003o00OoZJUEoooo
0?ooo`3oV9QVo`00oonHV6KoIVJH00?o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN700[o
003o0_ooo`0<o`00o`03oa0@k_ooo`3oZJUE01;o003o00CoEEFYoooo0?ooo`3oool00_l00?l01?o<
c3;oool0oooo0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l01Ol00?l2oooo09Wo003o0Oooool0
09_o003o0oooo`001?lQ8Mgo003oodA4^_nj^T@3o`00o`?oool000Co<S;<o`00oom4A;[ogMdQ2_l0
0?l2oooo00go003o00?o<S;<oooo0?mgMhL04Ol00?l01?nj^TCoool0oooo0?ooo`02o`00o`?oool0
2?l00?l2oooo0003onk^4?l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Jo`00o`04oeEEZOoo
o`3oool0omgM8@?o003o00Coool0o`00ool00?ooEEFY0_ooo`001_o^kQ3o003oo`00ool00?ooool0
ob4Qg@Wo003o0_ooo`0>o`00o`03ohN7Moooo`3oEEFY00oo003o00GoZJUEoooo0?ooo`3oool0ojVY
E@02o`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00o`7ooooo002Jo`00o`04ojVYEOooo`3o
ool0ogMgQ`?o003o00CoZJUEoeEEZOl00?ooZJUE0_ooo`001_nHV6Ko003oo`00ool00?ooZJUEogMg
Q`Wo003o0_ooo`0?o`00o`03onk^4?ooo`3o8B7M00co003o00?o<S;<olc<<_ooo`000oooo`000olQ
8Mgo003oo`00o`03oooo00So003o0oooo`07o`00o`;oool0VOl00?l1ooooo`00V_l00?l3oooo0007
ob4QgOl00?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l00?oo003oo`00oomEEJWogMdQ
2Ol00?l2oooo00oo003o00?oMgN7oooo0?o<c3802Ol00?l00om4A;[oMgN7omgM8@05oooo0004ofIV
V?l00?oo003oo`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00o`7ooooo002Io`00o`04oeEE
ZOooo`3oool0omgM8@Go003o00Gok^h@oeEEZOooo`3oool0onk^4005o`00o`03oooo0?lQ8Mgo003o
00Oo003o0_ooo`0?o`00o`04ob4QgOooo`3oool0oeEEZ@Go003o00?o<S;<oooo0?ooo`001oooo`00
0omVIYSo003oo`00o`02o`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00o`7ooooo002Io`00
o`04ojVYEOooo`3oool0ogMgQ`Go003o00Go^[Y4onk^4?ooo`3oool0ohN7M`05o`00o`03ojVYEOmg
MhOo003o00Oo003o0_ooo`0@o`00o`;oool000?o^[Y4o`00ool00?l00ol00?l00olQ8Mgoool0oooo
0005oooo0003ojVYEOlQ8Mgo003o00Co003o00Coc<`boooo0?ooo`3o<S;<1_l00?l01?lQ8Mgoool0
oooo0?o<c387o`00o`;oool0VOl00?l1ooooo`00V?l00?l01Ol@4>koool0oooo0?ooo`3o8B7M00Go
003o00GoIVJHoooo0?ooo`3oool0ob4Qg@05o`00o`03oeEEZOoMgB7o003o00Oo003o0_ooo`07o`00
o`03okZjA?lQ8Mgo003o00Ko003o0oooo`06o`00o`07ojVYEOooo`3ok^h@olc<<_n7QgOoEEFYoa0@
kP07o`00o`04oiRHI_ooo`3oool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oV9QV1ol00?l2oooo09Wo
003o0Oooool009So003o00CoIVJHoooo0?ooo`3ogMdQ1_l00?l01?mVIYSoool0oooo0?oMgB47o`00
o`03oooo0?lQ8Mgo003o00Ko003o0_ooo`07o`00o`03okZjA?nHV6Ko003o00Go003o00CoEEFYoooo
0?ooo`3oool01_l00?l00olQ8Mgok^h@o`00o`0;o`00o`04oeEEZOooo`3oool0ogMgQ`Ko003o00Co
IVJHoooo0?ooo`3oEEFY1ol00?l2oooo09Wo003o0Oooool009So003o00Coc<`boooo0?ooo`3oMgN7
1_l00?l01?nj^TCoool0oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o0_ooo`07o`00o`03
ofIVV?ooo`3o<S;<00Go003o00Coc<`boooo0?ooo`3oool01ol00?l00oo<c3;oEEFYo`00o`0;o`00
o`;oool000?oZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^4008o`00o`;oool0VOl00?l1oooo
o`00Uol00?l01OlQ8Mgoool0oooo0?ooo`3o8B7M00Go003o00Go413^oooo0?ooo`3oool0ob4Qg@07
o`00o`03oeEEZOoMgB7o003o00Ko003o0_ooo`07o`00o`08oa0@k_ooo`3oool0ofIVV?l@4>ko003o
oc8bc?o<c383oooo0003okZjA?l00?oo003o00Go003o00?oA4Bjolc<<_l00?l02ol00?l01?n7QgOo
ool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV0So003o0_ooo`2Io`00o`7ooooo002Go`00
o`04ojVYEOooo`3oool0omgM8@Ko003o00CoMgN7oooo0?ooo`3ogMdQ2Ol00?l00oooo`3o8B7Mo`00
o`05o`00o`;oool02?l00?l00omVIYSoool0oooo0007oooo0003oc8bc?l00?oo003o00Ko003o00?o
c<`boooo0?ooo`001Oooo`000oo<c3;o003oo`00o`03o`00o`03omgM8Oooo`3oQhMg00Co003o00?o
QhMgoooo0?o<c3802Ol00?l2oooo09Wo003o0Oooool009Go003o00?o8B7MohN7Moooo`000_ooo`00
0oo^kQ3o<S;<o`00o`03o`00o`06oeEEZOooo`3oool0oooo0?o^kQ3o<S;<1_l00?l01_lQ8MgoQhMg
oooo0?o^kQ3oEEFYoa0@kPCo003o0_ooo`09o`00o`03ohN7Moooo`3oool000Goool000?oIVJHo`00
ool00?l01ol00?l00omVIYSoool0oooo0006oooo0003ob4QgOl00?oo003o00;o003o00Co413^omgM
8Oooo`3oMgN70_l@4>h01?mgMhOoool0omgM8Ol@4>h9o`00o`;oool0VOl00?l1ooooo`00U?l00?l0
0om4A;[oool0oooo0007oooo0003ohN7Moooo`3oool000Ooool00_l00?l00on7QgOoool0oooo0005
oooo0004odA4^_l00?oo003oo`00o`;oool000?oMgN7o`00ool00?l01ol00?l00om4A;[o^[Y4oooo
0002oooo0003ojVYEOlb</co003o00[o003o00?ok^h@oooo0?ooo`001Oooo`000omgMhOo003oo`00
o`03o`00o`03oa0@k_n7QgOogMdQ00;oool000?ogMdQohN7Mol00?l02Ol00?l00omgMhOoool0oooo
002Io`00o`7ooooo002fo`00o`Ooool07_l00?l00omgMhOogMdQo`00o`0Ao`00o`Ooool0VOl00?l1
ooooo`00g?l00?l00olQ8Mgo003oo`00o`2`o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(275) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.985 .015 .985 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.963 .037 .963 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.9 .1 .9 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.901 .099 .901 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.973 .027 .973 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.93 .07 .93 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.91 .09 .91 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.786 .214 .786 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.889 .111 .889 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.941 .059 .941 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.789 .211 .789 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.937 .063 .937 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.533 .467 .533 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.443 .557 .443 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.807 .193 .807 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.901 .099 .901 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.923 .077 .923 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.725 .275 .725 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.625 .375 .625 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.749 .251 .749 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.893 .107 .893 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.984 .016 .984 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.836 .164 .836 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.95 .05 .95 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.35 .65 .35 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.96 .04 .96 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.295 .705 .295 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.339 .661 .339 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.503 .497 .503 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.191 .809 .191 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.798 .202 .798 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.119 .881 .119 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.338 .662 .338 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.947 .053 .947 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.525 .475 .525 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.795 .205 .795 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.514 .486 .514 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.236 .764 .236 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.123 .877 .123 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.104 .896 .104 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.645 .355 .645 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.801 .199 .801 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.844 .156 .844 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.897 .103 .897 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.227 .773 .227 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.105 .895 .105 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.065 .935 .065 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.134 .866 .134 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.23 .77 .23 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.923 .077 .923 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.972 .028 .972 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.781 .219 .781 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.065 .935 .065 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.935 .065 .935 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.533 .467 .533 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.713 .287 .713 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.304 .696 .304 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.423 .577 .423 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.97 .03 .97 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.661 .339 .661 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.108 .892 .108 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.979 .021 .979 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.608 .392 .608 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.092 .908 .092 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.049 .951 .049 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.858 .142 .858 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.89 .11 .89 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.15 .85 .15 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.165 .835 .165 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.739 .261 .739 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.931 .069 .931 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.066 .934 .066 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.043 .957 .043 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.081 .919 .081 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.481 .519 .481 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.554 .446 .554 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.734 .266 .734 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.327 .673 .327 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.066 .934 .066 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.985 .015 .985 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.963 .037 .963 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.05 .95 .05 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.309 .691 .309 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.807 .193 .807 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.944 .056 .944 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.2 .8 .2 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.693 .307 .693 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.161 .839 .161 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.979 .021 .979 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.917 .083 .917 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.157 .843 .157 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.354 .646 .354 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.791 .209 .791 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.951 .049 .951 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.943 .057 .943 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.85 .15 .85 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.822 .178 .822 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.828 .172 .828 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.93 .07 .93 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.836 .164 .836 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.926 .074 .926 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.929 .071 .929 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.98 .02 .98 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.957 .043 .957 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.977 .023 .977 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?l000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003oo0?loo`3o?ol0oco
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ol0ocoo0?l00Ko
o0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ol0oco
o0?l00_oo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooh1oP00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooP7n0;o00003oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooh
1oP2o`0000_ooP7n00?o0000oo`3o?ol0o`04Ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;on0Oh00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooP7n003o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`05?ol0o`00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oh1oP2o`0000KooP7n00?o0000oo`3
o?ol0o`05Ool0o`00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oh1oP00ol0003ooP7nooh1oP03ooh1oP03o`000?ol0oco
o0?l01Koo0?l00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom@[eo`000?ob3O;o0000onDJiOl0000JooP7n0;o00000_on0Oh00ol0003oo0?l
oo`3o00Hoo`3o003o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om@[e00Co0000oo8=l_ob3O;o00000_oU6^D00ol0003on0OhooP7n00IooP7
n003o`000?on0Oko000001_oo0?l00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005ooD:m@05o`000?ob3O;olPgboo8=
l_l000000ooU6^D00ol0003on0OhooP7n00IooP7n003o`000?ol0ocoo0?l01[oo0?l00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oe2_D01Ol0003olPgboo8=l_ob3O;o000000CoiA[U00?o0000ooP7
n?oh1oP06?oh1oP00ol0003oo0?loo`3o00Ioo`3o003o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om@[e00?o0000oo8=l_ob
3O800_ob3O800ol0003oiA[UonDJi@03onDJi@03o`000?oh1oSon0Oh01Oon0Oh00?o0000oo`3o?ol
0o`06Ool0o`00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooe2_D00ol0003olPgboo8=lP02oo8=lP03o`000?oU6^GoiA[U00Co
iA[U00?o0000ooP7n?oh1oP05ooh1oP00ol0003oo0?loo`3o00Hoo`3o003o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?ooD:m@03o`00
0?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D01OoU6^D00ol0003on0OhooP7n00FooP7n003o`00
0?ol0ocoo0?l01Ooo0?l00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000AooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D01_oU
6^D2o`0001Gon0Oh0ol0000Hoo`3o003o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
ooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D02?oU6^D00ol0003on0OhooP7n00@
ooP7n0;o00000ooS7><00ol0003oo0?loo`3o00Doo`3o003o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000ooD:mOoe2_D04_oe2_D00ol0003olPgboo8=lP05oo8=lP03o`000?oU6^GoiA[U
00WoiA[U00?o0000ooP7n?oh1oP03Ooh1oP2o`0000KohacS0_l0000Doo`3o003o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e01;om@[e00?o0000oo8=l_ob
3O801Oob3O800ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00[on0Oh0_l0000:on<Lh`03
o`000?ol0ocoo0?l017oo0?l00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om@[eooD:m@0@ooD:m@03o`000?ob3O;olPgb00Ko
lPgb00?o0000onDJiOoU6^D02ooU6^D00ol0003on0OhooP7n008ooP7n003o`000?oS7>?ohacS00_o
hacS0_l0000@oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O80
1oob3O800ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l0000@on<Lh`03o`00
0?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O801oob3O800ol0003oiA[UonDJ
i@0=onDJi@03o`000?oh1oSon0Oh00;on0Oh0_l0000Con<Lh`;o00003?ol0o`00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oe2_Go
m@[e00kom@[e00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJi@0>onDJi@04o`000?oh1oSo
0000o`0001OohacS00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00Loo`3o003o`000?oj
1O[onPGj00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oe2_Go
m@[e00com@[e00?o0000oo8=l_ob3O802Oob3O800ol0003oiA[UonDJi@0?onDJi@03o`000?oS7>?o
hacS01SohacS0_l00009oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000ooX5n_oj1OX01?oj1OX4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>ooD:m@03o`000?ob3O;olPgb
00WolPgb00?o0000onDJiOoU6^D03ooU6^D00ol0003ohacSon<Lh`0Jon<Lh`03o`000?ol0ocoo0?l
00Coo0?l0ol0000Loo`3o003o`000?oj1O[onPGj00WonPGj0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o`3o3ol0o`o`0000com@[e00?o0000oo8=l_ob3O802_ob3O800ol0003oiA[UonDJi@0?onDJ
i@03o`000?oS7>?ohacS01_ohacS0_l00003oo`3o004o`000?oa3_7ol@kaoo4>l@?o00006?ol0o`0
0ol0003onPGjooX5nP0=ooX5nP?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00;ol0o`00?o0000ooD:mOoe2_D02Ooe2_D00ol0003olPgboo8=lP0:oo8=lP03o`000?oU6^GoiA[U
00koiA[U00?o0000on<LhooS7><07_oS7><00ol0003oo0?lo`000007oo4>l@?o00005?ol0o`00ol0
003onPGjooX5nP0AooX5nP;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o`3o000ol0003om@[eooD:m@07ooD:m@03
o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003ohacSon<Lh`0Oon<Lh`03
o`000?oa3_7ol@ka00Wol@ka0ol0000@oo`3o003o`000?oj1O[onPGj01?onPGj00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol0o`
oo0?l007oo0?l003o`000?oe2_Gom@[e00Gom@[e00?o0000oo8=l_ob3O803?ob3O800ol0003oiA[U
onDJi@0>onDJi@03o`000?oS7>?ohacS01oohacS00?o0000oo4>lOoa3_403?oa3_43o`0000goo0?l
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ol0o`00?o0000ooD:mOoe2_D01?oe
2_D00ol0003olPgboo8=lP0<oo8=lP03o`000?oU6^GoiA[U00koiA[U00?o0000on<LhooS7><07_oS
7><00ol0003ol@kaoo4>l@0@oo4>l@?o00002Ool0o`00ol0003onPGjooX5nP0FooX5nPOo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000oo0?l?o`3o003?o`3o000ol0003om@[eooD:m@02ooD:m@03o`000?ob
3O;olPgb00golPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003ohacSon<Lh`0Non<Lh`03o`000?oa
3_7ol@ka01?ol@ka0ol00005oo`3o003o`000?oj1O[onPGj01OonPGj00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00kol0o`00Go0000
ooD:mOoe2_Gom@[eo`00000?oo8=lP03o`000?oU6^GoiA[U00goiA[U00?o0000on<LhooS7><07ooS
7><00ol0003ol@kaoo4>l@0Foo4>l@?o000000?oo0?lo`000?oj1OX06?oj1OX00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Boo0?l003o`000?oe2_Go0000013olPgb00?o0000onDJiOoU6^D02ooU6^D3
o`00023ohacS00?o0000oo4>lOoa3_406_oa3_400ol0003onPGjooX5nP0HooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`01?ol0o`00?o0000oo8=
l_ob3O803oob3O800ol0003oiA[UonDJi@07onDJi@Co00000_o7><L00ol0003ohacSon<Lh`0Non<L
h`03o`000?oa3_7ol@ka01[ol@ka00?o0000ooX5n_oj1OX05ooj1OX00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
l0o`00?o0000oo8=l_ob3O803oob3O800ol0003oiA[UonDJi@03onDJi@Co00001oo7><L00ol0003o
hacSon<Lh`0Lon<Lh`03o`000?oa3_7ol@ka01col@ka00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000oo0?l?o`3o005oo`3o000ol0003olPgboo8=lP0>oo8=lP03o`00
0?oU6^Go000000?o00003?o7><L00ol0003ohacSon<Lh`0Kon<Lh`03o`000?oa3_7ol@ka01col@ka
00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o`
3o05o`0000_olPgb0ol0000AolLha`03o`000?oS7>?ohacS01[ohacS00?o0000oo4>lOoa3_407Ooa
3_400ol0003onPGjooX5nP0CooX5nP03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o`3o3ol0o`01Wol0o`00?o0000
ol`cc?o<<l`00_o<<l`7o`0000?olPgb00?o0000olLhaoo7><L04oo7><L3o`0001OohacS0_l0000P
oo4>l@03o`000?oj1O[onPGj01?onPGj00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000oo0?l?o`3o006?o`3o000ol0
003oc3?<ol`cc00:ol`cc0?o00005_o7><L00ol0003oVfBKoi]TV`05o`00013ohacS0_l000000onk
A;_o0000oo4>l@0Ooo4>l@03o`000?oj1O[onPGj01;onPGj00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000oo0?l?o`3o005_o`3o000ol0003oc3?<ol`cc00=ol`cc003
o`000?o7><OoacS701?oacS700?o0000oi]TVonKI9/01_nKI9/4o`0000_ohacS00?o0000ok]4^onk
A;/00_nkA;/00ol0003ol@kaoo4>l@0Noo4>l@03o`000?oj1O[onPGj013onPGj00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ol0o`oo0?l00Doo0?l003o`000?o<<lcoc3?<00ooc3?<
00?o0000olLhaoo7><L04_o7><L00ol0003oVfBKoi]TV`0:oi]TV`Go00001?oS7><2o`0000Go^dBk
00?o0000oo4>lOoa3_407_oa3_400ol0003onPGjooX5nP0@ooX5nP03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o`
3o3ol0o`01Col0o`00?o0000ol`cc?o<<l`03oo<<l`00ol0003oacS7olLha`0BolLha`03o`000?nK
I9_oVfBK00ooVfBK1?l00008ok]4^`03o`000?oa3_7ol@ka01kol@ka00?o0000ooX5n_oj1OX03_oj
1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
oo0?l?o`3o004_o`3o000ol0003oc3?<ol`cc00@ol`cc003o`000?o7><OoacS7017oacS700?o0000
oi]TVonKI9/04OnKI9/00ol0003oNhAko`000009ok]4^`03o`000?oa3_7ol@ka01gol@ka00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000oo0?l?o`3o003_o`3o03o`0001Coc3?<00?o0000olLhaoo7><L04?o7><L00ol0
003oVfBKoi]TV`0@oi]TV`04o`000?mkQ7_oNhAko`0000Wo^dBk00?o0000oo4>lOoa3_407_oa3_40
0ol0003onPGjooX5nP0<ooX5nP03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000oo0?l?o`3o002_o`3o04o`0000;ocS7>00?o0000ol`c
c?o<<l`04_o<<l`00ol0003oacS7olLha`0@olLha`03o`000?nKI9_oVfBK00ooVfBK00Go0000og^4
NomkQ7_oNhAko`00000:ok]4^`03o`000?oa3_7ol@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000oo0?
l?o`3o001Oo`3o04o`0000OocS7>00?o0000ol`cc?o<<l`04Oo<<l`00ol0003oacS7olLha`0?olLh
a`03o`000?nKI9_oVfBK013oVfBK00Go0000og^4NomkQ7_oNhAko`00000:ok]4^`03o`000?oa3_7o
l@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o`3o3o
l0o`00Co00002oo><Lh00ol0003oc3?<ol`cc00Bol`cc003o`000?o7><OoacS700koacS700?o0000
oi]TVonKI9/03onKI9/00ol0003oNhAkog^4N`02og^4N`03o`000?nkA;_o^dBk00Wo^dBk00?o0000
oo4>lOoa3_407?oa3_43o`0000[onPGj00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000onhAk_l0003o00003oo><Lh00ol0003oc3?<ol`cc00Aol`cc003o`000?n3
O8?o000000ooacS700?o0000oi]TVonKI9/03_nKI9/00ol0003oNhAkog^4N`03og^4N`03o`000?nk
A;_o^dBk00Wo^dBk00?o0000oo4>lOoa3_406Ooa3_43o`0000?okQ7^00?o0000ooX5n_oj1OX01ooj
1OX00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o^4NkokQ7^o`00017ocS7>00?o
0000ol`cc?o<<l`03oo<<l`01Ol0003oPgb3oh=lPon3O8?o000000[oacS71?l0000Aoi]TV`03o`00
0?mkQ7_oNhAk00?oNhAk00?o0000ok]4^onkA;/02_nkA;/00ol0003ol@kaoo4>l@0Foo4>l@;o0000
1oo^4Nh00ol0003onPGjooX5nP05ooX5nP03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003okQ7^onhAkP02onhAkP03o`000?o><LkocS7>00kocS7>00?o
0000ol`cc?o<<l`03_o<<l`00ol0003oPgb3oh=lP`03oh=lP`04o`000?o7><OoacS7olLha`Ko0000
0on8MhP00ol0003oVfBKoi]TV`0>oi]TV`03o`000?mkQ7_oNhAk00CoNhAk00?o0000ok]4^onkA;/0
2_nkA;/00ol0003ol@kaoo4>l@0Coo4>l@?o00002_o^4Nh00ol0003onPGjooX5nP03ooX5nP03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o^
4NkokQ7^00?okQ7^00?o0000olhac_o><Lh03_o><Lh00ol0003oc3?<ol`cc00=ol`cc003o`000?n3
O8?oPgb300GoPgb30ol0000:ohQgR003o`000?nKI9_oVfBK00coVfBK00?o0000og^4NomkQ7/01Omk
Q7/00ol0003o^dBkok]4^`0;ok]4^`03o`000?oa3_7ol@ka013ol@ka0_l0000>onhAkP03o`000?oj
1O[onPGj00;onPGj00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o^4NkokQ7^00CokQ7^00?o0000olhac_o><Lh03oo><Lh00ol0003oc3?<ol`cc00;
ol`cc003o`000?n3O8?oPgb300KoPgb300?o0000ohQgR?n8MhP02on8MhP00ol0003oVfBKoi]TV`0;
oi]TV`03o`000?mkQ7_oNhAk00GoNhAk00?o0000ok]4^onkA;/03?nkA;/00ol0003ol@kaoo4>l@0<
oo4>l@?o00004Oo^4Nh5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o^4NkokQ7^
00KokQ7^00?o0000olhac_o><Lh03_o><Lh00ol0003oc3?<ol`cc00:ol`cc003o`000?n3O8?oPgb3
00OoPgb300?o0000ohQgR?n8MhP02on8MhP00ol0003oVfBKoi]TV`0:oi]TV`03o`000?mkQ7_oNhAk
00KoNhAk00?o0000ok]4^onkA;/03?nkA;/00ol0003ol@kaoo4>l@0:oo4>l@;o00005?o^4Nh00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003okQ7^onhAkP07onhA
kP03o`000?o><LkocS7>00kocS7>00?o0000ol`cc?o<<l`02Oo<<l`00ol0003oPgb3oh=lP`08oh=l
P`03o`000?n8MhSoR7N800coR7N800?o0000oi]TVonKI9/02?nKI9/00ol0003oNhAkog^4N`07og^4
N`03o`000?nkA;_o^dBk00go^dBk1Ol00004oo4>l@?o00005Oo^4Nh00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okQ7^onhAkP08onhA
kP03o`000?o><LkocS7>00oocS7>00?o0000ol`cc?o<<l`01oo<<l`00ol0003oPgb3oh=lP`09oh=l
P`03o`000?n8MhSoR7N800coR7N80ol00008oi]TV`03o`000?mkQ7_oNhAk00OoNhAk00?o0000ok]4
^onkA;/03OnkA;/00ol0003obSG:olXebP02olXebPCo00006?o^4Nh00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o^4NkokQ7^
00[okQ7^00?o0000olhac_o><Lh03_o><Lh00ol0003oc3?<ol`cc006ol`cc003o`000?n3O8?oPgb3
00[oPgb300?o0000ohQgR?n8MhP02_n8MhP2o`0000?oCK9=00?o0000oi]TVonKI9/01?nKI9/00ol0
003oNhAkog^4N`08og^4N`03o`000?nkA;_o^dBk00co^dBk00?o0000olXeb_o:=LX01_o:=LX00ol0
003okQ7^onhAkP0EonhAkP03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000onhAk_o^4Nh02oo^4Nh00ol0003o
cS7>olhacP0>olhacP03o`000?o<<lcoc3?<00Goc3?<00?o0000oh=lPon3O8<02on3O8<00ol0003o
R7N8ohQgR008ohQgR0;o00001_m=/Td00ol0003oVfBKoi]TV`02oi]TV`03o`000?mkQ7_oNhAk00Wo
NhAk00?o0000ok]4^onkA;/03?nkA;/00ol0003obSG:olXebP07olXebP03o`000?o^4NkokQ7^01Co
kQ7^00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o^4NkokQ7^00gokQ7^00?o0000olhac_o><Lh03_o><Lh00ol0003oc3?<ol`cc003ol`cc003o`00
0?n3O8?oPgb300coPgb300?o0000ohQgR?n8MhP01_n8MhP2o`0000WoCK9=00Go0000oi]TVonKI9_o
VfBKo`00000;og^4N`03o`000?nkA;_o^dBk00co^dBk00?o0000olXeb_o:=LX01oo:=LX00ol0003o
kQ7^onhAkP0ConhAkP03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o^4NkokQ7^00ko
kQ7^00?o0000olhac_o><Lh03_o><Lh00ol0003oc3?<ol`cc002ol`cc003o`000?n3O8?oPgb300go
Pgb300?o0000ohQgR?n8MhP01?n8MhP2o`0000coCK9=00?o0000oi]TVol000003?mkQ7/00ol0003o
^dBkok]4^`0;ok]4^`03o`000?o:=L[obSG:00WobSG:00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003okQ7^onhAkP0?onhAkP03o`000?o><LkocS7>00kocS7>00Go0000ol`cc?o<<lco
c3?<o`00000@oh=lP`03o`000?n8MhSoR7N800;oR7N80_l0000?odfbC@03o`000?mkQ7_oNhAk00_o
NhAk00?o0000ok]4^onkA;/02onkA;/00ol0003obSG:olXebP09olXebP03o`000?o^4NkokQ7^017o
kQ7^00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003ocS7>
olhacP0>olhacPCo00004?n3O8<00ol0003oR7N8ohQgR002o`00017oCK9=00?o0000og^4NomkQ7/0
2omkQ7/00ol0003o^dBkok]4^`0:ok]4^`03o`000?o:=L[obSG:00_obSG:00?o0000onhAk_o^4Nh0
3oo^4Nh00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ool0o`00ol0003onPGjooX5nP03ooX5nP03o`000?o^
4NkokQ7^01;okQ7^00?o0000olhac_o><Lh03Oo><Lh00ol0003oP7n0oh1oP002oh1oP0;o00003_n3
O8<3o`0001?oCK9=00?o0000og^4NomkQ7/02omkQ7/00ol0003o^dBkok]4^`0:ok]4^`03o`000?o:
=L[obSG:00_obSG:00?o0000onhAk_o^4Nh03oo^4Nh00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ol0ocoo0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`00000EonhAkP03o`000?o>
<LkocS7>00cocS7>00?o0000oh1oP?n0Oh001On0Oh02o`0000coPgb300?o0000odfbCOm=/Td05?m=
/Td00ol0003oNhAkog^4N`0:og^4N`03o`000?nkA;_o^dBk00[o^dBk00?o0000olXeb_o:=LX03?o:
=LX00ol0003okQ7^onhAkP0=onhAkP03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Soo0?l00?o0000
ooX5n_l000005oo^4Nh00ol0003ocS7>olhacP0:olhacP03o`000?n0Oh3oP7n000SoP7n000?o0000
oh=lPon3O8<02?n3O8<3o`0001GoCK9=0_l0000;og^4N`03o`000?nkA;_o^dBk00Wo^dBk00?o0000
olXeb_o:=LX03_o:=LX00ol0003okQ7^onhAkP0<onhAkP03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_oo0?l00?o0000onhAk_o^4Nh05_o^4Nh00ol0003ocS7>olhacP09olhacP03o`000?n0Oh3oP7n0
00[oP7n00_l00005oh=lP`?o00000oljaCX00ol0003oCK9=odfbC@0AodfbC@03o`000?lVfBKo9]TV
00;o00002OmkQ7/00ol0003o^dBkok]4^`09ok]4^`03o`000?o:=L[obSG:00kobSG:00?o0000onhA
k_o^4Nh02oo^4Nh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo`3o003o`000?o^4NkokQ7^01Ko
kQ7^00?o0000olhac_o><Lh00oo><Lh6o`0000ooP7n00_l000000on3O8?o0000o`000007oc[5>P;o
00004?m=/Td00ol0003o9]TVobKI9P03obKI9P?o00001_mkQ7/00ol0003o^dBkok]4^`09ok]4^`03
o`000?o:=L[obSG:00oobSG:00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ol0o`00ol0003okQ7^
onhAkP0FonhAkPGo00001OniA[T00ol0003oP7n0oh1oP00?oh1oP003o`000?ljaC[o>/Dj00Wo>/Dj
00?o0000odfbCOm=/Td03?m=/Td00ol0003o9]TVobKI9P07obKI9P;o00000_mkQ7/>o`0001;obSG:
00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh05Oo^
4Nh00ol0003o^DJiokU6^@09okU6^@03o`000?n0Oh3oP7n000koP7n000?o0000oc[5>_ljaCX02_lj
aCX2o`0000_oCK9=00?o0000obKI9_lVfBH02_lVfBH2o`0000goDjaC00?o0000olXeb_o:=LX04Oo:
=LX00ol0003okQ7^onhAkP07onhAkP03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ol0o`00ol0003okQ7^onhAkP0ConhAkP03o`000?niA[Wo^DJi00[o^DJi00?o
0000oh1oP?n0Oh003_n0Oh000ol0003o>/Djoc[5>P0<oc[5>P03o`000?m=/TgoCK9=00OoCK9=00?o
0000obKI9_lVfBH02olVfBH00ol0003oDjaCoe>/D`0=oe>/D`03o`000?o:=L[obSG:013obSG:00?o
0000onhAk_o^4Nh01oo^4Nh00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo0?loo`3o00Doo`3o003o`000?o^4NkokQ7^01;okQ7^00?o0000okU6^OniA[T02oni
A[T00ol0003oP7n0oh1oP00>oh1oP003o`000?ljaC[o>/Dj00go>/Dj00?o0000odfbCOm=/Td01?m=
/Td2o`0000ko9]TV00?o0000oe>/DomC[5<03OmC[5<00ol0003obSG:olXebP0@olXebPCo00001Oo^
4Nh00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l01Goo0?l5?l0000?okU6^@03o`000?n0Oh3oP7n000coP7n000?o0000occ3??l000003olj
aCX2o`0000?oCK9=00Co0000oaOX5olGj1Oo00003OlVfBH00ol0003oDjaCoe>/D`0>oe>/D`03o`00
0?o:=L[obSG:00cobSG:0ol00004om8]dP?o00000_o^4Nh00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`05Ool0o`00ol0003oj1OXonPG
j00@onPGj003o`000?niA[Wo^DJi00go^DJi00?o0000oh1oP?n0Oh002on0Oh001?l0003o?<<locc3
??l0000Aoc[5>P03o`000?m=/Tgo000000Co5nPG00?o0000obKI9_lVfBH02_lVfBH00ol0003oDjaC
oe>/D`0>oe>/D`03o`000?o:=L[obSG:00WobSG:0ol0000:om8]dP;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo0?loo`3o00Eoo`3o003o`000?oX5nSoj1OX013oj1OX00?o0000okU6^OniA[T03Oni
A[T00ol0003oP7n0oh1oP00:oh1oP003o`000?ll`cco?<<l00;o?<<l00?o0000oc[5>_ljaCX03olj
aCX00ol0003o5nPGoaOX5`04oaOX5`03o`000?lVfBKo9]TV00Wo9]TV00?o0000oe>/DomC[5<03_mC
[5<00ol0003obSG:olXebP06olXebP?o00003_oB;M800ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ol0ocoo0?l01Goo0?l00?o0000
onPGj?oX5nP04_oX5nP00ol0003o^DJiokU6^@0=okU6^@03o`000?n0Oh3oP7n000WoP7n000?o0000
occ3??ll`c`00_ll`c`00ol0003o>/Djoc[5>P0?oc[5>P03o`000?lGj1Oo5nPG00Go5nPG00?o0000
obKI9_lVfBH02?lVfBH00ol0003oDjaCoe>/D`0?oe>/D`03o`000?o:=L[obSG:00;obSG:0ol0000B
om8]dP03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo0?loo`3o00Coo`3o0?o00005?oX5nP00ol0003o^DJiokU6^@0=okU6^@03o`000?n0Oh3oP7n0
00SoP7n000?o0000occ3??ll`c`01?ll`c`00ol0003o>/Djoc[5>P0>oc[5>P03o`000?lGj1Oo5nPG
00Ko5nPG00?o0000obKI9_lVfBH01olVfBH00ol0003oDjaCoe>/D`0?oe>/D`03o`000?o:=L[o0000
00;o00005OoB;M800ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00ooo0?l1?l00002ooH9mP03o`000?oX5nSoj1OX01;o
j1OX00?o0000okU6^OniA[T03OniA[T00ol0003oP7n0oh1oP007oh1oP003o`000?ll`cco?<<l00Go
?<<l00?o0000oc[5>_ljaCX03OljaCX00ol0003o5nPGoaOX5`08oaOX5`03o`000?lVfBKo9]TV00Ko
9]TV00?o0000oe>/DomC[5<04?mC[5<00ol0003odRgBom8]dP0Fom8]dP03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02ool0o`4o`0000KomPWf
00?o0000onPGj?oX5nP04ooX5nP00ol0003o^DJiokU6^@0=okU6^@03o`000?n0Oh3oP7n000GoP7n0
00?o0000occ3??ll`c`01oll`c`00ol0003o>/Djoc[5>P0<oc[5>P03o`000?lGj1Oo5nPG00Wo5nPG
00?o0000obKI9_lVfBH01OlVfBH00ol0003oDjaCoe>/D`0@oe>/D`03o`000?oB;M;odRgB01OodRgB
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01ool
0o`4o`0000[omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o^DJiokU6^@0=okU6^@03o`000?n0
Oh3oP7n000CoP7n000?o0000occ3??ll`c`02?ll`c`00ol0003o>/Djoc[5>P0<oc[5>P03o`000?lG
j1Oo5nPG00[o5nPG00?o0000obKI9_lVfBH01?lVfBH00ol0003oDjaCoe>/D`0@oe>/D`03o`000?oB
;M;odRgB01OodRgB00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo0?loo`3o004oo`3o0Co00003_of2OH00ol0003oj1OXonPGj00ConPGj003o`000?niA[Wo
^DJi00go^DJi00?o0000oh1oP?n0Oh001?n0Oh000ol0003o?<<locc3?009occ3?003o`000?ljaC[o
>/Dj00_o>/Dj00?o0000oaOX5olGj1L02olGj1L00ol0003o9]TVobKI9P03obKI9P03o`000?mC[5?o
DjaC013oDjaC00?o0000om8]d_oB;M805ooB;M800ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo0?loo`3o004o`0001;omPWf00?o0000onPGj?oX5nP04ooX5nP00ol0
003o^DJiokU6^@0>okU6^@03o`000?n0Oh3oP7n000;oP7n000?o0000occ3??ll`c`02_ll`c`00ol0
003o>/Djoc[5>P0:oc[5>P03o`000?lGj1Oo5nPG00go5nPG00?o0000obKI9_lVfBH00_lVfBH00ol0
003oDjaCoe>/D`0@oe>/D`03o`000?oB;M;odRgB01SodRgB00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oX5nSoj1OX01?oj1OX00?o0000okU6^OniA[T03?niA[T4o`000003oh1oP?l0003o?<<l00go
?<<l00?o0000oc[5>_ljaCX02OljaCX00ol0003o5nPGoaOX5`0>oaOX5`05o`000?lVfBKo9]TVobKI
9_l000004_mC[5<00ol0003odRgBom8]dP0Hom8]dP?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oX5nSoj1OX
01?oj1OX00?o0000okU6^OniA[T02oniA[T00ol0003oBkA;od^dB`02od^dB`;o00003_ll`c`00ol0
003o>/Djoc[5>P09oc[5>P03o`000?lGj1Oo5nPG00oo5nPG00Co0000obKI9_lVfBKo00004_mC[5<0
0ol0003odRgBom8]dP0Hom8]dP03o`000?o]4^gokA;]00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onPGj?oX5nP04ooX5nP00ol0003o^DJiokU6^@0:
okU6^@03o`000?m;]4_oBkA;00GoBkA;00?o0000occ3??ll`c`03?ll`c`00ol0003o>/Djoc[5>P08
oc[5>P03o`000?lGj1Oo5nPG00oo5nPG1Ol0000Aoe>/D`03o`000?oB;M;odRgB01OodRgB00?o0000
ondBkOo]4^d01?o]4^d3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oX5nSoj1OX01?oj1OX00?o0000okU6^OniA[T02?niA[T2o`00
00WoBkA;00?o0000occ3??ll`c`02oll`c`00ol0003o>/Djoc[5>P07oc[5>P03o`000?lGj1Oo5nPG
00go5nPG0ol00005oa3_4003o`000?mC[5?oDjaC00koDjaC00?o0000om8]d_oB;M805_oB;M800ol0
003okA;]ondBk@08ondBk@?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonPGj003o`000?niA[Wo^DJi00Ko^DJi00?o0000od^dBom;
]4/02_m;]4/00ol0003o?<<locc3?00:occ3?1[o00002Ol@ka000ol0003oDjaCoe>/D`0<oe>/D`?o
00005_oB;M800ol0003okA;]ondBk@0<ondBk@?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oV6NH3o`0001;oj1OX00?o0000okU6^OniA[T01?niA[T2o`0000koBkA;
00?o0000occ3??ll`c`01oll`c`2o`0000[o6^DJ00?o0000o`cc3?l<l``03?l<l``00ol0003o4>l@
oa3_4008oa3_40;o00002_mC[5<2o`0000?o:MHY0_l0000Com8]dP03o`000?o]4^gokA;]013okA;]
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onHIiP;o00004?oX
5nP00ol0003o^DJiokU6^@03okU6^@03o`000?m;]4_oBkA;00ooBkA;00?o0000occ3??ll`c`01?ll
`c`2o`0000co6^DJ00?o0000o`cc3?l<l``03?l<l``00ol0003o4>l@oa3_400:oa3_4003o`000?mC
[5?oDjaC00GoDjaC0_l00007obWF:@03o`000?oB;M;odRgB00oodRgB00?o0000ondBkOo]4^d04Oo]
4^d01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onHIi_oV6NH01OoV6NH2o`0000ooj1OX00Go0000okU6^OniA[Wo^DJio`00000Cod^dB`03o`00
0?ll`cco?<<l00;o?<<l00?o0000oa[U6_lJiAX03OlJiAX00ol0003o3?<<o`cc300;o`cc3003o`00
0?l@ka3o4>l@00_o4>l@00?o0000oe>/DomC[5<00_mC[5<2o`0000[o:MHY0_l0000>om8]dP03o`00
0?o]4^gokA;]017okA;]00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onHIi_oV6NH01_oV6NH3o`0000_oj1OX1Ol0000Eod^dB`04o`00
0?ll`cco0000o`00013o6^DJ00?o0000o`cc3?l<l``02ol<l``00ol0003o4>l@oa3_400<oa3_4004
o`000?mC[5?o0000o`0000ko:MHY0_l0000;om8]dP03o`000?o]4^gokA;]017okA;]00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oV6NKoiQWV00WoiQWV0_l00008onPGj003o`000?nOGiooWenO00;oWenO00?o0000od^dBom;
]4/05?m;]4/00ol0003o6^DJoa[U6P0@oa[U6P03o`000?l<l`co3?<<00_o3?<<00?o0000oa3_4?l@
ka003Ol@ka000ol0003o:MHYobWF:@0@obWF:@03o`000?oB;M;odRgB00OodRgB00?o0000ondBkOo]
4^d04Oo]4^d00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oV6NKoiQWV00_oiQWV
0_l00005onPGj003o`000?nOGiooWenO00CoWenO00?o0000od^dBom;]4/04om;]4/00ol0003o6^DJ
oa[U6P0@oa[U6P03o`000?l<l`co3?<<00_o3?<<00?o0000oa3_4?l@ka003Ol@ka000ol0003o:MHY
obWF:@0AobWF:@;o00000ooB;M84o`0001?okA;]00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oV6NKoiQWV00goiQWV0ol000000ooX5nSo0000oimOW`07oimOW`03o`000?m;]4_oBkA;01;o
BkA;00?o0000oa[U6_lJiAX04?lJiAX00ol0003o3?<<o`cc300;o`cc3003o`000?l@ka3o4>l@00go
4>l@00?o0000obWF:OlYeRT04olYeRT3o`0000?oeRWF00?o0000ondBkOo]4^d04?o]4^d00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oV6NKoiQWV013oiQWV00?o0000oimOWonOGil0
2?nOGil00ol0003oBkA;od^dB`0Aod^dB`03o`000?lJiA[o6^DJ017o6^DJ00?o0000o`cc3?l<l``0
2_l<l``00ol0003o4>l@oa3_400<oa3_4003o`000?l<l`co000001Co:MHY00?o0000omHYe_oF:MH0
1?oF:MH00ol0003okA;]ondBk@0>ondBk@03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onHIi_oV6NH03ooV
6NH00ol0003oWenOoimOW`09oimOW`03o`000?m;]4_oBkA;013oBkA;00?o0000oa[U6_lJiAX04OlJ
iAX00ol0003o3?<<o`cc300:o`cc3003o`000?l@ka3o4>l@00_o4>l@00Co0000o`cc3?l<l`co0000
5?lYeRT00ol0003oeRWFomHYeP05omHYeP03o`000?o]4^gokA;]00cokA;]00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiQWVonHI
iP0?onHIiP03o`000?nOGiooWenO00[oWenO00?o0000od^dBom;]4/03_m;]4/00ol0003o6^DJo`00
000Boa[U6P03o`000?l<l`co3?<<00[o3?<<00?o0000oa3_4?l@ka002_l@ka000ol0003o3?<<o`cc
3002o`cc3003o`000?lYeRWo:MHY013o:MHY00?o0000omHYe_oF:MH01ooF:MH00ol0003okA;]ondB
k@0:ondBk@03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oV6NKoiQWV00ooiQWV00?o0000oimOWonOGil0
2onOGil00ol0003oBkA;od^dB`0<od^dB`05o`000?lJiA[o6^DJoa[U6_l000004OlJiAX00ol0003o
3?<<o`cc300:o`cc3003o`000?l@ka3o4>l@00Wo4>l@00?o0000o`cc3?l<l``00ol<l``00ol0003o
:MHYobWF:@0@obWF:@03o`000?oF:MKoeRWF00SoeRWF00?o0000ondBkOo]4^d02?o]4^d00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onHIi_oV6NH03_oV6NH00ol0003oWenOoimOW`0=oimOW`03o`00
0?m;]4_oBkA;00[oBkA;00?o0000oa[U6_lJiAX00olJiAX00ol0003o6^DJoa[U6P0?oa[U6P03o`00
0?l<l`co3?<<00Wo3?<<00?o0000oa3_4?l@ka002?l@ka000ol0003o3?<<o`cc3005o`cc3003o`00
0?lYeRWo:MHY00oo:MHY00?o0000omHYe_oF:MH02OoF:MH00ol0003okA;]ondBk@06ondBk@03o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiQWVonHIiP0>onHIiP03o`000?nO
GiooWenO00koWenO00?o0000od^dBom;]4/02?m;]4/00ol0003o6^DJoa[U6P05oa[U6P03o`000?lJ
iA[o6^DJ00ko6^DJ00?o0000o`cc3?l<l``02Ol<l``00ol0003o4>l@oa3_4007oa3_4003o`000?l<
l`co3?<<00Ko3?<<00?o0000obWF:OlYeRT03olYeRT00ol0003oeRWFomHYeP09omHYeP03o`000?o]
4^gokA;]00GokA;]00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiQWVonHIiP0=
onHIiP03o`000?nOGiooWenO00ooWenO00?o0000od^dBom;]4/01_m;]4/00ol0003o6^DJoa[U6P07
oa[U6P03o`000?lJiA[o6^DJ00go6^DJ00?o0000o`cc3?l<l``02Ol<l``00ol0003o4>l@oa3_4004
oa3_40?o00002_l<l``00ol0003o:MHYobWF:@0=obWF:@03o`000?oF:MKoeRWF00_oeRWF00?o0000
ondBkOo]4^d00oo]4^d00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oV6NKoiQWV
00goiQWV00?o0000oimOWonOGil04?nOGil00ol0003oBkA;od^dB`05od^dB`03o`000?lJiA[o6^DJ
00So6^DJ00?o0000oa[U6_lJiAX03?lJiAX00ol0003o3?<<o`cc3009o`cc3003o`000?l@ka3o0000
00Co00000_l;m0/00ol0003o3?<<o`cc3008o`cc3003o`000?lYeRWo:MHY00go:MHY00?o0000omHY
e_oF:MH03?oF:MH01Ol0003okA;]ondBkOo]4^go000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0
003oWenOoimOW`0AoimOW`03o`000?m;]4_oBkA;00?oBkA;00?o0000oa[U6_lJiAX02_lJiAX00ol0
003o6^DJoa[U6P0;oa[U6P03o`000?l<l`co3?<<00So3?<<0ol00008o`_d2`03o`000?l<l`co3?<<
00So3?<<00?o0000obWF:OlYeRT03?lYeRT00ol0003oeRWFomHYeP0=omHYeP03o`000?o]4^go0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oV6NKoiQWV00goiQWV00?o0000oimOWonOGil04_nOGil01Ol0
003oBkA;od^dBom;]4_o000000ko6^DJ00?o0000oa[U6_lJiAX02olJiAX00ol0003o3?<<o`cc3006
o`cc3003o`000?l;m0_o2o@;00Wo2o@;00?o0000o`cc3?l<l``02Ol<l``00ol0003o:MHYobWF:@0:
obWF:@03o`000?oF:MKoeRWF00ooeRWF00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0003oWenOoimOW`0CoimOW`03o`000?m;]4_o0000
013o6^DJ3_l00006o`cc30;o00003?l;m0/00ol0003o3?<<o`cc3009o`cc3003o`000?lYeRWo:MHY
00[o:MHY00?o0000omHYe_oF:MH03ooF:MH00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onHIi_oV6NH02ooV6NH00ol0003o
WenOoimOW`0DoimOW`?o00003olJiAX00ol0003o4>l@oa3_400<oa3_4004o`000?l<l`co3?<<o`cc
30;o00003ol;m0/00ol0003o3?<<o`cc3009o`cc3003o`000?lYeRWo:MHY00Wo:MHY00?o0000omHY
e_oF:MH04?oF:MH00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oV6NKoiQWV00_o
iQWV00?o0000oimOWonOGil04onOGil01Ol0003o<<l`oc3?<?l`cc3o000000go6^DJ00?o0000oa3_
4?l@ka003_l@ka000ol0003o3?<<o`00000Ao`_d2`03o`000?l<l`co3?<<00Wo3?<<00?o0000obWF
:OlYeRT02OlYeRT00ol0003oeRWFomHYeP0@omHYeP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000BoimOW`03o`000?l`cc3o<<l`00?o<<l`00?o0000oa[U6_lJiAX02OlJiAX00ol0003o
4>l@oa3_400@oa3_4003o`000?l;m0_o2o@;017o2o@;00?o0000o`cc3?l<l``02Ol<l``00ol0003o
:MHYobWF:@07obWF:@03o`000?oF:MKoeRWF017oeRWF00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iQWVonHIiP0<onHIiP03o`000?n8MhSoR7N800?o00003_nOGil00ol0003o<<l`oc3?<005oc3?<003
o`000?lJiA[o6^DJ00Oo6^DJ00?o0000oa3_4?l@ka004Ol@ka000ol0003o2o@;o`_d2`0Ao`_d2`03
o`000?l<l`co3?<<00Wo3?<<00?o0000obWF:OlYeRT01_lYeRT2o`0001CoeRWF00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiQWV00koiQWV
00?o0000ohQgR?n8MhP00on8MhP3o`0000[oWenO00?o0000oc3?<?l`cc001ol`cc000ol0003o6^DJ
oa[U6P05oa[U6P03o`000?l@ka3o4>l@01;o4>l@00?o0000o`_d2ol;m0/04Ol;m0/00ol0003o3?<<
o`cc300:o`cc3003o`000?lYeRWo:MHY00;o:MHY0ol00002obSG:003o`000?oF:MKoeRWF017oeRWF
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oV6NKoiQWV00koiQWV00?o0000ohQgR?n8MhP01_n8
MhP3o`0000KoWenO00?o0000oc3?<?l`cc002Ol`cc000ol0003o6^DJoa[U6P03oa[U6P03o`000?l@
ka3o4>l@01?o4>l@00?o0000o`_d2ol;m0/04_l;m0/00ol0003o3?<<o`cc3009o`cc3003o`000?lY
eRWo000000;o00001_lXebP00ol0003oeRWFomHYeP0@omHYeP03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oV6NKo
iQWV00goiQWV00?o0000ohQgR?n8MhP02_n8MhP3o`0000;oWenO00?o0000oc3?<?l`cc002ol`cc00
1Ol0003o6^DJoa[U6_lJiA[o000001Ko4>l@00?o0000o`_d2ol;m0/04_l;m0/00ol0003o3?<<o`cc
300:o`cc3003o`000?lXebSo:=LX00So:=LX00?o0000omHYe_oF:MH04?oF:MH00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oV6NKoiQWV00goiQWV00?o0000ohQgR?n8MhP03On8MhP2o`0000oo<<l`00?o0000oa[U6_l00000
5ol@ka000ol0003o2o@;o`_d2`0Co`_d2`03o`000?l<l`co3?<<00Wo3?<<00?o0000obSG:?lXebP0
2OlXebP00ol0003oeRWFomHYeP0?omHYeP03o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV
6NH00ol0003oR7N8ohQgR00>ohQgR003o`000?l`cc3o<<l`00ko<<l`00?o0000oa3_4?l@ka005_l@
ka000ol0003o2o@;o`_d2`0Co`_d2`03o`000?l<l`co3?<<00So3?<<00?o0000obSG:?lXebP02olX
ebP5o`0000coeRWF00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV6NH00ol0003oR7N8ohQgR00>
ohQgR003o`000?l`cc3o<<l`00ko<<l`00?o0000oa3_4?l@ka005_l@ka000ol0003o2o@;o`_d2`0C
o`_d2`03o`000?l<l`co3?<<00Oo3?<<00?o0000obSG:?lXebP03?lXebP00ol0003odbcCom</d`02
om</d`Wo00001?oF:MH00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiQWVonHIiP0<onHIiP03o`000?n8MhSoR7N8
00koR7N800?o0000oc3?<?l`cc003ol`cc000ol0003o4>l@oa3_400Eoa3_4003o`000?l;m0_o2o@;
01?o2o@;1?l00005o`cc3003o`000?lXebSo:=LX00go:=LX00?o0000om</dooC;=<02ooC;=<4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oV6NKoiQWV00_oiQWV00?o0000ohQgR?n8MhP03on8MhP00ol0003o<<l`oc3?<00?oc3?<003
o`000?l@ka3o4>l@01Go4>l@00?o0000o`_d2ol;m0/04?l;m0/3o`0000Co4>l@0ol000000ol<l`co
0000obSG:00>obSG:003o`000?oC;=?odbcC00oodbcC00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiQWVonHIiP0;onHIiP03o`00
0?n8MhSoR7N800ooR7N800?o0000oc3?<?l`cc003ol`cc02o`0001Co4>l@0ol0000@o`_d2`;o0000
2_l@ka000ol0003o:=LXobSG:00>obSG:003o`000?oC;=?odbcC013odbcC0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oV6NKoiQWV00_oiQWV4ol0000>oc3?<0?o0000
0_lNhAh00ol0003o4>l@oa3_400<oa3_40Go00000_l@ka000ol0003o2o@;o`_d2`0<o`_d2`;o0000
3?l@ka000ol0003o:=LXobSG:00>obSG:003o`000?oC;=?odbcC013odbcC00?o0000oo@;m?l00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV
6NKoiQWV00_oiQWV00?o0000og6>LOmaSW403omaSW400ol0003o<<l`oc3?<009oc3?<0?o00001_lN
hAh00ol0003o4>l@oa3_4006oa3_40Go00002?l@ka000ol0003o2o@;o`_d2`08o`_d2`?o00003ol@
ka000ol0003o:=LXobSG:00=obSG:003o`000?oC;=?odbcC00oodbcC00Go0000oo@;m?od2oCom0_d
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHI
iP0;onHIiP03o`000?maSW7oLHia00ooLHia00?o0000oc3?<?l`cc001_l`cc03o`0000[o7^4N00?o
0000oa3_4?l@ka001Ol0000>oa3_4003o`000?l;m0_o2o@;00Go2o@;0_l0000Boa3_4003o`000?lX
ebSo:=LX00co:=LX00?o0000om</dooC;=<04?oC;=<00ol0003om0_doo@;m002oo@;m003o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHIiP0;
onHIiP03o`000?maSW7oLHia013oLHia00?o0000oc3?<?l`cc000_l`cc03o`0000go7^4N0ol0000C
oa3_4003o`000?l;m0_o2o@;00?o2o@;0_l0000Eoa3_4003o`000?lXebSo:=LX00_o:=LX00?o0000
om</dooC;=<03ooC;=<00ol0003om0_doo@;m004oo@;m003o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiQWVonHIiP08onHIiPCo00004OmaSW400ol0003o<<l`o`000002o`00
00oo7^4N00?o0000oaoP7ol000005Ol@ka000ol0003o2o@;o`000002o`0001Oo4>l@00?o0000obSG
:?lXebP02olXebP00ol0003odbcCom</d`0>om</d`03o`000?od2oCom0_d00Kom0_d00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV6NKoiQWV00Go
iQWV0ol00004olTfb@03o`000?maSW7oLHia00koLHia0_l0000AoakQ7P04o`000?lOh1oo7n0Oo`00
01Ko4>l@00?o0000oa3_4?l@ka006?l@ka000ol0003o:=LXobSG:00;obSG:003o`000?oC;=?odbcC
00kodbcC00?o0000oo@;m?od2o@01ood2o@00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oV6NKoiQWV00;oiQWV0ol00008olTfb@03
o`000?maSW7oLHia00coLHia0ol0000?oakQ7P;o00000olOh1l00ol0003o4>l@oa3_400Doa3_4003
o`000?l@ka3o4>l@01Wo4>l@00?o0000obSG:?lXebP02_lXebP00ol0003odbcCom</d`0=om</d`03
o`000?od2oCom0_d00Wom0_d00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<olTfb@03o`000?maSW7oLHia00[oLHia00Go0000oeVVFOmIYUWo
FJIIo`00000=oakQ7P03o`000?lOh1oo7n0O00Co7n0O00?o0000oa3_4?l@ka004ol@ka000ol0003o
4>l@oa3_400Ioa3_4003o`000?lXebSo:=LX00Wo:=LX00?o0000om</dooC;=<03_oC;=<00ol0003o
m0_doo@;m00:oo@;m0;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o9=/WobCK900cobCK90_l00008og6>L@;o00001OmIYUT00ol0003o7^4NoakQ7P09oakQ7P03o`00
0?lOh1oo7n0O00Go7n0O00?o0000oa3_4?l@ka004ol@ka000ol0003o4>l@oa3_400Joa3_40go0000
3_oC;=<00ol0003om0_doo@;m00;oo@;m003o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003obCK9olTfb@0=olTfb@03o`000?ma
SW7oLHia00CoLHia00?o0000oeVVFOmIYUT01_mIYUT2o`0000So7^4N00?o0000oaoP7olOh1l01_lO
h1l00ol0003o4>l@oa3_400Doa3_4003o`000?l@ka3o4>l@01Wo4>l@00?o0000oeZUF_mJYEX02_mJ
YEX00ol0003odbcCom</d`0;om</d`03o`000?od2oCom0_d00com0_d00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000olTfbOo9=/T03_o9=/T0
1?l0003oLHiaog6>LOmaSW42o`0000_oFJII00?o0000oakQ7_lNhAh00olNhAh2o`0000Wo7n0O00?o
0000oa3_4?l@ka005?l@ka000ol0003o4>l@oa3_400Hoa3_4003o`000?mJYE[oFZEJ00coFZEJ00?o
0000om</dooC;=<02OoC;=<00ol0003om0_doo@;m00=oo@;m003o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obCK9olTfb@0>olTfb@03o`000?maSW7o
000000koFJII00Go0000oakQ7_lNhAko7^4No`00000;oaoP7`03o`000?l@ka3o4>l@01Co4>l@0_l0
000Ioa3_4003o`000?mJYE[oFZEJ00goFZEJ0_l00008om</d`03o`000?od2oCom0_d00kom0_d00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003obCK9olTfb@0?
olTfb@03o`000?mIYUWoFJII00koFJII00?o0000oakQ7_l000003?lOh1l00ol0003o4>l@oa3_400D
oa3_4003o`000?lDjaCo000000;o00005Ol@ka000ol0003oFZEJoeZUFP0@oeZUFP03o`000?oC;=?o
dbcC00GodbcC00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003obCK9olTfb@0>olTfb@03o`000?mIYUWoFJII00koFJII0_l0000=oaoP
7`03o`000?l@ka3o4>l@01?o4>l@00?o0000oaC[5?lDja@00olDja@2o`0001;o4>l@00?o0000oeZU
F_mJYEX04_mJYEX01?l0003odbcCom</dooC;=<3o`0001;om0_d00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000olTfbOo9=/T03Oo9=/T2o`0000ooFJII00?o0000oeJY
E_l000003_lOh1l00ol0003o4>l@oa3_400Boa3_4003o`000?lDjaCo5>/D00Go5>/D0ol0000?oa3_
4003o`000?mJYE[oFZEJ01?oFZEJ0ol00002ondBk@03o`000?od2oCom0_d013om0_d00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000olTfbOo9=/T02oo9=/T00ol0003o
bCK9o`00000>oeVVF@05o`000?mFZEKoEZUFoeJYE_l000003OlOh1l00ol0003o4>l@oa3_400Aoa3_
4003o`000?lDjaCo5>/D00Wo5>/D0ol0000:oa3_40;o00005_mJYEX00ol0003okA;]ondBk@03ondB
k@03o`000?od2oCom0_d013om0_d00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000olTfbOo9=/T02_o9=/T01Ol0003obCK9olTfbOo9=/Wo000000coFJII00?o0000oeJY
E_mFZEH00_mFZEH00ol0003o7n0OoaoP7`0;oaoP7`03o`000?l@ka3o4>l@017o4>l@00?o0000oaC[
5?lDja@03?lDja@2o`0000Ko4>l@0_l000000olcc3?o0000oeZUFP0DoeZUFP03o`000?o]4^gokA;]
00GokA;]00?o0000oo@;m?od2o@03ood2o@00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003obCK9olTfb@07olTfb@;o00001Oo9=/T00ol0003oFJIIoeVVF@08oeVVF@03
o`000?mFZEKoEZUF00CoEZUF00?o0000oaoP7olOh1l02OlOh1l4o`00013o4>l@00?o0000oaC[5?lD
ja@03olDja@3o`000003oa3_4?l0003o000000Co<l`c00?o0000oeZUF_mJYEX04OmJYEX00ol0003o
kA;]ondBk@07ondBk@03o`000?od2oCom0_d00oom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000olTfbOo9=/T01_o9=/T00ol0003obCK9olTfb@05olTfb@03o`00
0?mIYUWoFJII00OoFJII00?o0000oeJYE_mFZEH01OmFZEH00ol0003o7n0OoaoP7`08oaoP7`03o`00
0?lRgB;o8]dR00;o8]dR0ol0000=oa3_4003o`000?lDjaCo5>/D01;o5>/D00?o0000oc?<<olcc3<0
1Olcc3<00ol0003oFZEJoeZUFP0@oeZUFP03o`000?o]4^gokA;]00OokA;]00?o0000oo@;m?od2o@0
3ood2o@00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003obCK9olTf
b@04olTfb@03o`000?o9=/WobCK900OobCK900?o0000oeVVFOmIYUT01OmIYUT00ol0003oEZUFoeJY
EP07oeJYEP03o`000?lOh1oo7n0O00Ko7n0O00?o0000ob;M8_lRgB801_lRgB83o`0000So4>l@0_l0
000EoaC[5003o`000?lcc3?o<l`c00Ko<l`c00?o0000oeZUF_mJYEX03_mJYEX00ol0003okA;]ondB
k@09ondBk@03o`000?od2oCom0_d00kom0_d00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000olTfbOo9=/T00_o9=/T2o`0000[obCK900?o0000oeVVFOmIYUT01?mIYUT0
0ol0003oEZUFoeJYEP09oeJYEP03o`000?lOh1oo7n0O00?o7n0O0_l0000<ob;M8P?o00000_l@ka03
o`000003oa_T6ol0003o5>/D01Co5>/D00?o0000oc?<<olcc3<01olcc3<00ol0003oFZEJoeZUFP0<
oeZUFP03o`000?o]4^gokA;]00_okA;]00?o0000oo@;m?od2o@03_od2o@00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003obCK9olTfbOl0000=olTfb@03o`000?mIYUWo
FJII00;oFJII00?o0000oeJYE_mFZEH02_mFZEH00ol0003o7n0OoaoP7`02oaoP7`03o`000?lRgB;o
8]dR00oo8]dR0_l00005oa_T6`03o`000?lDjaCo5>/D01;o5>/D00?o0000oc?<<olcc3<02?lcc3<0
0ol0003oFZEJoeZUFP0:oeZUFP03o`000?o]4^gokA;]00gokA;]1Ol0000;oo@;m003o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o9=/Wo000000oobCK900Co0000oeVV
FOmIYUWo00003_mFZEH01?l0003o7n0OoaoP7ol0000Cob;M8P03o`000?lKi1_o6n@K00Co6n@K00?o
0000oaC[5?lDja@04?lDja@00ol0003o<l`coc?<<`09oc?<<`03o`000?mJYE[oFZEJ00[oFZEJ00?o
0000ondBkOo]4^d03Oo]4^d00ol0003onPGjooX5nP02ooX5nPWo00000_od2o@00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?o9=/WobCK900kobCK900?o0000oeVVFOl000003omFZEH0
0ol0003o7n0Oo`00000Cob;M8P03o`000?lKi1_o6n@K00Go6n@K00?o0000oaC[5?lDja@04?lDja@0
0ol0003o<l`coc?<<`0:oc?<<`03o`000?mJYE[oFZEJ00SoFZEJ00?o0000ondBkOo]4^d03Oo]4^d0
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000olTf
bOo9=/T03oo9=/T00ol0003oEZUFoeJYEP0>oeJYEP;o00005?lRgB800ol0003o6n@Koa_T6`06oa_T
6`03o`000?lDjaCo5>/D00oo5>/D00?o0000oc?<<olcc3<02olcc3<00ol0003oFZEJoeZUFP04oeZU
FP?o00004?o]4^d00ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
bCK9olTfb@0@olTfb@03o`000?mFZEKoEZUF00_oEZUF0ol000000omFZEKo0000ob;M8P0Bob;M8P03
o`000?lKi1_o6n@K00Oo6n@K00?o0000oaC[5?lDja@03olDja@00ol0003o<l`coc?<<`0<oc?<<`03
o`000?mJYE[oFZEJ00?o00000ooI9]T00ol0003okA;]ondBk@0=ondBk@03o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000olTfbOo9=/T04?o9=/T3o`0000WoEZUF0_l00005oeJYEP03o`00
0?lRgB;o8]dR013o8]dR00?o0000oa_T6olKi1/02?lKi1/00ol0003o5>/DoaC[500>oaC[5003o`00
0?lcc3?o<l`c00go<l`c0_l00007omTVf@03o`000?o]4^gokA;]00_okA;]00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o9=/WobCK900oobCK900Co
0000okm0_ono@;oo_d2o0_l00005oeJYEP;o00002?mFZEH00ol0003o8]dRob;M8P0>ob;M8P03o`00
0?lKi1_o6n@K00[o6n@K00?o0000oaC[5?lDja@03?lDja@00ol0003o<l`coc?<<`0>oc?<<`03o`00
0?oI9]WofBKI00OofBKI00?o0000ondBkOo]4^d02_o]4^d00ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006okm0_`03o`000?mFZEKo000000;o00002_mF
ZEH00ol0003o8]dRob;M8P0=ob;M8P03o`000?lKi1_o6n@K00_o6n@K00?o0000oaC[5?lDja@03?lD
ja@00ol0003o<l`coc?<<`0=oc?<<`03o`000?oI9]WofBKI00WofBKI00?o0000ondBkOo]4^d02?o]
4^d00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o_4>oo
ka3_00ooka3_00?o0000okm0_ono@;l01Ono@;l00ol0003oEZUFoeJYEP0<oeJYEP03o`000?lRgB;o
8]dR00co8]dR00?o0000oa_T6olKi1/03?lKi1/2o`0000co5>/D00?o0000oc?<<olcc3<03Olcc3<0
0ol0003ofBKIomTVf@0:omTVf@03o`000?o]4^gokA;]00OokA;]00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o_4>l04?o_4>l00ol0003o_d2ookm0_`06okm0_`03o`000?mFZEKo
EZUF00coEZUF00?o0000ob;M8_lRgB802olRgB800ol0003o6n@Koa_T6`0=oa_T6`04o`000?lZeB[o
0000o`0000[o5>/D00?o0000oc?<<olcc3<03Olcc3<00ol0003ofBKIomTVf@0;omTVf@03o`000?o]
4^gokA;]00KokA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003oka3_onl@k`0@
onl@k`03o`000?no@;oo_d2o00Ko_d2o00?o0000oeJYE_mFZEH03OmFZEH00ol0003o8]dRob;M8P0:
ob;M8P03o`000?lKi1_o6n@K00co6n@K00?o0000ob[E:_lZeBX00_lZeBX2o`0000So5>/D00?o0000
oc?<<olcc3<03?lcc3<00ol0003ofBKIomTVf@0=omTVf@03o`000?o]4^gokA;]00CokA;]00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@onl@k`03o`000?no@;oo_d2o
00Oo_d2o00?o0000oeJYE_mFZEH03_mFZEH<o`0000oo6n@K00?o0000ob[E:_lZeBX01?lZeBX2o`00
00Ko5>/D00?o0000oc?<<olcc3<03?lcc3<00ol0003ofBKIomTVf@0>omTVf@03o`000?o]4^gokA;]
00?okA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>onl@
k`03o`000?no@;oo_d2o00So_d2o00?o0000oeJYE_mFZEH03OmFZEH00ol0003o>/Djoc[5>P08oc[5
>P03o`000?lKi1_o6n@K00co6n@K00?o0000ob[E:_lZeBX01olZeBX2o`0000?o5>/D00?o0000oc?<
<olcc3<03Olcc3<00ol0003ofBKIomTVf@0?omTVf@05o`000?o]4^gokA;]ondBkOl000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo_4>l00ol0003o_d2ookm0_`08okm0_`03o`000?mFZEKo
EZUF00coEZUF00?o0000oc[5>_ljaCX02_ljaCX00ol0003o6n@Koa_T6`0;oa_T6`03o`000?lZeB[o
:]DZ00Wo:]DZ0_l000000olDjaCo0000oc?<<`08oc?<<`Ko00004ooI9]T01?l0003okA;]ondBkOl0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008onl@k`03o`000?no@;oo
_d2o00Wo_d2o00?o0000oeJYE_mFZEH03?mFZEH00ol0003o>/Djoc[5>P0:oc[5>P03o`000?lKi1_o
6n@K00[o6n@K00?o0000ob[E:_lZeBX03?lZeBX;o`0000Go/Dja00?o0000omTVfOoI9]T04_oI9]T0
0ol0003okA;]o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on<L
hooS7>?ohacS1Ol00003onl@k`03o`000?no@;oo_d2o00Wo_d2o00?o0000oeJYE_mFZEH02omFZEH0
0ol0003o>/Djoc[5>P0<oc[5>P03o`000?lKi1_o6n@K00Wo6n@K00?o0000ob[E:_lZeBX03?lZeBX0
0ol0003oCk1?odn`C`02odn`C`03o`000?naC[7o/Dja00Wo/Dja00?o0000omTVfOoI9]T04_oI9]T3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on<L
hooS7><01OoS7><3o`0000co_d2o00?o0000oeJYE_mFZEH02omFZEH00ol0003o>/Djoc[5>P0<oc[5
>P03o`000?lKi1_o6n@K00So6n@K00?o0000ob[E:_lZeBX03?lZeBX00ol0003oCk1?odn`C`04odn`
C`03o`000?naC[7o/Dja00So/Dja00?o0000omTVfOoI9]T04_oI9]T00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oS7>?ohacS00OohacS00?o0000okm0
_ono@;l02_no@;l00ol0003oEZUFoeJYEP09oeJYEP;o00003oljaCX00ol0003o6n@Koa_T6`08oa_T
6`03o`000?lZeB[o:]DZ00co:]DZ00?o0000odn`Com?/4l01?m?/4l00ol0003o/Djaok5>/@09ok5>
/@Co00003ooI9]T00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on<LhooS7><02?oS7><00ol0003o_d2ookm0_`09okm0_`03o`000?mFZEKoEZUF00Ko
EZUF0ol000000on6NHKo0000oc[5>P0?oc[5>P03o`000?lKi1_o6n@K00Ko6n@K00?o0000ob[E:_lZ
eBX03OlZeBX00ol0003oCk1?odn`C`05odn`C`03o`000?naC[7o/Dja00So/Dja00Co0000oo<<looc
3??ol`cc1Ol00009omTVf@03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003ohacSon<Lh`07on<Lh`03o`000?no@;oo_d2o00[o_d2o00?o0000oeJYE_mF
ZEH00_mFZEH3o`0000GoQWV600?o0000oc[5>_ljaCX03OljaCX00ol0003o6n@Koa_T6`06oa_T6`03
o`000?lZeB[o:]DZ00co:]DZ00?o0000odn`Com?/4l01_m?/4l00ol0003o/Djaok5>/@08ok5>/@03
o`000?oc3??ol`cc00Kol`cc1Ol00003omTVf@03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on<LhooS7><01ooS7><00ol0003o_d2ookm0_`0:okm0_`03o`000?mFZEKo000000;o0000
2?n6NHH00ol0003o>/Djoc[5>P0=oc[5>PCo00001?lKi1/00ol0003o:]DZob[E:P0=ob[E:P03o`00
0?m?/4ooCk1?00OoCk1?00?o0000ok5>/OnaC[401onaC[400ol0003ol`ccoo<<l`0;oo<<l`?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on<LhooS7><02?oS7><3o`0000Wo_d2o0_l0
000<ohIiQP03o`000?ljaC[o>/Dj00_o>/Dj00?o0000ofbCK?m/Tf`00_m/Tf`3o`000003oa_T6ol0
003o:]DZ00ko:]DZ00?o0000odn`Com?/4l01om?/4l00ol0003o/Djaok5>/@06ok5>/@03o`000?oc
3??ol`cc00kol`cc00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on<LhooS7><01_oS7><01?l0003oiQWVonHIi_oV6NH3o`0000Ko_d2o00?o0000ohIiQ_n6NHH03?n6
NHH00ol0003o>/Djoc[5>P09oc[5>P03o`000?m/TfcoK9=/00KoK9=/00?o0000ob[E:_lZeBX03OlZ
eBX00ol0003oCk1?odn`C`09odn`C`03o`000?naC[7o/Dja00Go/Dja00?o0000oo<<looc3?<03_oc
3?<00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003ohacSon<Lh`05
on<Lh`03o`000?oV6NKoiQWV00GoiQWV0ol00002okm0_`03o`000?n6NHKoQWV600goQWV600?o0000
oc[5>_ljaCX02?ljaCX00ol0003oK9=/ofbCK007ofbCK003o`000?lZeB[o:]DZ00co:]DZ0ol0000:
odn`C`03o`000?naC[7o/Dja00Go/Dja00?o0000oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003ohacSon<Lh`04on<Lh`03o`000?oV6NKoiQWV
00WoiQWV0_l0000AohIiQP03o`000?ljaC[o>/Dj00Go>/Dj0_l0000;ofbCK003o`000?lZeB[o:]DZ
00[o:]DZ00Go0000ohebSOn=LXgoSG:=o`00000:odn`C`03o`000?naC[7o/Dja00Co/Dja00?o0000
oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oS7>?ohacS
00;ohacS00?o0000onHIi_oV6NH02_oV6NH2o`00017oQWV600?o0000oc[5>_ljaCX01?ljaCX00ol0
003oK9=/ofbCK00<ofbCK003o`000?lZeB[o:]DZ00Oo:]DZ0_l00005ohebS@;o00002?m?/4l00ol0
003o/Djaok5>/@04ok5>/@03o`000?oc3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003ohacSon<LhooS7>?o000000coiQWV00Co0000omHY
e_oF:MKo00004On6NHH00ol0003o>/Djoc[5>P02oc[5>P03o`000?m/TfcoK9=/00koK9=/00?o0000
ob[E:_lZeBX01OlZeBX00ol0003oSG:=ohebS@07ohebS@03o`000?m?/4ooCk1?00KoCk1?00?o0000
ok5>/OnaC[400onaC[400ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on<LhooS7>?o00003?oV6NH00ol0003oeRWFomHYeP02omHYeP03o`000?n6NHKo
QWV600ooQWV600Co0000oc[5>_ljaC[o00004Om/Tf`00ol0003o:]DZob[E:P04ob[E:P03o`000?n=
LXgoSG:=00WoSG:=00?o0000odn`Com?/4l01Om?/4l00ol0003o/Djaok5>/@03ok5>/@03o`000?oc
3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onHIiP03o`000?oF:MKoeRWF00?oeRWF00?o0000ohIiQ_n6NHH03on6NHH00ol0003o>/Djo`00000C
ofbCK004o`000?lZeB[o:]DZob[E:P;o00003On=LXd2o`0000KoCk1?00Go0000ok5>/OnaC[7o/Dja
o`00000@oo<<l`03o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02_oV
6NH00ol0003oeRWFomHYeP05omHYeP03o`000?n6NHKoQWV600ooQWV600?o0000ofbCK?m/Tf`04om/
Tf`00ol0003o:]DZo`00000AohebS@03o`000?m?/4ooCk1?00?oCk1?00Go0000ok5>/OnaC[7o/Dja
o`00000>oo<<l`?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02OoV
6NH00ol0003oeRWFomHYeP07omHYeP03o`000?n6NHKoQWV600koQWV600?o0000ofbCK?m/Tf`05?m/
Tf`00ol0003oSG:=ohebS@0AohebS@;o00001?m?/4l01?l0003o/Djaok5>/Ol0000:oo<<l`Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onHIi_oV6NH02OoV6NH00ol0003oeRWFomHYeP08omHYeP03o`000?n6NHKoQWV600_oQWV60ol0
000GofbCK003o`000?n=LXgoSG:=01?oSG:=00Ko0000odn`Com?/4ooCk1?o`000?naC[45o`0000Co
l`cc0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oV6NKoiQWV00SoiQWV00?o0000omHYe_oF:MH02_oF:MH00ol0003oQWV6ohIiQP07ohIiQP?o0000
0_nUFZD00ol0003oK9=/ofbCK00EofbCK0;o00005On=LXd00ol0003oCk1?odn`C`02o`0000GojQGZ
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onHIi_oV6NH01ooV
6NH00ol0003oeRWFomHYeP0;omHYeP03o`000?n6NHKoQWV600CoQWV60ol00006ojEJY@03o`000?m/
TfcoK9=/01?oK9=/00Co0000oke2_Onm@[go00005On=LXd2o`0000WojQGZ00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiQWV00?o0000omHYe_oF:MH03OoF:MH00ol0003oQWV6ohIi
QP03o`0000[oYEZU00?o0000ofbCK?m/Tf`04Om/Tf`00ol0003o_D:moke2_@02oke2_@03o`000?n=
LXgoSG:=01;oSG:=00?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiQWVonHIiP05onHIiP03o`000?oF:MKoeRWF00ooeRWF0_l0000>
ojEJY@03o`000?m/TfcoK9=/00ooK9=/00?o0000oke2_Onm@[d01?nm@[d00ol0003oSG:=ohebS@0@
ohebS@;o00002ooZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onHIi_oV6NH00ooV6NH00ol0003oeRWFomHYeP0@omHYeP03o`000?nUFZGoYEZU
00goYEZU00?o0000ofbCK?m/Tf`03_m/Tf`00ol0003o_D:moke2_@06oke2_@;o00003_n=LXd2o`00
0003olhac_l0003ojQGZ00[ojQGZ00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiQWVonHIi_oV6NKo000001;oeRWF00?o0000ojEJYOnUFZD03onUFZD00ol0003oK9=/ofbCK00<
ofbCK003o`000?nm@[go_D:m00Wo_D:m00?o0000ohebSOn=LXd02On=LXd2o`0000?ocS7>00?o0000
onXEj_oZ5NX02OoZ5NX00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiQWVo`00000ComHY
eP03o`000?nUFZGoYEZU013oYEZU00?o0000ofbCK?m/Tf`02_m/Tf`00ol0003o_D:moke2_@0;oke2
_@03o`000?n=LXgoSG:=00GoSG:=0ol00006olhacP03o`000?oZ5N[ojQGZ00SojQGZ00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000omHYe_oF:MH04OoF:MH00ol0003oYEZUojEJY@0AojEJY@03o`000?m/TfcoK9=/00Wo
K9=/00?o0000oke2_Onm@[d03Onm@[d00ol0003oSG:=ohebS@02ohebS@;o00002Oo><Lh00ol0003o
jQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017oeRWF00?o0000ojEJYOnUFZD0
4_nUFZD00ol0003oK9=/ofbCK007ofbCK003o`000?nm@[go_D:m00oo_D:m00Co0000ohebSOl0003o
00002oo><Lh00ol0003ojQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000koeRWF00?o0000ojEJYOnUFZD04onUFZD00ol0003oK9=/ofbCK005ofbCK003o`00
0?nm@[go_D:m017o_D:m00?o0000olhac_o><Lh03?o><Lh00ol0003ojQGZonXEjP08onXEjP03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;omHYeP;o00005_nUFZD7o`0001Co_D:m00?o
0000olhac_o><Lh03?o><Lh00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oF:MH00ol0003obcC;o`000002o`0001;oYEZU00?o0000okI9]_nfBKH00_nf
BKH00ol0003oZEJYo`00000Doke2_@03o`000?o><LkocS7>00cocS7>00?o0000onXEj_oZ5NX02?oZ
5NX00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoF:MH00ol0003obcC;ol/db`03
ol/db`;o00003onUFZD00ol0003o]TVfokI9]P03okI9]P04o`000?nYEZWoZEJYo`0001?o_D:m00?o
0000olhac_o><Lh03Oo><Lh00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003omHYe_l0003o
bcC;00OobcC;0ol0000;ojEJY@03o`000?nfBKKo]TVf00Co]TVf00Go0000ojUFZOnYEZWoZEJYo`00
000Boke2_@03o`000?o><LkocS7>00gocS7>00?o0000onXEj_oZ5NX01ooZ5NX?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T04?oi1_T0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o;=<_obcC;00[obcC;0_l00008ojEJY@03o`000?nfBKKo
]TVf00Go]TVf00?o0000ojUFZOnYEZT00_nYEZT00ol0003o_D:moke2_@0?oke2_@03o`000?o><Lko
cS7>00gocS7>00?o0000onXEj_oZ5NX01_oZ5NX00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oi1_Won@Ki00oon@Ki00?o0000on`Ck?o/4n`03oo/4n`00ol0003obcC;ol/db`0<ol/d
b`;o00001OnUFZD00ol0003o]TVfokI9]P06okI9]P03o`000?nYEZWoZEJY00?oZEJY00?o0000oke2
_Onm@[d03_nm@[d00ol0003ocS7>olhacP0>olhacP03o`000?oZ5N[ojQGZ00CojQGZ00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00kon@Ki00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
bcC;ol/db`0>ol/db`?o000000?oYEZUo`000?nfBKH02?nfBKH00ol0003oZEJYojUFZ@04ojUFZ@03
o`000?nm@[go_D:m00go_D:m4_l00005onXEjP03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooT6n@03o`000?o/4ncok1?/00ook1?/0_l0000Col/db`03o`000?nfBKKo]TVf00So]TVf
00?o0000ojUFZOnYEZT01OnYEZT00ol0003o_D:moke2_@0<oke2_@03o`000?oa3_7ol@ka00ool@ka
00Go0000onXEj_oZ5N[ojQGZo`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n@Ki00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000Col/db`03o`000?nfBKKo]TVf00So
]TVf00?o0000ojUFZOnYEZT01OnYEZT00ol0003o_D:moke2_@0;oke2_@03o`000?oa3_7ol@ka017o
l@ka00?o0000onXEj_l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n@KiooT6n@0:ooT6n@03o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o;=<_obcC;013o
bcC;00?o0000okI9]_nfBKH02?nfBKH00ol0003oZEJYojUFZ@06ojUFZ@03o`000?nm@[go_D:m00[o
_D:m00?o0000oo4>lOoa3_404_oa3_400ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on@KiooT6n@09ooT6n@03o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003obcC;ol/db`0?ol/db`03o`000?nfBKKo]TVf00Wo]TVf00?o0000ojUFZOnYEZT0
1onYEZT00ol0003o_D:moke2_@09oke2_@03o`000?oa3_7ol@ka01;ol@ka00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003obcC;ol/db`0?ol/db`03o`000?nfBKKo]TVf00Wo]TVf00?o
0000ojUFZOnYEZT02?nYEZT00ol0003o_D:moke2_@07oke2_@03o`000?oa3_7ol@ka01?ol@ka00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000ol/dboo;=</03Oo;=</2
o`0000_o]TVf00?o0000ojUFZOnYEZT02OnYEZT00ol0003o_D:moke2_@06oke2_@03o`000?oa3_7o
l@ka01?ol@ka4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003obcC;ol/db`0;ol/db`;o000000?ocC;=o`000?nfBKH02_nfBKH00ol0
003oZEJYojUFZ@09ojUFZ@Ko00000onm@[d00ol0003ol@kaoo4>l@0Coo4>l@03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01?oi1_T3o`00
00Sok1?/0_l0000;on@Ki003o`000?o;=<_obcC;00WobcC;0_l00004oldbc@03o`000?nfBKKo]TVf
00So]TVf00?o0000ojUFZOnYEZT02?nYEZT00ol0003ofbCKom/Tf`04om/Tf`?o00005?oa3_43o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on@KiooT6n@03o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o;=<_obcC;00Go
bcC;0ol00007oldbc@03o`000?nfBKKo]TVf00Oo]TVf00?o0000ojUFZOnYEZT01onYEZT00ol0003o
fbCKom/Tf`08om/Tf`03o`000?oa3_7ol@ka013ol@ka00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000ol/d
boo;=</00oo;=</2o`0000[ocC;=00?o0000okI9]_nfBKH01onfBKH00ol0003oZEJYojUFZ@05ojUF
Z@;o00003?oK9=/00ol0003ol@kaoo4>l@0=oo4>l@;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000ol/dboo;=<_obcC;0_l0000=oldbc@03o`000?nfBKKo]TVf00Ko]TVf00?o0000ojUF
ZOnYEZT01?nYEZT00ol0003ofbCKom/Tf`0=om/Tf`Co00002_oa3_400ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013ocC;=00?o0000okI9]_nfBKH01OnfBKH00ol0003o
ZEJYojUFZ@03ojUFZ@03o`000?oK9=_ofbCK00kofbCK00Co0000ooH9m_of2OKomPWf1_l00003oo4>
l@03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o=</gocC;=013o
cC;=00?o0000okI9]_nfBKH01OnfBKH00ol0003oZEJYojUFZ@02ojUFZ@03o`000?oK9=_ofbCK00oo
fbCK00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000oldbcOo=</d0
4Oo=</d00ol0003o]TVfokI9]P04okI9]P03o`000?nYEZWoZEJY00;o00004OoK9=/00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o=</d3o`0000Co]TVf00?o0000ojUFZOl000004ooK
9=/00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003ocC;=017ocC;=0_l00003omPWf0;o00000_nfBKH2
o`0001CofbCK00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o=</gocC;=00gocC;=0_l00007omPWf0?o00005OoK9=/00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000oldbcOo=</d02_o=</d2o`0000_o
f2OH00?o0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o=</gocC;=00OocC;=0_l0000=omPWf003o`000?oK9=_ofbCK01;ofbCK00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000oldbcOo=</d01Oo=</d2o`0000oof2OH00?o
0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000oldbcOo=</d00_o=</d2o`0001;of2OH00?o0000om/TfooK9=/04OoK9=/0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003ol`ccoo<<lol0000@onDJi@04o`000?o=</go
0000o`0001Cof2OH00?o0000om/TfooK9=/04?oK9=/00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo<<looc3?<00_oc3?<00ol0003oiA[UonDJi@0>onDJi@03o`000?oH9mSof2OH01Cof2OH00?o0000
om/TfooK9=/03OoK9=/4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003ol`ccoo<<l`03oo<<l`03o`000?oU6^GoiA[U
00goiA[U00?o0000omPWf?oH9mP05?oH9mP00ol0003ofbCKom/Tf`07om/Tf`Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo<<looc3?<01Ooc3?<00ol0003oiA[UonDJi@0<onDJi@03
o`000?oH9mSof2OH01Gof2OH00?o0000om/TfooK9=/01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003ol`ccoo<<l`06oo<<l`03o`000?oU6^GoiA[U00_oiA[U00?o0000omPWf?oH9mP0
5OoH9mP3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo<<looc3?<02?oc3?<00ol0003oiA[UonDJ
i@0:onDJi@03o`000?oH9mSof2OH01Gof2OH00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo<<l`03o`000?oU6^GoiA[U00WoiA[U00?o0000omPWf?oH9mP05?oH9mP0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?oc3??ol`cc00_ol`cc00?o0000onDJiOoU6^D02OoU6^D0
0ol0003of2OHomPWf00ComPWf003o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?oc3?<00ol0003oiA[UonDJi@08onDJ
i@03o`000?oH9mSof2OH00oof2OH1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_oc3?<00ol0003oiA[UonDJi@07onDJi@03o`000?oH9mSof2OH00Sof2OH1ol00003on`C
k003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo<<l`03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omPWf?oH9mSof2OH1ol0000:on`Ck003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000Kol`cc00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
k1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?oc3?<00ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ok1?/01Cok1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000Col`cco`000?l0003o00001?oh1oP00ol0003ok1?/on`Ck00Bon`Ck0;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k00@on`Ck004o`000?o_4>ooka3_o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ok1?/on`Ck00?on`Ck003o`000?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o/4nco
k1?/00kok1?/00?o0000onl@koo_4>l01?o_4>l2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00=on`Ck003o`000?o_4>ooka3_
00Goka3_00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000onl@koo_4>l01_o_4>l00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ok1?/
on`Ck009on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o/4ncok1?/00Sok1?/00?o
0000onl@koo_4>l02?o_4>l00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000onl@koo_4>l02?o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ok1?/on`Ck005on`Ck003o`000?o_4>ooka3_00Woka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Co
k1?/00?o0000onl@koo_4>l02_o_4>l00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`Ck003on`Ck003o`00
0?o_4>ooka3_00[oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`C
k002on`Ck003o`000?o_4>ooka3_00_oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ok1?/on`Ck?l0000>onl@k`03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o_4>l00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000Woka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000Goka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?oka3_o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Oo
003o3?ooo`000olQ8Mgo003oo`00o`05o`00o`03oeEEZOooo`3ogMdQ00Wo003o00?o<S;<ojVYEOo^
kQ000oooo`001?oMgB7oZJUEofIVV?l@4>h;o`00o`;oool0VOl00?l1ooooo`00WOl00?l00onHV6Ko
ool0ogMgQ`07o`00o`03oiRHI_ooo`3oMgN700co003o0_ooo`07o`00o`03oc8bc?ooo`3oool000Wo
ool000?oV9QVo`00ool00?l01_l00?l2oooo0003ob4QgOl00?oo003o00Ko003o1?ooo`001onj^TCo
8B7Mo`00oolb</coZJUEoooo0?mgMhL02_l00?l2oooo09Wo003o0Oooool009go003o00?ok^h@oooo
0?oMgB401ol00?l00oo^kQ3oool0omgM8@0<o`00o`;oool02?l00?l00om4A;[oool0oooo0009oooo
0003oa0@k_l00?oo003o00Go003o00?oZJUEoooo0?nHV6H02?l00?l01?nj^TCoool0olc<<_m4A;X5
o`00o`03ofIVV?ooo`3oZJUE00Wo003o0_ooo`2Io`00o`7ooooo002Lo`00o`05oc8bc?ooo`3oool0
oooo0?l@4>h01Ol00?l01Olb</coool0oooo0?ooo`3o8B7M00_o003o0_ooo`09o`00o`03ofIVV?o^
kQ3o413^00Ko003o00?oA4Bjonk^4?n7QgL01ol00?l00olb</coool0onk^400Bo`00o`03ojVYEOoo
o`3oZJUE00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`05ojVYEOooo`3oool0oooo0?mVIYP01Ol0
0?l01OnHV6Koool0oooo0?ooo`3oMgN700_o003o0_ooo`0:o`00o`03oiRHI_oMgB7o413^00Ko003o
00?oA4BjojVYEOl00?l01ol00?l00oo^kQ3oool0odA4^P0Ao`00o`04oc8bc?ooo`3oool0odA4^POo
003o0_ooo`2Io`00o`7ooooo002Lo`00o`?oool000?oIVJHokZjA?l00?l01?l00?l01Oo^kQ3oool0
oooo0?mVIYSogMdQ00_o003o0_ooo`0;o`00o`03ojVYEOoMgB7o413^00oo003o00?oQhMgoooo0?nY
ZED04_l00?l2oooo0003okZjA?l00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Ko`00o`07oeEE
ZOooo`3oool0onk^4?l00?ook^h@oa0@kP03o`00o`07oeEEZOooo`3oool0onk^4?l00?ook^h@ob4Q
g@0:o`00o`;oool02ol00?l00ol@4>kogMdQojVYE@0?o`00o`03ob4QgOooo`3oool001;o003o0ooo
o`07o`00o`;oool0VOl00?l1ooooo`00Vol00?l01onYZEGoool0oooo0?nHV6Ko003ooiRHI_mVIYP0
0ol00?l01onYZEGoool0oooo0?nHV6Ko003ooiRHI_mgMhL02_l00?l2oooo00co003o00?o413^oooo
0?nYZED03ol00?l00ooMgB7oool0ofIVV00@o`00o`04oeEEZOooo`3oool0oooo00Oo003o0_ooo`2I
o`00o`7ooooo002Ko`00o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l00?oo
A4BjomgM8@[o003o0_ooo`0=o`00o`03oc8bc?ooo`3oMgN700ko003o00?oIVJHoooo0?nj^T@04?l0
0?l01?nj^TCoool0oooo0?ooo`07o`00o`;oool0VOl00?l1ooooo`00V_l00?l01?mEEJWoool0oooo
0?oMgB43o`00o`04oooo0?l00?oo003ooeEEZ@;oool000Kok^h@o`00ool00?oo003ooooo0?lQ8Md9
o`00o`;oool03_l00?l00on7QgOoool0oeEEZ@0=o`00o`04oa0@k_ooo`3oool0oa0@kPko003o00Go
ZJUEoooo0?ooo`3oool0ojVYE@07o`00o`;oool0VOl00?l1ooooo`00V_l00?l01?nYZEGoool0oooo
0?mgMhL3o`00o`04ojVYEOmEEJWo003oojVYE@;oool000KoV9QVo`00ool00?oo003oojVYEOmgMhL9
o`00o`;oool03ol00?l00oo^kQ3oool0ob4Qg@0=o`00o`03okZjA?ooo`3oMgN700co003o00?o<S;<
olc<<_ooo`000oooo`000olQ8Mgo003oo`00o`05o`00o`;oool0VOl00?l1ooooo`00V_l00?l3oooo
0007ob4QgOl00?oo003oo`00oomEEJWoZJUEo`00o`03oooo0006oc8bc?l00?oo003oo`00oomEEJWo
gMdQ2Ol00?l2oooo00oo003o00?oMgN7oooo0?o<c3803Ol00?l00omEEJWoool0omgM8@09o`00o`03
odA4^_mgMhOogMdQ00Goool000?oIVJHo`00ool00?l01_l00?l2oooo09Wo003o0Oooool009Wo003o
00CoEEFYoooo0?ooo`3ogMdQ1Ol00?l01Oo^kQ3oEEFYoooo0?ooo`3ok^h@00Go003o00?oool0ob4Q
gOl00?l01ol00?l2oooo00oo003o00Co8B7Moooo0?ooo`3oEEFY3Ol00?l2oooo0003ob4QgOl00?oo
003o00?o003o00?o<S;<oooo0?ooo`001oooo`000omVIYSo003oo`00o`07o`00o`;oool0VOl00?l1
ooooo`00VOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3oool0oooo0?n7QgL01Ol0
0?l00onYZEGoMgN7o`00o`07o`00o`;oool04?l00?l2oooo0003okZjA?l00?oo003o00_o003o00?o
ZJUEoooo0?n7QgL01Ol00?l00olQ8Mgoool0oooo0005oooo0003ojVYEOlQ8Mgo003o00Wo003o0_oo
o`2Io`00o`7ooooo002Ho`00o`05oa0@k_ooo`3oool0oooo0?lQ8Md01Ol00?l01OmVIYSoool0oooo
0?ooo`3o8B7M00Go003o00?oEEFYomgM8Ol00?l01ol00?l2oooo00Oo003o00?o^[Y4ob4QgOl00?l0
1_l00?l3oooo00go003o00?o<S;<oooo0?o^kQ001_l00?l01onYZEGoool0onk^4?o<c3;oQhMgoeEE
ZOl@4>h03?l00?l2oooo09Wo003o0Oooool009So003o00CoIVJHoooo0?ooo`3ogMdQ1_l00?l01?mV
IYSoool0oooo0?oMgB47o`00o`03oooo0?lQ8Mgo003o00Ko003o0_ooo`07o`00o`03okZjA?nHV6Ko
003o00Go003o00CoEEFYoooo0?ooo`3oool00ol00?l00omEEJWo413^o`00o`08o`00o`03onk^4?oo
o`3o<S;<00Go003o00?o8B7Monk^4?l00?l04?l00?l2oooo09Wo003o0Oooool009So003o00Coc<`b
oooo0?ooo`3oMgN71_l00?l01?nj^TCoool0oooo0?mgMhL7o`00o`03ojVYEOmgMhOo003o00Ko003o
0_ooo`07o`00o`03ofIVV?ooo`3o<S;<00Go003o00Coc<`boooo0?ooo`3oool00ol00?l2okZjA0Wo
003o00?oQhMgoooo0?nYZED01_l00?l00oo<c3;oEEFYo`00o`0?o`00o`;oool0VOl00?l1ooooo`00
Uol00?l01OlQ8Mgoool0oooo0?ooo`3o8B7M00Go003o00Go413^oooo0?ooo`3oool0ob4Qg@07o`00
o`03oeEEZOoMgB7o003o00Ko003o0_ooo`07o`00o`08oa0@k_ooo`3oool0ofIVV?l@4>ko003ooc8b
c?o<c383oooo0008okZjA?l00?oo003oo`00oomEEJWoool0okZjA?lQ8Md7o`00o`03ob4QgOooo`3o
ool000Ko003o00?oA4Bjolc<<_l00?l03ol00?l2oooo09Wo003o0Oooool009Oo003o00CoZJUEoooo
0?ooo`3ogMdQ1_l00?l01?mgMhOoool0oooo0?oMgB49o`00o`03oooo0?lQ8Mgo003o00Go003o0_oo
o`08o`00o`03ofIVV?ooo`3oool000Ooool000?o<S;<o`00ool00?l00_l00?l00oo^kQ3oool0oooo
000:oooo0003oeEEZOl00?oo003o00Co003o00?oc<`boooo0?ooo`001Oooo`000oo<c3;o003oo`00
o`06o`00o`;oool0VOl00?l1ooooo`00UOl00?l00olQ8MgoQhMgoooo0002oooo0003onk^4?lb</co
003o00?o003o00KoEEFYoooo0?ooo`3oool0onk^4?lb</`6o`00o`06ob4QgOn7QgOoool0onk^4?mE
EJWo413^1?l00?l2oooo00Wo003o00?oQhMgoooo0?ooo`001Oooo`000omVIYSo003oo`00o`03o`00
o`03ohN7Moooo`3oool000[oool000?o^[Y4o`00ool00?l01?l00?l00omVIYSoool0oooo0006oooo
0003ob4QgOl00?oo003o00Go003o0_ooo`2Io`00o`7ooooo002Do`00o`03odA4^_ooo`3oool000Oo
ool000?oQhMgoooo0?ooo`001oooo`02o`00o`03ohN7Moooo`3oool000Goool000CoA4Bjo`00ool0
0?oo003o0_ooo`000omgMhOo003oo`00o`07o`00o`03odA4^_nj^TCoool000;oool000?oZJUEoc8b
c?l00?l01Ol00?l00olQ8Mgoool0oooo000;oooo00Oo003o00?ok^h@oooo0?ooo`001Oooo`000omg
MhOo003oo`00o`04o`00o`03ogMgQoooo`3oool009Wo003o0Oooool00;Ko003o1oooo`0^o`00o`04
ogMgQooMgB7o003oo`00o`Ooool0VOl00?l1ooooo`00k?l00?l00olQ8Mgo003oo`00o`2Po`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03194 
%%ImageSize: 400 412.775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
0 0 1 r
MFill
% Scaling calculations
-0.30553 0.0103764 -0.221274 0.0103764 [
[.5 1.04444 -51.7188 0 ]
[.5 1.04444 51.7188 34 ]
[ 0 0 0 0 ]
[ 1 1.03194 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 0 r
gsave
.5 1.04444 -112.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(W) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
93.188 29.000 moveto
(@) show
103.812 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(300) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
151.812 29.000 moveto
(D) show
162.438 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.03194 L
0 1.03194 L
closepath
clip
newpath
1 0 1 r
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
F
0 g
.001 w
[ ] 0 setdash
.08051 .37214 m
.03839 .38418 L
.02654 .37191 L
.02866 .34383 L
.04437 .32483 L
.08743 .34097 L
.08051 .37214 L
s
.999 .001 .999 r
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
F
0 g
.09619 .3941 m
.06202 .42827 L
.0513 .43065 L
.03949 .41941 L
.03839 .38418 L
.08051 .37214 L
.09619 .3941 L
s
.999 .001 .999 r
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
F
0 g
.08743 .34097 m
.04437 .32483 L
.04205 .31214 L
.05349 .28418 L
.0675 .27319 L
.07889 .27825 L
.09364 .33725 L
.08743 .34097 L
s
.999 .001 .999 r
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
F
0 g
.07547 .498 m
.04865 .46769 L
.0513 .43065 L
.06202 .42827 L
.10248 .44446 L
.08666 .4919 L
.07547 .498 L
s
.998 .002 .998 r
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
F
0 g
.11274 .39961 m
.11274 .43859 L
.10248 .44446 L
.06202 .42827 L
.09619 .3941 L
.11274 .39961 L
s
.999 .001 .999 r
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
F
0 g
.13162 .25171 m
.12396 .23256 L
.09852 .21561 L
.08104 .22436 L
.0662 .2558 L
.0675 .27319 L
.07889 .27825 L
.09845 .27825 L
.13162 .25171 L
s
.998 .002 .998 r
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
F
0 g
.12392 .31221 m
.10004 .33609 L
.09364 .33725 L
.07889 .27825 L
.09845 .27825 L
.12392 .31221 L
s
.998 .002 .998 r
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
F
0 g
.13219 .36181 m
.10004 .33609 L
.09364 .33725 L
.08743 .34097 L
.08051 .37214 L
.09619 .3941 L
.11274 .39961 L
.12774 .39295 L
.13219 .36181 L
s
.997 .003 .997 r
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
F
0 g
.14163 .45097 m
.14404 .47264 L
.12478 .4919 L
.08666 .4919 L
.10248 .44446 L
.11274 .43859 L
.14163 .45097 L
s
.999 .001 .999 r
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
F
0 g
.12538 .57028 m
.14354 .52942 L
.12478 .4919 L
.08666 .4919 L
.07547 .498 L
.07152 .51314 L
.08748 .56001 L
.10684 .57724 L
.12538 .57028 L
s
.996 .004 .996 r
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
F
0 g
.13802 .25598 m
.13162 .25171 L
.09845 .27825 L
.12392 .31221 L
.13978 .30868 L
.14326 .28426 L
.13939 .25718 L
.13802 .25598 L
s
1 0 1 r
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.10142 .18742 L
.09852 .21561 L
.12396 .23256 L
.17426 .19232 L
.16931 .18737 L
.11583 .17209 L
s
.993 .007 .993 r
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
F
0 g
.17722 .33929 m
.17126 .32836 L
.13978 .30868 L
.12392 .31221 L
.10004 .33609 L
.13219 .36181 L
.17722 .33929 L
s
.992 .008 .992 r
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
F
0 g
.12774 .39295 m
.11274 .39961 L
.11274 .43859 L
.14163 .45097 L
.1633 .42931 L
.16367 .42847 L
.12839 .3932 L
.12774 .39295 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.10862 .75636 L
.11239 .70539 L
.11433 .70282 L
.15479 .71018 L
.1718 .72962 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
F
0 g
.11583 .17209 m
.16931 .18737 L
.15942 .12799 L
.13732 .12711 L
.11665 .14778 L
.11583 .17209 L
s
.985 .015 .985 r
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.19038 .34806 L
.17722 .33929 L
.13219 .36181 L
.12774 .39295 L
.12839 .3932 L
.19552 .37641 L
.19786 .36551 L
s
.994 .006 .994 r
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
F
0 g
.14354 .52942 m
.17527 .51582 L
.16089 .47986 L
.14404 .47264 L
.12478 .4919 L
.14354 .52942 L
s
.999 .001 .999 r
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
F
0 g
.1773 .62457 m
.17029 .60004 L
.13853 .57357 L
.12538 .57028 L
.10684 .57724 L
.10016 .60756 L
.11074 .64536 L
.16691 .64536 L
.1773 .62457 L
s
.999 .001 .999 r
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
F
0 g
.18337 .66731 m
.15479 .71018 L
.11433 .70282 L
.1066 .65641 L
.11074 .64536 L
.16691 .64536 L
.18337 .66731 L
s
.999 .001 .999 r
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.12969 .78046 L
.11863 .80447 L
.13187 .83965 L
.1524 .85108 L
.18459 .82695 L
.18576 .8237 L
.14068 .77862 L
s
.998 .002 .998 r
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
F
0 g
.17593 .19399 m
.17426 .19232 L
.12396 .23256 L
.13162 .25171 L
.13802 .25598 L
.17593 .21806 L
.17593 .19399 L
s
.963 .037 .963 r
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
F
0 g
.19552 .37641 m
.19777 .40567 L
.19593 .40831 L
.16367 .42847 L
.12839 .3932 L
.19552 .37641 L
s
.992 .008 .992 r
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.13802 .25598 L
.17593 .21806 L
.18376 .25718 L
s
.987 .013 .987 r
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
F
0 g
.18376 .25718 m
.13939 .25718 L
.14326 .28426 L
.18596 .28426 L
.19806 .26612 L
.18376 .25718 L
s
.986 .014 .986 r
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
F
0 g
.13978 .30868 m
.17126 .32836 L
.18596 .28426 L
.14326 .28426 L
.13978 .30868 L
s
.988 .012 .988 r
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
F
0 g
.1633 .42931 m
.1894 .46846 L
.16089 .47986 L
.14404 .47264 L
.14163 .45097 L
.1633 .42931 L
s
.995 .005 .995 r
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
F
0 g
.19098 .55609 m
.13853 .57357 L
.12538 .57028 L
.14354 .52942 L
.17527 .51582 L
.19098 .51931 L
.19098 .55609 L
s
.997 .003 .997 r
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
F
0 g
.14068 .77862 m
.18576 .8237 L
.19262 .8177 L
.20718 .7983 L
.20578 .78428 L
.1584 .76534 L
.14068 .77862 L
s
1 0 1 r
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
F
0 g
.16931 .18737 m
.17426 .19232 L
.21157 .14568 L
.19201 .11439 L
.18306 .11345 L
.15942 .12799 L
.16931 .18737 L
s
.981 .019 .981 r
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
F
0 g
.20434 .51189 m
.19098 .51931 L
.17527 .51582 L
.16089 .47986 L
.1894 .46846 L
.19729 .46958 L
.20434 .51189 L
s
.992 .008 .992 r
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
F
0 g
.21618 .57709 m
.17029 .60004 L
.13853 .57357 L
.19098 .55609 L
.21618 .57709 L
s
.968 .032 .968 r
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.16367 .42847 L
.1633 .42931 L
.1894 .46846 L
.19729 .46958 L
.20663 .4618 L
s
.995 .005 .995 r
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
F
0 g
.199 .67044 m
.20259 .67545 L
.20487 .68078 L
.18045 .72962 L
.1718 .72962 L
.15479 .71018 L
.18337 .66731 L
.199 .67044 L
s
.993 .007 .993 r
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
F
0 g
.1584 .76534 m
.1718 .72962 L
.18045 .72962 L
.20994 .73617 L
.2193 .75723 L
.20578 .78428 L
.1584 .76534 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.18459 .82695 L
.1524 .85108 L
.15529 .87486 L
.17426 .89462 L
.19184 .88803 L
s
.992 .008 .992 r
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18376 .25718 L
.17593 .21806 L
.17593 .19399 L
.22454 .21019 L
.21083 .26506 L
s
.989 .011 .989 r
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
F
0 g
.21235 .61873 m
.22324 .58061 L
.22267 .57904 L
.21618 .57709 L
.17029 .60004 L
.1773 .62457 L
.21235 .61873 L
s
.98 .02 .98 r
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
F
0 g
.21083 .26506 m
.19806 .26612 L
.18596 .28426 L
.17126 .32836 L
.17722 .33929 L
.19038 .34806 L
.23913 .29931 L
.22418 .27441 L
.21083 .26506 L
s
.995 .005 .995 r
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.199 .67044 L
.18337 .66731 L
.16691 .64536 L
.1773 .62457 L
.21235 .61873 L
.22769 .64175 L
s
.982 .018 .982 r
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
F
0 g
.18045 .72962 m
.20487 .68078 L
.22845 .71026 L
.20994 .73617 L
.18045 .72962 L
s
1 0 1 r
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.23612 .91017 L
.20451 .94177 L
.19036 .93549 L
.17335 .91307 L
.17426 .89462 L
.19184 .88803 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.2399 .20321 L
.22454 .21019 L
.17593 .19399 L
.17426 .19232 L
.21157 .14568 L
.22435 .14995 L
s
.971 .029 .971 r
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
F
0 g
.22935 .57013 m
.22267 .57904 L
.21618 .57709 L
.19098 .55609 L
.19098 .51931 L
.20434 .51189 L
.21189 .51264 L
.23418 .55724 L
.22935 .57013 L
s
.901 .099 .901 r
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
F
0 g
.20663 .4618 m
.19593 .40831 L
.19777 .40567 L
.25228 .42611 L
.24514 .4618 L
.20663 .4618 L
s
.902 .098 .902 r
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.24514 .4618 L
.20663 .4618 L
.19729 .46958 L
.20434 .51189 L
.21189 .51264 L
.23871 .50258 L
.24138 .4919 L
s
.998 .002 .998 r
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
F
0 g
.18576 .8237 m
.18459 .82695 L
.21265 .86202 L
.22809 .86202 L
.24138 .84209 L
.19262 .8177 L
.18576 .8237 L
s
.999 .001 .999 r
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
F
0 g
.19184 .88803 m
.21265 .86202 L
.22809 .86202 L
.24765 .89136 L
.24931 .89883 L
.24514 .90716 L
.23612 .91017 L
.19184 .88803 L
s
.993 .007 .993 r
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
F
0 g
.20718 .7983 m
.24978 .81047 L
.25229 .833 L
.24138 .84209 L
.19262 .8177 L
.20718 .7983 L
s
.999 .001 .999 r
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.25782 .09976 L
.25103 .08845 L
.22262 .08778 L
.19201 .11439 L
.21157 .14568 L
.22435 .14995 L
s
.972 .028 .972 r
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
F
0 g
.22769 .64175 m
.24665 .64386 L
.26019 .6574 L
.26214 .66227 L
.2546 .67545 L
.20259 .67545 L
.199 .67044 L
.22769 .64175 L
s
.973 .027 .973 r
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
F
0 g
.20487 .68078 m
.20259 .67545 L
.2546 .67545 L
.24576 .70641 L
.22845 .71026 L
.20487 .68078 L
s
.931 .069 .931 r
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.2617 .35498 L
.24364 .30081 L
.23913 .29931 L
.19038 .34806 L
.19786 .36551 L
s
.911 .089 .911 r
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
F
0 g
.19786 .36551 m
.25116 .36551 L
.26578 .41667 L
.25228 .42611 L
.19777 .40567 L
.19552 .37641 L
.19786 .36551 L
s
.784 .216 .784 r
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
F
0 g
.23418 .55724 m
.21189 .51264 L
.23871 .50258 L
.267 .52615 L
.26647 .53141 L
.23418 .55724 L
s
.968 .032 .968 r
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.22324 .58061 L
.21235 .61873 L
.22769 .64175 L
.24665 .64386 L
.25116 .63032 L
.23784 .59034 L
s
.985 .015 .985 r
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
F
0 g
.26019 .76573 m
.25901 .7622 L
.2193 .75723 L
.20578 .78428 L
.20718 .7983 L
.24978 .81047 L
.26019 .79833 L
.26019 .76573 L
s
1 0 1 r
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
F
0 g
.26406 .94026 m
.24514 .90716 L
.23612 .91017 L
.20451 .94177 L
.21069 .9558 L
.22944 .97012 L
.24623 .97146 L
.26406 .94026 L
s
.986 .014 .986 r
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.25797 .20773 L
.2399 .20321 L
.22454 .21019 L
.21083 .26506 L
.22418 .27441 L
.27352 .23741 L
.26703 .21578 L
s
.968 .032 .968 r
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
F
0 g
.27272 .74026 m
.25863 .71561 L
.24576 .70641 L
.22845 .71026 L
.20994 .73617 L
.2193 .75723 L
.25901 .7622 L
.27272 .74026 L
s
.998 .002 .998 r
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
F
0 g
.22435 .14995 m
.23431 .15848 L
.28516 .14153 L
.2849 .1384 L
.2757 .1154 L
.25782 .09976 L
.22435 .14995 L
s
.888 .112 .888 r
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
F
0 g
.23784 .59034 m
.26676 .59612 L
.27373 .60775 L
.25116 .63032 L
.23784 .59034 L
s
.995 .005 .995 r
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
F
0 g
.22809 .86202 m
.24138 .84209 L
.25229 .833 L
.2771 .84718 L
.24765 .89136 L
.22809 .86202 L
s
.994 .006 .994 r
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
F
0 g
.25797 .20773 m
.2919 .15117 L
.28516 .14153 L
.23431 .15848 L
.2399 .20321 L
.25797 .20773 L
s
.941 .059 .941 r
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
F
0 g
.28685 .29217 m
.24364 .30081 L
.23913 .29931 L
.22418 .27441 L
.27352 .23741 L
.29931 .2632 L
.30183 .27077 L
.28685 .29217 L
s
.783 .217 .783 r
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.22935 .57013 L
.23418 .55724 L
.26647 .53141 L
.28547 .5599 L
.28665 .56462 L
.27975 .57013 L
s
.936 .064 .936 r
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.23784 .59034 L
.22324 .58061 L
.22267 .57904 L
.22935 .57013 L
.27975 .57013 L
s
.546 .454 .546 r
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
F
0 g
.24138 .4919 m
.29028 .4919 L
.29028 .47685 L
.24514 .4618 L
.24138 .4919 L
s
.449 .551 .449 r
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
F
0 g
.29159 .50859 m
.267 .52615 L
.23871 .50258 L
.24138 .4919 L
.29028 .4919 L
.29209 .50634 L
.29159 .50859 L
s
.81 .19 .81 r
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
F
0 g
.30369 .33706 m
.28878 .35197 L
.2617 .35498 L
.24364 .30081 L
.28685 .29217 L
.30369 .33706 L
s
.9 .1 .9 r
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
F
0 g
.25116 .63032 m
.24665 .64386 L
.26019 .6574 L
.30081 .61678 L
.27373 .60775 L
.25116 .63032 L
s
.923 .077 .923 r
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
F
0 g
.26214 .66227 m
.30232 .67733 L
.30232 .68649 L
.25863 .71561 L
.24576 .70641 L
.2546 .67545 L
.26214 .66227 L
s
.995 .005 .995 r
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
F
0 g
.28577 .89362 m
.30038 .84977 L
.2771 .84718 L
.24765 .89136 L
.24931 .89883 L
.28577 .89362 L
s
.734 .266 .734 r
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
F
0 g
.28878 .35197 m
.2617 .35498 L
.25116 .36551 L
.26578 .41667 L
.27223 .41667 L
.30301 .39468 L
.28878 .35197 L
s
.638 .362 .638 r
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
F
0 g
.24514 .4618 m
.25228 .42611 L
.26578 .41667 L
.27223 .41667 L
.31135 .45579 L
.29028 .47685 L
.24514 .4618 L
s
.987 .013 .987 r
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
F
0 g
.29294 .80379 m
.30723 .84666 L
.30038 .84977 L
.2771 .84718 L
.25229 .833 L
.24978 .81047 L
.26019 .79833 L
.29294 .80379 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.30834 .91619 L
.28577 .89362 L
.24931 .89883 L
.24514 .90716 L
.26406 .94026 L
.30382 .94026 L
s
1 0 1 r
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.26406 .94026 L
.24623 .97146 L
.2581 .98679 L
.28156 .99484 L
.31688 .9838 L
.30382 .94026 L
s
.738 .262 .738 r
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
F
0 g
.27975 .57013 m
.26676 .59612 L
.27373 .60775 L
.30081 .61678 L
.30182 .61666 L
.30596 .61004 L
.29963 .57203 L
.28665 .56462 L
.27975 .57013 L
s
.892 .108 .892 r
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
F
0 g
.27644 .73985 m
.27272 .74026 L
.25863 .71561 L
.30232 .68649 L
.31422 .71824 L
.31304 .72416 L
.27644 .73985 L
s
.966 .034 .966 r
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
F
0 g
.31008 .78236 m
.26019 .76573 L
.26019 .79833 L
.29294 .80379 L
.31008 .78236 L
s
.999 .001 .999 r
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
F
0 g
.25782 .09976 m
.2757 .1154 L
.32639 .07738 L
.32639 .06578 L
.29813 .054 L
.26365 .06498 L
.25103 .08845 L
.25782 .09976 L
s
.984 .016 .984 r
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.34385 .18978 L
.33542 .17293 L
.2919 .15117 L
.25797 .20773 L
.26703 .21578 L
s
.832 .168 .832 r
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
F
0 g
.26019 .6574 m
.26214 .66227 L
.30232 .67733 L
.31276 .6682 L
.31958 .64774 L
.30182 .61666 L
.30081 .61678 L
.26019 .6574 L
s
.95 .05 .95 r
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
F
0 g
.31572 .77913 m
.31008 .78236 L
.26019 .76573 L
.25901 .7622 L
.27272 .74026 L
.27644 .73985 L
.31572 .77913 L
s
.34 .66 .34 r
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
F
0 g
.28547 .5599 m
.31661 .52876 L
.31659 .52859 L
.29159 .50859 L
.267 .52615 L
.26647 .53141 L
.28547 .5599 L
s
.96 .04 .96 r
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
F
0 g
.26703 .21578 m
.34294 .19048 L
.29931 .2632 L
.27352 .23741 L
.26703 .21578 L
s
.897 .103 .897 r
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.32893 .74641 L
.31304 .72416 L
.27644 .73985 L
.31572 .77913 L
.33186 .77555 L
.33212 .77517 L
s
.998 .002 .998 r
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
F
0 g
.32639 .07738 m
.33783 .10311 L
.2849 .1384 L
.2757 .1154 L
.32639 .07738 L
s
.318 .682 .318 r
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
F
0 g
.31274 .39576 m
.30301 .39468 L
.27223 .41667 L
.31135 .45579 L
.33597 .42624 L
.33805 .41685 L
.31274 .39576 L
s
.314 .686 .314 r
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
F
0 g
.28665 .56462 m
.29963 .57203 L
.33422 .5605 L
.33461 .55875 L
.31661 .52876 L
.28547 .5599 L
.28665 .56462 L
s
.993 .007 .993 r
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.31135 .84698 L
.30723 .84666 L
.30038 .84977 L
.28577 .89362 L
.30834 .91619 L
s
.52 .48 .52 r
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.30916 .33761 L
.30369 .33706 L
.28878 .35197 L
.30301 .39468 L
.31274 .39576 L
.33993 .35949 L
s
.203 .797 .203 r
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
F
0 g
.29209 .50634 m
.29028 .4919 L
.29028 .47685 L
.31135 .45579 L
.33761 .47767 L
.34211 .48967 L
.29209 .50634 L
s
.97 .03 .97 r
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
F
0 g
.33186 .77555 m
.34369 .8229 L
.33141 .83695 L
.31135 .84698 L
.30723 .84666 L
.29294 .80379 L
.31008 .78236 L
.31572 .77913 L
.33186 .77555 L
s
.996 .004 .996 r
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
F
0 g
.33542 .17293 m
.35189 .12351 L
.34918 .11446 L
.33783 .10311 L
.2849 .1384 L
.28516 .14153 L
.2919 .15117 L
.33542 .17293 L
s
.802 .198 .802 r
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34746 .29931 L
.34027 .27776 L
.30183 .27077 L
.28685 .29217 L
.30369 .33706 L
.30916 .33761 L
s
.12 .88 .12 r
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.34211 .48967 L
.29209 .50634 L
.29159 .50859 L
.31659 .52859 L
.35214 .50193 L
.35227 .50152 L
s
.303 .697 .303 r
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.29963 .57203 L
.30596 .61004 L
.33943 .59889 L
.3466 .58217 L
.33422 .5605 L
s
.947 .053 .947 r
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
F
0 g
.30183 .27077 m
.29931 .2632 L
.34294 .19048 L
.34385 .18978 L
.34627 .19084 L
.34746 .1927 L
.34746 .27148 L
.34027 .27776 L
.30183 .27077 L
s
.495 .505 .495 r
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
F
0 g
.33943 .59889 m
.35868 .63097 L
.35735 .63695 L
.31958 .64774 L
.30182 .61666 L
.30596 .61004 L
.33943 .59889 L
s
.792 .208 .792 r
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
F
0 g
.30232 .68649 m
.30232 .67733 L
.31276 .6682 L
.35777 .6862 L
.35585 .70159 L
.31422 .71824 L
.30232 .68649 L
s
.997 .003 .997 r
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
F
0 g
.30834 .91619 m
.32714 .87857 L
.36852 .89512 L
.36852 .90716 L
.36571 .91842 L
.31135 .92521 L
.30834 .91619 L
s
.525 .475 .525 r
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
F
0 g
.30916 .33761 m
.34043 .35548 L
.35906 .34617 L
.35949 .34445 L
.35949 .31135 L
.34746 .29931 L
.30916 .33761 L
s
.256 .744 .256 r
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.3625 .40463 L
.33805 .41685 L
.31274 .39576 L
.33993 .35949 L
s
.115 .885 .115 r
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
F
0 g
.35214 .50193 m
.35843 .53969 L
.33461 .55875 L
.31661 .52876 L
.31659 .52859 L
.35214 .50193 L
s
.999 .001 .999 r
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
F
0 g
.30382 .94026 m
.31135 .92521 L
.36571 .91842 L
.37594 .94094 L
.32043 .98535 L
.31955 .98529 L
.31688 .9838 L
.30382 .94026 L
s
.115 .885 .115 r
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
F
0 g
.33761 .47767 m
.31135 .45579 L
.33597 .42624 L
.3625 .45278 L
.33761 .47767 L
s
.631 .369 .631 r
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
F
0 g
.31276 .6682 m
.35777 .6862 L
.37805 .66592 L
.35735 .63695 L
.31958 .64774 L
.31276 .6682 L
s
.8 .2 .8 r
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
F
0 g
.32893 .74641 m
.37153 .7251 L
.35585 .70159 L
.31422 .71824 L
.31304 .72416 L
.32893 .74641 L
s
.988 .012 .988 r
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.32714 .87857 L
.31135 .84698 L
.33141 .83695 L
.37554 .88108 L
.36852 .89512 L
s
.843 .157 .843 r
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3941 .7552 L
.38816 .73342 L
.37153 .7251 L
.32893 .74641 L
.33212 .77517 L
s
.999 .001 .999 r
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
F
0 g
.32639 .06578 m
.34085 .05426 L
.38295 .05057 L
.39378 .05592 L
.38466 .08785 L
.34918 .11446 L
.33783 .10311 L
.32639 .07738 L
.32639 .06578 L
s
.898 .102 .898 r
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
F
0 g
.34746 .1927 m
.34746 .27148 L
.39345 .25998 L
.39783 .23588 L
.34746 .1927 L
s
.241 .759 .241 r
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
F
0 g
.33993 .35949 m
.34043 .35548 L
.35906 .34617 L
.39472 .36994 L
.38778 .40463 L
.3625 .40463 L
.33993 .35949 L
s
.114 .886 .114 r
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
F
0 g
.33805 .41685 m
.33597 .42624 L
.3625 .45278 L
.39741 .45278 L
.38778 .40463 L
.3625 .40463 L
.33805 .41685 L
s
.067 .933 .067 r
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
F
0 g
.35227 .50152 m
.40463 .48989 L
.40463 .4618 L
.39741 .45278 L
.3625 .45278 L
.33761 .47767 L
.34211 .48967 L
.35227 .50152 L
s
.119 .881 .119 r
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
F
0 g
.33422 .5605 m
.33461 .55875 L
.35843 .53969 L
.3956 .55208 L
.37841 .58217 L
.3466 .58217 L
.33422 .5605 L
s
.198 .802 .198 r
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
F
0 g
.3466 .58217 m
.37841 .58217 L
.38894 .60676 L
.35868 .63097 L
.33943 .59889 L
.3466 .58217 L
s
.923 .077 .923 r
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
F
0 g
.33212 .77517 m
.38985 .76795 L
.3932 .77716 L
.34746 .8229 L
.34369 .8229 L
.33186 .77555 L
.33212 .77517 L
s
.972 .028 .972 r
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
F
0 g
.37554 .88108 m
.38164 .87574 L
.39034 .84096 L
.38592 .83389 L
.34746 .8229 L
.34369 .8229 L
.33141 .83695 L
.37554 .88108 L
s
1 0 1 r
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
F
0 g
.3535 1.00524 m
.37418 1.00309 L
.39933 .98428 L
.40149 .98051 L
.39091 .95142 L
.37594 .94094 L
.32043 .98535 L
.3535 1.00524 L
s
.988 .012 .988 r
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.33542 .17293 L
.34385 .18978 L
.34627 .19084 L
.39289 .17012 L
.40693 .13269 L
s
.785 .215 .785 r
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
F
0 g
.34746 .29931 m
.35949 .31135 L
.39289 .30578 L
.40222 .27313 L
.39345 .25998 L
.34746 .27148 L
.34027 .27776 L
.34746 .29931 L
s
.063 .937 .063 r
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.40463 .48989 L
.35227 .50152 L
.35214 .50193 L
.35843 .53969 L
.3956 .55208 L
.40965 .54506 L
.42031 .52373 L
s
.935 .065 .935 r
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
F
0 g
.3932 .77716 m
.40095 .7888 L
.38592 .83389 L
.34746 .8229 L
.3932 .77716 L
s
.997 .003 .997 r
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.35189 .12351 L
.34918 .11446 L
.38466 .08785 L
.40704 .1326 L
.40693 .13269 L
s
.541 .459 .541 r
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
F
0 g
.35949 .31135 m
.39289 .30578 L
.40388 .32225 L
.35949 .34445 L
.35949 .31135 L
s
.705 .295 .705 r
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
F
0 g
.35777 .6862 m
.37805 .66592 L
.38958 .66697 L
.38958 .73142 L
.38816 .73342 L
.37153 .7251 L
.35585 .70159 L
.35777 .6862 L
s
.315 .685 .315 r
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.42199 .34514 L
.42032 .33596 L
.40388 .32225 L
.35949 .34445 L
.35906 .34617 L
.39472 .36994 L
s
.391 .609 .391 r
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.39627 .66576 L
.38958 .66697 L
.37805 .66592 L
.35735 .63695 L
.35868 .63097 L
.38894 .60676 L
.40574 .61305 L
.42295 .63314 L
s
.97 .03 .97 r
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
F
0 g
.39289 .17012 m
.34627 .19084 L
.34746 .1927 L
.39783 .23588 L
.43799 .21357 L
.43547 .1985 L
.39289 .17012 L
s
.649 .351 .649 r
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.39627 .66576 L
.38958 .66697 L
.38958 .73142 L
s
.999 .001 .999 r
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
F
0 g
.42827 .08265 m
.42171 .1286 L
.40704 .1326 L
.38466 .08785 L
.39378 .05592 L
.40467 .05511 L
.42827 .08265 L
s
.096 .904 .096 r
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
F
0 g
.40965 .54506 m
.3956 .55208 L
.37841 .58217 L
.38894 .60676 L
.40574 .61305 L
.42569 .57314 L
.40965 .54506 L
s
.994 .006 .994 r
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
F
0 g
.36852 .89512 m
.36852 .90716 L
.43773 .90716 L
.43085 .88652 L
.42905 .88365 L
.38164 .87574 L
.37554 .88108 L
.36852 .89512 L
s
.999 .001 .999 r
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
F
0 g
.36852 .90716 m
.43773 .90716 L
.4413 .91251 L
.44083 .91813 L
.39091 .95142 L
.37594 .94094 L
.36571 .91842 L
.36852 .90716 L
s
.972 .028 .972 r
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.44515 .8182 L
.43615 .802 L
.40095 .7888 L
.38592 .83389 L
.39034 .84096 L
.43515 .84096 L
.44212 .83486 L
s
.979 .021 .979 r
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
F
0 g
.43515 .84096 m
.39034 .84096 L
.38164 .87574 L
.42905 .88365 L
.43515 .84096 L
s
.616 .384 .616 r
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.40222 .27313 L
.39289 .30578 L
.40388 .32225 L
.42032 .33596 L
.45364 .28598 L
s
.994 .006 .994 r
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
F
0 g
.40693 .13269 m
.39289 .17012 L
.43547 .1985 L
.46231 .14484 L
.42171 .1286 L
.40704 .1326 L
.40693 .13269 L
s
.094 .906 .094 r
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
F
0 g
.39472 .36994 m
.40463 .3625 L
.44224 .40012 L
.4287 .40463 L
.38778 .40463 L
.39472 .36994 L
s
.051 .949 .051 r
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
F
0 g
.39741 .45278 m
.38778 .40463 L
.4287 .40463 L
.4287 .44977 L
.40463 .4618 L
.39741 .45278 L
s
.856 .144 .856 r
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
F
0 g
.38958 .73142 m
.42569 .70254 L
.44519 .7047 L
.45196 .71485 L
.44364 .74812 L
.3941 .7552 L
.38816 .73342 L
.38958 .73142 L
s
.891 .109 .891 r
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
F
0 g
.43799 .21357 m
.48908 .24609 L
.47921 .27405 L
.45879 .28426 L
.45364 .28598 L
.40222 .27313 L
.39345 .25998 L
.39783 .23588 L
.43799 .21357 L
s
.156 .844 .156 r
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
F
0 g
.44224 .40012 m
.40463 .3625 L
.42199 .34514 L
.44676 .35615 L
.44676 .39947 L
.44224 .40012 L
s
.145 .855 .145 r
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
F
0 g
.42569 .57314 m
.40574 .61305 L
.42295 .63314 L
.44991 .61388 L
.45895 .58977 L
.42569 .57314 L
s
.729 .271 .729 r
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
F
0 g
.45278 .68448 m
.44519 .7047 L
.42569 .70254 L
.39627 .66576 L
.42241 .63962 L
.45278 .66492 L
.45278 .68448 L
s
.93 .07 .93 r
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
F
0 g
.44364 .74812 m
.45508 .76414 L
.43615 .802 L
.40095 .7888 L
.3932 .77716 L
.38985 .76795 L
.3941 .7552 L
.44364 .74812 L
s
1 0 1 r
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
F
0 g
.44083 .91813 m
.39091 .95142 L
.40149 .98051 L
.43035 .98241 L
.45269 .97151 L
.46364 .95463 L
.44083 .91813 L
s
.067 .933 .067 r
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.44676 .39947 L
.44224 .40012 L
.4287 .40463 L
.4287 .44977 L
.45332 .44361 L
.47289 .42078 L
.47365 .41868 L
s
.999 .001 .999 r
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.46079 .03188 L
.42341 .03645 L
.40467 .05511 L
.42827 .08265 L
.45879 .08265 L
.47926 .05196 L
.47825 .04088 L
s
.997 .003 .997 r
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
F
0 g
.45879 .08265 m
.47963 .12432 L
.46348 .14451 L
.46231 .14484 L
.42171 .1286 L
.42827 .08265 L
.45879 .08265 L
s
.044 .956 .044 r
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
F
0 g
.40463 .4618 m
.4287 .44977 L
.45332 .44361 L
.47017 .48573 L
.41821 .508 L
.40463 .48989 L
.40463 .4618 L
s
.078 .922 .078 r
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.46853 .54181 L
.4607 .5888 L
.45895 .58977 L
.42569 .57314 L
.40965 .54506 L
.42031 .52373 L
s
.491 .509 .491 r
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
F
0 g
.45364 .28598 m
.42032 .33596 L
.42199 .34514 L
.44676 .35615 L
.45879 .35347 L
.45879 .28426 L
.45364 .28598 L
s
.989 .011 .989 r
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
F
0 g
.44212 .83486 m
.48158 .86116 L
.43085 .88652 L
.42905 .88365 L
.43515 .84096 L
.44212 .83486 L
s
.527 .473 .527 r
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
F
0 g
.42295 .63314 m
.42241 .63962 L
.45278 .66492 L
.4876 .64751 L
.48939 .64348 L
.44991 .61388 L
.42295 .63314 L
s
.998 .002 .998 r
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.4413 .91251 L
.43773 .90716 L
.43085 .88652 L
.48158 .86116 L
.49001 .86432 L
.4929 .86804 L
s
.739 .261 .739 r
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
F
0 g
.45879 .28426 m
.47921 .27405 L
.50312 .31789 L
.48889 .35347 L
.45879 .35347 L
.45879 .28426 L
s
.337 .663 .337 r
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.50135 .37841 L
.48889 .35347 L
.45879 .35347 L
.44676 .35615 L
.44676 .39947 L
.47365 .41868 L
s
.067 .933 .067 r
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
F
0 g
.42031 .52373 m
.41821 .508 L
.47017 .48573 L
.48708 .48949 L
.49591 .51597 L
.48719 .53559 L
.46853 .54181 L
.42031 .52373 L
s
.976 .024 .976 r
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
F
0 g
.48889 .80571 m
.44515 .8182 L
.43615 .802 L
.45508 .76414 L
.48889 .76836 L
.48889 .80571 L
s
.985 .015 .985 r
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
F
0 g
.43547 .1985 m
.43799 .21357 L
.48908 .24609 L
.49983 .23977 L
.51534 .19636 L
.46348 .14451 L
.46231 .14484 L
.43547 .1985 L
s
.963 .037 .963 r
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
F
0 g
.48889 .76836 m
.45508 .76414 L
.44364 .74812 L
.45196 .71485 L
.48562 .71905 L
.49321 .76458 L
.48889 .76836 L
s
.051 .949 .051 r
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
F
0 g
.47289 .42078 m
.49981 .47463 L
.48708 .48949 L
.47017 .48573 L
.45332 .44361 L
.47289 .42078 L
s
.29 .71 .29 r
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
F
0 g
.45895 .58977 m
.44991 .61388 L
.48939 .64348 L
.496 .63852 L
.47183 .59019 L
.4607 .5888 L
.45895 .58977 L
s
.8 .2 .8 r
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
F
0 g
.4876 .64751 m
.45278 .66492 L
.45278 .68448 L
.49992 .68448 L
.4876 .64751 L
s
.943 .057 .943 r
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
F
0 g
.50694 .69291 m
.50694 .69953 L
.50594 .70454 L
.48562 .71905 L
.45196 .71485 L
.44519 .7047 L
.45278 .68448 L
.49992 .68448 L
.50694 .69291 L
s
.992 .008 .992 r
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
F
0 g
.49001 .86432 m
.48158 .86116 L
.44212 .83486 L
.44515 .8182 L
.48889 .80571 L
.49842 .81387 L
.49001 .86432 L
s
1 0 1 r
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
F
0 g
.5105 .93355 m
.47905 .95385 L
.46364 .95463 L
.44083 .91813 L
.4413 .91251 L
.48421 .89412 L
.5105 .93355 L
s
.998 .002 .998 r
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
F
0 g
.47926 .05196 m
.51159 .08429 L
.49111 .12014 L
.47963 .12432 L
.45879 .08265 L
.47926 .05196 L
s
.2 .8 .2 r
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
F
0 g
.46853 .54181 m
.48719 .53559 L
.5113 .56453 L
.50336 .58569 L
.47183 .59019 L
.4607 .5888 L
.46853 .54181 L
s
.689 .311 .689 r
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
F
0 g
.50336 .58569 m
.47183 .59019 L
.496 .63852 L
.50309 .63537 L
.50956 .59654 L
.50336 .58569 L
s
.168 .832 .168 r
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
F
0 g
.47365 .41868 m
.49916 .40477 L
.53206 .42452 L
.52157 .46647 L
.49981 .47463 L
.47289 .42078 L
.47365 .41868 L
s
.994 .006 .994 r
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
F
0 g
.53055 .13705 m
.52286 .19089 L
.51534 .19636 L
.46348 .14451 L
.47963 .12432 L
.49111 .12014 L
.53055 .13705 L
s
.979 .021 .979 r
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
F
0 g
.51734 .7619 m
.525 .7236 L
.50594 .70454 L
.48562 .71905 L
.49321 .76458 L
.51734 .7619 L
s
.999 .001 .999 r
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
F
0 g
.47825 .04088 m
.49754 .02758 L
.53025 .02801 L
.54929 .04309 L
.53083 .08002 L
.51159 .08429 L
.47926 .05196 L
.47825 .04088 L
s
.915 .085 .915 r
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
F
0 g
.48939 .64348 m
.496 .63852 L
.50309 .63537 L
.51978 .63954 L
.52876 .67545 L
.50694 .69291 L
.49992 .68448 L
.4876 .64751 L
.48939 .64348 L
s
.994 .006 .994 r
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
F
0 g
.51838 .81387 m
.49842 .81387 L
.48889 .80571 L
.48889 .76836 L
.49321 .76458 L
.51734 .7619 L
.5343 .77038 L
.54258 .78363 L
.51838 .81387 L
s
.998 .002 .998 r
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51848 .86804 L
.4929 .86804 L
.49001 .86432 L
.49842 .81387 L
.51838 .81387 L
.54053 .84157 L
s
.999 .001 .999 r
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
F
0 g
.4929 .86804 m
.48421 .89412 L
.5105 .93355 L
.51181 .93366 L
.54946 .90555 L
.5495 .90527 L
.51848 .86804 L
.4929 .86804 L
s
.166 .834 .166 r
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
F
0 g
.49591 .51597 m
.48708 .48949 L
.49981 .47463 L
.52157 .46647 L
.53589 .47841 L
.5265 .51597 L
.49591 .51597 L
s
.37 .63 .37 r
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
F
0 g
.48719 .53559 m
.5113 .56453 L
.52981 .5599 L
.54907 .53101 L
.5265 .51597 L
.49591 .51597 L
.48719 .53559 L
s
.998 .002 .998 r
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
F
0 g
.51159 .08429 m
.49111 .12014 L
.53055 .13705 L
.55709 .12378 L
.5581 .11274 L
.53083 .08002 L
.51159 .08429 L
s
.795 .205 .795 r
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.54649 .36336 L
.50135 .37841 L
.48889 .35347 L
.50312 .31789 L
.52484 .32006 L
s
.95 .05 .95 r
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
F
0 g
.50956 .59654 m
.50309 .63537 L
.51978 .63954 L
.5507 .63071 L
.55352 .60533 L
.50956 .59654 L
s
.943 .057 .943 r
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
F
0 g
.56482 .26143 m
.57949 .29956 L
.52484 .32006 L
.50312 .31789 L
.47921 .27405 L
.48908 .24609 L
.49983 .23977 L
.56482 .26143 L
s
.852 .148 .852 r
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
F
0 g
.5113 .56453 m
.50336 .58569 L
.50956 .59654 L
.55352 .60533 L
.56283 .59292 L
.52981 .5599 L
.5113 .56453 L
s
.827 .173 .827 r
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
F
0 g
.54878 .42173 m
.53206 .42452 L
.49916 .40477 L
.50135 .37841 L
.54649 .36336 L
.56771 .36867 L
.57425 .39262 L
.54878 .42173 L
s
.991 .009 .991 r
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
F
0 g
.51978 .63954 m
.5507 .63071 L
.57071 .65406 L
.56909 .67185 L
.56497 .67545 L
.52876 .67545 L
.51978 .63954 L
s
.983 .017 .983 r
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
F
0 g
.52876 .67545 m
.56497 .67545 L
.5581 .69953 L
.50694 .69953 L
.50694 .69291 L
.52876 .67545 L
s
.985 .015 .985 r
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
F
0 g
.50694 .69953 m
.50594 .70454 L
.525 .7236 L
.5581 .7236 L
.5581 .69953 L
.50694 .69953 L
s
.993 .007 .993 r
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
F
0 g
.5343 .77038 m
.56412 .73062 L
.5581 .7236 L
.525 .7236 L
.51734 .7619 L
.5343 .77038 L
s
.835 .165 .835 r
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
F
0 g
.5265 .51597 m
.53589 .47841 L
.58428 .48532 L
.58461 .48991 L
.56336 .52816 L
.54907 .53101 L
.5265 .51597 L
s
.999 .001 .999 r
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
F
0 g
.54053 .84157 m
.51838 .81387 L
.54258 .78363 L
.56603 .79144 L
.57169 .80163 L
.56231 .83915 L
.54053 .84157 L
s
.994 .006 .994 r
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
F
0 g
.55709 .12378 m
.57916 .14584 L
.56151 .18703 L
.52286 .19089 L
.53055 .13705 L
.55709 .12378 L
s
.931 .069 .931 r
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
F
0 g
.52484 .32006 m
.57949 .29956 L
.59813 .3139 L
.56771 .36867 L
.54649 .36336 L
.52484 .32006 L
s
.842 .158 .842 r
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.58428 .48532 L
.53589 .47841 L
.52157 .46647 L
.53206 .42452 L
.54878 .42173 L
.57396 .45196 L
s
.999 .001 .999 r
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
F
0 g
.58009 .87734 m
.5495 .90527 L
.51848 .86804 L
.54053 .84157 L
.56231 .83915 L
.58399 .86083 L
.58009 .87734 L
s
.985 .015 .985 r
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
F
0 g
.52286 .19089 m
.51534 .19636 L
.49983 .23977 L
.56482 .26143 L
.58819 .23139 L
.58819 .20989 L
.56151 .18703 L
.52286 .19089 L
s
.928 .072 .928 r
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
F
0 g
.52981 .5599 m
.56283 .59292 L
.56481 .59212 L
.57889 .54989 L
.56336 .52816 L
.54907 .53101 L
.52981 .5599 L
s
.999 .001 .999 r
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
F
0 g
.53083 .08002 m
.5581 .11274 L
.59082 .08547 L
.58231 .04716 L
.56868 .04102 L
.54929 .04309 L
.53083 .08002 L
s
.998 .002 .998 r
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
F
0 g
.57515 .7343 m
.56412 .73062 L
.5343 .77038 L
.54258 .78363 L
.56603 .79144 L
.58649 .76076 L
.57515 .7343 L
s
.988 .012 .988 r
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
F
0 g
.55352 .60533 m
.5507 .63071 L
.57071 .65406 L
.61667 .6278 L
.60658 .60257 L
.56481 .59212 L
.56283 .59292 L
.55352 .60533 L
s
.997 .003 .997 r
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
F
0 g
.5988 .71853 m
.60272 .69107 L
.56909 .67185 L
.56497 .67545 L
.5581 .69953 L
.5581 .7236 L
.56412 .73062 L
.57515 .7343 L
.5988 .71853 L
s
.93 .07 .93 r
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.61967 .40625 L
.57425 .39262 L
.54878 .42173 L
.57396 .45196 L
s
.998 .002 .998 r
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
F
0 g
.5581 .11274 m
.59082 .08547 L
.62279 .10146 L
.61293 .14584 L
.57916 .14584 L
.55709 .12378 L
.5581 .11274 L
s
.994 .006 .994 r
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
F
0 g
.6193 .15301 m
.62253 .18536 L
.58819 .20989 L
.56151 .18703 L
.57916 .14584 L
.61293 .14584 L
.6193 .15301 L
s
.98 .02 .98 r
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
F
0 g
.6258 .55659 m
.62851 .5587 L
.60658 .60257 L
.56481 .59212 L
.57889 .54989 L
.6258 .55659 L
s
1 0 1 r
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
F
0 g
.60689 .85247 m
.62463 .82584 L
.6212 .8087 L
.57169 .80163 L
.56231 .83915 L
.58399 .86083 L
.60689 .85247 L
s
.977 .023 .977 r
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
F
0 g
.57396 .45196 m
.58549 .4827 L
.60086 .47416 L
.63412 .44565 L
.62346 .40657 L
.61967 .40625 L
.57396 .45196 L
s
.958 .042 .958 r
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.6258 .55659 L
.57889 .54989 L
.56336 .52816 L
.58461 .48991 L
.61087 .5118 L
s
.999 .001 .999 r
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.63593 .77936 L
.6212 .8087 L
.57169 .80163 L
.56603 .79144 L
.58649 .76076 L
.63369 .7675 L
s
.982 .018 .982 r
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
F
0 g
.63934 .35799 m
.6323 .39675 L
.62346 .40657 L
.61967 .40625 L
.57425 .39262 L
.56771 .36867 L
.59813 .3139 L
.60624 .31436 L
.63755 .33225 L
.63934 .33642 L
.63934 .35799 L
s
.999 .001 .999 r
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
F
0 g
.65683 .67078 m
.65948 .65559 L
.65359 .64794 L
.61667 .6278 L
.57071 .65406 L
.56909 .67185 L
.60272 .69107 L
.65683 .67078 L
s
.999 .001 .999 r
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
F
0 g
.63369 .7675 m
.58649 .76076 L
.57515 .7343 L
.5988 .71853 L
.64262 .74483 L
.63369 .7675 L
s
.977 .023 .977 r
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
F
0 g
.58819 .23139 m
.63538 .24487 L
.64138 .25287 L
.60624 .31436 L
.59813 .3139 L
.57949 .29956 L
.56482 .26143 L
.58819 .23139 L
s
.999 .001 .999 r
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
F
0 g
.58231 .04716 m
.59082 .08547 L
.62279 .10146 L
.65661 .08455 L
.65986 .07851 L
.6589 .07487 L
.63557 .04488 L
.60926 .03658 L
.58231 .04716 L
s
.987 .013 .987 r
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
F
0 g
.64315 .19825 m
.63538 .24487 L
.58819 .23139 L
.58819 .20989 L
.62253 .18536 L
.64315 .19825 L
s
.999 .001 .999 r
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
F
0 g
.64262 .74483 m
.65312 .73533 L
.66261 .68811 L
.65683 .67078 L
.60272 .69107 L
.5988 .71853 L
.64262 .74483 L
s
.98 .02 .98 r
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.65063 .49904 L
.60086 .47416 L
.58549 .4827 L
.58428 .48532 L
.58461 .48991 L
.61087 .5118 L
s
.994 .006 .994 r
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.63412 .44565 L
.60086 .47416 L
.65063 .49904 L
.66539 .48674 L
.66127 .4661 L
s
.987 .013 .987 r
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
F
0 g
.61087 .5118 m
.64837 .50243 L
.64837 .55717 L
.62851 .5587 L
.6258 .55659 L
.61087 .5118 L
s
.996 .004 .996 r
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
F
0 g
.60658 .60257 m
.61667 .6278 L
.65359 .64794 L
.66579 .56253 L
.64837 .55717 L
.62851 .5587 L
.60658 .60257 L
s
.998 .002 .998 r
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.6193 .15301 L
.61293 .14584 L
.62279 .10146 L
.65661 .08455 L
.67702 .13898 L
.67276 .14537 L
s
.995 .005 .995 r
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.64315 .19825 L
.62253 .18536 L
.6193 .15301 L
.67276 .14537 L
s
.986 .014 .986 r
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
F
0 g
.63755 .33225 m
.60624 .31436 L
.64138 .25287 L
.67229 .25596 L
.67803 .30189 L
.63755 .33225 L
s
.993 .007 .993 r
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
F
0 g
.67888 .19428 m
.68448 .1982 L
.68448 .24648 L
.67229 .25596 L
.64138 .25287 L
.63538 .24487 L
.64315 .19825 L
.67888 .19428 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.62346 .40657 L
.63412 .44565 L
.65439 .45579 L
.6942 .41597 L
.69095 .40512 L
s
.997 .003 .997 r
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
F
0 g
.69278 .50385 m
.6788 .55974 L
.66579 .56253 L
.64837 .55717 L
.64837 .50243 L
.65063 .49904 L
.66539 .48674 L
.69278 .50385 L
s
.994 .006 .994 r
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.6323 .39675 L
.63934 .35799 L
.69871 .38767 L
.69095 .40512 L
s
.995 .005 .995 r
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
F
0 g
.69871 .38767 m
.63934 .35799 L
.63934 .33642 L
.6905 .35347 L
.70984 .37282 L
.69871 .38767 L
s
.999 .001 .999 r
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
F
0 g
.71021 .57283 m
.6788 .55974 L
.66579 .56253 L
.65359 .64794 L
.65948 .65559 L
.68528 .64634 L
.7148 .60741 L
.71021 .57283 L
s
.992 .008 .992 r
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
F
0 g
.6905 .35347 m
.70281 .31654 L
.68222 .30282 L
.67803 .30189 L
.63755 .33225 L
.63934 .33642 L
.6905 .35347 L
s
.998 .002 .998 r
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
F
0 g
.66127 .4661 m
.65439 .45579 L
.6942 .41597 L
.71457 .43343 L
.71457 .45278 L
.66127 .4661 L
s
.999 .001 .999 r
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
F
0 g
.67702 .13898 m
.71774 .13446 L
.73109 .1173 L
.71883 .09307 L
.69623 .07835 L
.65986 .07851 L
.65661 .08455 L
.67702 .13898 L
s
.999 .001 .999 r
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.71984 .46331 L
.71457 .45278 L
.66127 .4661 L
.66539 .48674 L
.69278 .50385 L
.70077 .50145 L
s
.998 .002 .998 r
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
F
0 g
.67276 .14537 m
.67888 .19428 L
.68448 .1982 L
.72469 .19016 L
.72962 .18195 L
.71774 .13446 L
.67702 .13898 L
.67276 .14537 L
s
.994 .006 .994 r
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.68448 .24648 L
.67229 .25596 L
.67803 .30189 L
.68222 .30282 L
.71796 .279 L
s
.998 .002 .998 r
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
F
0 g
.70984 .37282 m
.6905 .35347 L
.70281 .31654 L
.73934 .32176 L
.73994 .32209 L
.74032 .32439 L
.72561 .36852 L
.70984 .37282 L
s
.998 .002 .998 r
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
F
0 g
.72199 .25482 m
.68448 .24648 L
.68448 .1982 L
.72469 .19016 L
.74888 .23852 L
.74415 .24595 L
.72199 .25482 L
s
.995 .005 .995 r
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.68222 .30282 L
.70281 .31654 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.7296 .56238 L
.71021 .57283 L
.6788 .55974 L
.69278 .50385 L
.70077 .50145 L
s
.999 .001 .999 r
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
F
0 g
.69095 .40512 m
.69871 .38767 L
.70984 .37282 L
.72561 .36852 L
.76792 .40025 L
.76574 .4115 L
.71457 .43343 L
.6942 .41597 L
.69095 .40512 L
s
1 0 1 r
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
F
0 g
.70077 .50145 m
.74554 .52064 L
.74845 .51904 L
.76283 .47825 L
.7617 .47527 L
.71984 .46331 L
.70077 .50145 L
s
.998 .002 .998 r
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
F
0 g
.71796 .279 m
.72199 .25482 L
.74415 .24595 L
.76573 .2963 L
.73994 .32209 L
.73934 .32176 L
.71796 .279 L
s
.999 .001 .999 r
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
F
0 g
.71984 .46331 m
.7617 .47527 L
.77492 .43483 L
.76574 .4115 L
.71457 .43343 L
.71457 .45278 L
.71984 .46331 L
s
1 0 1 r
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
F
0 g
.71774 .13446 m
.72962 .18195 L
.77455 .17072 L
.77633 .14483 L
.76678 .13038 L
.73823 .11725 L
.73109 .1173 L
.71774 .13446 L
s
.999 .001 .999 r
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
F
0 g
.72962 .18195 m
.77455 .17072 L
.78381 .17992 L
.79029 .21529 L
.7851 .22864 L
.74888 .23852 L
.72469 .19016 L
.72962 .18195 L
s
.999 .001 .999 r
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
F
0 g
.72561 .36852 m
.74032 .32439 L
.79363 .35637 L
.78189 .3899 L
.76792 .40025 L
.72561 .36852 L
s
.999 .001 .999 r
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
F
0 g
.74415 .24595 m
.74888 .23852 L
.7851 .22864 L
.80352 .24875 L
.80729 .27786 L
.79707 .2963 L
.76573 .2963 L
.74415 .24595 L
s
.999 .001 .999 r
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
F
0 g
.74032 .32439 m
.73994 .32209 L
.76573 .2963 L
.79707 .2963 L
.80742 .31551 L
.80256 .349 L
.79363 .35637 L
.74032 .32439 L
s
1 0 1 r
.875 .10319 m
.875 .1197 L
.95833 .1197 L
.95833 .10319 L
F
.98 .02 .98 r
.875 .1197 m
.875 .13622 L
.95833 .13622 L
.95833 .1197 L
F
.959 .041 .959 r
.875 .13622 m
.875 .15273 L
.95833 .15273 L
.95833 .13622 L
F
.939 .061 .939 r
.875 .15273 m
.875 .16924 L
.95833 .16924 L
.95833 .15273 L
F
.918 .082 .918 r
.875 .16924 m
.875 .18575 L
.95833 .18575 L
.95833 .16924 L
F
.898 .102 .898 r
.875 .18575 m
.875 .20226 L
.95833 .20226 L
.95833 .18575 L
F
.878 .122 .878 r
.875 .20226 m
.875 .21877 L
.95833 .21877 L
.95833 .20226 L
F
.857 .143 .857 r
.875 .21877 m
.875 .23528 L
.95833 .23528 L
.95833 .21877 L
F
.837 .163 .837 r
.875 .23528 m
.875 .25179 L
.95833 .25179 L
.95833 .23528 L
F
.816 .184 .816 r
.875 .25179 m
.875 .2683 L
.95833 .2683 L
.95833 .25179 L
F
.796 .204 .796 r
.875 .2683 m
.875 .28481 L
.95833 .28481 L
.95833 .2683 L
F
.776 .224 .776 r
.875 .28481 m
.875 .30133 L
.95833 .30133 L
.95833 .28481 L
F
.755 .245 .755 r
.875 .30133 m
.875 .31784 L
.95833 .31784 L
.95833 .30133 L
F
.735 .265 .735 r
.875 .31784 m
.875 .33435 L
.95833 .33435 L
.95833 .31784 L
F
.714 .286 .714 r
.875 .33435 m
.875 .35086 L
.95833 .35086 L
.95833 .33435 L
F
.694 .306 .694 r
.875 .35086 m
.875 .36737 L
.95833 .36737 L
.95833 .35086 L
F
.673 .327 .673 r
.875 .36737 m
.875 .38388 L
.95833 .38388 L
.95833 .36737 L
F
.653 .347 .653 r
.875 .38388 m
.875 .40039 L
.95833 .40039 L
.95833 .38388 L
F
.633 .367 .633 r
.875 .40039 m
.875 .4169 L
.95833 .4169 L
.95833 .40039 L
F
.612 .388 .612 r
.875 .4169 m
.875 .43341 L
.95833 .43341 L
.95833 .4169 L
F
.592 .408 .592 r
.875 .43341 m
.875 .44992 L
.95833 .44992 L
.95833 .43341 L
F
.571 .429 .571 r
.875 .44992 m
.875 .46644 L
.95833 .46644 L
.95833 .44992 L
F
.551 .449 .551 r
.875 .46644 m
.875 .48295 L
.95833 .48295 L
.95833 .46644 L
F
.531 .469 .531 r
.875 .48295 m
.875 .49946 L
.95833 .49946 L
.95833 .48295 L
F
.51 .49 .51 r
.875 .49946 m
.875 .51597 L
.95833 .51597 L
.95833 .49946 L
F
.49 .51 .49 r
.875 .51597 m
.875 .53248 L
.95833 .53248 L
.95833 .51597 L
F
.469 .531 .469 r
.875 .53248 m
.875 .54899 L
.95833 .54899 L
.95833 .53248 L
F
.449 .551 .449 r
.875 .54899 m
.875 .5655 L
.95833 .5655 L
.95833 .54899 L
F
.429 .571 .429 r
.875 .5655 m
.875 .58201 L
.95833 .58201 L
.95833 .5655 L
F
.408 .592 .408 r
.875 .58201 m
.875 .59852 L
.95833 .59852 L
.95833 .58201 L
F
.388 .612 .388 r
.875 .59852 m
.875 .61503 L
.95833 .61503 L
.95833 .59852 L
F
.367 .633 .367 r
.875 .61503 m
.875 .63155 L
.95833 .63155 L
.95833 .61503 L
F
.347 .653 .347 r
.875 .63155 m
.875 .64806 L
.95833 .64806 L
.95833 .63155 L
F
.327 .673 .327 r
.875 .64806 m
.875 .66457 L
.95833 .66457 L
.95833 .64806 L
F
.306 .694 .306 r
.875 .66457 m
.875 .68108 L
.95833 .68108 L
.95833 .66457 L
F
.286 .714 .286 r
.875 .68108 m
.875 .69759 L
.95833 .69759 L
.95833 .68108 L
F
.265 .735 .265 r
.875 .69759 m
.875 .7141 L
.95833 .7141 L
.95833 .69759 L
F
.245 .755 .245 r
.875 .7141 m
.875 .73061 L
.95833 .73061 L
.95833 .7141 L
F
.224 .776 .224 r
.875 .73061 m
.875 .74712 L
.95833 .74712 L
.95833 .73061 L
F
.204 .796 .204 r
.875 .74712 m
.875 .76363 L
.95833 .76363 L
.95833 .74712 L
F
.184 .816 .184 r
.875 .76363 m
.875 .78014 L
.95833 .78014 L
.95833 .76363 L
F
.163 .837 .163 r
.875 .78014 m
.875 .79666 L
.95833 .79666 L
.95833 .78014 L
F
.143 .857 .143 r
.875 .79666 m
.875 .81317 L
.95833 .81317 L
.95833 .79666 L
F
.122 .878 .122 r
.875 .81317 m
.875 .82968 L
.95833 .82968 L
.95833 .81317 L
F
.102 .898 .102 r
.875 .82968 m
.875 .84619 L
.95833 .84619 L
.95833 .82968 L
F
.082 .918 .082 r
.875 .84619 m
.875 .8627 L
.95833 .8627 L
.95833 .84619 L
F
.061 .939 .061 r
.875 .8627 m
.875 .87921 L
.95833 .87921 L
.95833 .8627 L
F
.041 .959 .041 r
.875 .87921 m
.875 .89572 L
.95833 .89572 L
.95833 .87921 L
F
.02 .98 .02 r
.875 .89572 m
.875 .91223 L
.95833 .91223 L
.95833 .89572 L
F
0 1 0 r
.875 .91223 m
.875 .92874 L
.95833 .92874 L
.95833 .91223 L
F
1 1 0 r
gsave
.91667 .92874 -71 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .10319 -71 -38 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 42 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 29.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 32.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 412.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001W2000`400?l00000o`00003oool00?n@
o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo
003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o
003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo0035o`00o`oo0000^ol00?l1
ooooo`00]_l00?l5o`0000Wo003o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`2ho`00
o`7ooooo002_o`00o`Oo00001Ooo0?l00ol0003o003oo`00o`04o`00o`;o00004Ooo0?l2o`000;So
003o0Oooool00:_o003o1?l0000=ool0o`;o00000ol00?l00ol0003oo`3oool0o`0Cool0o`03o`00
0?l00?oo003o01Co003o1?l0001Yo`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0]o`00
o`7ooooo002[o`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool000005ooo0?l00ol0003o
003oo`00o`0@o`00o`?o00001?oo0?l3o`0006Co003o00[o413^omgM8Oooo`3oMgN7oa0@k_l00?oo
EEFYoooo0?oMgB7o413^;?l00?l1ooooo`00Z_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o01Ooo`3o2Ol00007o`00o`;o00002_oo0?l3o`00067o003o00?ogMdQoooo0?mgMhL01?l0
0?l00om4A;[oool0omgM8@0/o`00o`7ooooo002Yo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`06ool0o`?o000000Co003oo`000?l0003o00003ooo
0?l00ol0003o003oo`00o`1Mo`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo0?mVIYP0:ol0
0?l1ooooo`00Z?l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Koo`3o00?o0000
ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05go003o0_ooo`00
0onHV6Ko003oo`00o`04o`00o`03ohN7Moooo`3ok^h@02_o003o0Oooool009Go003o2_l00008o`00
o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Fol00?l01?mEEJWoool0oooo0?mVIYP6
o`00o`04oeEEZOooo`3oool0oc8bc2[o003o0Oooool007go003o0ol0000=o`00o`So00002_oo0?l2
o`0000Go003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Jo`00o`04oiRHI_ooo`3o
ool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg:_l00?l1ooooo`00N_l00?l3o`0000?oo`3o0_l0
000:o`00o`03o`000?oo0?ooo`3o01;oo`3o1Ol0000Jool0o`;o00005Ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0FOl00?l01?o<c3;oool0oooo
0?l@4>h7o`00o`;oool000?oc<`bo`00ool00?l0:?l00?l1ooooo`00Mol00?l3o`0000Soo`3o0_l0
0007o`00o`03o`000?oo0?ooo`3o01?oo`3o00Go0000ool0oooo0?ooo`3oo`00000Iool0o`04o`00
0?oo0?ooo`3oo`0001?oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o05Wo003o0oooo`08o`00o`;oool000?ok^h@o`00ool00?l0:?l00?l1ooooo`00
M?l00?l3o`0000goo`3o0_l00004o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l0
0ooo0?l00ol0003oo`3oool0o`0Eool0o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
F?l00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001bo`00o`;o00004_oo0?l2o`000003o`00ool0
003oo`3o01Goo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo
0?ooo`3o01Coo`3o00?o0000o`00ool00?l0Eol00?l3oooo00So003o0oooo`0Zo`00o`7ooooo001b
o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`05
ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1G
o`00o`?oool02?l00?l3oooo02[o003o0Oooool0077o003o00?o0000ool0oooo0?l05?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0
003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko003o0oooo`08o`00o`?oool0:_l00?l1oooo
o`00LOl00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo
0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000o`00ool0
0?l0EOl00?l01?o<c3;oool0oooo0?lb</`6o`00o`04ob4QgOooo`3oool0olc<<R[o003o0Oooool0
073o003o00?o0000ool0oooo0?l05Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?l00?oo003o
05Co003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4A;[oool0oooo0?nHV6HZo`00o`7ooooo001_
o`00o`03o`000?oo0?ooo`3o01Goo`3o0_l0000Eool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Gool0o`oo0000Aol00?l01?mEEJWoool0oooo0?mg
MhL6o`00o`04ofIVV?ooo`3oool0oeEEZB[o003o0Oooool006oo003o00?o0000ool0oooo0?l05?oo
0?l00ol0003oo`3oo`00000Eool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00;oo`3o1?l0000Dool0o`03o`000?oo
0?ooo`3o01Ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`15o`00o`;oool000?o
ZJUEo`00ool00?l01?l00?l00onYZEGoool0onk^400[o`00o`7ooooo001^o`00o`03o`000?oo0?oo
o`3o01Coo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00coo`3o3?l0
000Bool0o`Co00000ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o01Coo`3o0_l0
000@ool0o`;o0000AOl00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV2_o
003o0Oooool006;o003o1ol00005o`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00004ool0o`03o`00
0?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Aool0o`?o0000
4ooo0?l2o`000003ool0ool0003oo`3o017oo`3o0_l00014o`00o`03omgM8Oooo`3oQhMg00Co003o
00?oQhMgoooo0?o<c380;?l00?l1ooooo`00HOl00?l00ol0003oo`3oool0o`05ool0o`Go00005?oo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l0000?ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?oo
0?ooo`3o00ooo`3o00Co0000ool0oooo0?ooo`3o0_l0000?ool0o`;o00001?oo0?l00ol0003oo`3o
ool0o`0Aool0o`03o`000?l00?oo003o047o003o00Co413^omgM8Oooo`3oMgN70_l@4>h01?mgMhOo
ool0omgM8Ol@4>h/o`00o`7ooooo001Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l04?oo0?l2o`0000Soo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oo`00000?ool0o`03
o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`08ool0o`03
o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l01?oo0?l3o`0000Woo`3o0ol00006ool0o`03
o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0@Ol00?l00ol@4>koQhMgomgM8@02oooo0003
omgM8On7QgOo003o02go003o0Oooool005oo003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Soo`3o
0_l00005ool0o`;o00002Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Ko003o
0Oooool005ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0;ool0o`;o000000?o
o`3oo`000?l000003?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o07Go003o0Ooo
ool005go003o00?o0000ool0oooo0?l03ooo0?l2o`0000_oo`3o0_l0000=ool0o`03o`000?oo0?oo
o`3o00Soo`3o0_l00007ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03?oo0?l0
0ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l01ooo0?l2
o`00013oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o07Go003o0Oooool005co003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oo`000009ool0
o`03o`000?oo0?ooo`3o00goo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0
oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o07Co003o0Oooool005_o
003o00?o0000ool0oooo0?l04?oo0?l01?l0003oo`3oool0oooo0?l2o`0000Goo`3o0_l0000?ool0
o`04o`000?on0OkooP7no`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`09
ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0=
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<ol00?lNool0ob;o003o0Oooool0
05[o003o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`04ool0o`05o`000?oo0?ooo`3o
ool0ool000003ooo0?l2o`0000CooP7n00Co0000ool0oooo0?ooo`3o0_l0000<ool0o`03o`000?oo
0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o017oo`3o00Go0000ool0oooo0?ooo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`0co`00oakoo`3o8_l00?l1ooooo`00FOl0
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0ool000003ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?oo000000ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003oo`3oo`00000Dool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l05?oo
0?l00ol0003o003oo`00o`0bo`00oakoo`3o8_l00?l1ooooo`00Dol00?l6o`0001?oo`3o00?o0000
ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`;o00002Oon0Oh00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0<_l00?lNool0ob;o003o0Oooool0
05;o003o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o
00Soo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o
00Coo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l05?oo0?l4o`00033o003o7_oo0?lRo`00o`7ooooo001@o`00o`;o
00001ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l02?oo0?l2o`0000gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?oo0?ooo`3o017oo`3o00Co0000ool0oooo0?ooo`3o0ol0000Fool0o`03o`000?oo0?ooo`3o
01?oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Dool0o`04o`000?oo0?ooo`3o
ool0o`;o0000;_l00?lNool0ob;o003o0Oooool004ko003o0_l0000:ool0o`03o`000?oo0?ooo`3o
00goo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n
00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l04Ooo0?l01?l0
003oo`3oo`000?l00003ooh1oP?o00004ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o013oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`;o0000;?l00?lN
ooX5nR;o003o0Oooool004go003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003ooP7nooh1oP0>ooh1
oP04o`000?ol0ocoo0?loo`3o0Go00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ooh1o_on0Oh01_on0Oh2o`00013oo`3o0ol0000Cool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`07ool0o`;o0000:_l00?lN
ooX5nR;o003o0Oooool004?o003o2_l0000>ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0
oooo0?l03?oo0?l00ol0003oo`3oool0o`03ool0o`;o00004?on0Oh00ol0003oo0?loo`3o007oo`3
o0Go00001Ooo0?l00ol0003oo`3oool0o`03ool0o`?o00004ooo0?l00ol0003ooP7nooh1oP08ooh1
oP;o00002ooo0?l3o`0000?ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l2o`0002So003o7_oj1OXRo`00
o`7ooooo0012o`00o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o
o`3oool0o`09ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003o
oP7nooh1oP0@ooh1oP03o`000?ol0ocoo0?l00coo0?l1_l00002ool0o`?o00000oon0Oh3o`0000oo
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Koo`3o0_l00007ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000o`00ool00?l09Ol00?lNooX5nR;o003o0Oooool0047o003o00?o0000ool0oooo0?l0
2?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`02o`0001?ooP7n00?o0000oo`3o?ol0o`04Ool0o`3o`0000WooP7n
0_l0000<ool0o`03o`000?on0OkooP7n00oooP7n0_l000001?oo0?oo0000o`000?l0000:ooh1oP03
o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`09ool0o`Go
00004?oo0?l00ol0003o003oo`00o`0Uo`00oakonPGj8_l00?l1ooooo`00@?l00?l00ol0003oo`3o
ool0o`09ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3o
ool0o`0?ool0o`;o00005?on0Oh00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00[ooP7n
0_l00009ool0o`03o`000?on0OkooP7n01;ooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3o
ool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l00_oo0?l7o`0000Coo`3o
00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0To`00oakonPGj8_l00?l1ooooo`00?ol0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01_oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`04_ol
0o`00ol0003ooP7nooh1oP0=ooh1oP?o00001Ooo0?l00ol0003ooP7nooh1oP0Cooh1oP03o`000?on
0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Dool0o`Co00002ooo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o02?o003o7_oe2_DRo`00o`7ooooo000n
o`00o`03o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`04
ool0o`03o`000?oo0?ooo`3o013oo`3o0_l0000Eooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000
ooh1o_on0Oh04?on0Oh2o`0000;oo`3o00?o0000ooh1o_on0Oh05?on0Oh00ol0003ooP7nooh1oP0>
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`0>
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l08_l00?lNooD:mB;o003o0Oooool0
03go003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`;o00001?oo0?l00ol0
003oo`3oool0o`0=ool0o`?o00000_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?ol0ocoo0?l
01?oo0?l00?o0000ooh1o_on0Oh04_on0Oh2o`0001OooP7n00?o0000ooh1o_on0Oh03oon0Oh=o`00
017oo`3o1?l0000Aool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l08Ol00?lNooD:
mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0?ool0o`06
o`000?oo0?oo0000o`000?oo0?oo00003Ooo0?l3o`0000KooP7n00?o0000ooh1o_on0Oh04?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01?ooP7n00?o0000oo`3o?l000005Oon0Oh0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l02?oo0?l7
o`0000?ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo
003o027o003o7_oe2_DRo`00o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`;o00002_oo0?l3o`0000[ooP7n0_l0000@ooh1
oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh01Ol0003oo0?loo`3o?ol0oco
000001CooP7n00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0;ooh1oP04o`000?oo0?oo
o`3oool0o`Ko00002_on0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o017oo`3o00?o
0000o`00ool00?l08Ol00?lNooD:mB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ool0oooo0?l01?oo0?l3
o`0000gooP7n00Co0000oo/4nol0003o00003Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`000?on
0OkooP7n01?ooP7n00?o0000oo`3o?ol0o`00_ol0o`00ol0003ooP7nooh1oP0Aooh1oP03o`000?on
0OkooP7n00oooP7n00?o0000ooh1o_on0Oh03?on0Oh3o`00013ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o027o003o7_oe2_DRo`00o`7ooooo000l
o`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`07
ool0o`03o`000?oo0?ooo`3o00?o00003oon0Oh00ol0003on`Ckoo/4n`02oo/4n`;o00002oon0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`01?ol0o`0
0ol0003ooP7nooh1oP0@ooh1oP03o`000?on0OkooP7n00kooP7n00?o0000ooh1o_on0Oh03Oon0Oh0
0ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0Qo`00oakol0o`8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0>ool0
o`03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`00017ooP7n00?o0000oo/4
nook1?/01Ook1?/2o`0000WooP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Booh1
oP03o`000?ol0ocoo0?l00Goo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003ooP7nooh1oP0>ooh1
oP03o`000?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co
003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[o
o`3o00?o0000ooh1o_on0Oh04?on0Oh00ol0003on`Ckoo/4n`07oo/4n`03o`000?on0OkooP7n00Go
oP7n00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0Cooh1oP03o`000?ol0ocoo0?l00Ko
o0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0OkooP7n00ko
oP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000o`00ool00?l08_l00?lNoo0?l2;o003o0Oooool003co003o00?o0000ool0oooo0?l0
3ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh0
3oon0Oh00ol0003on`Ckoo/4n`09oo/4n`;o00001Oon0Oh00ol0003oo0?loo`3o00Boo`3o003o`00
0?on0OkooP7n01;ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`00
0?on0OkooP7n00gooP7n00?o0000ooh1o_on0Oh03_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Ro`00oakol0o`
8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?ok1?_on`Ck00_on`Ck0_l0
0003ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh03Oon0Oh00ol0003ooP7nooh1
oP0?ooh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0
o`0>ool0o`03o`000?l00?oo003o02;o003o7_o`3o0Ro`00o`7ooooo000lo`00o`03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0Oko
oP7n00kooP7n00?o0000oo/4nook1?/03_ok1?/3o`0001?oo0?l0ol0000Cooh1oP03o`000?ol0oco
o0?l00_oo0?l00?o0000ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP0=ooh1oP03o`000?on0Oko
oP7n00oooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?oo
o`3o00coo`3o0ol0000To`00oakol0o`8_l00?l1ooooo`00??l00?l3o`0000ooo`3o00?o0000ool0
oooo0?l01_oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/04Ook1?/00ol0003oo0?loo`3o00?oo`3o0;o00000ooh1oP00ol0003ooP7nooh1oP0@ooh1
oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1o_on0Oh02Oon0Oh00ol0003ooP7nooh1oP0=ooh1
oP03o`000?on0OkooP7n013ooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003oo`3oool0o`0?ool0
o`03o`000?oo0?ooo`3o00Woo`3o0ol00003ool0o`03o`000?l00?oo003o027o003o7_o[5>/Ro`00
o`7ooooo000lo`00o`03o`000?oo0?ooo`3o00?o00003?oo0?l00ol0003oo`3oool0o`05ool0o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`0Aoo/4n`03
o`000?ol0ocoo0?l00goo0?l0_l00006ooP7n0;o00003oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh03?on0Oh00ol0003ooP7nooh1oP0Aooh1oP03
o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`06ool0o`?o
00001ooo0?l00ol0003o003oo`00o`0Po`00oakojaC[8_l00?l1ooooo`00>ol00?l00ol0003oo`3o
ool0o`04ool0o`?o00002Ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00ooo`3o
00?o0000ooh1o_on0Oh02oon0Oh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?ol0ocoo0?l00[oo0?l
0_l0000:ooP7n003o`000?on0OkooP7n00cooP7n00?o0000oo`3o?ol0o`03ool0o`00ol0003ooP7n
ooh1oP07ooh1oP03o`000?on0OkooP7n00cooP7n00?o0000ooh1o_on0Oh04Oon0Oh00ol0003ooP7n
ooh1oP0Aooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l00ooo0?l3o`0000_oo`3o
00?o0000o`00ool00?l07ol00?lNon/Djb;o003o0Oooool003[o003o00?o0000ool0oooo0?l02?oo
0?l3o`0000Ooo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?on
0OkooP7n00[ooP7n00?o0000oo/4nook1?/05Ook1?/00ol0003oo0?loo`3o006oo`3o0?o00003Ooh
1oP2o`0000_ooP7n00?o0000oo`3o?ol0o`04Ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?on
0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh04_on0Oh00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo
0?ooo`3o013oo`3o00?o0000ool0ool000000_l0000?ool0o`03o`000?l00?oo003o01ko003o7_o[
5>/Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o00coo`3o0ol00004ool0o`03o`000?oo0?oo
o`3o00;oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0:ooh1oP03o`000?ok1?_o
n`Ck01Gon`Ck00?o0000oo`3o?ol0o`01?ol0o`2o`0001;on0Oh00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00GooP7n00?o0000ooh1o_on0Oh02oon0Oh0
0ol0003ooP7nooh1oP0Booh1oP03o`000?on0OkooP7n017ooP7n00?o0000ool0oooo0?l04?oo0?l2
o`0001;oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool003So003o00?o0000ool0
oooo0?l04?oo0?l3o`000003ool0ool0003oo`3o00;oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck01Oon`Ck00Co0000oo`3o?ol0ocoo0?l0_l0000E
ooP7n003o`000?on0OkooP7n00KooP7n00?o0000oo`3o?ol0o`05?ol0o`00ol0003ooP7nooh1oP03
ooh1oP03o`000?on0OkooP7n00SooP7n1Ol0000Cooh1oP?o00004_on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l07_l00?lNon/Djb;o003o0Oooool0
03Oo003o00?o0000ool0oooo0?l05?oo0?l3o`000003ool0ool0003oo`3o01Coo`3o00?o0000ooh1
o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0Hoo/4n`?o00006?oh1oP2o`0000KooP7n00?o0000oo`3
o?ol0o`05Ool0o`00ol0003ooP7nooh1oP02ooh1oP04o`000?on0OkooP7nooh1oPOo00001Ool0o`0
0ol0003ooP7nooh1oP0?ooh1oP04o`000?ol0ocoo0?loo`3o0;o00004Oon0Oh00ol0003oo`3oool0
o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07_l00?lNonDJiB;o003o0Ooo
ool003Oo003o00?o0000ool0oooo0?l05_oo0?l2o`0001Koo`3o00?o0000ooh1o_on0Oh02?on0Oh0
0ol0003on`Ckoo/4n`0Goo/4n`Go00006_oh1oP00ol0003ooP7nooh1oP03ooh1oP03o`000?ol0oco
o0?l01Koo0?l00Co0000ooh1o_on0OkooP7n1?l0000=oo`3o003o`000?on0OkooP7n00gooP7n00?o
0000oo`3o?ol0o`01?ol0o`2o`0000oooP7n00?o0000ool0oooo0?l02_oo0?l4o`0001Koo`3o00?o
0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l05Ooo0?l0
0ol0003oo`3oool0o`02o`0001Goo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003on`Ckoo/4n`0E
oo/4n`?o000000Kom@[eo`000?ob3O;o0000onDJiOl0000JooP7n0;o00000_on0Oh00ol0003oo0?l
oo`3o00Hoo`3o003o`000?on0Oko000001;oo0?l00?o0000ooh1o_on0Oh02_on0Oh2o`0000Woo0?l
0_l00007ooh1oPSo00001?oo0?l7o`0000?oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003o
o`00o`0Mo`00oakoiA[U8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Dool0o`06o`000?oo
0?ooo`3oool0ool0003oo@;m0ol0000Bool0o`03o`000?on0OkooP7n00KooP7n00?o0000oo/4nook
1?/04_ok1?/3o`0000?om@[e00Co0000oo8=l_ob3O;o00000_oU6^D00ol0003on0OhooP7n00IooP7
n003o`000?on0Oko000001_oo0?l00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP08ooh1
oP03o`000?ol0ocoo0?l00_oo0?l1ol00008ooh1oPCo00002ooo0?l00ol0003oo`3oool0o`0Cool0
o`03o`000?l00?oo003o01go003o7_oU6^DRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01?o
o`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;mood2o@02ood2o@?o00003ooo0?l00ol0003o
oP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck013on`Ck0ol00005ooD:m@05o`000?ob3O;olPgboo8=
l_l000000ooU6^D00ol0003on0OhooP7n00IooP7n003o`000?ol0ocoo0?l01[oo0?l00?o0000oo`3
o?ol0o`04ool0o`00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooh1
o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00
ool00?l07Ol00?lNonDJiB;o003o0Oooool003Oo003o00?o0000ool0oooo0?l04_oo0?l00ol0003o
o`3oool0o`03ool0o`03o`000?om0_goo@;m00Goo@;m0ol0000;ool0o`Co00001Oon0Oh00ol0003o
n`Ckoo/4n`0=oo/4n`?o00002?oe2_D01Ol0003olPgboo8=l_ob3O;o000000CoiA[U00?o0000ooP7
n?oh1oP06?oh1oP00ol0003oo0?loo`3o00Ioo`3o003o`000?ol0ocoo0?l01Goo0?l00?o0000ooh1
o_on0Oh00oon0Oh2o`0000ooo0?l00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0=ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l07Ol00?lNonDJiB;o003o0Oooool003Ko
003o00?o0000ool0oooo0?l04Ooo0?l2o`0000Koo`3o00?o0000ood2oOom0_d02?om0_d3o`0000Ko
o`3o0_l00004oo`3o0?o000000?ooP7no`000?ok1?/03?ok1?/3o`0000[om@[e00?o0000oo8=l_ob
3O800_ob3O800ol0003oiA[UonDJi@03onDJi@03o`000?oh1oSon0Oh01Oon0Oh00?o0000oo`3o?ol
0o`06Ool0o`00ol0003oo0?loo`3o00Foo`3o005o`000?on0OkooP7nooh1o_l000004Ool0o`00ol0
003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0
003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00=_l00?l00ol0003oo`3oool0o`0@ool0o`03
o`000?oo0?ooo`3o00Koo`3o00?o0000ood2oOom0_d02oom0_d3o`000003ool0ool0003o000000Wo
o0?l0_l0000:oo/4n`?o00003Ooe2_D00ol0003olPgboo8=lP02oo8=lP03o`000?oU6^GoiA[U00Co
iA[U00?o0000ooP7n?oh1oP05ooh1oP00ol0003oo0?loo`3o00Hoo`3o003o`000?ol0ocoo0?l01Oo
o0?l00?o0000ooh1o_l000004Ool0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0Mo`00oakoh1oP8_l00?l1ooooo`00
=_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003oo0?loo`3o00;oo`3o003o`000?ok1?_on`Ck00Con`Ck0ol0000?ooD:m@03o`00
0?ob3O;olPgb00?olPgb00?o0000onDJiOoU6^D01OoU6^D00ol0003on0OhooP7n00FooP7n003o`00
0?ol0ocoo0?l01Ooo0?l00?o0000oo`3o?ol0o`06Ool0o`00ol0003oo0?loo`3o00@oo`3o003o`00
0?on0OkooP7n00gooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`00
0?l00?oo003o01co003o7_oP7n0Ro`00o`7ooooo000fo`00o`03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00coo0?l00?o
0000oo/4nook1?/00ol0000AooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D01_oU
6^D2o`0001Gon0Oh0ol0000Hoo`3o003o`000?ol0ocoo0?l01Woo0?l00?o0000oo`3o?ol0o`04?ol
0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l04Ooo
0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00=Ol00?l3o`0000koo`3o00?o0000
ool0oooo0?l02Ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000D
ooD:m@03o`000?ob3O;olPgb00ColPgb00?o0000onDJiOoU6^D02?oU6^D00ol0003on0OhooP7n00@
ooP7n0;o00000ooT6n@00ol0003oo0?loo`3o00Doo`3o003o`000?ol0ocoo0?l01[oo0?l00?o0000
oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1ooooo`00<_l00?l3o`00
00?oo`3o00?o0000ool0oooo0?l02Ooo0?l2o`0000_oo`3o0_l0000?ood2o@03o`000?ol0ocoo0?l
00koo0?l00?o0000ooD:mOoe2_D04_oe2_D00ol0003olPgboo8=lP05oo8=lP03o`000?oU6^GoiA[U
00WoiA[U00?o0000ooP7n?oh1oP03Ooh1oP2o`0000Koi1_T0_l0000Doo`3o003o`000?ol0ocoo0?l
01[oo0?l00?o0000oo`3o?ol0o`04?ol0o`00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
013oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0Lo`00oakoh1oP8_l00?l1oooo
o`00<?l00?l2o`0000Ooo`3o0_l00008ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ood2oOl0
00003oom0_d00ol0003oo0?loo`3o00>oo`3o003o`000?oe2_Gom@[e01;om@[e00?o0000oo8=l_ob
3O801Oob3O800ol0003oiA[UonDJi@0:onDJi@03o`000?oh1oSon0Oh00[on0Oh0_l0000:on@Ki003
o`000?ol0ocoo0?l017oo0?l00?o0000oo`3o?ol0o`06_ol0o`00ol0003oo0?loo`3o00?oo`3o003
o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0>ool0o`03
o`000?l00?oo003o01go003o7_oK9=/Ro`00o`7ooooo000_o`00o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0:ool0o`04o`000?om0_goo@;mo`0000oo
o@;m00?o0000oo`3o?ol0o`03ool0o`00ol0003om@[eooD:m@0@ooD:m@03o`000?ob3O;olPgb00Ko
lPgb00?o0000onDJiOoU6^D02ooU6^D00ol0003on0OhooP7n008ooP7n003o`000?oT6nCoi1_T00_o
i1_T0_l0000@oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000oo`3o?ol0o`03ool0o`00ol0003o
oP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003o
003oo`00o`0Mo`00oakofbCK8_l00?l1ooooo`00;ol00?l00ol0003oo`3oool0o`0:ool0o`;o0000
0ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_goo@;m00;oo@;m00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o00?oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O80
1oob3O800ol0003oiA[UonDJi@0<onDJi@03o`000?oh1oSon0Oh00Gon0Oh0_l0000@on@Ki003o`00
0?ol0ocoo0?l00goo0?l00?o0000oo`3o?ol0o`06ool0o`00ol0003oo0?loo`3o00?oo`3o003o`00
0?on0OkooP7n00kooP7n00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0:ool0o`?o0000
8?l00?lNom/Tfb;o003o0Oooool002ko003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oo`00
000<ool0o`03o`000?om0_goo@;m00?oo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3
o00@oo`3o003o`000?oe2_Gom@[e00oom@[e00?o0000oo8=l_ob3O801oob3O800ol0003oiA[UonDJ
i@0=onDJi@03o`000?oh1oSon0Oh00;on0Oh0_l0000Con@Ki0;o00003?ol0o`00ol0003oo0?loo`3
o00Loo`3o0?o00003ool0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l01ooo0?l3o`0000;oo`3o00?o0000o`00ool00?l07_l00?lNom/Tfb;o003o0Ooo
ool002ko003o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?om0_go
o@;m00Coo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oe2_Go
m@[e00kom@[e00?o0000oo8=l_ob3O802?ob3O800ol0003oiA[UonDJi@0>onDJi@04o`000?oh1oSo
0000o`0001Ooi1_T00?o0000oo`3o?ol0o`02Ool0o`00ol0003oo0?loo`3o00Loo`3o003o`000?oj
1O[onPGj00?o00003?ol0o`00ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l00ooo0?l3o`0000Koo`3o00?o0000o`00ool00?l07Ol00?lNom/Tfb;o003o0Ooo
ool002go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?om0_go
o@;m00Goo@;m00?o0000ood2oOom0_d02oom0_d00ol0003oo0?loo`3o00Aoo`3o003o`000?oe2_Go
m@[e00com@[e00?o0000oo8=l_ob3O802Oob3O800ol0003oiA[UonDJi@0?onDJi@03o`000?oT6nCo
i1_T01Soi1_T0_l00009oo`3o003o`000?ol0ocoo0?l01_oo0?l00?o0000ooX5n_oj1OX01?oj1OX4
o`0000Soo0?l00?o0000ooh1o_on0Oh03_on0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?oo
o`3o00?o00002_oo0?l00ol0003o003oo`00o`0Lo`00oakofbCK8_l00?l1ooooo`00;Ol00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01_om0_d00ol0
003oo@;mood2o@0;ood2o@03o`000?ol0ocoo0?l013oo0?l0_l0000>ooD:m@03o`000?ob3O;olPgb
00WolPgb00?o0000onDJiOoU6^D03ooU6^D00ol0003oi1_Ton@Ki00Jon@Ki003o`000?ol0ocoo0?l
00Coo0?l0ol0000Loo`3o003o`000?oj1O[onPGj00WonPGj0ol00004oo`3o003o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l05?oo0?l2o`0000koo`3o00?o0000o`00ool00?l06ol00?lNomHY
eR;o003o0Oooool002co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`06ool0o`03
o`000?om0_goo@;m00Soo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00@oo`3o004
o`000?o`3o3ol0o`o`0000com@[e00?o0000oo8=l_ob3O802_ob3O800ol0003oiA[UonDJi@0?onDJ
i@03o`000?oT6nCoi1_T01_oi1_T0_l00003oo`3o004o`000?oa3_7ol@kaoo4>l@?o00006?ol0o`0
0ol0003onPGjooX5nP0=ooX5nP?o000000?oo0?lo`000?on0Oh04?on0Oh00ol0003oo`3oool0o`0D
ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000o`00ool00?l06_l00?lNomHYeR;o003o0Oooool0
02co003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`04ool0o`03o`000?om0_goo@;m
00Woo@;m00?o0000ood2oOom0_d02Oom0_d00ol0003oo0?loo`3o00?oo`3o003o`000?o`3o3ol0o`
00;ol0o`00?o0000ooD:mOoe2_D02Ooe2_D00ol0003olPgboo8=lP0:oo8=lP03o`000?oU6^GoiA[U
00koiA[U00?o0000on@Ki?oT6n@07_oT6n@00ol0003oo0?lo`000007oo4>l@?o00005?ol0o`00ol0
003onPGjooX5nP0AooX5nP;o00004Oon0Oh00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o
013oo`3o00?o0000o`00ool00?l06Ol00?lNomHYeR;o003o0Oooool002co003o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`03ool0o`03o`000?om0_goo@;m00[oo@;m00?o0000ood2oOom
0_d02Oom0_d00ol0003oo0?loo`3o00=oo`3o0;o00001_o`3o000ol0003om@[eooD:m@07ooD:m@03
o`000?ob3O;olPgb00_olPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003oi1_Ton@Ki00Oon@Ki003
o`000?oa3_7ol@ka00Wol@ka0ol0000@oo`3o003o`000?oj1O[onPGj01?onPGj00?o0000ooh1o_on
0Oh03_on0Oh4o`00017oo`3o0_l0000Dool0o`03o`000?l00?oo003o01So003o7_oF:MHRo`00o`7o
oooo000[o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo@;m
ood2o@0;ood2o@03o`000?om0_goo@;m00Woo@;m00?o0000oo`3o?ol0o`03?ol0o`00ol0003ol0o`
oo0?l007oo0?l003o`000?oe2_Gom@[e00Gom@[e00?o0000oo8=l_ob3O803?ob3O800ol0003oiA[U
onDJi@0>onDJi@03o`000?oT6nCoi1_T01ooi1_T00?o0000oo4>lOoa3_403?oa3_43o`0000goo0?l
00?o0000ooX5n_oj1OX05?oj1OX00ol0003ooP7nooh1oP0;ooh1oP;o00001?on0Oh5o`0000Woo`3o
0ol000000ooo0?oo0000ool0o`0Dool0o`03o`000?l00?oo003o01Oo003o7_oF:MHRo`00o`7ooooo
000[o`00o`03o`000?oo0?ooo`3o01?oo`3o0ol000000ooo0?oo0000ood2o@0=ood2o@03o`000?om
0_goo@;m00Soo@;m00?o0000oo`3o?ol0o`02ool0o`2o`0000_ol0o`00?o0000ooD:mOoe2_D01?oe
2_D00ol0003olPgboo8=lP0<oo8=lP03o`000?oU6^GoiA[U00koiA[U00?o0000on@Ki?oT6n@07_oT
6n@00ol0003ol@kaoo4>l@0@oo4>l@?o00002Ool0o`00ol0003onPGjooX5nP0FooX5nPOo00001Oon
0Oh00ol0003ooP7nooh1oP09ooh1oPCo00000_oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l04_oo
0?l00ol0003o003oo`00o`0Go`00oakoeRWF8_l00?l1ooooo`00:_l00?l00ol0003oo`3oool0o`0C
ool0o`05o`000?on0OkooP7nooh1o_l000004?om0_d00ol0003oo@;mood2o@07ood2o@03o`000?ol
0ocoo0?l00[oo0?l00?o0000oo0?l?o`3o003?o`3o000ol0003om@[eooD:m@02ooD:m@03o`000?ob
3O;olPgb00golPgb00?o0000onDJiOoU6^D03_oU6^D00ol0003oi1_Ton@Ki00Non@Ki003o`000?oa
3_7ol@ka01?ol@ka0ol00005oo`3o003o`000?oj1O[onPGj01OonPGj00?o0000oo`3o?ol0o`01?ol
0o`5o`00013ooP7n0_l00008ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l05ol0
0?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP03
ooh1oQ;o00002?om0_d00ol0003oo0?loo`3o009oo`3o003o`000?o`3o3ol0o`00kol0o`00Go0000
ooD:mOoe2_Gom@[eo`00000?oo8=lP03o`000?oU6^GoiA[U00goiA[U00?o0000on@Ki?oT6n@07ooT
6n@00ol0003ol@kaoo4>l@0Foo4>l@?o000000?oo0?lo`000?oj1OX06?oj1OX00ol0003oo0?loo`3
o009oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000Zo`00o`03o`000?oo0?oo
o`3o013oo`3o0_l00006ooh1oP03o`000?ol0ocoo0?l00ooo0?l0_l00006ood2o@03o`000?ol0oco
o0?l00Ooo0?l0_l0000Boo0?l003o`000?oe2_Go0000013olPgb00?o0000onDJiOoU6^D02ooU6^D3
o`00023oi1_T00?o0000oo4>lOoa3_406_oa3_400ol0003onPGjooX5nP0HooX5nP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`07ool0o`03o`000?oo0?oo
o`3o017oo`3o00?o0000o`00ool00?l05ol00?lNom0_d2;o003o0Oooool002[o003o00?o0000ool0
oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ol0ocoo0?l017oo0?l00?o0000ood2
oOom0_d00_om0_d00ol0003oo0?loo`3o007oo`3o003o`000?o`3o3ol0o`01?ol0o`00?o0000oo8=
l_ob3O803oob3O800ol0003oiA[UonDJi@07onDJi@Co00000_o8=lP00ol0003oi1_Ton@Ki00Non@K
i003o`000?oa3_7ol@ka01[ol@ka00?o0000ooX5n_oj1OX05ooj1OX00ol0003oo0?loo`3o00:oo`3
o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0Aool0
o`03o`000?l00?oo003o01Oo003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo0?loo`3o00Boo`3o0Ko00001_ol0o`2o`0001Ko
l0o`00?o0000oo8=l_ob3O803oob3O800ol0003oiA[UonDJi@03onDJi@Co00001oo8=lP00ol0003o
i1_Ton@Ki00Lon@Ki003o`000?oa3_7ol@ka01col@ka00?o0000ooX5n_oj1OX05Ooj1OX00ol0003o
o0?loo`3o00;oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o7_o@;m0Ro`00o`7ooooo000[o`00o`03o`00
0?oo0?ooo`3o00_oo`3o0_l0000:ooh1oP03o`000?ol0ocoo0?l01;oo0?l00?o0000ooX5n_oj1OX0
0ooj1OX2o`0000?oo0?l00?o0000oo0?l?o`3o005oo`3o000ol0003olPgboo8=lP0>oo8=lP03o`00
0?oU6^Go000000?o00003?o8=lP00ol0003oi1_Ton@Ki00Kon@Ki003o`000?oa3_7ol@ka01col@ka
00?o0000ooX5n_oj1OX05Ooj1OX00ol0003oo0?loo`3o00<oo`3o003o`000?on0OkooP7n00gooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Ko003o
7_o@;m0Ro`00o`7ooooo000[o`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ooh1o_on0Oh02_on
0Oh00ol0003oo0?loo`3o00Aoo`3o003o`000?oj1O[onPGj00KonPGj00?o0000oo`3o?l000006_o`
3o05o`0000_olPgb0ol0000AolPgb003o`000?oT6nCoi1_T01[oi1_T00?o0000oo4>lOoa3_407Ooa
3_400ol0003onPGjooX5nP0CooX5nP03o`000?ol0ocoo0?l00goo0?l00?o0000ooh1o_on0Oh03Oon
0Oh00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l05_l0
0?lNol/dbb;o003o0Oooool002[o003o1?l00009ool0o`03o`000?on0OkooP7n00cooP7n00?o0000
oo`3o?ol0o`03ool0o`00ol0003onPGjooX5nP08ooX5nP03o`000?o`3o3ol0o`01Wol0o`00?o0000
oldbcOo=</d00_o=</d7o`0000?olPgb00?o0000olPgb?o8=lP04oo8=lP3o`0001Ooi1_T0_l0000P
oo4>l@03o`000?oj1O[onPGj01?onPGj00?o0000oo`3o?ol0o`03Ool0o`00ol0003ooP7nooh1oP0=
ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0F
o`00oakobcC;8_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`02ool0o`Wo00003oon0Oh00ol0
003oo0?loo`3o00>oo`3o003o`000?oj1O[onPGj00WonPGj00?o0000oo0?l?o`3o006?o`3o000ol0
003ocC;=oldbc@0:oldbc@?o00005_o8=lP00ol0003oWF:MoieRW@05o`00013oi1_T0_l000000onm
@[go0000oo4>l@0Ooo4>l@03o`000?oj1O[onPGj01;onPGj00?o0000oo`3o?ol0o`03_ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Fo`00oakobcC;8_l00?l1ooooo`00:?l00?l00ol0003oo`3oool0o`04ool0o`03
o`000?oo0?ooo`3o00Coo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo0?loo`3o00>oo`3o003
o`000?oj1O[onPGj00[onPGj00?o0000oo0?l?o`3o005_o`3o000ol0003ocC;=oldbc@0=oldbc@03
o`000?o8=lSob3O801?ob3O800?o0000oieRWOnMHYd01_nMHYd4o`0000_oi1_T00?o0000oke2_Onm
@[d00_nm@[d00ol0003ol@kaoo4>l@0Noo4>l@03o`000?oj1O[onPGj013onPGj00?o0000oo`3o?ol
0o`03ool0o`00ol0003ooP7nooh1oP0<ooh1oP;o00003Ooo0?l00ol0003oo`3oool0o`0?ool0o`03
o`000?l00?oo003o01Ko003o7_o;=</Ro`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00Goo`3o
00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?ol0ocoo0?l00goo0?l
00?o0000ooX5n_oj1OX03?oj1OX00ol0003ol0o`oo0?l00Doo0?l003o`000?o=</gocC;=00oocC;=
00?o0000olPgb?o8=lP04_o8=lP00ol0003oWF:MoieRW@0:oieRW@Go00001?oT6n@2o`0000Go_D:m
00?o0000oo4>lOoa3_407_oa3_400ol0003onPGjooX5nP0@ooX5nP03o`000?ol0ocoo0?l00ooo0?l
00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7no`00000>ool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000o`00ool00?l05ol00?lNol/dbb;o003o0Oooool002Ko003o00?o0000ool0oooo0?l01ooo
0?l00ol0003oo`3oool0o`05ool0o`03o`000?on0OkooP7n00_ooP7n4?l0000?ooX5nP03o`000?o`
3o3ol0o`01Col0o`00?o0000oldbcOo=</d03oo=</d00ol0003ob3O8olPgb00BolPgb003o`000?nM
HYgoWF:M00ooWF:M1?l00008oke2_@03o`000?oa3_7ol@ka01kol@ka00?o0000ooX5n_oj1OX03_oj
1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00WooP7n0_l00003ooh1oP03o`000?oo
0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003o003oo`00o`0Go`00oakobcC;8_l0
0?l1ooooo`009_l00?l00ol0003oo`3oool0o`07ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000
ooh1o_on0Oh02oon0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj00konPGj00?o0000
oo0?l?o`3o004_o`3o000ol0003ocC;=oldbc@0@oldbc@03o`000?o8=lSob3O8017ob3O800?o0000
oieRWOnMHYd04OnMHYd00ol0003oOH9mo`000009oke2_@03o`000?oa3_7ol@ka01gol@ka00?o0000
ooX5n_oj1OX03_oj1OX00ol0003oo0?loo`3o00@oo`3o003o`000?on0OkooP7n00OooP7n0_l00005
ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`0H
o`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o
00Koo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003oo0?loo`3o00<oo`3o003o`000?oj1O[onPGj
00oonPGj00?o0000oo0?l?o`3o003_o`3o03o`0001CocC;=00?o0000olPgb?o8=lP04?o8=lP00ol0
003oWF:MoieRW@0@oieRW@04o`000?mmPWgoOH9mo`0000Wo_D:m00?o0000oo4>lOoa3_407_oa3_40
0ol0003onPGjooX5nP0<ooX5nP03o`000?ol0ocoo0?l017oo0?l00?o0000ooh1o_on0Oh01_on0Oh0
0ol0003ooP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1ooooo`009Ol00?l00ol0003oo`3oool0o`08ool0
o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo0?loo`3o00;oo`3
o003o`000?oj1O[onPGj013onPGj00?o0000oo0?l?o`3o002_o`3o04o`0000;occ3?00?o0000oldb
cOo=</d04_o=</d00ol0003ob3O8olPgb00@olPgb003o`000?nMHYgoWF:M00ooWF:M00Go0000ogf2
OOmmPWgoOH9mo`00000:oke2_@03o`000?oa3_7ol@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX0
0ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00?ooP7n0_l00009ooh1oP03o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`0Io`00oakoaSW68_l00?l1
ooooo`009?l00?l00ol0003oo`3oool0o`09ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1
o_on0Oh02?on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[onPGj017onPGj00?o0000oo0?
l?o`3o001Oo`3o04o`0000Oocc3?00?o0000oldbcOo=</d04Oo=</d00ol0003ob3O8olPgb00?olPg
b003o`000?nMHYgoWF:M013oWF:M00Go0000ogf2OOmmPWgoOH9mo`00000:oke2_@03o`000?oa3_7o
l@ka01gol@ka00?o0000ooX5n_oj1OX02ooj1OX00ol0003oo0?loo`3o00Coo`3o004o`000?on0Oko
oP7nooh1oP;o00003?on0Oh00ol0003oo`3oool0o`0;ool0o`co00007?l00?lNolHiaR;o003o0Ooo
ool002Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0Oko
oP7n00OooP7n00?o0000oo`3o?ol0o`03?ol0o`00ol0003onPGjooX5nP0BooX5nP03o`000?o`3o3o
l0o`00Co00002oo?<<l00ol0003ocC;=oldbc@0Boldbc@03o`000?o8=lSob3O800kob3O800?o0000
oieRWOnMHYd03onMHYd00ol0003oOH9mogf2O@02ogf2O@03o`000?nm@[go_D:m00Wo_D:m00?o0000
oo4>lOoa3_407?oa3_43o`0000[onPGj00?o0000oo`3o?ol0o`05?ol0o`01?l0003ooP7nooh1o_l0
000>ooh1oP03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003o003oo`00
o`0Jo`00oakoaSW68_l00?l1ooooo`008ol00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00Soo`3o00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00;oo`3o003o`000?oj1O[o
nPGj01;onPGj00Co0000onhAk_l0003o00003oo?<<l00ol0003ocC;=oldbc@0Aoldbc@03o`000?n6
NHKo000000oob3O800?o0000oieRWOnMHYd03_nMHYd00ol0003oOH9mogf2O@03ogf2O@03o`000?nm
@[go_D:m00Wo_D:m00?o0000oo4>lOoa3_406Ooa3_43o`0000?okQ7^00?o0000ooX5n_oj1OX01ooj
1OX00ol0003oo0?loo`3o00Coo`3o0Go00003oon0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo
0?ooo`3o00_oo`3o00?o0000o`00ool00?l06Ol00?lNolHiaR;o003o0Oooool002?o003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`09ool0o`03o`000?on0OkooP7n00GooP7n00?o0000
oo`3o?ol0o`02ool0o`00ol0003onPGjooX5nP0AooX5nP04o`000?o^4NkokQ7^o`00017occ3?00?o
0000oldbcOo=</d03oo=</d01Ol0003oQWV6ohIiQ_n6NHKo000000[ob3O81?l0000AoieRW@03o`00
0?mmPWgoOH9m00?oOH9m00?o0000oke2_Onm@[d02_nm@[d00ol0003ol@kaoo4>l@0Foo4>l@;o0000
1oo^4Nh00ol0003onPGjooX5nP05ooX5nP03o`000?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d0
0oom0_d00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`0Io`00oako`Ck18_l00?l1ooooo`008_l00?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ooh1o_on0Oh01?on0Oh3o`0000coo0?l00?o
0000ooX5n_oj1OX04?oj1OX00ol0003okQ7^onhAkP02onhAkP03o`000?o?<<oocc3?00kocc3?00?o
0000oldbcOo=</d03_o=</d00ol0003oQWV6ohIiQP03ohIiQP04o`000?o8=lSob3O8olPgb0Ko0000
0on:MHX00ol0003oWF:MoieRW@0>oieRW@03o`000?mmPWgoOH9m00CoOH9m00?o0000oke2_Onm@[d0
2_nm@[d00ol0003ol@kaoo4>l@0Coo4>l@?o00002_o^4Nh00ol0003onPGjooX5nP03ooX5nP03o`00
0?ol0ocoo0?l01?oo0?l00?o0000ood2oOom0_d01Oom0_d2o`0000gooP7n00?o0000ool0oooo0?l0
1Ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o01So003o7_o1?/4Ro`00o`7ooooo
000Ro`00o`03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP03o`0000?ooP7n00?o0000oo`3o?ol0o`02?ol0o`00ol0003onPGjooX5nP0@ooX5nP03o`000?o^
4NkokQ7^00?okQ7^00?o0000oll`coo?<<l03_o?<<l00ol0003ocC;=oldbc@0=oldbc@03o`000?n6
NHKoQWV600GoQWV60ol0000:ohYeRP03o`000?nMHYgoWF:M00coWF:M00?o0000ogf2OOmmPWd01Omm
PWd00ol0003o_D:moke2_@0;oke2_@03o`000?oa3_7ol@ka013ol@ka0_l0000>onhAkP03o`000?oj
1O[onPGj00;onPGj00?o0000oo`3o?ol0o`04_ol0o`00ol0003oo@;mood2o@08ood2o@03o`000?on
0OkooP7n00_ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l0
0?oo003o01Oo003o7_o1?/4Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l02Ooo0?l3o`0000OooP7n00?o0000oo`3o?ol0o`01ool0o`00ol0003onPGjooX5nP0?
ooX5nP03o`000?o^4NkokQ7^00CokQ7^00?o0000oll`coo?<<l03oo?<<l00ol0003ocC;=oldbc@0;
oldbc@03o`000?n6NHKoQWV600KoQWV600?o0000ohYeR_n:MHX02on:MHX00ol0003oWF:MoieRW@0;
oieRW@03o`000?mmPWgoOH9m00GoOH9m00?o0000oke2_Onm@[d03?nm@[d00ol0003ol@kaoo4>l@0<
oo4>l@?o00004Oo^4Nh5o`0001;oo0?l0_l0000<ood2o@03o`000?on0OkooP7n00[ooP7n00?o0000
ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o01Oo003o7_o1?/4R
o`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l02?oo0?l00ol0
003ooP7nooh1oP09ooh1oP;o00001ool0o`00ol0003onPGjooX5nP0>ooX5nP03o`000?o^4NkokQ7^
00KokQ7^00?o0000oll`coo?<<l03_o?<<l00ol0003ocC;=oldbc@0:oldbc@03o`000?n6NHKoQWV6
00OoQWV600?o0000ohYeR_n:MHX02on:MHX00ol0003oWF:MoieRW@0:oieRW@03o`000?mmPWgoOH9m
00KoOH9m00?o0000oke2_Onm@[d03?nm@[d00ol0003ol@kaoo4>l@0:oo4>l@;o00005?o^4Nh00ol0
003on`Ckoo/4n`02oo/4n`;o00003ool0o`00ol0003oo@;mood2o@0=ood2o@Go00002?on0Oh01?l0
003oo`3oool0ool0000Eool0o`03o`000?l00?oo003o01Ko003o7_o1?/4Ro`00o`7ooooo000Qo`00
o`03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003ooP7nooh1oP0<ooh1
oP03o`000?ol0ocoo0?l00?oo0?l00?o0000ooX5n_oj1OX03_oj1OX00ol0003okQ7^onhAkP07onhA
kP03o`000?o?<<oocc3?00kocc3?00?o0000oldbcOo=</d02Oo=</d00ol0003oQWV6ohIiQP08ohIi
QP03o`000?n:MH[oRWF:00coRWF:00?o0000oieRWOnMHYd02?nMHYd00ol0003oOH9mogf2O@07ogf2
O@03o`000?nm@[go_D:m00go_D:m1Ol00004oo4>l@?o00005Oo^4Nh00ol0003on`Ckoo/4n`05oo/4
n`03o`000?ol0ocoo0?l00_oo0?l00?o0000ood2oOom0_d03_om0_d00ol0003oo`3oool0o`02ool0
o`Oo000000CooP7no`000?oo0?oo00005_oo0?l00ol0003o003oo`00o`0Fo`00oako`Ck18_l00?l1
ooooo`008_l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ooh1
o_on0Oh03_on0Oh2o`0000?oo0?l00?o0000ooX5n_oj1OX03Ooj1OX00ol0003okQ7^onhAkP08onhA
kP03o`000?o?<<oocc3?00oocc3?00?o0000oldbcOo=</d01oo=</d00ol0003oQWV6ohIiQP09ohIi
QP03o`000?n:MH[oRWF:00coRWF:0ol00008oieRW@03o`000?mmPWgoOH9m00OoOH9m00?o0000oke2
_Onm@[d03Onm@[d00ol0003obcC;ol/db`02ol/db`Co00006?o^4Nh00ol0003on`Ckoo/4n`06oo/4
n`;o00002Ool0o`2o`00017oo@;m00?o0000ool0oooo0?l02Ooo0?l3o`0001Ooo`3o00?o0000o`00
ool00?l05_l00?lNoka3_2;o003o0Oooool002;o003o0_l0000?ool0o`03o`000?oo0?ooo`3o00Co
o`3o00?o0000ooh1o_on0Oh04Oon0Oh01?l0003oo0?loo`3o?l0000>ooX5nP03o`000?o^4NkokQ7^
00[okQ7^00?o0000oll`coo?<<l03_o?<<l00ol0003ocC;=oldbc@06oldbc@03o`000?n6NHKoQWV6
00[oQWV600?o0000ohYeR_n:MHX02_n:MHX2o`0000?oD:m@00?o0000oieRWOnMHYd01?nMHYd00ol0
003oOH9mogf2O@08ogf2O@03o`000?nm@[go_D:m00co_D:m00?o0000ol/dboo;=</01_o;=</00ol0
003okQ7^onhAkP0EonhAkP03o`000?ok1?_on`Ck00Won`Ck0_l00006oo`3o003o`000?om0_goo@;m
013oo@;m00?o0000ool0oooo0?l03?oo0?l2o`0001Koo`3o00?o0000o`00ool00?l05_l00?lNoka3
_2;o003o0Oooool002;o003o00?o0000ool0ool000000_l0000<ool0o`03o`000?oo0?ooo`3o00?o
o`3o00?o0000ooh1o_on0Oh04oon0Oh2o`0000konPGj00?o0000onhAk_o^4Nh02oo^4Nh00ol0003o
cc3?oll`c`0>oll`c`03o`000?o=</gocC;=00GocC;=00?o0000ohIiQ_n6NHH02on6NHH00ol0003o
RWF:ohYeRP08ohYeRP;o00001_m@[e000ol0003oWF:MoieRW@02oieRW@03o`000?mmPWgoOH9m00Wo
OH9m00?o0000oke2_Onm@[d03?nm@[d00ol0003obcC;ol/db`07ol/db`03o`000?o^4NkokQ7^01Co
kQ7^00?o0000oo/4nook1?/02ook1?/00ol0003oo0?loo`3o002oo`3o003o`000?om0_goo@;m017o
o@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oo`00000Dool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Qo`00o`03o`000?oo0?ooo`3o00?oo`3o0ol00009ool0o`03o`00
0?oo0?ooo`3o00;oo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003onPGjooX5nP0;ooX5nP03o`00
0?o^4NkokQ7^00gokQ7^00?o0000oll`coo?<<l03_o?<<l00ol0003ocC;=oldbc@03oldbc@03o`00
0?n6NHKoQWV600coQWV600?o0000ohYeR_n:MHX01_n:MHX2o`0000WoD:m@00Go0000oieRWOnMHYgo
WF:Mo`00000;ogf2O@03o`000?nm@[go_D:m00co_D:m00?o0000ol/dboo;=</01oo;=</00ol0003o
kQ7^onhAkP0ConhAkP03o`000?ok1?_on`Ck00gon`Ck0_l000000ool0oco0000ood2o@0Cood2o@03
o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l00_l0000Bool0o`03o`000?l00?oo003o01Oo
003o7_nl@k`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00Ooo`3o0_l00007ool0o`05o`00
0?oo0?ooo`3oool0ool000006?on0Oh00ol0003onPGjooX5nP0:ooX5nP03o`000?o^4NkokQ7^00ko
kQ7^00?o0000oll`coo?<<l03_o?<<l00ol0003ocC;=oldbc@02oldbc@03o`000?n6NHKoQWV600go
QWV600?o0000ohYeR_n:MHX01?n:MHX2o`0000coD:m@00?o0000oieRWOl000003?mmPWd00ol0003o
_D:moke2_@0;oke2_@03o`000?o;=<_obcC;00WobcC;00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003o
n`Ckoo/4n`0@oo/4n`03o`000?om0_goo@;m01;oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`03ool0o`;o00004?oo0?l00ol0003o003oo`00o`0Go`00oako_4>l8_l00?l1ooooo`00
7ol00?l00ol0003oo`3oool0o`0:ool0o`?o00001Ooo0?l4o`0001WooP7n00?o0000ooX5n_oj1OX0
2?oj1OX00ol0003okQ7^onhAkP0?onhAkP03o`000?o?<<oocc3?00kocc3?00Go0000oldbcOo=</go
cC;=o`00000@ohIiQP03o`000?n:MH[oRWF:00;oRWF:0_l0000?oe2_D003o`000?mmPWgoOH9m00_o
OH9m00?o0000oke2_Onm@[d02onm@[d00ol0003obcC;ol/db`09ol/db`03o`000?o^4NkokQ7^017o
kQ7^00?o0000oo/4nook1?/04?ok1?/2o`0001?oo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003o
o`3oool0o`05ool0o`03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l05ol00?lNoka3_2;o
003o0Oooool001oo003o00?o0000ool0oooo0?l03Ooo0?l3o`000003ool0ool0003o000000?oo`3o
00?o0000ooh1o_on0Oh05_on0Oh3o`0000OonPGj00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003occ3?
oll`c`0>oll`c`Co00004?n6NHH00ol0003oRWF:ohYeRP02o`00017oD:m@00?o0000ogf2OOmmPWd0
2ommPWd00ol0003o_D:moke2_@0:oke2_@03o`000?o;=<_obcC;00_obcC;00?o0000onhAk_o^4Nh0
3oo^4Nh00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on0Oko000000;o00004?om0_d00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000=ool0o`03o`000?l00?oo003o01Oo003o
7_nfBKHRo`00o`7ooooo000No`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo
0?l00ol0003ooP7nooh1oP0Cooh1oP;o00000ool0o`00ol0003onPGjooX5nP03ooX5nP03o`000?o^
4NkokQ7^01;okQ7^00?o0000oll`coo?<<l03Oo?<<l00ol0003oQGZ5ohEjQ@02ohEjQ@;o00003_n6
NHH3o`0001?oD:m@00?o0000ogf2OOmmPWd02ommPWd00ol0003o_D:moke2_@0:oke2_@03o`000?o;
=<_obcC;00_obcC;00?o0000onhAk_o^4Nh03oo^4Nh00ol0003on`Ckoo/4n`0Aoo/4n`03o`000?on
0OkooP7n00;ooP7n0ol0000=ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l02Ooo
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01Oo003o7_nfBKHRo`00o`7ooooo000M
o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0A
ooh1oP03o`000?ol0ocoo0?l00Coo0?l00Go0000ooX5n_oj1O[onPGjo`00000EonhAkP03o`000?o?
<<oocc3?00cocc3?00?o0000ohEjQOn5NXD01On5NXD2o`0000coQWV600?o0000oe2_D?m@[e005?m@
[e000ol0003oOH9mogf2O@0:ogf2O@03o`000?nm@[go_D:m00[o_D:m00?o0000ol/dboo;=</03?o;
=</00ol0003okQ7^onhAkP0=onhAkP03o`000?ok1?_on`Ck01;on`Ck00?o0000ooh1o_on0Oh01Oon
0Oh3o`0000Woo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0:ool0o`;o00002Ooo
0?l00ol0003o003oo`00o`0Ho`00oako]TVf8_l00?l1ooooo`007Ol00?l00ol0003oo`3oool0o`0B
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh03_on0Oh2o`0000Soo0?l00?o0000
ooX5n_l000005oo^4Nh00ol0003occ3?oll`c`0:oll`c`03o`000?n5NXGoQGZ500SoQGZ500?o0000
ohIiQ_n6NHH02?n6NHH3o`0001GoD:m@0_l0000;ogf2O@03o`000?nm@[go_D:m00Wo_D:m00?o0000
ol/dboo;=</03_o;=</00ol0003okQ7^onhAkP0<onhAkP03o`000?ok1?_on`Ck01;on`Ck00?o0000
ooh1o_on0Oh02?on0Oh2o`0000Ooo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<
ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o0000o`00ool00?l06?l00?lNokI9]R;o003o0Oooool0
01go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003?on0Oh2o`00
00_oo0?l00?o0000onhAk_o^4Nh05_o^4Nh00ol0003occ3?oll`c`09oll`c`03o`000?n5NXGoQGZ5
00[oQGZ50_l00005ohIiQP?o00000olm`Sd00ol0003oD:m@oe2_D00Aoe2_D003o`000?lWf2Oo9mPW
00;o00002OmmPWd00ol0003o_D:moke2_@09oke2_@03o`000?o;=<_obcC;00kobcC;00?o0000onhA
k_o^4Nh02oo^4Nh00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0OkooP7n00[ooP7n0ol00004ood2
o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo0?l03_oo0?l2o`0000Koo`3o00?o0000o`00
ool00?l06?l00?lNokI9]R;o003o0Oooool001go003o00?o0000ool0oooo0?l04Ooo0?l00ol0003o
o`3oool0o`0:ool0o`03o`000?on0OkooP7n00OooP7n0_l0000=oo`3o003o`000?o^4NkokQ7^01Ko
kQ7^00?o0000oll`coo?<<l00oo?<<l6o`0000ooQGZ50_l000000on6NHKo0000o`000007ocg2?@;o
00004?m@[e000ol0003o9mPWobOH9`03obOH9`?o00001_mmPWd00ol0003o_D:moke2_@09oke2_@03
o`000?o;=<_obcC;00oobcC;00?o0000onhAk_o^4Nh02_o^4Nh00ol0003on`Ckoo/4n`0Coo/4n`03
o`000?on0OkooP7n00gooP7n1?l0000>ool0o`03o`000?oo0?ooo`3o013oo`3o0_l00003ool0o`03
o`000?l00?oo003o01Wo003o7_nfBKHRo`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o017oo`3o
00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP04ooh1oP;o00004?ol0o`00ol0003okQ7^
onhAkP0FonhAkPGo00001OnkA;/00ol0003oQGZ5ohEjQ@0?ohEjQ@03o`000?lm`Sgo?L8m00Wo?L8m
00?o0000oe2_D?m@[e003?m@[e000ol0003o9mPWobOH9`07obOH9`;o00000_mmPWd>o`0001;obcC;
00?o0000onhAk_o^4Nh02Oo^4Nh00ol0003on`Ckoo/4n`0Doo/4n`03o`000?on0OkooP7n013ooP7n
00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?oo000001co003o
7_naC[4Ro`00o`7ooooo000Mo`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP02ooh1oP03o`000?ol0ocoo0?l013oo0?l00?o0000onhAk_o^4Nh05Oo^
4Nh00ol0003o^dBkok]4^`09ok]4^`03o`000?n5NXGoQGZ500koQGZ500?o0000ocg2?Olm`Sd02_lm
`Sd2o`0000_oD:m@00?o0000obOH9olWf2L02_lWf2L2o`0000goEZUF00?o0000ol/dboo;=</04Oo;
=</00ol0003okQ7^onhAkP07onhAkP03o`000?ok1?_on`Ck01Gon`Ck0_l0000Booh1oP03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`0Ko`00oako/Dja8_l0
0?l1ooooo`007?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o00Co0000
ooh1o_l0003o00005?ol0o`00ol0003okQ7^onhAkP0ConhAkP03o`000?nkA;_o^dBk00[o^dBk00?o
0000ohEjQOn5NXD03_n5NXD00ol0003o?L8mocg2?@0<ocg2?@03o`000?m@[e3oD:m@00OoD:m@00?o
0000obOH9olWf2L02olWf2L00ol0003oEZUFoeJYEP0=oeJYEP03o`000?o;=<_obcC;013obcC;00?o
0000onhAk_o^4Nh01oo^4Nh00ol0003on`Ckoo/4n`0Eoo/4n`04o`000?on0Oko0000o`00017ooP7n
00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o01_o003o
7_naC[4Ro`00o`7ooooo000Lo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03ooo
0?l00ol0003oo0?loo`3o00Doo`3o003o`000?o^4NkokQ7^01;okQ7^00?o0000ok]4^onkA;/02onk
A;/00ol0003oQGZ5ohEjQ@0>ohEjQ@03o`000?lm`Sgo?L8m00go?L8m00?o0000oe2_D?m@[e001?m@
[e02o`0000ko9mPW00?o0000oeJYE_mFZEH03OmFZEH00ol0003obcC;ol/db`0@ol/db`Co00001Oo^
4Nh00ol0003on`Ckoo/4n`0Foo/4n`04o`000?on0OkooP7nooh1oP;o00004?on0Oh00ol0003oo`3o
ool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l07?l00?lNok5>/B;o003o
0Oooool001co003o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l01Goo0?l5?l0000?ok]4^`03o`000?n5NXGoQGZ500coQGZ500?o0000od6n@Ol000003olm
`Sd2o`0000?oD:m@00Co0000oaSW6?lHiaSo00003OlWf2L00ol0003oEZUFoeJYEP0>oeJYEP03o`00
0?o;=<_obcC;00cobcC;0ol00004om</d`?o00000_o^4Nh00ol0003on`Ckoo/4n`0Foo/4n`03o`00
0?on0OkooP7n00?ooP7n0_l0000?ooh1oP03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
5?oo0?l00ol0003o003oo`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000oo`3o?ol0o`05Ool0o`00ol0003ojAKYonTF
j@0@onTFj@03o`000?nkA;_o^dBk00go^dBk00?o0000ohEjQOn5NXD02on5NXD01?l0003o@Ki1od6n
@Ol0000Aocg2?@03o`000?m@[e3o000000Co6>LH00?o0000obOH9olWf2L02_lWf2L00ol0003oEZUF
oeJYEP0>oeJYEP03o`000?o;=<_obcC;00WobcC;0ol0000:om</d`;o00006?ok1?/00ol0003ooP7n
ooh1oP06ooh1oP;o00003_on0Oh00ol0003oo`3oool0o`04ool0o`?o00005Ooo0?l00ol0003o003o
o`00o`0Lo`00oako/Dja8_l00?l1ooooo`007?l00?l00ol0003oo`3oool0o`0?ool0o`;o00004_oo
0?l00ol0003oo0?loo`3o00Eoo`3o003o`000?oY5^WojAKY013ojAKY00?o0000ok]4^onkA;/03Onk
A;/00ol0003oQGZ5ohEjQ@0:ohEjQ@03o`000?m1_T7o@Ki100;o@Ki100?o0000ocg2?Olm`Sd03olm
`Sd00ol0003o6>LHoaSW6004oaSW6003o`000?lWf2Oo9mPW00Wo9mPW00?o0000oeJYE_mFZEH03_mF
ZEH00ol0003obcC;ol/db`06ol/db`?o00003_oC;=<00ol0003on`Ckoo/4n`0Foo/4n`03o`000?on
0OkooP7n00SooP7n0_l0000=ooh1oP03o`000?oo0?ooo`3o00?o00000ooo0?l00ol0003oo`3oool0
o`0Aool0o`03o`000?l00?oo003o01go003o7_n/Dj`Ro`00o`7ooooo000Lo`00o`03o`000?oo0?oo
o`3o00coo`3o0ol000000ooo0?oo0000ool0o`0@ool0o`03o`000?ol0ocoo0?l01Goo0?l00?o0000
onTFjOoY5^T04_oY5^T00ol0003o^dBkok]4^`0=ok]4^`03o`000?n5NXGoQGZ500WoQGZ500?o0000
od6n@Om1_T400_m1_T400ol0003o?L8mocg2?@0?ocg2?@03o`000?lHiaSo6>LH00Go6>LH00?o0000
obOH9olWf2L02?lWf2L00ol0003oEZUFoeJYEP0?oeJYEP03o`000?o;=<_obcC;00;obcC;0ol0000B
om</d`03o`000?ok1?_on`Ck01Gon`Ck00?o0000ooh1o_on0Oh02_on0Oh2o`0000cooP7n0_l00007
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l07Ol00?lNojaC[2;o003o0Oooool0
01go003o00?o0000ool0oooo0?l02?oo0?l3o`0000Goo`3o00?o0000ool0oooo0?l03_oo0?l00ol0
003oo0?loo`3o00Coo`3o0?o00005?oY5^T00ol0003o^dBkok]4^`0=ok]4^`03o`000?n5NXGoQGZ5
00SoQGZ500?o0000od6n@Om1_T401?m1_T400ol0003o?L8mocg2?@0>ocg2?@03o`000?lHiaSo6>LH
00Ko6>LH00?o0000obOH9olWf2L01olWf2L00ol0003oEZUFoeJYEP0?oeJYEP03o`000?o;=<_o0000
00;o00005OoC;=<00ol0003on`Ckoo/4n`0Eoo/4n`03o`000?on0OkooP7n00cooP7n0_l0000:ooh1
oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0Mo`00
oako[5>/8_l00?l1ooooo`007_l00?l00ol0003oo`3oool0o`04ool0o`?o00002Ooo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?ol0ocoo0?l00ooo0?l1?l00002ooH9mP03o`000?oY5^WojAKY01;o
jAKY00?o0000ok]4^onkA;/03OnkA;/00ol0003oQGZ5ohEjQ@07ohEjQ@03o`000?m1_T7o@Ki100Go
@Ki100?o0000ocg2?Olm`Sd03Olm`Sd00ol0003o6>LHoaSW6008oaSW6003o`000?lWf2Oo9mPW00Ko
9mPW00?o0000oeJYE_mFZEH04?mFZEH00ol0003odbcCom</d`0Fom</d`03o`000?ok1?_on`Ck01Go
n`Ck00?o0000ooh1o_on0Oh03_on0Oh2o`0000OooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000ko
o`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o0Oooool001oo003o00?o0000ool0oooo0?l0
0ol0000=ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02ool0o`4o`0000KomPWf
00?o0000onTFjOoY5^T04ooY5^T00ol0003o^dBkok]4^`0=ok]4^`03o`000?n5NXGoQGZ500GoQGZ5
00?o0000od6n@Om1_T401om1_T400ol0003o?L8mocg2?@0<ocg2?@03o`000?lHiaSo6>LH00Wo6>LH
00?o0000obOH9olWf2L01OlWf2L00ol0003oEZUFoeJYEP0@oeJYEP03o`000?oC;=?odbcC01OodbcC
00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0@ooh1oP;o00001?on0Oh00ol0003oo`3o
ool0o`0<ool0o`03o`000?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l07_l00?lNojaC[2;o003o
0Oooool0023o003o0_l0000@ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`01ool
0o`4o`0000[omPWf00?o0000onTFjOoY5^T04ooY5^T00ol0003o^dBkok]4^`0=ok]4^`03o`000?n5
NXGoQGZ500CoQGZ500?o0000od6n@Om1_T402?m1_T400ol0003o?L8mocg2?@0<ocg2?@03o`000?lH
iaSo6>LH00[o6>LH00?o0000obOH9olWf2L01?lWf2L00ol0003oEZUFoeJYEP0@oeJYEP03o`000?oC
;=?odbcC01OodbcC00?o0000oo/4nook1?/05?ok1?/00ol0003ooP7nooh1oP0Booh1oP;o000000?o
oP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0:ool0o`03o`000?l00?oo003o01ko003o7_n/
Dj`Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo0?loo`3o004oo`3o0Co00003_of2OH00ol0003ojAKYonTFj@0ConTFj@03o`000?nkA;_o
^dBk00go^dBk00?o0000ohEjQOn5NXD01?n5NXD00ol0003o@Ki1od6n@@09od6n@@03o`000?lm`Sgo
?L8m00_o?L8m00?o0000oaSW6?lHiaP02olHiaP00ol0003o9mPWobOH9`03obOH9`03o`000?mFZEKo
EZUF013oEZUF00?o0000om</dooC;=<05ooC;=<00ol0003on`Ckoo/4n`0Coo/4n`03o`000?on0Oko
oP7n01GooP7n00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`08ool0o`03o`000?l00?oo
003o01oo003o7_nWF:LRo`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0
oooo0?l02Ooo0?l00ol0003oo0?loo`3o004o`0001;omPWf00?o0000onTFjOoY5^T04ooY5^T00ol0
003o^dBkok]4^`0>ok]4^`03o`000?n5NXGoQGZ500;oQGZ500?o0000od6n@Om1_T402_m1_T400ol0
003o?L8mocg2?@0:ocg2?@03o`000?lHiaSo6>LH00go6>LH00?o0000obOH9olWf2L00_lWf2L00ol0
003oEZUFoeJYEP0@oeJYEP03o`000?oC;=?odbcC01SodbcC00?o0000oo/4nook1?/04_ok1?/00ol0
003ooP7nooh1oP0Eooh1oP03o`000?oo0?ooo`3o017oo`3o0_l00007ool0o`;o00008Ol00?lNojMH
Yb;o003o0Oooool0023o003o00?o0000ool0oooo0?l04_oo0?l3o`0000Ooo`3o1?l0000GooH9mP03
o`000?oY5^WojAKY01?ojAKY00?o0000ok]4^onkA;/03?nkA;/4o`000003ohEjQOl0003o@Ki100go
@Ki100?o0000ocg2?Olm`Sd02Olm`Sd00ol0003o6>LHoaSW600>oaSW6005o`000?lWf2Oo9mPWobOH
9ol000004_mFZEH00ol0003odbcCom</d`0Hom</d`?o00004_ok1?/00ol0003ooP7nooh1oP0Dooh1
oP03o`000?oo0?ooo`3o01Coo`3o00?o0000ool0oooo0?l00ooo0?l00ol0003o003oo`00o`0Qo`00
oakoYeRW8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?o
000000Coo`3oo`000?l0003o00000_om0_d00ol0003omPWfooH9mP0FooH9mP03o`000?oY5^WojAKY
01?ojAKY00?o0000ok]4^onkA;/02onkA;/00ol0003oDJiAoe6^D@02oe6^D@;o00003_m1_T400ol0
003o?L8mocg2?@09ocg2?@03o`000?lHiaSo6>LH00oo6>LH00Co0000obOH9olWf2Oo00004_mFZEH0
0ol0003odbcCom</d`0Hom</d`03o`000?o^4NkokQ7^00?o00003ook1?/5o`0001;ooP7n00?o0000
ool0oooo0?l05Ooo0?l01Ol0003oo`3oool0oooo0?oo000002Co003o7_nWF:LRo`00o`7ooooo000P
o`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l01?oo0?l00ol0003oo@;mood2o@04
ood2o@03o`000?of2OKomPWf01GomPWf00?o0000onTFjOoY5^T04ooY5^T00ol0003o^dBkok]4^`0:
ok]4^`03o`000?mA[U7oDJiA00GoDJiA00?o0000od6n@Om1_T403?m1_T400ol0003o?L8mocg2?@08
ocg2?@03o`000?lHiaSo6>LH00oo6>LH1Ol0000AoeJYEP03o`000?oC;=?odbcC01OodbcC00?o0000
onhAk_o^4Nh01?o^4Nh3o`0000con`Ck00?o0000ooh1o_on0Oh00_on0Oh7o`0000[ooP7n00?o0000
ool0oooo0?l05ooo0?l00ol0003oo`3oo`00000Uo`00oakoYeRW8_l00?l1ooooo`008?l00?l00ol0
003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Goo`3o00?o0000ood2oOom0_d01Oom0_d00ol0
003omPWfooH9mP0DooH9mP03o`000?oY5^WojAKY01?ojAKY00?o0000ok]4^onkA;/02?nkA;/2o`00
00WoDJiA00?o0000od6n@Om1_T402om1_T400ol0003o?L8mocg2?@07ocg2?@03o`000?lHiaSo6>LH
00go6>LH0ol00005oa7^4@03o`000?mFZEKoEZUF00koEZUF00?o0000om</dooC;=<05_oC;=<00ol0
003okQ7^onhAkP08onhAkP?o00002?ok1?/00ol0003ooP7nooh1oP0:ooh1oPOo00000oon0Oh00ol0
003oo`3oool0o`0Hool0o`03o`000?l00?oo003o02Co003o7_nWF:LRo`00o`7ooooo000Po`00o`03
o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo@;mood2o@06ood2o@03
o`000?of2OKomPWf01?omPWf0_l0000EonTFj@03o`000?nkA;_o^dBk00Ko^dBk00?o0000oe6^DOmA
[U402_mA[U400ol0003o@Ki1od6n@@0:od6n@A[o00002OlAkQ400ol0003oEZUFoeJYEP0<oeJYEP?o
00005_oC;=<00ol0003okQ7^onhAkP0<onhAkP?o00001?ok1?/00ol0003ooP7nooh1oP0Booh1oP?o
00006ooo0?l00ol0003o003oo`00o`0To`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3o
ool0o`0>ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ood2oOom0_d01oom0_d00ol0003omPWf
ooH9mP0@ooH9mP;o00000_oV6NH3o`0001;ojAKY00?o0000ok]4^onkA;/01?nkA;/2o`0000koDJiA
00?o0000od6n@Om1_T401om1_T42o`0000[o7N8M00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o4NhA
oa7^4@08oa7^4@;o00002_mFZEH2o`0000?o:m@[0_l0000Com</d`03o`000?o^4NkokQ7^013okQ7^
1?l0000Gooh1oP03o`000?oo0?ooo`3o01Woo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o
0Oooool0023o003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`08ool0o`03o`000?om
0_goo@;m00Soo@;m00?o0000ooH9m_of2OH03_of2OH00ol0003om`Sgo`000005onHIiP;o00004?oY
5^T00ol0003o^dBkok]4^`03ok]4^`03o`000?mA[U7oDJiA00ooDJiA00?o0000od6n@Om1_T401?m1
_T42o`0000co7N8M00?o0000o`gb3Ol=lPd03?l=lPd00ol0003o4NhAoa7^4@0:oa7^4@03o`000?mF
ZEKoEZUF00GoEZUF0_l00007ob_D:`03o`000?oC;=?odbcC00oodbcC00?o0000onhAk_o^4Nh04Oo^
4Nh01?l0003onPGjooX5n_l0000Gooh1oP03o`000?oo0?ooo`3o01Soo`3o00?o0000o`00ool00?l0
9Ol00?lNoj9MXR;o003o0Oooool0023o003o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`09ool0o`03o`000?om0_goo@;m00Woo@;m00?o0000ooH9m_of2OH02oof2OH2o`0000;om`Sg00?o
0000onHIi_oV6NH01OoV6NH2o`0000oojAKY00Go0000ok]4^onkA;_o^dBko`00000Coe6^D@03o`00
0?m1_T7o@Ki100;o@Ki100?o0000oagR7OlMhQd03OlMhQd00ol0003o3O8=o`gb3@0;o`gb3@03o`00
0?lAkQ7o4NhA00_o4NhA00?o0000oeJYE_mFZEH00_mFZEH2o`0000[o:m@[0_l0000>om</d`03o`00
0?o^4NkokQ7^017okQ7^00Go0000ooX5n_oj1O[onPGjo`00000Hooh1oP03o`000?oo0?ooo`3o01Ko
o`3o0_l0000Wo`00oakoXUfR8_l00?l1ooooo`008?l00?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o00[oo`3o00?o0000ood2oOom0_d02_om0_d00ol0003omPWfooH9mP09ooH9mP03o`00
0?og2?Oom`Sg00?om`Sg00?o0000onHIi_oV6NH01_oV6NH3o`0000_ojAKY1Ol0000Eoe6^D@04o`00
0?m1_T7o0000o`00013o7N8M00?o0000o`gb3Ol=lPd02ol=lPd00ol0003o4NhAoa7^4@0<oa7^4@04
o`000?mFZEKo0000o`0000ko:m@[0_l0000;om</d`03o`000?o^4NkokQ7^017okQ7^00?o0000ooX5
n_oj1OX00ooj1OX00ol0003ooP7nooh1oP0Eooh1oP;o00005Ooo0?l2o`000003ool0ool0003o003o
02Ko003o7_nRGJ8Ro`00o`7ooooo000Po`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02ooo0?l00ol0003oo@;mood2o@0;ood2o@03o`000?of2OKomPWf00KomPWf0_l00006ooL8m`03
o`000?oV6NKoiQWV00WoiQWV0_l00008onTFj@03o`000?nSG:?oXebS00;oXebS00?o0000oe6^DOmA
[U405?mA[U400ol0003o7N8MoagR7@0@oagR7@03o`000?l=lPgo3O8=00_o3O8=00?o0000oa7^4OlA
kQ403OlAkQ400ol0003o:m@[ob_D:`0@ob_D:`03o`000?oC;=?odbcC00OodbcC00?o0000onhAk_o^
4Nh04Oo^4Nh00ol0003onPGjooX5nP04ooX5nP03o`000?on0OkooP7n01GooP7n00?o0000ool0ool0
00004Ooo0?l3o`0000Coo`3o00?o0000o`00ool00?l09?l00?lNoj9MXR;o003o0Oooool0027o003o
00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?om0_goo@;m00coo@;m
00?o0000ooH9m_of2OH01?of2OH00ol0003om`SgooL8m`06ooL8m`03o`000?oV6NKoiQWV00_oiQWV
0_l00005onTFj@03o`000?nSG:?oXebS00CoXebS00?o0000oe6^DOmA[U404omA[U400ol0003o7N8M
oagR7@0@oagR7@03o`000?l=lPgo3O8=00_o3O8=00?o0000oa7^4OlAkQ403OlAkQ400ol0003o:m@[
ob_D:`0Aob_D:`;o00000ooC;=<4o`0001?okQ7^00?o0000ooX5n_oj1OX01Ooj1OX00ol0003ooP7n
ooh1oP0Dooh1oP05o`000?oo0?ooo`3oool0ool000003_oo0?l2o`0000Ooo`3o00?o0000o`00ool0
0?l09?l00?lNoiaSW2;o003o0Oooool002;o003o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0=ool0o`03o`000?om0_goo@;m00goo@;m00Co0000ooH9m_of2OKomPWf0_l00009ooL8m`03
o`000?oV6NKoiQWV00goiQWV0ol000000ooY5^Wo0000oj=LX`07oj=LX`03o`000?mA[U7oDJiA01;o
DJiA00?o0000oagR7OlMhQd04?lMhQd00ol0003o3O8=o`gb3@0;o`gb3@03o`000?lAkQ7o4NhA00go
4NhA00?o0000ob_D:ol[e2/04ol[e2/3o`0000?oebSG00?o0000onhAk_o^4Nh04?o^4Nh00ol0003o
nPGjooX5nP07ooX5nP03o`000?on0OkooP7n01;ooP7n00?o0000ool0oooo0?l00ooo0?l00ol0003o
o`3oool0o`09ool0o`;o00002Ooo0?l00ol0003o003oo`00o`0To`00oakoW6>L8_l00?l1ooooo`00
8ol00?l00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000ood2oOom0_d0
3_om0_d00ol0003omPWfo`00000;ooL8m`03o`000?oV6NKoiQWV013oiQWV00?o0000oj=LXonSG:<0
2?nSG:<00ol0003oDJiAoe6^D@0Aoe6^D@03o`000?lMhQgo7N8M017o7N8M00?o0000o`gb3Ol=lPd0
2_l=lPd00ol0003o4NhAoa7^4@0<oa7^4@03o`000?l=lPgo000001Co:m@[00?o0000omLXeooG:=L0
1?oG:=L00ol0003okQ7^onhAkP0>onhAkP03o`000?oj1O[onPGj00SonPGj00?o0000ooh1o_on0Oh0
4Oon0Oh00ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0000<ool0o`03o`00
0?l00?oo003o02?o003o7_nLHi`Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00Co00004?oo
0?l00ol0003oo@;mood2o@0?ood2o@03o`000?og2?Oom`Sg00_om`Sg00?o0000onHIi_oV6NH03ooV
6NH00ol0003oXebSoj=LX`09oj=LX`03o`000?mA[U7oDJiA013oDJiA00?o0000oagR7OlMhQd04OlM
hQd00ol0003o3O8=o`gb3@0:o`gb3@03o`000?lAkQ7o4NhA00_o4NhA00Co0000o`gb3Ol=lPgo0000
5?l[e2/00ol0003oebSGomLXe`05omLXe`03o`000?o^4NkokQ7^00cokQ7^00?o0000ooX5n_oj1OX0
2Ooj1OX00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l0
0_oo0?l3o`0000koo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o0Oooool002Go003o0_l0
0004ool0o`?o00003Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00003Oog2?L00ol0003oiQWVonHI
iP0?onHIiP03o`000?nSG:?oXebS00[oXebS00?o0000oe6^DOmA[U403_mA[U400ol0003o7N8Mo`00
000BoagR7@03o`000?l=lPgo3O8=00[o3O8=00?o0000oa7^4OlAkQ402_lAkQ400ol0003o3O8=o`gb
3@02o`gb3@03o`000?l[e2_o:m@[013o:m@[00?o0000omLXeooG:=L01ooG:=L00ol0003okQ7^onhA
kP0:onhAkP03o`000?oj1O[onPGj00[onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0
o`09ool0o`04o`000?oo0?oo0000o`00017oo`3o00?o0000o`00ool00?l08ol00?lNoiaSW2;o003o
0Oooool002Go003o00?o0000ool0oooo0?l01_oo0?l3o`0000[oo`3o00?o0000ood2oOom0_d03Oom
0_d01?l0003oo0?loo`3o?l0000<ooL8m`03o`000?oV6NKoiQWV00ooiQWV00?o0000oj=LXonSG:<0
2onSG:<00ol0003oDJiAoe6^D@0<oe6^D@05o`000?lMhQgo7N8MoagR7Ol000004OlMhQd00ol0003o
3O8=o`gb3@0:o`gb3@03o`000?lAkQ7o4NhA00Wo4NhA00?o0000o`gb3Ol=lPd00ol=lPd00ol0003o
:m@[ob_D:`0@ob_D:`03o`000?oG:=OoebSG00SoebSG00?o0000onhAk_o^4Nh02?o^4Nh00ol0003o
nPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?l00?oo003o02;o003o7_nLHi`Ro`00o`7ooooo000Uo`00o`03o`00
0?oo0?ooo`3o00Woo`3o0ol00006ool0o`?o00003Oom0_d00ol0003oo0?loo`3o002oo`3o003o`00
0?og2?Oom`Sg00Wom`Sg00?o0000onHIi_oV6NH03_oV6NH00ol0003oXebSoj=LX`0=oj=LX`03o`00
0?mA[U7oDJiA00[oDJiA00?o0000oagR7OlMhQd00olMhQd00ol0003o7N8MoagR7@0?oagR7@03o`00
0?l=lPgo3O8=00Wo3O8=00?o0000oa7^4OlAkQ402?lAkQ400ol0003o3O8=o`gb3@05o`gb3@03o`00
0?l[e2_o:m@[00oo:m@[00?o0000omLXeooG:=L02OoG:=L00ol0003okQ7^onhAkP06onhAkP03o`00
0?oj1O[onPGj00gonPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0<ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l08_l00?lNoiMXUb;o003o0Oooool002Go003o00?o
0000ool0oooo0?l03?oo0?l3o`000003ool0ool0003o000000?oo`3o0_l0000:ood2o@03o`000?ol
0ocoo0?l00Coo0?l00?o0000ooL8moog2?L02?og2?L00ol0003oiQWVonHIiP0>onHIiP03o`000?nS
G:?oXebS00koXebS00?o0000oe6^DOmA[U402?mA[U400ol0003o7N8MoagR7@05oagR7@03o`000?lM
hQgo7N8M00ko7N8M00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o4NhAoa7^4@07oa7^4@03o`000?l=
lPgo3O8=00Ko3O8=00?o0000ob_D:ol[e2/03ol[e2/00ol0003oebSGomLXe`09omLXe`03o`000?o^
4NkokQ7^00GokQ7^00?o0000ooX5n_oj1OX03_oj1OX00ol0003ooP7nooh1oP0;ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`0Ro`00oakoUfRG8_l0
0?l1ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Goo`3o0_l00007
ood2o@03o`000?ol0ocoo0?l00Goo0?l00?o0000ooL8moog2?L02Oog2?L00ol0003oiQWVonHIiP0=
onHIiP03o`000?nSG:?oXebS00ooXebS00?o0000oe6^DOmA[U401_mA[U400ol0003o7N8MoagR7@07
oagR7@03o`000?lMhQgo7N8M00go7N8M00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o4NhAoa7^4@04
oa7^4@?o00002_l=lPd00ol0003o:m@[ob_D:`0=ob_D:`03o`000?oG:=OoebSG00_oebSG00?o0000
onhAk_o^4Nh00oo^4Nh00ol0003onPGjooX5nP0@ooX5nP03o`000?on0OkooP7n00WooP7n00?o0000
ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02?o003o7_nGJ9LR
o`00o`7ooooo000Uo`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l2o`00
00Coo@;m00?o0000oo`3o?ol0o`01ool0o`00ol0003om`SgooL8m`08ooL8m`03o`000?oV6NKoiQWV
00goiQWV00?o0000oj=LXonSG:<04?nSG:<00ol0003oDJiAoe6^D@05oe6^D@03o`000?lMhQgo7N8M
00So7N8M00?o0000oagR7OlMhQd03?lMhQd00ol0003o3O8=o`gb3@09o`gb3@03o`000?lAkQ7o0000
00Co00000_l;m0/00ol0003o3O8=o`gb3@08o`gb3@03o`000?l[e2_o:m@[00go:m@[00?o0000omLX
eooG:=L03?oG:=L01Ol0003okQ7^onhAk_o^4Nko000001;onPGj0ol00009ooh1oP03o`000?oo0?oo
o`3o00ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1
ooooo`009Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Woo`3o0_l000000oom
0_go0000oo`3o00:oo`3o003o`000?og2?Oom`Sg00Oom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0
003oXebSoj=LX`0Aoj=LX`03o`000?mA[U7oDJiA00?oDJiA00?o0000oagR7OlMhQd02_lMhQd00ol0
003o7N8MoagR7@0;oagR7@03o`000?l=lPgo3O8=00So3O8=0ol00008o`_d2`03o`000?l=lPgo3O8=
00So3O8=00?o0000ob_D:ol[e2/03?l[e2/00ol0003oebSGomLXe`0=omLXe`03o`000?o^4Nko0000
01;onPGj00Co0000ooh1o_on0OkooP7n0_l00006ooh1oP03o`000?oo0?ooo`3o013oo`3o00?o0000
ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0So`00oakoUfRG8_l00?l1ooooo`009?l00?l00ol0
003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00coo`3o00?o0000oo`3o?ol0o`02_ol0o`00ol0
003om`SgooL8m`07ooL8m`03o`000?oV6NKoiQWV00goiQWV00?o0000oj=LXonSG:<04_nSG:<01Ol0
003oDJiAoe6^DOmA[U7o000000ko7N8M00?o0000oagR7OlMhQd02olMhQd00ol0003o3O8=o`gb3@06
o`gb3@03o`000?l;m0_o2o@;00Wo2o@;00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o:m@[ob_D:`0:
ob_D:`03o`000?oG:=OoebSG00ooebSG00?o0000ooX5n_oj1OX04?oj1OX00ol0003ooP7nooh1oP04
ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0A
ool0o`03o`000?l00?oo003o02?o003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o
00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo0?loo`3o00;oo`3o003o`000?og2?Oom`Sg
00Kom`Sg00?o0000onHIi_oV6NH03OoV6NH00ol0003oXebSoj=LX`0Coj=LX`03o`000?mA[U7o0000
013o7N8M3_l00006o`gb3@;o00003?l;m0/00ol0003o3O8=o`gb3@09o`gb3@03o`000?l[e2_o:m@[
00[o:m@[00?o0000omLXeooG:=L03ooG:=L00ol0003onPGjooX5nP0>ooX5nP;o00002?on0Oh2o`00
0003ooh1o_l0003oo`3o017oo`3o0ol0000Bool0o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00
o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003o
o0?loo`3o00<oo`3o003o`000?og2?Oom`Sg00Kom`Sg00?o0000onHIi_oV6NH02ooV6NH00ol0003o
XebSoj=LX`0Doj=LX`?o00003olMhQd00ol0003o4NhAoa7^4@0<oa7^4@04o`000?l=lPgo3O8=o`gb
3@;o00003ol;m0/00ol0003o3O8=o`gb3@09o`gb3@03o`000?l[e2_o:m@[00Wo:m@[00?o0000omLX
eooG:=L04?oG:=L00ol0003onPGjooX5nP0<ooX5nP03o`000?on0OkooP7n00[ooP7n00?o0000ool0
oooo0?l03?oo0?l5o`0000;oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0To`00
oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00go
o`3o00?o0000oo`3o?ol0o`03Ool0o`00ol0003om`SgooL8m`05ooL8m`03o`000?oV6NKoiQWV00_o
iQWV00?o0000oj=LXonSG:<04onSG:<01Ol0003o<l`coc?<<olcc3?o000000go7N8M00?o0000oa7^
4OlAkQ403_lAkQ400ol0003o3O8=o`00000Ao`_d2`03o`000?l=lPgo3O8=00Wo3O8=00?o0000ob_D
:ol[e2/02Ol[e2/00ol0003oebSGomLXe`0@omLXe`03o`000?oj1O[onPGj00_onPGj00?o0000ooh1
o_on0Oh02oon0Oh00ol0003oo`3oool0o`07ool0o`Go00002?oo0?l00ol0003oo`3oool0o`0?ool0
o`03o`000?l00?oo003o02Co003o7_nBKI8Ro`00o`7ooooo000To`00o`03o`000?oo0?ooo`3o00ko
o`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo0?loo`3o00=oo`3o003o`000?og2?Oom`Sg00Go
m`Sg4Ol0000Boj=LX`03o`000?lcc3?o<l`c00?o<l`c00?o0000oagR7OlMhQd02OlMhQd00ol0003o
4NhAoa7^4@0@oa7^4@03o`000?l;m0_o2o@;017o2o@;00?o0000o`gb3Ol=lPd02Ol=lPd00ol0003o
:m@[ob_D:`07ob_D:`03o`000?oG:=OoebSG017oebSG00?o0000ooX5n_oj1OX02_oj1OX00ol0003o
oP7nooh1oP0=ooh1oP04o`000?oo0?ooo`3oool0o`Go00003_oo0?l3o`0000goo`3o00?o0000o`00
ool00?l09Ol00?lNoi9]TR;o003o0Oooool002Co003o00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0>ool0o`03o`000?ol0ocoo0?l00goo0?l00?o0000ooL8moog2?L00oog2?L00ol0003o
iQWVonHIiP0<onHIiP03o`000?n;M8_oRgB;00?o00003_nSG:<00ol0003o<l`coc?<<`05oc?<<`03
o`000?lMhQgo7N8M00Oo7N8M00?o0000oa7^4OlAkQ404OlAkQ400ol0003o2o@;o`_d2`0Ao`_d2`03
o`000?l=lPgo3O8=00Wo3O8=00?o0000ob_D:ol[e2/01_l[e2/2o`0001CoebSG00?o0000ooX5n_oj
1OX01ooj1OX2o`00017ooP7n0ol0000Cool0o`03o`000?oo0?ooo`3o00?o00002_oo0?l00ol0003o
003oo`00o`0Uo`00oakoTVfB8_l00?l1ooooo`009?l00?l00ol0003oo`3oool0o`0>ool0o`03o`00
0?oo0?ooo`3o00koo`3o00?o0000oo`3o?ol0o`03Ool0o`4o`000003ooL8mol0003oiQWV00koiQWV
00?o0000oh]dRon;M8/00on;M8/3o`0000[oXebS00?o0000oc?<<olcc3<01olcc3<00ol0003o7N8M
oagR7@05oagR7@03o`000?lAkQ7o4NhA01;o4NhA00?o0000o`_d2ol;m0/04Ol;m0/00ol0003o3O8=
o`gb3@0:o`gb3@03o`000?l[e2_o:m@[00;o:m@[0ol00002ob[E:P03o`000?oG:=OoebSG017oebSG
00?o0000ooX5n_oj1OX01_oj1OX00ol0003ooP7nooh1oP0Aooh1oP03o`000?oo0?ooo`3o01;oo`3o
00?o0000ool0oooo0?l01?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l09Ol00?lNohebSB;o003o
0Oooool002Co003o00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?ol
0ocoo0?l00[oo0?l0ol00004oo/4n`03o`000?oV6NKoiQWV00koiQWV00?o0000oh]dRon;M8/01_n;
M8/3o`0000KoXebS00?o0000oc?<<olcc3<02Olcc3<00ol0003o7N8MoagR7@03oagR7@03o`000?lA
kQ7o4NhA01?o4NhA00?o0000o`_d2ol;m0/04_l;m0/00ol0003o3O8=o`gb3@09o`gb3@03o`000?l[
e2_o000000;o00001_lZeBX00ol0003oebSGomLXe`0@omLXe`03o`000?oj1O[onPGj00GonPGj00?o
0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00Ooo`3o0ol0
0004ool0o`03o`000?l00?oo003o02Go003o7_n=LXdRo`00o`7ooooo000Uo`00o`03o`000?oo0?oo
o`3o00coo`3o00?o0000ool0oooo0?l03ooo0?l3o`0000Ooo0?l0ol00007oo/4n`03o`000?oV6NKo
iQWV00goiQWV00?o0000oh]dRon;M8/02_n;M8/3o`0000;oXebS00?o0000oc?<<olcc3<02olcc3<0
1Ol0003o7N8MoagR7OlMhQgo000001Ko4NhA00?o0000o`_d2ol;m0/04_l;m0/00ol0003o3O8=o`gb
3@0:o`gb3@03o`000?lZeB[o:]DZ00So:]DZ00?o0000omLXeooG:=L04?oG:=L00ol0003onPGjooX5
nP02ooX5nP?o00005Oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00_oo`3o1?l0
000Xo`00oakoSG:=8_l00?l1ooooo`009_l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?oo
o`3o00koo`3o00Co0000ooh1o_on0OkooP7n0ol000001?ol0oco0000o`000?l0000:oo/4n`03o`00
0?oV6NKoiQWV00goiQWV00?o0000oh]dRon;M8/03On;M8/2o`0000oo<l`c00?o0000oagR7Ol00000
5olAkQ400ol0003o2o@;o`_d2`0Co`_d2`03o`000?l=lPgo3O8=00Wo3O8=00?o0000ob[E:_lZeBX0
2OlZeBX00ol0003oebSGomLXe`0?omLXe`03o`000?oj1O[onPGj00;o00000ooj1OX2o`0001?ooP7n
00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o02Ko003o
7_n=LXdRo`00o`7ooooo000Wo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV
6NH00ol0003oRgB;oh]dR`0>oh]dR`03o`000?lcc3?o<l`c00ko<l`c00?o0000oa7^4OlAkQ405_lA
kQ400ol0003o2o@;o`_d2`0Co`_d2`03o`000?l=lPgo3O8=00So3O8=00?o0000ob[E:_lZeBX02olZ
eBX5o`0000coebSG00?o0000ooX5n_l000001ooj1OX2o`00017ooP7n00?o0000ool0oooo0?l03ooo
0?l00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o02Ko003o7_n=LXdRo`00o`7ooooo000X
o`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03Ooo0?l00ol0003ooP7nooh1oP06
ooh1oP03o`000?ok1?_on`Ck00_on`Ck00?o0000onHIi_oV6NH03OoV6NH00ol0003oRgB;oh]dR`0>
oh]dR`03o`000?lcc3?o<l`c00ko<l`c00?o0000oa7^4OlAkQ405_lAkQ400ol0003o2o@;o`_d2`0C
o`_d2`03o`000?l=lPgo3O8=00Oo3O8=00?o0000ob[E:_lZeBX03?lZeBX00ol0003oeB[EomDZe@02
omDZe@Wo00001?oG:=L00ol0003onPGjooX5nP08ooX5nP;o00003oon0Oh00ol0003oo`3oool0o`0?
ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09_l00?lNohebSB;o003o0Oooool0
02Wo003o00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n
00SooP7n00?o0000oo/4nook1?/02ook1?/00ol0003oiQWVonHIiP0<onHIiP03o`000?n;M8_oRgB;
00koRgB;00?o0000oc?<<olcc3<03olcc3<00ol0003o4NhAoa7^4@0Eoa7^4@03o`000?l;m0_o2o@;
01?o2o@;1?l00005o`gb3@03o`000?lZeB[o:]DZ00go:]DZ00?o0000omDZeOoE:]D02ooE:]D4o`00
00gonPGj0_l0000>ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l03ooo0?l00ol0
003o003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:Ol00?l00ol0003oo`3oool0o`07ool0o`03
o`000?oo0?ooo`3o00_oo`3o00?o0000ooh1o_on0Oh02Oon0Oh00ol0003on`Ckoo/4n`0;oo/4n`03
o`000?oV6NKoiQWV00_oiQWV00?o0000oh]dRon;M8/03on;M8/00ol0003o<l`coc?<<`0?oc?<<`03
o`000?lAkQ7o4NhA01Go4NhA00?o0000o`_d2ol;m0/04?l;m0/3o`0000Co4NhA0ol000000ol=lPgo
0000ob[E:P0>ob[E:P03o`000?oE:]GoeB[E00ooeB[E00?o0000ooX5n_oj1OX03Ooj1OX2o`0000_o
oP7n0ol0000>ool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l09ol00?lNohMhQb;o
003o0Oooool002[o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`00
0?on0OkooP7n00_ooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003oiQWVonHIiP0;onHIiP03o`00
0?n;M8_oRgB;00ooRgB;00?o0000oc?<<olcc3<03olcc3<2o`0001Co4NhA0ol0000@o`_d2`;o0000
2_lAkQ400ol0003o:]DZob[E:P0>ob[E:P03o`000?oE:]GoeB[E013oeB[E0_l0000?ooX5nP;o0000
2?on0Oh01?l0003oo`3oool0oooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o
003oo`00o`0Wo`00oakoQgR78_l00?l1ooooo`00:ol00?l00ol0003oo`3oool0o`03ool0o`oo0000
3_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?oV6NKoiQWV00_oiQWV4ol0000>oc?<<`?o0000
0_lNhAh00ol0003o4NhAoa7^4@0<oa7^4@Go00000_l@ka000ol0003o2o@;o`_d2`0<o`_d2`;o0000
3?lAkQ400ol0003o:]DZob[E:P0>ob[E:P03o`000?oE:]GoeB[E013oeB[E00?o0000ooD:mOl00000
4?oj1OX2o`0000CooP7n0_l00006ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l0
3ooo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;?l00?l00ol0003oo`3oo`00
0002o`0000koo`3o00?o0000ooh1o_on0Oh03Oon0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV
6NKoiQWV00_oiQWV00?o0000og:=L_mbSG803ombSG800ol0003o<l`coc?<<`09oc?<<`?o00001_lN
hAh00ol0003o4NhAoa7^4@06oa7^4@Go00002?l@ka000ol0003o2o@;o`_d2`08o`_d2`?o00003olA
kQ400ol0003o:]DZob[E:P0=ob[E:P03o`000?oE:]GoeB[E00ooeB[E00Go0000ooD:mOoe2_Gom@[e
o`00000AooX5nP;o000000?ooP7no`000?oo0?l02?oo0?l2o`0000Ooo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0
o`0@ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHI
iP0;onHIiP03o`000?mbSG;oLXeb00ooLXeb00?o0000oc?<<olcc3<01_lcc3<3o`0000[o7^4N00?o
0000oa7^4OlAkQ401Ol0000>oa3_4003o`000?l;m0_o2o@;00Go2o@;0_l0000Boa7^4@03o`000?lZ
eB[o:]DZ00co:]DZ00?o0000omDZeOoE:]D04?oE:]D00ol0003om@[eooD:m@02ooD:m@03o`000?oj
1O[onPGj013onPGj00?o0000ool0oooo0?l02_oo0?l2o`0000Goo`3o00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0Xo`00oakoQgR78_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0@
ool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4nook1?/02Ook1?/00ol0003oiQWVonHIiP0;
onHIiP03o`000?mbSG;oLXeb013oLXeb00?o0000oc?<<olcc3<00_lcc3<3o`0000go7^4N0ol0000C
oa3_4003o`000?l;m0_o2o@;00?o2o@;0_l0000Eoa7^4@03o`000?lZeB[o:]DZ00_o:]DZ00?o0000
omDZeOoE:]D03ooE:]D00ol0003om@[eooD:m@04ooD:m@03o`000?oj1O[onPGj00gonPGj0ol0000>
ool0o`03o`000?oo0?ooo`3o00?o00004Ooo0?l00ol0003o003oo`00o`0Yo`00oakoPWf28_l00?l1
ooooo`00;Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n00cooP7n00?o0000oo/4
nook1?/02Ook1?/00ol0003oiQWVonHIiP08onHIiPCo00004OmbSG800ol0003o<l`co`000002o`00
00oo7^4N00?o0000oagR7Ol000005Ol@ka000ol0003o2o@;o`000002o`0001Oo4NhA00?o0000ob[E
:_lZeBX02olZeBX00ol0003oeB[EomDZe@0>omDZe@03o`000?oe2_Gom@[e00Kom@[e00?o0000ooX5
n_oj1OX02Ooj1OX3o`0000;oo0?l00?o0000ool0oooo0?l03Ooo0?l2o`0000?oo`3o0_l0000?ool0
o`03o`000?l00?oo003o02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01;o
o`3o00?o0000ooh1o_on0Oh03?on0Oh00ol0003on`Ckoo/4n`09oo/4n`03o`000?oV6NKoiQWV00Go
iQWV0ol00004olPgb003o`000?mbSG;oLXeb00koLXeb0_l0000AoakQ7P04o`000?lMhQgo7N8Mo`00
01Ko4>l@00?o0000oa7^4OlAkQ406?lAkQ400ol0003o:]DZob[E:P0;ob[E:P03o`000?oE:]GoeB[E
00koeB[E00?o0000ooD:mOoe2_D01ooe2_D00ol0003onPGjooX5nP04ooX5nPCo00001Ool0o`00ol0
003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol0000<ool0o`03o`000?l00?oo003o
02Wo003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ooh1o_on
0Oh03?on0Oh00ol0003on`Ckoo/4n`08oo/4n`03o`000?oV6NKoiQWV00;oiQWV0ol00008olPgb003
o`000?mbSG;oLXeb00coLXeb0ol0000?oakQ7P;o00000olMhQd00ol0003o4>l@oa3_400Doa3_4003
o`000?lAkQ7o4NhA01Wo4NhA00?o0000ob[E:_lZeBX02_lZeBX00ol0003oeB[EomDZe@0=omDZe@03
o`000?oe2_Gom@[e00Wom@[e00?o0000ooX5n_oj1OX00ol00009oo`3o003o`000?oo0?ooo`3o00go
o`3o00?o0000ool0oooo0?l01ooo0?l2o`0000Woo`3o00?o0000o`00ool00?l0:_l00?lNoh9mPR;o
003o0Oooool002co003o00?o0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0;ooh1oP03o`00
0?ok1?_on`Ck00Oon`Ck1_l0000<olPgb003o`000?mbSG;oLXeb00[oLXeb00Go0000oeNXEomGZ5Oo
EjQGo`00000=oakQ7P03o`000?lMhQgo7N8M00Co7N8M00?o0000oa3_4?l@ka004ol@ka000ol0003o
4NhAoa7^4@0Ioa7^4@03o`000?lZeB[o:]DZ00Wo:]DZ00?o0000omDZeOoE:]D03_oE:]D00ol0003o
m@[eooD:m@0:ooD:m@;o00003?ol0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00[o
o`3o0_l00007ool0o`03o`000?l00?oo003o02[o003o7_n2OH8Ro`00o`7ooooo000/o`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Gon`Ck0_l00004ooP7n003o`00
0?o8=lSob3O800cob3O80_l00008og:=LP;o00001OmGZ5L00ol0003o7^4NoakQ7P09oakQ7P03o`00
0?lMhQgo7N8M00Go7N8M00?o0000oa3_4?l@ka004ol@ka000ol0003o4NhAoa7^4@0Joa7^4@go0000
3_oE:]D00ol0003om@[eooD:m@0;ooD:m@03o`000?ol0ocoo0?l00_oo0?l00?o0000ool0oooo0?l0
3?oo0?l00ol0003oo`3oool0o`0<ool0o`?o00001?oo0?l00ol0003o003oo`00o`0Zo`00oakoPWf2
8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0OkooP7n00OooP7n0ol0
0003ooh1oP?o000000?on`Cko`000?oh1oP01_oh1oP00ol0003ob3O8olPgb00=olPgb003o`000?mb
SG;oLXeb00CoLXeb00?o0000oeNXEomGZ5L01_mGZ5L2o`0000So7^4N00?o0000oagR7OlMhQd01_lM
hQd00ol0003o4>l@oa3_400Doa3_4003o`000?lAkQ7o4NhA01Wo4NhA00?o0000oejQG_mNXEh02_mN
XEh00ol0003oeB[EomDZe@0;omDZe@03o`000?oe2_Gom@[e00com@[e00?o0000oo`3o?ol0o`02_ol
0o`00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00ooo`3o0_l000000ooo0?oo0000o`00
o`0/o`00oakoOH9m8_l00?l1ooooo`00;Ol00?l00ol0003oo`3oool0o`0Dool0o`03o`000?on0Oko
oP7n00GooP7n0_l00009ooh1oP03o`000?oh1oSon0Oh00Kon0Oh00?o0000olPgb?o8=lP03_o8=lP0
1?l0003oLXebog:=L_mbSG82o`0000_oEjQG00?o0000oakQ7_lNhAh00olNhAh2o`0000Wo7N8M00?o
0000oa3_4?l@ka005?l@ka000ol0003o4NhAoa7^4@0Hoa7^4@03o`000?mNXEkoGZ5N00coGZ5N00?o
0000omDZeOoE:]D02OoE:]D00ol0003om@[eooD:m@0=ooD:m@03o`000?ol0ocoo0?l00[oo0?l00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o02co003o7_mm
PWdRo`00o`7ooooo000]o`00o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ooh1o_on0Oh00_on0Oh2
o`0000_ooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ob3O8olPgb00>olPgb003o`000?mbSG;o
000000koEjQG00Go0000oakQ7_lNhAko7^4No`00000;oagR7@03o`000?l@ka3o4>l@01Co4>l@0_l0
000Ioa7^4@03o`000?mNXEkoGZ5N00goGZ5N0_l00008omDZe@03o`000?oe2_Gom@[e00kom@[e00?o
0000oo`3o?ol0o`02_ol0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0;?l00?lNogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05?oo0?l0
0ol0003ooP7no`000002o`0000gooP7n00?o0000ooP7n?oh1oP01ooh1oP00ol0003ob3O8olPgb00?
olPgb003o`000?mGZ5OoEjQG00koEjQG00?o0000oakQ7_l000003?lMhQd00ol0003o4>l@oa3_400D
oa3_4003o`000?lCk1?o000000;o00005OlAkQ400ol0003oGZ5NoejQGP0@oejQGP03o`000?oE:]Go
eB[E00GoeB[E00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o009oo`3o003o`000?oo0?oo
o`3o00_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0]o`00oakoOH9m8_l00?l1
ooooo`00;_l00?l00ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00kooP7n00?o0000ooP7
n?oh1oP02?oh1oP00ol0003ob3O8olPgb00>olPgb003o`000?mGZ5OoEjQG00koEjQG0_l0000=oagR
7@03o`000?l@ka3o4>l@01?o4>l@00?o0000oa?/4olCk1<00olCk1<2o`0001;o4NhA00?o0000oejQ
G_mNXEh04_mNXEh01?l0003oeB[EomDZeOoE:]D3o`0001;om@[e00?o0000oo`3o?ol0o`02Ool0o`0
0ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;Ol00?lN
ogf2OB;o003o0Oooool002ko003o00?o0000ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP0>ooh1
oP03o`000?oh1oSon0Oh00Son0Oh00?o0000olPgb?o8=lP03Oo8=lP2o`0000ooEjQG00?o0000oe2_
D?l000003_lMhQd00ol0003o4>l@oa3_400Boa3_4003o`000?lCk1?o4n`C00Go4n`C0ol0000?oa7^
4@03o`000?mNXEkoGZ5N01?oGZ5N0ol00002ondBk@03o`000?oe2_Gom@[e013om@[e00?o0000oo`3
o?ol0o`02Ool0o`00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00
ool00?l0;Ol00?lNogf2OB;o003o0Oooool002oo003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Won0Oh00?o0000olPgb?o8=lP02oo8=lP00ol0003o
b3O8o`00000>oeNXE`05o`000?m@[e3oD:m@oe2_D?l000003OlMhQd00ol0003o4>l@oa3_400Aoa3_
4003o`000?lCk1?o4n`C00Wo4n`C0ol0000:oa7^4@;o00005_mNXEh00ol0003okA;]ondBk@03ondB
k@03o`000?oe2_Gom@[e013om@[e00?o0000oo`3o?ol0o`02?ol0o`00ol0003oo`3oool0o`0:ool0
o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;_l00?lNogR7N2;o003o0Oooool002oo
003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0?ooh1oP03o`000?oh1oSon0Oh00Wo
n0Oh00?o0000olPgb?o8=lP02_o8=lP01Ol0003ob3O8olPgb?o8=lSo000000coEjQG00?o0000oe2_
D?m@[e000_m@[e000ol0003o7N8MoagR7@0;oagR7@03o`000?l@ka3o4>l@017o4>l@00?o0000oa?/
4olCk1<03?lCk1<2o`0000Ko4NhA0_l000000olcc3?o0000oejQGP0DoejQGP03o`000?o]4^gokA;]
00GokA;]00?o0000ooD:mOoe2_D03ooe2_D00ol0003oo0?loo`3o008oo`3o003o`000?oo0?ooo`3o
00[oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0^o`00oakoN8Mh8_l00?l1oooo
o`00;ol00?l00ol0003oo`3oool0o`0Cool0o`03o`000?on0OkooP7n00oooP7n00?o0000ooP7n?oh
1oP02_oh1oP00ol0003ob3O8olPgb007olPgb0;o00001Oo8=lP00ol0003oEjQGoeNXE`08oeNXE`03
o`000?m@[e3oD:m@00CoD:m@00?o0000oagR7OlMhQd02OlMhQd4o`00013o4>l@00?o0000oa?/4olC
k1<03olCk1<3o`000003oa7^4Ol0003o000000Co<l`c00?o0000oejQG_mNXEh04OmNXEh00ol0003o
kA;]ondBk@07ondBk@03o`000?oe2_Gom@[e00oom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003o
o`3oool0o`0:ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o
003o0Oooool0033o003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`00
0?oh1oSon0Oh00[on0Oh00?o0000olPgb?o8=lP01_o8=lP00ol0003ob3O8olPgb005olPgb003o`00
0?mGZ5OoEjQG00OoEjQG00?o0000oe2_D?m@[e001Om@[e000ol0003o7N8MoagR7@08oagR7@03o`00
0?lNhAko7^4N00;o7^4N0ol0000=oa3_4003o`000?lCk1?o4n`C01;o4n`C00?o0000oc?<<olcc3<0
1Olcc3<00ol0003oGZ5NoejQGP0@oejQGP03o`000?o]4^gokA;]00OokA;]00?o0000ooD:mOoe2_D0
3ooe2_D00ol0003oo0?loo`3o007oo`3o003o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l0
4?oo0?l00ol0003o003oo`00o`0_o`00oakoN8Mh8_l00?l1ooooo`00<?l00?l00ol0003oo`3oool0
o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooP7n?oh1oP02ooh1oP00ol0003ob3O8olPg
b004olPgb003o`000?o8=lSob3O800Oob3O800?o0000oeNXEomGZ5L01OmGZ5L00ol0003oD:m@oe2_
D007oe2_D003o`000?lMhQgo7N8M00Ko7N8M00?o0000oakQ7_lNhAh01_lNhAh3o`0000So4>l@0_l0
000Eoa?/4`03o`000?lcc3?o<l`c00Ko<l`c00?o0000oejQG_mNXEh03_mNXEh00ol0003okA;]ondB
k@09ondBk@03o`000?oe2_Gom@[e00kom@[e00?o0000oo`3o?ol0o`01ool0o`00ol0003oo`3oool0
o`09ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0;ol00?lNogR7N2;o003o0Ooo
ool0033o003o00?o0000ool0oooo0?l04?oo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`000?oh1oSo
n0Oh00_on0Oh00?o0000olPgb?o8=lP00_o8=lP2o`0000[ob3O800?o0000oeNXEomGZ5L01?mGZ5L0
0ol0003oD:m@oe2_D009oe2_D003o`000?lMhQgo7N8M00?o7N8M0_l0000<oakQ7P?o00000_l@ka03
o`000003oaSW6?l0003o4n`C01Co4n`C00?o0000oc?<<olcc3<01olcc3<00ol0003oGZ5NoejQGP0<
oejQGP03o`000?o]4^gokA;]00_okA;]00?o0000ooD:mOoe2_D03_oe2_D00ol0003oo0?loo`3o006
oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`0`
o`00oakoN8Mh8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0?ool0o`03o`000?on0OkooP7n
017ooP7n00?o0000ooP7n?oh1oP03?oh1oP01?l0003ob3O8olPgb?l0000=olPgb003o`000?mGZ5Oo
EjQG00;oEjQG00?o0000oe2_D?m@[e002_m@[e000ol0003o7N8MoagR7@02oagR7@03o`000?lNhAko
7^4N00oo7^4N0_l00005oaSW6003o`000?lCk1?o4n`C01;o4n`C00?o0000oc?<<olcc3<02?lcc3<0
0ol0003oGZ5NoejQGP0:oejQGP03o`000?o]4^gokA;]00gokA;]1Ol0000;ooD:m@03o`000?ol0oco
o0?l00Koo0?l00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo
003o033o003o7_mbSG8Ro`00o`7ooooo000ao`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1
o_on0Oh04Oon0Oh00ol0003on0OhooP7n00<ooP7n003o`000?o8=lSo000000oob3O800Co0000oeNX
EomGZ5Oo00003_m@[e001?l0003o7N8MoagR7Ol0000CoakQ7P03o`000?lHiaSo6>LH00Co6>LH00?o
0000oa?/4olCk1<04?lCk1<00ol0003o<l`coc?<<`09oc?<<`03o`000?mNXEkoGZ5N00[oGZ5N00?o
0000ondBkOo]4^d03Oo]4^d00ol0003onPGjooX5nP02ooX5nPWo00000_oe2_D00ol0003oo0?loo`3
o006oo`3o003o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ao`00oakoLXeb8_l00?l1ooooo`00<Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0Oko
oP7n013ooP7n1?l0000>ooP7n003o`000?o8=lSob3O800kob3O800?o0000oeNXEol000003om@[e00
0ol0003o7N8Mo`00000CoakQ7P03o`000?lHiaSo6>LH00Go6>LH00?o0000oa?/4olCk1<04?lCk1<0
0ol0003o<l`coc?<<`0:oc?<<`03o`000?mNXEkoGZ5N00SoGZ5N00?o0000ondBkOo]4^d03Oo]4^d0
0ol0003onPGjooX5nP0<ooX5nPCo00000ool0o`7o`0000Soo`3o00?o0000ool0oooo0?l04?oo0?l0
0ol0003o003oo`00o`0ao`00oakoLXeb8_l00?l1ooooo`00<_l00?l00ol0003oo`3oool0o`0=ool0
o`03o`000?on0OkooP7n00gooP7n0ol00004ood2o@03o`000?oh1oSon0Oh00_on0Oh00?o0000olPg
b?o8=lP03oo8=lP00ol0003oD:m@oe2_D00>oe2_D0;o00005?lNhAh00ol0003o6>LHoaSW6006oaSW
6003o`000?lCk1?o4n`C00oo4n`C00?o0000oc?<<olcc3<02olcc3<00ol0003oGZ5NoejQGP04oejQ
GP?o00004?o]4^d00ol0003onPGjooX5nP0?ooX5nPCo00001oon0Oh3o`0000?oo`3o1?l0000Aool0
o`03o`000?l00?oo003o037o003o7_mbSG8Ro`00o`7ooooo000co`00o`03o`000?oo0?ooo`3o00_o
o`3o00?o0000ooh1o_on0Oh02oon0Oh3o`0000Soo@;m00?o0000ooP7n?oh1oP02Ooh1oP00ol0003o
b3O8olPgb00@olPgb003o`000?m@[e3oD:m@00_oD:m@0ol000000om=/Tgo0000oakQ7P0BoakQ7P03
o`000?lHiaSo6>LH00Oo6>LH00?o0000oa?/4olCk1<03olCk1<00ol0003o<l`coc?<<`0<oc?<<`03
o`000?mNXEkoGZ5N00?o00000ooJ9MX00ol0003okA;]ondBk@0=ondBk@03o`000?oj1O[onPGj00oo
nPGj00?o0000ooh1o_on0Oh02oon0Oh3o`0000Coo`3o0_l0000=ool0o`;o0000=?l00?lNog:=LR;o
003o0Oooool003Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP08ooh1oP?o0000
3?om0_d2o`0000Won0Oh00?o0000olPgb?o8=lP04?o8=lP3o`0000WoD:m@0_l00005odfbC@03o`00
0?lNhAko7^4N013o7^4N00?o0000oaSW6?lHiaP02?lHiaP00ol0003o4n`Coa?/4`0>oa?/4`03o`00
0?lcc3?o<l`c00go<l`c0_l00007omXUfP03o`000?o]4^gokA;]00_okA;]00?o0000ooX5n_oj1OX0
3ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo0?ooo`3o00Koo`3o0ol00008ool0o`;o0000
=_l00?lNog:=LR;o003o0Oooool003Go003o00?o0000ool0oooo0?l02Ooo0?l00ol0003ooP7nooh1
oP05ooh1oP?o00004Oom0_d00ol0003on0OhooP7n006ooP7n003o`000?o8=lSob3O800oob3O800Co
0000oka3_?nl@kco_4>l0_l00005oe2_D0;o00002?m=/Td00ol0003o7^4NoakQ7P0>oakQ7P03o`00
0?lHiaSo6>LH00[o6>LH00?o0000oa?/4olCk1<03?lCk1<00ol0003o<l`coc?<<`0>oc?<<`03o`00
0?oJ9M[ofRGJ00OofRGJ00?o0000ondBkOo]4^d02_o]4^d00ol0003onPGjooX5nP0?ooX5nP03o`00
0?on0OkooP7n00cooP7n00?o0000ool0oooo0?l02Ooo0?l2o`0000Goo`3o00?o0000o`00ool00?l0
=_l00?lNoffBKB;o003o0Oooool003Ko003o00?o0000ool0oooo0?l01_oo0?l4o`0000?ooP7n0ol0
000Eood2o@03o`000?oh1oSon0Oh00Con0Oh4ol00006oka3_003o`000?m@[e3o000000;o00002_m=
/Td00ol0003o7^4NoakQ7P0=oakQ7P03o`000?lHiaSo6>LH00_o6>LH00?o0000oa?/4olCk1<03?lC
k1<00ol0003o<l`coc?<<`0=oc?<<`03o`000?oJ9M[ofRGJ00WofRGJ00?o0000ondBkOo]4^d02?o]
4^d00ol0003onPGjooX5nP0?ooX5nP03o`000?on0OkooP7n00gooP7n00?o0000ool0oooo0?l02ooo
0?l2o`000003ool0ool0003o000003Wo003o7_m]TVdRo`00o`7ooooo000go`00o`03o`000?oo0?oo
o`3o00;oo`3o0ol00004ool0o`?o00006Oom0_d00ol0003on0OhooP7n003ooP7n003o`000?o_4>oo
ka3_00ooka3_00?o0000oka3_?nl@k`01Onl@k`00ol0003oCK9=odfbC@0<odfbC@03o`000?lNhAko
7^4N00co7^4N00?o0000oaSW6?lHiaP03?lHiaP2o`0000co4n`C00?o0000oc?<<olcc3<03Olcc3<0
0ol0003ofRGJomXUfP0:omXUfP03o`000?o]4^gokA;]00OokA;]00?o0000ooX5n_oj1OX03ooj1OX0
0ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00goo`3o00?o0000o`00ool00?l0>Ol00?lN
offBKB;o003o0Oooool003So003o00Co0000ool0ool0003o00002_oo0?l00ol0003oo@;mood2o@0F
ood2o@Co000000?on0Oho`000?o_4>l04?o_4>l00ol0003o_4>loka3_006oka3_003o`000?m=/Tgo
CK9=00coCK9=00?o0000oakQ7_lNhAh02olNhAh00ol0003o6>LHoaSW600=oaSW6004o`000?lUfRGo
0000o`0000[o4n`C00?o0000oc?<<olcc3<03Olcc3<00ol0003ofRGJomXUfP0;omXUfP03o`000?o]
4^gokA;]00KokA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l02ooo0?l00ol0003oo@;mood2o@0Cood2o@;o00001?om0_d00ol0003oka3_onl@k`0@
onl@k`03o`000?nl@kco_4>l00Ko_4>l00?o0000odfbCOm=/Td03Om=/Td00ol0003o7^4NoakQ7P0:
oakQ7P03o`000?lHiaSo6>LH00co6>LH00?o0000obGJ9OlUfRD00_lUfRD2o`0000So4n`C00?o0000
oc?<<olcc3<03?lcc3<00ol0003ofRGJomXUfP0=omXUfP03o`000?o]4^gokA;]00CokA;]00?o0000
ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000
o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l03?oo0?l00ol0
003oo@;mood2o@0Aood2o@03o`000?om0_goo@;m00Coo@;m0_l0000@onl@k`03o`000?nl@kco_4>l
00Oo_4>l00?o0000odfbCOm=/Td03_m=/Td<o`0000oo6>LH00?o0000obGJ9OlUfRD01?lUfRD2o`00
00Ko4n`C00?o0000oc?<<olcc3<03?lcc3<00ol0003ofRGJomXUfP0>omXUfP03o`000?o]4^gokA;]
00?okA;]00?o0000ooX5n_oj1OX03ooj1OX00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o
00koo`3o00?o0000o`00ool00?l0>Ol00?lNoffBKB;o003o0Oooool003Wo003o00?o0000ool0oooo
0?l03Ooo0?l00ol0003oo@;mood2o@0>ood2o@;o00001oom0_d01?l0003om`Sgo`000?l0000>onl@
k`03o`000?nl@kco_4>l00So_4>l00?o0000odfbCOm=/Td03Om=/Td00ol0003o</dboc;=<P08oc;=
<P03o`000?lHiaSo6>LH00co6>LH00?o0000obGJ9OlUfRD01olUfRD2o`0000?o4n`C00?o0000oc?<
<olcc3<03Olcc3<00ol0003ofRGJomXUfP0?omXUfP05o`000?o]4^gokA;]ondBkOl000004Ooj1OX0
0ol0003ooP7nooh1oP0>ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>?l00?lN
ofRGJ2;o003o0Oooool003So003o00?o0000ool0oooo0?l03ooo0?l2o`0000coo@;m0_l00009ood2
o@05o`000?og2?Oom`SgooL8mol000003Oo_4>l00ol0003o_4>loka3_008oka3_003o`000?m=/Tgo
CK9=00coCK9=00?o0000oc;=<_lbcC802_lbcC800ol0003o6>LHoaSW600;oaSW6003o`000?lUfRGo
9MXU00Wo9MXU0_l000000olCk1?o0000oc?<<`08oc?<<`Ko00004ooJ9MX01?l0003okA;]ondBkOl0
000AooX5nP03o`000?on0OkooP7n00kooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00
o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?om0_go
o@;m00Ooo@;m0_l0000:ood2o@03o`000?og2?Oom`Sg00?om`Sg1?l00008onl@k`03o`000?nl@kco
_4>l00Wo_4>l00?o0000odfbCOm=/Td03?m=/Td00ol0003o</dboc;=<P0:oc;=<P03o`000?lHiaSo
6>LH00[o6>LH00?o0000obGJ9OlUfRD03?lUfRD;o`0000Go/4n`00?o0000omXUf_oJ9MX04_oJ9MX0
0ol0003okA;]o`00000@ooX5nP03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l0
0ol0003o003oo`00o`0ho`00oakoJ9MX8_l00?l1ooooo`00>?l00?l00ol0003oo`3oool0o`0Bool0
o`03o`000?om0_goo@;m00Coo@;m0_l0000<ood2o@03o`000?og2?Oom`Sg00?om`Sg00Co0000on<L
hooS7>?ohacS1Ol00003onl@k`03o`000?nl@kco_4>l00Wo_4>l00?o0000odfbCOm=/Td02om=/Td0
0ol0003o</dboc;=<P0<oc;=<P03o`000?lHiaSo6>LH00Wo6>LH00?o0000obGJ9OlUfRD03?lUfRD0
0ol0003oB[E:odZeBP02odZeBP03o`000?n`Ck3o/4n`00Wo/4n`00?o0000omXUf_oJ9MX04_oJ9MX3
o`0000oonPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo
003o03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Coo`3o00?o0000ood2
oOom0_d00_om0_d00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Com`Sg00?o0000on<L
hooS7><01OoS7><3o`0000co_4>l00?o0000odfbCOm=/Td02om=/Td00ol0003o</dboc;=<P0<oc;=
<P03o`000?lHiaSo6>LH00So6>LH00?o0000obGJ9OlUfRD03?lUfRD00ol0003oB[E:odZeBP04odZe
BP03o`000?n`Ck3o/4n`00So/4n`00?o0000omXUf_oJ9MX04_oJ9MX00ol0003oo0?loo`3o004o`00
00_onPGj00?o0000ooh1o_on0Oh03oon0Oh00ol0003oo`3oool0o`0?ool0o`03o`000?l00?oo003o
03So003o7_mXUfPRo`00o`7ooooo000go`00o`03o`000?oo0?ooo`3o01Goo`3o00Co0000ood2oOl0
003o00003_om0_d00ol0003om`SgooL8m`05ooL8m`03o`000?oS7>?ohacS00OohacS00?o0000oka3
_?nl@k`02_nl@k`00ol0003oCK9=odfbC@09odfbC@;o00003olbcC800ol0003o6>LHoaSW6008oaSW
6003o`000?lUfRGo9MXU00co9MXU00?o0000odZeB_m:]DX01?m:]DX00ol0003o/4n`ok1?/009ok1?
/0Co00003ooJ9MX00ol0003oo0?loo`3o005oo`3o0Co00001_oj1OX00ol0003ooP7nooh1oP0?ooh1
oP03o`000?oo0?ooo`3o013oo`3o00?o0000o`00ool00?l0>?l00?lNofRGJ2;o003o0Oooool003Oo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Go
m`Sg00?o0000on<LhooS7><02?oS7><00ol0003o_4>loka3_009oka3_003o`000?m=/TgoCK9=00Ko
CK9=0ol000000omnPGko0000oc;=<P0?oc;=<P03o`000?lHiaSo6>LH00Ko6>LH00?o0000obGJ9OlU
fRD03OlUfRD00ol0003oB[E:odZeBP05odZeBP03o`000?n`Ck3o/4n`00So/4n`00Co0000oo<<looc
3??ol`cc1Ol00009omXUfP03o`000?ol0ocoo0?l00[oo0?l1?l00002ooX5nP03o`000?on0OkooP7n
00oooP7n00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`0go`00oakoHiaS8_l00?l1oooo
o`00=_l00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00koo@;m00?o0000ooL8moog
2?L01_og2?L00ol0003ohacSon<Lh`07on<Lh`03o`000?nl@kco_4>l00[o_4>l00?o0000odfbCOm=
/Td00_m=/Td3o`0000GoOX5n00?o0000oc;=<_lbcC803OlbcC800ol0003o6>LHoaSW6006oaSW6003
o`000?lUfRGo9MXU00co9MXU00?o0000odZeB_m:]DX01_m:]DX00ol0003o/4n`ok1?/008ok1?/003
o`000?oc3??ol`cc00Kol`cc1Ol00003omXUfP03o`000?ol0ocoo0?l00ooo0?l0_l0000Booh1oP03
o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o
00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@0>ood2o@03o`000?og2?Oom`Sg00Kom`Sg
00?o0000on<LhooS7><01ooS7><00ol0003o_4>loka3_00:oka3_003o`000?m=/Tgo000000;o0000
2?mnPGh00ol0003o</dboc;=<P0=oc;=<PCo00001?lHiaP00ol0003o9MXUobGJ9@0=obGJ9@03o`00
0?m:]D[oB[E:00OoB[E:00?o0000ok1?/?n`Ck001on`Ck000ol0003ol`ccoo<<l`0;oo<<l`?o0000
4ool0o`00ol0003ooP7nooh1oP0@ooh1oP03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0
=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000ool0oooo0?l06?oo0?l00ol0003oo@;mood2
o@0<ood2o@03o`000?og2?Oom`Sg00Oom`Sg00?o0000on<LhooS7><02?oS7><3o`0000Wo_4>l0_l0
000<ogj1OP03o`000?lbcC;o</db00_o</db00?o0000ofBKI?mTVf@00_mTVf@3o`000003oaSW6?l0
003o9MXU00ko9MXU00?o0000odZeB_m:]DX01om:]DX00ol0003o/4n`ok1?/006ok1?/003o`000?oc
3??ol`cc00kol`cc00?o0000oo`3o?ol0o`04_ol0o`00ol0003ooP7nooh1oP0?ooh1oP03o`000?oo
0?ooo`3o017oo`3o00?o0000o`00ool00?l0=ol00?lNof>LHb;o003o0Oooool003Ko003o00?o0000
ool0oooo0?l06?oo0?l00ol0003oo@;mood2o@0<ood2o@03o`000?og2?Oom`Sg00Som`Sg00?o0000
on<LhooS7><01_oS7><01?l0003oiQWVonHIi_oV6NH3o`0000Ko_4>l00?o0000ogj1O_mnPGh03?mn
PGh00ol0003o</dboc;=<P09oc;=<P03o`000?mTVfCoI9]T00KoI9]T00?o0000obGJ9OlUfRD03OlU
fRD00ol0003oB[E:odZeBP09odZeBP03o`000?n`Ck3o/4n`00Go/4n`00?o0000oo<<looc3?<03_oc
3?<00ol0003oo0?loo`3o00Boo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l04?oo
0?l00ol0003o003oo`00o`0ho`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0G
ool0o`03o`000?om0_goo@;m00coo@;m00?o0000ooL8moog2?L02?og2?L00ol0003ohacSon<Lh`05
on<Lh`03o`000?oV6NKoiQWV00GoiQWV0ol00002oka3_003o`000?mnPGkoOX5n00goOX5n00?o0000
oc;=<_lbcC802?lbcC800ol0003oI9]TofBKI007ofBKI003o`000?lUfRGo9MXU00co9MXU0ol0000:
odZeBP03o`000?n`Ck3o/4n`00Go/4n`00?o0000oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00B
oo`3o003o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0i
o`00oakoHiaS8_l00?l1ooooo`00=ol00?l00ol0003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m
00_oo@;m00?o0000ooL8moog2?L02Oog2?L00ol0003ohacSon<Lh`04on<Lh`03o`000?oV6NKoiQWV
00WoiQWV0_l0000Aogj1OP03o`000?lbcC;o</db00Go</db0_l0000;ofBKI003o`000?lUfRGo9MXU
00[o9MXU00Go0000ohIiQ_n6NHKoQWV6o`00000:odZeBP03o`000?n`Ck3o/4n`00Co/4n`00?o0000
oo<<looc3?<03_oc3?<00ol0003oo0?loo`3o00Coo`3o003o`000?on0OkooP7n00gooP7n00?o0000
ool0oooo0?l03ooo0?l00ol0003o003oo`00o`0jo`00oakoGJ9M8_l00?l1ooooo`00=ol00?l00ol0
003oo`3oool0o`0Gool0o`03o`000?om0_goo@;m00Soo@;m1?l0000<ooL8m`03o`000?oS7>?ohacS
00;ohacS00?o0000onHIi_oV6NH02_oV6NH2o`00017oOX5n00?o0000oc;=<_lbcC801?lbcC800ol0
003oI9]TofBKI00<ofBKI003o`000?lUfRGo9MXU00Oo9MXU0_l00005ohIiQP;o00002?m:]DX00ol0
003o/4n`ok1?/004ok1?/003o`000?oc3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05?ol0o`00ol0
003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000o`00ool00?l0>_l00?lNoefR
GB;o003o0Oooool003So003o00?o0000ool0oooo0?l05ooo0?l00ol0003oo@;mood2o@07o`0000?o
oP7n00?o0000ooL8moog2?L02_og2?L01Ol0003ohacSon<LhooS7>?o000000coiQWV00Co0000om@[
e?oD:mCo00004OmnPGh00ol0003o</dboc;=<P02oc;=<P03o`000?mTVfCoI9]T00koI9]T00?o0000
obGJ9OlUfRD01OlUfRD00ol0003oQWV6ohIiQP07ohIiQP03o`000?m:]D[oB[E:00KoB[E:00?o0000
ok1?/?n`Ck000on`Ck000ol0003ol`ccoo<<l`0=oo<<l`03o`000?ol0ocoo0?l01Coo0?l00?o0000
ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0>ool0o`03o`000?l00?oo003o03_o003o7_mMXUdR
o`00o`7ooooo000ho`00o`03o`000?oo0?ooo`3o01Ooo`3o0ol0000;ooh1oP03o`000?og2?Oom`Sg
00Wom`Sg00Co0000on<LhooS7>?o00003?oV6NH00ol0003oe2_Dom@[e002om@[e003o`000?mnPGko
OX5n00ooOX5n00Co0000oc;=<_lbcC;o00004OmTVf@00ol0003o9MXUobGJ9@04obGJ9@03o`000?n6
NHKoQWV600WoQWV600?o0000odZeB_m:]DX01Om:]DX00ol0003o/4n`ok1?/003ok1?/003o`000?oc
3??ol`cc00gol`cc00?o0000oo`3o?ol0o`05Ool0o`00ol0003ooP7nooh1oP0<ooh1oP03o`000?oo
0?ooo`3o00goo`3o00?o0000o`00ool00?l0??l00?lNoefRGB;o003o0Oooool003So003o00?o0000
ool0oooo0?l05ooo0?l00ol0003ooP7nooh1oP0<ooh1oP03o`000?og2?Oom`Sg00Wom`Sg0_l0000<
onHIiP03o`000?oD:mCoe2_D00?oe2_D00?o0000ogj1O_mnPGh03omnPGh00ol0003o</dbo`00000C
ofBKI004o`000?lUfRGo9MXUobGJ9@;o00003On6NHH2o`0000KoB[E:00Go0000ok1?/?n`Ck3o/4n`
o`00000@oo<<l`03o`000?ol0ocoo0?l01Coo0?l0ol0000=ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003So003o00?o0000ool0oooo0?l05_oo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02_oV
6NH00ol0003oe2_Dom@[e005om@[e003o`000?mnPGkoOX5n00ooOX5n00?o0000ofBKI?mTVf@04omT
Vf@00ol0003o9MXUo`00000AohIiQP03o`000?m:]D[oB[E:00?oB[E:00Go0000ok1?/?n`Ck3o/4n`
o`00000>oo<<l`?o00005?ol0o`2o`0000?oo`3o0_l0000;ooh1oP03o`000?oo0?ooo`3o00coo`3o
00?o0000o`00ool00?l0?Ol00?lNoefRGB;o003o0Oooool003Wo003o00?o0000ool0oooo0?l05Ooo
0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg00Som`Sg00?o0000onHIi_oV6NH02OoV
6NH00ol0003oe2_Dom@[e007om@[e003o`000?mnPGkoOX5n00koOX5n00?o0000ofBKI?mTVf@05?mT
Vf@00ol0003oQWV6ohIiQP0AohIiQP;o00001?m:]DX01?l0003o/4n`ok1?/?l0000:oo<<l`Co0000
0oom0_d00ol0003oo0?loo`3o00@oo`3o003o`000?oo0?ooo`3o00Goo`3o0_l00009ooh1oP03o`00
0?oo0?ooo`3o00_oo`3o00?o0000o`00ool00?l0?_l00?lNoeRWF2;o003o0Oooool003Wo003o00?o
0000ool0oooo0?l05?oo0?l00ol0003ooP7nooh1oP0@ooh1oP03o`000?og2?Oom`Sg00Kom`Sg00?o
0000onHIi_oV6NH02OoV6NH00ol0003oe2_Dom@[e008om@[e003o`000?mnPGkoOX5n00_oOX5n0ol0
000GofBKI003o`000?n6NHKoQWV601?oQWV600Ko0000odZeB_m:]D[oB[E:o`000?n`Ck05o`0000Co
l`cc0ol00008ood2o@03o`000?ol0ocoo0?l00goo0?l0_l0000:ool0o`;o00001oon0Oh00ol0003o
o`3oool0o`0:ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000io`00o`03o`00
0?oo0?ooo`3o01Coo`3o00?o0000ooh1o_on0Oh04Oon0Oh00ol0003om`SgooL8m`05ooL8m`03o`00
0?oV6NKoiQWV00SoiQWV00?o0000om@[e?oD:m@02_oD:m@00ol0003oOX5nogj1OP07ogj1OP?o0000
0_nQGZ400ol0003oI9]TofBKI00EofBKI0;o00005On6NHH00ol0003oB[E:odZeBP02o`0000GojQGZ
1?l0000<ood2o@03o`000?ol0ocoo0?l00[oo0?l0_l0000>ool0o`;o00001?on0Oh00ol0003oo`3o
ool0o`0;ool0o`03o`000?l00?oo003o03oo003o7_mHYePRo`00o`7ooooo000jo`00o`03o`000?oo
0?ooo`3o01?oo`3o00?o0000ooh1o_on0Oh04Oon0Oh5o`0000?om`Sg00?o0000onHIi_oV6NH01ooV
6NH00ol0003oe2_Dom@[e00;om@[e003o`000?mnPGkoOX5n00CoOX5n0ol00006oj5NX@03o`000?mT
VfCoI9]T01?oI9]T00Co0000okY5^_njAK[o00005On6NHH2o`0000WojQGZ00?o0000ood2oOom0_d0
3?om0_d00ol0003oo0?loo`3o007oo`3o0;o00004_oo0?l2o`0000;ooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003o003oo`00o`10o`00oakoF:MH8_l00?l1ooooo`00>_l00?lFo`0001?ooP7n00?o
0000ooP7n?oh1oP00ooh1oP3o`0000WoiQWV00?o0000om@[e?oD:m@03OoD:m@00ol0003oOX5nogj1
OP03o`0000[oXEjQ00?o0000ofBKI?mTVf@04OmTVf@00ol0003o^TFjokY5^P02okY5^P03o`000?n6
NHKoQWV601;oQWV600?o0000onXEj_oZ5NX02?oZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol
0ocoo0?l00Coo0?l0_l0000Fool0o`?o00002ooo0?l00ol0003o003oo`00o`11o`00oakoF:MH8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n013ooP7n00?o0000
ooP7n?oh1oP01ooh1oP00ol0003oiQWVonHIiP05onHIiP03o`000?oD:mCoe2_D00ooe2_D0_l0000>
oj5NX@03o`000?mTVfCoI9]T00ooI9]T00?o0000okY5^_njAKX01?njAKX00ol0003oQWV6ohIiQP0@
ohIiQP;o00002ooZ5NX00ol0003oo@;mood2o@0=ood2o@03o`000?ol0ocoo0?l00;oo0?l00?o0000
ool0oooo0?l06?oo0?l00ol0003oo`3oool0o`07ool0o`;o0000A?l00?lNoeRWF2;o003o0Oooool0
03[o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?oh1oSon0Oh
00Won0Oh00?o0000onHIi_oV6NH00ooV6NH00ol0003oe2_Dom@[e00@om@[e003o`000?nQGZ7oXEjQ
00goXEjQ00?o0000ofBKI?mTVf@03_mTVf@00ol0003o^TFjokY5^P06okY5^P;o00003_n6NHH2o`00
0003ol`cc?l0003ojQGZ00[ojQGZ00?o0000ood2oOom0_d03_om0_d01?l0003oo0?lo`000?l0000K
ool0o`03o`000?oo0?ooo`3o00Coo`3o0ol00016o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0
003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00cooP7n00?o0000ooP7n?oh1oP02ooh1oP01Ol0
003oiQWVonHIi_oV6NKo000001;oe2_D00?o0000oj5NXOnQGZ403onQGZ400ol0003oI9]TofBKI00<
ofBKI003o`000?njAK[o^TFj00Wo^TFj00?o0000ohIiQ_n6NHH02On6NHH2o`0000?oc3?<00?o0000
onXEj_oZ5NX02OoZ5NX00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?ooo`3o01coo`3o00?o0000
ool0oooo0?l00ol00019o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Eool0
o`03o`000?on0OkooP7n00_ooP7n00?o0000ooP7n?oh1oP03Ooh1oP00ol0003oiQWVo`00000Com@[
e003o`000?nQGZ7oXEjQ013oXEjQ00?o0000ofBKI?mTVf@02_mTVf@00ol0003o^TFjokY5^P0;okY5
^P03o`000?n6NHKoQWV600GoQWV60ol00006ol`cc003o`000?oZ5N[ojQGZ00SojQGZ00?o0000ood2
oOom0_d03oom0_d00ol0003oo`3oool0o`0Mool0o`;o0000C?l00?lNoe>/Db;o003o0Oooool003Wo
003o00?o0000ool0oooo0?l05_oo0?l00ol0003ooP7nooh1oP09ooh1oP03o`000?oh1oSon0Oh00oo
n0Oh00?o0000om@[e?oD:m@04OoD:m@00ol0003oXEjQoj5NX@0Aoj5NX@03o`000?mTVfCoI9]T00Wo
I9]T00?o0000okY5^_njAKX03OnjAKX00ol0003oQWV6ohIiQP02ohIiQP;o00002Oo<<l`00ol0003o
jQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o
003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Fool0o`03o`00
0?on0OkooP7n00SooP7n00?o0000ooP7n?oh1oP04Ooh1oP2o`00017oe2_D00?o0000oj5NXOnQGZ40
4_nQGZ400ol0003oI9]TofBKI007ofBKI003o`000?njAK[o^TFj00oo^TFj00Co0000ohIiQ_l0003o
00002oo<<l`00ol0003ojQGZonXEjP09onXEjP03o`000?om0_goo@;m00koo@;m00?o0000ool0oooo
0?l07Ooo0?l00ol0003o003oo`00o`1;o`00oakoDjaC8_l00?l1ooooo`00>Ol00?l00ol0003oo`3o
ool0o`0Gool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooP7n?oh1oP04_oh1oP00ol0003ok1?/
o`000002o`0000koe2_D00?o0000oj5NXOnQGZ404onQGZ400ol0003oI9]TofBKI005ofBKI003o`00
0?njAK[o^TFj017o^TFj00?o0000ol`cc?o<<l`03?o<<l`00ol0003ojQGZonXEjP08onXEjP03o`00
0?om0_goo@;m00goo@;m00?o0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoDjaC
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Gool0o`Co00000oon0Oh00ol0003on0OhooP7
n00BooP7n003o`000?o/4ncok1?/00?ok1?/0_l0000;om@[e0;o00005_nQGZ47o`0001Co^TFj00?o
0000ol`cc?o<<l`03?o<<l`00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00goo@;m00?o
0000ool0oooo0?l07Ooo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Gool0o`04o`000?on0OkooP7nooh1oP?o00005?oh1oP00ol0003ok1?/on`C
k006on`Ck0?o00002?oD:m@00ol0003obSG:o`000002o`0001;oXEjQ00?o0000okA;]?ndBk@00_nd
Bk@00ol0003oYUVVo`00000DokY5^P03o`000?o<<lcoc3?<00coc3?<00?o0000onXEj_oZ5NX02?oZ
5NX00ol0003oo@;mood2o@0=ood2o@03o`000?oo0?ooo`3o01coo`3o0_l0001>o`00oakoC[5>8_l0
0?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Fool0o`03o`000?on0OkooP7n00CooP7n00?o0000
ooP7n?oh1oP04_oh1oP00ol0003ok1?/on`Ck009on`Ck0;o00001OoD:m@00ol0003obSG:olXebP03
olXebP;o00003onQGZ400ol0003o]4^dokA;]003okA;]004o`000?nVFJKoYUVVo`0001?o^TFj00?o
0000ol`cc?o<<l`03Oo<<l`00ol0003ojQGZonXEjP08onXEjP03o`000?om0_goo@;m00_oo@;m0ol0
000Jool0o`?o000000?oo`3oo`000?l00?l0COl00?lNodjaCR;o003o0Oooool003[o003o00?o0000
ool0oooo0?l05Ooo0?l00ol0003ooP7nooh1oP06ooh1oQCo00003_o/4n`3o`000003om@[e?l0003o
bSG:00OobSG:0ol0000;oj5NX@03o`000?ndBkCo]4^d00Co]4^d00Go0000ojIIY_nVFJKoYUVVo`00
000BokY5^P03o`000?o<<lcoc3?<00goc3?<00?o0000onXEj_oZ5NX01ooZ5NX?o`0000?oo`3o0_l0
000Fool0o`;o00001?oo0?l00ol0003o003oo`00o`1<o`00oakoC[5>8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Eool0o`03o`000?on0OkooP7n00KooP7n00?o0000ooT6nOoi1_T04?oi1_T0
0ol0003ok1?/on`Ck00?on`Ck003o`000?o:=L[obSG:00[obSG:0_l00008oj5NX@03o`000?ndBkCo
]4^d00Go]4^d00?o0000ojIIY_nVFJH00_nVFJH00ol0003o^TFjokY5^P0?okY5^P03o`000?o<<lco
c3?<00goc3?<00?o0000onXEj_oZ5NX01_oZ5NX00ol0003on`Ckoo/4n`0<oo/4n`03o`000?oo0?oo
o`3o00?oo`3o00?o0000ool0oooo0?l04?oo0?l3o`0000Ooo`3o00?o0000o`00ool00?l0Bol00?lN
odjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003ooP7nooh1oP08ooh1
oP03o`000?oi1_Won@Ki00oon@Ki00?o0000on`Ck?o/4n`03oo/4n`00ol0003obSG:olXebP0<olXe
bP;o00001OnQGZ400ol0003o]4^dokA;]006okA;]003o`000?nVFJKoYUVV00?oYUVV00?o0000okY5
^_njAKX03_njAKX00ol0003oc3?<ol`cc00>ol`cc003o`000?oZ5N[ojQGZ00CojQGZ00?o0000oo/4
nook1?/03Ook1?/00ol0003oo`3oool0o`04ool0o`;o00003_oo0?l2o`0000[oo`3o00?o0000o`00
ool00?l0Bol00?lNodjaCR;o003o0Oooool003_o003o00?o0000ool0oooo0?l04ooo0?l00ol0003o
oP7nooh1oP08ooh1oP03o`000?oi1_Won@Ki00kon@Ki00?o0000on`Ck?o/4n`04?o/4n`00ol0003o
bSG:olXebP0>olXebP?o000000?oXEjQo`000?ndBk@02?ndBk@00ol0003oYUVVojIIYP04ojIIYP03
o`000?njAK[o^TFj00go^TFj4_l00005onXEjP03o`000?ok1?_on`Ck00gon`Ck00?o0000ool0oooo
0?l01ooo0?l2o`0000Woo`3o0ol0000<ool0o`03o`000?l00?oo003o04_o003o7_m9]TTRo`00o`7o
oooo000ko`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ck
o`00000?ooT6n@03o`000?o/4ncok1?/00ook1?/0_l0000ColXebP03o`000?ndBkCo]4^d00So]4^d
00?o0000ojIIY_nVFJH01OnVFJH00ol0003o^TFjokY5^P0<okY5^P03o`000?oa3_7ol@ka00ool@ka
00Go0000onXEj_oZ5N[ojQGZo`00000@oo/4n`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo
0?l01?oo0?l2o`00013oo`3o00?o0000o`00ool00?l0B_l00?lNodVfBB;o003o0Oooool003_o003o
00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP09ooh1oP04o`000?ok1?_on`Cko`0000ko
n@Ki00?o0000on`Ck?o/4n`03_o/4n`00ol0003oi1_To`00000ColXebP03o`000?ndBkCo]4^d00So
]4^d00?o0000ojIIY_nVFJH01OnVFJH00ol0003o^TFjokY5^P0;okY5^P03o`000?oa3_7ol@ka017o
l@ka00?o0000onXEj_l000004Ook1?/00ol0003oo`3oool0o`0:ool0o`;o000000Coo`3oo`000?l0
003o00004_oo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00>ol00?l00ol0003o
o`3oool0o`0Aool0o`03o`000?on0OkooP7n00SooP7n00?o0000oo/4nook1?/00_ok1?/00ol0003o
n@KiooT6n@0:ooT6n@03o`000?o/4ncok1?/00gok1?/0_l00003on@Ki003o`000?o:=L[obSG:013o
bSG:00?o0000okA;]?ndBk@02?ndBk@00ol0003oYUVVojIIYP06ojIIYP03o`000?njAK[o^TFj00[o
^TFj00?o0000oo4>lOoa3_404_oa3_400ol0003on`Ckoo/4n`0@oo/4n`03o`000?oo0?ooo`3o00co
o`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1:o`00oakoBKI98_l00?l1ooooo`00
>ol00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/0
0ook1?/00ol0003on@KiooT6n@09ooT6n@03o`000?o/4ncok1?/00cok1?/00?o0000on@Ki?oT6n@0
0ooT6n@00ol0003obSG:olXebP0?olXebP03o`000?ndBkCo]4^d00Wo]4^d00?o0000ojIIY_nVFJH0
1onVFJH00ol0003o^TFjokY5^P09okY5^P03o`000?oa3_7ol@ka01;ol@ka00?o0000oo/4nook1?/0
4?ok1?/00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0
B_l00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1
oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T00ol0003ok1?/on`C
k00:on`Ck0;o00001_oT6n@00ol0003obSG:olXebP0?olXebP03o`000?ndBkCo]4^d00Wo]4^d00?o
0000ojIIY_nVFJH02?nVFJH00ol0003o^TFjokY5^P07okY5^P03o`000?oa3_7ol@ka01?ol@ka00?o
0000oo/4nook1?/03ook1?/00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000o`00ool00?l0Bol00?lNodVfBB;o003o0Oooool003co003o00?o0000ool0oooo0?l03_oo0?l0
0ol0003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Gon`Ck00?o0000ooT6nOoi1_T02?oi1_T0
0ol0003ok1?/on`Ck009on`Ck003o`000?oT6nCoi1_T00Ooi1_T00?o0000olXeb_o:=LX03Oo:=LX2
o`0000_o]4^d00?o0000ojIIY_nVFJH02OnVFJH00ol0003o^TFjokY5^P06okY5^P03o`000?oa3_7o
l@ka01?ol@ka4ol0000?ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Bol00?lN
od>l@b;o003o0Oooool003co003o0ol0000=ool0o`03o`000?on0OkooP7n00WooP7n00?o0000oo/4
nook1?/01ook1?/00ol0003on@KiooT6n@06ooT6n@03o`000?o/4ncok1?/00Wok1?/00?o0000on@K
i?oT6n@02?oT6n@00ol0003obSG:olXebP0;olXebP;o000000?oc3?<o`000?ndBk@02_ndBk@00ol0
003oYUVVojIIYP09ojIIYPKo00000onjAKX00ol0003ol@kaoo4>l@0Coo4>l@03o`000?ol0ocoo0?l
00ooo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`04o`000?oo0?ooo`3oool0o`Go00002?oo0?l00ol0
003ooP7nooh1oP09ooh1oP03o`000?ok1?_on`Ck00Son`Ck00?o0000ooT6nOoi1_T01?oi1_T3o`00
00Sok1?/0_l0000;on@Ki003o`000?o:=L[obSG:00WobSG:0_l00004ol`cc003o`000?ndBkCo]4^d
00So]4^d00?o0000ojIIY_nVFJH02?nVFJH00ol0003ofbCKom/Tf`04om/Tf`?o00005?oa3_43o`00
017oo0?l00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o
04_o003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00Koo`3o1Ol00002ool0o`03
o`000?on0OkooP7n00WooP7n00?o0000oo/4nook1?/02_ok1?/00ol0003on@KiooT6n@03o`0000?o
m`Sg00?o0000on`Ck?o/4n`01?o/4n`00ol0003oi1_Ton@Ki00<on@Ki003o`000?o:=L[obSG:00Go
bSG:0ol00007ol`cc003o`000?ndBkCo]4^d00Oo]4^d00?o0000ojIIY_nVFJH01onVFJH00ol0003o
fbCKom/Tf`08om/Tf`03o`000?oa3_7ol@ka013ol@ka00Go0000ooX5n_oj1O[onPGjo`00000@oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0;ool0o`;o00003?on0Oh00ol0003o
n`Ckoo/4n`0;oo/4n`;o00001oog2?L01?l0003ok1?/on`Ck?o/4n`2o`0000ooi1_T00?o0000olXe
b_o:=LX00oo:=LX2o`0000[oc3?<00?o0000okA;]?ndBk@01ondBk@00ol0003oYUVVojIIYP05ojII
YP;o00003?oK9=/00ol0003ol@kaoo4>l@0=oo4>l@;o00001Ooj1OX00ol0003oo0?loo`3o00=oo`3
o003o`000?oo0?ooo`3o00coo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1<o`00
oako@ka38_l00?l1ooooo`00>ol00?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00Wo
oP7n00?o0000oo/4nook1?/03?ok1?/00ol0003om`SgooL8m`07ooL8m`03o`000?o/4nco0000017o
i1_T00Co0000olXeb_o:=L[obSG:0_l0000=ol`cc003o`000?ndBkCo]4^d00Ko]4^d00?o0000ojII
Y_nVFJH01?nVFJH00ol0003ofbCKom/Tf`0=om/Tf`Co00002_oa3_400ol0003onPGjooX5nP06ooX5
nP03o`000?ol0ocoo0?l00coo0?l00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o04co003o7_m3_4<Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00go
o`3o00?o0000ooh1o_on0Oh02?on0Oh00ol0003on`Ckoo/4n`0;oo/4n`03o`000?og2?Oom`Sg00Wo
m`Sg00?o0000on@Ki?oT6n@04OoT6n@3o`00013oc3?<00?o0000okA;]?ndBk@01OndBk@00ol0003o
YUVVojIIYP03ojIIYP03o`000?oK9=_ofbCK00kofbCK00Co0000ooH9m_of2OKomPWf1_l00003oo4>
l@03o`000?oj1O[onPGj00SonPGj00?o0000oo`3o?ol0o`02ool0o`00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0C?l00?lNock1?R;o003o0Oooool003[o
003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP06ooh1oP03o`000?ok1?_on`Ck00_o
n`Ck00?o0000ooL8moog2?L02_og2?L00ol0003oi1_Ton@Ki00Aon@Ki003o`000?o<<lcoc3?<013o
c3?<00?o0000okA;]?ndBk@01OndBk@00ol0003oYUVVojIIYP02ojIIYP03o`000?oK9=_ofbCK00oo
fbCK00?o0000ooH9m_of2OH01oof2OH3o`0000conPGj00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
o`3oool0o`0;ool0o`?o00004ooo0?l00ol0003o003oo`00o`1<o`00oako?/4n8_l00?l1ooooo`00
>_l00?l00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n00GooP7n00?o0000oo/4nook1?/0
2_ok1?/00ol0003om`SgooL8m`0<ooL8m`03o`000?oT6nCoi1_T013oi1_T00?o0000ol`cc?o<<l`0
4Oo<<l`00ol0003o]4^dokA;]004okA;]003o`000?nVFJKoYUVV00;o00004OoK9=/00ol0003omPWf
ooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj3Ol0000;ool0o`;o00000ooo0?l2o`00013oo`3o
00?o0000o`00ool00?l0COl00?lNock1?R;o003o0Oooool003[o003o00?o0000ool0oooo0?l04Ooo
0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?ok1?_on`Ck00[on`Ck00?o0000ooL8moog2?L03_og
2?L00ol0003oi1_Ton@Ki00=on@Ki0;o00005?o<<l`3o`0000Co]4^d00?o0000ojIIY_l000004ooK
9=/00ol0003omPWfooH9mP0:ooH9mP03o`000?oj1O[onPGj00_onPGj00?o0000ooh1o_on0Oh02Oon
0Oh00ol0003oo`3oool0o`07ool0o`;o00001ooo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?l0
0?oo003o04go003o7_ln`ChRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000
ooh1o_on0Oh00_on0Oh00ol0003on`Ckoo/4n`0:oo/4n`03o`000?og2?Oom`Sg00kom`Sg00?o0000
on@Ki?oT6n@02_oT6n@3o`000003onDJiOl0003oc3?<017oc3?<0_l00003omLXe`;o00000_ndBk@2
o`0001CofbCK00?o0000ooH9m_of2OH02_of2OH00ol0003onPGjooX5nP0;ooX5nP03o`000?on0Oko
oP7n00[ooP7n00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`08ool0o`;o00003Ooo0?l0
0ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Cool0
o`Oo00002Ook1?/00ol0003om`SgooL8m`0@ooL8m`03o`000?oT6nCoi1_T00Koi1_T0ol00005onDJ
i@03o`000?o<<lcoc3?<00goc3?<0_l00007omLXe`?o00005OoK9=/00ol0003omPWfooH9mP0;ooH9
mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh03?on0Oh3o`0000;oo`3o0_l0000=ool0
o`;o00002ooo0?l00ol0003o003oo`00o`1=o`00oako?/4n8_l00?l1ooooo`00>_l00?l00ol0003o
o`3oool0o`0Cool0o`03o`000?on0OkooP7n00CooP7n1Ol00003oo/4n`03o`000?og2?Oom`Sg017o
m`Sg00?o0000on@Ki?oT6n@01?oT6n@2o`0000WoiA[U00?o0000ol`cc?o<<l`02_o<<l`2o`0000_o
ebSG00?o0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00Wo
nPGj00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`02o`00017oo`3o0_l00008ool0o`03
o`000?l00?oo003o04ko003o7_liaSTRo`00o`7ooooo000jo`00o`03o`000?oo0?ooo`3o01;oo`3o
00?o0000ooh1o_on0Oh02_on0Oh3o`0001Gom`Sg00?o0000on@Ki?oT6n@00ol0000<onDJi@03o`00
0?o<<lcoc3?<00Ooc3?<0_l0000=omLXe`03o`000?oK9=_ofbCK01;ofbCK00?o0000ooH9m_of2OH0
3?of2OH00ol0003onPGjooX5nP09ooX5nP03o`000?on0OkooP7n00_ooP7n00?o0000ool0oooo0?l0
0_oo0?l00ol0003oo`3oool0o`0Aool0o`;o00001_oo0?l00ol0003o003oo`00o`1>o`00oako>LHi
8_l00?l1ooooo`00>_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00cooP7n00?o
0000ooL8moog2?L05?og2?L2o`0000ooiA[U00?o0000ol`cc?o<<l`01Oo<<l`2o`0000ooebSG00?o
0000om/TfooK9=/04_oK9=/00ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o
0000ooh1o_on0Oh02_on0Oh00ol0003oo`3oool0o`04ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o
0000ool0oooo0?l00_oo0?l00ol0003o003oo`00o`1?o`00oako>LHi8_l00?l1ooooo`00>_l00?l0
0ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n00gooP7n00?o0000ooL8moog2?L04oog2?L2
o`00013oiA[U00?o0000ol`cc?o<<l`00_o<<l`2o`0001;oebSG00?o0000om/TfooK9=/04OoK9=/0
0ol0003omPWfooH9mP0<ooH9mP03o`000?oj1O[onPGj00WonPGj00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`05ool0o`03o`000?oo0?ooo`3o01?oo`3o0_l000000ooo0?oo0000o`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Bool0o`03o`000?on0OkooP7n
00kooP7n00?o0000ooL8moog2?L04_og2?L01?l0003ol`ccoo<<lol0000@onDJi@04o`000?o<<lco
0000o`0001CoebSG00?o0000om/TfooK9=/04?oK9=/00ol0003omPWfooH9mP0>ooH9mP03o`000?oj
1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02Oon0Oh00ol0003oo`3oool0o`06ool0o`03o`000?oo
0?ooo`3o01Goo`3o00?o0000o`00ool00?l0DOl00?lNocW6>B;o003o0Oooool003Wo003o00?o0000
ool0oooo0?l04_oo0?l00ol0003ooP7nooh1oP0>ooh1oP03o`000?og2?Oom`Sg017om`Sg00?o0000
oo<<looc3?<00_oc3?<00ol0003oiA[UonDJi@0>onDJi@03o`000?oG:=OoebSG01CoebSG00?o0000
om/TfooK9=/03OoK9=/4o`00013omPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP09
ooh1oP03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003o003oo`00o`1A
o`00oako>LHi8_l00?l1ooooo`00>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n
013ooP7n00?o0000ooL8moog2?L04?og2?L00ol0003ol`ccoo<<l`03oo<<l`03o`000?oU6^GoiA[U
00goiA[U00?o0000omLXeooG:=L05?oG:=L00ol0003ofbCKom/Tf`07om/Tf`Ko00000oo^4Nh00ol0
003omPWfooH9mP0>ooH9mP03o`000?oj1O[onPGj00OonPGj00?o0000ooh1o_on0Oh02?on0Oh00ol0
003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0D_l00?lNocC;
=2;o003o0Oooool003Wo003o00?o0000ool0oooo0?l04Ooo0?l00ol0003ooP7nooh1oP0@ooh1oP03
o`000?og2?Oom`Sg00oom`Sg00?o0000oo<<looc3?<01Ooc3?<00ol0003oiA[UonDJi@0<onDJi@03
o`000?oG:=OoebSG01GoebSG00?o0000om/TfooK9=/01_l0000:onhAkP03o`000?of2OKomPWf00go
mPWf00?o0000ooX5n_oj1OX01ooj1OX00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o00[o
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Bo`00oako=</d8_l00?l1ooooo`00
>Ol00?l00ol0003oo`3oool0o`0Aool0o`03o`000?on0OkooP7n013ooP7n00?o0000ooL8moog2?L0
3oog2?L00ol0003ol`ccoo<<l`06oo<<l`03o`000?oU6^GoiA[U00_oiA[U00?o0000omLXeooG:=L0
5OoG:=L3o`00017okQ7^00?o0000ooH9m_of2OH03?of2OH00ol0003onPGjooX5nP07ooX5nP03o`00
0?on0OkooP7n00KooP7n00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?l00?oo003o05?o003o7_ldbc@Ro`00o`7ooooo000io`00o`03o`000?oo0?ooo`3o013oo`3o00?o
0000ooh1o_on0Oh04_on0Oh9o`0000Oom`Sg00?o0000oo<<looc3?<02?oc3?<00ol0003oiA[UonDJ
i@0:onDJi@03o`000?oG:=OoebSG01GoebSG00?o0000onhAk_o^4Nh04Oo^4Nh00ol0003omPWfooH9
mP0=ooH9mP03o`000?oj1O[onPGj00GonPGj00?o0000ooh1o_on0Oh01oon0Oh00ol0003oo`3oool0
o`0;ool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000o`00ool00?l0Dol00?lNocC;=2;o003o0Ooo
ool003[o003o00?o0000ool0oooo0?l03ooo0?l00ol0003ooP7nooh1oP0Booh1oP03o`000?ol0oco
o0?l00Koo0?l1ol0000<oo<<l`03o`000?oU6^GoiA[U00WoiA[U00?o0000omLXeooG:=L05?oG:=L0
0ol0003okQ7^onhAkP0ConhAkP03o`000?of2OKomPWf00comPWf00Co0000ooX5n_oj1O[onPGj1_l0
0007ooh1oP03o`000?oo0?ooo`3o00goo`3o1Ol0000=ool0o`03o`000?l00?oo003o05Co003o7_ld
bc@Ro`00o`7ooooo000ko`00o`03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh04Oon0Oh0
0ol0003oo0?loo`3o00=oo`3o003o`000?oc3??ol`cc00_ol`cc00?o0000onDJiOoU6^D02OoU6^D0
0ol0003oebSGomLXe`0ComLXe`03o`000?o^4NkokQ7^01CokQ7^1?l0000:ooH9mPCo00001_on0Oh2
o`0000CooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001?oo0?l0
0ol0003o003oo`00o`1Do`00oako=</d8_l00?l1ooooo`00??l00?l00ol0003oo`3oool0o`0;ool0
o`Co00004_on0Oh00ol0003oo0?loo`3o00=oo`3o0?o00003?oc3?<00ol0003oiA[UonDJi@08onDJ
i@03o`000?oG:=OoebSG00ooebSG1?l0000GonhAkP04o`000?oi1_Won@KiooT6n@Ko00000oof2OH0
0ol0003ooP7nooh1oP0:ooh1oP;o000000?ooP7no`000?oo0?l03ooo0?l00ol0003oo`3oool0o`0<
ool0o`Co0000Eol00?lNobo@;b;o003o0Oooool003go003o00?o0000ool0oooo0?l02Ooo0?l00ol0
003oo`3oool0o`02ool0o`?o00003_on0Oh00ol0003oo0?loo`3o00>oo`3o003o`000?og2?Oom`Sg
00?o00002_oc3?<00ol0003oiA[UonDJi@07onDJi@03o`000?oG:=OoebSG00SoebSG1ol00003on`C
k003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6nOoi1_T02?oi1_T3o`0000oooP7n00?o0000ool0
oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05Go003o7_l_d2lRo`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00Koo`3o0_l00008ool0o`?o00002oon0Oh00ol0003o
o0?loo`3o00>oo`3o003o`000?og2?Oom`Sg00?om`Sg0ol00008oo<<l`03o`000?oU6^GoiA[U00Ko
iA[U00Co0000omLXeooG:=OoebSG1ol0000:on`Ck003o`000?o^4NkokQ7^01CokQ7^00?o0000ooT6
nOoi1_T02_oi1_T00ol0003ooP7nooh1oP0=ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0
oooo0?l04?oo0?l00ol0003o003oo`00o`1Eo`00oako;m0_8_l00?l1ooooo`00?ol00?l00ol0003o
o`3oool0o`04ool0o`03o`000?oo0?ooo`3o00_oo`3o0ol00008ooh1oP03o`000?ol0ocoo0?l00ko
o0?l00?o0000ooL8moog2?L01_og2?L3o`0000Kol`cc00?o0000onDJiOoU6^D01?oU6^D5o`0001;o
k1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@KiooT6n@0;ooT6n@03o`000?on0OkooP7n00ko
oP7n00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o05Co
003o7_l_d2lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00?o00004Ooo0?l3o`0000CooP7n
00?o0000oo`3o?ol0o`03ool0o`00ol0003om`SgooL8m`09ooL8m`?o00001?oc3?<00ol0003oiA[U
onDJi@03o`000003ooP7n?l0003ok1?/01Cok1?/00?o0000onhAk_o^4Nh04_o^4Nh00ol0003on@Ki
ooT6n@0;ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3o
ool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo0011o`00o`;o00000_oo
0?l00ol0003oo`3oool0o`0Bool0o`?o000000?ooP7no`000?ol0o`04?ol0o`00ol0003om`SgooL8
m`0<ooL8m`?o000000Col`cco`000?l0003o00001?oh1oP00ol0003ok1?/on`Ck00Bon`Ck0;o0000
4oo^4Nh00ol0003on@KiooT6n@0<ooT6n@03o`000?on0OkooP7n00oooP7n00?o0000ool0oooo0?l0
2_oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?l00?oo003o05Co003o7_l_d2lRo`00o`7ooooo
0011o`00o`03o`000?oo0?ooo`3o00;oo`3o00?o0000ool0oooo0?l05?oo0?l00ol0003oo0?loo`3
o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh1oP00ol0003ok1?/on`C
k00@on`Ck004o`000?o_4>ooka3_o`0001;okQ7^00?o0000ooT6nOoi1_T03?oi1_T00ol0003ooP7n
ooh1oP0@ooh1oP?o00002?oo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Co003o
7_lYeRTRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04ooo
0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg00oom`Sg00?o0000ooP7n?oh1oP01_oh
1oP00ol0003ok1?/on`Ck00?on`Ck003o`000?o_4>ooka3_00;oka3_00?o0000onhAk_o^4Nh03_o^
4Nh00ol0003on@KiooT6n@0=ooT6n@03o`000?on0OkooP7n013ooP7n00?o0000ool0oooo0?l00ol0
0005ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000o`00ool00?l0EOl00?lNobWF:B;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?ol0oco
o0?l013oo0?l00?o0000ooL8moog2?L03_og2?L00ol0003on0OhooP7n007ooP7n003o`000?o/4nco
k1?/00kok1?/00?o0000onl@koo_4>l01?o_4>l2o`0000kokQ7^00?o0000ooT6nOoi1_T03Ooi1_T0
0ol0003ooP7nooh1oP0?ooh1oP03o`000?oo0?ooo`3o00Coo`3o0ol000000ooo0?oo0000ool0o`0E
ool0o`03o`000?l00?oo003o05Go003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o
00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo0?loo`3o00@oo`3o003o`000?og2?Oom`Sg
00gom`Sg00?o0000ooP7n?oh1oP02?oh1oP00ol0003ok1?/on`Ck00=on`Ck003o`000?o_4>ooka3_
00Goka3_00?o0000ooP7n?l000000_l0000:onhAkP03o`000?oi1_Won@Ki00kon@Ki00?o0000ooh1
o_on0Oh03_on0Oh00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00
ool00?l0E_l00?lNobWF:B;o003o0Oooool003oo003o00?o0000ool0oooo0?l02?oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?ol0ocoo0?l013oo0?l00?o0000ooL8moog2?L03?og2?L00ol0003o
n0OhooP7n00:ooP7n003o`000?o/4ncok1?/00_ok1?/00?o0000onl@koo_4>l01_o_4>l00ol0003o
n0OhooP7n002ooP7n0?o00001oo^4Nh00ol0003on@KiooT6n@0>ooT6n@03o`000?on0OkooP7n00go
oP7n00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?l00?oo003o05Ko
003o7_lYeRTRo`00o`7ooooo000oo`00o`03o`000?oo0?ooo`3o00Woo`3o00?o0000ool0oooo0?l0
3ooo0?l3o`00013oo0?l1?l0000:ooL8m`03o`000?oh1oSon0Oh00_on0Oh00?o0000on`Ck?o/4n`0
2_o/4n`00ol0003oka3_onl@k`06onl@k`03o`000?oh1oSon0Oh00Kon0Oh0_l00004onhAkP03o`00
0?oi1_Won@Ki00oon@Ki00?o0000ooh1o_on0Oh03Oon0Oh00ol0003oo`3oool0o`0:ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobWF:B;o003o0Oooool003ko003o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?on0OkooP7n00?o00003Ool
0o`01?l0003oo0?loo`3o?ol0o`6o`0000?om`Sg00?o0000ooP7n?oh1oP03?oh1oP00ol0003ok1?/
on`Ck009on`Ck003o`000?o_4>ooka3_00Ooka3_00?o0000ooP7n?oh1oP02?oh1oP3o`000003onhA
k_l0003on@Ki013on@Ki00?o0000ooh1o_on0Oh03?on0Oh00ol0003oo`3oool0o`0;ool0o`03o`00
0?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0Eol00?lNobCK92;o003o0Oooool003ko003o00?o
0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?on0OkooP7n00CooP7n0ol0
0009oo`3o003o`000?ol0ocoo0?l00Soo0?l0ol0000?ooP7n003o`000?o/4ncok1?/00Sok1?/00?o
0000onl@koo_4>l02?o_4>l00ol0003on0OhooP7n00;ooP7n003o`000?oi1_Won@Ki013on@Ki00?o
0000ooh1o_on0Oh02oon0Oh00ol0003oo`3oool0o`0=ool0o`Ko00003Ooo0?l00ol0003o003oo`00
o`1Ho`00oako9=/T8_l00?l1ooooo`00?Ol00?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?oo
o`3o00[oo`3o00?o0000ooh1o_on0Oh02?on0Oh3o`0000Goo0?l00?o0000oo`3o?ol0o`02ool0o`0
0ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Ook1?/00?o0000onl@koo_4>l02?o_4>l0
0ol0003on0OhooP7n00<ooP7n003o`000?oi1_Won@Ki00kon@Ki0ol0000=ooh1oP03o`000?oo0?oo
o`3o00goo`3o00?o0000ool0oooo0?l00ooo0?l9o`0000Coo`3o00?o0000o`00ool00?l0F?l00?lN
obCK92;o003o0Oooool003go003o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`08ool0
o`03o`000?on0OkooP7n00cooP7n0ol00002oo`3o003o`000?ol0ocoo0?l00_oo0?l00?o0000ooP7
n?oh1oP03_oh1oP00ol0003ok1?/on`Ck005on`Ck003o`000?o_4>ooka3_00Woka3_00?o0000ooP7
n?oh1oP03Ooh1oP00ol0003on@KiooT6n@0:ooT6n@?o00000oom0_d00ol0003ooP7nooh1oP09ooh1
oP03o`000?oo0?ooo`3o00koo`3o00?o0000ool0oooo0?l03?oo0?l4o`0005_o003o7_lTfb@Ro`00
o`7ooooo000no`00o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o
oP7nooh1oP0?ooh1oP;o00003ool0o`00ol0003on0OhooP7n00=ooP7n003o`000?o/4ncok1?/00Co
k1?/00?o0000onl@koo_4>l02_o_4>l00ol0003on0OhooP7n00=ooP7n003o`000?oi1_Won@Ki00Oo
n@Ki0ol00007ood2o@03o`000?on0OkooP7n00OooP7n00?o0000ool0oooo0?l03_oo0?l00ol0003o
o`3oool0o`0@ool0o`03o`000?l00?oo003o05Wo003o7_lTfb@Ro`00o`7ooooo000no`00o`03o`00
0?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP0Aooh1oP03o`00
0?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`Ck003on`Ck003o`00
0?o_4>ooka3_00[oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6n@03ooT6n@?o0000
2oom0_d9o`00017oo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003o003oo`00o`1Io`00oako9=/T
8_l00?l1ooooo`00?_l00?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00?oo`3o0_l0
000Cooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh1oP03Ooh1oP00ol0003ok1?/on`C
k002on`Ck003o`000?o_4>ooka3_00_oka3_00?o0000ooP7n?oh1oP03ooh1oP00ol0003on@KiooT6
n@03o`0000koo@;m00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo
0?ooo`3o013oo`3o00?o0000o`00ool00?l0FOl00?lNoaoP7b;o003o0Oooool003oo003o00?o0000
ool0oooo0?l04Ooo0?l01Ol0003oo`3oool0oooo0?oo000000;oo`3o0_l0000Aooh1oP03o`000?ol
0ocoo0?l00koo0?l00?o0000ooP7n?oh1oP03Ooh1oP01?l0003ok1?/on`Ck?l0000>onl@k`03o`00
0?oh1oSon0Oh013on0Oh0_l0000Aood2o@03o`000?oo0?ooo`3o00Koo`3o00?o0000ool0oooo0?l0
3_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo
000oo`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0ool000001Ooo0?l2o`0000oooP7n00?o
0000oo`3o?ol0o`03_ol0o`00ol0003on0OhooP7n00=ooP7n0Go00003?o_4>l00ol0003on0OhooP7
n00AooP7n003o`000?om0_goo@;m013oo@;m00?o0000ool0oooo0?l01ooo0?l00ol0003oo`3oool0
o`0<ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000o`00ool00?l0F?l00?lNoaoP7b;o003o0Ooo
ool0043o003o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`06ool0o`;o00003Oon0Oh0
0ol0003oo0?loo`3o00>oo`3o003o`000?oh1oSon0Oh00gon0Oh00?o0000ooP7n?oh1oP00_oh1oP3
o`0000Woka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2o@03o`000?oo0?oo
o`3o00Woo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo
003o05So003o7_lOh1lRo`00o`7ooooo0010o`00o`03o`000?oo0?ooo`3o017oo`3o0_l0000:ool0
o`;o00002oon0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooP7
n?oh1oP01_oh1oP4o`0000Goka3_00?o0000ooP7n?oh1oP04Ooh1oP00ol0003oo@;mood2o@0?ood2
o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0Bool0
o`03o`000?l00?oo003o05So003o7_lOh1lRo`00o`7ooooo0011o`00o`03o`000?oo0?ooo`3o00oo
o`3o00?o0000ool0ool000003?oo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?ol0ocoo0?l00oo
o0?l00?o0000ooP7n?oh1oP02_oh1oP00ol0003on0OhooP7n00;ooP7n0?o000000?oka3_o`000?oh
1oP04_oh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo
0?l02_oo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?l00?oo003o05Wo003o7_lOh1lRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00koo`3o00Go0000ool0oooo0?ooo`3oo`00000<ool0o`;o
00001oon0Oh3o`00013oo0?l00?o0000ooP7n?oh1oP02Ooh1oP00ol0003on0OhooP7n00?ooP7n0;o
00004ooh1oP00ol0003oo@;mood2o@0@ood2o@03o`000?oo0?ooo`3o00_oo`3o00?o0000ool0oooo
0?l02Ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05[o003o7_lJiAXRo`00o`7o
oooo0011o`00o`03o`000?oo0?ooo`3o00coo`3o0_l00005ool0o`03o`000?oo0?ooo`3o00_oo`3o
0_l00004ooh1oP04o`000?on0OkooP7nooh1oP;o00003ool0o`00ol0003on0OhooP7n006ooP7n0;o
00004ooh1oP00ol0003on0OhooP7n00AooP7n0;o00004Oom0_d00ol0003oo`3oool0o`0<ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003o003oo`00o`1Jo`00oako
6^DJ8_l00?l1ooooo`00@_l00?l2o`0000_oo`3o00?o0000ool0oooo0?l01_oo0?l00ol0003oo`3o
ool0o`0<ool0o`;o000000?ooP7no`000?on0Oh01Oon0Oh2o`0000goo0?l00?o0000ooP7n?oh1oP0
1?oh1oP2o`0000;oo0?l00?o0000ooP7n?oh1oP04Ooh1oP00ol0003on0OhooP7n00?ooP7n004o`00
0?om0_goo@;mo`00013oo@;m00?o0000ool0oooo0?l03Ooo0?l00ol0003oo`3oool0o`02ool0o`Go
00004_oo0?l00ol0003o003oo`00o`1Ko`00oako6^DJ8_l00?l1ooooo`00A?l00?l00ol0003oo`3o
ool0o`07ool0o`03o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7n
ooh1oP07ooh1oP03o`000?ol0ocoo0?l00[oo0?l00?o0000ooP7n?oh1oP00ooh1oP00ol0003oo0?l
oo`3o003oo`3o003o`000?oh1oSon0Oh013on0Oh4_l00004ood2o@;o00003Oom0_d00ol0003oo`3o
ool0o`0?ool0o`Co00001?oo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?l00?oo003o05_o003o
7_lJiAXRo`00o`7ooooo0015o`00o`;o00001Ooo0?l2o`0000_oo`3o00?o0000ool0oooo0?l03Ooo
0?l00ol0003ooP7nooh1oP08ooh1oP;o00002ool0o`00ol0003on0OhooP7n002o`0000Ooo0?l00?o
0000ooP7n?oh1oP03ooh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00Coo@;m00?o
0000ood2oOom0_d02_om0_d00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Koo`3o00?o
0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Lo`00oako6^DJ8_l00?l1ooooo`00Aol00?l0
1Ol0003oo`3oool0oooo0?oo000000koo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1
oP0;ooh1oPKo00001?ol0o`4o`0000[oo0?l00?o0000ooP7n?oh1oP03_oh1oP00ol0003onPGjooX5
nP0>ooX5nP03o`000?om0_goo@;m00Goo@;m0_l0000:ood2o@03o`000?oo0?ooo`3o00koo`3o00?o
0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?l00?oo003o05go003o7_lJ
iAXRo`00o`7ooooo0018o`00o`03o`000?oo0?oo0000013oo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003ooP7nooh1oP0;ooh1oP03o`000?on0OkooP7n00?ooP7n1?l00003ooh1oP03o`000?ol0oco
o0?l00Woo0?l00?o0000ooP7n?oh1oP03?oh1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_go
o@;m00Soo@;m0_l00008ood2o@03o`000?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02_oo0?l0
0ol0003oo`3oool0o`0;ool0o`03o`000?l00?oo003o05go003o7_lDja@Ro`00o`7ooooo0019o`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003ooP7nooh1oP0;ooh1
oP03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on0Oh00_on0Oh00ol0003oo0?loo`3o009oo`3
o003o`000?oh1oSon0Oh00_on0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@0:ood2
o@03o`000?om0_goo@;m00Goo@;m00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0o`0<ool0
o`03o`000?oo0?ooo`3o00Soo`3o0_l0001Po`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003o
o`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ooh1o_on0Oh02_on0Oh00ol0003o
oP7nooh1oP08ooh1oP03o`000?on0OkooP7n00;ooP7n00?o0000oo`3o?ol0o`02_ol0o`00ol0003o
n0OhooP7n00:ooP7n003o`000?oj1O[onPGj00konPGj00?o0000ood2oOom0_d02oom0_d2o`0000Go
o@;m00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o00Co
o`3o0ol0001Ro`00oako5>/D8_l00?l1ooooo`00BOl00?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00Koo`3o00?o0000ooh1o_on0Oh02oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`00
0?on0OkooP7n00?ooP7n00?o0000oo`3o?ol0o`02ool0o`00ol0003on0OhooP7n009ooP7n003o`00
0?oj1O[onPGj00konPGj00?o0000ood2oOom0_d03Oom0_d01Ol0003oo@;mood2oOom0_go000000ko
o`3o00?o0000ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`03o`0006Go003o7_lDja@Ro`00o`7o
oooo0019o`00o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7n
ooh1oP0:ooh1oP03o`000?on0OkooP7n00SooP7n00?o0000ooh1o_on0Oh01?on0Oh00ol0003oo0?l
oo`3o00;oo`3o003o`000?oh1oSon0Oh00Oon0Oh00?o0000ooX5n_oj1OX03ooj1OX00ol0003oo@;m
ood2o@0=ood2o@Go00003Ooo0?l00ol0003oo`3oool0o`0Aool0o`;o0000J?l00?lNoaC[52;o003o
0Oooool004Wo003o00?o0000ool0oooo0?l04ooo0?l7o`0000gooP7n00?o0000ooh1o_on0Oh02?on
0Oh00ol0003ooP7nooh1oP04ooh1oP03o`000?ol0ocoo0?l00coo0?l00?o0000ooP7n?oh1oP01_oh
1oP00ol0003onPGjooX5nP0>ooX5nP03o`000?om0_goo@;m00coo@;m0_l00004ool0o`03o`000?oo
0?ooo`3o00[oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003o003oo`00o`1Wo`00oako5>/D8_l0
0?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo0?ooo`3o00?oo`3o00?o0000
ooh1o_on0Oh02_on0Oh00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n00KooP7n00?o0000
oo`3o?ol0o`03?ol0o`00ol0003on0OhooP7n005ooP7n003o`000?oj1O[onPGj00konPGj00?o0000
ood2oOom0_d02_om0_d2o`0000Koo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0C
ool0o`03o`000?l00?oo003o06Oo003o7_l?l0lRo`00o`7ooooo001:o`00o`03o`000?oo0?ooo`3o
017oo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003ooP7nooh1oP08ooh1oP03o`000?on0OkooP7n
00WooP7n00?o0000ooh1o_on0Oh01_on0Oh00ol0003oo0?loo`3o00=oo`3o003o`000?oh1oSon0Oh
00Con0Oh00?o0000ooX5n_oj1OX03_oj1OX00ol0003oo@;mood2o@08ood2o@;o00002Ooo0?l;o`00
01Koo`3o00?o0000o`00ool00?l0Iol00?lNo`o`3b;o003o0Oooool004[o003o00?o0000ool0oooo
0?l04?oo0?l00ol0003oo`3oool0o`07ool0o`03o`000?on0OkooP7n00OooP7n00?o0000ooh1o_on
0Oh02Oon0Oh00ol0003ooP7nooh1oP07ooh1oP03o`000?ol0ocoo0?l00goo0?l00?o0000ooP7n?oh
1oP00_oh1oP00ol0003onPGjooX5nP0?ooX5nP03o`000?om0_goo@;m00Koo@;m0_l0000;ool0o`03
o`000?oo0?ooo`3o00Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003o003oo`00o`1Xo`00oako
3o0?8_l00?l1ooooo`00B_l00?l00ol0003oo`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00Soo`3o
00?o0000ooh1o_on0Oh01_on0Oh00ol0003ooP7nooh1oP09ooh1oP03o`000?on0OkooP7n00SooP7n
00?o0000oo`3o?ol0o`03_ol0o`01?l0003on0OhooP7n?oh1oP4o`0000konPGj00?o0000ood2oOom
0_d01?om0_d2o`0000coo`3o00?o0000ool0oooo0?l02Ooo0?l00ol0003oo`3oool0o`0Bool0o`03
o`000?l00?oo003o06So003o7_l?l0lRo`00o`7ooooo001;o`00o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003ooP7nooh1oP04ooh1oP03o`000?on0OkooP7n00[ooP7n
00?o0000ooh1o_on0Oh02?on0Oh00ol0003oo0?loo`3o00?oo`3o003o`000?oh1oSo000000CooP7n
1_l00007ooX5nP03o`000?om0_goo@;m00?oo@;m0_l0000>ool0o`03o`000?oo0?ooo`3o00[oo`3o
00?o0000ool0oooo0?l04?oo0?l2o`0006[o003o7_l?l0lRo`00o`7ooooo001<o`00o`03o`000?oo
0?ooo`3o00coo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003ooP7nooh1oP03ooh1oP03o`000?on
0OkooP7n00[ooP7n00?o0000ooh1o_on0Oh02Oon0Oh3o`0000ooo0?l00?o0000ooh1o_on0Oh02Oon
0Oh5o`0000;onPGj00Co0000ood2oOom0_goo@;m0_l0000@ool0o`03o`000?oo0?ooo`3o00_oo`3o
00?o0000ool0oooo0?l03_oo0?l00ol0003o003oo`00o`1Zo`00oako3o0?8_l00?l1ooooo`00COl0
0?l00ol0003oo`3oool0o`0:ool0o`03o`000?oo0?ooo`3o00goo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00[ooP7n00?o0000ool0oooo0?l00ol0000<oo`3o003o`00
0?on0OkooP7n00kooP7n0ol000000oom0_go0000o`00000Aool0o`03o`000?oo0?ooo`3o00goo`3o
00?o0000ool0oooo0?l03?oo0?l00ol0003o003oo`00o`1[o`00oako2_D:8_l00?l1ooooo`00C_l0
0?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?ooo`3o00koo`3o00Go0000ooh1o_on0OkooP7n
o`00000<ooh1oP03o`000?on0OkooP7n00WooP7n00?o0000ool0oooo0?l01?oo0?l3o`0000Soo0?l
00?o0000ooh1o_on0Oh04_on0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00koo`3o
00?o0000ool0oooo0?l02_oo0?l00ol0003o003oo`00o`1/o`00oako2_D:8_l00?l1ooooo`00Col0
0?l00ol0003oo`3oool0o`04ool0o`Co00004Ooo0?l00ol0003ooP7no`00000=ooh1oP03o`000?on
0OkooP7n00WooP7n00?o0000ool0oooo0?l01ooo0?l3o`0000Coo0?l00?o0000ooh1o_on0Oh04oon
0Oh00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000ool0oooo0?l02?oo
0?l00ol0003o003oo`00o`1]o`00oako2_D:8_l00?l1ooooo`00D?l00?l00ol0003oo`3oool0o`03
o`0000Coo`3o0_l0000@ool0o`03o`000?on0OkooP7n00_ooP7n00?o0000ooh1o_on0Oh02Oon0Oh0
0ol0003oo`3oool0o`0;ool0o`?o000000?oo0?lo`000?on0Oh05?on0Oh00ol0003oo`3oool0o`0@
ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l01ooo0?l00ol0003o003oo`00o`1^
o`00oako2_D:8_l00?l1ooooo`00DOl00?l2o`0000Woo`3o0_l0000>ool0o`03o`000?on0OkooP7n
00SooP7n1?l0000;ooh1oP03o`000?oo0?ooo`3o00koo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0
003oo`3oool0o`0>ool0o`;o00004ooo0?l00ol0003oo`3oool0o`05ool0o`03o`000?l00?oo003o
06oo003o7_l:m@XRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00[oo`3o0_l0000<ool0o`04
o`000?on0OkooP7nooh1oPOo00001?oo0?l00ol0003ooP7nooh1oP07ooh1oP03o`000?oo0?ooo`3o
00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`0<ool0o`;o000000?oo`3oo`00
0?oo0?l04ooo0?l00ol0003oo`3oool0o`03ool0o`03o`000?l00?oo003o073o003o7_l:m@XRo`00
o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o00coo`3o0_l0000:ool0o`Co00003?oo0?l00ol0003o
oP7nooh1oP06ooh1oP03o`000?oo0?ooo`3o00ooo`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003o
o`3oool0o`0:ool0o`;o00001?oo0?l00ol0003oo`3oool0o`0Bool0o`05o`000?oo0?ooo`3oool0
ool00000Lol00?lNo`Gj1B;o003o0Oooool0057o003o00?o0000ool0oooo0?l03_oo0?l2o`0000So
o`3o00?o0000ool0oooo0?l03_oo0?l00ol0003ooP7nooh1oP05ooh1oP03o`000?oo0?ooo`3o00oo
o`3o00?o0000ooh1o_on0Oh05Oon0Oh00ol0003oo`3oool0o`07ool0o`?o00001ooo0?l00ol0003o
o`3oool0o`0Bool0o`03o`000?oo0?oo000007Co003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`00
0?oo0?ooo`3o013oo`3o0_l00005ool0o`03o`000?oo0?ooo`3o013oo`3o00?o0000ooh1o_on0Oh0
0oon0Oh00ol0003oo`3oool0o`0@ool0o`03o`000?on0OkooP7n01KooP7n00?o0000ool0oooo0?l0
1?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l2o`0007Go003o7_l5nPDRo`00o`7ooooo
001Ao`00o`03o`000?oo0?ooo`3o01;oo`3o0_l00002ool0o`;o00004ooo0?l00ol0003ooP7nooh1
oP02ooh1oP03o`000?oo0?ooo`3o013oo`3o6_l00004ool0o`;o00003Ooo0?l00ol0003oo`3oool0
o`0@ool0o`03o`000?l00?oo003o07Go003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?oo
o`3o01?oo`3o0ol000000ooo0?oo0000ool0o`0Cool0o`04o`000?on0OkooP7no`0001?oo`3o00?o
0000ool0oooo0?l05ooo0?l01?l0003oo`3oo`000?l0000@ool0o`03o`000?oo0?ooo`3o00goo`3o
0_l0001ho`00oako1OX58_l00?l1ooooo`00DOl00?l00ol0003oo`3oool0o`0Bool0o`03o`000?oo
0?ooo`3o00?oo`3o00?o0000ool0oooo0?l04_oo0?l00ol0003ooP7no`00000Cool0o`03o`000?oo
0?ooo`3o01Soo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?l0
0?oo003o07So003o7_l5nPDRo`00o`7ooooo001Ao`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l01?oo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o017oo`3o00?o0000
ool0oooo0?l06Ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000
o`00ool00?l0NOl00?lNo`3o02;o003o0Oooool005;o003o00?o0000ool0oooo0?l03ooo0?l00ol0
003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l03?oo0?l6o`00
01[oo`3o0_l0000Dool0o`03o`000?oo0?ooo`3o00Ooo`3o0_l0001lo`00oako0?l08_l00?l1oooo
o`00Dol00?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo
0?l04_oo0?l00ol0003oo`3oool0o`02ool0o`Wo00001Ooo0?l00ol0003oo`3oool0o`0Gool0o`03
o`000?oo0?oo000001Goo`3o00?o0000ool0oooo0?l01Ooo0?l00ol0003o003oo`00o`1lo`00oako
0?l08_l00?l1ooooo`00E?l00?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo0?ooo`3o00Woo`3o
00?o0000ool0oooo0?l04_oo0?l5o`0000ooo`3o00?o0000ool0oooo0?l05?oo0?l2o`0000?oo`3o
00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oool0o`02ool0o`;o0000Ool00?lNo`3o02;o003o
0Oooool005Co003o00?o0000ool0oooo0?l02_oo0?l00ol0003oo`3oool0o`0;ool0o`03o`000?oo
0?ooo`3o017oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo
0?ooo`3o00Coo`3o00?o0000ool0oooo0?l04_oo0?l01Ol0003oo`3oool0oooo0?oo0000087o003o
7_l0o`0Ro`00o`7ooooo001Eo`00o`03o`000?oo0?ooo`3o00Soo`3o00?o0000ool0oooo0?l03?oo
0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo
0?l2o`0000Ooo`3o00?o0000ool0oooo0?l04ooo0?l00ol0003oo`3oo`000022o`00oako0?l08_l0
0?l1ooooo`00E_l00?l00ol0003oo`3oool0o`06ool0o`03o`000?oo0?ooo`3o00koo`3o00?o0000
ool0oooo0?l03ooo0?l00ol0003oo`3oool0o`0Cool0o`03o`000?oo0?ooo`3o00ooo`3o00?o0000
ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0Bool0o`;o0000`ol00?l1ooooo`00Eol00?l2o`00
00Goo`3o00?o0000ool0oooo0?l04?oo0?l00ol0003oo`3oool0o`0=ool0o`03o`000?oo0?ooo`3o
01Goo`3o00?o0000ool0oooo0?l03?oo0?l2o`0000_oo`3o00?o0000ool0oooo0?l04Ooo0?l00ol0
003o003oo`00o`33o`00o`7ooooo001Io`00o`?o000000?oo`3oo`000?oo0?l04_oo0?l00ol0003o
o`3oool0o`0=ool0o`03o`000?oo0?ooo`3o01Goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003o
o`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00koo`3o0_l00036o`00o`7ooooo001Lo`00o`03o`00
0?oo0?ooo`3o01?oo`3o3ol0000Hool0o`?o00002Ooo0?l2o`00013oo`3o00?o0000ool0oooo0?l0
3?oo0?l00ol0003o003oo`00o`36o`00o`7ooooo001Lo`00o`03o`000?oo0?ooo`3o01?oo`3o00?o
0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Eool0o`05o`000?oo0?ooo`3oool0ool00000
1ooo0?l00ol0003oo`3oool0o`0@ool0o`03o`000?oo0?ooo`3o00[oo`3o0_l00039o`00o`7ooooo
001Mo`00o`03o`000?oo0?ooo`3o017oo`3o00?o0000ool0oooo0?l03?oo0?l00ol0003oo`3oool0
o`0Dool0o`03o`000?oo0?ooo`3o00?oo`3o0_l00003ool0o`;o00005?oo0?l00ol0003oo`3oool0
o`08ool0o`03o`000?l00?oo003o0<Wo003o0Oooool005go003o00?o0000ool0oooo0?l04?oo0?l0
0ol0003oo`3oool0o`0>ool0o`03o`000?oo0?ooo`3o01;oo`3o00?o0000ool0oooo0?l01_oo0?l0
0ol0003oo`3oo`00000Fool0o`03o`000?oo0?ooo`3o00Koo`3o0_l0003<o`00o`7ooooo001Mo`00
o`03o`000?oo0?ooo`3o013oo`3o00?o0000ool0oooo0?l03_oo0?l00ol0003oo`3oool0o`0@ool0
o`;o00002_oo0?l00ol0003oo`3oool0o`0Fool0o`03o`000?oo0?ooo`3o00Coo`3o00?o0000o`00
ool00?l0c?l00?l1ooooo`00G_l00?l2o`0000ooo`3o00?o0000ool0oooo0?l03ooo0?l00ol0003o
o`3oool0o`0?ool0o`03o`000?oo0?ooo`3o00[oo`3o00?o0000ool0oooo0?l05ooo0?l6o`000<oo
003o0Oooool0063o003o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Aool0o`03o`00
0?oo0?ooo`3o00goo`3o00?o0000ool0oooo0?l02ooo0?l00ol0003oo`3oool0o`0Gool0o`03o`00
0?l00?oo003o09go003o2Oooo`0/o`00o`7ooooo001Qo`00o`03o`000?oo0?ooo`3o00[oo`3o00?o
0000ool0oooo0?l04Ooo0?l00ol0003oo`3oool0o`0<ool0o`03o`000?oo0?ooo`3o00goo`3o00?o
0000ool0oooo0?l05Ooo0?l00ol0003o003oo`00o`2Oo`00o`03ob4QgOnHV6Koool000;oool000?o
EEFYo`00ool00?l0;?l00?l1ooooo`00H_l00?l00ol0003oo`3oool0o`08ool0o`03o`000?oo0?oo
o`3o01;oo`3o00?o0000ool0oooo0?l02_oo0?l2o`00013oo`3o00?o0000ool0oooo0?l05?oo0?l0
0ol0003o003oo`00o`2Ro`00o`?oool0;ol00?l1ooooo`00Hol00?l00ol0003oo`3oool0o`07ool0
o`03o`000?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l02?oo0?l00ol0003oo`3oool0o`0@ool0
o`03o`000?oo0?ooo`3o01Coo`3o00?o0000o`00ool00?l0X_l00?l3oooo02oo003o0Oooool006Co
003o00?o0000ool0oooo0?l01Ooo0?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o00Oo
o`3o00?o0000ool0oooo0?l04_oo0?l00ol0003oo`3oool0o`0Bool0o`03o`000?l00?oo003o0:?o
003o0oooo`0_o`00o`7ooooo001Uo`00o`Oo00005ooo0?l00ol0003oo`3oool0o`06ool0o`03o`00
0?oo0?ooo`3o01?oo`3o00?o0000ool0oooo0?l04?oo0?l2o`000:Ko003o0oooo`0_o`00o`7ooooo
001[o`00o`03o`000?oo0?ooo`3o01Koo`3o00?o0000ool0oooo0?l00ooo0?l2o`0001Koo`3o00?o
0000ool0oooo0?l03_oo0?l2o`000:So003o0oooo`0_o`00o`7ooooo001/o`00o`03o`000?oo0?oo
o`3o01Goo`3o00?o0000ool0oooo0?l00_oo0?l00ol0003oo`3oool0o`0Gool0o`03o`000?oo0?oo
o`3o00_oo`3o0_l0002Zo`00o`?oool0;ol00?l1ooooo`00KOl00?l00ol0003oo`3oool0o`0Dool0
o`05o`000?oo0?ooo`3oool0ool000006_oo0?l7o`0000Goo`3o0_l0002/o`00o`?oool0;ol00?l1
ooooo`00K_l00?l00ol0003oo`3oool0o`0Dool0o`03o`000?oo0?oo000001_oo`3o00?o0000o`00
ool00?l01?l00?l5o`000:ko003o0oooo`0_o`00o`7ooooo001_o`00o`03o`000?oo0?ooo`3o017o
o`3o1Ol0000Jool0o`;o0000^Ol00?l3oooo02oo003o0Oooool0073o003o0_l0000>ool0o`?o0000
1Ol00?l2o`0001Ooo`3o00?o0000o`00ool00?l0^Ol00?l3oooo02oo003o0Oooool007;o003o0ol0
0008ool0o`?o00002_l00?l00ol0003oo`3oool0o`0Bool0o`;o0000_?l00?l3oooo02oo003o0Ooo
ool007Go003o0ol00002ool0o`?o00003_l00?l2o`00017oo`3o00?o0000o`00ool00?l0_?l00?l3
oooo02oo003o0Oooool007So003o0_l0000Co`00o`;o00003_oo0?l00ol0003o003oo`00o`2mo`00
o`?oool0;ol00?l1ooooo`00Sol00?l00ol0003oo`3oool0o`09ool0o`;o0000`?l00?l3oooo02oo
003o0Oooool0093o003o0_l00008ool0o`03o`000?l00?oo003o0<3o003o0oooo`0_o`00o`7ooooo
002Bo`00o`So0000`?l00?l00oo<c3;oIVJHogMgQ`03oooo02oo003o0Oooool00?oo003oFol00?l0
0om4A;[oc<`boooo0003oooo02oo003o0Oooool00?oo003oGOl00?l01?m4A;[ok^h@oooo0?ooo`0_
o`00o`7ooooo003oo`00oeoo003o00?oIVJHonk^4?l00?l0;_l00?l1ooooo`00ool00?n@o`00o`7o
oooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00
oi3o003o0Oooool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Ooo
ool00?oo003oT?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003o
T?l00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool00?oo003oT?l00?l1oooo
o`00]_l00?l7oooo03;o003o1oooo`2Io`00o`7ooooo002fo`00o`;oool000?oMgN7o`00ool00?l0
>?l00?l00omgMhOoool0oooo002Io`00o`7ooooo002fo`00o`;oool0??l00?l2oooo09Wo003o0Ooo
ool00;Ko003o0_ooo`0lo`00o`;oool0VOl00?l1ooooo`00]_l00?l2oooo03co003o0_ooo`2Io`00
o`7ooooo002Mo`00o`03oc8bc?ooo`3o8B7M00Oo003o00?o<S;<oooo0?lQ8Md03?l00?l2oooo00Ko
003o00?o<S;<okZjA?ooo`000oooo`001?o<c3;oZJUEofIVV?l@4>h;o`00o`07ogMgQooMgB7oool0
oooo0?oMgB7oQhMgoa0@kP09o`00o`07ogMgQooMgB7oool0oooo0?oMgB7oQhMgoa0@kP0:o`00o`;o
ool0VOl00?l1ooooo`00WOl00?l00onHV6Koool0ogMgQ`07o`00o`03oiRHI_ooo`3oMgN700co003o
0_ooo`06o`00o`?oool000SogMdQoeEEZOl00?oo003ooc8bc?n7QgOoool0ohN7M`So003o00[o413^
omgM8Oooo`3oMgN7oa0@k_l00?ooEEFYoooo0?oMgB7o413^1_l00?l02_l@4>kogMdQoooo0?mgMhOo
413^o`00oomEEJWoool0omgM8Ol@4>h9o`00o`;oool0VOl00?l1ooooo`00WOl00?l00oo^kQ3oool0
omgM8@07o`00o`03onk^4?ooo`3ogMdQ00co003o0_ooo`06o`00o`03omgM8Oo^kQ3oMgN700Ko003o
00CoIVJHoooo0?nj^TCo413^1_l00?l00ooMgB7oool0ogMgQ`04o`00o`03odA4^_ooo`3ogMdQ00Ko
003o00?ogMdQoooo0?mgMhL01?l00?l00om4A;[oool0omgM8@09o`00o`;oool0VOl00?l1ooooo`00
W?l00?l01Olb</coool0oooo0?ooo`3o413^00Go003o00Go<S;<oooo0?ooo`3oool0ob4Qg@0;o`00
o`;oool04?l00?l00onYZEGoool0okZjA005o`00o`03ohN7Moooo`3oool000Ko003o00?ogMdQoooo
0?mVIYP01?l00?l00on7QgOoool0oooo0006o`00o`03omgM8Oooo`3oIVJH00So003o0_ooo`2Io`00
o`7ooooo002Lo`00o`05ojVYEOooo`3oool0oooo0?mVIYP01Ol00?l01OnHV6Koool0oooo0?ooo`3o
MgN700_o003o0_ooo`0@o`00o`04oc8bc?ooo`3oool0ofIVV0Co003o0_ooo`000onHV6Ko003oo`00
o`04o`00o`03ohN7Moooo`3ok^h@00Co003o0_ooo`000onHV6Ko003oo`00o`04o`00o`03ohN7Mooo
o`3ok^h@00So003o0_ooo`2Io`00o`7ooooo002Lo`00o`?oool000?oIVJHokZjA?l00?l01?l00?l0
1Oo^kQ3oool0oooo0?mVIYSogMdQ00_o003o0_ooo`0Ao`00o`;oool000Goc<`bo`00ool00?oo003o
oeEEZ@02oooo0003ofIVV?l00?oo003o00Co003o00CoEEFYoooo0?ooo`3o<S;<0_l00?l01?mEEJWo
ool0oooo0?mVIYP6o`00o`04oeEEZOooo`3oool0oc8bc0Oo003o0_ooo`2Io`00o`7ooooo002Ko`00
o`07oeEEZOooo`3oool0onk^4?l00?ook^h@oa0@kP03o`00o`07oeEEZOooo`3oool0onk^4?l00?oo
k^h@ob4Qg@0:o`00o`;oool04Ol00?l3oooo00?o003o00CoV9QVoooo0?ooo`3oA4Bj1_l00?l01?m4
A;[oool0oooo0?n7QgL2o`00o`04oiRHI_ooo`3oool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oQhMg
1ol00?l2oooo09Wo003o0Oooool009_o003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoIVJH00?o
003o00OoZJUEoooo0?ooo`3oV9QVo`00oonHV6KoMgN700[o003o0_ooo`0@o`00o`04oeEEZOooo`3o
ool0oooo00?o003o00Coc<`boooo0?ooo`3o413^1ol00?l2oooo0004olc<<_l00?oo003oolc<<P;o
ool000?o413^o`00ool00?l01Ol00?l2oooo0003olc<<_l00?oo003o00Go003o0_ooo`2Io`00o`7o
oooo002Ko`00o`?oool000Co8B7Mo`00oom4A;[o^[Y40ol00?l3oooo0004oc8bc?l00?ooA4BjomgM
8@[o003o0_ooo`0@o`00o`04omgM8Oooo`3oool0omgM8@?o003o0oooo`08o`00o`;oool000?ok^h@
o`00ool00?l00oooo`08o`00o`;oool000?ok^h@o`00ool00?l01Ol00?l2oooo09Wo003o0Oooool0
09[o003o00CoEEFYoooo0?ooo`3ogMdQ0ol00?l01?ooo`3o003oo`00oomEEJT2oooo0006onk^4?l0
0?oo003oo`00ooooo`3o8B7M2Ol00?l2oooo00ko003o00?o413^okZjA?ooo`000_ooo`001?mVIYSo
003oo`00ool00?l3oooo00So003o0oooo`02o`00o`?oool02?l00?l3oooo00Oo003o0_ooo`2Io`00
o`7ooooo002Jo`00o`04ojVYEOooo`3oool0ogMgQ`?o003o00CoZJUEoeEEZOl00?ooZJUE0_ooo`00
1_nHV6Ko003oo`00ool00?ooZJUEogMgQ`Wo003o0_ooo`0;o`00o`03oa0@k_m4A;[oV9QV00Coool0
00?oZJUEo`00ool00?l00_l00?l3oooo00So003o0oooo`02o`00o`?oool02?l00?l3oooo00Oo003o
0_ooo`2Io`00o`7ooooo002Jo`00o`?oool000Oo8B7Mo`00ool00?oo003ooeEEZOnYZEGo003o00?o
ool000Ko<S;<o`00ool00?oo003ooeEEZOoMgB49o`00o`;oool02Ol00?l00onYZEGoool0oooo0005
oooo0003ohN7Mol00?oo003o00?o003o0oooo`08o`00o`?oool00_l00?l3oooo00So003o0oooo`07
o`00o`;oool0VOl00?l1ooooo`00VOl00?l01?mEEJWoool0oooo0?oMgB45o`00o`05onk^4?mEEJWo
ool0oooo0?o^kQ001Ol00?l00oooo`3o8B7Mo`00o`07o`00o`;oool02ol00?l01_lb</coV9QVoooo
0?ooo`3ogMdQoa0@kPKo003o0oooo`08o`00o`?oool00_l00?l3oooo00So003o0oooo`07o`00o`;o
ool0VOl00?l1ooooo`00VOl00?l01?nYZEGoool0oooo0?mgMhL5o`00o`05okZjA?o^kQ3oool0oooo
0?n7QgL01Ol00?l00onYZEGoMgN7o`00o`07o`00o`;oool03Ol00?l01Ol@4>koQhMgoooo0?oMgB7o
8B7M00Go003o00Coc<`boooo0?ooo`3o<S;<1_l00?l01?lQ8Mgoool0oooo0?o<c382o`00o`04olc<
<_ooo`3oool0oc8bc0Ko003o00Co8B7Moooo0?ooo`3oc<`b1ol00?l2oooo09Wo003o0Oooool009So
003o00Go413^oooo0?ooo`3oool0ob4Qg@05o`00o`05ofIVV?ooo`3oool0oooo0?lQ8Md01Ol00?l0
0omEEJWogMdQo`00o`07o`00o`;oool03ol00?l01?n7QgOoool0oooo0?lQ8Md4o`00o`04oiRHI_oo
o`3oool0odA4^PKo003o00CoA4Bjoooo0?ooo`3oV9QV0_l00?l01?nHV6Koool0oooo0?m4A;X6o`00
o`04odA4^_ooo`3oool0oiRHIPOo003o0_ooo`2Io`00o`7ooooo002Ho`00o`04ofIVV?ooo`3oool0
omgM8@Ko003o00CoIVJHoooo0?ooo`3ogMdQ1ol00?l00oooo`3o8B7Mo`00o`06o`00o`;oool03ol0
0?l01?l@4>koool0oooo0?nj^T@4o`00o`04oeEEZOooo`3oool0ogMgQ`Ko003o00CoIVJHoooo0?oo
o`3oEEFY0_l00?l01?mEEJWoool0oooo0?mgMhL6o`00o`04ofIVV?ooo`3oool0oeEEZ@Oo003o0_oo
o`2Io`00o`7ooooo002Ho`00o`04olc<<_ooo`3oool0ogMgQ`Ko003o00Co^[Y4oooo0?ooo`3oMgN7
1ol00?l00onYZEGoMgN7o`00o`06o`00o`;oool01_l00?l00onj^TCo8B7Mo`00o`06o`00o`04oa0@
k_ooo`3oool0oooo00Go003o0_ooo`000onYZEGo003oo`00o`04o`00o`03ojVYEOooo`3ok^h@00Co
003o0_ooo`000onYZEGo003oo`00o`04o`00o`03ojVYEOooo`3ok^h@00So003o0_ooo`2Io`00o`7o
oooo002Go`00o`05ob4QgOooo`3oool0oooo0?lQ8Md01Ol00?l01Ol@4>koool0oooo0?ooo`3o8B7M
00Oo003o00?oEEFYomgM8Ol00?l01_l00?l2oooo00Ko003o00?oA4BjomgM8OlQ8Md01_l00?l01?n7
QgOoool0oooo0?ooo`05o`00o`04ohN7Moooo`3oool0oa0@kPCo003o00Co413^oooo0?ooo`3oIVJH
1?l00?l01?n7QgOoool0oooo0?l@4>h4o`00o`04oa0@k_ooo`3oool0ofIVV0So003o0_ooo`2Io`00
o`7ooooo002Go`00o`04ojVYEOooo`3oool0omgM8@Ko003o00CoMgN7oooo0?ooo`3ogMdQ2Ol00?l0
0oooo`3o8B7Mo`00o`05o`00o`;oool01ol00?l01?nHV6Koool0ohN7MolQ8Md2o`00o`03oeEEZOnj
^TCoool000;oool000?oQhMgo`00ool00?l01?l00?l00ooMgB7oool0ohN7M`04o`00o`03ohN7Mooo
o`3oc<`b00Ko003o00?ogMdQoooo0?n7QgL01?l00?l00on7QgOoool0olc<<P09o`00o`;oool0VOl0
0?l1ooooo`00UOl00?l00olQ8MgoQhMgoooo0002oooo0003onk^4?lb</co003o00?o003o00KoEEFY
oooo0?ooo`3oool0onk^4?lb</`6o`00o`06ob4QgOn7QgOoool0onk^4?mEEJWo413^1?l00?l2oooo
00So003o00?oMgN7oooo0?ooo`001_ooo`000onj^TCo003oo`00o`05o`00o`04oa0@k_oMgB7oool0
ogMgQ`;o413^00CoMgN7oooo0?oMgB7o413^1_l00?l01?l@4>kogMdQoooo0?mgMhL2oa0@kP04ogMg
Qoooo`3ogMdQoa0@kPWo003o0_ooo`2Io`00o`7ooooo002Do`00o`03odA4^_ooo`3oool000Ooool0
00?oQhMgoooo0?ooo`001oooo`02o`00o`03ohN7Moooo`3oool000Goool000CoA4Bjo`00ool00?oo
003o0_ooo`000omgMhOo003oo`00o`06o`00o`03ob4QgOnHV6KogMdQ00?oool000?o^[Y4ofIVV?l0
0?l02?l00?l00ol@4>koQhMgomgM8@02oooo0003omgM8On7QgOo003o00So003o00?o413^ohN7MooM
gB400_ooo`000ooMgB7oQhMgo`00o`09o`00o`03ogMgQoooo`3oool009Wo003o0Oooool00;Ko003o
1oooo`0bo`00o`Ooool0VOl00?l1ooooo`00ool00?n@o`00o`7ooooo003oo`00oi3o003o0Oooool0
0?oo003oT?l00?l1ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {411.75, 0}} -> {24.4716, 21.3242, 0.266463, \
0.266463}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 874}},
WindowSize->{762, 899},
WindowMargins->{{Automatic, 232}, {104, Automatic}},
ShowSelection->True,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style. Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0.771908, 0.399634, 0.262867]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    CellBracketOptions->{"Color"->RGBColor[0.771908, 0.399634, 0.262867]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.771908, 0.399634, 0.262867]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "ColorPrintout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Presentation"],
    FontSize->18]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{36, 20}, {2, 10}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{100, 4}, {8, 10}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    TextAlignment->Left,
    LineSpacing->{1, 17},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->60,
    FontSlant->"Italic",
    FontColor->RGBColor[0.620523, 0.66688, 0.409964]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{56, 20}, {8, 18}},
    FontSize->90],
  
  Cell[StyleData["Title", "Printout"],
    FontSize->48,
    FontColor->GrayLevel[0.4]],
  
  Cell[StyleData["Title", "ColorPrintout"],
    FontSize->48]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellFrame->{{0, 0}, {3, 3}},
    CellMargins->{{36, 20}, {2, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.500008, 0, 0.500008],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.700008, 0.700008, 1],
    FontVariations->{"Shadow"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{220, 20}, {2, 16}},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    FontSize->18,
    FontColor->GrayLevel[0.300008]],
  
  Cell[StyleData["Subtitle", "ColorPrintout"],
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{37, 20}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{220, 20}, {4, 4}},
    FontSize->21],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "ColorPrintout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{36, 20}, {10, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{10, 4}, {6, 2}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{56, 20}, {16, 26}},
    FontSize->21],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14,
    FontColor->GrayLevel[0.300008]],
  
  Cell[StyleData["Section", "ColorPrintout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[GraySquare]",
    CellMargins->{{53, 20}, {Inherited, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{2, 12}, {0, 12}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0.749996, 0, 0.749996],
    Background->RGBColor[0.749996, 1, 0.749996]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{56, 20}, {10, 28}},
    FontSize->18],
  
  Cell[StyleData["Subsection", "Printout"]],
  
  Cell[StyleData["Subsection", "ColorPrintout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{51, Inherited}, {Inherited, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubsection",
    FontFamily->"Arial",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.228321, 0.223514, 0.570138],
    Background->RGBColor[1, 0.874372, 0.698604],
    FontVariations->{"Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{56, 20}, {6, 14}},
    FontSize->15],
  
  Cell[StyleData["Subsubsection", "Printout"]],
  
  Cell[StyleData["Subsubsection", "ColorPrintout"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->False,
    CellMargins->{{36, 20}, {4, 4}},
    CellFrameMargins->{{4, 10}, {6, 0}},
    CellFrameLabelMargins->4,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 6},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{56, 20}, {8, 6}},
    FontSize->18],
  
  Cell[StyleData["Text", "Printout"],
    Hyphenation->True,
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["Text", "ColorPrintout"],
    Hyphenation->True,
    LineSpacing->{1, 5},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{100, 38}, {4, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1.25, 1},
    CounterIncrements->"SmallText",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{152, 38}, {6, 6}},
    FontSize->15],
  
  Cell[StyleData["SmallText", "Printout"],
    Hyphenation->True,
    FontSize->9],
  
  Cell[StyleData["SmallText", "ColorPrintout"],
    Hyphenation->True,
    FontSize->9]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->True,
    CellMargins->{{36, 0}, {0, Inherited}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.840558, 0.58323, 0.941176]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{56, 0}, {0, 8}},
    CellFrameMargins->{{10, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Input", "Printout"],
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Input", "ColorPrintout"],
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInput", "Presentation"],
    CellMargins->{{10, 4}, {6, 6}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{36, 0}, {Inherited, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.711162, 0.834546, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{56, 0}, {8, 0}},
    CellFrameMargins->{{12, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]],
  
  Cell[StyleData["Output", "ColorPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{64, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique"],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{96, 10}, {8, 6}},
    FontSize->15],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Message", "ColorPrintout"],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{36, 20}, {3, 3}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{56, 20}, {2, 2}},
    CellFrameMargins->{{10, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Print", "ColorPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{36, 0}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    Background->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{56, 20}, {0, 2}},
    CellFrameMargins->{{10, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]],
  
  Cell[StyleData["Graphics", "ColorPrintout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.551492, 0.231144, 0.313466]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "ColorPrintout"],
    FontSize->8]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {10, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {5, 10}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 43, 0, 64, "Subtitle"],
Cell[1822, 55, 713, 10, 228, "Text"],
Cell[2538, 67, 201, 6, 88, "Text"],

Cell[CellGroupData[{
Cell[2764, 77, 37, 0, 56, "Subsection"],
Cell[2804, 79, 1377, 18, 308, "Text"],
Cell[4184, 99, 26604, 515, 10288, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[30825, 619, 46, 0, 48, "Section"],

Cell[CellGroupData[{
Cell[30896, 623, 97, 2, 43, "Input"],
Cell[30996, 627, 151, 2, 39, "Print"],
Cell[31150, 631, 153, 2, 39, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31340, 638, 44, 1, 27, "Input"],
Cell[31387, 641, 170, 2, 39, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31594, 648, 47, 1, 27, "Input"],
Cell[31644, 651, 151, 2, 39, "Print"],
Cell[31798, 655, 170, 2, 39, "Print"],
Cell[31971, 659, 273, 5, 23, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32293, 670, 114, 3, 77, "Section"],
Cell[32410, 675, 454, 8, 91, "Input"],
Cell[32867, 685, 69, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[32961, 690, 43, 1, 27, "Input"],
Cell[33007, 693, 37, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33081, 699, 485, 8, 91, "Input"],
Cell[33569, 709, 60516, 1236, 408, 9517, 603, "GraphicsData", "PostScript", \
"Graphics"],
Cell[94088, 1947, 130, 3, 27, "Output"]
}, Open  ]],
Cell[94233, 1953, 1199, 21, 267, "Input"],

Cell[CellGroupData[{
Cell[95457, 1978, 84, 1, 27, "Input"],
Cell[95544, 1981, 7545, 116, 747, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[103138, 2103, 41, 0, 48, "Section"],

Cell[CellGroupData[{
Cell[103204, 2107, 55, 1, 35, "Input"],
Cell[103262, 2110, 37, 1, 47, "Output"]
}, Open  ]],
Cell[103314, 2114, 197, 3, 67, "Input"],

Cell[CellGroupData[{
Cell[103536, 2121, 330, 6, 67, "Input"],
Cell[103869, 2129, 265731, 7585, 700, 70274, 5168, "GraphicsData", \
"PostScript", "Graphics"],
Cell[369603, 9716, 130, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369770, 9724, 304, 6, 67, "Input"],
Cell[370077, 9732, 678587, 20580, 700, 393540, 17057, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1048667, 30314, 130, 3, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1048846, 30323, 49, 0, 48, "Section"],

Cell[CellGroupData[{
Cell[1048920, 30327, 142, 4, 27, "Input"],
Cell[1049065, 30333, 266, 4, 59, "Output"]
}, Open  ]],
Cell[1049346, 30340, 161, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[1049532, 30347, 248, 4, 43, "Input"],
Cell[1049783, 30353, 243623, 7119, 708, 65253, 4913, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1293409, 37474, 130, 3, 27, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1293588, 37483, 55, 0, 48, "Section"],

Cell[CellGroupData[{
Cell[1293668, 37487, 60, 1, 35, "Input"],
Cell[1293731, 37490, 37, 1, 35, "Output"]
}, Open  ]],
Cell[1293783, 37494, 134, 2, 51, "Input"],

Cell[CellGroupData[{
Cell[1293942, 37500, 41, 1, 35, "Input"],
Cell[1293986, 37503, 67, 1, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1294090, 37509, 79, 1, 35, "Input"],
Cell[1294172, 37512, 134, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1294343, 37519, 224, 4, 51, "Input"],
Cell[1294570, 37525, 432, 11, 66, "Output"]
}, Open  ]],
Cell[1295017, 37539, 282, 6, 67, "Input"],
Cell[1295302, 37547, 423, 6, 67, "Input"],
Cell[1295728, 37555, 111, 2, 35, "Input"],
Cell[1295842, 37559, 1589, 25, 291, "Input"],

Cell[CellGroupData[{
Cell[1297456, 37588, 49, 1, 27, "Input"],
Cell[1297508, 37591, 70, 1, 27, "Output"]
}, Open  ]],
Cell[1297593, 37595, 543, 10, 173, "Input"],

Cell[CellGroupData[{
Cell[1298161, 37609, 106, 2, 27, "Input"],
Cell[1298270, 37613, 5846, 85, 427, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1304153, 37703, 58, 1, 27, "Input"],
Cell[1304214, 37706, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1304303, 37712, 48, 1, 27, "Input"],
Cell[1304354, 37715, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1304443, 37721, 46, 1, 27, "Input"],
Cell[1304492, 37724, 37, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1304566, 37730, 77, 1, 27, "Input"],
Cell[1304646, 37733, 9706, 133, 1547, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1314389, 37871, 49, 1, 24, "Input"],
Cell[1314441, 37874, 9026, 126, 1531, "Output"]
}, Closed]],
Cell[1323482, 38003, 35, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[1323542, 38008, 43, 1, 27, "Input"],
Cell[1323588, 38011, 37, 1, 27, "Output"]
}, Open  ]],
Cell[1323640, 38015, 561, 10, 147, "Input"],
Cell[1324204, 38027, 103, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[1324332, 38033, 9425, 172, 1538, "Input"],
Cell[1333760, 38207, 1483, 37, 37, "Print"],
Cell[1335246, 38246, 1479, 37, 37, "Print"],
Cell[1336728, 38285, 68, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1336833, 38291, 139, 4, 51, "Input"],
Cell[1336975, 38297, 107, 2, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337119, 38304, 236, 5, 51, "Input"],
Cell[1337358, 38311, 209, 7, 38, "Output"],
Cell[1337570, 38320, 1897, 46, 195, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1339516, 38372, 50, 0, 48, "Section"],
Cell[1339569, 38374, 26, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[1339620, 38378, 85, 1, 27, "Input"],
Cell[1339708, 38381, 1483, 37, 23, "Print"],
Cell[1341194, 38420, 1479, 37, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1342710, 38462, 200, 3, 59, "Input"],
Cell[1342913, 38467, 175, 3, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1343125, 38475, 62, 1, 27, "Input"],
Cell[1343190, 38478, 6333, 85, 443, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1349560, 38568, 104, 2, 24, "Input"],
Cell[1349667, 38572, 536338, 18855, 349, 233341, 15110, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1886008, 57429, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1886153, 57435, 125, 3, 27, "Input"],
Cell[1886281, 57440, 99, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[1886405, 57447, 168, 3, 59, "Input"],
Cell[1886576, 57452, 44003, 1015, 4059, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1930616, 58472, 411, 7, 72, "Input"],

Cell[CellGroupData[{
Cell[1931052, 58483, 173385, 6357, 318, 68701, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2104440, 64842, 175828, 6360, 318, 70913, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2280271, 71204, 175983, 6362, 318, 70898, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2456257, 77568, 175885, 6361, 318, 70877, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2632145, 83931, 176000, 6362, 318, 70907, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2808148, 90295, 175868, 6360, 318, 70889, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2984019, 96657, 175975, 6362, 318, 70886, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3159997, 103021, 176022, 6363, 318, 70856, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3336022, 109386, 175917, 6362, 318, 70820, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3511942, 115750, 175910, 6362, 318, 70841, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3687855, 122114, 176296, 6366, 318, 70887, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3864154, 128482, 176031, 6362, 318, 70890, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4040188, 134846, 176221, 6365, 318, 70905, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4216412, 141213, 176129, 6364, 318, 70890, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4392544, 147579, 176223, 6365, 318, 70899, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4568770, 153946, 176118, 6363, 318, 70908, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4744891, 160311, 176231, 6365, 318, 70911, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4921125, 166678, 176314, 6366, 318, 70917, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5097442, 173046, 176202, 6365, 318, 70878, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5273647, 179413, 176207, 6364, 318, 70908, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5449857, 185779, 176488, 6368, 318, 70905, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5626348, 192149, 176243, 6365, 318, 70923, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5802594, 198516, 176383, 6367, 318, 70893, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5978980, 204885, 176291, 6366, 318, 70878, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6155274, 211253, 176382, 6367, 318, 70884, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6331659, 217622, 176250, 6365, 318, 70866, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6507912, 223989, 176311, 6367, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6684226, 230358, 176422, 6368, 318, 70851, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6860651, 236728, 176312, 6367, 318, 70818, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7036966, 243097, 176274, 6367, 318, 70800, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7213243, 249466, 176324, 6367, 318, 70818, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7389570, 255835, 176054, 6364, 318, 70815, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7565627, 262201, 176212, 6366, 318, 70803, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7741842, 268569, 176138, 6365, 318, 70806, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7917983, 274936, 176238, 6366, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8094224, 281304, 176133, 6364, 318, 70830, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8270360, 287670, 176210, 6366, 318, 70797, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8446573, 294038, 176284, 6367, 318, 70794, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8622860, 300407, 176263, 6366, 318, 70842, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8799126, 306775, 176214, 6366, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8975343, 313143, 176403, 6368, 318, 70812, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9151749, 319513, 176125, 6365, 318, 70809, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9327877, 325880, 176296, 6367, 318, 70806, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9504176, 332249, 176195, 6366, 318, 70782, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9680374, 338617, 176297, 6367, 318, 70827, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9856674, 344986, 176184, 6365, 318, 70800, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10032861, 351353, 70870, 5063, 318, 70815, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10103734, 356418, 70876, 5063, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10174613, 361483, 70885, 5063, 318, 70830, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10245501, 366548, 70864, 5063, 318, 70809, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10316368, 371613, 70885, 5063, 318, 70830, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10387256, 376678, 70876, 5063, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10458135, 381743, 70882, 5063, 318, 70827, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10529020, 386808, 70894, 5063, 318, 70839, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10599917, 391873, 70906, 5063, 318, 70851, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10670826, 396938, 70885, 5063, 318, 70830, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10741714, 402003, 70900, 5063, 318, 70845, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10812617, 407068, 70903, 5063, 318, 70848, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10883523, 412133, 70891, 5063, 318, 70836, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[10954417, 417198, 70912, 5063, 318, 70857, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11025332, 422263, 70906, 5063, 318, 70851, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11096241, 427328, 176189, 6365, 318, 70869, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11272433, 433695, 70918, 5063, 318, 70863, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11343354, 438760, 176270, 6366, 318, 70857, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11519627, 445128, 176381, 6367, 318, 70863, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11696011, 451497, 70915, 5063, 318, 70860, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11766929, 456562, 70876, 5063, 318, 70821, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[11837808, 461627, 176458, 6368, 318, 70887, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12014269, 467997, 70930, 5063, 318, 70875, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12085202, 473062, 70918, 5063, 318, 70863, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12156123, 478127, 70933, 5063, 318, 70878, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12227059, 483192, 70927, 5063, 318, 70872, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12297989, 488257, 70945, 5063, 318, 70890, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12368937, 493322, 70918, 5063, 318, 70863, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12439858, 498387, 176457, 6368, 318, 70878, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12616318, 504757, 70933, 5063, 318, 70878, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12687254, 509822, 70963, 5063, 318, 70908, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12758220, 514887, 70957, 5063, 318, 70902, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12829180, 519952, 70948, 5063, 318, 70893, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12900131, 525017, 70939, 5063, 318, 70884, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[12971073, 530082, 70942, 5063, 318, 70887, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13042018, 535147, 176217, 6365, 318, 70893, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13218238, 541514, 176406, 6367, 318, 70908, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13394647, 547883, 176313, 6366, 318, 70908, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13570963, 554251, 176445, 6367, 318, 70911, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13747411, 560620, 70975, 5063, 318, 70920, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13818389, 565685, 70975, 5063, 318, 70920, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13889367, 570750, 70972, 5063, 318, 70917, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[13960342, 575815, 70960, 5063, 318, 70905, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14031305, 580880, 70987, 5063, 318, 70932, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14102295, 585945, 70948, 5063, 318, 70893, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14173246, 591010, 176201, 6364, 318, 70902, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14349450, 597376, 70948, 5063, 318, 70893, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14420401, 602441, 70978, 5063, 318, 70923, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14491382, 607506, 71002, 5063, 318, 70947, 5061, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[14562387, 612571, 176296, 6365, 318, 70932, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14738686, 618938, 176385, 6367, 318, 70911, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14915074, 625307, 176450, 6367, 318, 70920, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15091527, 631676, 176398, 6367, 318, 70920, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15267928, 638045, 176351, 6366, 318, 70902, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15444282, 644413, 176822, 6372, 318, 70915, 5061, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15621119, 650788, 12584, 305, 251, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[15633740, 651098, 46, 1, 24, "Input"],
Cell[15633789, 651101, 597072, 12114, 47159, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16230910, 663221, 53, 0, 48, "Section"],

Cell[CellGroupData[{
Cell[16230988, 663225, 1835, 34, 323, "Input"],
Cell[16232826, 663261, 104, 2, 37, "Print"],
Cell[16232933, 663265, 157, 3, 37, "Print"],
Cell[16233093, 663270, 139, 3, 37, "Print"],
Cell[16233235, 663275, 167, 3, 37, "Print"],
Cell[16233405, 663280, 177, 3, 37, "Print"],
Cell[16233585, 663285, 157, 3, 37, "Print"],
Cell[16233745, 663290, 161, 3, 37, "Print"],
Cell[16233909, 663295, 60, 1, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16234006, 663301, 44, 1, 35, "Input"],
Cell[16234053, 663304, 38, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16234128, 663310, 36, 1, 35, "Input"],
Cell[16234167, 663313, 324325, 6245, 36720, "Output"]
}, Closed]],
Cell[16558507, 669561, 382, 6, 115, "Input"],

Cell[CellGroupData[{
Cell[16558914, 669571, 82, 1, 35, "Input"],
Cell[16558999, 669574, 51, 1, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16559087, 669580, 37, 1, 35, "Input"],
Cell[16559127, 669583, 450591, 8628, 40217, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[17009755, 678216, 35, 1, 35, "Input"],
Cell[17009793, 678219, 266, 4, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17010096, 678228, 47, 1, 35, "Input"],
Cell[17010146, 678231, 46, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17010229, 678237, 293, 6, 67, "Input"],
Cell[17010525, 678245, 60, 1, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17010622, 678251, 695, 12, 131, "Input"],

Cell[CellGroupData[{
Cell[17011342, 678267, 815968, 37440, 371, 527365, 33874, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17827313, 715709, 838609, 41109, 371, 593708, 38082, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18665925, 756820, 739756, 39096, 371, 578348, 37100, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19405684, 795918, 690608, 36696, 371, 543277, 34874, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20096341, 832620, 439, 9, 83, "Input"],
Cell[20096783, 832631, 917859, 42024, 433, 597998, 38072, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21014679, 874660, 432, 8, 67, "Input"],

Cell[CellGroupData[{
Cell[21015136, 874672, 213278, 6849, 413, 68696, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21228417, 881523, 216202, 6858, 413, 70911, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21444622, 888383, 216366, 6861, 413, 70860, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21660991, 895246, 215952, 6856, 413, 70827, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21876946, 902104, 216899, 6868, 413, 70822, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22093848, 908974, 216507, 6863, 413, 70819, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22310358, 915839, 216731, 6866, 413, 70828, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22527092, 922707, 216341, 6861, 413, 70819, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22743436, 929570, 217393, 6874, 413, 70810, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22960832, 936446, 216974, 6869, 413, 70816, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23177809, 943317, 217196, 6872, 413, 70807, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23395008, 950191, 216818, 6867, 413, 70798, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23611829, 957060, 217426, 6875, 413, 70786, 5061, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[23829270, 963938, 1672, 41, 63, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

